import { Construct } from 'constructs';
import { TerraformResource } from 'cdktf';
import { TerraformMetaArguments } from 'cdktf';
import { ComplexComputedList } from "cdktf";
/**
 *
 */
export interface AppServiceConfig extends TerraformMetaArguments {
    /**
     *
     */
    readonly appServicePlanId: string;
    /**
     *
     */
    readonly appSettings?: {
        [key: string]: string;
    };
    /**
     *
     */
    readonly clientAffinityEnabled?: boolean;
    /**
     *
     */
    readonly clientCertEnabled?: boolean;
    /**
     *
     */
    readonly enabled?: boolean;
    /**
     *
     */
    readonly httpsOnly?: boolean;
    /**
     *
     */
    readonly location: string;
    /**
     *
     */
    readonly name: string;
    /**
     *
     */
    readonly resourceGroupName: string;
    /**
     *
     */
    readonly tags?: {
        [key: string]: string;
    };
    /**
     * auth_settings block.
     */
    readonly authSettings?: AppServiceAuthSettings[];
    /**
     * backup block.
     */
    readonly backup?: AppServiceBackup[];
    /**
     * connection_string block.
     */
    readonly connectionString?: AppServiceConnectionString[];
    /**
     * identity block.
     */
    readonly identity?: AppServiceIdentity[];
    /**
     * logs block.
     */
    readonly logs?: AppServiceLogs[];
    /**
     * site_config block.
     */
    readonly siteConfig?: AppServiceSiteConfig[];
    /**
     * storage_account block.
     */
    readonly storageAccount?: AppServiceStorageAccount[];
    /**
     * timeouts block.
     */
    readonly timeouts?: AppServiceTimeouts;
}
/**
 *
 */
export declare class AppServiceSiteCredential extends ComplexComputedList {
    /**
     *
     */
    get password(): string;
    /**
     *
     */
    get username(): string;
}
/**
 *
 */
export declare class AppServiceSourceControl extends ComplexComputedList {
    /**
     *
     */
    get branch(): string;
    /**
     *
     */
    get repoUrl(): string;
}
/**
 *
 */
export interface AppServiceAuthSettingsActiveDirectory {
    /**
     *
     */
    readonly allowedAudiences?: string[];
    /**
     *
     */
    readonly clientId: string;
    /**
     *
     */
    readonly clientSecret?: string;
}
/**
 *
 */
export interface AppServiceAuthSettingsFacebook {
    /**
     *
     */
    readonly appId: string;
    /**
     *
     */
    readonly appSecret: string;
    /**
     *
     */
    readonly oauthScopes?: string[];
}
/**
 *
 */
export interface AppServiceAuthSettingsGoogle {
    /**
     *
     */
    readonly clientId: string;
    /**
     *
     */
    readonly clientSecret: string;
    /**
     *
     */
    readonly oauthScopes?: string[];
}
/**
 *
 */
export interface AppServiceAuthSettingsMicrosoft {
    /**
     *
     */
    readonly clientId: string;
    /**
     *
     */
    readonly clientSecret: string;
    /**
     *
     */
    readonly oauthScopes?: string[];
}
/**
 *
 */
export interface AppServiceAuthSettingsTwitter {
    /**
     *
     */
    readonly consumerKey: string;
    /**
     *
     */
    readonly consumerSecret: string;
}
/**
 *
 */
export interface AppServiceAuthSettings {
    /**
     *
     */
    readonly additionalLoginParams?: {
        [key: string]: string;
    };
    /**
     *
     */
    readonly allowedExternalRedirectUrls?: string[];
    /**
     *
     */
    readonly defaultProvider?: string;
    /**
     *
     */
    readonly enabled: boolean;
    /**
     *
     */
    readonly issuer?: string;
    /**
     *
     */
    readonly runtimeVersion?: string;
    /**
     *
     */
    readonly tokenRefreshExtensionHours?: number;
    /**
     *
     */
    readonly tokenStoreEnabled?: boolean;
    /**
     *
     */
    readonly unauthenticatedClientAction?: string;
    /**
     * active_directory block.
     */
    readonly activeDirectory?: AppServiceAuthSettingsActiveDirectory[];
    /**
     * facebook block.
     */
    readonly facebook?: AppServiceAuthSettingsFacebook[];
    /**
     * google block.
     */
    readonly google?: AppServiceAuthSettingsGoogle[];
    /**
     * microsoft block.
     */
    readonly microsoft?: AppServiceAuthSettingsMicrosoft[];
    /**
     * twitter block.
     */
    readonly twitter?: AppServiceAuthSettingsTwitter[];
}
/**
 *
 */
export interface AppServiceBackupSchedule {
    /**
     *
     */
    readonly frequencyInterval: number;
    /**
     *
     */
    readonly frequencyUnit: string;
    /**
     *
     */
    readonly keepAtLeastOneBackup?: boolean;
    /**
     *
     */
    readonly retentionPeriodInDays?: number;
    /**
     *
     */
    readonly startTime?: string;
}
/**
 *
 */
export interface AppServiceBackup {
    /**
     *
     */
    readonly enabled?: boolean;
    /**
     *
     */
    readonly name: string;
    /**
     *
     */
    readonly storageAccountUrl: string;
    /**
     * schedule block.
     */
    readonly schedule: AppServiceBackupSchedule[];
}
/**
 *
 */
export interface AppServiceConnectionString {
    /**
     *
     */
    readonly name: string;
    /**
     *
     */
    readonly type: string;
    /**
     *
     */
    readonly value: string;
}
/**
 *
 */
export interface AppServiceIdentity {
    /**
     *
     */
    readonly identityIds?: string[];
    /**
     *
     */
    readonly type: string;
}
/**
 *
 */
export interface AppServiceLogsApplicationLogsAzureBlobStorage {
    /**
     *
     */
    readonly level: string;
    /**
     *
     */
    readonly retentionInDays: number;
    /**
     *
     */
    readonly sasUrl: string;
}
/**
 *
 */
export interface AppServiceLogsApplicationLogs {
    /**
     * azure_blob_storage block.
     */
    readonly azureBlobStorage?: AppServiceLogsApplicationLogsAzureBlobStorage[];
}
/**
 *
 */
export interface AppServiceLogsHttpLogsAzureBlobStorage {
    /**
     *
     */
    readonly retentionInDays: number;
    /**
     *
     */
    readonly sasUrl: string;
}
/**
 *
 */
export interface AppServiceLogsHttpLogsFileSystem {
    /**
     *
     */
    readonly retentionInDays: number;
    /**
     *
     */
    readonly retentionInMb: number;
}
/**
 *
 */
export interface AppServiceLogsHttpLogs {
    /**
     * azure_blob_storage block.
     */
    readonly azureBlobStorage?: AppServiceLogsHttpLogsAzureBlobStorage[];
    /**
     * file_system block.
     */
    readonly fileSystem?: AppServiceLogsHttpLogsFileSystem[];
}
/**
 *
 */
export interface AppServiceLogs {
    /**
     * application_logs block.
     */
    readonly applicationLogs?: AppServiceLogsApplicationLogs[];
    /**
     * http_logs block.
     */
    readonly httpLogs?: AppServiceLogsHttpLogs[];
}
/**
 *
 */
export interface AppServiceSiteConfigIpRestriction {
    /**
     *
     */
    readonly ipAddress?: string;
    /**
     *
     */
    readonly virtualNetworkSubnetId?: string;
}
/**
 *
 */
export interface AppServiceSiteConfigCors {
    /**
     *
     */
    readonly allowedOrigins: string[];
    /**
     *
     */
    readonly supportCredentials?: boolean;
}
/**
 *
 */
export interface AppServiceSiteConfig {
    /**
     *
     */
    readonly alwaysOn?: boolean;
    /**
     *
     */
    readonly appCommandLine?: string;
    /**
     *
     */
    readonly autoSwapSlotName?: string;
    /**
     *
     */
    readonly defaultDocuments?: string[];
    /**
     *
     */
    readonly dotnetFrameworkVersion?: string;
    /**
     *
     */
    readonly ftpsState?: string;
    /**
     *
     */
    readonly http2Enabled?: boolean;
    /**
     *
     */
    readonly ipRestriction?: AppServiceSiteConfigIpRestriction[];
    /**
     *
     */
    readonly javaContainer?: string;
    /**
     *
     */
    readonly javaContainerVersion?: string;
    /**
     *
     */
    readonly javaVersion?: string;
    /**
     *
     */
    readonly linuxFxVersion?: string;
    /**
     *
     */
    readonly localMysqlEnabled?: boolean;
    /**
     *
     */
    readonly managedPipelineMode?: string;
    /**
     *
     */
    readonly minTlsVersion?: string;
    /**
     *
     */
    readonly phpVersion?: string;
    /**
     *
     */
    readonly pythonVersion?: string;
    /**
     *
     */
    readonly remoteDebuggingEnabled?: boolean;
    /**
     *
     */
    readonly remoteDebuggingVersion?: string;
    /**
     *
     */
    readonly scmType?: string;
    /**
     *
     */
    readonly use32BitWorkerProcess?: boolean;
    /**
     *
     */
    readonly websocketsEnabled?: boolean;
    /**
     *
     */
    readonly windowsFxVersion?: string;
    /**
     * cors block.
     */
    readonly cors?: AppServiceSiteConfigCors[];
}
/**
 *
 */
export interface AppServiceStorageAccount {
    /**
     *
     */
    readonly accessKey: string;
    /**
     *
     */
    readonly accountName: string;
    /**
     *
     */
    readonly mountPath?: string;
    /**
     *
     */
    readonly name: string;
    /**
     *
     */
    readonly shareName: string;
    /**
     *
     */
    readonly type: string;
}
/**
 *
 */
export interface AppServiceTimeouts {
    /**
     *
     */
    readonly create?: string;
    /**
     *
     */
    readonly delete?: string;
    /**
     *
     */
    readonly read?: string;
    /**
     *
     */
    readonly update?: string;
}
/**
 *
 */
export declare class AppService extends TerraformResource {
    /**
     *
     */
    constructor(scope: Construct, id: string, config: AppServiceConfig);
    private _appServicePlanId;
    /**
     *
     */
    get appServicePlanId(): string;
    /**
     *
     */
    set appServicePlanId(value: string);
    private _appSettings?;
    /**
     *
     */
    get appSettings(): {
        [key: string]: string;
    } | undefined;
    /**
     *
     */
    set appSettings(value: {
        [key: string]: string;
    } | undefined);
    private _clientAffinityEnabled?;
    /**
     *
     */
    get clientAffinityEnabled(): boolean | undefined;
    /**
     *
     */
    set clientAffinityEnabled(value: boolean | undefined);
    private _clientCertEnabled?;
    /**
     *
     */
    get clientCertEnabled(): boolean | undefined;
    /**
     *
     */
    set clientCertEnabled(value: boolean | undefined);
    /**
     *
     */
    get defaultSiteHostname(): string;
    private _enabled?;
    /**
     *
     */
    get enabled(): boolean | undefined;
    /**
     *
     */
    set enabled(value: boolean | undefined);
    private _httpsOnly?;
    /**
     *
     */
    get httpsOnly(): boolean | undefined;
    /**
     *
     */
    set httpsOnly(value: boolean | undefined);
    private _id?;
    /**
     *
     */
    get id(): string | undefined;
    /**
     *
     */
    set id(value: string | undefined);
    private _location;
    /**
     *
     */
    get location(): string;
    /**
     *
     */
    set location(value: string);
    private _name;
    /**
     *
     */
    get name(): string;
    /**
     *
     */
    set name(value: string);
    /**
     *
     */
    get outboundIpAddresses(): string;
    /**
     *
     */
    get possibleOutboundIpAddresses(): string;
    private _resourceGroupName;
    /**
     *
     */
    get resourceGroupName(): string;
    /**
     *
     */
    set resourceGroupName(value: string);
    /**
     *
     */
    siteCredential(index: string): AppServiceSiteCredential;
    /**
     *
     */
    sourceControl(index: string): AppServiceSourceControl;
    private _tags?;
    /**
     *
     */
    get tags(): {
        [key: string]: string;
    } | undefined;
    /**
     *
     */
    set tags(value: {
        [key: string]: string;
    } | undefined);
    private _authSettings?;
    /**
     *
     */
    get authSettings(): AppServiceAuthSettings[] | undefined;
    /**
     *
     */
    set authSettings(value: AppServiceAuthSettings[] | undefined);
    private _backup?;
    /**
     *
     */
    get backup(): AppServiceBackup[] | undefined;
    /**
     *
     */
    set backup(value: AppServiceBackup[] | undefined);
    private _connectionString?;
    /**
     *
     */
    get connectionString(): AppServiceConnectionString[] | undefined;
    /**
     *
     */
    set connectionString(value: AppServiceConnectionString[] | undefined);
    private _identity?;
    /**
     *
     */
    get identity(): AppServiceIdentity[] | undefined;
    /**
     *
     */
    set identity(value: AppServiceIdentity[] | undefined);
    private _logs?;
    /**
     *
     */
    get logs(): AppServiceLogs[] | undefined;
    /**
     *
     */
    set logs(value: AppServiceLogs[] | undefined);
    private _siteConfig?;
    /**
     *
     */
    get siteConfig(): AppServiceSiteConfig[] | undefined;
    /**
     *
     */
    set siteConfig(value: AppServiceSiteConfig[] | undefined);
    private _storageAccount?;
    /**
     *
     */
    get storageAccount(): AppServiceStorageAccount[] | undefined;
    /**
     *
     */
    set storageAccount(value: AppServiceStorageAccount[] | undefined);
    private _timeouts?;
    /**
     *
     */
    get timeouts(): AppServiceTimeouts | undefined;
    /**
     *
     */
    set timeouts(value: AppServiceTimeouts | undefined);
    /**
     *
     */
    protected synthesizeAttributes(): {
        [name: string]: any;
    };
}
