import { Construct } from 'constructs';
import { TerraformResource } from 'cdktf';
import { TerraformMetaArguments } from 'cdktf';
/**
 *
 */
export interface FrontdoorConfig extends TerraformMetaArguments {
    /**
     *
     */
    readonly enforceBackendPoolsCertificateNameCheck: boolean;
    /**
     *
     */
    readonly friendlyName?: string;
    /**
     *
     */
    readonly loadBalancerEnabled?: boolean;
    /**
     *
     */
    readonly location: string;
    /**
     *
     */
    readonly name: string;
    /**
     *
     */
    readonly resourceGroupName: string;
    /**
     *
     */
    readonly tags?: {
        [key: string]: string;
    };
    /**
     * backend_pool block.
     */
    readonly backendPool: FrontdoorBackendPool[];
    /**
     * backend_pool_health_probe block.
     */
    readonly backendPoolHealthProbe: FrontdoorBackendPoolHealthProbe[];
    /**
     * backend_pool_load_balancing block.
     */
    readonly backendPoolLoadBalancing: FrontdoorBackendPoolLoadBalancing[];
    /**
     * frontend_endpoint block.
     */
    readonly frontendEndpoint: FrontdoorFrontendEndpoint[];
    /**
     * routing_rule block.
     */
    readonly routingRule: FrontdoorRoutingRule[];
    /**
     * timeouts block.
     */
    readonly timeouts?: FrontdoorTimeouts;
}
/**
 *
 */
export interface FrontdoorBackendPoolBackend {
    /**
     *
     */
    readonly address: string;
    /**
     *
     */
    readonly enabled?: boolean;
    /**
     *
     */
    readonly hostHeader: string;
    /**
     *
     */
    readonly httpPort: number;
    /**
     *
     */
    readonly httpsPort: number;
    /**
     *
     */
    readonly priority?: number;
    /**
     *
     */
    readonly weight?: number;
}
/**
 *
 */
export interface FrontdoorBackendPool {
    /**
     *
     */
    readonly healthProbeName: string;
    /**
     *
     */
    readonly loadBalancingName: string;
    /**
     *
     */
    readonly name: string;
    /**
     * backend block.
     */
    readonly backend: FrontdoorBackendPoolBackend[];
}
/**
 *
 */
export interface FrontdoorBackendPoolHealthProbe {
    /**
     *
     */
    readonly intervalInSeconds?: number;
    /**
     *
     */
    readonly name: string;
    /**
     *
     */
    readonly path?: string;
    /**
     *
     */
    readonly protocol?: string;
}
/**
 *
 */
export interface FrontdoorBackendPoolLoadBalancing {
    /**
     *
     */
    readonly additionalLatencyMilliseconds?: number;
    /**
     *
     */
    readonly name: string;
    /**
     *
     */
    readonly sampleSize?: number;
    /**
     *
     */
    readonly successfulSamplesRequired?: number;
}
/**
 *
 */
export interface FrontdoorFrontendEndpointCustomHttpsConfiguration {
    /**
     *
     */
    readonly azureKeyVaultCertificateSecretName?: string;
    /**
     *
     */
    readonly azureKeyVaultCertificateSecretVersion?: string;
    /**
     *
     */
    readonly azureKeyVaultCertificateVaultId?: string;
    /**
     *
     */
    readonly certificateSource?: string;
}
/**
 *
 */
export interface FrontdoorFrontendEndpoint {
    /**
     *
     */
    readonly customHttpsProvisioningEnabled: boolean;
    /**
     *
     */
    readonly hostName: string;
    /**
     *
     */
    readonly name: string;
    /**
     *
     */
    readonly sessionAffinityEnabled?: boolean;
    /**
     *
     */
    readonly sessionAffinityTtlSeconds?: number;
    /**
     *
     */
    readonly webApplicationFirewallPolicyLinkId?: string;
    /**
     * custom_https_configuration block.
     */
    readonly customHttpsConfiguration?: FrontdoorFrontendEndpointCustomHttpsConfiguration[];
}
/**
 *
 */
export interface FrontdoorRoutingRuleForwardingConfiguration {
    /**
     *
     */
    readonly backendPoolName: string;
    /**
     *
     */
    readonly cacheEnabled?: boolean;
    /**
     *
     */
    readonly cacheQueryParameterStripDirective?: string;
    /**
     *
     */
    readonly cacheUseDynamicCompression?: boolean;
    /**
     *
     */
    readonly customForwardingPath?: string;
    /**
     *
     */
    readonly forwardingProtocol?: string;
}
/**
 *
 */
export interface FrontdoorRoutingRuleRedirectConfiguration {
    /**
     *
     */
    readonly customFragment?: string;
    /**
     *
     */
    readonly customHost?: string;
    /**
     *
     */
    readonly customPath?: string;
    /**
     *
     */
    readonly customQueryString?: string;
    /**
     *
     */
    readonly redirectProtocol: string;
    /**
     *
     */
    readonly redirectType: string;
}
/**
 *
 */
export interface FrontdoorRoutingRule {
    /**
     *
     */
    readonly acceptedProtocols: string[];
    /**
     *
     */
    readonly enabled?: boolean;
    /**
     *
     */
    readonly frontendEndpoints: string[];
    /**
     *
     */
    readonly name: string;
    /**
     *
     */
    readonly patternsToMatch: string[];
    /**
     * forwarding_configuration block.
     */
    readonly forwardingConfiguration?: FrontdoorRoutingRuleForwardingConfiguration[];
    /**
     * redirect_configuration block.
     */
    readonly redirectConfiguration?: FrontdoorRoutingRuleRedirectConfiguration[];
}
/**
 *
 */
export interface FrontdoorTimeouts {
    /**
     *
     */
    readonly create?: string;
    /**
     *
     */
    readonly delete?: string;
    /**
     *
     */
    readonly read?: string;
    /**
     *
     */
    readonly update?: string;
}
/**
 *
 */
export declare class Frontdoor extends TerraformResource {
    /**
     *
     */
    constructor(scope: Construct, id: string, config: FrontdoorConfig);
    /**
     *
     */
    get cname(): string;
    private _enforceBackendPoolsCertificateNameCheck;
    /**
     *
     */
    get enforceBackendPoolsCertificateNameCheck(): boolean;
    /**
     *
     */
    set enforceBackendPoolsCertificateNameCheck(value: boolean);
    private _friendlyName?;
    /**
     *
     */
    get friendlyName(): string | undefined;
    /**
     *
     */
    set friendlyName(value: string | undefined);
    private _id?;
    /**
     *
     */
    get id(): string | undefined;
    /**
     *
     */
    set id(value: string | undefined);
    private _loadBalancerEnabled?;
    /**
     *
     */
    get loadBalancerEnabled(): boolean | undefined;
    /**
     *
     */
    set loadBalancerEnabled(value: boolean | undefined);
    private _location;
    /**
     *
     */
    get location(): string;
    /**
     *
     */
    set location(value: string);
    private _name;
    /**
     *
     */
    get name(): string;
    /**
     *
     */
    set name(value: string);
    private _resourceGroupName;
    /**
     *
     */
    get resourceGroupName(): string;
    /**
     *
     */
    set resourceGroupName(value: string);
    private _tags?;
    /**
     *
     */
    get tags(): {
        [key: string]: string;
    } | undefined;
    /**
     *
     */
    set tags(value: {
        [key: string]: string;
    } | undefined);
    private _backendPool;
    /**
     *
     */
    get backendPool(): FrontdoorBackendPool[];
    /**
     *
     */
    set backendPool(value: FrontdoorBackendPool[]);
    private _backendPoolHealthProbe;
    /**
     *
     */
    get backendPoolHealthProbe(): FrontdoorBackendPoolHealthProbe[];
    /**
     *
     */
    set backendPoolHealthProbe(value: FrontdoorBackendPoolHealthProbe[]);
    private _backendPoolLoadBalancing;
    /**
     *
     */
    get backendPoolLoadBalancing(): FrontdoorBackendPoolLoadBalancing[];
    /**
     *
     */
    set backendPoolLoadBalancing(value: FrontdoorBackendPoolLoadBalancing[]);
    private _frontendEndpoint;
    /**
     *
     */
    get frontendEndpoint(): FrontdoorFrontendEndpoint[];
    /**
     *
     */
    set frontendEndpoint(value: FrontdoorFrontendEndpoint[]);
    private _routingRule;
    /**
     *
     */
    get routingRule(): FrontdoorRoutingRule[];
    /**
     *
     */
    set routingRule(value: FrontdoorRoutingRule[]);
    private _timeouts?;
    /**
     *
     */
    get timeouts(): FrontdoorTimeouts | undefined;
    /**
     *
     */
    set timeouts(value: FrontdoorTimeouts | undefined);
    /**
     *
     */
    protected synthesizeAttributes(): {
        [name: string]: any;
    };
}
