import { Construct } from 'constructs';
import { TerraformResource } from 'cdktf';
import { TerraformMetaArguments } from 'cdktf';
import { ComplexComputedList } from "cdktf";
/**
 *
 */
export interface FunctionAppConfig extends TerraformMetaArguments {
    /**
     *
     */
    readonly appServicePlanId: string;
    /**
     *
     */
    readonly appSettings?: {
        [key: string]: string;
    };
    /**
     *
     */
    readonly clientAffinityEnabled?: boolean;
    /**
     *
     */
    readonly enableBuiltinLogging?: boolean;
    /**
     *
     */
    readonly enabled?: boolean;
    /**
     *
     */
    readonly httpsOnly?: boolean;
    /**
     *
     */
    readonly location: string;
    /**
     *
     */
    readonly name: string;
    /**
     *
     */
    readonly resourceGroupName: string;
    /**
     *
     */
    readonly storageConnectionString: string;
    /**
     *
     */
    readonly tags?: {
        [key: string]: string;
    };
    /**
     *
     */
    readonly version?: string;
    /**
     * auth_settings block.
     */
    readonly authSettings?: FunctionAppAuthSettings[];
    /**
     * connection_string block.
     */
    readonly connectionString?: FunctionAppConnectionString[];
    /**
     * identity block.
     */
    readonly identity?: FunctionAppIdentity[];
    /**
     * site_config block.
     */
    readonly siteConfig?: FunctionAppSiteConfig[];
    /**
     * timeouts block.
     */
    readonly timeouts?: FunctionAppTimeouts;
}
/**
 *
 */
export declare class FunctionAppSiteCredential extends ComplexComputedList {
    /**
     *
     */
    get password(): string;
    /**
     *
     */
    get username(): string;
}
/**
 *
 */
export interface FunctionAppAuthSettingsActiveDirectory {
    /**
     *
     */
    readonly allowedAudiences?: string[];
    /**
     *
     */
    readonly clientId: string;
    /**
     *
     */
    readonly clientSecret?: string;
}
/**
 *
 */
export interface FunctionAppAuthSettingsFacebook {
    /**
     *
     */
    readonly appId: string;
    /**
     *
     */
    readonly appSecret: string;
    /**
     *
     */
    readonly oauthScopes?: string[];
}
/**
 *
 */
export interface FunctionAppAuthSettingsGoogle {
    /**
     *
     */
    readonly clientId: string;
    /**
     *
     */
    readonly clientSecret: string;
    /**
     *
     */
    readonly oauthScopes?: string[];
}
/**
 *
 */
export interface FunctionAppAuthSettingsMicrosoft {
    /**
     *
     */
    readonly clientId: string;
    /**
     *
     */
    readonly clientSecret: string;
    /**
     *
     */
    readonly oauthScopes?: string[];
}
/**
 *
 */
export interface FunctionAppAuthSettingsTwitter {
    /**
     *
     */
    readonly consumerKey: string;
    /**
     *
     */
    readonly consumerSecret: string;
}
/**
 *
 */
export interface FunctionAppAuthSettings {
    /**
     *
     */
    readonly additionalLoginParams?: {
        [key: string]: string;
    };
    /**
     *
     */
    readonly allowedExternalRedirectUrls?: string[];
    /**
     *
     */
    readonly defaultProvider?: string;
    /**
     *
     */
    readonly enabled: boolean;
    /**
     *
     */
    readonly issuer?: string;
    /**
     *
     */
    readonly runtimeVersion?: string;
    /**
     *
     */
    readonly tokenRefreshExtensionHours?: number;
    /**
     *
     */
    readonly tokenStoreEnabled?: boolean;
    /**
     *
     */
    readonly unauthenticatedClientAction?: string;
    /**
     * active_directory block.
     */
    readonly activeDirectory?: FunctionAppAuthSettingsActiveDirectory[];
    /**
     * facebook block.
     */
    readonly facebook?: FunctionAppAuthSettingsFacebook[];
    /**
     * google block.
     */
    readonly google?: FunctionAppAuthSettingsGoogle[];
    /**
     * microsoft block.
     */
    readonly microsoft?: FunctionAppAuthSettingsMicrosoft[];
    /**
     * twitter block.
     */
    readonly twitter?: FunctionAppAuthSettingsTwitter[];
}
/**
 *
 */
export interface FunctionAppConnectionString {
    /**
     *
     */
    readonly name: string;
    /**
     *
     */
    readonly type: string;
    /**
     *
     */
    readonly value: string;
}
/**
 *
 */
export interface FunctionAppIdentity {
    /**
     *
     */
    readonly identityIds?: string[];
    /**
     *
     */
    readonly type: string;
}
/**
 *
 */
export interface FunctionAppSiteConfigIpRestriction {
    /**
     *
     */
    readonly ipAddress?: string;
    /**
     *
     */
    readonly subnetId?: string;
}
/**
 *
 */
export interface FunctionAppSiteConfigCors {
    /**
     *
     */
    readonly allowedOrigins: string[];
    /**
     *
     */
    readonly supportCredentials?: boolean;
}
/**
 *
 */
export interface FunctionAppSiteConfig {
    /**
     *
     */
    readonly alwaysOn?: boolean;
    /**
     *
     */
    readonly ftpsState?: string;
    /**
     *
     */
    readonly http2Enabled?: boolean;
    /**
     *
     */
    readonly ipRestriction?: FunctionAppSiteConfigIpRestriction[];
    /**
     *
     */
    readonly linuxFxVersion?: string;
    /**
     *
     */
    readonly minTlsVersion?: string;
    /**
     *
     */
    readonly use32BitWorkerProcess?: boolean;
    /**
     *
     */
    readonly websocketsEnabled?: boolean;
    /**
     * cors block.
     */
    readonly cors?: FunctionAppSiteConfigCors[];
}
/**
 *
 */
export interface FunctionAppTimeouts {
    /**
     *
     */
    readonly create?: string;
    /**
     *
     */
    readonly delete?: string;
    /**
     *
     */
    readonly read?: string;
    /**
     *
     */
    readonly update?: string;
}
/**
 *
 */
export declare class FunctionApp extends TerraformResource {
    /**
     *
     */
    constructor(scope: Construct, id: string, config: FunctionAppConfig);
    private _appServicePlanId;
    /**
     *
     */
    get appServicePlanId(): string;
    /**
     *
     */
    set appServicePlanId(value: string);
    private _appSettings?;
    /**
     *
     */
    get appSettings(): {
        [key: string]: string;
    } | undefined;
    /**
     *
     */
    set appSettings(value: {
        [key: string]: string;
    } | undefined);
    private _clientAffinityEnabled?;
    /**
     *
     */
    get clientAffinityEnabled(): boolean | undefined;
    /**
     *
     */
    set clientAffinityEnabled(value: boolean | undefined);
    /**
     *
     */
    get defaultHostname(): string;
    private _enableBuiltinLogging?;
    /**
     *
     */
    get enableBuiltinLogging(): boolean | undefined;
    /**
     *
     */
    set enableBuiltinLogging(value: boolean | undefined);
    private _enabled?;
    /**
     *
     */
    get enabled(): boolean | undefined;
    /**
     *
     */
    set enabled(value: boolean | undefined);
    private _httpsOnly?;
    /**
     *
     */
    get httpsOnly(): boolean | undefined;
    /**
     *
     */
    set httpsOnly(value: boolean | undefined);
    private _id?;
    /**
     *
     */
    get id(): string | undefined;
    /**
     *
     */
    set id(value: string | undefined);
    /**
     *
     */
    get kind(): string;
    private _location;
    /**
     *
     */
    get location(): string;
    /**
     *
     */
    set location(value: string);
    private _name;
    /**
     *
     */
    get name(): string;
    /**
     *
     */
    set name(value: string);
    /**
     *
     */
    get outboundIpAddresses(): string;
    /**
     *
     */
    get possibleOutboundIpAddresses(): string;
    private _resourceGroupName;
    /**
     *
     */
    get resourceGroupName(): string;
    /**
     *
     */
    set resourceGroupName(value: string);
    /**
     *
     */
    siteCredential(index: string): FunctionAppSiteCredential;
    private _storageConnectionString;
    /**
     *
     */
    get storageConnectionString(): string;
    /**
     *
     */
    set storageConnectionString(value: string);
    private _tags?;
    /**
     *
     */
    get tags(): {
        [key: string]: string;
    } | undefined;
    /**
     *
     */
    set tags(value: {
        [key: string]: string;
    } | undefined);
    private _version?;
    /**
     *
     */
    get version(): string | undefined;
    /**
     *
     */
    set version(value: string | undefined);
    private _authSettings?;
    /**
     *
     */
    get authSettings(): FunctionAppAuthSettings[] | undefined;
    /**
     *
     */
    set authSettings(value: FunctionAppAuthSettings[] | undefined);
    private _connectionString?;
    /**
     *
     */
    get connectionString(): FunctionAppConnectionString[] | undefined;
    /**
     *
     */
    set connectionString(value: FunctionAppConnectionString[] | undefined);
    private _identity?;
    /**
     *
     */
    get identity(): FunctionAppIdentity[] | undefined;
    /**
     *
     */
    set identity(value: FunctionAppIdentity[] | undefined);
    private _siteConfig?;
    /**
     *
     */
    get siteConfig(): FunctionAppSiteConfig[] | undefined;
    /**
     *
     */
    set siteConfig(value: FunctionAppSiteConfig[] | undefined);
    private _timeouts?;
    /**
     *
     */
    get timeouts(): FunctionAppTimeouts | undefined;
    /**
     *
     */
    set timeouts(value: FunctionAppTimeouts | undefined);
    /**
     *
     */
    protected synthesizeAttributes(): {
        [name: string]: any;
    };
}
