import { Construct } from 'constructs';
import { TerraformResource } from 'cdktf';
import { TerraformMetaArguments } from 'cdktf';
/**
 *
 */
export interface VpnServerConfigurationConfig extends TerraformMetaArguments {
    /**
     *
     */
    readonly location: string;
    /**
     *
     */
    readonly name: string;
    /**
     *
     */
    readonly resourceGroupName: string;
    /**
     *
     */
    readonly tags?: {
        [key: string]: string;
    };
    /**
     *
     */
    readonly vpnAuthenticationTypes: string[];
    /**
     *
     */
    readonly vpnProtocols?: string[];
    /**
     * azure_active_directory_authentication block.
     */
    readonly azureActiveDirectoryAuthentication?: VpnServerConfigurationAzureActiveDirectoryAuthentication[];
    /**
     * client_revoked_certificate block.
     */
    readonly clientRevokedCertificate?: VpnServerConfigurationClientRevokedCertificate[];
    /**
     * client_root_certificate block.
     */
    readonly clientRootCertificate?: VpnServerConfigurationClientRootCertificate[];
    /**
     * ipsec_policy block.
     */
    readonly ipsecPolicy?: VpnServerConfigurationIpsecPolicy[];
    /**
     * radius_server block.
     */
    readonly radiusServer?: VpnServerConfigurationRadiusServer[];
    /**
     * timeouts block.
     */
    readonly timeouts?: VpnServerConfigurationTimeouts;
}
/**
 *
 */
export interface VpnServerConfigurationAzureActiveDirectoryAuthentication {
    /**
     *
     */
    readonly audience: string;
    /**
     *
     */
    readonly issuer: string;
    /**
     *
     */
    readonly tenant: string;
}
/**
 *
 */
export interface VpnServerConfigurationClientRevokedCertificate {
    /**
     *
     */
    readonly name: string;
    /**
     *
     */
    readonly thumbprint: string;
}
/**
 *
 */
export interface VpnServerConfigurationClientRootCertificate {
    /**
     *
     */
    readonly name: string;
    /**
     *
     */
    readonly publicCertData: string;
}
/**
 *
 */
export interface VpnServerConfigurationIpsecPolicy {
    /**
     *
     */
    readonly dhGroup: string;
    /**
     *
     */
    readonly ikeEncryption: string;
    /**
     *
     */
    readonly ikeIntegrity: string;
    /**
     *
     */
    readonly ipsecEncryption: string;
    /**
     *
     */
    readonly ipsecIntegrity: string;
    /**
     *
     */
    readonly pfsGroup: string;
    /**
     *
     */
    readonly saDataSizeKilobytes: number;
    /**
     *
     */
    readonly saLifetimeSeconds: number;
}
/**
 *
 */
export interface VpnServerConfigurationRadiusServerClientRootCertificate {
    /**
     *
     */
    readonly name: string;
    /**
     *
     */
    readonly thumbprint: string;
}
/**
 *
 */
export interface VpnServerConfigurationRadiusServerServerRootCertificate {
    /**
     *
     */
    readonly name: string;
    /**
     *
     */
    readonly publicCertData: string;
}
/**
 *
 */
export interface VpnServerConfigurationRadiusServer {
    /**
     *
     */
    readonly address: string;
    /**
     *
     */
    readonly secret: string;
    /**
     * client_root_certificate block.
     */
    readonly clientRootCertificate?: VpnServerConfigurationRadiusServerClientRootCertificate[];
    /**
     * server_root_certificate block.
     */
    readonly serverRootCertificate: VpnServerConfigurationRadiusServerServerRootCertificate[];
}
/**
 *
 */
export interface VpnServerConfigurationTimeouts {
    /**
     *
     */
    readonly create?: string;
    /**
     *
     */
    readonly delete?: string;
    /**
     *
     */
    readonly read?: string;
    /**
     *
     */
    readonly update?: string;
}
/**
 *
 */
export declare class VpnServerConfiguration extends TerraformResource {
    /**
     *
     */
    constructor(scope: Construct, id: string, config: VpnServerConfigurationConfig);
    private _id?;
    /**
     *
     */
    get id(): string | undefined;
    /**
     *
     */
    set id(value: string | undefined);
    private _location;
    /**
     *
     */
    get location(): string;
    /**
     *
     */
    set location(value: string);
    private _name;
    /**
     *
     */
    get name(): string;
    /**
     *
     */
    set name(value: string);
    private _resourceGroupName;
    /**
     *
     */
    get resourceGroupName(): string;
    /**
     *
     */
    set resourceGroupName(value: string);
    private _tags?;
    /**
     *
     */
    get tags(): {
        [key: string]: string;
    } | undefined;
    /**
     *
     */
    set tags(value: {
        [key: string]: string;
    } | undefined);
    private _vpnAuthenticationTypes;
    /**
     *
     */
    get vpnAuthenticationTypes(): string[];
    /**
     *
     */
    set vpnAuthenticationTypes(value: string[]);
    private _vpnProtocols?;
    /**
     *
     */
    get vpnProtocols(): string[] | undefined;
    /**
     *
     */
    set vpnProtocols(value: string[] | undefined);
    private _azureActiveDirectoryAuthentication?;
    /**
     *
     */
    get azureActiveDirectoryAuthentication(): VpnServerConfigurationAzureActiveDirectoryAuthentication[] | undefined;
    /**
     *
     */
    set azureActiveDirectoryAuthentication(value: VpnServerConfigurationAzureActiveDirectoryAuthentication[] | undefined);
    private _clientRevokedCertificate?;
    /**
     *
     */
    get clientRevokedCertificate(): VpnServerConfigurationClientRevokedCertificate[] | undefined;
    /**
     *
     */
    set clientRevokedCertificate(value: VpnServerConfigurationClientRevokedCertificate[] | undefined);
    private _clientRootCertificate?;
    /**
     *
     */
    get clientRootCertificate(): VpnServerConfigurationClientRootCertificate[] | undefined;
    /**
     *
     */
    set clientRootCertificate(value: VpnServerConfigurationClientRootCertificate[] | undefined);
    private _ipsecPolicy?;
    /**
     *
     */
    get ipsecPolicy(): VpnServerConfigurationIpsecPolicy[] | undefined;
    /**
     *
     */
    set ipsecPolicy(value: VpnServerConfigurationIpsecPolicy[] | undefined);
    private _radiusServer?;
    /**
     *
     */
    get radiusServer(): VpnServerConfigurationRadiusServer[] | undefined;
    /**
     *
     */
    set radiusServer(value: VpnServerConfigurationRadiusServer[] | undefined);
    private _timeouts?;
    /**
     *
     */
    get timeouts(): VpnServerConfigurationTimeouts | undefined;
    /**
     *
     */
    set timeouts(value: VpnServerConfigurationTimeouts | undefined);
    /**
     *
     */
    protected synthesizeAttributes(): {
        [name: string]: any;
    };
}
