"""
# Terraform CDK azurerm Provider ~> 2.0.0

This repo builds and publishes the Terraform azurerm Provider bindings for [cdktf](https://cdk.tf).

Current build targets are:

* npm
* Pypi

## Versioning

This project is explicitly not tracking the Terraform azurerm Provider version 1:1. In fact, it always tracks `latest` of `~> 2.0.0` with every release. If there scenarios where you explicitly have to pin your provider version, you can do so by generating the [provider constructs manually](https://cdk.tf/imports).

These are the upstream dependencies:

* [Terraform CDK](https://cdk.tf)
* [Terraform azurerm Provider](https://github.com/terraform-providers/terraform-provider-azurerm)
* [Terraform Engine](https://terraform.io)

If there are breaking changes (backward incompatible) in any of the above, the major version of this project will be bumped. While the Terraform Engine and the Terraform azurerm Provider are relatively stable, the Terraform CDK is in an early stage. Therefore, it's likely that there will be breaking changes.

## Features / Issues / Bugs

Please report bugs and issues to the [terraform cdk](https://cdk.tf) project:

* [Create bug report](https://cdk.tf/bug)
* [Create feature request](https://cdk.tf/feature)

## Contributing

## projen

This is mostly based on [projen](https://github.com/eladb/projen), which takes care of generating the entire repository.

## cdktf-provider-project based on projen

There's a custom [project builder](https://github.com/skorfmann/cdktf-provider-project) which encapsulate the common settings for all `cdktf` providers.

## provider version

The provider version can be adjusted in [./.projenrc.js](./.projenrc.js).
"""
import abc
import builtins
import datetime
import enum
import typing

import jsii
import publication
import typing_extensions

from ._jsii import *

import cdktf
import constructs


class AdvancedThreatProtection(
    cdktf.TerraformResource,
    metaclass=jsii.JSIIMeta,
    jsii_type="@cdktf/provider-azurerm.AdvancedThreatProtection",
):
    def __init__(
        self,
        scope: constructs.Construct,
        id: builtins.str,
        *,
        enabled: builtins.bool,
        target_resource_id: builtins.str,
        timeouts: typing.Optional["AdvancedThreatProtectionTimeouts"] = None,
        count: typing.Optional[jsii.Number] = None,
        depends_on: typing.Optional[typing.List[cdktf.TerraformResource]] = None,
        lifecycle: typing.Optional[cdktf.TerraformResourceLifecycle] = None,
        provider: typing.Optional[cdktf.TerraformProvider] = None,
    ) -> None:
        """
        :param scope: -
        :param id: -
        :param enabled: 
        :param target_resource_id: 
        :param timeouts: timeouts block.
        :param count: 
        :param depends_on: 
        :param lifecycle: 
        :param provider: 
        """
        config = AdvancedThreatProtectionConfig(
            enabled=enabled,
            target_resource_id=target_resource_id,
            timeouts=timeouts,
            count=count,
            depends_on=depends_on,
            lifecycle=lifecycle,
            provider=provider,
        )

        jsii.create(AdvancedThreatProtection, self, [scope, id, config])

    @jsii.member(jsii_name="synthesizeAttributes")
    def _synthesize_attributes(self) -> typing.Mapping[builtins.str, typing.Any]:
        return jsii.invoke(self, "synthesizeAttributes", [])

    @builtins.property # type: ignore
    @jsii.member(jsii_name="enabled")
    def enabled(self) -> builtins.bool:
        return jsii.get(self, "enabled")

    @enabled.setter # type: ignore
    def enabled(self, value: builtins.bool) -> None:
        jsii.set(self, "enabled", value)

    @builtins.property # type: ignore
    @jsii.member(jsii_name="targetResourceId")
    def target_resource_id(self) -> builtins.str:
        return jsii.get(self, "targetResourceId")

    @target_resource_id.setter # type: ignore
    def target_resource_id(self, value: builtins.str) -> None:
        jsii.set(self, "targetResourceId", value)

    @builtins.property # type: ignore
    @jsii.member(jsii_name="id")
    def id(self) -> typing.Optional[builtins.str]:
        return jsii.get(self, "id")

    @id.setter # type: ignore
    def id(self, value: typing.Optional[builtins.str]) -> None:
        jsii.set(self, "id", value)

    @builtins.property # type: ignore
    @jsii.member(jsii_name="timeouts")
    def timeouts(self) -> typing.Optional["AdvancedThreatProtectionTimeouts"]:
        return jsii.get(self, "timeouts")

    @timeouts.setter # type: ignore
    def timeouts(
        self,
        value: typing.Optional["AdvancedThreatProtectionTimeouts"],
    ) -> None:
        jsii.set(self, "timeouts", value)


@jsii.data_type(
    jsii_type="@cdktf/provider-azurerm.AdvancedThreatProtectionConfig",
    jsii_struct_bases=[cdktf.TerraformMetaArguments],
    name_mapping={
        "count": "count",
        "depends_on": "dependsOn",
        "lifecycle": "lifecycle",
        "provider": "provider",
        "enabled": "enabled",
        "target_resource_id": "targetResourceId",
        "timeouts": "timeouts",
    },
)
class AdvancedThreatProtectionConfig(cdktf.TerraformMetaArguments):
    def __init__(
        self,
        *,
        count: typing.Optional[jsii.Number] = None,
        depends_on: typing.Optional[typing.List[cdktf.TerraformResource]] = None,
        lifecycle: typing.Optional[cdktf.TerraformResourceLifecycle] = None,
        provider: typing.Optional[cdktf.TerraformProvider] = None,
        enabled: builtins.bool,
        target_resource_id: builtins.str,
        timeouts: typing.Optional["AdvancedThreatProtectionTimeouts"] = None,
    ) -> None:
        """
        :param count: 
        :param depends_on: 
        :param lifecycle: 
        :param provider: 
        :param enabled: 
        :param target_resource_id: 
        :param timeouts: timeouts block.
        """
        if isinstance(lifecycle, dict):
            lifecycle = cdktf.TerraformResourceLifecycle(**lifecycle)
        if isinstance(timeouts, dict):
            timeouts = AdvancedThreatProtectionTimeouts(**timeouts)
        self._values: typing.Dict[str, typing.Any] = {
            "enabled": enabled,
            "target_resource_id": target_resource_id,
        }
        if count is not None:
            self._values["count"] = count
        if depends_on is not None:
            self._values["depends_on"] = depends_on
        if lifecycle is not None:
            self._values["lifecycle"] = lifecycle
        if provider is not None:
            self._values["provider"] = provider
        if timeouts is not None:
            self._values["timeouts"] = timeouts

    @builtins.property
    def count(self) -> typing.Optional[jsii.Number]:
        """
        :stability: experimental
        """
        result = self._values.get("count")
        return result

    @builtins.property
    def depends_on(self) -> typing.Optional[typing.List[cdktf.TerraformResource]]:
        """
        :stability: experimental
        """
        result = self._values.get("depends_on")
        return result

    @builtins.property
    def lifecycle(self) -> typing.Optional[cdktf.TerraformResourceLifecycle]:
        """
        :stability: experimental
        """
        result = self._values.get("lifecycle")
        return result

    @builtins.property
    def provider(self) -> typing.Optional[cdktf.TerraformProvider]:
        """
        :stability: experimental
        """
        result = self._values.get("provider")
        return result

    @builtins.property
    def enabled(self) -> builtins.bool:
        result = self._values.get("enabled")
        assert result is not None, "Required property 'enabled' is missing"
        return result

    @builtins.property
    def target_resource_id(self) -> builtins.str:
        result = self._values.get("target_resource_id")
        assert result is not None, "Required property 'target_resource_id' is missing"
        return result

    @builtins.property
    def timeouts(self) -> typing.Optional["AdvancedThreatProtectionTimeouts"]:
        """timeouts block."""
        result = self._values.get("timeouts")
        return result

    def __eq__(self, rhs: typing.Any) -> builtins.bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs: typing.Any) -> builtins.bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return "AdvancedThreatProtectionConfig(%s)" % ", ".join(
            k + "=" + repr(v) for k, v in self._values.items()
        )


@jsii.data_type(
    jsii_type="@cdktf/provider-azurerm.AdvancedThreatProtectionTimeouts",
    jsii_struct_bases=[],
    name_mapping={
        "create": "create",
        "delete": "delete",
        "read": "read",
        "update": "update",
    },
)
class AdvancedThreatProtectionTimeouts:
    def __init__(
        self,
        *,
        create: typing.Optional[builtins.str] = None,
        delete: typing.Optional[builtins.str] = None,
        read: typing.Optional[builtins.str] = None,
        update: typing.Optional[builtins.str] = None,
    ) -> None:
        """
        :param create: 
        :param delete: 
        :param read: 
        :param update: 
        """
        self._values: typing.Dict[str, typing.Any] = {}
        if create is not None:
            self._values["create"] = create
        if delete is not None:
            self._values["delete"] = delete
        if read is not None:
            self._values["read"] = read
        if update is not None:
            self._values["update"] = update

    @builtins.property
    def create(self) -> typing.Optional[builtins.str]:
        result = self._values.get("create")
        return result

    @builtins.property
    def delete(self) -> typing.Optional[builtins.str]:
        result = self._values.get("delete")
        return result

    @builtins.property
    def read(self) -> typing.Optional[builtins.str]:
        result = self._values.get("read")
        return result

    @builtins.property
    def update(self) -> typing.Optional[builtins.str]:
        result = self._values.get("update")
        return result

    def __eq__(self, rhs: typing.Any) -> builtins.bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs: typing.Any) -> builtins.bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return "AdvancedThreatProtectionTimeouts(%s)" % ", ".join(
            k + "=" + repr(v) for k, v in self._values.items()
        )


class AnalysisServicesServer(
    cdktf.TerraformResource,
    metaclass=jsii.JSIIMeta,
    jsii_type="@cdktf/provider-azurerm.AnalysisServicesServer",
):
    def __init__(
        self,
        scope: constructs.Construct,
        id: builtins.str,
        *,
        location: builtins.str,
        name: builtins.str,
        resource_group_name: builtins.str,
        sku: builtins.str,
        admin_users: typing.Optional[typing.List[builtins.str]] = None,
        backup_blob_container_uri: typing.Optional[builtins.str] = None,
        enable_power_bi_service: typing.Optional[builtins.bool] = None,
        ipv4_firewall_rule: typing.Optional[typing.List["AnalysisServicesServerIpv4FirewallRule"]] = None,
        querypool_connection_mode: typing.Optional[builtins.str] = None,
        tags: typing.Optional[typing.Mapping[builtins.str, builtins.str]] = None,
        timeouts: typing.Optional["AnalysisServicesServerTimeouts"] = None,
        count: typing.Optional[jsii.Number] = None,
        depends_on: typing.Optional[typing.List[cdktf.TerraformResource]] = None,
        lifecycle: typing.Optional[cdktf.TerraformResourceLifecycle] = None,
        provider: typing.Optional[cdktf.TerraformProvider] = None,
    ) -> None:
        """
        :param scope: -
        :param id: -
        :param location: 
        :param name: 
        :param resource_group_name: 
        :param sku: 
        :param admin_users: 
        :param backup_blob_container_uri: 
        :param enable_power_bi_service: 
        :param ipv4_firewall_rule: ipv4_firewall_rule block.
        :param querypool_connection_mode: 
        :param tags: 
        :param timeouts: timeouts block.
        :param count: 
        :param depends_on: 
        :param lifecycle: 
        :param provider: 
        """
        config = AnalysisServicesServerConfig(
            location=location,
            name=name,
            resource_group_name=resource_group_name,
            sku=sku,
            admin_users=admin_users,
            backup_blob_container_uri=backup_blob_container_uri,
            enable_power_bi_service=enable_power_bi_service,
            ipv4_firewall_rule=ipv4_firewall_rule,
            querypool_connection_mode=querypool_connection_mode,
            tags=tags,
            timeouts=timeouts,
            count=count,
            depends_on=depends_on,
            lifecycle=lifecycle,
            provider=provider,
        )

        jsii.create(AnalysisServicesServer, self, [scope, id, config])

    @jsii.member(jsii_name="synthesizeAttributes")
    def _synthesize_attributes(self) -> typing.Mapping[builtins.str, typing.Any]:
        return jsii.invoke(self, "synthesizeAttributes", [])

    @builtins.property # type: ignore
    @jsii.member(jsii_name="serverFullName")
    def server_full_name(self) -> builtins.str:
        return jsii.get(self, "serverFullName")

    @builtins.property # type: ignore
    @jsii.member(jsii_name="location")
    def location(self) -> builtins.str:
        return jsii.get(self, "location")

    @location.setter # type: ignore
    def location(self, value: builtins.str) -> None:
        jsii.set(self, "location", value)

    @builtins.property # type: ignore
    @jsii.member(jsii_name="name")
    def name(self) -> builtins.str:
        return jsii.get(self, "name")

    @name.setter # type: ignore
    def name(self, value: builtins.str) -> None:
        jsii.set(self, "name", value)

    @builtins.property # type: ignore
    @jsii.member(jsii_name="resourceGroupName")
    def resource_group_name(self) -> builtins.str:
        return jsii.get(self, "resourceGroupName")

    @resource_group_name.setter # type: ignore
    def resource_group_name(self, value: builtins.str) -> None:
        jsii.set(self, "resourceGroupName", value)

    @builtins.property # type: ignore
    @jsii.member(jsii_name="sku")
    def sku(self) -> builtins.str:
        return jsii.get(self, "sku")

    @sku.setter # type: ignore
    def sku(self, value: builtins.str) -> None:
        jsii.set(self, "sku", value)

    @builtins.property # type: ignore
    @jsii.member(jsii_name="adminUsers")
    def admin_users(self) -> typing.Optional[typing.List[builtins.str]]:
        return jsii.get(self, "adminUsers")

    @admin_users.setter # type: ignore
    def admin_users(self, value: typing.Optional[typing.List[builtins.str]]) -> None:
        jsii.set(self, "adminUsers", value)

    @builtins.property # type: ignore
    @jsii.member(jsii_name="backupBlobContainerUri")
    def backup_blob_container_uri(self) -> typing.Optional[builtins.str]:
        return jsii.get(self, "backupBlobContainerUri")

    @backup_blob_container_uri.setter # type: ignore
    def backup_blob_container_uri(self, value: typing.Optional[builtins.str]) -> None:
        jsii.set(self, "backupBlobContainerUri", value)

    @builtins.property # type: ignore
    @jsii.member(jsii_name="enablePowerBiService")
    def enable_power_bi_service(self) -> typing.Optional[builtins.bool]:
        return jsii.get(self, "enablePowerBiService")

    @enable_power_bi_service.setter # type: ignore
    def enable_power_bi_service(self, value: typing.Optional[builtins.bool]) -> None:
        jsii.set(self, "enablePowerBiService", value)

    @builtins.property # type: ignore
    @jsii.member(jsii_name="id")
    def id(self) -> typing.Optional[builtins.str]:
        return jsii.get(self, "id")

    @id.setter # type: ignore
    def id(self, value: typing.Optional[builtins.str]) -> None:
        jsii.set(self, "id", value)

    @builtins.property # type: ignore
    @jsii.member(jsii_name="ipv4FirewallRule")
    def ipv4_firewall_rule(
        self,
    ) -> typing.Optional[typing.List["AnalysisServicesServerIpv4FirewallRule"]]:
        return jsii.get(self, "ipv4FirewallRule")

    @ipv4_firewall_rule.setter # type: ignore
    def ipv4_firewall_rule(
        self,
        value: typing.Optional[typing.List["AnalysisServicesServerIpv4FirewallRule"]],
    ) -> None:
        jsii.set(self, "ipv4FirewallRule", value)

    @builtins.property # type: ignore
    @jsii.member(jsii_name="querypoolConnectionMode")
    def querypool_connection_mode(self) -> typing.Optional[builtins.str]:
        return jsii.get(self, "querypoolConnectionMode")

    @querypool_connection_mode.setter # type: ignore
    def querypool_connection_mode(self, value: typing.Optional[builtins.str]) -> None:
        jsii.set(self, "querypoolConnectionMode", value)

    @builtins.property # type: ignore
    @jsii.member(jsii_name="tags")
    def tags(self) -> typing.Optional[typing.Mapping[builtins.str, builtins.str]]:
        return jsii.get(self, "tags")

    @tags.setter # type: ignore
    def tags(
        self,
        value: typing.Optional[typing.Mapping[builtins.str, builtins.str]],
    ) -> None:
        jsii.set(self, "tags", value)

    @builtins.property # type: ignore
    @jsii.member(jsii_name="timeouts")
    def timeouts(self) -> typing.Optional["AnalysisServicesServerTimeouts"]:
        return jsii.get(self, "timeouts")

    @timeouts.setter # type: ignore
    def timeouts(
        self,
        value: typing.Optional["AnalysisServicesServerTimeouts"],
    ) -> None:
        jsii.set(self, "timeouts", value)


@jsii.data_type(
    jsii_type="@cdktf/provider-azurerm.AnalysisServicesServerConfig",
    jsii_struct_bases=[cdktf.TerraformMetaArguments],
    name_mapping={
        "count": "count",
        "depends_on": "dependsOn",
        "lifecycle": "lifecycle",
        "provider": "provider",
        "location": "location",
        "name": "name",
        "resource_group_name": "resourceGroupName",
        "sku": "sku",
        "admin_users": "adminUsers",
        "backup_blob_container_uri": "backupBlobContainerUri",
        "enable_power_bi_service": "enablePowerBiService",
        "ipv4_firewall_rule": "ipv4FirewallRule",
        "querypool_connection_mode": "querypoolConnectionMode",
        "tags": "tags",
        "timeouts": "timeouts",
    },
)
class AnalysisServicesServerConfig(cdktf.TerraformMetaArguments):
    def __init__(
        self,
        *,
        count: typing.Optional[jsii.Number] = None,
        depends_on: typing.Optional[typing.List[cdktf.TerraformResource]] = None,
        lifecycle: typing.Optional[cdktf.TerraformResourceLifecycle] = None,
        provider: typing.Optional[cdktf.TerraformProvider] = None,
        location: builtins.str,
        name: builtins.str,
        resource_group_name: builtins.str,
        sku: builtins.str,
        admin_users: typing.Optional[typing.List[builtins.str]] = None,
        backup_blob_container_uri: typing.Optional[builtins.str] = None,
        enable_power_bi_service: typing.Optional[builtins.bool] = None,
        ipv4_firewall_rule: typing.Optional[typing.List["AnalysisServicesServerIpv4FirewallRule"]] = None,
        querypool_connection_mode: typing.Optional[builtins.str] = None,
        tags: typing.Optional[typing.Mapping[builtins.str, builtins.str]] = None,
        timeouts: typing.Optional["AnalysisServicesServerTimeouts"] = None,
    ) -> None:
        """
        :param count: 
        :param depends_on: 
        :param lifecycle: 
        :param provider: 
        :param location: 
        :param name: 
        :param resource_group_name: 
        :param sku: 
        :param admin_users: 
        :param backup_blob_container_uri: 
        :param enable_power_bi_service: 
        :param ipv4_firewall_rule: ipv4_firewall_rule block.
        :param querypool_connection_mode: 
        :param tags: 
        :param timeouts: timeouts block.
        """
        if isinstance(lifecycle, dict):
            lifecycle = cdktf.TerraformResourceLifecycle(**lifecycle)
        if isinstance(timeouts, dict):
            timeouts = AnalysisServicesServerTimeouts(**timeouts)
        self._values: typing.Dict[str, typing.Any] = {
            "location": location,
            "name": name,
            "resource_group_name": resource_group_name,
            "sku": sku,
        }
        if count is not None:
            self._values["count"] = count
        if depends_on is not None:
            self._values["depends_on"] = depends_on
        if lifecycle is not None:
            self._values["lifecycle"] = lifecycle
        if provider is not None:
            self._values["provider"] = provider
        if admin_users is not None:
            self._values["admin_users"] = admin_users
        if backup_blob_container_uri is not None:
            self._values["backup_blob_container_uri"] = backup_blob_container_uri
        if enable_power_bi_service is not None:
            self._values["enable_power_bi_service"] = enable_power_bi_service
        if ipv4_firewall_rule is not None:
            self._values["ipv4_firewall_rule"] = ipv4_firewall_rule
        if querypool_connection_mode is not None:
            self._values["querypool_connection_mode"] = querypool_connection_mode
        if tags is not None:
            self._values["tags"] = tags
        if timeouts is not None:
            self._values["timeouts"] = timeouts

    @builtins.property
    def count(self) -> typing.Optional[jsii.Number]:
        """
        :stability: experimental
        """
        result = self._values.get("count")
        return result

    @builtins.property
    def depends_on(self) -> typing.Optional[typing.List[cdktf.TerraformResource]]:
        """
        :stability: experimental
        """
        result = self._values.get("depends_on")
        return result

    @builtins.property
    def lifecycle(self) -> typing.Optional[cdktf.TerraformResourceLifecycle]:
        """
        :stability: experimental
        """
        result = self._values.get("lifecycle")
        return result

    @builtins.property
    def provider(self) -> typing.Optional[cdktf.TerraformProvider]:
        """
        :stability: experimental
        """
        result = self._values.get("provider")
        return result

    @builtins.property
    def location(self) -> builtins.str:
        result = self._values.get("location")
        assert result is not None, "Required property 'location' is missing"
        return result

    @builtins.property
    def name(self) -> builtins.str:
        result = self._values.get("name")
        assert result is not None, "Required property 'name' is missing"
        return result

    @builtins.property
    def resource_group_name(self) -> builtins.str:
        result = self._values.get("resource_group_name")
        assert result is not None, "Required property 'resource_group_name' is missing"
        return result

    @builtins.property
    def sku(self) -> builtins.str:
        result = self._values.get("sku")
        assert result is not None, "Required property 'sku' is missing"
        return result

    @builtins.property
    def admin_users(self) -> typing.Optional[typing.List[builtins.str]]:
        result = self._values.get("admin_users")
        return result

    @builtins.property
    def backup_blob_container_uri(self) -> typing.Optional[builtins.str]:
        result = self._values.get("backup_blob_container_uri")
        return result

    @builtins.property
    def enable_power_bi_service(self) -> typing.Optional[builtins.bool]:
        result = self._values.get("enable_power_bi_service")
        return result

    @builtins.property
    def ipv4_firewall_rule(
        self,
    ) -> typing.Optional[typing.List["AnalysisServicesServerIpv4FirewallRule"]]:
        """ipv4_firewall_rule block."""
        result = self._values.get("ipv4_firewall_rule")
        return result

    @builtins.property
    def querypool_connection_mode(self) -> typing.Optional[builtins.str]:
        result = self._values.get("querypool_connection_mode")
        return result

    @builtins.property
    def tags(self) -> typing.Optional[typing.Mapping[builtins.str, builtins.str]]:
        result = self._values.get("tags")
        return result

    @builtins.property
    def timeouts(self) -> typing.Optional["AnalysisServicesServerTimeouts"]:
        """timeouts block."""
        result = self._values.get("timeouts")
        return result

    def __eq__(self, rhs: typing.Any) -> builtins.bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs: typing.Any) -> builtins.bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return "AnalysisServicesServerConfig(%s)" % ", ".join(
            k + "=" + repr(v) for k, v in self._values.items()
        )


@jsii.data_type(
    jsii_type="@cdktf/provider-azurerm.AnalysisServicesServerIpv4FirewallRule",
    jsii_struct_bases=[],
    name_mapping={
        "name": "name",
        "range_end": "rangeEnd",
        "range_start": "rangeStart",
    },
)
class AnalysisServicesServerIpv4FirewallRule:
    def __init__(
        self,
        *,
        name: builtins.str,
        range_end: builtins.str,
        range_start: builtins.str,
    ) -> None:
        """
        :param name: 
        :param range_end: 
        :param range_start: 
        """
        self._values: typing.Dict[str, typing.Any] = {
            "name": name,
            "range_end": range_end,
            "range_start": range_start,
        }

    @builtins.property
    def name(self) -> builtins.str:
        result = self._values.get("name")
        assert result is not None, "Required property 'name' is missing"
        return result

    @builtins.property
    def range_end(self) -> builtins.str:
        result = self._values.get("range_end")
        assert result is not None, "Required property 'range_end' is missing"
        return result

    @builtins.property
    def range_start(self) -> builtins.str:
        result = self._values.get("range_start")
        assert result is not None, "Required property 'range_start' is missing"
        return result

    def __eq__(self, rhs: typing.Any) -> builtins.bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs: typing.Any) -> builtins.bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return "AnalysisServicesServerIpv4FirewallRule(%s)" % ", ".join(
            k + "=" + repr(v) for k, v in self._values.items()
        )


@jsii.data_type(
    jsii_type="@cdktf/provider-azurerm.AnalysisServicesServerTimeouts",
    jsii_struct_bases=[],
    name_mapping={
        "create": "create",
        "delete": "delete",
        "read": "read",
        "update": "update",
    },
)
class AnalysisServicesServerTimeouts:
    def __init__(
        self,
        *,
        create: typing.Optional[builtins.str] = None,
        delete: typing.Optional[builtins.str] = None,
        read: typing.Optional[builtins.str] = None,
        update: typing.Optional[builtins.str] = None,
    ) -> None:
        """
        :param create: 
        :param delete: 
        :param read: 
        :param update: 
        """
        self._values: typing.Dict[str, typing.Any] = {}
        if create is not None:
            self._values["create"] = create
        if delete is not None:
            self._values["delete"] = delete
        if read is not None:
            self._values["read"] = read
        if update is not None:
            self._values["update"] = update

    @builtins.property
    def create(self) -> typing.Optional[builtins.str]:
        result = self._values.get("create")
        return result

    @builtins.property
    def delete(self) -> typing.Optional[builtins.str]:
        result = self._values.get("delete")
        return result

    @builtins.property
    def read(self) -> typing.Optional[builtins.str]:
        result = self._values.get("read")
        return result

    @builtins.property
    def update(self) -> typing.Optional[builtins.str]:
        result = self._values.get("update")
        return result

    def __eq__(self, rhs: typing.Any) -> builtins.bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs: typing.Any) -> builtins.bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return "AnalysisServicesServerTimeouts(%s)" % ", ".join(
            k + "=" + repr(v) for k, v in self._values.items()
        )


class ApiManagement(
    cdktf.TerraformResource,
    metaclass=jsii.JSIIMeta,
    jsii_type="@cdktf/provider-azurerm.ApiManagement",
):
    def __init__(
        self,
        scope: constructs.Construct,
        id: builtins.str,
        *,
        location: builtins.str,
        name: builtins.str,
        publisher_email: builtins.str,
        publisher_name: builtins.str,
        resource_group_name: builtins.str,
        sku_name: builtins.str,
        additional_location: typing.Optional[typing.List["ApiManagementAdditionalLocation"]] = None,
        certificate: typing.Optional[typing.List["ApiManagementCertificate"]] = None,
        hostname_configuration: typing.Optional[typing.List["ApiManagementHostnameConfiguration"]] = None,
        identity: typing.Optional[typing.List["ApiManagementIdentity"]] = None,
        notification_sender_email: typing.Optional[builtins.str] = None,
        policy: typing.Optional[typing.List["ApiManagementPolicy"]] = None,
        protocols: typing.Optional[typing.List["ApiManagementProtocols"]] = None,
        security: typing.Optional[typing.List["ApiManagementSecurity"]] = None,
        sign_in: typing.Optional[typing.List["ApiManagementSignIn"]] = None,
        sign_up: typing.Optional[typing.List["ApiManagementSignUp"]] = None,
        tags: typing.Optional[typing.Mapping[builtins.str, builtins.str]] = None,
        timeouts: typing.Optional["ApiManagementTimeouts"] = None,
        count: typing.Optional[jsii.Number] = None,
        depends_on: typing.Optional[typing.List[cdktf.TerraformResource]] = None,
        lifecycle: typing.Optional[cdktf.TerraformResourceLifecycle] = None,
        provider: typing.Optional[cdktf.TerraformProvider] = None,
    ) -> None:
        """
        :param scope: -
        :param id: -
        :param location: 
        :param name: 
        :param publisher_email: 
        :param publisher_name: 
        :param resource_group_name: 
        :param sku_name: 
        :param additional_location: additional_location block.
        :param certificate: certificate block.
        :param hostname_configuration: hostname_configuration block.
        :param identity: identity block.
        :param notification_sender_email: 
        :param policy: 
        :param protocols: protocols block.
        :param security: security block.
        :param sign_in: sign_in block.
        :param sign_up: sign_up block.
        :param tags: 
        :param timeouts: timeouts block.
        :param count: 
        :param depends_on: 
        :param lifecycle: 
        :param provider: 
        """
        config = ApiManagementConfig(
            location=location,
            name=name,
            publisher_email=publisher_email,
            publisher_name=publisher_name,
            resource_group_name=resource_group_name,
            sku_name=sku_name,
            additional_location=additional_location,
            certificate=certificate,
            hostname_configuration=hostname_configuration,
            identity=identity,
            notification_sender_email=notification_sender_email,
            policy=policy,
            protocols=protocols,
            security=security,
            sign_in=sign_in,
            sign_up=sign_up,
            tags=tags,
            timeouts=timeouts,
            count=count,
            depends_on=depends_on,
            lifecycle=lifecycle,
            provider=provider,
        )

        jsii.create(ApiManagement, self, [scope, id, config])

    @jsii.member(jsii_name="synthesizeAttributes")
    def _synthesize_attributes(self) -> typing.Mapping[builtins.str, typing.Any]:
        return jsii.invoke(self, "synthesizeAttributes", [])

    @builtins.property # type: ignore
    @jsii.member(jsii_name="gatewayRegionalUrl")
    def gateway_regional_url(self) -> builtins.str:
        return jsii.get(self, "gatewayRegionalUrl")

    @builtins.property # type: ignore
    @jsii.member(jsii_name="gatewayUrl")
    def gateway_url(self) -> builtins.str:
        return jsii.get(self, "gatewayUrl")

    @builtins.property # type: ignore
    @jsii.member(jsii_name="managementApiUrl")
    def management_api_url(self) -> builtins.str:
        return jsii.get(self, "managementApiUrl")

    @builtins.property # type: ignore
    @jsii.member(jsii_name="portalUrl")
    def portal_url(self) -> builtins.str:
        return jsii.get(self, "portalUrl")

    @builtins.property # type: ignore
    @jsii.member(jsii_name="publicIpAddresses")
    def public_ip_addresses(self) -> typing.List[builtins.str]:
        return jsii.get(self, "publicIpAddresses")

    @builtins.property # type: ignore
    @jsii.member(jsii_name="scmUrl")
    def scm_url(self) -> builtins.str:
        return jsii.get(self, "scmUrl")

    @builtins.property # type: ignore
    @jsii.member(jsii_name="location")
    def location(self) -> builtins.str:
        return jsii.get(self, "location")

    @location.setter # type: ignore
    def location(self, value: builtins.str) -> None:
        jsii.set(self, "location", value)

    @builtins.property # type: ignore
    @jsii.member(jsii_name="name")
    def name(self) -> builtins.str:
        return jsii.get(self, "name")

    @name.setter # type: ignore
    def name(self, value: builtins.str) -> None:
        jsii.set(self, "name", value)

    @builtins.property # type: ignore
    @jsii.member(jsii_name="publisherEmail")
    def publisher_email(self) -> builtins.str:
        return jsii.get(self, "publisherEmail")

    @publisher_email.setter # type: ignore
    def publisher_email(self, value: builtins.str) -> None:
        jsii.set(self, "publisherEmail", value)

    @builtins.property # type: ignore
    @jsii.member(jsii_name="publisherName")
    def publisher_name(self) -> builtins.str:
        return jsii.get(self, "publisherName")

    @publisher_name.setter # type: ignore
    def publisher_name(self, value: builtins.str) -> None:
        jsii.set(self, "publisherName", value)

    @builtins.property # type: ignore
    @jsii.member(jsii_name="resourceGroupName")
    def resource_group_name(self) -> builtins.str:
        return jsii.get(self, "resourceGroupName")

    @resource_group_name.setter # type: ignore
    def resource_group_name(self, value: builtins.str) -> None:
        jsii.set(self, "resourceGroupName", value)

    @builtins.property # type: ignore
    @jsii.member(jsii_name="skuName")
    def sku_name(self) -> builtins.str:
        return jsii.get(self, "skuName")

    @sku_name.setter # type: ignore
    def sku_name(self, value: builtins.str) -> None:
        jsii.set(self, "skuName", value)

    @builtins.property # type: ignore
    @jsii.member(jsii_name="additionalLocation")
    def additional_location(
        self,
    ) -> typing.Optional[typing.List["ApiManagementAdditionalLocation"]]:
        return jsii.get(self, "additionalLocation")

    @additional_location.setter # type: ignore
    def additional_location(
        self,
        value: typing.Optional[typing.List["ApiManagementAdditionalLocation"]],
    ) -> None:
        jsii.set(self, "additionalLocation", value)

    @builtins.property # type: ignore
    @jsii.member(jsii_name="certificate")
    def certificate(self) -> typing.Optional[typing.List["ApiManagementCertificate"]]:
        return jsii.get(self, "certificate")

    @certificate.setter # type: ignore
    def certificate(
        self,
        value: typing.Optional[typing.List["ApiManagementCertificate"]],
    ) -> None:
        jsii.set(self, "certificate", value)

    @builtins.property # type: ignore
    @jsii.member(jsii_name="hostnameConfiguration")
    def hostname_configuration(
        self,
    ) -> typing.Optional[typing.List["ApiManagementHostnameConfiguration"]]:
        return jsii.get(self, "hostnameConfiguration")

    @hostname_configuration.setter # type: ignore
    def hostname_configuration(
        self,
        value: typing.Optional[typing.List["ApiManagementHostnameConfiguration"]],
    ) -> None:
        jsii.set(self, "hostnameConfiguration", value)

    @builtins.property # type: ignore
    @jsii.member(jsii_name="id")
    def id(self) -> typing.Optional[builtins.str]:
        return jsii.get(self, "id")

    @id.setter # type: ignore
    def id(self, value: typing.Optional[builtins.str]) -> None:
        jsii.set(self, "id", value)

    @builtins.property # type: ignore
    @jsii.member(jsii_name="identity")
    def identity(self) -> typing.Optional[typing.List["ApiManagementIdentity"]]:
        return jsii.get(self, "identity")

    @identity.setter # type: ignore
    def identity(
        self,
        value: typing.Optional[typing.List["ApiManagementIdentity"]],
    ) -> None:
        jsii.set(self, "identity", value)

    @builtins.property # type: ignore
    @jsii.member(jsii_name="notificationSenderEmail")
    def notification_sender_email(self) -> typing.Optional[builtins.str]:
        return jsii.get(self, "notificationSenderEmail")

    @notification_sender_email.setter # type: ignore
    def notification_sender_email(self, value: typing.Optional[builtins.str]) -> None:
        jsii.set(self, "notificationSenderEmail", value)

    @builtins.property # type: ignore
    @jsii.member(jsii_name="policy")
    def policy(self) -> typing.Optional[typing.List["ApiManagementPolicy"]]:
        return jsii.get(self, "policy")

    @policy.setter # type: ignore
    def policy(
        self,
        value: typing.Optional[typing.List["ApiManagementPolicy"]],
    ) -> None:
        jsii.set(self, "policy", value)

    @builtins.property # type: ignore
    @jsii.member(jsii_name="protocols")
    def protocols(self) -> typing.Optional[typing.List["ApiManagementProtocols"]]:
        return jsii.get(self, "protocols")

    @protocols.setter # type: ignore
    def protocols(
        self,
        value: typing.Optional[typing.List["ApiManagementProtocols"]],
    ) -> None:
        jsii.set(self, "protocols", value)

    @builtins.property # type: ignore
    @jsii.member(jsii_name="security")
    def security(self) -> typing.Optional[typing.List["ApiManagementSecurity"]]:
        return jsii.get(self, "security")

    @security.setter # type: ignore
    def security(
        self,
        value: typing.Optional[typing.List["ApiManagementSecurity"]],
    ) -> None:
        jsii.set(self, "security", value)

    @builtins.property # type: ignore
    @jsii.member(jsii_name="signIn")
    def sign_in(self) -> typing.Optional[typing.List["ApiManagementSignIn"]]:
        return jsii.get(self, "signIn")

    @sign_in.setter # type: ignore
    def sign_in(
        self,
        value: typing.Optional[typing.List["ApiManagementSignIn"]],
    ) -> None:
        jsii.set(self, "signIn", value)

    @builtins.property # type: ignore
    @jsii.member(jsii_name="signUp")
    def sign_up(self) -> typing.Optional[typing.List["ApiManagementSignUp"]]:
        return jsii.get(self, "signUp")

    @sign_up.setter # type: ignore
    def sign_up(
        self,
        value: typing.Optional[typing.List["ApiManagementSignUp"]],
    ) -> None:
        jsii.set(self, "signUp", value)

    @builtins.property # type: ignore
    @jsii.member(jsii_name="tags")
    def tags(self) -> typing.Optional[typing.Mapping[builtins.str, builtins.str]]:
        return jsii.get(self, "tags")

    @tags.setter # type: ignore
    def tags(
        self,
        value: typing.Optional[typing.Mapping[builtins.str, builtins.str]],
    ) -> None:
        jsii.set(self, "tags", value)

    @builtins.property # type: ignore
    @jsii.member(jsii_name="timeouts")
    def timeouts(self) -> typing.Optional["ApiManagementTimeouts"]:
        return jsii.get(self, "timeouts")

    @timeouts.setter # type: ignore
    def timeouts(self, value: typing.Optional["ApiManagementTimeouts"]) -> None:
        jsii.set(self, "timeouts", value)


@jsii.data_type(
    jsii_type="@cdktf/provider-azurerm.ApiManagementAdditionalLocation",
    jsii_struct_bases=[],
    name_mapping={"location": "location"},
)
class ApiManagementAdditionalLocation:
    def __init__(self, *, location: builtins.str) -> None:
        """
        :param location: 
        """
        self._values: typing.Dict[str, typing.Any] = {
            "location": location,
        }

    @builtins.property
    def location(self) -> builtins.str:
        result = self._values.get("location")
        assert result is not None, "Required property 'location' is missing"
        return result

    def __eq__(self, rhs: typing.Any) -> builtins.bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs: typing.Any) -> builtins.bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return "ApiManagementAdditionalLocation(%s)" % ", ".join(
            k + "=" + repr(v) for k, v in self._values.items()
        )


class ApiManagementApi(
    cdktf.TerraformResource,
    metaclass=jsii.JSIIMeta,
    jsii_type="@cdktf/provider-azurerm.ApiManagementApi",
):
    def __init__(
        self,
        scope: constructs.Construct,
        id: builtins.str,
        *,
        api_management_name: builtins.str,
        display_name: builtins.str,
        name: builtins.str,
        path: builtins.str,
        protocols: typing.List[builtins.str],
        resource_group_name: builtins.str,
        revision: builtins.str,
        description: typing.Optional[builtins.str] = None,
        import_: typing.Optional[typing.List["ApiManagementApiImport"]] = None,
        service_url: typing.Optional[builtins.str] = None,
        soap_pass_through: typing.Optional[builtins.bool] = None,
        subscription_key_parameter_names: typing.Optional[typing.List["ApiManagementApiSubscriptionKeyParameterNames"]] = None,
        timeouts: typing.Optional["ApiManagementApiTimeouts"] = None,
        version: typing.Optional[builtins.str] = None,
        version_set_id: typing.Optional[builtins.str] = None,
        count: typing.Optional[jsii.Number] = None,
        depends_on: typing.Optional[typing.List[cdktf.TerraformResource]] = None,
        lifecycle: typing.Optional[cdktf.TerraformResourceLifecycle] = None,
        provider: typing.Optional[cdktf.TerraformProvider] = None,
    ) -> None:
        """
        :param scope: -
        :param id: -
        :param api_management_name: 
        :param display_name: 
        :param name: 
        :param path: 
        :param protocols: 
        :param resource_group_name: 
        :param revision: 
        :param description: 
        :param import_: import block.
        :param service_url: 
        :param soap_pass_through: 
        :param subscription_key_parameter_names: subscription_key_parameter_names block.
        :param timeouts: timeouts block.
        :param version: 
        :param version_set_id: 
        :param count: 
        :param depends_on: 
        :param lifecycle: 
        :param provider: 
        """
        config = ApiManagementApiConfig(
            api_management_name=api_management_name,
            display_name=display_name,
            name=name,
            path=path,
            protocols=protocols,
            resource_group_name=resource_group_name,
            revision=revision,
            description=description,
            import_=import_,
            service_url=service_url,
            soap_pass_through=soap_pass_through,
            subscription_key_parameter_names=subscription_key_parameter_names,
            timeouts=timeouts,
            version=version,
            version_set_id=version_set_id,
            count=count,
            depends_on=depends_on,
            lifecycle=lifecycle,
            provider=provider,
        )

        jsii.create(ApiManagementApi, self, [scope, id, config])

    @jsii.member(jsii_name="synthesizeAttributes")
    def _synthesize_attributes(self) -> typing.Mapping[builtins.str, typing.Any]:
        return jsii.invoke(self, "synthesizeAttributes", [])

    @builtins.property # type: ignore
    @jsii.member(jsii_name="isCurrent")
    def is_current(self) -> builtins.bool:
        return jsii.get(self, "isCurrent")

    @builtins.property # type: ignore
    @jsii.member(jsii_name="isOnline")
    def is_online(self) -> builtins.bool:
        return jsii.get(self, "isOnline")

    @builtins.property # type: ignore
    @jsii.member(jsii_name="apiManagementName")
    def api_management_name(self) -> builtins.str:
        return jsii.get(self, "apiManagementName")

    @api_management_name.setter # type: ignore
    def api_management_name(self, value: builtins.str) -> None:
        jsii.set(self, "apiManagementName", value)

    @builtins.property # type: ignore
    @jsii.member(jsii_name="displayName")
    def display_name(self) -> builtins.str:
        return jsii.get(self, "displayName")

    @display_name.setter # type: ignore
    def display_name(self, value: builtins.str) -> None:
        jsii.set(self, "displayName", value)

    @builtins.property # type: ignore
    @jsii.member(jsii_name="name")
    def name(self) -> builtins.str:
        return jsii.get(self, "name")

    @name.setter # type: ignore
    def name(self, value: builtins.str) -> None:
        jsii.set(self, "name", value)

    @builtins.property # type: ignore
    @jsii.member(jsii_name="path")
    def path(self) -> builtins.str:
        return jsii.get(self, "path")

    @path.setter # type: ignore
    def path(self, value: builtins.str) -> None:
        jsii.set(self, "path", value)

    @builtins.property # type: ignore
    @jsii.member(jsii_name="protocols")
    def protocols(self) -> typing.List[builtins.str]:
        return jsii.get(self, "protocols")

    @protocols.setter # type: ignore
    def protocols(self, value: typing.List[builtins.str]) -> None:
        jsii.set(self, "protocols", value)

    @builtins.property # type: ignore
    @jsii.member(jsii_name="resourceGroupName")
    def resource_group_name(self) -> builtins.str:
        return jsii.get(self, "resourceGroupName")

    @resource_group_name.setter # type: ignore
    def resource_group_name(self, value: builtins.str) -> None:
        jsii.set(self, "resourceGroupName", value)

    @builtins.property # type: ignore
    @jsii.member(jsii_name="revision")
    def revision(self) -> builtins.str:
        return jsii.get(self, "revision")

    @revision.setter # type: ignore
    def revision(self, value: builtins.str) -> None:
        jsii.set(self, "revision", value)

    @builtins.property # type: ignore
    @jsii.member(jsii_name="description")
    def description(self) -> typing.Optional[builtins.str]:
        return jsii.get(self, "description")

    @description.setter # type: ignore
    def description(self, value: typing.Optional[builtins.str]) -> None:
        jsii.set(self, "description", value)

    @builtins.property # type: ignore
    @jsii.member(jsii_name="id")
    def id(self) -> typing.Optional[builtins.str]:
        return jsii.get(self, "id")

    @id.setter # type: ignore
    def id(self, value: typing.Optional[builtins.str]) -> None:
        jsii.set(self, "id", value)

    @builtins.property # type: ignore
    @jsii.member(jsii_name="import")
    def import_(self) -> typing.Optional[typing.List["ApiManagementApiImport"]]:
        return jsii.get(self, "import")

    @import_.setter # type: ignore
    def import_(
        self,
        value: typing.Optional[typing.List["ApiManagementApiImport"]],
    ) -> None:
        jsii.set(self, "import", value)

    @builtins.property # type: ignore
    @jsii.member(jsii_name="serviceUrl")
    def service_url(self) -> typing.Optional[builtins.str]:
        return jsii.get(self, "serviceUrl")

    @service_url.setter # type: ignore
    def service_url(self, value: typing.Optional[builtins.str]) -> None:
        jsii.set(self, "serviceUrl", value)

    @builtins.property # type: ignore
    @jsii.member(jsii_name="soapPassThrough")
    def soap_pass_through(self) -> typing.Optional[builtins.bool]:
        return jsii.get(self, "soapPassThrough")

    @soap_pass_through.setter # type: ignore
    def soap_pass_through(self, value: typing.Optional[builtins.bool]) -> None:
        jsii.set(self, "soapPassThrough", value)

    @builtins.property # type: ignore
    @jsii.member(jsii_name="subscriptionKeyParameterNames")
    def subscription_key_parameter_names(
        self,
    ) -> typing.Optional[typing.List["ApiManagementApiSubscriptionKeyParameterNames"]]:
        return jsii.get(self, "subscriptionKeyParameterNames")

    @subscription_key_parameter_names.setter # type: ignore
    def subscription_key_parameter_names(
        self,
        value: typing.Optional[typing.List["ApiManagementApiSubscriptionKeyParameterNames"]],
    ) -> None:
        jsii.set(self, "subscriptionKeyParameterNames", value)

    @builtins.property # type: ignore
    @jsii.member(jsii_name="timeouts")
    def timeouts(self) -> typing.Optional["ApiManagementApiTimeouts"]:
        return jsii.get(self, "timeouts")

    @timeouts.setter # type: ignore
    def timeouts(self, value: typing.Optional["ApiManagementApiTimeouts"]) -> None:
        jsii.set(self, "timeouts", value)

    @builtins.property # type: ignore
    @jsii.member(jsii_name="version")
    def version(self) -> typing.Optional[builtins.str]:
        return jsii.get(self, "version")

    @version.setter # type: ignore
    def version(self, value: typing.Optional[builtins.str]) -> None:
        jsii.set(self, "version", value)

    @builtins.property # type: ignore
    @jsii.member(jsii_name="versionSetId")
    def version_set_id(self) -> typing.Optional[builtins.str]:
        return jsii.get(self, "versionSetId")

    @version_set_id.setter # type: ignore
    def version_set_id(self, value: typing.Optional[builtins.str]) -> None:
        jsii.set(self, "versionSetId", value)


@jsii.data_type(
    jsii_type="@cdktf/provider-azurerm.ApiManagementApiConfig",
    jsii_struct_bases=[cdktf.TerraformMetaArguments],
    name_mapping={
        "count": "count",
        "depends_on": "dependsOn",
        "lifecycle": "lifecycle",
        "provider": "provider",
        "api_management_name": "apiManagementName",
        "display_name": "displayName",
        "name": "name",
        "path": "path",
        "protocols": "protocols",
        "resource_group_name": "resourceGroupName",
        "revision": "revision",
        "description": "description",
        "import_": "import",
        "service_url": "serviceUrl",
        "soap_pass_through": "soapPassThrough",
        "subscription_key_parameter_names": "subscriptionKeyParameterNames",
        "timeouts": "timeouts",
        "version": "version",
        "version_set_id": "versionSetId",
    },
)
class ApiManagementApiConfig(cdktf.TerraformMetaArguments):
    def __init__(
        self,
        *,
        count: typing.Optional[jsii.Number] = None,
        depends_on: typing.Optional[typing.List[cdktf.TerraformResource]] = None,
        lifecycle: typing.Optional[cdktf.TerraformResourceLifecycle] = None,
        provider: typing.Optional[cdktf.TerraformProvider] = None,
        api_management_name: builtins.str,
        display_name: builtins.str,
        name: builtins.str,
        path: builtins.str,
        protocols: typing.List[builtins.str],
        resource_group_name: builtins.str,
        revision: builtins.str,
        description: typing.Optional[builtins.str] = None,
        import_: typing.Optional[typing.List["ApiManagementApiImport"]] = None,
        service_url: typing.Optional[builtins.str] = None,
        soap_pass_through: typing.Optional[builtins.bool] = None,
        subscription_key_parameter_names: typing.Optional[typing.List["ApiManagementApiSubscriptionKeyParameterNames"]] = None,
        timeouts: typing.Optional["ApiManagementApiTimeouts"] = None,
        version: typing.Optional[builtins.str] = None,
        version_set_id: typing.Optional[builtins.str] = None,
    ) -> None:
        """
        :param count: 
        :param depends_on: 
        :param lifecycle: 
        :param provider: 
        :param api_management_name: 
        :param display_name: 
        :param name: 
        :param path: 
        :param protocols: 
        :param resource_group_name: 
        :param revision: 
        :param description: 
        :param import_: import block.
        :param service_url: 
        :param soap_pass_through: 
        :param subscription_key_parameter_names: subscription_key_parameter_names block.
        :param timeouts: timeouts block.
        :param version: 
        :param version_set_id: 
        """
        if isinstance(lifecycle, dict):
            lifecycle = cdktf.TerraformResourceLifecycle(**lifecycle)
        if isinstance(timeouts, dict):
            timeouts = ApiManagementApiTimeouts(**timeouts)
        self._values: typing.Dict[str, typing.Any] = {
            "api_management_name": api_management_name,
            "display_name": display_name,
            "name": name,
            "path": path,
            "protocols": protocols,
            "resource_group_name": resource_group_name,
            "revision": revision,
        }
        if count is not None:
            self._values["count"] = count
        if depends_on is not None:
            self._values["depends_on"] = depends_on
        if lifecycle is not None:
            self._values["lifecycle"] = lifecycle
        if provider is not None:
            self._values["provider"] = provider
        if description is not None:
            self._values["description"] = description
        if import_ is not None:
            self._values["import_"] = import_
        if service_url is not None:
            self._values["service_url"] = service_url
        if soap_pass_through is not None:
            self._values["soap_pass_through"] = soap_pass_through
        if subscription_key_parameter_names is not None:
            self._values["subscription_key_parameter_names"] = subscription_key_parameter_names
        if timeouts is not None:
            self._values["timeouts"] = timeouts
        if version is not None:
            self._values["version"] = version
        if version_set_id is not None:
            self._values["version_set_id"] = version_set_id

    @builtins.property
    def count(self) -> typing.Optional[jsii.Number]:
        """
        :stability: experimental
        """
        result = self._values.get("count")
        return result

    @builtins.property
    def depends_on(self) -> typing.Optional[typing.List[cdktf.TerraformResource]]:
        """
        :stability: experimental
        """
        result = self._values.get("depends_on")
        return result

    @builtins.property
    def lifecycle(self) -> typing.Optional[cdktf.TerraformResourceLifecycle]:
        """
        :stability: experimental
        """
        result = self._values.get("lifecycle")
        return result

    @builtins.property
    def provider(self) -> typing.Optional[cdktf.TerraformProvider]:
        """
        :stability: experimental
        """
        result = self._values.get("provider")
        return result

    @builtins.property
    def api_management_name(self) -> builtins.str:
        result = self._values.get("api_management_name")
        assert result is not None, "Required property 'api_management_name' is missing"
        return result

    @builtins.property
    def display_name(self) -> builtins.str:
        result = self._values.get("display_name")
        assert result is not None, "Required property 'display_name' is missing"
        return result

    @builtins.property
    def name(self) -> builtins.str:
        result = self._values.get("name")
        assert result is not None, "Required property 'name' is missing"
        return result

    @builtins.property
    def path(self) -> builtins.str:
        result = self._values.get("path")
        assert result is not None, "Required property 'path' is missing"
        return result

    @builtins.property
    def protocols(self) -> typing.List[builtins.str]:
        result = self._values.get("protocols")
        assert result is not None, "Required property 'protocols' is missing"
        return result

    @builtins.property
    def resource_group_name(self) -> builtins.str:
        result = self._values.get("resource_group_name")
        assert result is not None, "Required property 'resource_group_name' is missing"
        return result

    @builtins.property
    def revision(self) -> builtins.str:
        result = self._values.get("revision")
        assert result is not None, "Required property 'revision' is missing"
        return result

    @builtins.property
    def description(self) -> typing.Optional[builtins.str]:
        result = self._values.get("description")
        return result

    @builtins.property
    def import_(self) -> typing.Optional[typing.List["ApiManagementApiImport"]]:
        """import block."""
        result = self._values.get("import_")
        return result

    @builtins.property
    def service_url(self) -> typing.Optional[builtins.str]:
        result = self._values.get("service_url")
        return result

    @builtins.property
    def soap_pass_through(self) -> typing.Optional[builtins.bool]:
        result = self._values.get("soap_pass_through")
        return result

    @builtins.property
    def subscription_key_parameter_names(
        self,
    ) -> typing.Optional[typing.List["ApiManagementApiSubscriptionKeyParameterNames"]]:
        """subscription_key_parameter_names block."""
        result = self._values.get("subscription_key_parameter_names")
        return result

    @builtins.property
    def timeouts(self) -> typing.Optional["ApiManagementApiTimeouts"]:
        """timeouts block."""
        result = self._values.get("timeouts")
        return result

    @builtins.property
    def version(self) -> typing.Optional[builtins.str]:
        result = self._values.get("version")
        return result

    @builtins.property
    def version_set_id(self) -> typing.Optional[builtins.str]:
        result = self._values.get("version_set_id")
        return result

    def __eq__(self, rhs: typing.Any) -> builtins.bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs: typing.Any) -> builtins.bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return "ApiManagementApiConfig(%s)" % ", ".join(
            k + "=" + repr(v) for k, v in self._values.items()
        )


@jsii.data_type(
    jsii_type="@cdktf/provider-azurerm.ApiManagementApiImport",
    jsii_struct_bases=[],
    name_mapping={
        "content_format": "contentFormat",
        "content_value": "contentValue",
        "wsdl_selector": "wsdlSelector",
    },
)
class ApiManagementApiImport:
    def __init__(
        self,
        *,
        content_format: builtins.str,
        content_value: builtins.str,
        wsdl_selector: typing.Optional[typing.List["ApiManagementApiImportWsdlSelector"]] = None,
    ) -> None:
        """
        :param content_format: 
        :param content_value: 
        :param wsdl_selector: wsdl_selector block.
        """
        self._values: typing.Dict[str, typing.Any] = {
            "content_format": content_format,
            "content_value": content_value,
        }
        if wsdl_selector is not None:
            self._values["wsdl_selector"] = wsdl_selector

    @builtins.property
    def content_format(self) -> builtins.str:
        result = self._values.get("content_format")
        assert result is not None, "Required property 'content_format' is missing"
        return result

    @builtins.property
    def content_value(self) -> builtins.str:
        result = self._values.get("content_value")
        assert result is not None, "Required property 'content_value' is missing"
        return result

    @builtins.property
    def wsdl_selector(
        self,
    ) -> typing.Optional[typing.List["ApiManagementApiImportWsdlSelector"]]:
        """wsdl_selector block."""
        result = self._values.get("wsdl_selector")
        return result

    def __eq__(self, rhs: typing.Any) -> builtins.bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs: typing.Any) -> builtins.bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return "ApiManagementApiImport(%s)" % ", ".join(
            k + "=" + repr(v) for k, v in self._values.items()
        )


@jsii.data_type(
    jsii_type="@cdktf/provider-azurerm.ApiManagementApiImportWsdlSelector",
    jsii_struct_bases=[],
    name_mapping={"endpoint_name": "endpointName", "service_name": "serviceName"},
)
class ApiManagementApiImportWsdlSelector:
    def __init__(
        self,
        *,
        endpoint_name: builtins.str,
        service_name: builtins.str,
    ) -> None:
        """
        :param endpoint_name: 
        :param service_name: 
        """
        self._values: typing.Dict[str, typing.Any] = {
            "endpoint_name": endpoint_name,
            "service_name": service_name,
        }

    @builtins.property
    def endpoint_name(self) -> builtins.str:
        result = self._values.get("endpoint_name")
        assert result is not None, "Required property 'endpoint_name' is missing"
        return result

    @builtins.property
    def service_name(self) -> builtins.str:
        result = self._values.get("service_name")
        assert result is not None, "Required property 'service_name' is missing"
        return result

    def __eq__(self, rhs: typing.Any) -> builtins.bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs: typing.Any) -> builtins.bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return "ApiManagementApiImportWsdlSelector(%s)" % ", ".join(
            k + "=" + repr(v) for k, v in self._values.items()
        )


class ApiManagementApiOperation(
    cdktf.TerraformResource,
    metaclass=jsii.JSIIMeta,
    jsii_type="@cdktf/provider-azurerm.ApiManagementApiOperation",
):
    def __init__(
        self,
        scope: constructs.Construct,
        id: builtins.str,
        *,
        api_management_name: builtins.str,
        api_name: builtins.str,
        display_name: builtins.str,
        method: builtins.str,
        operation_id: builtins.str,
        resource_group_name: builtins.str,
        url_template: builtins.str,
        description: typing.Optional[builtins.str] = None,
        request: typing.Optional[typing.List["ApiManagementApiOperationRequest"]] = None,
        response: typing.Optional[typing.List["ApiManagementApiOperationResponse"]] = None,
        template_parameter: typing.Optional[typing.List["ApiManagementApiOperationTemplateParameter"]] = None,
        timeouts: typing.Optional["ApiManagementApiOperationTimeouts"] = None,
        count: typing.Optional[jsii.Number] = None,
        depends_on: typing.Optional[typing.List[cdktf.TerraformResource]] = None,
        lifecycle: typing.Optional[cdktf.TerraformResourceLifecycle] = None,
        provider: typing.Optional[cdktf.TerraformProvider] = None,
    ) -> None:
        """
        :param scope: -
        :param id: -
        :param api_management_name: 
        :param api_name: 
        :param display_name: 
        :param method: 
        :param operation_id: 
        :param resource_group_name: 
        :param url_template: 
        :param description: 
        :param request: request block.
        :param response: response block.
        :param template_parameter: template_parameter block.
        :param timeouts: timeouts block.
        :param count: 
        :param depends_on: 
        :param lifecycle: 
        :param provider: 
        """
        config = ApiManagementApiOperationConfig(
            api_management_name=api_management_name,
            api_name=api_name,
            display_name=display_name,
            method=method,
            operation_id=operation_id,
            resource_group_name=resource_group_name,
            url_template=url_template,
            description=description,
            request=request,
            response=response,
            template_parameter=template_parameter,
            timeouts=timeouts,
            count=count,
            depends_on=depends_on,
            lifecycle=lifecycle,
            provider=provider,
        )

        jsii.create(ApiManagementApiOperation, self, [scope, id, config])

    @jsii.member(jsii_name="synthesizeAttributes")
    def _synthesize_attributes(self) -> typing.Mapping[builtins.str, typing.Any]:
        return jsii.invoke(self, "synthesizeAttributes", [])

    @builtins.property # type: ignore
    @jsii.member(jsii_name="apiManagementName")
    def api_management_name(self) -> builtins.str:
        return jsii.get(self, "apiManagementName")

    @api_management_name.setter # type: ignore
    def api_management_name(self, value: builtins.str) -> None:
        jsii.set(self, "apiManagementName", value)

    @builtins.property # type: ignore
    @jsii.member(jsii_name="apiName")
    def api_name(self) -> builtins.str:
        return jsii.get(self, "apiName")

    @api_name.setter # type: ignore
    def api_name(self, value: builtins.str) -> None:
        jsii.set(self, "apiName", value)

    @builtins.property # type: ignore
    @jsii.member(jsii_name="displayName")
    def display_name(self) -> builtins.str:
        return jsii.get(self, "displayName")

    @display_name.setter # type: ignore
    def display_name(self, value: builtins.str) -> None:
        jsii.set(self, "displayName", value)

    @builtins.property # type: ignore
    @jsii.member(jsii_name="method")
    def method(self) -> builtins.str:
        return jsii.get(self, "method")

    @method.setter # type: ignore
    def method(self, value: builtins.str) -> None:
        jsii.set(self, "method", value)

    @builtins.property # type: ignore
    @jsii.member(jsii_name="operationId")
    def operation_id(self) -> builtins.str:
        return jsii.get(self, "operationId")

    @operation_id.setter # type: ignore
    def operation_id(self, value: builtins.str) -> None:
        jsii.set(self, "operationId", value)

    @builtins.property # type: ignore
    @jsii.member(jsii_name="resourceGroupName")
    def resource_group_name(self) -> builtins.str:
        return jsii.get(self, "resourceGroupName")

    @resource_group_name.setter # type: ignore
    def resource_group_name(self, value: builtins.str) -> None:
        jsii.set(self, "resourceGroupName", value)

    @builtins.property # type: ignore
    @jsii.member(jsii_name="urlTemplate")
    def url_template(self) -> builtins.str:
        return jsii.get(self, "urlTemplate")

    @url_template.setter # type: ignore
    def url_template(self, value: builtins.str) -> None:
        jsii.set(self, "urlTemplate", value)

    @builtins.property # type: ignore
    @jsii.member(jsii_name="description")
    def description(self) -> typing.Optional[builtins.str]:
        return jsii.get(self, "description")

    @description.setter # type: ignore
    def description(self, value: typing.Optional[builtins.str]) -> None:
        jsii.set(self, "description", value)

    @builtins.property # type: ignore
    @jsii.member(jsii_name="id")
    def id(self) -> typing.Optional[builtins.str]:
        return jsii.get(self, "id")

    @id.setter # type: ignore
    def id(self, value: typing.Optional[builtins.str]) -> None:
        jsii.set(self, "id", value)

    @builtins.property # type: ignore
    @jsii.member(jsii_name="request")
    def request(
        self,
    ) -> typing.Optional[typing.List["ApiManagementApiOperationRequest"]]:
        return jsii.get(self, "request")

    @request.setter # type: ignore
    def request(
        self,
        value: typing.Optional[typing.List["ApiManagementApiOperationRequest"]],
    ) -> None:
        jsii.set(self, "request", value)

    @builtins.property # type: ignore
    @jsii.member(jsii_name="response")
    def response(
        self,
    ) -> typing.Optional[typing.List["ApiManagementApiOperationResponse"]]:
        return jsii.get(self, "response")

    @response.setter # type: ignore
    def response(
        self,
        value: typing.Optional[typing.List["ApiManagementApiOperationResponse"]],
    ) -> None:
        jsii.set(self, "response", value)

    @builtins.property # type: ignore
    @jsii.member(jsii_name="templateParameter")
    def template_parameter(
        self,
    ) -> typing.Optional[typing.List["ApiManagementApiOperationTemplateParameter"]]:
        return jsii.get(self, "templateParameter")

    @template_parameter.setter # type: ignore
    def template_parameter(
        self,
        value: typing.Optional[typing.List["ApiManagementApiOperationTemplateParameter"]],
    ) -> None:
        jsii.set(self, "templateParameter", value)

    @builtins.property # type: ignore
    @jsii.member(jsii_name="timeouts")
    def timeouts(self) -> typing.Optional["ApiManagementApiOperationTimeouts"]:
        return jsii.get(self, "timeouts")

    @timeouts.setter # type: ignore
    def timeouts(
        self,
        value: typing.Optional["ApiManagementApiOperationTimeouts"],
    ) -> None:
        jsii.set(self, "timeouts", value)


@jsii.data_type(
    jsii_type="@cdktf/provider-azurerm.ApiManagementApiOperationConfig",
    jsii_struct_bases=[cdktf.TerraformMetaArguments],
    name_mapping={
        "count": "count",
        "depends_on": "dependsOn",
        "lifecycle": "lifecycle",
        "provider": "provider",
        "api_management_name": "apiManagementName",
        "api_name": "apiName",
        "display_name": "displayName",
        "method": "method",
        "operation_id": "operationId",
        "resource_group_name": "resourceGroupName",
        "url_template": "urlTemplate",
        "description": "description",
        "request": "request",
        "response": "response",
        "template_parameter": "templateParameter",
        "timeouts": "timeouts",
    },
)
class ApiManagementApiOperationConfig(cdktf.TerraformMetaArguments):
    def __init__(
        self,
        *,
        count: typing.Optional[jsii.Number] = None,
        depends_on: typing.Optional[typing.List[cdktf.TerraformResource]] = None,
        lifecycle: typing.Optional[cdktf.TerraformResourceLifecycle] = None,
        provider: typing.Optional[cdktf.TerraformProvider] = None,
        api_management_name: builtins.str,
        api_name: builtins.str,
        display_name: builtins.str,
        method: builtins.str,
        operation_id: builtins.str,
        resource_group_name: builtins.str,
        url_template: builtins.str,
        description: typing.Optional[builtins.str] = None,
        request: typing.Optional[typing.List["ApiManagementApiOperationRequest"]] = None,
        response: typing.Optional[typing.List["ApiManagementApiOperationResponse"]] = None,
        template_parameter: typing.Optional[typing.List["ApiManagementApiOperationTemplateParameter"]] = None,
        timeouts: typing.Optional["ApiManagementApiOperationTimeouts"] = None,
    ) -> None:
        """
        :param count: 
        :param depends_on: 
        :param lifecycle: 
        :param provider: 
        :param api_management_name: 
        :param api_name: 
        :param display_name: 
        :param method: 
        :param operation_id: 
        :param resource_group_name: 
        :param url_template: 
        :param description: 
        :param request: request block.
        :param response: response block.
        :param template_parameter: template_parameter block.
        :param timeouts: timeouts block.
        """
        if isinstance(lifecycle, dict):
            lifecycle = cdktf.TerraformResourceLifecycle(**lifecycle)
        if isinstance(timeouts, dict):
            timeouts = ApiManagementApiOperationTimeouts(**timeouts)
        self._values: typing.Dict[str, typing.Any] = {
            "api_management_name": api_management_name,
            "api_name": api_name,
            "display_name": display_name,
            "method": method,
            "operation_id": operation_id,
            "resource_group_name": resource_group_name,
            "url_template": url_template,
        }
        if count is not None:
            self._values["count"] = count
        if depends_on is not None:
            self._values["depends_on"] = depends_on
        if lifecycle is not None:
            self._values["lifecycle"] = lifecycle
        if provider is not None:
            self._values["provider"] = provider
        if description is not None:
            self._values["description"] = description
        if request is not None:
            self._values["request"] = request
        if response is not None:
            self._values["response"] = response
        if template_parameter is not None:
            self._values["template_parameter"] = template_parameter
        if timeouts is not None:
            self._values["timeouts"] = timeouts

    @builtins.property
    def count(self) -> typing.Optional[jsii.Number]:
        """
        :stability: experimental
        """
        result = self._values.get("count")
        return result

    @builtins.property
    def depends_on(self) -> typing.Optional[typing.List[cdktf.TerraformResource]]:
        """
        :stability: experimental
        """
        result = self._values.get("depends_on")
        return result

    @builtins.property
    def lifecycle(self) -> typing.Optional[cdktf.TerraformResourceLifecycle]:
        """
        :stability: experimental
        """
        result = self._values.get("lifecycle")
        return result

    @builtins.property
    def provider(self) -> typing.Optional[cdktf.TerraformProvider]:
        """
        :stability: experimental
        """
        result = self._values.get("provider")
        return result

    @builtins.property
    def api_management_name(self) -> builtins.str:
        result = self._values.get("api_management_name")
        assert result is not None, "Required property 'api_management_name' is missing"
        return result

    @builtins.property
    def api_name(self) -> builtins.str:
        result = self._values.get("api_name")
        assert result is not None, "Required property 'api_name' is missing"
        return result

    @builtins.property
    def display_name(self) -> builtins.str:
        result = self._values.get("display_name")
        assert result is not None, "Required property 'display_name' is missing"
        return result

    @builtins.property
    def method(self) -> builtins.str:
        result = self._values.get("method")
        assert result is not None, "Required property 'method' is missing"
        return result

    @builtins.property
    def operation_id(self) -> builtins.str:
        result = self._values.get("operation_id")
        assert result is not None, "Required property 'operation_id' is missing"
        return result

    @builtins.property
    def resource_group_name(self) -> builtins.str:
        result = self._values.get("resource_group_name")
        assert result is not None, "Required property 'resource_group_name' is missing"
        return result

    @builtins.property
    def url_template(self) -> builtins.str:
        result = self._values.get("url_template")
        assert result is not None, "Required property 'url_template' is missing"
        return result

    @builtins.property
    def description(self) -> typing.Optional[builtins.str]:
        result = self._values.get("description")
        return result

    @builtins.property
    def request(
        self,
    ) -> typing.Optional[typing.List["ApiManagementApiOperationRequest"]]:
        """request block."""
        result = self._values.get("request")
        return result

    @builtins.property
    def response(
        self,
    ) -> typing.Optional[typing.List["ApiManagementApiOperationResponse"]]:
        """response block."""
        result = self._values.get("response")
        return result

    @builtins.property
    def template_parameter(
        self,
    ) -> typing.Optional[typing.List["ApiManagementApiOperationTemplateParameter"]]:
        """template_parameter block."""
        result = self._values.get("template_parameter")
        return result

    @builtins.property
    def timeouts(self) -> typing.Optional["ApiManagementApiOperationTimeouts"]:
        """timeouts block."""
        result = self._values.get("timeouts")
        return result

    def __eq__(self, rhs: typing.Any) -> builtins.bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs: typing.Any) -> builtins.bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return "ApiManagementApiOperationConfig(%s)" % ", ".join(
            k + "=" + repr(v) for k, v in self._values.items()
        )


class ApiManagementApiOperationPolicy(
    cdktf.TerraformResource,
    metaclass=jsii.JSIIMeta,
    jsii_type="@cdktf/provider-azurerm.ApiManagementApiOperationPolicy",
):
    def __init__(
        self,
        scope: constructs.Construct,
        id: builtins.str,
        *,
        api_management_name: builtins.str,
        api_name: builtins.str,
        operation_id: builtins.str,
        resource_group_name: builtins.str,
        timeouts: typing.Optional["ApiManagementApiOperationPolicyTimeouts"] = None,
        xml_content: typing.Optional[builtins.str] = None,
        xml_link: typing.Optional[builtins.str] = None,
        count: typing.Optional[jsii.Number] = None,
        depends_on: typing.Optional[typing.List[cdktf.TerraformResource]] = None,
        lifecycle: typing.Optional[cdktf.TerraformResourceLifecycle] = None,
        provider: typing.Optional[cdktf.TerraformProvider] = None,
    ) -> None:
        """
        :param scope: -
        :param id: -
        :param api_management_name: 
        :param api_name: 
        :param operation_id: 
        :param resource_group_name: 
        :param timeouts: timeouts block.
        :param xml_content: 
        :param xml_link: 
        :param count: 
        :param depends_on: 
        :param lifecycle: 
        :param provider: 
        """
        config = ApiManagementApiOperationPolicyConfig(
            api_management_name=api_management_name,
            api_name=api_name,
            operation_id=operation_id,
            resource_group_name=resource_group_name,
            timeouts=timeouts,
            xml_content=xml_content,
            xml_link=xml_link,
            count=count,
            depends_on=depends_on,
            lifecycle=lifecycle,
            provider=provider,
        )

        jsii.create(ApiManagementApiOperationPolicy, self, [scope, id, config])

    @jsii.member(jsii_name="synthesizeAttributes")
    def _synthesize_attributes(self) -> typing.Mapping[builtins.str, typing.Any]:
        return jsii.invoke(self, "synthesizeAttributes", [])

    @builtins.property # type: ignore
    @jsii.member(jsii_name="apiManagementName")
    def api_management_name(self) -> builtins.str:
        return jsii.get(self, "apiManagementName")

    @api_management_name.setter # type: ignore
    def api_management_name(self, value: builtins.str) -> None:
        jsii.set(self, "apiManagementName", value)

    @builtins.property # type: ignore
    @jsii.member(jsii_name="apiName")
    def api_name(self) -> builtins.str:
        return jsii.get(self, "apiName")

    @api_name.setter # type: ignore
    def api_name(self, value: builtins.str) -> None:
        jsii.set(self, "apiName", value)

    @builtins.property # type: ignore
    @jsii.member(jsii_name="operationId")
    def operation_id(self) -> builtins.str:
        return jsii.get(self, "operationId")

    @operation_id.setter # type: ignore
    def operation_id(self, value: builtins.str) -> None:
        jsii.set(self, "operationId", value)

    @builtins.property # type: ignore
    @jsii.member(jsii_name="resourceGroupName")
    def resource_group_name(self) -> builtins.str:
        return jsii.get(self, "resourceGroupName")

    @resource_group_name.setter # type: ignore
    def resource_group_name(self, value: builtins.str) -> None:
        jsii.set(self, "resourceGroupName", value)

    @builtins.property # type: ignore
    @jsii.member(jsii_name="id")
    def id(self) -> typing.Optional[builtins.str]:
        return jsii.get(self, "id")

    @id.setter # type: ignore
    def id(self, value: typing.Optional[builtins.str]) -> None:
        jsii.set(self, "id", value)

    @builtins.property # type: ignore
    @jsii.member(jsii_name="timeouts")
    def timeouts(self) -> typing.Optional["ApiManagementApiOperationPolicyTimeouts"]:
        return jsii.get(self, "timeouts")

    @timeouts.setter # type: ignore
    def timeouts(
        self,
        value: typing.Optional["ApiManagementApiOperationPolicyTimeouts"],
    ) -> None:
        jsii.set(self, "timeouts", value)

    @builtins.property # type: ignore
    @jsii.member(jsii_name="xmlContent")
    def xml_content(self) -> typing.Optional[builtins.str]:
        return jsii.get(self, "xmlContent")

    @xml_content.setter # type: ignore
    def xml_content(self, value: typing.Optional[builtins.str]) -> None:
        jsii.set(self, "xmlContent", value)

    @builtins.property # type: ignore
    @jsii.member(jsii_name="xmlLink")
    def xml_link(self) -> typing.Optional[builtins.str]:
        return jsii.get(self, "xmlLink")

    @xml_link.setter # type: ignore
    def xml_link(self, value: typing.Optional[builtins.str]) -> None:
        jsii.set(self, "xmlLink", value)


@jsii.data_type(
    jsii_type="@cdktf/provider-azurerm.ApiManagementApiOperationPolicyConfig",
    jsii_struct_bases=[cdktf.TerraformMetaArguments],
    name_mapping={
        "count": "count",
        "depends_on": "dependsOn",
        "lifecycle": "lifecycle",
        "provider": "provider",
        "api_management_name": "apiManagementName",
        "api_name": "apiName",
        "operation_id": "operationId",
        "resource_group_name": "resourceGroupName",
        "timeouts": "timeouts",
        "xml_content": "xmlContent",
        "xml_link": "xmlLink",
    },
)
class ApiManagementApiOperationPolicyConfig(cdktf.TerraformMetaArguments):
    def __init__(
        self,
        *,
        count: typing.Optional[jsii.Number] = None,
        depends_on: typing.Optional[typing.List[cdktf.TerraformResource]] = None,
        lifecycle: typing.Optional[cdktf.TerraformResourceLifecycle] = None,
        provider: typing.Optional[cdktf.TerraformProvider] = None,
        api_management_name: builtins.str,
        api_name: builtins.str,
        operation_id: builtins.str,
        resource_group_name: builtins.str,
        timeouts: typing.Optional["ApiManagementApiOperationPolicyTimeouts"] = None,
        xml_content: typing.Optional[builtins.str] = None,
        xml_link: typing.Optional[builtins.str] = None,
    ) -> None:
        """
        :param count: 
        :param depends_on: 
        :param lifecycle: 
        :param provider: 
        :param api_management_name: 
        :param api_name: 
        :param operation_id: 
        :param resource_group_name: 
        :param timeouts: timeouts block.
        :param xml_content: 
        :param xml_link: 
        """
        if isinstance(lifecycle, dict):
            lifecycle = cdktf.TerraformResourceLifecycle(**lifecycle)
        if isinstance(timeouts, dict):
            timeouts = ApiManagementApiOperationPolicyTimeouts(**timeouts)
        self._values: typing.Dict[str, typing.Any] = {
            "api_management_name": api_management_name,
            "api_name": api_name,
            "operation_id": operation_id,
            "resource_group_name": resource_group_name,
        }
        if count is not None:
            self._values["count"] = count
        if depends_on is not None:
            self._values["depends_on"] = depends_on
        if lifecycle is not None:
            self._values["lifecycle"] = lifecycle
        if provider is not None:
            self._values["provider"] = provider
        if timeouts is not None:
            self._values["timeouts"] = timeouts
        if xml_content is not None:
            self._values["xml_content"] = xml_content
        if xml_link is not None:
            self._values["xml_link"] = xml_link

    @builtins.property
    def count(self) -> typing.Optional[jsii.Number]:
        """
        :stability: experimental
        """
        result = self._values.get("count")
        return result

    @builtins.property
    def depends_on(self) -> typing.Optional[typing.List[cdktf.TerraformResource]]:
        """
        :stability: experimental
        """
        result = self._values.get("depends_on")
        return result

    @builtins.property
    def lifecycle(self) -> typing.Optional[cdktf.TerraformResourceLifecycle]:
        """
        :stability: experimental
        """
        result = self._values.get("lifecycle")
        return result

    @builtins.property
    def provider(self) -> typing.Optional[cdktf.TerraformProvider]:
        """
        :stability: experimental
        """
        result = self._values.get("provider")
        return result

    @builtins.property
    def api_management_name(self) -> builtins.str:
        result = self._values.get("api_management_name")
        assert result is not None, "Required property 'api_management_name' is missing"
        return result

    @builtins.property
    def api_name(self) -> builtins.str:
        result = self._values.get("api_name")
        assert result is not None, "Required property 'api_name' is missing"
        return result

    @builtins.property
    def operation_id(self) -> builtins.str:
        result = self._values.get("operation_id")
        assert result is not None, "Required property 'operation_id' is missing"
        return result

    @builtins.property
    def resource_group_name(self) -> builtins.str:
        result = self._values.get("resource_group_name")
        assert result is not None, "Required property 'resource_group_name' is missing"
        return result

    @builtins.property
    def timeouts(self) -> typing.Optional["ApiManagementApiOperationPolicyTimeouts"]:
        """timeouts block."""
        result = self._values.get("timeouts")
        return result

    @builtins.property
    def xml_content(self) -> typing.Optional[builtins.str]:
        result = self._values.get("xml_content")
        return result

    @builtins.property
    def xml_link(self) -> typing.Optional[builtins.str]:
        result = self._values.get("xml_link")
        return result

    def __eq__(self, rhs: typing.Any) -> builtins.bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs: typing.Any) -> builtins.bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return "ApiManagementApiOperationPolicyConfig(%s)" % ", ".join(
            k + "=" + repr(v) for k, v in self._values.items()
        )


@jsii.data_type(
    jsii_type="@cdktf/provider-azurerm.ApiManagementApiOperationPolicyTimeouts",
    jsii_struct_bases=[],
    name_mapping={
        "create": "create",
        "delete": "delete",
        "read": "read",
        "update": "update",
    },
)
class ApiManagementApiOperationPolicyTimeouts:
    def __init__(
        self,
        *,
        create: typing.Optional[builtins.str] = None,
        delete: typing.Optional[builtins.str] = None,
        read: typing.Optional[builtins.str] = None,
        update: typing.Optional[builtins.str] = None,
    ) -> None:
        """
        :param create: 
        :param delete: 
        :param read: 
        :param update: 
        """
        self._values: typing.Dict[str, typing.Any] = {}
        if create is not None:
            self._values["create"] = create
        if delete is not None:
            self._values["delete"] = delete
        if read is not None:
            self._values["read"] = read
        if update is not None:
            self._values["update"] = update

    @builtins.property
    def create(self) -> typing.Optional[builtins.str]:
        result = self._values.get("create")
        return result

    @builtins.property
    def delete(self) -> typing.Optional[builtins.str]:
        result = self._values.get("delete")
        return result

    @builtins.property
    def read(self) -> typing.Optional[builtins.str]:
        result = self._values.get("read")
        return result

    @builtins.property
    def update(self) -> typing.Optional[builtins.str]:
        result = self._values.get("update")
        return result

    def __eq__(self, rhs: typing.Any) -> builtins.bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs: typing.Any) -> builtins.bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return "ApiManagementApiOperationPolicyTimeouts(%s)" % ", ".join(
            k + "=" + repr(v) for k, v in self._values.items()
        )


@jsii.data_type(
    jsii_type="@cdktf/provider-azurerm.ApiManagementApiOperationRequest",
    jsii_struct_bases=[],
    name_mapping={
        "description": "description",
        "header": "header",
        "query_parameter": "queryParameter",
        "representation": "representation",
    },
)
class ApiManagementApiOperationRequest:
    def __init__(
        self,
        *,
        description: typing.Optional[builtins.str] = None,
        header: typing.Optional[typing.List["ApiManagementApiOperationRequestHeader"]] = None,
        query_parameter: typing.Optional[typing.List["ApiManagementApiOperationRequestQueryParameter"]] = None,
        representation: typing.Optional[typing.List["ApiManagementApiOperationRequestRepresentation"]] = None,
    ) -> None:
        """
        :param description: 
        :param header: header block.
        :param query_parameter: query_parameter block.
        :param representation: representation block.
        """
        self._values: typing.Dict[str, typing.Any] = {}
        if description is not None:
            self._values["description"] = description
        if header is not None:
            self._values["header"] = header
        if query_parameter is not None:
            self._values["query_parameter"] = query_parameter
        if representation is not None:
            self._values["representation"] = representation

    @builtins.property
    def description(self) -> typing.Optional[builtins.str]:
        result = self._values.get("description")
        return result

    @builtins.property
    def header(
        self,
    ) -> typing.Optional[typing.List["ApiManagementApiOperationRequestHeader"]]:
        """header block."""
        result = self._values.get("header")
        return result

    @builtins.property
    def query_parameter(
        self,
    ) -> typing.Optional[typing.List["ApiManagementApiOperationRequestQueryParameter"]]:
        """query_parameter block."""
        result = self._values.get("query_parameter")
        return result

    @builtins.property
    def representation(
        self,
    ) -> typing.Optional[typing.List["ApiManagementApiOperationRequestRepresentation"]]:
        """representation block."""
        result = self._values.get("representation")
        return result

    def __eq__(self, rhs: typing.Any) -> builtins.bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs: typing.Any) -> builtins.bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return "ApiManagementApiOperationRequest(%s)" % ", ".join(
            k + "=" + repr(v) for k, v in self._values.items()
        )


@jsii.data_type(
    jsii_type="@cdktf/provider-azurerm.ApiManagementApiOperationRequestHeader",
    jsii_struct_bases=[],
    name_mapping={
        "name": "name",
        "required": "required",
        "type": "type",
        "default_value": "defaultValue",
        "description": "description",
        "values": "values",
    },
)
class ApiManagementApiOperationRequestHeader:
    def __init__(
        self,
        *,
        name: builtins.str,
        required: builtins.bool,
        type: builtins.str,
        default_value: typing.Optional[builtins.str] = None,
        description: typing.Optional[builtins.str] = None,
        values: typing.Optional[typing.List[builtins.str]] = None,
    ) -> None:
        """
        :param name: 
        :param required: 
        :param type: 
        :param default_value: 
        :param description: 
        :param values: 
        """
        self._values: typing.Dict[str, typing.Any] = {
            "name": name,
            "required": required,
            "type": type,
        }
        if default_value is not None:
            self._values["default_value"] = default_value
        if description is not None:
            self._values["description"] = description
        if values is not None:
            self._values["values"] = values

    @builtins.property
    def name(self) -> builtins.str:
        result = self._values.get("name")
        assert result is not None, "Required property 'name' is missing"
        return result

    @builtins.property
    def required(self) -> builtins.bool:
        result = self._values.get("required")
        assert result is not None, "Required property 'required' is missing"
        return result

    @builtins.property
    def type(self) -> builtins.str:
        result = self._values.get("type")
        assert result is not None, "Required property 'type' is missing"
        return result

    @builtins.property
    def default_value(self) -> typing.Optional[builtins.str]:
        result = self._values.get("default_value")
        return result

    @builtins.property
    def description(self) -> typing.Optional[builtins.str]:
        result = self._values.get("description")
        return result

    @builtins.property
    def values(self) -> typing.Optional[typing.List[builtins.str]]:
        result = self._values.get("values")
        return result

    def __eq__(self, rhs: typing.Any) -> builtins.bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs: typing.Any) -> builtins.bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return "ApiManagementApiOperationRequestHeader(%s)" % ", ".join(
            k + "=" + repr(v) for k, v in self._values.items()
        )


@jsii.data_type(
    jsii_type="@cdktf/provider-azurerm.ApiManagementApiOperationRequestQueryParameter",
    jsii_struct_bases=[],
    name_mapping={
        "name": "name",
        "required": "required",
        "type": "type",
        "default_value": "defaultValue",
        "description": "description",
        "values": "values",
    },
)
class ApiManagementApiOperationRequestQueryParameter:
    def __init__(
        self,
        *,
        name: builtins.str,
        required: builtins.bool,
        type: builtins.str,
        default_value: typing.Optional[builtins.str] = None,
        description: typing.Optional[builtins.str] = None,
        values: typing.Optional[typing.List[builtins.str]] = None,
    ) -> None:
        """
        :param name: 
        :param required: 
        :param type: 
        :param default_value: 
        :param description: 
        :param values: 
        """
        self._values: typing.Dict[str, typing.Any] = {
            "name": name,
            "required": required,
            "type": type,
        }
        if default_value is not None:
            self._values["default_value"] = default_value
        if description is not None:
            self._values["description"] = description
        if values is not None:
            self._values["values"] = values

    @builtins.property
    def name(self) -> builtins.str:
        result = self._values.get("name")
        assert result is not None, "Required property 'name' is missing"
        return result

    @builtins.property
    def required(self) -> builtins.bool:
        result = self._values.get("required")
        assert result is not None, "Required property 'required' is missing"
        return result

    @builtins.property
    def type(self) -> builtins.str:
        result = self._values.get("type")
        assert result is not None, "Required property 'type' is missing"
        return result

    @builtins.property
    def default_value(self) -> typing.Optional[builtins.str]:
        result = self._values.get("default_value")
        return result

    @builtins.property
    def description(self) -> typing.Optional[builtins.str]:
        result = self._values.get("description")
        return result

    @builtins.property
    def values(self) -> typing.Optional[typing.List[builtins.str]]:
        result = self._values.get("values")
        return result

    def __eq__(self, rhs: typing.Any) -> builtins.bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs: typing.Any) -> builtins.bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return "ApiManagementApiOperationRequestQueryParameter(%s)" % ", ".join(
            k + "=" + repr(v) for k, v in self._values.items()
        )


@jsii.data_type(
    jsii_type="@cdktf/provider-azurerm.ApiManagementApiOperationRequestRepresentation",
    jsii_struct_bases=[],
    name_mapping={
        "content_type": "contentType",
        "form_parameter": "formParameter",
        "sample": "sample",
        "schema_id": "schemaId",
        "type_name": "typeName",
    },
)
class ApiManagementApiOperationRequestRepresentation:
    def __init__(
        self,
        *,
        content_type: builtins.str,
        form_parameter: typing.Optional[typing.List["ApiManagementApiOperationRequestRepresentationFormParameter"]] = None,
        sample: typing.Optional[builtins.str] = None,
        schema_id: typing.Optional[builtins.str] = None,
        type_name: typing.Optional[builtins.str] = None,
    ) -> None:
        """
        :param content_type: 
        :param form_parameter: form_parameter block.
        :param sample: 
        :param schema_id: 
        :param type_name: 
        """
        self._values: typing.Dict[str, typing.Any] = {
            "content_type": content_type,
        }
        if form_parameter is not None:
            self._values["form_parameter"] = form_parameter
        if sample is not None:
            self._values["sample"] = sample
        if schema_id is not None:
            self._values["schema_id"] = schema_id
        if type_name is not None:
            self._values["type_name"] = type_name

    @builtins.property
    def content_type(self) -> builtins.str:
        result = self._values.get("content_type")
        assert result is not None, "Required property 'content_type' is missing"
        return result

    @builtins.property
    def form_parameter(
        self,
    ) -> typing.Optional[typing.List["ApiManagementApiOperationRequestRepresentationFormParameter"]]:
        """form_parameter block."""
        result = self._values.get("form_parameter")
        return result

    @builtins.property
    def sample(self) -> typing.Optional[builtins.str]:
        result = self._values.get("sample")
        return result

    @builtins.property
    def schema_id(self) -> typing.Optional[builtins.str]:
        result = self._values.get("schema_id")
        return result

    @builtins.property
    def type_name(self) -> typing.Optional[builtins.str]:
        result = self._values.get("type_name")
        return result

    def __eq__(self, rhs: typing.Any) -> builtins.bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs: typing.Any) -> builtins.bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return "ApiManagementApiOperationRequestRepresentation(%s)" % ", ".join(
            k + "=" + repr(v) for k, v in self._values.items()
        )


@jsii.data_type(
    jsii_type="@cdktf/provider-azurerm.ApiManagementApiOperationRequestRepresentationFormParameter",
    jsii_struct_bases=[],
    name_mapping={
        "name": "name",
        "required": "required",
        "type": "type",
        "default_value": "defaultValue",
        "description": "description",
        "values": "values",
    },
)
class ApiManagementApiOperationRequestRepresentationFormParameter:
    def __init__(
        self,
        *,
        name: builtins.str,
        required: builtins.bool,
        type: builtins.str,
        default_value: typing.Optional[builtins.str] = None,
        description: typing.Optional[builtins.str] = None,
        values: typing.Optional[typing.List[builtins.str]] = None,
    ) -> None:
        """
        :param name: 
        :param required: 
        :param type: 
        :param default_value: 
        :param description: 
        :param values: 
        """
        self._values: typing.Dict[str, typing.Any] = {
            "name": name,
            "required": required,
            "type": type,
        }
        if default_value is not None:
            self._values["default_value"] = default_value
        if description is not None:
            self._values["description"] = description
        if values is not None:
            self._values["values"] = values

    @builtins.property
    def name(self) -> builtins.str:
        result = self._values.get("name")
        assert result is not None, "Required property 'name' is missing"
        return result

    @builtins.property
    def required(self) -> builtins.bool:
        result = self._values.get("required")
        assert result is not None, "Required property 'required' is missing"
        return result

    @builtins.property
    def type(self) -> builtins.str:
        result = self._values.get("type")
        assert result is not None, "Required property 'type' is missing"
        return result

    @builtins.property
    def default_value(self) -> typing.Optional[builtins.str]:
        result = self._values.get("default_value")
        return result

    @builtins.property
    def description(self) -> typing.Optional[builtins.str]:
        result = self._values.get("description")
        return result

    @builtins.property
    def values(self) -> typing.Optional[typing.List[builtins.str]]:
        result = self._values.get("values")
        return result

    def __eq__(self, rhs: typing.Any) -> builtins.bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs: typing.Any) -> builtins.bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return "ApiManagementApiOperationRequestRepresentationFormParameter(%s)" % ", ".join(
            k + "=" + repr(v) for k, v in self._values.items()
        )


@jsii.data_type(
    jsii_type="@cdktf/provider-azurerm.ApiManagementApiOperationResponse",
    jsii_struct_bases=[],
    name_mapping={
        "status_code": "statusCode",
        "description": "description",
        "header": "header",
        "representation": "representation",
    },
)
class ApiManagementApiOperationResponse:
    def __init__(
        self,
        *,
        status_code: jsii.Number,
        description: typing.Optional[builtins.str] = None,
        header: typing.Optional[typing.List["ApiManagementApiOperationResponseHeader"]] = None,
        representation: typing.Optional[typing.List["ApiManagementApiOperationResponseRepresentation"]] = None,
    ) -> None:
        """
        :param status_code: 
        :param description: 
        :param header: header block.
        :param representation: representation block.
        """
        self._values: typing.Dict[str, typing.Any] = {
            "status_code": status_code,
        }
        if description is not None:
            self._values["description"] = description
        if header is not None:
            self._values["header"] = header
        if representation is not None:
            self._values["representation"] = representation

    @builtins.property
    def status_code(self) -> jsii.Number:
        result = self._values.get("status_code")
        assert result is not None, "Required property 'status_code' is missing"
        return result

    @builtins.property
    def description(self) -> typing.Optional[builtins.str]:
        result = self._values.get("description")
        return result

    @builtins.property
    def header(
        self,
    ) -> typing.Optional[typing.List["ApiManagementApiOperationResponseHeader"]]:
        """header block."""
        result = self._values.get("header")
        return result

    @builtins.property
    def representation(
        self,
    ) -> typing.Optional[typing.List["ApiManagementApiOperationResponseRepresentation"]]:
        """representation block."""
        result = self._values.get("representation")
        return result

    def __eq__(self, rhs: typing.Any) -> builtins.bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs: typing.Any) -> builtins.bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return "ApiManagementApiOperationResponse(%s)" % ", ".join(
            k + "=" + repr(v) for k, v in self._values.items()
        )


@jsii.data_type(
    jsii_type="@cdktf/provider-azurerm.ApiManagementApiOperationResponseHeader",
    jsii_struct_bases=[],
    name_mapping={
        "name": "name",
        "required": "required",
        "type": "type",
        "default_value": "defaultValue",
        "description": "description",
        "values": "values",
    },
)
class ApiManagementApiOperationResponseHeader:
    def __init__(
        self,
        *,
        name: builtins.str,
        required: builtins.bool,
        type: builtins.str,
        default_value: typing.Optional[builtins.str] = None,
        description: typing.Optional[builtins.str] = None,
        values: typing.Optional[typing.List[builtins.str]] = None,
    ) -> None:
        """
        :param name: 
        :param required: 
        :param type: 
        :param default_value: 
        :param description: 
        :param values: 
        """
        self._values: typing.Dict[str, typing.Any] = {
            "name": name,
            "required": required,
            "type": type,
        }
        if default_value is not None:
            self._values["default_value"] = default_value
        if description is not None:
            self._values["description"] = description
        if values is not None:
            self._values["values"] = values

    @builtins.property
    def name(self) -> builtins.str:
        result = self._values.get("name")
        assert result is not None, "Required property 'name' is missing"
        return result

    @builtins.property
    def required(self) -> builtins.bool:
        result = self._values.get("required")
        assert result is not None, "Required property 'required' is missing"
        return result

    @builtins.property
    def type(self) -> builtins.str:
        result = self._values.get("type")
        assert result is not None, "Required property 'type' is missing"
        return result

    @builtins.property
    def default_value(self) -> typing.Optional[builtins.str]:
        result = self._values.get("default_value")
        return result

    @builtins.property
    def description(self) -> typing.Optional[builtins.str]:
        result = self._values.get("description")
        return result

    @builtins.property
    def values(self) -> typing.Optional[typing.List[builtins.str]]:
        result = self._values.get("values")
        return result

    def __eq__(self, rhs: typing.Any) -> builtins.bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs: typing.Any) -> builtins.bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return "ApiManagementApiOperationResponseHeader(%s)" % ", ".join(
            k + "=" + repr(v) for k, v in self._values.items()
        )


@jsii.data_type(
    jsii_type="@cdktf/provider-azurerm.ApiManagementApiOperationResponseRepresentation",
    jsii_struct_bases=[],
    name_mapping={
        "content_type": "contentType",
        "form_parameter": "formParameter",
        "sample": "sample",
        "schema_id": "schemaId",
        "type_name": "typeName",
    },
)
class ApiManagementApiOperationResponseRepresentation:
    def __init__(
        self,
        *,
        content_type: builtins.str,
        form_parameter: typing.Optional[typing.List["ApiManagementApiOperationResponseRepresentationFormParameter"]] = None,
        sample: typing.Optional[builtins.str] = None,
        schema_id: typing.Optional[builtins.str] = None,
        type_name: typing.Optional[builtins.str] = None,
    ) -> None:
        """
        :param content_type: 
        :param form_parameter: form_parameter block.
        :param sample: 
        :param schema_id: 
        :param type_name: 
        """
        self._values: typing.Dict[str, typing.Any] = {
            "content_type": content_type,
        }
        if form_parameter is not None:
            self._values["form_parameter"] = form_parameter
        if sample is not None:
            self._values["sample"] = sample
        if schema_id is not None:
            self._values["schema_id"] = schema_id
        if type_name is not None:
            self._values["type_name"] = type_name

    @builtins.property
    def content_type(self) -> builtins.str:
        result = self._values.get("content_type")
        assert result is not None, "Required property 'content_type' is missing"
        return result

    @builtins.property
    def form_parameter(
        self,
    ) -> typing.Optional[typing.List["ApiManagementApiOperationResponseRepresentationFormParameter"]]:
        """form_parameter block."""
        result = self._values.get("form_parameter")
        return result

    @builtins.property
    def sample(self) -> typing.Optional[builtins.str]:
        result = self._values.get("sample")
        return result

    @builtins.property
    def schema_id(self) -> typing.Optional[builtins.str]:
        result = self._values.get("schema_id")
        return result

    @builtins.property
    def type_name(self) -> typing.Optional[builtins.str]:
        result = self._values.get("type_name")
        return result

    def __eq__(self, rhs: typing.Any) -> builtins.bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs: typing.Any) -> builtins.bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return "ApiManagementApiOperationResponseRepresentation(%s)" % ", ".join(
            k + "=" + repr(v) for k, v in self._values.items()
        )


@jsii.data_type(
    jsii_type="@cdktf/provider-azurerm.ApiManagementApiOperationResponseRepresentationFormParameter",
    jsii_struct_bases=[],
    name_mapping={
        "name": "name",
        "required": "required",
        "type": "type",
        "default_value": "defaultValue",
        "description": "description",
        "values": "values",
    },
)
class ApiManagementApiOperationResponseRepresentationFormParameter:
    def __init__(
        self,
        *,
        name: builtins.str,
        required: builtins.bool,
        type: builtins.str,
        default_value: typing.Optional[builtins.str] = None,
        description: typing.Optional[builtins.str] = None,
        values: typing.Optional[typing.List[builtins.str]] = None,
    ) -> None:
        """
        :param name: 
        :param required: 
        :param type: 
        :param default_value: 
        :param description: 
        :param values: 
        """
        self._values: typing.Dict[str, typing.Any] = {
            "name": name,
            "required": required,
            "type": type,
        }
        if default_value is not None:
            self._values["default_value"] = default_value
        if description is not None:
            self._values["description"] = description
        if values is not None:
            self._values["values"] = values

    @builtins.property
    def name(self) -> builtins.str:
        result = self._values.get("name")
        assert result is not None, "Required property 'name' is missing"
        return result

    @builtins.property
    def required(self) -> builtins.bool:
        result = self._values.get("required")
        assert result is not None, "Required property 'required' is missing"
        return result

    @builtins.property
    def type(self) -> builtins.str:
        result = self._values.get("type")
        assert result is not None, "Required property 'type' is missing"
        return result

    @builtins.property
    def default_value(self) -> typing.Optional[builtins.str]:
        result = self._values.get("default_value")
        return result

    @builtins.property
    def description(self) -> typing.Optional[builtins.str]:
        result = self._values.get("description")
        return result

    @builtins.property
    def values(self) -> typing.Optional[typing.List[builtins.str]]:
        result = self._values.get("values")
        return result

    def __eq__(self, rhs: typing.Any) -> builtins.bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs: typing.Any) -> builtins.bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return "ApiManagementApiOperationResponseRepresentationFormParameter(%s)" % ", ".join(
            k + "=" + repr(v) for k, v in self._values.items()
        )


@jsii.data_type(
    jsii_type="@cdktf/provider-azurerm.ApiManagementApiOperationTemplateParameter",
    jsii_struct_bases=[],
    name_mapping={
        "name": "name",
        "required": "required",
        "type": "type",
        "default_value": "defaultValue",
        "description": "description",
        "values": "values",
    },
)
class ApiManagementApiOperationTemplateParameter:
    def __init__(
        self,
        *,
        name: builtins.str,
        required: builtins.bool,
        type: builtins.str,
        default_value: typing.Optional[builtins.str] = None,
        description: typing.Optional[builtins.str] = None,
        values: typing.Optional[typing.List[builtins.str]] = None,
    ) -> None:
        """
        :param name: 
        :param required: 
        :param type: 
        :param default_value: 
        :param description: 
        :param values: 
        """
        self._values: typing.Dict[str, typing.Any] = {
            "name": name,
            "required": required,
            "type": type,
        }
        if default_value is not None:
            self._values["default_value"] = default_value
        if description is not None:
            self._values["description"] = description
        if values is not None:
            self._values["values"] = values

    @builtins.property
    def name(self) -> builtins.str:
        result = self._values.get("name")
        assert result is not None, "Required property 'name' is missing"
        return result

    @builtins.property
    def required(self) -> builtins.bool:
        result = self._values.get("required")
        assert result is not None, "Required property 'required' is missing"
        return result

    @builtins.property
    def type(self) -> builtins.str:
        result = self._values.get("type")
        assert result is not None, "Required property 'type' is missing"
        return result

    @builtins.property
    def default_value(self) -> typing.Optional[builtins.str]:
        result = self._values.get("default_value")
        return result

    @builtins.property
    def description(self) -> typing.Optional[builtins.str]:
        result = self._values.get("description")
        return result

    @builtins.property
    def values(self) -> typing.Optional[typing.List[builtins.str]]:
        result = self._values.get("values")
        return result

    def __eq__(self, rhs: typing.Any) -> builtins.bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs: typing.Any) -> builtins.bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return "ApiManagementApiOperationTemplateParameter(%s)" % ", ".join(
            k + "=" + repr(v) for k, v in self._values.items()
        )


@jsii.data_type(
    jsii_type="@cdktf/provider-azurerm.ApiManagementApiOperationTimeouts",
    jsii_struct_bases=[],
    name_mapping={
        "create": "create",
        "delete": "delete",
        "read": "read",
        "update": "update",
    },
)
class ApiManagementApiOperationTimeouts:
    def __init__(
        self,
        *,
        create: typing.Optional[builtins.str] = None,
        delete: typing.Optional[builtins.str] = None,
        read: typing.Optional[builtins.str] = None,
        update: typing.Optional[builtins.str] = None,
    ) -> None:
        """
        :param create: 
        :param delete: 
        :param read: 
        :param update: 
        """
        self._values: typing.Dict[str, typing.Any] = {}
        if create is not None:
            self._values["create"] = create
        if delete is not None:
            self._values["delete"] = delete
        if read is not None:
            self._values["read"] = read
        if update is not None:
            self._values["update"] = update

    @builtins.property
    def create(self) -> typing.Optional[builtins.str]:
        result = self._values.get("create")
        return result

    @builtins.property
    def delete(self) -> typing.Optional[builtins.str]:
        result = self._values.get("delete")
        return result

    @builtins.property
    def read(self) -> typing.Optional[builtins.str]:
        result = self._values.get("read")
        return result

    @builtins.property
    def update(self) -> typing.Optional[builtins.str]:
        result = self._values.get("update")
        return result

    def __eq__(self, rhs: typing.Any) -> builtins.bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs: typing.Any) -> builtins.bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return "ApiManagementApiOperationTimeouts(%s)" % ", ".join(
            k + "=" + repr(v) for k, v in self._values.items()
        )


class ApiManagementApiPolicy(
    cdktf.TerraformResource,
    metaclass=jsii.JSIIMeta,
    jsii_type="@cdktf/provider-azurerm.ApiManagementApiPolicy",
):
    def __init__(
        self,
        scope: constructs.Construct,
        id: builtins.str,
        *,
        api_management_name: builtins.str,
        api_name: builtins.str,
        resource_group_name: builtins.str,
        timeouts: typing.Optional["ApiManagementApiPolicyTimeouts"] = None,
        xml_content: typing.Optional[builtins.str] = None,
        xml_link: typing.Optional[builtins.str] = None,
        count: typing.Optional[jsii.Number] = None,
        depends_on: typing.Optional[typing.List[cdktf.TerraformResource]] = None,
        lifecycle: typing.Optional[cdktf.TerraformResourceLifecycle] = None,
        provider: typing.Optional[cdktf.TerraformProvider] = None,
    ) -> None:
        """
        :param scope: -
        :param id: -
        :param api_management_name: 
        :param api_name: 
        :param resource_group_name: 
        :param timeouts: timeouts block.
        :param xml_content: 
        :param xml_link: 
        :param count: 
        :param depends_on: 
        :param lifecycle: 
        :param provider: 
        """
        config = ApiManagementApiPolicyConfig(
            api_management_name=api_management_name,
            api_name=api_name,
            resource_group_name=resource_group_name,
            timeouts=timeouts,
            xml_content=xml_content,
            xml_link=xml_link,
            count=count,
            depends_on=depends_on,
            lifecycle=lifecycle,
            provider=provider,
        )

        jsii.create(ApiManagementApiPolicy, self, [scope, id, config])

    @jsii.member(jsii_name="synthesizeAttributes")
    def _synthesize_attributes(self) -> typing.Mapping[builtins.str, typing.Any]:
        return jsii.invoke(self, "synthesizeAttributes", [])

    @builtins.property # type: ignore
    @jsii.member(jsii_name="apiManagementName")
    def api_management_name(self) -> builtins.str:
        return jsii.get(self, "apiManagementName")

    @api_management_name.setter # type: ignore
    def api_management_name(self, value: builtins.str) -> None:
        jsii.set(self, "apiManagementName", value)

    @builtins.property # type: ignore
    @jsii.member(jsii_name="apiName")
    def api_name(self) -> builtins.str:
        return jsii.get(self, "apiName")

    @api_name.setter # type: ignore
    def api_name(self, value: builtins.str) -> None:
        jsii.set(self, "apiName", value)

    @builtins.property # type: ignore
    @jsii.member(jsii_name="resourceGroupName")
    def resource_group_name(self) -> builtins.str:
        return jsii.get(self, "resourceGroupName")

    @resource_group_name.setter # type: ignore
    def resource_group_name(self, value: builtins.str) -> None:
        jsii.set(self, "resourceGroupName", value)

    @builtins.property # type: ignore
    @jsii.member(jsii_name="id")
    def id(self) -> typing.Optional[builtins.str]:
        return jsii.get(self, "id")

    @id.setter # type: ignore
    def id(self, value: typing.Optional[builtins.str]) -> None:
        jsii.set(self, "id", value)

    @builtins.property # type: ignore
    @jsii.member(jsii_name="timeouts")
    def timeouts(self) -> typing.Optional["ApiManagementApiPolicyTimeouts"]:
        return jsii.get(self, "timeouts")

    @timeouts.setter # type: ignore
    def timeouts(
        self,
        value: typing.Optional["ApiManagementApiPolicyTimeouts"],
    ) -> None:
        jsii.set(self, "timeouts", value)

    @builtins.property # type: ignore
    @jsii.member(jsii_name="xmlContent")
    def xml_content(self) -> typing.Optional[builtins.str]:
        return jsii.get(self, "xmlContent")

    @xml_content.setter # type: ignore
    def xml_content(self, value: typing.Optional[builtins.str]) -> None:
        jsii.set(self, "xmlContent", value)

    @builtins.property # type: ignore
    @jsii.member(jsii_name="xmlLink")
    def xml_link(self) -> typing.Optional[builtins.str]:
        return jsii.get(self, "xmlLink")

    @xml_link.setter # type: ignore
    def xml_link(self, value: typing.Optional[builtins.str]) -> None:
        jsii.set(self, "xmlLink", value)


@jsii.data_type(
    jsii_type="@cdktf/provider-azurerm.ApiManagementApiPolicyConfig",
    jsii_struct_bases=[cdktf.TerraformMetaArguments],
    name_mapping={
        "count": "count",
        "depends_on": "dependsOn",
        "lifecycle": "lifecycle",
        "provider": "provider",
        "api_management_name": "apiManagementName",
        "api_name": "apiName",
        "resource_group_name": "resourceGroupName",
        "timeouts": "timeouts",
        "xml_content": "xmlContent",
        "xml_link": "xmlLink",
    },
)
class ApiManagementApiPolicyConfig(cdktf.TerraformMetaArguments):
    def __init__(
        self,
        *,
        count: typing.Optional[jsii.Number] = None,
        depends_on: typing.Optional[typing.List[cdktf.TerraformResource]] = None,
        lifecycle: typing.Optional[cdktf.TerraformResourceLifecycle] = None,
        provider: typing.Optional[cdktf.TerraformProvider] = None,
        api_management_name: builtins.str,
        api_name: builtins.str,
        resource_group_name: builtins.str,
        timeouts: typing.Optional["ApiManagementApiPolicyTimeouts"] = None,
        xml_content: typing.Optional[builtins.str] = None,
        xml_link: typing.Optional[builtins.str] = None,
    ) -> None:
        """
        :param count: 
        :param depends_on: 
        :param lifecycle: 
        :param provider: 
        :param api_management_name: 
        :param api_name: 
        :param resource_group_name: 
        :param timeouts: timeouts block.
        :param xml_content: 
        :param xml_link: 
        """
        if isinstance(lifecycle, dict):
            lifecycle = cdktf.TerraformResourceLifecycle(**lifecycle)
        if isinstance(timeouts, dict):
            timeouts = ApiManagementApiPolicyTimeouts(**timeouts)
        self._values: typing.Dict[str, typing.Any] = {
            "api_management_name": api_management_name,
            "api_name": api_name,
            "resource_group_name": resource_group_name,
        }
        if count is not None:
            self._values["count"] = count
        if depends_on is not None:
            self._values["depends_on"] = depends_on
        if lifecycle is not None:
            self._values["lifecycle"] = lifecycle
        if provider is not None:
            self._values["provider"] = provider
        if timeouts is not None:
            self._values["timeouts"] = timeouts
        if xml_content is not None:
            self._values["xml_content"] = xml_content
        if xml_link is not None:
            self._values["xml_link"] = xml_link

    @builtins.property
    def count(self) -> typing.Optional[jsii.Number]:
        """
        :stability: experimental
        """
        result = self._values.get("count")
        return result

    @builtins.property
    def depends_on(self) -> typing.Optional[typing.List[cdktf.TerraformResource]]:
        """
        :stability: experimental
        """
        result = self._values.get("depends_on")
        return result

    @builtins.property
    def lifecycle(self) -> typing.Optional[cdktf.TerraformResourceLifecycle]:
        """
        :stability: experimental
        """
        result = self._values.get("lifecycle")
        return result

    @builtins.property
    def provider(self) -> typing.Optional[cdktf.TerraformProvider]:
        """
        :stability: experimental
        """
        result = self._values.get("provider")
        return result

    @builtins.property
    def api_management_name(self) -> builtins.str:
        result = self._values.get("api_management_name")
        assert result is not None, "Required property 'api_management_name' is missing"
        return result

    @builtins.property
    def api_name(self) -> builtins.str:
        result = self._values.get("api_name")
        assert result is not None, "Required property 'api_name' is missing"
        return result

    @builtins.property
    def resource_group_name(self) -> builtins.str:
        result = self._values.get("resource_group_name")
        assert result is not None, "Required property 'resource_group_name' is missing"
        return result

    @builtins.property
    def timeouts(self) -> typing.Optional["ApiManagementApiPolicyTimeouts"]:
        """timeouts block."""
        result = self._values.get("timeouts")
        return result

    @builtins.property
    def xml_content(self) -> typing.Optional[builtins.str]:
        result = self._values.get("xml_content")
        return result

    @builtins.property
    def xml_link(self) -> typing.Optional[builtins.str]:
        result = self._values.get("xml_link")
        return result

    def __eq__(self, rhs: typing.Any) -> builtins.bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs: typing.Any) -> builtins.bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return "ApiManagementApiPolicyConfig(%s)" % ", ".join(
            k + "=" + repr(v) for k, v in self._values.items()
        )


@jsii.data_type(
    jsii_type="@cdktf/provider-azurerm.ApiManagementApiPolicyTimeouts",
    jsii_struct_bases=[],
    name_mapping={
        "create": "create",
        "delete": "delete",
        "read": "read",
        "update": "update",
    },
)
class ApiManagementApiPolicyTimeouts:
    def __init__(
        self,
        *,
        create: typing.Optional[builtins.str] = None,
        delete: typing.Optional[builtins.str] = None,
        read: typing.Optional[builtins.str] = None,
        update: typing.Optional[builtins.str] = None,
    ) -> None:
        """
        :param create: 
        :param delete: 
        :param read: 
        :param update: 
        """
        self._values: typing.Dict[str, typing.Any] = {}
        if create is not None:
            self._values["create"] = create
        if delete is not None:
            self._values["delete"] = delete
        if read is not None:
            self._values["read"] = read
        if update is not None:
            self._values["update"] = update

    @builtins.property
    def create(self) -> typing.Optional[builtins.str]:
        result = self._values.get("create")
        return result

    @builtins.property
    def delete(self) -> typing.Optional[builtins.str]:
        result = self._values.get("delete")
        return result

    @builtins.property
    def read(self) -> typing.Optional[builtins.str]:
        result = self._values.get("read")
        return result

    @builtins.property
    def update(self) -> typing.Optional[builtins.str]:
        result = self._values.get("update")
        return result

    def __eq__(self, rhs: typing.Any) -> builtins.bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs: typing.Any) -> builtins.bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return "ApiManagementApiPolicyTimeouts(%s)" % ", ".join(
            k + "=" + repr(v) for k, v in self._values.items()
        )


class ApiManagementApiSchema(
    cdktf.TerraformResource,
    metaclass=jsii.JSIIMeta,
    jsii_type="@cdktf/provider-azurerm.ApiManagementApiSchema",
):
    def __init__(
        self,
        scope: constructs.Construct,
        id: builtins.str,
        *,
        api_management_name: builtins.str,
        api_name: builtins.str,
        content_type: builtins.str,
        resource_group_name: builtins.str,
        schema_id: builtins.str,
        value: builtins.str,
        timeouts: typing.Optional["ApiManagementApiSchemaTimeouts"] = None,
        count: typing.Optional[jsii.Number] = None,
        depends_on: typing.Optional[typing.List[cdktf.TerraformResource]] = None,
        lifecycle: typing.Optional[cdktf.TerraformResourceLifecycle] = None,
        provider: typing.Optional[cdktf.TerraformProvider] = None,
    ) -> None:
        """
        :param scope: -
        :param id: -
        :param api_management_name: 
        :param api_name: 
        :param content_type: 
        :param resource_group_name: 
        :param schema_id: 
        :param value: 
        :param timeouts: timeouts block.
        :param count: 
        :param depends_on: 
        :param lifecycle: 
        :param provider: 
        """
        config = ApiManagementApiSchemaConfig(
            api_management_name=api_management_name,
            api_name=api_name,
            content_type=content_type,
            resource_group_name=resource_group_name,
            schema_id=schema_id,
            value=value,
            timeouts=timeouts,
            count=count,
            depends_on=depends_on,
            lifecycle=lifecycle,
            provider=provider,
        )

        jsii.create(ApiManagementApiSchema, self, [scope, id, config])

    @jsii.member(jsii_name="synthesizeAttributes")
    def _synthesize_attributes(self) -> typing.Mapping[builtins.str, typing.Any]:
        return jsii.invoke(self, "synthesizeAttributes", [])

    @builtins.property # type: ignore
    @jsii.member(jsii_name="apiManagementName")
    def api_management_name(self) -> builtins.str:
        return jsii.get(self, "apiManagementName")

    @api_management_name.setter # type: ignore
    def api_management_name(self, value: builtins.str) -> None:
        jsii.set(self, "apiManagementName", value)

    @builtins.property # type: ignore
    @jsii.member(jsii_name="apiName")
    def api_name(self) -> builtins.str:
        return jsii.get(self, "apiName")

    @api_name.setter # type: ignore
    def api_name(self, value: builtins.str) -> None:
        jsii.set(self, "apiName", value)

    @builtins.property # type: ignore
    @jsii.member(jsii_name="contentType")
    def content_type(self) -> builtins.str:
        return jsii.get(self, "contentType")

    @content_type.setter # type: ignore
    def content_type(self, value: builtins.str) -> None:
        jsii.set(self, "contentType", value)

    @builtins.property # type: ignore
    @jsii.member(jsii_name="resourceGroupName")
    def resource_group_name(self) -> builtins.str:
        return jsii.get(self, "resourceGroupName")

    @resource_group_name.setter # type: ignore
    def resource_group_name(self, value: builtins.str) -> None:
        jsii.set(self, "resourceGroupName", value)

    @builtins.property # type: ignore
    @jsii.member(jsii_name="schemaId")
    def schema_id(self) -> builtins.str:
        return jsii.get(self, "schemaId")

    @schema_id.setter # type: ignore
    def schema_id(self, value: builtins.str) -> None:
        jsii.set(self, "schemaId", value)

    @builtins.property # type: ignore
    @jsii.member(jsii_name="value")
    def value(self) -> builtins.str:
        return jsii.get(self, "value")

    @value.setter # type: ignore
    def value(self, value: builtins.str) -> None:
        jsii.set(self, "value", value)

    @builtins.property # type: ignore
    @jsii.member(jsii_name="id")
    def id(self) -> typing.Optional[builtins.str]:
        return jsii.get(self, "id")

    @id.setter # type: ignore
    def id(self, value: typing.Optional[builtins.str]) -> None:
        jsii.set(self, "id", value)

    @builtins.property # type: ignore
    @jsii.member(jsii_name="timeouts")
    def timeouts(self) -> typing.Optional["ApiManagementApiSchemaTimeouts"]:
        return jsii.get(self, "timeouts")

    @timeouts.setter # type: ignore
    def timeouts(
        self,
        value: typing.Optional["ApiManagementApiSchemaTimeouts"],
    ) -> None:
        jsii.set(self, "timeouts", value)


@jsii.data_type(
    jsii_type="@cdktf/provider-azurerm.ApiManagementApiSchemaConfig",
    jsii_struct_bases=[cdktf.TerraformMetaArguments],
    name_mapping={
        "count": "count",
        "depends_on": "dependsOn",
        "lifecycle": "lifecycle",
        "provider": "provider",
        "api_management_name": "apiManagementName",
        "api_name": "apiName",
        "content_type": "contentType",
        "resource_group_name": "resourceGroupName",
        "schema_id": "schemaId",
        "value": "value",
        "timeouts": "timeouts",
    },
)
class ApiManagementApiSchemaConfig(cdktf.TerraformMetaArguments):
    def __init__(
        self,
        *,
        count: typing.Optional[jsii.Number] = None,
        depends_on: typing.Optional[typing.List[cdktf.TerraformResource]] = None,
        lifecycle: typing.Optional[cdktf.TerraformResourceLifecycle] = None,
        provider: typing.Optional[cdktf.TerraformProvider] = None,
        api_management_name: builtins.str,
        api_name: builtins.str,
        content_type: builtins.str,
        resource_group_name: builtins.str,
        schema_id: builtins.str,
        value: builtins.str,
        timeouts: typing.Optional["ApiManagementApiSchemaTimeouts"] = None,
    ) -> None:
        """
        :param count: 
        :param depends_on: 
        :param lifecycle: 
        :param provider: 
        :param api_management_name: 
        :param api_name: 
        :param content_type: 
        :param resource_group_name: 
        :param schema_id: 
        :param value: 
        :param timeouts: timeouts block.
        """
        if isinstance(lifecycle, dict):
            lifecycle = cdktf.TerraformResourceLifecycle(**lifecycle)
        if isinstance(timeouts, dict):
            timeouts = ApiManagementApiSchemaTimeouts(**timeouts)
        self._values: typing.Dict[str, typing.Any] = {
            "api_management_name": api_management_name,
            "api_name": api_name,
            "content_type": content_type,
            "resource_group_name": resource_group_name,
            "schema_id": schema_id,
            "value": value,
        }
        if count is not None:
            self._values["count"] = count
        if depends_on is not None:
            self._values["depends_on"] = depends_on
        if lifecycle is not None:
            self._values["lifecycle"] = lifecycle
        if provider is not None:
            self._values["provider"] = provider
        if timeouts is not None:
            self._values["timeouts"] = timeouts

    @builtins.property
    def count(self) -> typing.Optional[jsii.Number]:
        """
        :stability: experimental
        """
        result = self._values.get("count")
        return result

    @builtins.property
    def depends_on(self) -> typing.Optional[typing.List[cdktf.TerraformResource]]:
        """
        :stability: experimental
        """
        result = self._values.get("depends_on")
        return result

    @builtins.property
    def lifecycle(self) -> typing.Optional[cdktf.TerraformResourceLifecycle]:
        """
        :stability: experimental
        """
        result = self._values.get("lifecycle")
        return result

    @builtins.property
    def provider(self) -> typing.Optional[cdktf.TerraformProvider]:
        """
        :stability: experimental
        """
        result = self._values.get("provider")
        return result

    @builtins.property
    def api_management_name(self) -> builtins.str:
        result = self._values.get("api_management_name")
        assert result is not None, "Required property 'api_management_name' is missing"
        return result

    @builtins.property
    def api_name(self) -> builtins.str:
        result = self._values.get("api_name")
        assert result is not None, "Required property 'api_name' is missing"
        return result

    @builtins.property
    def content_type(self) -> builtins.str:
        result = self._values.get("content_type")
        assert result is not None, "Required property 'content_type' is missing"
        return result

    @builtins.property
    def resource_group_name(self) -> builtins.str:
        result = self._values.get("resource_group_name")
        assert result is not None, "Required property 'resource_group_name' is missing"
        return result

    @builtins.property
    def schema_id(self) -> builtins.str:
        result = self._values.get("schema_id")
        assert result is not None, "Required property 'schema_id' is missing"
        return result

    @builtins.property
    def value(self) -> builtins.str:
        result = self._values.get("value")
        assert result is not None, "Required property 'value' is missing"
        return result

    @builtins.property
    def timeouts(self) -> typing.Optional["ApiManagementApiSchemaTimeouts"]:
        """timeouts block."""
        result = self._values.get("timeouts")
        return result

    def __eq__(self, rhs: typing.Any) -> builtins.bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs: typing.Any) -> builtins.bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return "ApiManagementApiSchemaConfig(%s)" % ", ".join(
            k + "=" + repr(v) for k, v in self._values.items()
        )


@jsii.data_type(
    jsii_type="@cdktf/provider-azurerm.ApiManagementApiSchemaTimeouts",
    jsii_struct_bases=[],
    name_mapping={
        "create": "create",
        "delete": "delete",
        "read": "read",
        "update": "update",
    },
)
class ApiManagementApiSchemaTimeouts:
    def __init__(
        self,
        *,
        create: typing.Optional[builtins.str] = None,
        delete: typing.Optional[builtins.str] = None,
        read: typing.Optional[builtins.str] = None,
        update: typing.Optional[builtins.str] = None,
    ) -> None:
        """
        :param create: 
        :param delete: 
        :param read: 
        :param update: 
        """
        self._values: typing.Dict[str, typing.Any] = {}
        if create is not None:
            self._values["create"] = create
        if delete is not None:
            self._values["delete"] = delete
        if read is not None:
            self._values["read"] = read
        if update is not None:
            self._values["update"] = update

    @builtins.property
    def create(self) -> typing.Optional[builtins.str]:
        result = self._values.get("create")
        return result

    @builtins.property
    def delete(self) -> typing.Optional[builtins.str]:
        result = self._values.get("delete")
        return result

    @builtins.property
    def read(self) -> typing.Optional[builtins.str]:
        result = self._values.get("read")
        return result

    @builtins.property
    def update(self) -> typing.Optional[builtins.str]:
        result = self._values.get("update")
        return result

    def __eq__(self, rhs: typing.Any) -> builtins.bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs: typing.Any) -> builtins.bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return "ApiManagementApiSchemaTimeouts(%s)" % ", ".join(
            k + "=" + repr(v) for k, v in self._values.items()
        )


@jsii.data_type(
    jsii_type="@cdktf/provider-azurerm.ApiManagementApiSubscriptionKeyParameterNames",
    jsii_struct_bases=[],
    name_mapping={"header": "header", "query": "query"},
)
class ApiManagementApiSubscriptionKeyParameterNames:
    def __init__(self, *, header: builtins.str, query: builtins.str) -> None:
        """
        :param header: 
        :param query: 
        """
        self._values: typing.Dict[str, typing.Any] = {
            "header": header,
            "query": query,
        }

    @builtins.property
    def header(self) -> builtins.str:
        result = self._values.get("header")
        assert result is not None, "Required property 'header' is missing"
        return result

    @builtins.property
    def query(self) -> builtins.str:
        result = self._values.get("query")
        assert result is not None, "Required property 'query' is missing"
        return result

    def __eq__(self, rhs: typing.Any) -> builtins.bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs: typing.Any) -> builtins.bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return "ApiManagementApiSubscriptionKeyParameterNames(%s)" % ", ".join(
            k + "=" + repr(v) for k, v in self._values.items()
        )


@jsii.data_type(
    jsii_type="@cdktf/provider-azurerm.ApiManagementApiTimeouts",
    jsii_struct_bases=[],
    name_mapping={
        "create": "create",
        "delete": "delete",
        "read": "read",
        "update": "update",
    },
)
class ApiManagementApiTimeouts:
    def __init__(
        self,
        *,
        create: typing.Optional[builtins.str] = None,
        delete: typing.Optional[builtins.str] = None,
        read: typing.Optional[builtins.str] = None,
        update: typing.Optional[builtins.str] = None,
    ) -> None:
        """
        :param create: 
        :param delete: 
        :param read: 
        :param update: 
        """
        self._values: typing.Dict[str, typing.Any] = {}
        if create is not None:
            self._values["create"] = create
        if delete is not None:
            self._values["delete"] = delete
        if read is not None:
            self._values["read"] = read
        if update is not None:
            self._values["update"] = update

    @builtins.property
    def create(self) -> typing.Optional[builtins.str]:
        result = self._values.get("create")
        return result

    @builtins.property
    def delete(self) -> typing.Optional[builtins.str]:
        result = self._values.get("delete")
        return result

    @builtins.property
    def read(self) -> typing.Optional[builtins.str]:
        result = self._values.get("read")
        return result

    @builtins.property
    def update(self) -> typing.Optional[builtins.str]:
        result = self._values.get("update")
        return result

    def __eq__(self, rhs: typing.Any) -> builtins.bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs: typing.Any) -> builtins.bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return "ApiManagementApiTimeouts(%s)" % ", ".join(
            k + "=" + repr(v) for k, v in self._values.items()
        )


class ApiManagementApiVersionSet(
    cdktf.TerraformResource,
    metaclass=jsii.JSIIMeta,
    jsii_type="@cdktf/provider-azurerm.ApiManagementApiVersionSet",
):
    def __init__(
        self,
        scope: constructs.Construct,
        id: builtins.str,
        *,
        api_management_name: builtins.str,
        display_name: builtins.str,
        name: builtins.str,
        resource_group_name: builtins.str,
        versioning_scheme: builtins.str,
        description: typing.Optional[builtins.str] = None,
        timeouts: typing.Optional["ApiManagementApiVersionSetTimeouts"] = None,
        version_header_name: typing.Optional[builtins.str] = None,
        version_query_name: typing.Optional[builtins.str] = None,
        count: typing.Optional[jsii.Number] = None,
        depends_on: typing.Optional[typing.List[cdktf.TerraformResource]] = None,
        lifecycle: typing.Optional[cdktf.TerraformResourceLifecycle] = None,
        provider: typing.Optional[cdktf.TerraformProvider] = None,
    ) -> None:
        """
        :param scope: -
        :param id: -
        :param api_management_name: 
        :param display_name: 
        :param name: 
        :param resource_group_name: 
        :param versioning_scheme: 
        :param description: 
        :param timeouts: timeouts block.
        :param version_header_name: 
        :param version_query_name: 
        :param count: 
        :param depends_on: 
        :param lifecycle: 
        :param provider: 
        """
        config = ApiManagementApiVersionSetConfig(
            api_management_name=api_management_name,
            display_name=display_name,
            name=name,
            resource_group_name=resource_group_name,
            versioning_scheme=versioning_scheme,
            description=description,
            timeouts=timeouts,
            version_header_name=version_header_name,
            version_query_name=version_query_name,
            count=count,
            depends_on=depends_on,
            lifecycle=lifecycle,
            provider=provider,
        )

        jsii.create(ApiManagementApiVersionSet, self, [scope, id, config])

    @jsii.member(jsii_name="synthesizeAttributes")
    def _synthesize_attributes(self) -> typing.Mapping[builtins.str, typing.Any]:
        return jsii.invoke(self, "synthesizeAttributes", [])

    @builtins.property # type: ignore
    @jsii.member(jsii_name="apiManagementName")
    def api_management_name(self) -> builtins.str:
        return jsii.get(self, "apiManagementName")

    @api_management_name.setter # type: ignore
    def api_management_name(self, value: builtins.str) -> None:
        jsii.set(self, "apiManagementName", value)

    @builtins.property # type: ignore
    @jsii.member(jsii_name="displayName")
    def display_name(self) -> builtins.str:
        return jsii.get(self, "displayName")

    @display_name.setter # type: ignore
    def display_name(self, value: builtins.str) -> None:
        jsii.set(self, "displayName", value)

    @builtins.property # type: ignore
    @jsii.member(jsii_name="name")
    def name(self) -> builtins.str:
        return jsii.get(self, "name")

    @name.setter # type: ignore
    def name(self, value: builtins.str) -> None:
        jsii.set(self, "name", value)

    @builtins.property # type: ignore
    @jsii.member(jsii_name="resourceGroupName")
    def resource_group_name(self) -> builtins.str:
        return jsii.get(self, "resourceGroupName")

    @resource_group_name.setter # type: ignore
    def resource_group_name(self, value: builtins.str) -> None:
        jsii.set(self, "resourceGroupName", value)

    @builtins.property # type: ignore
    @jsii.member(jsii_name="versioningScheme")
    def versioning_scheme(self) -> builtins.str:
        return jsii.get(self, "versioningScheme")

    @versioning_scheme.setter # type: ignore
    def versioning_scheme(self, value: builtins.str) -> None:
        jsii.set(self, "versioningScheme", value)

    @builtins.property # type: ignore
    @jsii.member(jsii_name="description")
    def description(self) -> typing.Optional[builtins.str]:
        return jsii.get(self, "description")

    @description.setter # type: ignore
    def description(self, value: typing.Optional[builtins.str]) -> None:
        jsii.set(self, "description", value)

    @builtins.property # type: ignore
    @jsii.member(jsii_name="id")
    def id(self) -> typing.Optional[builtins.str]:
        return jsii.get(self, "id")

    @id.setter # type: ignore
    def id(self, value: typing.Optional[builtins.str]) -> None:
        jsii.set(self, "id", value)

    @builtins.property # type: ignore
    @jsii.member(jsii_name="timeouts")
    def timeouts(self) -> typing.Optional["ApiManagementApiVersionSetTimeouts"]:
        return jsii.get(self, "timeouts")

    @timeouts.setter # type: ignore
    def timeouts(
        self,
        value: typing.Optional["ApiManagementApiVersionSetTimeouts"],
    ) -> None:
        jsii.set(self, "timeouts", value)

    @builtins.property # type: ignore
    @jsii.member(jsii_name="versionHeaderName")
    def version_header_name(self) -> typing.Optional[builtins.str]:
        return jsii.get(self, "versionHeaderName")

    @version_header_name.setter # type: ignore
    def version_header_name(self, value: typing.Optional[builtins.str]) -> None:
        jsii.set(self, "versionHeaderName", value)

    @builtins.property # type: ignore
    @jsii.member(jsii_name="versionQueryName")
    def version_query_name(self) -> typing.Optional[builtins.str]:
        return jsii.get(self, "versionQueryName")

    @version_query_name.setter # type: ignore
    def version_query_name(self, value: typing.Optional[builtins.str]) -> None:
        jsii.set(self, "versionQueryName", value)


@jsii.data_type(
    jsii_type="@cdktf/provider-azurerm.ApiManagementApiVersionSetConfig",
    jsii_struct_bases=[cdktf.TerraformMetaArguments],
    name_mapping={
        "count": "count",
        "depends_on": "dependsOn",
        "lifecycle": "lifecycle",
        "provider": "provider",
        "api_management_name": "apiManagementName",
        "display_name": "displayName",
        "name": "name",
        "resource_group_name": "resourceGroupName",
        "versioning_scheme": "versioningScheme",
        "description": "description",
        "timeouts": "timeouts",
        "version_header_name": "versionHeaderName",
        "version_query_name": "versionQueryName",
    },
)
class ApiManagementApiVersionSetConfig(cdktf.TerraformMetaArguments):
    def __init__(
        self,
        *,
        count: typing.Optional[jsii.Number] = None,
        depends_on: typing.Optional[typing.List[cdktf.TerraformResource]] = None,
        lifecycle: typing.Optional[cdktf.TerraformResourceLifecycle] = None,
        provider: typing.Optional[cdktf.TerraformProvider] = None,
        api_management_name: builtins.str,
        display_name: builtins.str,
        name: builtins.str,
        resource_group_name: builtins.str,
        versioning_scheme: builtins.str,
        description: typing.Optional[builtins.str] = None,
        timeouts: typing.Optional["ApiManagementApiVersionSetTimeouts"] = None,
        version_header_name: typing.Optional[builtins.str] = None,
        version_query_name: typing.Optional[builtins.str] = None,
    ) -> None:
        """
        :param count: 
        :param depends_on: 
        :param lifecycle: 
        :param provider: 
        :param api_management_name: 
        :param display_name: 
        :param name: 
        :param resource_group_name: 
        :param versioning_scheme: 
        :param description: 
        :param timeouts: timeouts block.
        :param version_header_name: 
        :param version_query_name: 
        """
        if isinstance(lifecycle, dict):
            lifecycle = cdktf.TerraformResourceLifecycle(**lifecycle)
        if isinstance(timeouts, dict):
            timeouts = ApiManagementApiVersionSetTimeouts(**timeouts)
        self._values: typing.Dict[str, typing.Any] = {
            "api_management_name": api_management_name,
            "display_name": display_name,
            "name": name,
            "resource_group_name": resource_group_name,
            "versioning_scheme": versioning_scheme,
        }
        if count is not None:
            self._values["count"] = count
        if depends_on is not None:
            self._values["depends_on"] = depends_on
        if lifecycle is not None:
            self._values["lifecycle"] = lifecycle
        if provider is not None:
            self._values["provider"] = provider
        if description is not None:
            self._values["description"] = description
        if timeouts is not None:
            self._values["timeouts"] = timeouts
        if version_header_name is not None:
            self._values["version_header_name"] = version_header_name
        if version_query_name is not None:
            self._values["version_query_name"] = version_query_name

    @builtins.property
    def count(self) -> typing.Optional[jsii.Number]:
        """
        :stability: experimental
        """
        result = self._values.get("count")
        return result

    @builtins.property
    def depends_on(self) -> typing.Optional[typing.List[cdktf.TerraformResource]]:
        """
        :stability: experimental
        """
        result = self._values.get("depends_on")
        return result

    @builtins.property
    def lifecycle(self) -> typing.Optional[cdktf.TerraformResourceLifecycle]:
        """
        :stability: experimental
        """
        result = self._values.get("lifecycle")
        return result

    @builtins.property
    def provider(self) -> typing.Optional[cdktf.TerraformProvider]:
        """
        :stability: experimental
        """
        result = self._values.get("provider")
        return result

    @builtins.property
    def api_management_name(self) -> builtins.str:
        result = self._values.get("api_management_name")
        assert result is not None, "Required property 'api_management_name' is missing"
        return result

    @builtins.property
    def display_name(self) -> builtins.str:
        result = self._values.get("display_name")
        assert result is not None, "Required property 'display_name' is missing"
        return result

    @builtins.property
    def name(self) -> builtins.str:
        result = self._values.get("name")
        assert result is not None, "Required property 'name' is missing"
        return result

    @builtins.property
    def resource_group_name(self) -> builtins.str:
        result = self._values.get("resource_group_name")
        assert result is not None, "Required property 'resource_group_name' is missing"
        return result

    @builtins.property
    def versioning_scheme(self) -> builtins.str:
        result = self._values.get("versioning_scheme")
        assert result is not None, "Required property 'versioning_scheme' is missing"
        return result

    @builtins.property
    def description(self) -> typing.Optional[builtins.str]:
        result = self._values.get("description")
        return result

    @builtins.property
    def timeouts(self) -> typing.Optional["ApiManagementApiVersionSetTimeouts"]:
        """timeouts block."""
        result = self._values.get("timeouts")
        return result

    @builtins.property
    def version_header_name(self) -> typing.Optional[builtins.str]:
        result = self._values.get("version_header_name")
        return result

    @builtins.property
    def version_query_name(self) -> typing.Optional[builtins.str]:
        result = self._values.get("version_query_name")
        return result

    def __eq__(self, rhs: typing.Any) -> builtins.bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs: typing.Any) -> builtins.bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return "ApiManagementApiVersionSetConfig(%s)" % ", ".join(
            k + "=" + repr(v) for k, v in self._values.items()
        )


@jsii.data_type(
    jsii_type="@cdktf/provider-azurerm.ApiManagementApiVersionSetTimeouts",
    jsii_struct_bases=[],
    name_mapping={
        "create": "create",
        "delete": "delete",
        "read": "read",
        "update": "update",
    },
)
class ApiManagementApiVersionSetTimeouts:
    def __init__(
        self,
        *,
        create: typing.Optional[builtins.str] = None,
        delete: typing.Optional[builtins.str] = None,
        read: typing.Optional[builtins.str] = None,
        update: typing.Optional[builtins.str] = None,
    ) -> None:
        """
        :param create: 
        :param delete: 
        :param read: 
        :param update: 
        """
        self._values: typing.Dict[str, typing.Any] = {}
        if create is not None:
            self._values["create"] = create
        if delete is not None:
            self._values["delete"] = delete
        if read is not None:
            self._values["read"] = read
        if update is not None:
            self._values["update"] = update

    @builtins.property
    def create(self) -> typing.Optional[builtins.str]:
        result = self._values.get("create")
        return result

    @builtins.property
    def delete(self) -> typing.Optional[builtins.str]:
        result = self._values.get("delete")
        return result

    @builtins.property
    def read(self) -> typing.Optional[builtins.str]:
        result = self._values.get("read")
        return result

    @builtins.property
    def update(self) -> typing.Optional[builtins.str]:
        result = self._values.get("update")
        return result

    def __eq__(self, rhs: typing.Any) -> builtins.bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs: typing.Any) -> builtins.bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return "ApiManagementApiVersionSetTimeouts(%s)" % ", ".join(
            k + "=" + repr(v) for k, v in self._values.items()
        )


class ApiManagementAuthorizationServer(
    cdktf.TerraformResource,
    metaclass=jsii.JSIIMeta,
    jsii_type="@cdktf/provider-azurerm.ApiManagementAuthorizationServer",
):
    def __init__(
        self,
        scope: constructs.Construct,
        id: builtins.str,
        *,
        api_management_name: builtins.str,
        authorization_endpoint: builtins.str,
        authorization_methods: typing.List[builtins.str],
        client_id: builtins.str,
        client_registration_endpoint: builtins.str,
        display_name: builtins.str,
        grant_types: typing.List[builtins.str],
        name: builtins.str,
        resource_group_name: builtins.str,
        bearer_token_sending_methods: typing.Optional[typing.List[builtins.str]] = None,
        client_authentication_method: typing.Optional[typing.List[builtins.str]] = None,
        client_secret: typing.Optional[builtins.str] = None,
        default_scope: typing.Optional[builtins.str] = None,
        description: typing.Optional[builtins.str] = None,
        resource_owner_password: typing.Optional[builtins.str] = None,
        resource_owner_username: typing.Optional[builtins.str] = None,
        support_state: typing.Optional[builtins.bool] = None,
        timeouts: typing.Optional["ApiManagementAuthorizationServerTimeouts"] = None,
        token_body_parameter: typing.Optional[typing.List["ApiManagementAuthorizationServerTokenBodyParameter"]] = None,
        token_endpoint: typing.Optional[builtins.str] = None,
        count: typing.Optional[jsii.Number] = None,
        depends_on: typing.Optional[typing.List[cdktf.TerraformResource]] = None,
        lifecycle: typing.Optional[cdktf.TerraformResourceLifecycle] = None,
        provider: typing.Optional[cdktf.TerraformProvider] = None,
    ) -> None:
        """
        :param scope: -
        :param id: -
        :param api_management_name: 
        :param authorization_endpoint: 
        :param authorization_methods: 
        :param client_id: 
        :param client_registration_endpoint: 
        :param display_name: 
        :param grant_types: 
        :param name: 
        :param resource_group_name: 
        :param bearer_token_sending_methods: 
        :param client_authentication_method: 
        :param client_secret: 
        :param default_scope: 
        :param description: 
        :param resource_owner_password: 
        :param resource_owner_username: 
        :param support_state: 
        :param timeouts: timeouts block.
        :param token_body_parameter: token_body_parameter block.
        :param token_endpoint: 
        :param count: 
        :param depends_on: 
        :param lifecycle: 
        :param provider: 
        """
        config = ApiManagementAuthorizationServerConfig(
            api_management_name=api_management_name,
            authorization_endpoint=authorization_endpoint,
            authorization_methods=authorization_methods,
            client_id=client_id,
            client_registration_endpoint=client_registration_endpoint,
            display_name=display_name,
            grant_types=grant_types,
            name=name,
            resource_group_name=resource_group_name,
            bearer_token_sending_methods=bearer_token_sending_methods,
            client_authentication_method=client_authentication_method,
            client_secret=client_secret,
            default_scope=default_scope,
            description=description,
            resource_owner_password=resource_owner_password,
            resource_owner_username=resource_owner_username,
            support_state=support_state,
            timeouts=timeouts,
            token_body_parameter=token_body_parameter,
            token_endpoint=token_endpoint,
            count=count,
            depends_on=depends_on,
            lifecycle=lifecycle,
            provider=provider,
        )

        jsii.create(ApiManagementAuthorizationServer, self, [scope, id, config])

    @jsii.member(jsii_name="synthesizeAttributes")
    def _synthesize_attributes(self) -> typing.Mapping[builtins.str, typing.Any]:
        return jsii.invoke(self, "synthesizeAttributes", [])

    @builtins.property # type: ignore
    @jsii.member(jsii_name="apiManagementName")
    def api_management_name(self) -> builtins.str:
        return jsii.get(self, "apiManagementName")

    @api_management_name.setter # type: ignore
    def api_management_name(self, value: builtins.str) -> None:
        jsii.set(self, "apiManagementName", value)

    @builtins.property # type: ignore
    @jsii.member(jsii_name="authorizationEndpoint")
    def authorization_endpoint(self) -> builtins.str:
        return jsii.get(self, "authorizationEndpoint")

    @authorization_endpoint.setter # type: ignore
    def authorization_endpoint(self, value: builtins.str) -> None:
        jsii.set(self, "authorizationEndpoint", value)

    @builtins.property # type: ignore
    @jsii.member(jsii_name="authorizationMethods")
    def authorization_methods(self) -> typing.List[builtins.str]:
        return jsii.get(self, "authorizationMethods")

    @authorization_methods.setter # type: ignore
    def authorization_methods(self, value: typing.List[builtins.str]) -> None:
        jsii.set(self, "authorizationMethods", value)

    @builtins.property # type: ignore
    @jsii.member(jsii_name="clientId")
    def client_id(self) -> builtins.str:
        return jsii.get(self, "clientId")

    @client_id.setter # type: ignore
    def client_id(self, value: builtins.str) -> None:
        jsii.set(self, "clientId", value)

    @builtins.property # type: ignore
    @jsii.member(jsii_name="clientRegistrationEndpoint")
    def client_registration_endpoint(self) -> builtins.str:
        return jsii.get(self, "clientRegistrationEndpoint")

    @client_registration_endpoint.setter # type: ignore
    def client_registration_endpoint(self, value: builtins.str) -> None:
        jsii.set(self, "clientRegistrationEndpoint", value)

    @builtins.property # type: ignore
    @jsii.member(jsii_name="displayName")
    def display_name(self) -> builtins.str:
        return jsii.get(self, "displayName")

    @display_name.setter # type: ignore
    def display_name(self, value: builtins.str) -> None:
        jsii.set(self, "displayName", value)

    @builtins.property # type: ignore
    @jsii.member(jsii_name="grantTypes")
    def grant_types(self) -> typing.List[builtins.str]:
        return jsii.get(self, "grantTypes")

    @grant_types.setter # type: ignore
    def grant_types(self, value: typing.List[builtins.str]) -> None:
        jsii.set(self, "grantTypes", value)

    @builtins.property # type: ignore
    @jsii.member(jsii_name="name")
    def name(self) -> builtins.str:
        return jsii.get(self, "name")

    @name.setter # type: ignore
    def name(self, value: builtins.str) -> None:
        jsii.set(self, "name", value)

    @builtins.property # type: ignore
    @jsii.member(jsii_name="resourceGroupName")
    def resource_group_name(self) -> builtins.str:
        return jsii.get(self, "resourceGroupName")

    @resource_group_name.setter # type: ignore
    def resource_group_name(self, value: builtins.str) -> None:
        jsii.set(self, "resourceGroupName", value)

    @builtins.property # type: ignore
    @jsii.member(jsii_name="bearerTokenSendingMethods")
    def bearer_token_sending_methods(
        self,
    ) -> typing.Optional[typing.List[builtins.str]]:
        return jsii.get(self, "bearerTokenSendingMethods")

    @bearer_token_sending_methods.setter # type: ignore
    def bearer_token_sending_methods(
        self,
        value: typing.Optional[typing.List[builtins.str]],
    ) -> None:
        jsii.set(self, "bearerTokenSendingMethods", value)

    @builtins.property # type: ignore
    @jsii.member(jsii_name="clientAuthenticationMethod")
    def client_authentication_method(
        self,
    ) -> typing.Optional[typing.List[builtins.str]]:
        return jsii.get(self, "clientAuthenticationMethod")

    @client_authentication_method.setter # type: ignore
    def client_authentication_method(
        self,
        value: typing.Optional[typing.List[builtins.str]],
    ) -> None:
        jsii.set(self, "clientAuthenticationMethod", value)

    @builtins.property # type: ignore
    @jsii.member(jsii_name="clientSecret")
    def client_secret(self) -> typing.Optional[builtins.str]:
        return jsii.get(self, "clientSecret")

    @client_secret.setter # type: ignore
    def client_secret(self, value: typing.Optional[builtins.str]) -> None:
        jsii.set(self, "clientSecret", value)

    @builtins.property # type: ignore
    @jsii.member(jsii_name="defaultScope")
    def default_scope(self) -> typing.Optional[builtins.str]:
        return jsii.get(self, "defaultScope")

    @default_scope.setter # type: ignore
    def default_scope(self, value: typing.Optional[builtins.str]) -> None:
        jsii.set(self, "defaultScope", value)

    @builtins.property # type: ignore
    @jsii.member(jsii_name="description")
    def description(self) -> typing.Optional[builtins.str]:
        return jsii.get(self, "description")

    @description.setter # type: ignore
    def description(self, value: typing.Optional[builtins.str]) -> None:
        jsii.set(self, "description", value)

    @builtins.property # type: ignore
    @jsii.member(jsii_name="id")
    def id(self) -> typing.Optional[builtins.str]:
        return jsii.get(self, "id")

    @id.setter # type: ignore
    def id(self, value: typing.Optional[builtins.str]) -> None:
        jsii.set(self, "id", value)

    @builtins.property # type: ignore
    @jsii.member(jsii_name="resourceOwnerPassword")
    def resource_owner_password(self) -> typing.Optional[builtins.str]:
        return jsii.get(self, "resourceOwnerPassword")

    @resource_owner_password.setter # type: ignore
    def resource_owner_password(self, value: typing.Optional[builtins.str]) -> None:
        jsii.set(self, "resourceOwnerPassword", value)

    @builtins.property # type: ignore
    @jsii.member(jsii_name="resourceOwnerUsername")
    def resource_owner_username(self) -> typing.Optional[builtins.str]:
        return jsii.get(self, "resourceOwnerUsername")

    @resource_owner_username.setter # type: ignore
    def resource_owner_username(self, value: typing.Optional[builtins.str]) -> None:
        jsii.set(self, "resourceOwnerUsername", value)

    @builtins.property # type: ignore
    @jsii.member(jsii_name="supportState")
    def support_state(self) -> typing.Optional[builtins.bool]:
        return jsii.get(self, "supportState")

    @support_state.setter # type: ignore
    def support_state(self, value: typing.Optional[builtins.bool]) -> None:
        jsii.set(self, "supportState", value)

    @builtins.property # type: ignore
    @jsii.member(jsii_name="timeouts")
    def timeouts(self) -> typing.Optional["ApiManagementAuthorizationServerTimeouts"]:
        return jsii.get(self, "timeouts")

    @timeouts.setter # type: ignore
    def timeouts(
        self,
        value: typing.Optional["ApiManagementAuthorizationServerTimeouts"],
    ) -> None:
        jsii.set(self, "timeouts", value)

    @builtins.property # type: ignore
    @jsii.member(jsii_name="tokenBodyParameter")
    def token_body_parameter(
        self,
    ) -> typing.Optional[typing.List["ApiManagementAuthorizationServerTokenBodyParameter"]]:
        return jsii.get(self, "tokenBodyParameter")

    @token_body_parameter.setter # type: ignore
    def token_body_parameter(
        self,
        value: typing.Optional[typing.List["ApiManagementAuthorizationServerTokenBodyParameter"]],
    ) -> None:
        jsii.set(self, "tokenBodyParameter", value)

    @builtins.property # type: ignore
    @jsii.member(jsii_name="tokenEndpoint")
    def token_endpoint(self) -> typing.Optional[builtins.str]:
        return jsii.get(self, "tokenEndpoint")

    @token_endpoint.setter # type: ignore
    def token_endpoint(self, value: typing.Optional[builtins.str]) -> None:
        jsii.set(self, "tokenEndpoint", value)


@jsii.data_type(
    jsii_type="@cdktf/provider-azurerm.ApiManagementAuthorizationServerConfig",
    jsii_struct_bases=[cdktf.TerraformMetaArguments],
    name_mapping={
        "count": "count",
        "depends_on": "dependsOn",
        "lifecycle": "lifecycle",
        "provider": "provider",
        "api_management_name": "apiManagementName",
        "authorization_endpoint": "authorizationEndpoint",
        "authorization_methods": "authorizationMethods",
        "client_id": "clientId",
        "client_registration_endpoint": "clientRegistrationEndpoint",
        "display_name": "displayName",
        "grant_types": "grantTypes",
        "name": "name",
        "resource_group_name": "resourceGroupName",
        "bearer_token_sending_methods": "bearerTokenSendingMethods",
        "client_authentication_method": "clientAuthenticationMethod",
        "client_secret": "clientSecret",
        "default_scope": "defaultScope",
        "description": "description",
        "resource_owner_password": "resourceOwnerPassword",
        "resource_owner_username": "resourceOwnerUsername",
        "support_state": "supportState",
        "timeouts": "timeouts",
        "token_body_parameter": "tokenBodyParameter",
        "token_endpoint": "tokenEndpoint",
    },
)
class ApiManagementAuthorizationServerConfig(cdktf.TerraformMetaArguments):
    def __init__(
        self,
        *,
        count: typing.Optional[jsii.Number] = None,
        depends_on: typing.Optional[typing.List[cdktf.TerraformResource]] = None,
        lifecycle: typing.Optional[cdktf.TerraformResourceLifecycle] = None,
        provider: typing.Optional[cdktf.TerraformProvider] = None,
        api_management_name: builtins.str,
        authorization_endpoint: builtins.str,
        authorization_methods: typing.List[builtins.str],
        client_id: builtins.str,
        client_registration_endpoint: builtins.str,
        display_name: builtins.str,
        grant_types: typing.List[builtins.str],
        name: builtins.str,
        resource_group_name: builtins.str,
        bearer_token_sending_methods: typing.Optional[typing.List[builtins.str]] = None,
        client_authentication_method: typing.Optional[typing.List[builtins.str]] = None,
        client_secret: typing.Optional[builtins.str] = None,
        default_scope: typing.Optional[builtins.str] = None,
        description: typing.Optional[builtins.str] = None,
        resource_owner_password: typing.Optional[builtins.str] = None,
        resource_owner_username: typing.Optional[builtins.str] = None,
        support_state: typing.Optional[builtins.bool] = None,
        timeouts: typing.Optional["ApiManagementAuthorizationServerTimeouts"] = None,
        token_body_parameter: typing.Optional[typing.List["ApiManagementAuthorizationServerTokenBodyParameter"]] = None,
        token_endpoint: typing.Optional[builtins.str] = None,
    ) -> None:
        """
        :param count: 
        :param depends_on: 
        :param lifecycle: 
        :param provider: 
        :param api_management_name: 
        :param authorization_endpoint: 
        :param authorization_methods: 
        :param client_id: 
        :param client_registration_endpoint: 
        :param display_name: 
        :param grant_types: 
        :param name: 
        :param resource_group_name: 
        :param bearer_token_sending_methods: 
        :param client_authentication_method: 
        :param client_secret: 
        :param default_scope: 
        :param description: 
        :param resource_owner_password: 
        :param resource_owner_username: 
        :param support_state: 
        :param timeouts: timeouts block.
        :param token_body_parameter: token_body_parameter block.
        :param token_endpoint: 
        """
        if isinstance(lifecycle, dict):
            lifecycle = cdktf.TerraformResourceLifecycle(**lifecycle)
        if isinstance(timeouts, dict):
            timeouts = ApiManagementAuthorizationServerTimeouts(**timeouts)
        self._values: typing.Dict[str, typing.Any] = {
            "api_management_name": api_management_name,
            "authorization_endpoint": authorization_endpoint,
            "authorization_methods": authorization_methods,
            "client_id": client_id,
            "client_registration_endpoint": client_registration_endpoint,
            "display_name": display_name,
            "grant_types": grant_types,
            "name": name,
            "resource_group_name": resource_group_name,
        }
        if count is not None:
            self._values["count"] = count
        if depends_on is not None:
            self._values["depends_on"] = depends_on
        if lifecycle is not None:
            self._values["lifecycle"] = lifecycle
        if provider is not None:
            self._values["provider"] = provider
        if bearer_token_sending_methods is not None:
            self._values["bearer_token_sending_methods"] = bearer_token_sending_methods
        if client_authentication_method is not None:
            self._values["client_authentication_method"] = client_authentication_method
        if client_secret is not None:
            self._values["client_secret"] = client_secret
        if default_scope is not None:
            self._values["default_scope"] = default_scope
        if description is not None:
            self._values["description"] = description
        if resource_owner_password is not None:
            self._values["resource_owner_password"] = resource_owner_password
        if resource_owner_username is not None:
            self._values["resource_owner_username"] = resource_owner_username
        if support_state is not None:
            self._values["support_state"] = support_state
        if timeouts is not None:
            self._values["timeouts"] = timeouts
        if token_body_parameter is not None:
            self._values["token_body_parameter"] = token_body_parameter
        if token_endpoint is not None:
            self._values["token_endpoint"] = token_endpoint

    @builtins.property
    def count(self) -> typing.Optional[jsii.Number]:
        """
        :stability: experimental
        """
        result = self._values.get("count")
        return result

    @builtins.property
    def depends_on(self) -> typing.Optional[typing.List[cdktf.TerraformResource]]:
        """
        :stability: experimental
        """
        result = self._values.get("depends_on")
        return result

    @builtins.property
    def lifecycle(self) -> typing.Optional[cdktf.TerraformResourceLifecycle]:
        """
        :stability: experimental
        """
        result = self._values.get("lifecycle")
        return result

    @builtins.property
    def provider(self) -> typing.Optional[cdktf.TerraformProvider]:
        """
        :stability: experimental
        """
        result = self._values.get("provider")
        return result

    @builtins.property
    def api_management_name(self) -> builtins.str:
        result = self._values.get("api_management_name")
        assert result is not None, "Required property 'api_management_name' is missing"
        return result

    @builtins.property
    def authorization_endpoint(self) -> builtins.str:
        result = self._values.get("authorization_endpoint")
        assert result is not None, "Required property 'authorization_endpoint' is missing"
        return result

    @builtins.property
    def authorization_methods(self) -> typing.List[builtins.str]:
        result = self._values.get("authorization_methods")
        assert result is not None, "Required property 'authorization_methods' is missing"
        return result

    @builtins.property
    def client_id(self) -> builtins.str:
        result = self._values.get("client_id")
        assert result is not None, "Required property 'client_id' is missing"
        return result

    @builtins.property
    def client_registration_endpoint(self) -> builtins.str:
        result = self._values.get("client_registration_endpoint")
        assert result is not None, "Required property 'client_registration_endpoint' is missing"
        return result

    @builtins.property
    def display_name(self) -> builtins.str:
        result = self._values.get("display_name")
        assert result is not None, "Required property 'display_name' is missing"
        return result

    @builtins.property
    def grant_types(self) -> typing.List[builtins.str]:
        result = self._values.get("grant_types")
        assert result is not None, "Required property 'grant_types' is missing"
        return result

    @builtins.property
    def name(self) -> builtins.str:
        result = self._values.get("name")
        assert result is not None, "Required property 'name' is missing"
        return result

    @builtins.property
    def resource_group_name(self) -> builtins.str:
        result = self._values.get("resource_group_name")
        assert result is not None, "Required property 'resource_group_name' is missing"
        return result

    @builtins.property
    def bearer_token_sending_methods(
        self,
    ) -> typing.Optional[typing.List[builtins.str]]:
        result = self._values.get("bearer_token_sending_methods")
        return result

    @builtins.property
    def client_authentication_method(
        self,
    ) -> typing.Optional[typing.List[builtins.str]]:
        result = self._values.get("client_authentication_method")
        return result

    @builtins.property
    def client_secret(self) -> typing.Optional[builtins.str]:
        result = self._values.get("client_secret")
        return result

    @builtins.property
    def default_scope(self) -> typing.Optional[builtins.str]:
        result = self._values.get("default_scope")
        return result

    @builtins.property
    def description(self) -> typing.Optional[builtins.str]:
        result = self._values.get("description")
        return result

    @builtins.property
    def resource_owner_password(self) -> typing.Optional[builtins.str]:
        result = self._values.get("resource_owner_password")
        return result

    @builtins.property
    def resource_owner_username(self) -> typing.Optional[builtins.str]:
        result = self._values.get("resource_owner_username")
        return result

    @builtins.property
    def support_state(self) -> typing.Optional[builtins.bool]:
        result = self._values.get("support_state")
        return result

    @builtins.property
    def timeouts(self) -> typing.Optional["ApiManagementAuthorizationServerTimeouts"]:
        """timeouts block."""
        result = self._values.get("timeouts")
        return result

    @builtins.property
    def token_body_parameter(
        self,
    ) -> typing.Optional[typing.List["ApiManagementAuthorizationServerTokenBodyParameter"]]:
        """token_body_parameter block."""
        result = self._values.get("token_body_parameter")
        return result

    @builtins.property
    def token_endpoint(self) -> typing.Optional[builtins.str]:
        result = self._values.get("token_endpoint")
        return result

    def __eq__(self, rhs: typing.Any) -> builtins.bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs: typing.Any) -> builtins.bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return "ApiManagementAuthorizationServerConfig(%s)" % ", ".join(
            k + "=" + repr(v) for k, v in self._values.items()
        )


@jsii.data_type(
    jsii_type="@cdktf/provider-azurerm.ApiManagementAuthorizationServerTimeouts",
    jsii_struct_bases=[],
    name_mapping={
        "create": "create",
        "delete": "delete",
        "read": "read",
        "update": "update",
    },
)
class ApiManagementAuthorizationServerTimeouts:
    def __init__(
        self,
        *,
        create: typing.Optional[builtins.str] = None,
        delete: typing.Optional[builtins.str] = None,
        read: typing.Optional[builtins.str] = None,
        update: typing.Optional[builtins.str] = None,
    ) -> None:
        """
        :param create: 
        :param delete: 
        :param read: 
        :param update: 
        """
        self._values: typing.Dict[str, typing.Any] = {}
        if create is not None:
            self._values["create"] = create
        if delete is not None:
            self._values["delete"] = delete
        if read is not None:
            self._values["read"] = read
        if update is not None:
            self._values["update"] = update

    @builtins.property
    def create(self) -> typing.Optional[builtins.str]:
        result = self._values.get("create")
        return result

    @builtins.property
    def delete(self) -> typing.Optional[builtins.str]:
        result = self._values.get("delete")
        return result

    @builtins.property
    def read(self) -> typing.Optional[builtins.str]:
        result = self._values.get("read")
        return result

    @builtins.property
    def update(self) -> typing.Optional[builtins.str]:
        result = self._values.get("update")
        return result

    def __eq__(self, rhs: typing.Any) -> builtins.bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs: typing.Any) -> builtins.bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return "ApiManagementAuthorizationServerTimeouts(%s)" % ", ".join(
            k + "=" + repr(v) for k, v in self._values.items()
        )


@jsii.data_type(
    jsii_type="@cdktf/provider-azurerm.ApiManagementAuthorizationServerTokenBodyParameter",
    jsii_struct_bases=[],
    name_mapping={"name": "name", "value": "value"},
)
class ApiManagementAuthorizationServerTokenBodyParameter:
    def __init__(self, *, name: builtins.str, value: builtins.str) -> None:
        """
        :param name: 
        :param value: 
        """
        self._values: typing.Dict[str, typing.Any] = {
            "name": name,
            "value": value,
        }

    @builtins.property
    def name(self) -> builtins.str:
        result = self._values.get("name")
        assert result is not None, "Required property 'name' is missing"
        return result

    @builtins.property
    def value(self) -> builtins.str:
        result = self._values.get("value")
        assert result is not None, "Required property 'value' is missing"
        return result

    def __eq__(self, rhs: typing.Any) -> builtins.bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs: typing.Any) -> builtins.bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return "ApiManagementAuthorizationServerTokenBodyParameter(%s)" % ", ".join(
            k + "=" + repr(v) for k, v in self._values.items()
        )


class ApiManagementBackend(
    cdktf.TerraformResource,
    metaclass=jsii.JSIIMeta,
    jsii_type="@cdktf/provider-azurerm.ApiManagementBackend",
):
    def __init__(
        self,
        scope: constructs.Construct,
        id: builtins.str,
        *,
        api_management_name: builtins.str,
        name: builtins.str,
        protocol: builtins.str,
        resource_group_name: builtins.str,
        url: builtins.str,
        credentials: typing.Optional[typing.List["ApiManagementBackendCredentials"]] = None,
        description: typing.Optional[builtins.str] = None,
        proxy: typing.Optional[typing.List["ApiManagementBackendProxy"]] = None,
        resource_id: typing.Optional[builtins.str] = None,
        service_fabric_cluster: typing.Optional[typing.List["ApiManagementBackendServiceFabricCluster"]] = None,
        timeouts: typing.Optional["ApiManagementBackendTimeouts"] = None,
        title: typing.Optional[builtins.str] = None,
        tls: typing.Optional[typing.List["ApiManagementBackendTls"]] = None,
        count: typing.Optional[jsii.Number] = None,
        depends_on: typing.Optional[typing.List[cdktf.TerraformResource]] = None,
        lifecycle: typing.Optional[cdktf.TerraformResourceLifecycle] = None,
        provider: typing.Optional[cdktf.TerraformProvider] = None,
    ) -> None:
        """
        :param scope: -
        :param id: -
        :param api_management_name: 
        :param name: 
        :param protocol: 
        :param resource_group_name: 
        :param url: 
        :param credentials: credentials block.
        :param description: 
        :param proxy: proxy block.
        :param resource_id: 
        :param service_fabric_cluster: service_fabric_cluster block.
        :param timeouts: timeouts block.
        :param title: 
        :param tls: tls block.
        :param count: 
        :param depends_on: 
        :param lifecycle: 
        :param provider: 
        """
        config = ApiManagementBackendConfig(
            api_management_name=api_management_name,
            name=name,
            protocol=protocol,
            resource_group_name=resource_group_name,
            url=url,
            credentials=credentials,
            description=description,
            proxy=proxy,
            resource_id=resource_id,
            service_fabric_cluster=service_fabric_cluster,
            timeouts=timeouts,
            title=title,
            tls=tls,
            count=count,
            depends_on=depends_on,
            lifecycle=lifecycle,
            provider=provider,
        )

        jsii.create(ApiManagementBackend, self, [scope, id, config])

    @jsii.member(jsii_name="synthesizeAttributes")
    def _synthesize_attributes(self) -> typing.Mapping[builtins.str, typing.Any]:
        return jsii.invoke(self, "synthesizeAttributes", [])

    @builtins.property # type: ignore
    @jsii.member(jsii_name="apiManagementName")
    def api_management_name(self) -> builtins.str:
        return jsii.get(self, "apiManagementName")

    @api_management_name.setter # type: ignore
    def api_management_name(self, value: builtins.str) -> None:
        jsii.set(self, "apiManagementName", value)

    @builtins.property # type: ignore
    @jsii.member(jsii_name="name")
    def name(self) -> builtins.str:
        return jsii.get(self, "name")

    @name.setter # type: ignore
    def name(self, value: builtins.str) -> None:
        jsii.set(self, "name", value)

    @builtins.property # type: ignore
    @jsii.member(jsii_name="protocol")
    def protocol(self) -> builtins.str:
        return jsii.get(self, "protocol")

    @protocol.setter # type: ignore
    def protocol(self, value: builtins.str) -> None:
        jsii.set(self, "protocol", value)

    @builtins.property # type: ignore
    @jsii.member(jsii_name="resourceGroupName")
    def resource_group_name(self) -> builtins.str:
        return jsii.get(self, "resourceGroupName")

    @resource_group_name.setter # type: ignore
    def resource_group_name(self, value: builtins.str) -> None:
        jsii.set(self, "resourceGroupName", value)

    @builtins.property # type: ignore
    @jsii.member(jsii_name="url")
    def url(self) -> builtins.str:
        return jsii.get(self, "url")

    @url.setter # type: ignore
    def url(self, value: builtins.str) -> None:
        jsii.set(self, "url", value)

    @builtins.property # type: ignore
    @jsii.member(jsii_name="credentials")
    def credentials(
        self,
    ) -> typing.Optional[typing.List["ApiManagementBackendCredentials"]]:
        return jsii.get(self, "credentials")

    @credentials.setter # type: ignore
    def credentials(
        self,
        value: typing.Optional[typing.List["ApiManagementBackendCredentials"]],
    ) -> None:
        jsii.set(self, "credentials", value)

    @builtins.property # type: ignore
    @jsii.member(jsii_name="description")
    def description(self) -> typing.Optional[builtins.str]:
        return jsii.get(self, "description")

    @description.setter # type: ignore
    def description(self, value: typing.Optional[builtins.str]) -> None:
        jsii.set(self, "description", value)

    @builtins.property # type: ignore
    @jsii.member(jsii_name="id")
    def id(self) -> typing.Optional[builtins.str]:
        return jsii.get(self, "id")

    @id.setter # type: ignore
    def id(self, value: typing.Optional[builtins.str]) -> None:
        jsii.set(self, "id", value)

    @builtins.property # type: ignore
    @jsii.member(jsii_name="proxy")
    def proxy(self) -> typing.Optional[typing.List["ApiManagementBackendProxy"]]:
        return jsii.get(self, "proxy")

    @proxy.setter # type: ignore
    def proxy(
        self,
        value: typing.Optional[typing.List["ApiManagementBackendProxy"]],
    ) -> None:
        jsii.set(self, "proxy", value)

    @builtins.property # type: ignore
    @jsii.member(jsii_name="resourceId")
    def resource_id(self) -> typing.Optional[builtins.str]:
        return jsii.get(self, "resourceId")

    @resource_id.setter # type: ignore
    def resource_id(self, value: typing.Optional[builtins.str]) -> None:
        jsii.set(self, "resourceId", value)

    @builtins.property # type: ignore
    @jsii.member(jsii_name="serviceFabricCluster")
    def service_fabric_cluster(
        self,
    ) -> typing.Optional[typing.List["ApiManagementBackendServiceFabricCluster"]]:
        return jsii.get(self, "serviceFabricCluster")

    @service_fabric_cluster.setter # type: ignore
    def service_fabric_cluster(
        self,
        value: typing.Optional[typing.List["ApiManagementBackendServiceFabricCluster"]],
    ) -> None:
        jsii.set(self, "serviceFabricCluster", value)

    @builtins.property # type: ignore
    @jsii.member(jsii_name="timeouts")
    def timeouts(self) -> typing.Optional["ApiManagementBackendTimeouts"]:
        return jsii.get(self, "timeouts")

    @timeouts.setter # type: ignore
    def timeouts(self, value: typing.Optional["ApiManagementBackendTimeouts"]) -> None:
        jsii.set(self, "timeouts", value)

    @builtins.property # type: ignore
    @jsii.member(jsii_name="title")
    def title(self) -> typing.Optional[builtins.str]:
        return jsii.get(self, "title")

    @title.setter # type: ignore
    def title(self, value: typing.Optional[builtins.str]) -> None:
        jsii.set(self, "title", value)

    @builtins.property # type: ignore
    @jsii.member(jsii_name="tls")
    def tls(self) -> typing.Optional[typing.List["ApiManagementBackendTls"]]:
        return jsii.get(self, "tls")

    @tls.setter # type: ignore
    def tls(
        self,
        value: typing.Optional[typing.List["ApiManagementBackendTls"]],
    ) -> None:
        jsii.set(self, "tls", value)


@jsii.data_type(
    jsii_type="@cdktf/provider-azurerm.ApiManagementBackendConfig",
    jsii_struct_bases=[cdktf.TerraformMetaArguments],
    name_mapping={
        "count": "count",
        "depends_on": "dependsOn",
        "lifecycle": "lifecycle",
        "provider": "provider",
        "api_management_name": "apiManagementName",
        "name": "name",
        "protocol": "protocol",
        "resource_group_name": "resourceGroupName",
        "url": "url",
        "credentials": "credentials",
        "description": "description",
        "proxy": "proxy",
        "resource_id": "resourceId",
        "service_fabric_cluster": "serviceFabricCluster",
        "timeouts": "timeouts",
        "title": "title",
        "tls": "tls",
    },
)
class ApiManagementBackendConfig(cdktf.TerraformMetaArguments):
    def __init__(
        self,
        *,
        count: typing.Optional[jsii.Number] = None,
        depends_on: typing.Optional[typing.List[cdktf.TerraformResource]] = None,
        lifecycle: typing.Optional[cdktf.TerraformResourceLifecycle] = None,
        provider: typing.Optional[cdktf.TerraformProvider] = None,
        api_management_name: builtins.str,
        name: builtins.str,
        protocol: builtins.str,
        resource_group_name: builtins.str,
        url: builtins.str,
        credentials: typing.Optional[typing.List["ApiManagementBackendCredentials"]] = None,
        description: typing.Optional[builtins.str] = None,
        proxy: typing.Optional[typing.List["ApiManagementBackendProxy"]] = None,
        resource_id: typing.Optional[builtins.str] = None,
        service_fabric_cluster: typing.Optional[typing.List["ApiManagementBackendServiceFabricCluster"]] = None,
        timeouts: typing.Optional["ApiManagementBackendTimeouts"] = None,
        title: typing.Optional[builtins.str] = None,
        tls: typing.Optional[typing.List["ApiManagementBackendTls"]] = None,
    ) -> None:
        """
        :param count: 
        :param depends_on: 
        :param lifecycle: 
        :param provider: 
        :param api_management_name: 
        :param name: 
        :param protocol: 
        :param resource_group_name: 
        :param url: 
        :param credentials: credentials block.
        :param description: 
        :param proxy: proxy block.
        :param resource_id: 
        :param service_fabric_cluster: service_fabric_cluster block.
        :param timeouts: timeouts block.
        :param title: 
        :param tls: tls block.
        """
        if isinstance(lifecycle, dict):
            lifecycle = cdktf.TerraformResourceLifecycle(**lifecycle)
        if isinstance(timeouts, dict):
            timeouts = ApiManagementBackendTimeouts(**timeouts)
        self._values: typing.Dict[str, typing.Any] = {
            "api_management_name": api_management_name,
            "name": name,
            "protocol": protocol,
            "resource_group_name": resource_group_name,
            "url": url,
        }
        if count is not None:
            self._values["count"] = count
        if depends_on is not None:
            self._values["depends_on"] = depends_on
        if lifecycle is not None:
            self._values["lifecycle"] = lifecycle
        if provider is not None:
            self._values["provider"] = provider
        if credentials is not None:
            self._values["credentials"] = credentials
        if description is not None:
            self._values["description"] = description
        if proxy is not None:
            self._values["proxy"] = proxy
        if resource_id is not None:
            self._values["resource_id"] = resource_id
        if service_fabric_cluster is not None:
            self._values["service_fabric_cluster"] = service_fabric_cluster
        if timeouts is not None:
            self._values["timeouts"] = timeouts
        if title is not None:
            self._values["title"] = title
        if tls is not None:
            self._values["tls"] = tls

    @builtins.property
    def count(self) -> typing.Optional[jsii.Number]:
        """
        :stability: experimental
        """
        result = self._values.get("count")
        return result

    @builtins.property
    def depends_on(self) -> typing.Optional[typing.List[cdktf.TerraformResource]]:
        """
        :stability: experimental
        """
        result = self._values.get("depends_on")
        return result

    @builtins.property
    def lifecycle(self) -> typing.Optional[cdktf.TerraformResourceLifecycle]:
        """
        :stability: experimental
        """
        result = self._values.get("lifecycle")
        return result

    @builtins.property
    def provider(self) -> typing.Optional[cdktf.TerraformProvider]:
        """
        :stability: experimental
        """
        result = self._values.get("provider")
        return result

    @builtins.property
    def api_management_name(self) -> builtins.str:
        result = self._values.get("api_management_name")
        assert result is not None, "Required property 'api_management_name' is missing"
        return result

    @builtins.property
    def name(self) -> builtins.str:
        result = self._values.get("name")
        assert result is not None, "Required property 'name' is missing"
        return result

    @builtins.property
    def protocol(self) -> builtins.str:
        result = self._values.get("protocol")
        assert result is not None, "Required property 'protocol' is missing"
        return result

    @builtins.property
    def resource_group_name(self) -> builtins.str:
        result = self._values.get("resource_group_name")
        assert result is not None, "Required property 'resource_group_name' is missing"
        return result

    @builtins.property
    def url(self) -> builtins.str:
        result = self._values.get("url")
        assert result is not None, "Required property 'url' is missing"
        return result

    @builtins.property
    def credentials(
        self,
    ) -> typing.Optional[typing.List["ApiManagementBackendCredentials"]]:
        """credentials block."""
        result = self._values.get("credentials")
        return result

    @builtins.property
    def description(self) -> typing.Optional[builtins.str]:
        result = self._values.get("description")
        return result

    @builtins.property
    def proxy(self) -> typing.Optional[typing.List["ApiManagementBackendProxy"]]:
        """proxy block."""
        result = self._values.get("proxy")
        return result

    @builtins.property
    def resource_id(self) -> typing.Optional[builtins.str]:
        result = self._values.get("resource_id")
        return result

    @builtins.property
    def service_fabric_cluster(
        self,
    ) -> typing.Optional[typing.List["ApiManagementBackendServiceFabricCluster"]]:
        """service_fabric_cluster block."""
        result = self._values.get("service_fabric_cluster")
        return result

    @builtins.property
    def timeouts(self) -> typing.Optional["ApiManagementBackendTimeouts"]:
        """timeouts block."""
        result = self._values.get("timeouts")
        return result

    @builtins.property
    def title(self) -> typing.Optional[builtins.str]:
        result = self._values.get("title")
        return result

    @builtins.property
    def tls(self) -> typing.Optional[typing.List["ApiManagementBackendTls"]]:
        """tls block."""
        result = self._values.get("tls")
        return result

    def __eq__(self, rhs: typing.Any) -> builtins.bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs: typing.Any) -> builtins.bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return "ApiManagementBackendConfig(%s)" % ", ".join(
            k + "=" + repr(v) for k, v in self._values.items()
        )


@jsii.data_type(
    jsii_type="@cdktf/provider-azurerm.ApiManagementBackendCredentials",
    jsii_struct_bases=[],
    name_mapping={
        "authorization": "authorization",
        "certificate": "certificate",
        "header": "header",
        "query": "query",
    },
)
class ApiManagementBackendCredentials:
    def __init__(
        self,
        *,
        authorization: typing.Optional[typing.List["ApiManagementBackendCredentialsAuthorization"]] = None,
        certificate: typing.Optional[typing.List[builtins.str]] = None,
        header: typing.Optional[typing.Mapping[builtins.str, builtins.str]] = None,
        query: typing.Optional[typing.Mapping[builtins.str, builtins.str]] = None,
    ) -> None:
        """
        :param authorization: authorization block.
        :param certificate: 
        :param header: 
        :param query: 
        """
        self._values: typing.Dict[str, typing.Any] = {}
        if authorization is not None:
            self._values["authorization"] = authorization
        if certificate is not None:
            self._values["certificate"] = certificate
        if header is not None:
            self._values["header"] = header
        if query is not None:
            self._values["query"] = query

    @builtins.property
    def authorization(
        self,
    ) -> typing.Optional[typing.List["ApiManagementBackendCredentialsAuthorization"]]:
        """authorization block."""
        result = self._values.get("authorization")
        return result

    @builtins.property
    def certificate(self) -> typing.Optional[typing.List[builtins.str]]:
        result = self._values.get("certificate")
        return result

    @builtins.property
    def header(self) -> typing.Optional[typing.Mapping[builtins.str, builtins.str]]:
        result = self._values.get("header")
        return result

    @builtins.property
    def query(self) -> typing.Optional[typing.Mapping[builtins.str, builtins.str]]:
        result = self._values.get("query")
        return result

    def __eq__(self, rhs: typing.Any) -> builtins.bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs: typing.Any) -> builtins.bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return "ApiManagementBackendCredentials(%s)" % ", ".join(
            k + "=" + repr(v) for k, v in self._values.items()
        )


@jsii.data_type(
    jsii_type="@cdktf/provider-azurerm.ApiManagementBackendCredentialsAuthorization",
    jsii_struct_bases=[],
    name_mapping={"parameter": "parameter", "scheme": "scheme"},
)
class ApiManagementBackendCredentialsAuthorization:
    def __init__(
        self,
        *,
        parameter: typing.Optional[builtins.str] = None,
        scheme: typing.Optional[builtins.str] = None,
    ) -> None:
        """
        :param parameter: 
        :param scheme: 
        """
        self._values: typing.Dict[str, typing.Any] = {}
        if parameter is not None:
            self._values["parameter"] = parameter
        if scheme is not None:
            self._values["scheme"] = scheme

    @builtins.property
    def parameter(self) -> typing.Optional[builtins.str]:
        result = self._values.get("parameter")
        return result

    @builtins.property
    def scheme(self) -> typing.Optional[builtins.str]:
        result = self._values.get("scheme")
        return result

    def __eq__(self, rhs: typing.Any) -> builtins.bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs: typing.Any) -> builtins.bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return "ApiManagementBackendCredentialsAuthorization(%s)" % ", ".join(
            k + "=" + repr(v) for k, v in self._values.items()
        )


@jsii.data_type(
    jsii_type="@cdktf/provider-azurerm.ApiManagementBackendProxy",
    jsii_struct_bases=[],
    name_mapping={"url": "url", "username": "username", "password": "password"},
)
class ApiManagementBackendProxy:
    def __init__(
        self,
        *,
        url: builtins.str,
        username: builtins.str,
        password: typing.Optional[builtins.str] = None,
    ) -> None:
        """
        :param url: 
        :param username: 
        :param password: 
        """
        self._values: typing.Dict[str, typing.Any] = {
            "url": url,
            "username": username,
        }
        if password is not None:
            self._values["password"] = password

    @builtins.property
    def url(self) -> builtins.str:
        result = self._values.get("url")
        assert result is not None, "Required property 'url' is missing"
        return result

    @builtins.property
    def username(self) -> builtins.str:
        result = self._values.get("username")
        assert result is not None, "Required property 'username' is missing"
        return result

    @builtins.property
    def password(self) -> typing.Optional[builtins.str]:
        result = self._values.get("password")
        return result

    def __eq__(self, rhs: typing.Any) -> builtins.bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs: typing.Any) -> builtins.bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return "ApiManagementBackendProxy(%s)" % ", ".join(
            k + "=" + repr(v) for k, v in self._values.items()
        )


@jsii.data_type(
    jsii_type="@cdktf/provider-azurerm.ApiManagementBackendServiceFabricCluster",
    jsii_struct_bases=[],
    name_mapping={
        "client_certificate_thumbprint": "clientCertificateThumbprint",
        "management_endpoints": "managementEndpoints",
        "max_partition_resolution_retries": "maxPartitionResolutionRetries",
        "server_certificate_thumbprints": "serverCertificateThumbprints",
        "server_x509_name": "serverX509Name",
    },
)
class ApiManagementBackendServiceFabricCluster:
    def __init__(
        self,
        *,
        client_certificate_thumbprint: builtins.str,
        management_endpoints: typing.List[builtins.str],
        max_partition_resolution_retries: jsii.Number,
        server_certificate_thumbprints: typing.Optional[typing.List[builtins.str]] = None,
        server_x509_name: typing.Optional[typing.List["ApiManagementBackendServiceFabricClusterServerX509Name"]] = None,
    ) -> None:
        """
        :param client_certificate_thumbprint: 
        :param management_endpoints: 
        :param max_partition_resolution_retries: 
        :param server_certificate_thumbprints: 
        :param server_x509_name: server_x509_name block.
        """
        self._values: typing.Dict[str, typing.Any] = {
            "client_certificate_thumbprint": client_certificate_thumbprint,
            "management_endpoints": management_endpoints,
            "max_partition_resolution_retries": max_partition_resolution_retries,
        }
        if server_certificate_thumbprints is not None:
            self._values["server_certificate_thumbprints"] = server_certificate_thumbprints
        if server_x509_name is not None:
            self._values["server_x509_name"] = server_x509_name

    @builtins.property
    def client_certificate_thumbprint(self) -> builtins.str:
        result = self._values.get("client_certificate_thumbprint")
        assert result is not None, "Required property 'client_certificate_thumbprint' is missing"
        return result

    @builtins.property
    def management_endpoints(self) -> typing.List[builtins.str]:
        result = self._values.get("management_endpoints")
        assert result is not None, "Required property 'management_endpoints' is missing"
        return result

    @builtins.property
    def max_partition_resolution_retries(self) -> jsii.Number:
        result = self._values.get("max_partition_resolution_retries")
        assert result is not None, "Required property 'max_partition_resolution_retries' is missing"
        return result

    @builtins.property
    def server_certificate_thumbprints(
        self,
    ) -> typing.Optional[typing.List[builtins.str]]:
        result = self._values.get("server_certificate_thumbprints")
        return result

    @builtins.property
    def server_x509_name(
        self,
    ) -> typing.Optional[typing.List["ApiManagementBackendServiceFabricClusterServerX509Name"]]:
        """server_x509_name block."""
        result = self._values.get("server_x509_name")
        return result

    def __eq__(self, rhs: typing.Any) -> builtins.bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs: typing.Any) -> builtins.bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return "ApiManagementBackendServiceFabricCluster(%s)" % ", ".join(
            k + "=" + repr(v) for k, v in self._values.items()
        )


@jsii.data_type(
    jsii_type="@cdktf/provider-azurerm.ApiManagementBackendServiceFabricClusterServerX509Name",
    jsii_struct_bases=[],
    name_mapping={
        "issuer_certificate_thumbprint": "issuerCertificateThumbprint",
        "name": "name",
    },
)
class ApiManagementBackendServiceFabricClusterServerX509Name:
    def __init__(
        self,
        *,
        issuer_certificate_thumbprint: builtins.str,
        name: builtins.str,
    ) -> None:
        """
        :param issuer_certificate_thumbprint: 
        :param name: 
        """
        self._values: typing.Dict[str, typing.Any] = {
            "issuer_certificate_thumbprint": issuer_certificate_thumbprint,
            "name": name,
        }

    @builtins.property
    def issuer_certificate_thumbprint(self) -> builtins.str:
        result = self._values.get("issuer_certificate_thumbprint")
        assert result is not None, "Required property 'issuer_certificate_thumbprint' is missing"
        return result

    @builtins.property
    def name(self) -> builtins.str:
        result = self._values.get("name")
        assert result is not None, "Required property 'name' is missing"
        return result

    def __eq__(self, rhs: typing.Any) -> builtins.bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs: typing.Any) -> builtins.bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return "ApiManagementBackendServiceFabricClusterServerX509Name(%s)" % ", ".join(
            k + "=" + repr(v) for k, v in self._values.items()
        )


@jsii.data_type(
    jsii_type="@cdktf/provider-azurerm.ApiManagementBackendTimeouts",
    jsii_struct_bases=[],
    name_mapping={
        "create": "create",
        "delete": "delete",
        "read": "read",
        "update": "update",
    },
)
class ApiManagementBackendTimeouts:
    def __init__(
        self,
        *,
        create: typing.Optional[builtins.str] = None,
        delete: typing.Optional[builtins.str] = None,
        read: typing.Optional[builtins.str] = None,
        update: typing.Optional[builtins.str] = None,
    ) -> None:
        """
        :param create: 
        :param delete: 
        :param read: 
        :param update: 
        """
        self._values: typing.Dict[str, typing.Any] = {}
        if create is not None:
            self._values["create"] = create
        if delete is not None:
            self._values["delete"] = delete
        if read is not None:
            self._values["read"] = read
        if update is not None:
            self._values["update"] = update

    @builtins.property
    def create(self) -> typing.Optional[builtins.str]:
        result = self._values.get("create")
        return result

    @builtins.property
    def delete(self) -> typing.Optional[builtins.str]:
        result = self._values.get("delete")
        return result

    @builtins.property
    def read(self) -> typing.Optional[builtins.str]:
        result = self._values.get("read")
        return result

    @builtins.property
    def update(self) -> typing.Optional[builtins.str]:
        result = self._values.get("update")
        return result

    def __eq__(self, rhs: typing.Any) -> builtins.bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs: typing.Any) -> builtins.bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return "ApiManagementBackendTimeouts(%s)" % ", ".join(
            k + "=" + repr(v) for k, v in self._values.items()
        )


@jsii.data_type(
    jsii_type="@cdktf/provider-azurerm.ApiManagementBackendTls",
    jsii_struct_bases=[],
    name_mapping={
        "validate_certificate_chain": "validateCertificateChain",
        "validate_certificate_name": "validateCertificateName",
    },
)
class ApiManagementBackendTls:
    def __init__(
        self,
        *,
        validate_certificate_chain: typing.Optional[builtins.bool] = None,
        validate_certificate_name: typing.Optional[builtins.bool] = None,
    ) -> None:
        """
        :param validate_certificate_chain: 
        :param validate_certificate_name: 
        """
        self._values: typing.Dict[str, typing.Any] = {}
        if validate_certificate_chain is not None:
            self._values["validate_certificate_chain"] = validate_certificate_chain
        if validate_certificate_name is not None:
            self._values["validate_certificate_name"] = validate_certificate_name

    @builtins.property
    def validate_certificate_chain(self) -> typing.Optional[builtins.bool]:
        result = self._values.get("validate_certificate_chain")
        return result

    @builtins.property
    def validate_certificate_name(self) -> typing.Optional[builtins.bool]:
        result = self._values.get("validate_certificate_name")
        return result

    def __eq__(self, rhs: typing.Any) -> builtins.bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs: typing.Any) -> builtins.bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return "ApiManagementBackendTls(%s)" % ", ".join(
            k + "=" + repr(v) for k, v in self._values.items()
        )


@jsii.data_type(
    jsii_type="@cdktf/provider-azurerm.ApiManagementCertificate",
    jsii_struct_bases=[],
    name_mapping={
        "certificate_password": "certificatePassword",
        "encoded_certificate": "encodedCertificate",
        "store_name": "storeName",
    },
)
class ApiManagementCertificate:
    def __init__(
        self,
        *,
        certificate_password: builtins.str,
        encoded_certificate: builtins.str,
        store_name: builtins.str,
    ) -> None:
        """
        :param certificate_password: 
        :param encoded_certificate: 
        :param store_name: 
        """
        self._values: typing.Dict[str, typing.Any] = {
            "certificate_password": certificate_password,
            "encoded_certificate": encoded_certificate,
            "store_name": store_name,
        }

    @builtins.property
    def certificate_password(self) -> builtins.str:
        result = self._values.get("certificate_password")
        assert result is not None, "Required property 'certificate_password' is missing"
        return result

    @builtins.property
    def encoded_certificate(self) -> builtins.str:
        result = self._values.get("encoded_certificate")
        assert result is not None, "Required property 'encoded_certificate' is missing"
        return result

    @builtins.property
    def store_name(self) -> builtins.str:
        result = self._values.get("store_name")
        assert result is not None, "Required property 'store_name' is missing"
        return result

    def __eq__(self, rhs: typing.Any) -> builtins.bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs: typing.Any) -> builtins.bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return "ApiManagementCertificate(%s)" % ", ".join(
            k + "=" + repr(v) for k, v in self._values.items()
        )


class ApiManagementCertificateA(
    cdktf.TerraformResource,
    metaclass=jsii.JSIIMeta,
    jsii_type="@cdktf/provider-azurerm.ApiManagementCertificateA",
):
    def __init__(
        self,
        scope: constructs.Construct,
        id: builtins.str,
        *,
        api_management_name: builtins.str,
        data: builtins.str,
        name: builtins.str,
        resource_group_name: builtins.str,
        password: typing.Optional[builtins.str] = None,
        timeouts: typing.Optional["ApiManagementCertificateTimeouts"] = None,
        count: typing.Optional[jsii.Number] = None,
        depends_on: typing.Optional[typing.List[cdktf.TerraformResource]] = None,
        lifecycle: typing.Optional[cdktf.TerraformResourceLifecycle] = None,
        provider: typing.Optional[cdktf.TerraformProvider] = None,
    ) -> None:
        """
        :param scope: -
        :param id: -
        :param api_management_name: 
        :param data: 
        :param name: 
        :param resource_group_name: 
        :param password: 
        :param timeouts: timeouts block.
        :param count: 
        :param depends_on: 
        :param lifecycle: 
        :param provider: 
        """
        config = ApiManagementCertificateAConfig(
            api_management_name=api_management_name,
            data=data,
            name=name,
            resource_group_name=resource_group_name,
            password=password,
            timeouts=timeouts,
            count=count,
            depends_on=depends_on,
            lifecycle=lifecycle,
            provider=provider,
        )

        jsii.create(ApiManagementCertificateA, self, [scope, id, config])

    @jsii.member(jsii_name="synthesizeAttributes")
    def _synthesize_attributes(self) -> typing.Mapping[builtins.str, typing.Any]:
        return jsii.invoke(self, "synthesizeAttributes", [])

    @builtins.property # type: ignore
    @jsii.member(jsii_name="expiration")
    def expiration(self) -> builtins.str:
        return jsii.get(self, "expiration")

    @builtins.property # type: ignore
    @jsii.member(jsii_name="subject")
    def subject(self) -> builtins.str:
        return jsii.get(self, "subject")

    @builtins.property # type: ignore
    @jsii.member(jsii_name="thumbprint")
    def thumbprint(self) -> builtins.str:
        return jsii.get(self, "thumbprint")

    @builtins.property # type: ignore
    @jsii.member(jsii_name="apiManagementName")
    def api_management_name(self) -> builtins.str:
        return jsii.get(self, "apiManagementName")

    @api_management_name.setter # type: ignore
    def api_management_name(self, value: builtins.str) -> None:
        jsii.set(self, "apiManagementName", value)

    @builtins.property # type: ignore
    @jsii.member(jsii_name="data")
    def data(self) -> builtins.str:
        return jsii.get(self, "data")

    @data.setter # type: ignore
    def data(self, value: builtins.str) -> None:
        jsii.set(self, "data", value)

    @builtins.property # type: ignore
    @jsii.member(jsii_name="name")
    def name(self) -> builtins.str:
        return jsii.get(self, "name")

    @name.setter # type: ignore
    def name(self, value: builtins.str) -> None:
        jsii.set(self, "name", value)

    @builtins.property # type: ignore
    @jsii.member(jsii_name="resourceGroupName")
    def resource_group_name(self) -> builtins.str:
        return jsii.get(self, "resourceGroupName")

    @resource_group_name.setter # type: ignore
    def resource_group_name(self, value: builtins.str) -> None:
        jsii.set(self, "resourceGroupName", value)

    @builtins.property # type: ignore
    @jsii.member(jsii_name="id")
    def id(self) -> typing.Optional[builtins.str]:
        return jsii.get(self, "id")

    @id.setter # type: ignore
    def id(self, value: typing.Optional[builtins.str]) -> None:
        jsii.set(self, "id", value)

    @builtins.property # type: ignore
    @jsii.member(jsii_name="password")
    def password(self) -> typing.Optional[builtins.str]:
        return jsii.get(self, "password")

    @password.setter # type: ignore
    def password(self, value: typing.Optional[builtins.str]) -> None:
        jsii.set(self, "password", value)

    @builtins.property # type: ignore
    @jsii.member(jsii_name="timeouts")
    def timeouts(self) -> typing.Optional["ApiManagementCertificateTimeouts"]:
        return jsii.get(self, "timeouts")

    @timeouts.setter # type: ignore
    def timeouts(
        self,
        value: typing.Optional["ApiManagementCertificateTimeouts"],
    ) -> None:
        jsii.set(self, "timeouts", value)


@jsii.data_type(
    jsii_type="@cdktf/provider-azurerm.ApiManagementCertificateAConfig",
    jsii_struct_bases=[cdktf.TerraformMetaArguments],
    name_mapping={
        "count": "count",
        "depends_on": "dependsOn",
        "lifecycle": "lifecycle",
        "provider": "provider",
        "api_management_name": "apiManagementName",
        "data": "data",
        "name": "name",
        "resource_group_name": "resourceGroupName",
        "password": "password",
        "timeouts": "timeouts",
    },
)
class ApiManagementCertificateAConfig(cdktf.TerraformMetaArguments):
    def __init__(
        self,
        *,
        count: typing.Optional[jsii.Number] = None,
        depends_on: typing.Optional[typing.List[cdktf.TerraformResource]] = None,
        lifecycle: typing.Optional[cdktf.TerraformResourceLifecycle] = None,
        provider: typing.Optional[cdktf.TerraformProvider] = None,
        api_management_name: builtins.str,
        data: builtins.str,
        name: builtins.str,
        resource_group_name: builtins.str,
        password: typing.Optional[builtins.str] = None,
        timeouts: typing.Optional["ApiManagementCertificateTimeouts"] = None,
    ) -> None:
        """
        :param count: 
        :param depends_on: 
        :param lifecycle: 
        :param provider: 
        :param api_management_name: 
        :param data: 
        :param name: 
        :param resource_group_name: 
        :param password: 
        :param timeouts: timeouts block.
        """
        if isinstance(lifecycle, dict):
            lifecycle = cdktf.TerraformResourceLifecycle(**lifecycle)
        if isinstance(timeouts, dict):
            timeouts = ApiManagementCertificateTimeouts(**timeouts)
        self._values: typing.Dict[str, typing.Any] = {
            "api_management_name": api_management_name,
            "data": data,
            "name": name,
            "resource_group_name": resource_group_name,
        }
        if count is not None:
            self._values["count"] = count
        if depends_on is not None:
            self._values["depends_on"] = depends_on
        if lifecycle is not None:
            self._values["lifecycle"] = lifecycle
        if provider is not None:
            self._values["provider"] = provider
        if password is not None:
            self._values["password"] = password
        if timeouts is not None:
            self._values["timeouts"] = timeouts

    @builtins.property
    def count(self) -> typing.Optional[jsii.Number]:
        """
        :stability: experimental
        """
        result = self._values.get("count")
        return result

    @builtins.property
    def depends_on(self) -> typing.Optional[typing.List[cdktf.TerraformResource]]:
        """
        :stability: experimental
        """
        result = self._values.get("depends_on")
        return result

    @builtins.property
    def lifecycle(self) -> typing.Optional[cdktf.TerraformResourceLifecycle]:
        """
        :stability: experimental
        """
        result = self._values.get("lifecycle")
        return result

    @builtins.property
    def provider(self) -> typing.Optional[cdktf.TerraformProvider]:
        """
        :stability: experimental
        """
        result = self._values.get("provider")
        return result

    @builtins.property
    def api_management_name(self) -> builtins.str:
        result = self._values.get("api_management_name")
        assert result is not None, "Required property 'api_management_name' is missing"
        return result

    @builtins.property
    def data(self) -> builtins.str:
        result = self._values.get("data")
        assert result is not None, "Required property 'data' is missing"
        return result

    @builtins.property
    def name(self) -> builtins.str:
        result = self._values.get("name")
        assert result is not None, "Required property 'name' is missing"
        return result

    @builtins.property
    def resource_group_name(self) -> builtins.str:
        result = self._values.get("resource_group_name")
        assert result is not None, "Required property 'resource_group_name' is missing"
        return result

    @builtins.property
    def password(self) -> typing.Optional[builtins.str]:
        result = self._values.get("password")
        return result

    @builtins.property
    def timeouts(self) -> typing.Optional["ApiManagementCertificateTimeouts"]:
        """timeouts block."""
        result = self._values.get("timeouts")
        return result

    def __eq__(self, rhs: typing.Any) -> builtins.bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs: typing.Any) -> builtins.bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return "ApiManagementCertificateAConfig(%s)" % ", ".join(
            k + "=" + repr(v) for k, v in self._values.items()
        )


@jsii.data_type(
    jsii_type="@cdktf/provider-azurerm.ApiManagementCertificateTimeouts",
    jsii_struct_bases=[],
    name_mapping={
        "create": "create",
        "delete": "delete",
        "read": "read",
        "update": "update",
    },
)
class ApiManagementCertificateTimeouts:
    def __init__(
        self,
        *,
        create: typing.Optional[builtins.str] = None,
        delete: typing.Optional[builtins.str] = None,
        read: typing.Optional[builtins.str] = None,
        update: typing.Optional[builtins.str] = None,
    ) -> None:
        """
        :param create: 
        :param delete: 
        :param read: 
        :param update: 
        """
        self._values: typing.Dict[str, typing.Any] = {}
        if create is not None:
            self._values["create"] = create
        if delete is not None:
            self._values["delete"] = delete
        if read is not None:
            self._values["read"] = read
        if update is not None:
            self._values["update"] = update

    @builtins.property
    def create(self) -> typing.Optional[builtins.str]:
        result = self._values.get("create")
        return result

    @builtins.property
    def delete(self) -> typing.Optional[builtins.str]:
        result = self._values.get("delete")
        return result

    @builtins.property
    def read(self) -> typing.Optional[builtins.str]:
        result = self._values.get("read")
        return result

    @builtins.property
    def update(self) -> typing.Optional[builtins.str]:
        result = self._values.get("update")
        return result

    def __eq__(self, rhs: typing.Any) -> builtins.bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs: typing.Any) -> builtins.bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return "ApiManagementCertificateTimeouts(%s)" % ", ".join(
            k + "=" + repr(v) for k, v in self._values.items()
        )


@jsii.data_type(
    jsii_type="@cdktf/provider-azurerm.ApiManagementConfig",
    jsii_struct_bases=[cdktf.TerraformMetaArguments],
    name_mapping={
        "count": "count",
        "depends_on": "dependsOn",
        "lifecycle": "lifecycle",
        "provider": "provider",
        "location": "location",
        "name": "name",
        "publisher_email": "publisherEmail",
        "publisher_name": "publisherName",
        "resource_group_name": "resourceGroupName",
        "sku_name": "skuName",
        "additional_location": "additionalLocation",
        "certificate": "certificate",
        "hostname_configuration": "hostnameConfiguration",
        "identity": "identity",
        "notification_sender_email": "notificationSenderEmail",
        "policy": "policy",
        "protocols": "protocols",
        "security": "security",
        "sign_in": "signIn",
        "sign_up": "signUp",
        "tags": "tags",
        "timeouts": "timeouts",
    },
)
class ApiManagementConfig(cdktf.TerraformMetaArguments):
    def __init__(
        self,
        *,
        count: typing.Optional[jsii.Number] = None,
        depends_on: typing.Optional[typing.List[cdktf.TerraformResource]] = None,
        lifecycle: typing.Optional[cdktf.TerraformResourceLifecycle] = None,
        provider: typing.Optional[cdktf.TerraformProvider] = None,
        location: builtins.str,
        name: builtins.str,
        publisher_email: builtins.str,
        publisher_name: builtins.str,
        resource_group_name: builtins.str,
        sku_name: builtins.str,
        additional_location: typing.Optional[typing.List[ApiManagementAdditionalLocation]] = None,
        certificate: typing.Optional[typing.List[ApiManagementCertificate]] = None,
        hostname_configuration: typing.Optional[typing.List["ApiManagementHostnameConfiguration"]] = None,
        identity: typing.Optional[typing.List["ApiManagementIdentity"]] = None,
        notification_sender_email: typing.Optional[builtins.str] = None,
        policy: typing.Optional[typing.List["ApiManagementPolicy"]] = None,
        protocols: typing.Optional[typing.List["ApiManagementProtocols"]] = None,
        security: typing.Optional[typing.List["ApiManagementSecurity"]] = None,
        sign_in: typing.Optional[typing.List["ApiManagementSignIn"]] = None,
        sign_up: typing.Optional[typing.List["ApiManagementSignUp"]] = None,
        tags: typing.Optional[typing.Mapping[builtins.str, builtins.str]] = None,
        timeouts: typing.Optional["ApiManagementTimeouts"] = None,
    ) -> None:
        """
        :param count: 
        :param depends_on: 
        :param lifecycle: 
        :param provider: 
        :param location: 
        :param name: 
        :param publisher_email: 
        :param publisher_name: 
        :param resource_group_name: 
        :param sku_name: 
        :param additional_location: additional_location block.
        :param certificate: certificate block.
        :param hostname_configuration: hostname_configuration block.
        :param identity: identity block.
        :param notification_sender_email: 
        :param policy: 
        :param protocols: protocols block.
        :param security: security block.
        :param sign_in: sign_in block.
        :param sign_up: sign_up block.
        :param tags: 
        :param timeouts: timeouts block.
        """
        if isinstance(lifecycle, dict):
            lifecycle = cdktf.TerraformResourceLifecycle(**lifecycle)
        if isinstance(timeouts, dict):
            timeouts = ApiManagementTimeouts(**timeouts)
        self._values: typing.Dict[str, typing.Any] = {
            "location": location,
            "name": name,
            "publisher_email": publisher_email,
            "publisher_name": publisher_name,
            "resource_group_name": resource_group_name,
            "sku_name": sku_name,
        }
        if count is not None:
            self._values["count"] = count
        if depends_on is not None:
            self._values["depends_on"] = depends_on
        if lifecycle is not None:
            self._values["lifecycle"] = lifecycle
        if provider is not None:
            self._values["provider"] = provider
        if additional_location is not None:
            self._values["additional_location"] = additional_location
        if certificate is not None:
            self._values["certificate"] = certificate
        if hostname_configuration is not None:
            self._values["hostname_configuration"] = hostname_configuration
        if identity is not None:
            self._values["identity"] = identity
        if notification_sender_email is not None:
            self._values["notification_sender_email"] = notification_sender_email
        if policy is not None:
            self._values["policy"] = policy
        if protocols is not None:
            self._values["protocols"] = protocols
        if security is not None:
            self._values["security"] = security
        if sign_in is not None:
            self._values["sign_in"] = sign_in
        if sign_up is not None:
            self._values["sign_up"] = sign_up
        if tags is not None:
            self._values["tags"] = tags
        if timeouts is not None:
            self._values["timeouts"] = timeouts

    @builtins.property
    def count(self) -> typing.Optional[jsii.Number]:
        """
        :stability: experimental
        """
        result = self._values.get("count")
        return result

    @builtins.property
    def depends_on(self) -> typing.Optional[typing.List[cdktf.TerraformResource]]:
        """
        :stability: experimental
        """
        result = self._values.get("depends_on")
        return result

    @builtins.property
    def lifecycle(self) -> typing.Optional[cdktf.TerraformResourceLifecycle]:
        """
        :stability: experimental
        """
        result = self._values.get("lifecycle")
        return result

    @builtins.property
    def provider(self) -> typing.Optional[cdktf.TerraformProvider]:
        """
        :stability: experimental
        """
        result = self._values.get("provider")
        return result

    @builtins.property
    def location(self) -> builtins.str:
        result = self._values.get("location")
        assert result is not None, "Required property 'location' is missing"
        return result

    @builtins.property
    def name(self) -> builtins.str:
        result = self._values.get("name")
        assert result is not None, "Required property 'name' is missing"
        return result

    @builtins.property
    def publisher_email(self) -> builtins.str:
        result = self._values.get("publisher_email")
        assert result is not None, "Required property 'publisher_email' is missing"
        return result

    @builtins.property
    def publisher_name(self) -> builtins.str:
        result = self._values.get("publisher_name")
        assert result is not None, "Required property 'publisher_name' is missing"
        return result

    @builtins.property
    def resource_group_name(self) -> builtins.str:
        result = self._values.get("resource_group_name")
        assert result is not None, "Required property 'resource_group_name' is missing"
        return result

    @builtins.property
    def sku_name(self) -> builtins.str:
        result = self._values.get("sku_name")
        assert result is not None, "Required property 'sku_name' is missing"
        return result

    @builtins.property
    def additional_location(
        self,
    ) -> typing.Optional[typing.List[ApiManagementAdditionalLocation]]:
        """additional_location block."""
        result = self._values.get("additional_location")
        return result

    @builtins.property
    def certificate(self) -> typing.Optional[typing.List[ApiManagementCertificate]]:
        """certificate block."""
        result = self._values.get("certificate")
        return result

    @builtins.property
    def hostname_configuration(
        self,
    ) -> typing.Optional[typing.List["ApiManagementHostnameConfiguration"]]:
        """hostname_configuration block."""
        result = self._values.get("hostname_configuration")
        return result

    @builtins.property
    def identity(self) -> typing.Optional[typing.List["ApiManagementIdentity"]]:
        """identity block."""
        result = self._values.get("identity")
        return result

    @builtins.property
    def notification_sender_email(self) -> typing.Optional[builtins.str]:
        result = self._values.get("notification_sender_email")
        return result

    @builtins.property
    def policy(self) -> typing.Optional[typing.List["ApiManagementPolicy"]]:
        result = self._values.get("policy")
        return result

    @builtins.property
    def protocols(self) -> typing.Optional[typing.List["ApiManagementProtocols"]]:
        """protocols block."""
        result = self._values.get("protocols")
        return result

    @builtins.property
    def security(self) -> typing.Optional[typing.List["ApiManagementSecurity"]]:
        """security block."""
        result = self._values.get("security")
        return result

    @builtins.property
    def sign_in(self) -> typing.Optional[typing.List["ApiManagementSignIn"]]:
        """sign_in block."""
        result = self._values.get("sign_in")
        return result

    @builtins.property
    def sign_up(self) -> typing.Optional[typing.List["ApiManagementSignUp"]]:
        """sign_up block."""
        result = self._values.get("sign_up")
        return result

    @builtins.property
    def tags(self) -> typing.Optional[typing.Mapping[builtins.str, builtins.str]]:
        result = self._values.get("tags")
        return result

    @builtins.property
    def timeouts(self) -> typing.Optional["ApiManagementTimeouts"]:
        """timeouts block."""
        result = self._values.get("timeouts")
        return result

    def __eq__(self, rhs: typing.Any) -> builtins.bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs: typing.Any) -> builtins.bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return "ApiManagementConfig(%s)" % ", ".join(
            k + "=" + repr(v) for k, v in self._values.items()
        )


class ApiManagementDiagnostic(
    cdktf.TerraformResource,
    metaclass=jsii.JSIIMeta,
    jsii_type="@cdktf/provider-azurerm.ApiManagementDiagnostic",
):
    def __init__(
        self,
        scope: constructs.Construct,
        id: builtins.str,
        *,
        api_management_name: builtins.str,
        enabled: builtins.bool,
        identifier: builtins.str,
        resource_group_name: builtins.str,
        timeouts: typing.Optional["ApiManagementDiagnosticTimeouts"] = None,
        count: typing.Optional[jsii.Number] = None,
        depends_on: typing.Optional[typing.List[cdktf.TerraformResource]] = None,
        lifecycle: typing.Optional[cdktf.TerraformResourceLifecycle] = None,
        provider: typing.Optional[cdktf.TerraformProvider] = None,
    ) -> None:
        """
        :param scope: -
        :param id: -
        :param api_management_name: 
        :param enabled: 
        :param identifier: 
        :param resource_group_name: 
        :param timeouts: timeouts block.
        :param count: 
        :param depends_on: 
        :param lifecycle: 
        :param provider: 
        """
        config = ApiManagementDiagnosticConfig(
            api_management_name=api_management_name,
            enabled=enabled,
            identifier=identifier,
            resource_group_name=resource_group_name,
            timeouts=timeouts,
            count=count,
            depends_on=depends_on,
            lifecycle=lifecycle,
            provider=provider,
        )

        jsii.create(ApiManagementDiagnostic, self, [scope, id, config])

    @jsii.member(jsii_name="synthesizeAttributes")
    def _synthesize_attributes(self) -> typing.Mapping[builtins.str, typing.Any]:
        return jsii.invoke(self, "synthesizeAttributes", [])

    @builtins.property # type: ignore
    @jsii.member(jsii_name="apiManagementName")
    def api_management_name(self) -> builtins.str:
        return jsii.get(self, "apiManagementName")

    @api_management_name.setter # type: ignore
    def api_management_name(self, value: builtins.str) -> None:
        jsii.set(self, "apiManagementName", value)

    @builtins.property # type: ignore
    @jsii.member(jsii_name="enabled")
    def enabled(self) -> builtins.bool:
        return jsii.get(self, "enabled")

    @enabled.setter # type: ignore
    def enabled(self, value: builtins.bool) -> None:
        jsii.set(self, "enabled", value)

    @builtins.property # type: ignore
    @jsii.member(jsii_name="identifier")
    def identifier(self) -> builtins.str:
        return jsii.get(self, "identifier")

    @identifier.setter # type: ignore
    def identifier(self, value: builtins.str) -> None:
        jsii.set(self, "identifier", value)

    @builtins.property # type: ignore
    @jsii.member(jsii_name="resourceGroupName")
    def resource_group_name(self) -> builtins.str:
        return jsii.get(self, "resourceGroupName")

    @resource_group_name.setter # type: ignore
    def resource_group_name(self, value: builtins.str) -> None:
        jsii.set(self, "resourceGroupName", value)

    @builtins.property # type: ignore
    @jsii.member(jsii_name="id")
    def id(self) -> typing.Optional[builtins.str]:
        return jsii.get(self, "id")

    @id.setter # type: ignore
    def id(self, value: typing.Optional[builtins.str]) -> None:
        jsii.set(self, "id", value)

    @builtins.property # type: ignore
    @jsii.member(jsii_name="timeouts")
    def timeouts(self) -> typing.Optional["ApiManagementDiagnosticTimeouts"]:
        return jsii.get(self, "timeouts")

    @timeouts.setter # type: ignore
    def timeouts(
        self,
        value: typing.Optional["ApiManagementDiagnosticTimeouts"],
    ) -> None:
        jsii.set(self, "timeouts", value)


@jsii.data_type(
    jsii_type="@cdktf/provider-azurerm.ApiManagementDiagnosticConfig",
    jsii_struct_bases=[cdktf.TerraformMetaArguments],
    name_mapping={
        "count": "count",
        "depends_on": "dependsOn",
        "lifecycle": "lifecycle",
        "provider": "provider",
        "api_management_name": "apiManagementName",
        "enabled": "enabled",
        "identifier": "identifier",
        "resource_group_name": "resourceGroupName",
        "timeouts": "timeouts",
    },
)
class ApiManagementDiagnosticConfig(cdktf.TerraformMetaArguments):
    def __init__(
        self,
        *,
        count: typing.Optional[jsii.Number] = None,
        depends_on: typing.Optional[typing.List[cdktf.TerraformResource]] = None,
        lifecycle: typing.Optional[cdktf.TerraformResourceLifecycle] = None,
        provider: typing.Optional[cdktf.TerraformProvider] = None,
        api_management_name: builtins.str,
        enabled: builtins.bool,
        identifier: builtins.str,
        resource_group_name: builtins.str,
        timeouts: typing.Optional["ApiManagementDiagnosticTimeouts"] = None,
    ) -> None:
        """
        :param count: 
        :param depends_on: 
        :param lifecycle: 
        :param provider: 
        :param api_management_name: 
        :param enabled: 
        :param identifier: 
        :param resource_group_name: 
        :param timeouts: timeouts block.
        """
        if isinstance(lifecycle, dict):
            lifecycle = cdktf.TerraformResourceLifecycle(**lifecycle)
        if isinstance(timeouts, dict):
            timeouts = ApiManagementDiagnosticTimeouts(**timeouts)
        self._values: typing.Dict[str, typing.Any] = {
            "api_management_name": api_management_name,
            "enabled": enabled,
            "identifier": identifier,
            "resource_group_name": resource_group_name,
        }
        if count is not None:
            self._values["count"] = count
        if depends_on is not None:
            self._values["depends_on"] = depends_on
        if lifecycle is not None:
            self._values["lifecycle"] = lifecycle
        if provider is not None:
            self._values["provider"] = provider
        if timeouts is not None:
            self._values["timeouts"] = timeouts

    @builtins.property
    def count(self) -> typing.Optional[jsii.Number]:
        """
        :stability: experimental
        """
        result = self._values.get("count")
        return result

    @builtins.property
    def depends_on(self) -> typing.Optional[typing.List[cdktf.TerraformResource]]:
        """
        :stability: experimental
        """
        result = self._values.get("depends_on")
        return result

    @builtins.property
    def lifecycle(self) -> typing.Optional[cdktf.TerraformResourceLifecycle]:
        """
        :stability: experimental
        """
        result = self._values.get("lifecycle")
        return result

    @builtins.property
    def provider(self) -> typing.Optional[cdktf.TerraformProvider]:
        """
        :stability: experimental
        """
        result = self._values.get("provider")
        return result

    @builtins.property
    def api_management_name(self) -> builtins.str:
        result = self._values.get("api_management_name")
        assert result is not None, "Required property 'api_management_name' is missing"
        return result

    @builtins.property
    def enabled(self) -> builtins.bool:
        result = self._values.get("enabled")
        assert result is not None, "Required property 'enabled' is missing"
        return result

    @builtins.property
    def identifier(self) -> builtins.str:
        result = self._values.get("identifier")
        assert result is not None, "Required property 'identifier' is missing"
        return result

    @builtins.property
    def resource_group_name(self) -> builtins.str:
        result = self._values.get("resource_group_name")
        assert result is not None, "Required property 'resource_group_name' is missing"
        return result

    @builtins.property
    def timeouts(self) -> typing.Optional["ApiManagementDiagnosticTimeouts"]:
        """timeouts block."""
        result = self._values.get("timeouts")
        return result

    def __eq__(self, rhs: typing.Any) -> builtins.bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs: typing.Any) -> builtins.bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return "ApiManagementDiagnosticConfig(%s)" % ", ".join(
            k + "=" + repr(v) for k, v in self._values.items()
        )


@jsii.data_type(
    jsii_type="@cdktf/provider-azurerm.ApiManagementDiagnosticTimeouts",
    jsii_struct_bases=[],
    name_mapping={
        "create": "create",
        "delete": "delete",
        "read": "read",
        "update": "update",
    },
)
class ApiManagementDiagnosticTimeouts:
    def __init__(
        self,
        *,
        create: typing.Optional[builtins.str] = None,
        delete: typing.Optional[builtins.str] = None,
        read: typing.Optional[builtins.str] = None,
        update: typing.Optional[builtins.str] = None,
    ) -> None:
        """
        :param create: 
        :param delete: 
        :param read: 
        :param update: 
        """
        self._values: typing.Dict[str, typing.Any] = {}
        if create is not None:
            self._values["create"] = create
        if delete is not None:
            self._values["delete"] = delete
        if read is not None:
            self._values["read"] = read
        if update is not None:
            self._values["update"] = update

    @builtins.property
    def create(self) -> typing.Optional[builtins.str]:
        result = self._values.get("create")
        return result

    @builtins.property
    def delete(self) -> typing.Optional[builtins.str]:
        result = self._values.get("delete")
        return result

    @builtins.property
    def read(self) -> typing.Optional[builtins.str]:
        result = self._values.get("read")
        return result

    @builtins.property
    def update(self) -> typing.Optional[builtins.str]:
        result = self._values.get("update")
        return result

    def __eq__(self, rhs: typing.Any) -> builtins.bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs: typing.Any) -> builtins.bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return "ApiManagementDiagnosticTimeouts(%s)" % ", ".join(
            k + "=" + repr(v) for k, v in self._values.items()
        )


class ApiManagementGroup(
    cdktf.TerraformResource,
    metaclass=jsii.JSIIMeta,
    jsii_type="@cdktf/provider-azurerm.ApiManagementGroup",
):
    def __init__(
        self,
        scope: constructs.Construct,
        id: builtins.str,
        *,
        api_management_name: builtins.str,
        display_name: builtins.str,
        name: builtins.str,
        resource_group_name: builtins.str,
        description: typing.Optional[builtins.str] = None,
        external_id: typing.Optional[builtins.str] = None,
        timeouts: typing.Optional["ApiManagementGroupTimeouts"] = None,
        type: typing.Optional[builtins.str] = None,
        count: typing.Optional[jsii.Number] = None,
        depends_on: typing.Optional[typing.List[cdktf.TerraformResource]] = None,
        lifecycle: typing.Optional[cdktf.TerraformResourceLifecycle] = None,
        provider: typing.Optional[cdktf.TerraformProvider] = None,
    ) -> None:
        """
        :param scope: -
        :param id: -
        :param api_management_name: 
        :param display_name: 
        :param name: 
        :param resource_group_name: 
        :param description: 
        :param external_id: 
        :param timeouts: timeouts block.
        :param type: 
        :param count: 
        :param depends_on: 
        :param lifecycle: 
        :param provider: 
        """
        config = ApiManagementGroupConfig(
            api_management_name=api_management_name,
            display_name=display_name,
            name=name,
            resource_group_name=resource_group_name,
            description=description,
            external_id=external_id,
            timeouts=timeouts,
            type=type,
            count=count,
            depends_on=depends_on,
            lifecycle=lifecycle,
            provider=provider,
        )

        jsii.create(ApiManagementGroup, self, [scope, id, config])

    @jsii.member(jsii_name="synthesizeAttributes")
    def _synthesize_attributes(self) -> typing.Mapping[builtins.str, typing.Any]:
        return jsii.invoke(self, "synthesizeAttributes", [])

    @builtins.property # type: ignore
    @jsii.member(jsii_name="apiManagementName")
    def api_management_name(self) -> builtins.str:
        return jsii.get(self, "apiManagementName")

    @api_management_name.setter # type: ignore
    def api_management_name(self, value: builtins.str) -> None:
        jsii.set(self, "apiManagementName", value)

    @builtins.property # type: ignore
    @jsii.member(jsii_name="displayName")
    def display_name(self) -> builtins.str:
        return jsii.get(self, "displayName")

    @display_name.setter # type: ignore
    def display_name(self, value: builtins.str) -> None:
        jsii.set(self, "displayName", value)

    @builtins.property # type: ignore
    @jsii.member(jsii_name="name")
    def name(self) -> builtins.str:
        return jsii.get(self, "name")

    @name.setter # type: ignore
    def name(self, value: builtins.str) -> None:
        jsii.set(self, "name", value)

    @builtins.property # type: ignore
    @jsii.member(jsii_name="resourceGroupName")
    def resource_group_name(self) -> builtins.str:
        return jsii.get(self, "resourceGroupName")

    @resource_group_name.setter # type: ignore
    def resource_group_name(self, value: builtins.str) -> None:
        jsii.set(self, "resourceGroupName", value)

    @builtins.property # type: ignore
    @jsii.member(jsii_name="description")
    def description(self) -> typing.Optional[builtins.str]:
        return jsii.get(self, "description")

    @description.setter # type: ignore
    def description(self, value: typing.Optional[builtins.str]) -> None:
        jsii.set(self, "description", value)

    @builtins.property # type: ignore
    @jsii.member(jsii_name="externalId")
    def external_id(self) -> typing.Optional[builtins.str]:
        return jsii.get(self, "externalId")

    @external_id.setter # type: ignore
    def external_id(self, value: typing.Optional[builtins.str]) -> None:
        jsii.set(self, "externalId", value)

    @builtins.property # type: ignore
    @jsii.member(jsii_name="id")
    def id(self) -> typing.Optional[builtins.str]:
        return jsii.get(self, "id")

    @id.setter # type: ignore
    def id(self, value: typing.Optional[builtins.str]) -> None:
        jsii.set(self, "id", value)

    @builtins.property # type: ignore
    @jsii.member(jsii_name="timeouts")
    def timeouts(self) -> typing.Optional["ApiManagementGroupTimeouts"]:
        return jsii.get(self, "timeouts")

    @timeouts.setter # type: ignore
    def timeouts(self, value: typing.Optional["ApiManagementGroupTimeouts"]) -> None:
        jsii.set(self, "timeouts", value)

    @builtins.property # type: ignore
    @jsii.member(jsii_name="type")
    def type(self) -> typing.Optional[builtins.str]:
        return jsii.get(self, "type")

    @type.setter # type: ignore
    def type(self, value: typing.Optional[builtins.str]) -> None:
        jsii.set(self, "type", value)


@jsii.data_type(
    jsii_type="@cdktf/provider-azurerm.ApiManagementGroupConfig",
    jsii_struct_bases=[cdktf.TerraformMetaArguments],
    name_mapping={
        "count": "count",
        "depends_on": "dependsOn",
        "lifecycle": "lifecycle",
        "provider": "provider",
        "api_management_name": "apiManagementName",
        "display_name": "displayName",
        "name": "name",
        "resource_group_name": "resourceGroupName",
        "description": "description",
        "external_id": "externalId",
        "timeouts": "timeouts",
        "type": "type",
    },
)
class ApiManagementGroupConfig(cdktf.TerraformMetaArguments):
    def __init__(
        self,
        *,
        count: typing.Optional[jsii.Number] = None,
        depends_on: typing.Optional[typing.List[cdktf.TerraformResource]] = None,
        lifecycle: typing.Optional[cdktf.TerraformResourceLifecycle] = None,
        provider: typing.Optional[cdktf.TerraformProvider] = None,
        api_management_name: builtins.str,
        display_name: builtins.str,
        name: builtins.str,
        resource_group_name: builtins.str,
        description: typing.Optional[builtins.str] = None,
        external_id: typing.Optional[builtins.str] = None,
        timeouts: typing.Optional["ApiManagementGroupTimeouts"] = None,
        type: typing.Optional[builtins.str] = None,
    ) -> None:
        """
        :param count: 
        :param depends_on: 
        :param lifecycle: 
        :param provider: 
        :param api_management_name: 
        :param display_name: 
        :param name: 
        :param resource_group_name: 
        :param description: 
        :param external_id: 
        :param timeouts: timeouts block.
        :param type: 
        """
        if isinstance(lifecycle, dict):
            lifecycle = cdktf.TerraformResourceLifecycle(**lifecycle)
        if isinstance(timeouts, dict):
            timeouts = ApiManagementGroupTimeouts(**timeouts)
        self._values: typing.Dict[str, typing.Any] = {
            "api_management_name": api_management_name,
            "display_name": display_name,
            "name": name,
            "resource_group_name": resource_group_name,
        }
        if count is not None:
            self._values["count"] = count
        if depends_on is not None:
            self._values["depends_on"] = depends_on
        if lifecycle is not None:
            self._values["lifecycle"] = lifecycle
        if provider is not None:
            self._values["provider"] = provider
        if description is not None:
            self._values["description"] = description
        if external_id is not None:
            self._values["external_id"] = external_id
        if timeouts is not None:
            self._values["timeouts"] = timeouts
        if type is not None:
            self._values["type"] = type

    @builtins.property
    def count(self) -> typing.Optional[jsii.Number]:
        """
        :stability: experimental
        """
        result = self._values.get("count")
        return result

    @builtins.property
    def depends_on(self) -> typing.Optional[typing.List[cdktf.TerraformResource]]:
        """
        :stability: experimental
        """
        result = self._values.get("depends_on")
        return result

    @builtins.property
    def lifecycle(self) -> typing.Optional[cdktf.TerraformResourceLifecycle]:
        """
        :stability: experimental
        """
        result = self._values.get("lifecycle")
        return result

    @builtins.property
    def provider(self) -> typing.Optional[cdktf.TerraformProvider]:
        """
        :stability: experimental
        """
        result = self._values.get("provider")
        return result

    @builtins.property
    def api_management_name(self) -> builtins.str:
        result = self._values.get("api_management_name")
        assert result is not None, "Required property 'api_management_name' is missing"
        return result

    @builtins.property
    def display_name(self) -> builtins.str:
        result = self._values.get("display_name")
        assert result is not None, "Required property 'display_name' is missing"
        return result

    @builtins.property
    def name(self) -> builtins.str:
        result = self._values.get("name")
        assert result is not None, "Required property 'name' is missing"
        return result

    @builtins.property
    def resource_group_name(self) -> builtins.str:
        result = self._values.get("resource_group_name")
        assert result is not None, "Required property 'resource_group_name' is missing"
        return result

    @builtins.property
    def description(self) -> typing.Optional[builtins.str]:
        result = self._values.get("description")
        return result

    @builtins.property
    def external_id(self) -> typing.Optional[builtins.str]:
        result = self._values.get("external_id")
        return result

    @builtins.property
    def timeouts(self) -> typing.Optional["ApiManagementGroupTimeouts"]:
        """timeouts block."""
        result = self._values.get("timeouts")
        return result

    @builtins.property
    def type(self) -> typing.Optional[builtins.str]:
        result = self._values.get("type")
        return result

    def __eq__(self, rhs: typing.Any) -> builtins.bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs: typing.Any) -> builtins.bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return "ApiManagementGroupConfig(%s)" % ", ".join(
            k + "=" + repr(v) for k, v in self._values.items()
        )


@jsii.data_type(
    jsii_type="@cdktf/provider-azurerm.ApiManagementGroupTimeouts",
    jsii_struct_bases=[],
    name_mapping={
        "create": "create",
        "delete": "delete",
        "read": "read",
        "update": "update",
    },
)
class ApiManagementGroupTimeouts:
    def __init__(
        self,
        *,
        create: typing.Optional[builtins.str] = None,
        delete: typing.Optional[builtins.str] = None,
        read: typing.Optional[builtins.str] = None,
        update: typing.Optional[builtins.str] = None,
    ) -> None:
        """
        :param create: 
        :param delete: 
        :param read: 
        :param update: 
        """
        self._values: typing.Dict[str, typing.Any] = {}
        if create is not None:
            self._values["create"] = create
        if delete is not None:
            self._values["delete"] = delete
        if read is not None:
            self._values["read"] = read
        if update is not None:
            self._values["update"] = update

    @builtins.property
    def create(self) -> typing.Optional[builtins.str]:
        result = self._values.get("create")
        return result

    @builtins.property
    def delete(self) -> typing.Optional[builtins.str]:
        result = self._values.get("delete")
        return result

    @builtins.property
    def read(self) -> typing.Optional[builtins.str]:
        result = self._values.get("read")
        return result

    @builtins.property
    def update(self) -> typing.Optional[builtins.str]:
        result = self._values.get("update")
        return result

    def __eq__(self, rhs: typing.Any) -> builtins.bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs: typing.Any) -> builtins.bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return "ApiManagementGroupTimeouts(%s)" % ", ".join(
            k + "=" + repr(v) for k, v in self._values.items()
        )


class ApiManagementGroupUser(
    cdktf.TerraformResource,
    metaclass=jsii.JSIIMeta,
    jsii_type="@cdktf/provider-azurerm.ApiManagementGroupUser",
):
    def __init__(
        self,
        scope: constructs.Construct,
        id: builtins.str,
        *,
        api_management_name: builtins.str,
        group_name: builtins.str,
        resource_group_name: builtins.str,
        user_id: builtins.str,
        timeouts: typing.Optional["ApiManagementGroupUserTimeouts"] = None,
        count: typing.Optional[jsii.Number] = None,
        depends_on: typing.Optional[typing.List[cdktf.TerraformResource]] = None,
        lifecycle: typing.Optional[cdktf.TerraformResourceLifecycle] = None,
        provider: typing.Optional[cdktf.TerraformProvider] = None,
    ) -> None:
        """
        :param scope: -
        :param id: -
        :param api_management_name: 
        :param group_name: 
        :param resource_group_name: 
        :param user_id: 
        :param timeouts: timeouts block.
        :param count: 
        :param depends_on: 
        :param lifecycle: 
        :param provider: 
        """
        config = ApiManagementGroupUserConfig(
            api_management_name=api_management_name,
            group_name=group_name,
            resource_group_name=resource_group_name,
            user_id=user_id,
            timeouts=timeouts,
            count=count,
            depends_on=depends_on,
            lifecycle=lifecycle,
            provider=provider,
        )

        jsii.create(ApiManagementGroupUser, self, [scope, id, config])

    @jsii.member(jsii_name="synthesizeAttributes")
    def _synthesize_attributes(self) -> typing.Mapping[builtins.str, typing.Any]:
        return jsii.invoke(self, "synthesizeAttributes", [])

    @builtins.property # type: ignore
    @jsii.member(jsii_name="apiManagementName")
    def api_management_name(self) -> builtins.str:
        return jsii.get(self, "apiManagementName")

    @api_management_name.setter # type: ignore
    def api_management_name(self, value: builtins.str) -> None:
        jsii.set(self, "apiManagementName", value)

    @builtins.property # type: ignore
    @jsii.member(jsii_name="groupName")
    def group_name(self) -> builtins.str:
        return jsii.get(self, "groupName")

    @group_name.setter # type: ignore
    def group_name(self, value: builtins.str) -> None:
        jsii.set(self, "groupName", value)

    @builtins.property # type: ignore
    @jsii.member(jsii_name="resourceGroupName")
    def resource_group_name(self) -> builtins.str:
        return jsii.get(self, "resourceGroupName")

    @resource_group_name.setter # type: ignore
    def resource_group_name(self, value: builtins.str) -> None:
        jsii.set(self, "resourceGroupName", value)

    @builtins.property # type: ignore
    @jsii.member(jsii_name="userId")
    def user_id(self) -> builtins.str:
        return jsii.get(self, "userId")

    @user_id.setter # type: ignore
    def user_id(self, value: builtins.str) -> None:
        jsii.set(self, "userId", value)

    @builtins.property # type: ignore
    @jsii.member(jsii_name="id")
    def id(self) -> typing.Optional[builtins.str]:
        return jsii.get(self, "id")

    @id.setter # type: ignore
    def id(self, value: typing.Optional[builtins.str]) -> None:
        jsii.set(self, "id", value)

    @builtins.property # type: ignore
    @jsii.member(jsii_name="timeouts")
    def timeouts(self) -> typing.Optional["ApiManagementGroupUserTimeouts"]:
        return jsii.get(self, "timeouts")

    @timeouts.setter # type: ignore
    def timeouts(
        self,
        value: typing.Optional["ApiManagementGroupUserTimeouts"],
    ) -> None:
        jsii.set(self, "timeouts", value)


@jsii.data_type(
    jsii_type="@cdktf/provider-azurerm.ApiManagementGroupUserConfig",
    jsii_struct_bases=[cdktf.TerraformMetaArguments],
    name_mapping={
        "count": "count",
        "depends_on": "dependsOn",
        "lifecycle": "lifecycle",
        "provider": "provider",
        "api_management_name": "apiManagementName",
        "group_name": "groupName",
        "resource_group_name": "resourceGroupName",
        "user_id": "userId",
        "timeouts": "timeouts",
    },
)
class ApiManagementGroupUserConfig(cdktf.TerraformMetaArguments):
    def __init__(
        self,
        *,
        count: typing.Optional[jsii.Number] = None,
        depends_on: typing.Optional[typing.List[cdktf.TerraformResource]] = None,
        lifecycle: typing.Optional[cdktf.TerraformResourceLifecycle] = None,
        provider: typing.Optional[cdktf.TerraformProvider] = None,
        api_management_name: builtins.str,
        group_name: builtins.str,
        resource_group_name: builtins.str,
        user_id: builtins.str,
        timeouts: typing.Optional["ApiManagementGroupUserTimeouts"] = None,
    ) -> None:
        """
        :param count: 
        :param depends_on: 
        :param lifecycle: 
        :param provider: 
        :param api_management_name: 
        :param group_name: 
        :param resource_group_name: 
        :param user_id: 
        :param timeouts: timeouts block.
        """
        if isinstance(lifecycle, dict):
            lifecycle = cdktf.TerraformResourceLifecycle(**lifecycle)
        if isinstance(timeouts, dict):
            timeouts = ApiManagementGroupUserTimeouts(**timeouts)
        self._values: typing.Dict[str, typing.Any] = {
            "api_management_name": api_management_name,
            "group_name": group_name,
            "resource_group_name": resource_group_name,
            "user_id": user_id,
        }
        if count is not None:
            self._values["count"] = count
        if depends_on is not None:
            self._values["depends_on"] = depends_on
        if lifecycle is not None:
            self._values["lifecycle"] = lifecycle
        if provider is not None:
            self._values["provider"] = provider
        if timeouts is not None:
            self._values["timeouts"] = timeouts

    @builtins.property
    def count(self) -> typing.Optional[jsii.Number]:
        """
        :stability: experimental
        """
        result = self._values.get("count")
        return result

    @builtins.property
    def depends_on(self) -> typing.Optional[typing.List[cdktf.TerraformResource]]:
        """
        :stability: experimental
        """
        result = self._values.get("depends_on")
        return result

    @builtins.property
    def lifecycle(self) -> typing.Optional[cdktf.TerraformResourceLifecycle]:
        """
        :stability: experimental
        """
        result = self._values.get("lifecycle")
        return result

    @builtins.property
    def provider(self) -> typing.Optional[cdktf.TerraformProvider]:
        """
        :stability: experimental
        """
        result = self._values.get("provider")
        return result

    @builtins.property
    def api_management_name(self) -> builtins.str:
        result = self._values.get("api_management_name")
        assert result is not None, "Required property 'api_management_name' is missing"
        return result

    @builtins.property
    def group_name(self) -> builtins.str:
        result = self._values.get("group_name")
        assert result is not None, "Required property 'group_name' is missing"
        return result

    @builtins.property
    def resource_group_name(self) -> builtins.str:
        result = self._values.get("resource_group_name")
        assert result is not None, "Required property 'resource_group_name' is missing"
        return result

    @builtins.property
    def user_id(self) -> builtins.str:
        result = self._values.get("user_id")
        assert result is not None, "Required property 'user_id' is missing"
        return result

    @builtins.property
    def timeouts(self) -> typing.Optional["ApiManagementGroupUserTimeouts"]:
        """timeouts block."""
        result = self._values.get("timeouts")
        return result

    def __eq__(self, rhs: typing.Any) -> builtins.bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs: typing.Any) -> builtins.bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return "ApiManagementGroupUserConfig(%s)" % ", ".join(
            k + "=" + repr(v) for k, v in self._values.items()
        )


@jsii.data_type(
    jsii_type="@cdktf/provider-azurerm.ApiManagementGroupUserTimeouts",
    jsii_struct_bases=[],
    name_mapping={
        "create": "create",
        "delete": "delete",
        "read": "read",
        "update": "update",
    },
)
class ApiManagementGroupUserTimeouts:
    def __init__(
        self,
        *,
        create: typing.Optional[builtins.str] = None,
        delete: typing.Optional[builtins.str] = None,
        read: typing.Optional[builtins.str] = None,
        update: typing.Optional[builtins.str] = None,
    ) -> None:
        """
        :param create: 
        :param delete: 
        :param read: 
        :param update: 
        """
        self._values: typing.Dict[str, typing.Any] = {}
        if create is not None:
            self._values["create"] = create
        if delete is not None:
            self._values["delete"] = delete
        if read is not None:
            self._values["read"] = read
        if update is not None:
            self._values["update"] = update

    @builtins.property
    def create(self) -> typing.Optional[builtins.str]:
        result = self._values.get("create")
        return result

    @builtins.property
    def delete(self) -> typing.Optional[builtins.str]:
        result = self._values.get("delete")
        return result

    @builtins.property
    def read(self) -> typing.Optional[builtins.str]:
        result = self._values.get("read")
        return result

    @builtins.property
    def update(self) -> typing.Optional[builtins.str]:
        result = self._values.get("update")
        return result

    def __eq__(self, rhs: typing.Any) -> builtins.bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs: typing.Any) -> builtins.bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return "ApiManagementGroupUserTimeouts(%s)" % ", ".join(
            k + "=" + repr(v) for k, v in self._values.items()
        )


@jsii.data_type(
    jsii_type="@cdktf/provider-azurerm.ApiManagementHostnameConfiguration",
    jsii_struct_bases=[],
    name_mapping={
        "management": "management",
        "portal": "portal",
        "proxy": "proxy",
        "scm": "scm",
    },
)
class ApiManagementHostnameConfiguration:
    def __init__(
        self,
        *,
        management: typing.Optional[typing.List["ApiManagementHostnameConfigurationManagement"]] = None,
        portal: typing.Optional[typing.List["ApiManagementHostnameConfigurationPortal"]] = None,
        proxy: typing.Optional[typing.List["ApiManagementHostnameConfigurationProxy"]] = None,
        scm: typing.Optional[typing.List["ApiManagementHostnameConfigurationScm"]] = None,
    ) -> None:
        """
        :param management: management block.
        :param portal: portal block.
        :param proxy: proxy block.
        :param scm: scm block.
        """
        self._values: typing.Dict[str, typing.Any] = {}
        if management is not None:
            self._values["management"] = management
        if portal is not None:
            self._values["portal"] = portal
        if proxy is not None:
            self._values["proxy"] = proxy
        if scm is not None:
            self._values["scm"] = scm

    @builtins.property
    def management(
        self,
    ) -> typing.Optional[typing.List["ApiManagementHostnameConfigurationManagement"]]:
        """management block."""
        result = self._values.get("management")
        return result

    @builtins.property
    def portal(
        self,
    ) -> typing.Optional[typing.List["ApiManagementHostnameConfigurationPortal"]]:
        """portal block."""
        result = self._values.get("portal")
        return result

    @builtins.property
    def proxy(
        self,
    ) -> typing.Optional[typing.List["ApiManagementHostnameConfigurationProxy"]]:
        """proxy block."""
        result = self._values.get("proxy")
        return result

    @builtins.property
    def scm(
        self,
    ) -> typing.Optional[typing.List["ApiManagementHostnameConfigurationScm"]]:
        """scm block."""
        result = self._values.get("scm")
        return result

    def __eq__(self, rhs: typing.Any) -> builtins.bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs: typing.Any) -> builtins.bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return "ApiManagementHostnameConfiguration(%s)" % ", ".join(
            k + "=" + repr(v) for k, v in self._values.items()
        )


@jsii.data_type(
    jsii_type="@cdktf/provider-azurerm.ApiManagementHostnameConfigurationManagement",
    jsii_struct_bases=[],
    name_mapping={
        "host_name": "hostName",
        "certificate": "certificate",
        "certificate_password": "certificatePassword",
        "key_vault_id": "keyVaultId",
        "negotiate_client_certificate": "negotiateClientCertificate",
    },
)
class ApiManagementHostnameConfigurationManagement:
    def __init__(
        self,
        *,
        host_name: builtins.str,
        certificate: typing.Optional[builtins.str] = None,
        certificate_password: typing.Optional[builtins.str] = None,
        key_vault_id: typing.Optional[builtins.str] = None,
        negotiate_client_certificate: typing.Optional[builtins.bool] = None,
    ) -> None:
        """
        :param host_name: 
        :param certificate: 
        :param certificate_password: 
        :param key_vault_id: 
        :param negotiate_client_certificate: 
        """
        self._values: typing.Dict[str, typing.Any] = {
            "host_name": host_name,
        }
        if certificate is not None:
            self._values["certificate"] = certificate
        if certificate_password is not None:
            self._values["certificate_password"] = certificate_password
        if key_vault_id is not None:
            self._values["key_vault_id"] = key_vault_id
        if negotiate_client_certificate is not None:
            self._values["negotiate_client_certificate"] = negotiate_client_certificate

    @builtins.property
    def host_name(self) -> builtins.str:
        result = self._values.get("host_name")
        assert result is not None, "Required property 'host_name' is missing"
        return result

    @builtins.property
    def certificate(self) -> typing.Optional[builtins.str]:
        result = self._values.get("certificate")
        return result

    @builtins.property
    def certificate_password(self) -> typing.Optional[builtins.str]:
        result = self._values.get("certificate_password")
        return result

    @builtins.property
    def key_vault_id(self) -> typing.Optional[builtins.str]:
        result = self._values.get("key_vault_id")
        return result

    @builtins.property
    def negotiate_client_certificate(self) -> typing.Optional[builtins.bool]:
        result = self._values.get("negotiate_client_certificate")
        return result

    def __eq__(self, rhs: typing.Any) -> builtins.bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs: typing.Any) -> builtins.bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return "ApiManagementHostnameConfigurationManagement(%s)" % ", ".join(
            k + "=" + repr(v) for k, v in self._values.items()
        )


@jsii.data_type(
    jsii_type="@cdktf/provider-azurerm.ApiManagementHostnameConfigurationPortal",
    jsii_struct_bases=[],
    name_mapping={
        "host_name": "hostName",
        "certificate": "certificate",
        "certificate_password": "certificatePassword",
        "key_vault_id": "keyVaultId",
        "negotiate_client_certificate": "negotiateClientCertificate",
    },
)
class ApiManagementHostnameConfigurationPortal:
    def __init__(
        self,
        *,
        host_name: builtins.str,
        certificate: typing.Optional[builtins.str] = None,
        certificate_password: typing.Optional[builtins.str] = None,
        key_vault_id: typing.Optional[builtins.str] = None,
        negotiate_client_certificate: typing.Optional[builtins.bool] = None,
    ) -> None:
        """
        :param host_name: 
        :param certificate: 
        :param certificate_password: 
        :param key_vault_id: 
        :param negotiate_client_certificate: 
        """
        self._values: typing.Dict[str, typing.Any] = {
            "host_name": host_name,
        }
        if certificate is not None:
            self._values["certificate"] = certificate
        if certificate_password is not None:
            self._values["certificate_password"] = certificate_password
        if key_vault_id is not None:
            self._values["key_vault_id"] = key_vault_id
        if negotiate_client_certificate is not None:
            self._values["negotiate_client_certificate"] = negotiate_client_certificate

    @builtins.property
    def host_name(self) -> builtins.str:
        result = self._values.get("host_name")
        assert result is not None, "Required property 'host_name' is missing"
        return result

    @builtins.property
    def certificate(self) -> typing.Optional[builtins.str]:
        result = self._values.get("certificate")
        return result

    @builtins.property
    def certificate_password(self) -> typing.Optional[builtins.str]:
        result = self._values.get("certificate_password")
        return result

    @builtins.property
    def key_vault_id(self) -> typing.Optional[builtins.str]:
        result = self._values.get("key_vault_id")
        return result

    @builtins.property
    def negotiate_client_certificate(self) -> typing.Optional[builtins.bool]:
        result = self._values.get("negotiate_client_certificate")
        return result

    def __eq__(self, rhs: typing.Any) -> builtins.bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs: typing.Any) -> builtins.bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return "ApiManagementHostnameConfigurationPortal(%s)" % ", ".join(
            k + "=" + repr(v) for k, v in self._values.items()
        )


@jsii.data_type(
    jsii_type="@cdktf/provider-azurerm.ApiManagementHostnameConfigurationProxy",
    jsii_struct_bases=[],
    name_mapping={
        "host_name": "hostName",
        "certificate": "certificate",
        "certificate_password": "certificatePassword",
        "default_ssl_binding": "defaultSslBinding",
        "key_vault_id": "keyVaultId",
        "negotiate_client_certificate": "negotiateClientCertificate",
    },
)
class ApiManagementHostnameConfigurationProxy:
    def __init__(
        self,
        *,
        host_name: builtins.str,
        certificate: typing.Optional[builtins.str] = None,
        certificate_password: typing.Optional[builtins.str] = None,
        default_ssl_binding: typing.Optional[builtins.bool] = None,
        key_vault_id: typing.Optional[builtins.str] = None,
        negotiate_client_certificate: typing.Optional[builtins.bool] = None,
    ) -> None:
        """
        :param host_name: 
        :param certificate: 
        :param certificate_password: 
        :param default_ssl_binding: 
        :param key_vault_id: 
        :param negotiate_client_certificate: 
        """
        self._values: typing.Dict[str, typing.Any] = {
            "host_name": host_name,
        }
        if certificate is not None:
            self._values["certificate"] = certificate
        if certificate_password is not None:
            self._values["certificate_password"] = certificate_password
        if default_ssl_binding is not None:
            self._values["default_ssl_binding"] = default_ssl_binding
        if key_vault_id is not None:
            self._values["key_vault_id"] = key_vault_id
        if negotiate_client_certificate is not None:
            self._values["negotiate_client_certificate"] = negotiate_client_certificate

    @builtins.property
    def host_name(self) -> builtins.str:
        result = self._values.get("host_name")
        assert result is not None, "Required property 'host_name' is missing"
        return result

    @builtins.property
    def certificate(self) -> typing.Optional[builtins.str]:
        result = self._values.get("certificate")
        return result

    @builtins.property
    def certificate_password(self) -> typing.Optional[builtins.str]:
        result = self._values.get("certificate_password")
        return result

    @builtins.property
    def default_ssl_binding(self) -> typing.Optional[builtins.bool]:
        result = self._values.get("default_ssl_binding")
        return result

    @builtins.property
    def key_vault_id(self) -> typing.Optional[builtins.str]:
        result = self._values.get("key_vault_id")
        return result

    @builtins.property
    def negotiate_client_certificate(self) -> typing.Optional[builtins.bool]:
        result = self._values.get("negotiate_client_certificate")
        return result

    def __eq__(self, rhs: typing.Any) -> builtins.bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs: typing.Any) -> builtins.bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return "ApiManagementHostnameConfigurationProxy(%s)" % ", ".join(
            k + "=" + repr(v) for k, v in self._values.items()
        )


@jsii.data_type(
    jsii_type="@cdktf/provider-azurerm.ApiManagementHostnameConfigurationScm",
    jsii_struct_bases=[],
    name_mapping={
        "host_name": "hostName",
        "certificate": "certificate",
        "certificate_password": "certificatePassword",
        "key_vault_id": "keyVaultId",
        "negotiate_client_certificate": "negotiateClientCertificate",
    },
)
class ApiManagementHostnameConfigurationScm:
    def __init__(
        self,
        *,
        host_name: builtins.str,
        certificate: typing.Optional[builtins.str] = None,
        certificate_password: typing.Optional[builtins.str] = None,
        key_vault_id: typing.Optional[builtins.str] = None,
        negotiate_client_certificate: typing.Optional[builtins.bool] = None,
    ) -> None:
        """
        :param host_name: 
        :param certificate: 
        :param certificate_password: 
        :param key_vault_id: 
        :param negotiate_client_certificate: 
        """
        self._values: typing.Dict[str, typing.Any] = {
            "host_name": host_name,
        }
        if certificate is not None:
            self._values["certificate"] = certificate
        if certificate_password is not None:
            self._values["certificate_password"] = certificate_password
        if key_vault_id is not None:
            self._values["key_vault_id"] = key_vault_id
        if negotiate_client_certificate is not None:
            self._values["negotiate_client_certificate"] = negotiate_client_certificate

    @builtins.property
    def host_name(self) -> builtins.str:
        result = self._values.get("host_name")
        assert result is not None, "Required property 'host_name' is missing"
        return result

    @builtins.property
    def certificate(self) -> typing.Optional[builtins.str]:
        result = self._values.get("certificate")
        return result

    @builtins.property
    def certificate_password(self) -> typing.Optional[builtins.str]:
        result = self._values.get("certificate_password")
        return result

    @builtins.property
    def key_vault_id(self) -> typing.Optional[builtins.str]:
        result = self._values.get("key_vault_id")
        return result

    @builtins.property
    def negotiate_client_certificate(self) -> typing.Optional[builtins.bool]:
        result = self._values.get("negotiate_client_certificate")
        return result

    def __eq__(self, rhs: typing.Any) -> builtins.bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs: typing.Any) -> builtins.bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return "ApiManagementHostnameConfigurationScm(%s)" % ", ".join(
            k + "=" + repr(v) for k, v in self._values.items()
        )


@jsii.data_type(
    jsii_type="@cdktf/provider-azurerm.ApiManagementIdentity",
    jsii_struct_bases=[],
    name_mapping={"type": "type"},
)
class ApiManagementIdentity:
    def __init__(self, *, type: builtins.str) -> None:
        """
        :param type: 
        """
        self._values: typing.Dict[str, typing.Any] = {
            "type": type,
        }

    @builtins.property
    def type(self) -> builtins.str:
        result = self._values.get("type")
        assert result is not None, "Required property 'type' is missing"
        return result

    def __eq__(self, rhs: typing.Any) -> builtins.bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs: typing.Any) -> builtins.bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return "ApiManagementIdentity(%s)" % ", ".join(
            k + "=" + repr(v) for k, v in self._values.items()
        )


class ApiManagementIdentityProviderAad(
    cdktf.TerraformResource,
    metaclass=jsii.JSIIMeta,
    jsii_type="@cdktf/provider-azurerm.ApiManagementIdentityProviderAad",
):
    def __init__(
        self,
        scope: constructs.Construct,
        id: builtins.str,
        *,
        allowed_tenants: typing.List[builtins.str],
        api_management_name: builtins.str,
        client_id: builtins.str,
        client_secret: builtins.str,
        resource_group_name: builtins.str,
        timeouts: typing.Optional["ApiManagementIdentityProviderAadTimeouts"] = None,
        count: typing.Optional[jsii.Number] = None,
        depends_on: typing.Optional[typing.List[cdktf.TerraformResource]] = None,
        lifecycle: typing.Optional[cdktf.TerraformResourceLifecycle] = None,
        provider: typing.Optional[cdktf.TerraformProvider] = None,
    ) -> None:
        """
        :param scope: -
        :param id: -
        :param allowed_tenants: 
        :param api_management_name: 
        :param client_id: 
        :param client_secret: 
        :param resource_group_name: 
        :param timeouts: timeouts block.
        :param count: 
        :param depends_on: 
        :param lifecycle: 
        :param provider: 
        """
        config = ApiManagementIdentityProviderAadConfig(
            allowed_tenants=allowed_tenants,
            api_management_name=api_management_name,
            client_id=client_id,
            client_secret=client_secret,
            resource_group_name=resource_group_name,
            timeouts=timeouts,
            count=count,
            depends_on=depends_on,
            lifecycle=lifecycle,
            provider=provider,
        )

        jsii.create(ApiManagementIdentityProviderAad, self, [scope, id, config])

    @jsii.member(jsii_name="synthesizeAttributes")
    def _synthesize_attributes(self) -> typing.Mapping[builtins.str, typing.Any]:
        return jsii.invoke(self, "synthesizeAttributes", [])

    @builtins.property # type: ignore
    @jsii.member(jsii_name="allowedTenants")
    def allowed_tenants(self) -> typing.List[builtins.str]:
        return jsii.get(self, "allowedTenants")

    @allowed_tenants.setter # type: ignore
    def allowed_tenants(self, value: typing.List[builtins.str]) -> None:
        jsii.set(self, "allowedTenants", value)

    @builtins.property # type: ignore
    @jsii.member(jsii_name="apiManagementName")
    def api_management_name(self) -> builtins.str:
        return jsii.get(self, "apiManagementName")

    @api_management_name.setter # type: ignore
    def api_management_name(self, value: builtins.str) -> None:
        jsii.set(self, "apiManagementName", value)

    @builtins.property # type: ignore
    @jsii.member(jsii_name="clientId")
    def client_id(self) -> builtins.str:
        return jsii.get(self, "clientId")

    @client_id.setter # type: ignore
    def client_id(self, value: builtins.str) -> None:
        jsii.set(self, "clientId", value)

    @builtins.property # type: ignore
    @jsii.member(jsii_name="clientSecret")
    def client_secret(self) -> builtins.str:
        return jsii.get(self, "clientSecret")

    @client_secret.setter # type: ignore
    def client_secret(self, value: builtins.str) -> None:
        jsii.set(self, "clientSecret", value)

    @builtins.property # type: ignore
    @jsii.member(jsii_name="resourceGroupName")
    def resource_group_name(self) -> builtins.str:
        return jsii.get(self, "resourceGroupName")

    @resource_group_name.setter # type: ignore
    def resource_group_name(self, value: builtins.str) -> None:
        jsii.set(self, "resourceGroupName", value)

    @builtins.property # type: ignore
    @jsii.member(jsii_name="id")
    def id(self) -> typing.Optional[builtins.str]:
        return jsii.get(self, "id")

    @id.setter # type: ignore
    def id(self, value: typing.Optional[builtins.str]) -> None:
        jsii.set(self, "id", value)

    @builtins.property # type: ignore
    @jsii.member(jsii_name="timeouts")
    def timeouts(self) -> typing.Optional["ApiManagementIdentityProviderAadTimeouts"]:
        return jsii.get(self, "timeouts")

    @timeouts.setter # type: ignore
    def timeouts(
        self,
        value: typing.Optional["ApiManagementIdentityProviderAadTimeouts"],
    ) -> None:
        jsii.set(self, "timeouts", value)


@jsii.data_type(
    jsii_type="@cdktf/provider-azurerm.ApiManagementIdentityProviderAadConfig",
    jsii_struct_bases=[cdktf.TerraformMetaArguments],
    name_mapping={
        "count": "count",
        "depends_on": "dependsOn",
        "lifecycle": "lifecycle",
        "provider": "provider",
        "allowed_tenants": "allowedTenants",
        "api_management_name": "apiManagementName",
        "client_id": "clientId",
        "client_secret": "clientSecret",
        "resource_group_name": "resourceGroupName",
        "timeouts": "timeouts",
    },
)
class ApiManagementIdentityProviderAadConfig(cdktf.TerraformMetaArguments):
    def __init__(
        self,
        *,
        count: typing.Optional[jsii.Number] = None,
        depends_on: typing.Optional[typing.List[cdktf.TerraformResource]] = None,
        lifecycle: typing.Optional[cdktf.TerraformResourceLifecycle] = None,
        provider: typing.Optional[cdktf.TerraformProvider] = None,
        allowed_tenants: typing.List[builtins.str],
        api_management_name: builtins.str,
        client_id: builtins.str,
        client_secret: builtins.str,
        resource_group_name: builtins.str,
        timeouts: typing.Optional["ApiManagementIdentityProviderAadTimeouts"] = None,
    ) -> None:
        """
        :param count: 
        :param depends_on: 
        :param lifecycle: 
        :param provider: 
        :param allowed_tenants: 
        :param api_management_name: 
        :param client_id: 
        :param client_secret: 
        :param resource_group_name: 
        :param timeouts: timeouts block.
        """
        if isinstance(lifecycle, dict):
            lifecycle = cdktf.TerraformResourceLifecycle(**lifecycle)
        if isinstance(timeouts, dict):
            timeouts = ApiManagementIdentityProviderAadTimeouts(**timeouts)
        self._values: typing.Dict[str, typing.Any] = {
            "allowed_tenants": allowed_tenants,
            "api_management_name": api_management_name,
            "client_id": client_id,
            "client_secret": client_secret,
            "resource_group_name": resource_group_name,
        }
        if count is not None:
            self._values["count"] = count
        if depends_on is not None:
            self._values["depends_on"] = depends_on
        if lifecycle is not None:
            self._values["lifecycle"] = lifecycle
        if provider is not None:
            self._values["provider"] = provider
        if timeouts is not None:
            self._values["timeouts"] = timeouts

    @builtins.property
    def count(self) -> typing.Optional[jsii.Number]:
        """
        :stability: experimental
        """
        result = self._values.get("count")
        return result

    @builtins.property
    def depends_on(self) -> typing.Optional[typing.List[cdktf.TerraformResource]]:
        """
        :stability: experimental
        """
        result = self._values.get("depends_on")
        return result

    @builtins.property
    def lifecycle(self) -> typing.Optional[cdktf.TerraformResourceLifecycle]:
        """
        :stability: experimental
        """
        result = self._values.get("lifecycle")
        return result

    @builtins.property
    def provider(self) -> typing.Optional[cdktf.TerraformProvider]:
        """
        :stability: experimental
        """
        result = self._values.get("provider")
        return result

    @builtins.property
    def allowed_tenants(self) -> typing.List[builtins.str]:
        result = self._values.get("allowed_tenants")
        assert result is not None, "Required property 'allowed_tenants' is missing"
        return result

    @builtins.property
    def api_management_name(self) -> builtins.str:
        result = self._values.get("api_management_name")
        assert result is not None, "Required property 'api_management_name' is missing"
        return result

    @builtins.property
    def client_id(self) -> builtins.str:
        result = self._values.get("client_id")
        assert result is not None, "Required property 'client_id' is missing"
        return result

    @builtins.property
    def client_secret(self) -> builtins.str:
        result = self._values.get("client_secret")
        assert result is not None, "Required property 'client_secret' is missing"
        return result

    @builtins.property
    def resource_group_name(self) -> builtins.str:
        result = self._values.get("resource_group_name")
        assert result is not None, "Required property 'resource_group_name' is missing"
        return result

    @builtins.property
    def timeouts(self) -> typing.Optional["ApiManagementIdentityProviderAadTimeouts"]:
        """timeouts block."""
        result = self._values.get("timeouts")
        return result

    def __eq__(self, rhs: typing.Any) -> builtins.bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs: typing.Any) -> builtins.bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return "ApiManagementIdentityProviderAadConfig(%s)" % ", ".join(
            k + "=" + repr(v) for k, v in self._values.items()
        )


@jsii.data_type(
    jsii_type="@cdktf/provider-azurerm.ApiManagementIdentityProviderAadTimeouts",
    jsii_struct_bases=[],
    name_mapping={
        "create": "create",
        "delete": "delete",
        "read": "read",
        "update": "update",
    },
)
class ApiManagementIdentityProviderAadTimeouts:
    def __init__(
        self,
        *,
        create: typing.Optional[builtins.str] = None,
        delete: typing.Optional[builtins.str] = None,
        read: typing.Optional[builtins.str] = None,
        update: typing.Optional[builtins.str] = None,
    ) -> None:
        """
        :param create: 
        :param delete: 
        :param read: 
        :param update: 
        """
        self._values: typing.Dict[str, typing.Any] = {}
        if create is not None:
            self._values["create"] = create
        if delete is not None:
            self._values["delete"] = delete
        if read is not None:
            self._values["read"] = read
        if update is not None:
            self._values["update"] = update

    @builtins.property
    def create(self) -> typing.Optional[builtins.str]:
        result = self._values.get("create")
        return result

    @builtins.property
    def delete(self) -> typing.Optional[builtins.str]:
        result = self._values.get("delete")
        return result

    @builtins.property
    def read(self) -> typing.Optional[builtins.str]:
        result = self._values.get("read")
        return result

    @builtins.property
    def update(self) -> typing.Optional[builtins.str]:
        result = self._values.get("update")
        return result

    def __eq__(self, rhs: typing.Any) -> builtins.bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs: typing.Any) -> builtins.bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return "ApiManagementIdentityProviderAadTimeouts(%s)" % ", ".join(
            k + "=" + repr(v) for k, v in self._values.items()
        )


class ApiManagementIdentityProviderFacebook(
    cdktf.TerraformResource,
    metaclass=jsii.JSIIMeta,
    jsii_type="@cdktf/provider-azurerm.ApiManagementIdentityProviderFacebook",
):
    def __init__(
        self,
        scope: constructs.Construct,
        id: builtins.str,
        *,
        api_management_name: builtins.str,
        app_id: builtins.str,
        app_secret: builtins.str,
        resource_group_name: builtins.str,
        timeouts: typing.Optional["ApiManagementIdentityProviderFacebookTimeouts"] = None,
        count: typing.Optional[jsii.Number] = None,
        depends_on: typing.Optional[typing.List[cdktf.TerraformResource]] = None,
        lifecycle: typing.Optional[cdktf.TerraformResourceLifecycle] = None,
        provider: typing.Optional[cdktf.TerraformProvider] = None,
    ) -> None:
        """
        :param scope: -
        :param id: -
        :param api_management_name: 
        :param app_id: 
        :param app_secret: 
        :param resource_group_name: 
        :param timeouts: timeouts block.
        :param count: 
        :param depends_on: 
        :param lifecycle: 
        :param provider: 
        """
        config = ApiManagementIdentityProviderFacebookConfig(
            api_management_name=api_management_name,
            app_id=app_id,
            app_secret=app_secret,
            resource_group_name=resource_group_name,
            timeouts=timeouts,
            count=count,
            depends_on=depends_on,
            lifecycle=lifecycle,
            provider=provider,
        )

        jsii.create(ApiManagementIdentityProviderFacebook, self, [scope, id, config])

    @jsii.member(jsii_name="synthesizeAttributes")
    def _synthesize_attributes(self) -> typing.Mapping[builtins.str, typing.Any]:
        return jsii.invoke(self, "synthesizeAttributes", [])

    @builtins.property # type: ignore
    @jsii.member(jsii_name="apiManagementName")
    def api_management_name(self) -> builtins.str:
        return jsii.get(self, "apiManagementName")

    @api_management_name.setter # type: ignore
    def api_management_name(self, value: builtins.str) -> None:
        jsii.set(self, "apiManagementName", value)

    @builtins.property # type: ignore
    @jsii.member(jsii_name="appId")
    def app_id(self) -> builtins.str:
        return jsii.get(self, "appId")

    @app_id.setter # type: ignore
    def app_id(self, value: builtins.str) -> None:
        jsii.set(self, "appId", value)

    @builtins.property # type: ignore
    @jsii.member(jsii_name="appSecret")
    def app_secret(self) -> builtins.str:
        return jsii.get(self, "appSecret")

    @app_secret.setter # type: ignore
    def app_secret(self, value: builtins.str) -> None:
        jsii.set(self, "appSecret", value)

    @builtins.property # type: ignore
    @jsii.member(jsii_name="resourceGroupName")
    def resource_group_name(self) -> builtins.str:
        return jsii.get(self, "resourceGroupName")

    @resource_group_name.setter # type: ignore
    def resource_group_name(self, value: builtins.str) -> None:
        jsii.set(self, "resourceGroupName", value)

    @builtins.property # type: ignore
    @jsii.member(jsii_name="id")
    def id(self) -> typing.Optional[builtins.str]:
        return jsii.get(self, "id")

    @id.setter # type: ignore
    def id(self, value: typing.Optional[builtins.str]) -> None:
        jsii.set(self, "id", value)

    @builtins.property # type: ignore
    @jsii.member(jsii_name="timeouts")
    def timeouts(
        self,
    ) -> typing.Optional["ApiManagementIdentityProviderFacebookTimeouts"]:
        return jsii.get(self, "timeouts")

    @timeouts.setter # type: ignore
    def timeouts(
        self,
        value: typing.Optional["ApiManagementIdentityProviderFacebookTimeouts"],
    ) -> None:
        jsii.set(self, "timeouts", value)


@jsii.data_type(
    jsii_type="@cdktf/provider-azurerm.ApiManagementIdentityProviderFacebookConfig",
    jsii_struct_bases=[cdktf.TerraformMetaArguments],
    name_mapping={
        "count": "count",
        "depends_on": "dependsOn",
        "lifecycle": "lifecycle",
        "provider": "provider",
        "api_management_name": "apiManagementName",
        "app_id": "appId",
        "app_secret": "appSecret",
        "resource_group_name": "resourceGroupName",
        "timeouts": "timeouts",
    },
)
class ApiManagementIdentityProviderFacebookConfig(cdktf.TerraformMetaArguments):
    def __init__(
        self,
        *,
        count: typing.Optional[jsii.Number] = None,
        depends_on: typing.Optional[typing.List[cdktf.TerraformResource]] = None,
        lifecycle: typing.Optional[cdktf.TerraformResourceLifecycle] = None,
        provider: typing.Optional[cdktf.TerraformProvider] = None,
        api_management_name: builtins.str,
        app_id: builtins.str,
        app_secret: builtins.str,
        resource_group_name: builtins.str,
        timeouts: typing.Optional["ApiManagementIdentityProviderFacebookTimeouts"] = None,
    ) -> None:
        """
        :param count: 
        :param depends_on: 
        :param lifecycle: 
        :param provider: 
        :param api_management_name: 
        :param app_id: 
        :param app_secret: 
        :param resource_group_name: 
        :param timeouts: timeouts block.
        """
        if isinstance(lifecycle, dict):
            lifecycle = cdktf.TerraformResourceLifecycle(**lifecycle)
        if isinstance(timeouts, dict):
            timeouts = ApiManagementIdentityProviderFacebookTimeouts(**timeouts)
        self._values: typing.Dict[str, typing.Any] = {
            "api_management_name": api_management_name,
            "app_id": app_id,
            "app_secret": app_secret,
            "resource_group_name": resource_group_name,
        }
        if count is not None:
            self._values["count"] = count
        if depends_on is not None:
            self._values["depends_on"] = depends_on
        if lifecycle is not None:
            self._values["lifecycle"] = lifecycle
        if provider is not None:
            self._values["provider"] = provider
        if timeouts is not None:
            self._values["timeouts"] = timeouts

    @builtins.property
    def count(self) -> typing.Optional[jsii.Number]:
        """
        :stability: experimental
        """
        result = self._values.get("count")
        return result

    @builtins.property
    def depends_on(self) -> typing.Optional[typing.List[cdktf.TerraformResource]]:
        """
        :stability: experimental
        """
        result = self._values.get("depends_on")
        return result

    @builtins.property
    def lifecycle(self) -> typing.Optional[cdktf.TerraformResourceLifecycle]:
        """
        :stability: experimental
        """
        result = self._values.get("lifecycle")
        return result

    @builtins.property
    def provider(self) -> typing.Optional[cdktf.TerraformProvider]:
        """
        :stability: experimental
        """
        result = self._values.get("provider")
        return result

    @builtins.property
    def api_management_name(self) -> builtins.str:
        result = self._values.get("api_management_name")
        assert result is not None, "Required property 'api_management_name' is missing"
        return result

    @builtins.property
    def app_id(self) -> builtins.str:
        result = self._values.get("app_id")
        assert result is not None, "Required property 'app_id' is missing"
        return result

    @builtins.property
    def app_secret(self) -> builtins.str:
        result = self._values.get("app_secret")
        assert result is not None, "Required property 'app_secret' is missing"
        return result

    @builtins.property
    def resource_group_name(self) -> builtins.str:
        result = self._values.get("resource_group_name")
        assert result is not None, "Required property 'resource_group_name' is missing"
        return result

    @builtins.property
    def timeouts(
        self,
    ) -> typing.Optional["ApiManagementIdentityProviderFacebookTimeouts"]:
        """timeouts block."""
        result = self._values.get("timeouts")
        return result

    def __eq__(self, rhs: typing.Any) -> builtins.bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs: typing.Any) -> builtins.bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return "ApiManagementIdentityProviderFacebookConfig(%s)" % ", ".join(
            k + "=" + repr(v) for k, v in self._values.items()
        )


@jsii.data_type(
    jsii_type="@cdktf/provider-azurerm.ApiManagementIdentityProviderFacebookTimeouts",
    jsii_struct_bases=[],
    name_mapping={
        "create": "create",
        "delete": "delete",
        "read": "read",
        "update": "update",
    },
)
class ApiManagementIdentityProviderFacebookTimeouts:
    def __init__(
        self,
        *,
        create: typing.Optional[builtins.str] = None,
        delete: typing.Optional[builtins.str] = None,
        read: typing.Optional[builtins.str] = None,
        update: typing.Optional[builtins.str] = None,
    ) -> None:
        """
        :param create: 
        :param delete: 
        :param read: 
        :param update: 
        """
        self._values: typing.Dict[str, typing.Any] = {}
        if create is not None:
            self._values["create"] = create
        if delete is not None:
            self._values["delete"] = delete
        if read is not None:
            self._values["read"] = read
        if update is not None:
            self._values["update"] = update

    @builtins.property
    def create(self) -> typing.Optional[builtins.str]:
        result = self._values.get("create")
        return result

    @builtins.property
    def delete(self) -> typing.Optional[builtins.str]:
        result = self._values.get("delete")
        return result

    @builtins.property
    def read(self) -> typing.Optional[builtins.str]:
        result = self._values.get("read")
        return result

    @builtins.property
    def update(self) -> typing.Optional[builtins.str]:
        result = self._values.get("update")
        return result

    def __eq__(self, rhs: typing.Any) -> builtins.bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs: typing.Any) -> builtins.bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return "ApiManagementIdentityProviderFacebookTimeouts(%s)" % ", ".join(
            k + "=" + repr(v) for k, v in self._values.items()
        )


class ApiManagementIdentityProviderGoogle(
    cdktf.TerraformResource,
    metaclass=jsii.JSIIMeta,
    jsii_type="@cdktf/provider-azurerm.ApiManagementIdentityProviderGoogle",
):
    def __init__(
        self,
        scope: constructs.Construct,
        id: builtins.str,
        *,
        api_management_name: builtins.str,
        client_id: builtins.str,
        client_secret: builtins.str,
        resource_group_name: builtins.str,
        timeouts: typing.Optional["ApiManagementIdentityProviderGoogleTimeouts"] = None,
        count: typing.Optional[jsii.Number] = None,
        depends_on: typing.Optional[typing.List[cdktf.TerraformResource]] = None,
        lifecycle: typing.Optional[cdktf.TerraformResourceLifecycle] = None,
        provider: typing.Optional[cdktf.TerraformProvider] = None,
    ) -> None:
        """
        :param scope: -
        :param id: -
        :param api_management_name: 
        :param client_id: 
        :param client_secret: 
        :param resource_group_name: 
        :param timeouts: timeouts block.
        :param count: 
        :param depends_on: 
        :param lifecycle: 
        :param provider: 
        """
        config = ApiManagementIdentityProviderGoogleConfig(
            api_management_name=api_management_name,
            client_id=client_id,
            client_secret=client_secret,
            resource_group_name=resource_group_name,
            timeouts=timeouts,
            count=count,
            depends_on=depends_on,
            lifecycle=lifecycle,
            provider=provider,
        )

        jsii.create(ApiManagementIdentityProviderGoogle, self, [scope, id, config])

    @jsii.member(jsii_name="synthesizeAttributes")
    def _synthesize_attributes(self) -> typing.Mapping[builtins.str, typing.Any]:
        return jsii.invoke(self, "synthesizeAttributes", [])

    @builtins.property # type: ignore
    @jsii.member(jsii_name="apiManagementName")
    def api_management_name(self) -> builtins.str:
        return jsii.get(self, "apiManagementName")

    @api_management_name.setter # type: ignore
    def api_management_name(self, value: builtins.str) -> None:
        jsii.set(self, "apiManagementName", value)

    @builtins.property # type: ignore
    @jsii.member(jsii_name="clientId")
    def client_id(self) -> builtins.str:
        return jsii.get(self, "clientId")

    @client_id.setter # type: ignore
    def client_id(self, value: builtins.str) -> None:
        jsii.set(self, "clientId", value)

    @builtins.property # type: ignore
    @jsii.member(jsii_name="clientSecret")
    def client_secret(self) -> builtins.str:
        return jsii.get(self, "clientSecret")

    @client_secret.setter # type: ignore
    def client_secret(self, value: builtins.str) -> None:
        jsii.set(self, "clientSecret", value)

    @builtins.property # type: ignore
    @jsii.member(jsii_name="resourceGroupName")
    def resource_group_name(self) -> builtins.str:
        return jsii.get(self, "resourceGroupName")

    @resource_group_name.setter # type: ignore
    def resource_group_name(self, value: builtins.str) -> None:
        jsii.set(self, "resourceGroupName", value)

    @builtins.property # type: ignore
    @jsii.member(jsii_name="id")
    def id(self) -> typing.Optional[builtins.str]:
        return jsii.get(self, "id")

    @id.setter # type: ignore
    def id(self, value: typing.Optional[builtins.str]) -> None:
        jsii.set(self, "id", value)

    @builtins.property # type: ignore
    @jsii.member(jsii_name="timeouts")
    def timeouts(
        self,
    ) -> typing.Optional["ApiManagementIdentityProviderGoogleTimeouts"]:
        return jsii.get(self, "timeouts")

    @timeouts.setter # type: ignore
    def timeouts(
        self,
        value: typing.Optional["ApiManagementIdentityProviderGoogleTimeouts"],
    ) -> None:
        jsii.set(self, "timeouts", value)


@jsii.data_type(
    jsii_type="@cdktf/provider-azurerm.ApiManagementIdentityProviderGoogleConfig",
    jsii_struct_bases=[cdktf.TerraformMetaArguments],
    name_mapping={
        "count": "count",
        "depends_on": "dependsOn",
        "lifecycle": "lifecycle",
        "provider": "provider",
        "api_management_name": "apiManagementName",
        "client_id": "clientId",
        "client_secret": "clientSecret",
        "resource_group_name": "resourceGroupName",
        "timeouts": "timeouts",
    },
)
class ApiManagementIdentityProviderGoogleConfig(cdktf.TerraformMetaArguments):
    def __init__(
        self,
        *,
        count: typing.Optional[jsii.Number] = None,
        depends_on: typing.Optional[typing.List[cdktf.TerraformResource]] = None,
        lifecycle: typing.Optional[cdktf.TerraformResourceLifecycle] = None,
        provider: typing.Optional[cdktf.TerraformProvider] = None,
        api_management_name: builtins.str,
        client_id: builtins.str,
        client_secret: builtins.str,
        resource_group_name: builtins.str,
        timeouts: typing.Optional["ApiManagementIdentityProviderGoogleTimeouts"] = None,
    ) -> None:
        """
        :param count: 
        :param depends_on: 
        :param lifecycle: 
        :param provider: 
        :param api_management_name: 
        :param client_id: 
        :param client_secret: 
        :param resource_group_name: 
        :param timeouts: timeouts block.
        """
        if isinstance(lifecycle, dict):
            lifecycle = cdktf.TerraformResourceLifecycle(**lifecycle)
        if isinstance(timeouts, dict):
            timeouts = ApiManagementIdentityProviderGoogleTimeouts(**timeouts)
        self._values: typing.Dict[str, typing.Any] = {
            "api_management_name": api_management_name,
            "client_id": client_id,
            "client_secret": client_secret,
            "resource_group_name": resource_group_name,
        }
        if count is not None:
            self._values["count"] = count
        if depends_on is not None:
            self._values["depends_on"] = depends_on
        if lifecycle is not None:
            self._values["lifecycle"] = lifecycle
        if provider is not None:
            self._values["provider"] = provider
        if timeouts is not None:
            self._values["timeouts"] = timeouts

    @builtins.property
    def count(self) -> typing.Optional[jsii.Number]:
        """
        :stability: experimental
        """
        result = self._values.get("count")
        return result

    @builtins.property
    def depends_on(self) -> typing.Optional[typing.List[cdktf.TerraformResource]]:
        """
        :stability: experimental
        """
        result = self._values.get("depends_on")
        return result

    @builtins.property
    def lifecycle(self) -> typing.Optional[cdktf.TerraformResourceLifecycle]:
        """
        :stability: experimental
        """
        result = self._values.get("lifecycle")
        return result

    @builtins.property
    def provider(self) -> typing.Optional[cdktf.TerraformProvider]:
        """
        :stability: experimental
        """
        result = self._values.get("provider")
        return result

    @builtins.property
    def api_management_name(self) -> builtins.str:
        result = self._values.get("api_management_name")
        assert result is not None, "Required property 'api_management_name' is missing"
        return result

    @builtins.property
    def client_id(self) -> builtins.str:
        result = self._values.get("client_id")
        assert result is not None, "Required property 'client_id' is missing"
        return result

    @builtins.property
    def client_secret(self) -> builtins.str:
        result = self._values.get("client_secret")
        assert result is not None, "Required property 'client_secret' is missing"
        return result

    @builtins.property
    def resource_group_name(self) -> builtins.str:
        result = self._values.get("resource_group_name")
        assert result is not None, "Required property 'resource_group_name' is missing"
        return result

    @builtins.property
    def timeouts(
        self,
    ) -> typing.Optional["ApiManagementIdentityProviderGoogleTimeouts"]:
        """timeouts block."""
        result = self._values.get("timeouts")
        return result

    def __eq__(self, rhs: typing.Any) -> builtins.bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs: typing.Any) -> builtins.bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return "ApiManagementIdentityProviderGoogleConfig(%s)" % ", ".join(
            k + "=" + repr(v) for k, v in self._values.items()
        )


@jsii.data_type(
    jsii_type="@cdktf/provider-azurerm.ApiManagementIdentityProviderGoogleTimeouts",
    jsii_struct_bases=[],
    name_mapping={
        "create": "create",
        "delete": "delete",
        "read": "read",
        "update": "update",
    },
)
class ApiManagementIdentityProviderGoogleTimeouts:
    def __init__(
        self,
        *,
        create: typing.Optional[builtins.str] = None,
        delete: typing.Optional[builtins.str] = None,
        read: typing.Optional[builtins.str] = None,
        update: typing.Optional[builtins.str] = None,
    ) -> None:
        """
        :param create: 
        :param delete: 
        :param read: 
        :param update: 
        """
        self._values: typing.Dict[str, typing.Any] = {}
        if create is not None:
            self._values["create"] = create
        if delete is not None:
            self._values["delete"] = delete
        if read is not None:
            self._values["read"] = read
        if update is not None:
            self._values["update"] = update

    @builtins.property
    def create(self) -> typing.Optional[builtins.str]:
        result = self._values.get("create")
        return result

    @builtins.property
    def delete(self) -> typing.Optional[builtins.str]:
        result = self._values.get("delete")
        return result

    @builtins.property
    def read(self) -> typing.Optional[builtins.str]:
        result = self._values.get("read")
        return result

    @builtins.property
    def update(self) -> typing.Optional[builtins.str]:
        result = self._values.get("update")
        return result

    def __eq__(self, rhs: typing.Any) -> builtins.bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs: typing.Any) -> builtins.bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return "ApiManagementIdentityProviderGoogleTimeouts(%s)" % ", ".join(
            k + "=" + repr(v) for k, v in self._values.items()
        )


class ApiManagementIdentityProviderMicrosoft(
    cdktf.TerraformResource,
    metaclass=jsii.JSIIMeta,
    jsii_type="@cdktf/provider-azurerm.ApiManagementIdentityProviderMicrosoft",
):
    def __init__(
        self,
        scope: constructs.Construct,
        id: builtins.str,
        *,
        api_management_name: builtins.str,
        client_id: builtins.str,
        client_secret: builtins.str,
        resource_group_name: builtins.str,
        timeouts: typing.Optional["ApiManagementIdentityProviderMicrosoftTimeouts"] = None,
        count: typing.Optional[jsii.Number] = None,
        depends_on: typing.Optional[typing.List[cdktf.TerraformResource]] = None,
        lifecycle: typing.Optional[cdktf.TerraformResourceLifecycle] = None,
        provider: typing.Optional[cdktf.TerraformProvider] = None,
    ) -> None:
        """
        :param scope: -
        :param id: -
        :param api_management_name: 
        :param client_id: 
        :param client_secret: 
        :param resource_group_name: 
        :param timeouts: timeouts block.
        :param count: 
        :param depends_on: 
        :param lifecycle: 
        :param provider: 
        """
        config = ApiManagementIdentityProviderMicrosoftConfig(
            api_management_name=api_management_name,
            client_id=client_id,
            client_secret=client_secret,
            resource_group_name=resource_group_name,
            timeouts=timeouts,
            count=count,
            depends_on=depends_on,
            lifecycle=lifecycle,
            provider=provider,
        )

        jsii.create(ApiManagementIdentityProviderMicrosoft, self, [scope, id, config])

    @jsii.member(jsii_name="synthesizeAttributes")
    def _synthesize_attributes(self) -> typing.Mapping[builtins.str, typing.Any]:
        return jsii.invoke(self, "synthesizeAttributes", [])

    @builtins.property # type: ignore
    @jsii.member(jsii_name="apiManagementName")
    def api_management_name(self) -> builtins.str:
        return jsii.get(self, "apiManagementName")

    @api_management_name.setter # type: ignore
    def api_management_name(self, value: builtins.str) -> None:
        jsii.set(self, "apiManagementName", value)

    @builtins.property # type: ignore
    @jsii.member(jsii_name="clientId")
    def client_id(self) -> builtins.str:
        return jsii.get(self, "clientId")

    @client_id.setter # type: ignore
    def client_id(self, value: builtins.str) -> None:
        jsii.set(self, "clientId", value)

    @builtins.property # type: ignore
    @jsii.member(jsii_name="clientSecret")
    def client_secret(self) -> builtins.str:
        return jsii.get(self, "clientSecret")

    @client_secret.setter # type: ignore
    def client_secret(self, value: builtins.str) -> None:
        jsii.set(self, "clientSecret", value)

    @builtins.property # type: ignore
    @jsii.member(jsii_name="resourceGroupName")
    def resource_group_name(self) -> builtins.str:
        return jsii.get(self, "resourceGroupName")

    @resource_group_name.setter # type: ignore
    def resource_group_name(self, value: builtins.str) -> None:
        jsii.set(self, "resourceGroupName", value)

    @builtins.property # type: ignore
    @jsii.member(jsii_name="id")
    def id(self) -> typing.Optional[builtins.str]:
        return jsii.get(self, "id")

    @id.setter # type: ignore
    def id(self, value: typing.Optional[builtins.str]) -> None:
        jsii.set(self, "id", value)

    @builtins.property # type: ignore
    @jsii.member(jsii_name="timeouts")
    def timeouts(
        self,
    ) -> typing.Optional["ApiManagementIdentityProviderMicrosoftTimeouts"]:
        return jsii.get(self, "timeouts")

    @timeouts.setter # type: ignore
    def timeouts(
        self,
        value: typing.Optional["ApiManagementIdentityProviderMicrosoftTimeouts"],
    ) -> None:
        jsii.set(self, "timeouts", value)


@jsii.data_type(
    jsii_type="@cdktf/provider-azurerm.ApiManagementIdentityProviderMicrosoftConfig",
    jsii_struct_bases=[cdktf.TerraformMetaArguments],
    name_mapping={
        "count": "count",
        "depends_on": "dependsOn",
        "lifecycle": "lifecycle",
        "provider": "provider",
        "api_management_name": "apiManagementName",
        "client_id": "clientId",
        "client_secret": "clientSecret",
        "resource_group_name": "resourceGroupName",
        "timeouts": "timeouts",
    },
)
class ApiManagementIdentityProviderMicrosoftConfig(cdktf.TerraformMetaArguments):
    def __init__(
        self,
        *,
        count: typing.Optional[jsii.Number] = None,
        depends_on: typing.Optional[typing.List[cdktf.TerraformResource]] = None,
        lifecycle: typing.Optional[cdktf.TerraformResourceLifecycle] = None,
        provider: typing.Optional[cdktf.TerraformProvider] = None,
        api_management_name: builtins.str,
        client_id: builtins.str,
        client_secret: builtins.str,
        resource_group_name: builtins.str,
        timeouts: typing.Optional["ApiManagementIdentityProviderMicrosoftTimeouts"] = None,
    ) -> None:
        """
        :param count: 
        :param depends_on: 
        :param lifecycle: 
        :param provider: 
        :param api_management_name: 
        :param client_id: 
        :param client_secret: 
        :param resource_group_name: 
        :param timeouts: timeouts block.
        """
        if isinstance(lifecycle, dict):
            lifecycle = cdktf.TerraformResourceLifecycle(**lifecycle)
        if isinstance(timeouts, dict):
            timeouts = ApiManagementIdentityProviderMicrosoftTimeouts(**timeouts)
        self._values: typing.Dict[str, typing.Any] = {
            "api_management_name": api_management_name,
            "client_id": client_id,
            "client_secret": client_secret,
            "resource_group_name": resource_group_name,
        }
        if count is not None:
            self._values["count"] = count
        if depends_on is not None:
            self._values["depends_on"] = depends_on
        if lifecycle is not None:
            self._values["lifecycle"] = lifecycle
        if provider is not None:
            self._values["provider"] = provider
        if timeouts is not None:
            self._values["timeouts"] = timeouts

    @builtins.property
    def count(self) -> typing.Optional[jsii.Number]:
        """
        :stability: experimental
        """
        result = self._values.get("count")
        return result

    @builtins.property
    def depends_on(self) -> typing.Optional[typing.List[cdktf.TerraformResource]]:
        """
        :stability: experimental
        """
        result = self._values.get("depends_on")
        return result

    @builtins.property
    def lifecycle(self) -> typing.Optional[cdktf.TerraformResourceLifecycle]:
        """
        :stability: experimental
        """
        result = self._values.get("lifecycle")
        return result

    @builtins.property
    def provider(self) -> typing.Optional[cdktf.TerraformProvider]:
        """
        :stability: experimental
        """
        result = self._values.get("provider")
        return result

    @builtins.property
    def api_management_name(self) -> builtins.str:
        result = self._values.get("api_management_name")
        assert result is not None, "Required property 'api_management_name' is missing"
        return result

    @builtins.property
    def client_id(self) -> builtins.str:
        result = self._values.get("client_id")
        assert result is not None, "Required property 'client_id' is missing"
        return result

    @builtins.property
    def client_secret(self) -> builtins.str:
        result = self._values.get("client_secret")
        assert result is not None, "Required property 'client_secret' is missing"
        return result

    @builtins.property
    def resource_group_name(self) -> builtins.str:
        result = self._values.get("resource_group_name")
        assert result is not None, "Required property 'resource_group_name' is missing"
        return result

    @builtins.property
    def timeouts(
        self,
    ) -> typing.Optional["ApiManagementIdentityProviderMicrosoftTimeouts"]:
        """timeouts block."""
        result = self._values.get("timeouts")
        return result

    def __eq__(self, rhs: typing.Any) -> builtins.bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs: typing.Any) -> builtins.bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return "ApiManagementIdentityProviderMicrosoftConfig(%s)" % ", ".join(
            k + "=" + repr(v) for k, v in self._values.items()
        )


@jsii.data_type(
    jsii_type="@cdktf/provider-azurerm.ApiManagementIdentityProviderMicrosoftTimeouts",
    jsii_struct_bases=[],
    name_mapping={
        "create": "create",
        "delete": "delete",
        "read": "read",
        "update": "update",
    },
)
class ApiManagementIdentityProviderMicrosoftTimeouts:
    def __init__(
        self,
        *,
        create: typing.Optional[builtins.str] = None,
        delete: typing.Optional[builtins.str] = None,
        read: typing.Optional[builtins.str] = None,
        update: typing.Optional[builtins.str] = None,
    ) -> None:
        """
        :param create: 
        :param delete: 
        :param read: 
        :param update: 
        """
        self._values: typing.Dict[str, typing.Any] = {}
        if create is not None:
            self._values["create"] = create
        if delete is not None:
            self._values["delete"] = delete
        if read is not None:
            self._values["read"] = read
        if update is not None:
            self._values["update"] = update

    @builtins.property
    def create(self) -> typing.Optional[builtins.str]:
        result = self._values.get("create")
        return result

    @builtins.property
    def delete(self) -> typing.Optional[builtins.str]:
        result = self._values.get("delete")
        return result

    @builtins.property
    def read(self) -> typing.Optional[builtins.str]:
        result = self._values.get("read")
        return result

    @builtins.property
    def update(self) -> typing.Optional[builtins.str]:
        result = self._values.get("update")
        return result

    def __eq__(self, rhs: typing.Any) -> builtins.bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs: typing.Any) -> builtins.bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return "ApiManagementIdentityProviderMicrosoftTimeouts(%s)" % ", ".join(
            k + "=" + repr(v) for k, v in self._values.items()
        )


class ApiManagementIdentityProviderTwitter(
    cdktf.TerraformResource,
    metaclass=jsii.JSIIMeta,
    jsii_type="@cdktf/provider-azurerm.ApiManagementIdentityProviderTwitter",
):
    def __init__(
        self,
        scope: constructs.Construct,
        id: builtins.str,
        *,
        api_key: builtins.str,
        api_management_name: builtins.str,
        api_secret_key: builtins.str,
        resource_group_name: builtins.str,
        timeouts: typing.Optional["ApiManagementIdentityProviderTwitterTimeouts"] = None,
        count: typing.Optional[jsii.Number] = None,
        depends_on: typing.Optional[typing.List[cdktf.TerraformResource]] = None,
        lifecycle: typing.Optional[cdktf.TerraformResourceLifecycle] = None,
        provider: typing.Optional[cdktf.TerraformProvider] = None,
    ) -> None:
        """
        :param scope: -
        :param id: -
        :param api_key: 
        :param api_management_name: 
        :param api_secret_key: 
        :param resource_group_name: 
        :param timeouts: timeouts block.
        :param count: 
        :param depends_on: 
        :param lifecycle: 
        :param provider: 
        """
        config = ApiManagementIdentityProviderTwitterConfig(
            api_key=api_key,
            api_management_name=api_management_name,
            api_secret_key=api_secret_key,
            resource_group_name=resource_group_name,
            timeouts=timeouts,
            count=count,
            depends_on=depends_on,
            lifecycle=lifecycle,
            provider=provider,
        )

        jsii.create(ApiManagementIdentityProviderTwitter, self, [scope, id, config])

    @jsii.member(jsii_name="synthesizeAttributes")
    def _synthesize_attributes(self) -> typing.Mapping[builtins.str, typing.Any]:
        return jsii.invoke(self, "synthesizeAttributes", [])

    @builtins.property # type: ignore
    @jsii.member(jsii_name="apiKey")
    def api_key(self) -> builtins.str:
        return jsii.get(self, "apiKey")

    @api_key.setter # type: ignore
    def api_key(self, value: builtins.str) -> None:
        jsii.set(self, "apiKey", value)

    @builtins.property # type: ignore
    @jsii.member(jsii_name="apiManagementName")
    def api_management_name(self) -> builtins.str:
        return jsii.get(self, "apiManagementName")

    @api_management_name.setter # type: ignore
    def api_management_name(self, value: builtins.str) -> None:
        jsii.set(self, "apiManagementName", value)

    @builtins.property # type: ignore
    @jsii.member(jsii_name="apiSecretKey")
    def api_secret_key(self) -> builtins.str:
        return jsii.get(self, "apiSecretKey")

    @api_secret_key.setter # type: ignore
    def api_secret_key(self, value: builtins.str) -> None:
        jsii.set(self, "apiSecretKey", value)

    @builtins.property # type: ignore
    @jsii.member(jsii_name="resourceGroupName")
    def resource_group_name(self) -> builtins.str:
        return jsii.get(self, "resourceGroupName")

    @resource_group_name.setter # type: ignore
    def resource_group_name(self, value: builtins.str) -> None:
        jsii.set(self, "resourceGroupName", value)

    @builtins.property # type: ignore
    @jsii.member(jsii_name="id")
    def id(self) -> typing.Optional[builtins.str]:
        return jsii.get(self, "id")

    @id.setter # type: ignore
    def id(self, value: typing.Optional[builtins.str]) -> None:
        jsii.set(self, "id", value)

    @builtins.property # type: ignore
    @jsii.member(jsii_name="timeouts")
    def timeouts(
        self,
    ) -> typing.Optional["ApiManagementIdentityProviderTwitterTimeouts"]:
        return jsii.get(self, "timeouts")

    @timeouts.setter # type: ignore
    def timeouts(
        self,
        value: typing.Optional["ApiManagementIdentityProviderTwitterTimeouts"],
    ) -> None:
        jsii.set(self, "timeouts", value)


@jsii.data_type(
    jsii_type="@cdktf/provider-azurerm.ApiManagementIdentityProviderTwitterConfig",
    jsii_struct_bases=[cdktf.TerraformMetaArguments],
    name_mapping={
        "count": "count",
        "depends_on": "dependsOn",
        "lifecycle": "lifecycle",
        "provider": "provider",
        "api_key": "apiKey",
        "api_management_name": "apiManagementName",
        "api_secret_key": "apiSecretKey",
        "resource_group_name": "resourceGroupName",
        "timeouts": "timeouts",
    },
)
class ApiManagementIdentityProviderTwitterConfig(cdktf.TerraformMetaArguments):
    def __init__(
        self,
        *,
        count: typing.Optional[jsii.Number] = None,
        depends_on: typing.Optional[typing.List[cdktf.TerraformResource]] = None,
        lifecycle: typing.Optional[cdktf.TerraformResourceLifecycle] = None,
        provider: typing.Optional[cdktf.TerraformProvider] = None,
        api_key: builtins.str,
        api_management_name: builtins.str,
        api_secret_key: builtins.str,
        resource_group_name: builtins.str,
        timeouts: typing.Optional["ApiManagementIdentityProviderTwitterTimeouts"] = None,
    ) -> None:
        """
        :param count: 
        :param depends_on: 
        :param lifecycle: 
        :param provider: 
        :param api_key: 
        :param api_management_name: 
        :param api_secret_key: 
        :param resource_group_name: 
        :param timeouts: timeouts block.
        """
        if isinstance(lifecycle, dict):
            lifecycle = cdktf.TerraformResourceLifecycle(**lifecycle)
        if isinstance(timeouts, dict):
            timeouts = ApiManagementIdentityProviderTwitterTimeouts(**timeouts)
        self._values: typing.Dict[str, typing.Any] = {
            "api_key": api_key,
            "api_management_name": api_management_name,
            "api_secret_key": api_secret_key,
            "resource_group_name": resource_group_name,
        }
        if count is not None:
            self._values["count"] = count
        if depends_on is not None:
            self._values["depends_on"] = depends_on
        if lifecycle is not None:
            self._values["lifecycle"] = lifecycle
        if provider is not None:
            self._values["provider"] = provider
        if timeouts is not None:
            self._values["timeouts"] = timeouts

    @builtins.property
    def count(self) -> typing.Optional[jsii.Number]:
        """
        :stability: experimental
        """
        result = self._values.get("count")
        return result

    @builtins.property
    def depends_on(self) -> typing.Optional[typing.List[cdktf.TerraformResource]]:
        """
        :stability: experimental
        """
        result = self._values.get("depends_on")
        return result

    @builtins.property
    def lifecycle(self) -> typing.Optional[cdktf.TerraformResourceLifecycle]:
        """
        :stability: experimental
        """
        result = self._values.get("lifecycle")
        return result

    @builtins.property
    def provider(self) -> typing.Optional[cdktf.TerraformProvider]:
        """
        :stability: experimental
        """
        result = self._values.get("provider")
        return result

    @builtins.property
    def api_key(self) -> builtins.str:
        result = self._values.get("api_key")
        assert result is not None, "Required property 'api_key' is missing"
        return result

    @builtins.property
    def api_management_name(self) -> builtins.str:
        result = self._values.get("api_management_name")
        assert result is not None, "Required property 'api_management_name' is missing"
        return result

    @builtins.property
    def api_secret_key(self) -> builtins.str:
        result = self._values.get("api_secret_key")
        assert result is not None, "Required property 'api_secret_key' is missing"
        return result

    @builtins.property
    def resource_group_name(self) -> builtins.str:
        result = self._values.get("resource_group_name")
        assert result is not None, "Required property 'resource_group_name' is missing"
        return result

    @builtins.property
    def timeouts(
        self,
    ) -> typing.Optional["ApiManagementIdentityProviderTwitterTimeouts"]:
        """timeouts block."""
        result = self._values.get("timeouts")
        return result

    def __eq__(self, rhs: typing.Any) -> builtins.bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs: typing.Any) -> builtins.bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return "ApiManagementIdentityProviderTwitterConfig(%s)" % ", ".join(
            k + "=" + repr(v) for k, v in self._values.items()
        )


@jsii.data_type(
    jsii_type="@cdktf/provider-azurerm.ApiManagementIdentityProviderTwitterTimeouts",
    jsii_struct_bases=[],
    name_mapping={
        "create": "create",
        "delete": "delete",
        "read": "read",
        "update": "update",
    },
)
class ApiManagementIdentityProviderTwitterTimeouts:
    def __init__(
        self,
        *,
        create: typing.Optional[builtins.str] = None,
        delete: typing.Optional[builtins.str] = None,
        read: typing.Optional[builtins.str] = None,
        update: typing.Optional[builtins.str] = None,
    ) -> None:
        """
        :param create: 
        :param delete: 
        :param read: 
        :param update: 
        """
        self._values: typing.Dict[str, typing.Any] = {}
        if create is not None:
            self._values["create"] = create
        if delete is not None:
            self._values["delete"] = delete
        if read is not None:
            self._values["read"] = read
        if update is not None:
            self._values["update"] = update

    @builtins.property
    def create(self) -> typing.Optional[builtins.str]:
        result = self._values.get("create")
        return result

    @builtins.property
    def delete(self) -> typing.Optional[builtins.str]:
        result = self._values.get("delete")
        return result

    @builtins.property
    def read(self) -> typing.Optional[builtins.str]:
        result = self._values.get("read")
        return result

    @builtins.property
    def update(self) -> typing.Optional[builtins.str]:
        result = self._values.get("update")
        return result

    def __eq__(self, rhs: typing.Any) -> builtins.bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs: typing.Any) -> builtins.bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return "ApiManagementIdentityProviderTwitterTimeouts(%s)" % ", ".join(
            k + "=" + repr(v) for k, v in self._values.items()
        )


class ApiManagementLogger(
    cdktf.TerraformResource,
    metaclass=jsii.JSIIMeta,
    jsii_type="@cdktf/provider-azurerm.ApiManagementLogger",
):
    def __init__(
        self,
        scope: constructs.Construct,
        id: builtins.str,
        *,
        api_management_name: builtins.str,
        name: builtins.str,
        resource_group_name: builtins.str,
        application_insights: typing.Optional[typing.List["ApiManagementLoggerApplicationInsights"]] = None,
        buffered: typing.Optional[builtins.bool] = None,
        description: typing.Optional[builtins.str] = None,
        eventhub: typing.Optional[typing.List["ApiManagementLoggerEventhub"]] = None,
        timeouts: typing.Optional["ApiManagementLoggerTimeouts"] = None,
        count: typing.Optional[jsii.Number] = None,
        depends_on: typing.Optional[typing.List[cdktf.TerraformResource]] = None,
        lifecycle: typing.Optional[cdktf.TerraformResourceLifecycle] = None,
        provider: typing.Optional[cdktf.TerraformProvider] = None,
    ) -> None:
        """
        :param scope: -
        :param id: -
        :param api_management_name: 
        :param name: 
        :param resource_group_name: 
        :param application_insights: application_insights block.
        :param buffered: 
        :param description: 
        :param eventhub: eventhub block.
        :param timeouts: timeouts block.
        :param count: 
        :param depends_on: 
        :param lifecycle: 
        :param provider: 
        """
        config = ApiManagementLoggerConfig(
            api_management_name=api_management_name,
            name=name,
            resource_group_name=resource_group_name,
            application_insights=application_insights,
            buffered=buffered,
            description=description,
            eventhub=eventhub,
            timeouts=timeouts,
            count=count,
            depends_on=depends_on,
            lifecycle=lifecycle,
            provider=provider,
        )

        jsii.create(ApiManagementLogger, self, [scope, id, config])

    @jsii.member(jsii_name="synthesizeAttributes")
    def _synthesize_attributes(self) -> typing.Mapping[builtins.str, typing.Any]:
        return jsii.invoke(self, "synthesizeAttributes", [])

    @builtins.property # type: ignore
    @jsii.member(jsii_name="apiManagementName")
    def api_management_name(self) -> builtins.str:
        return jsii.get(self, "apiManagementName")

    @api_management_name.setter # type: ignore
    def api_management_name(self, value: builtins.str) -> None:
        jsii.set(self, "apiManagementName", value)

    @builtins.property # type: ignore
    @jsii.member(jsii_name="name")
    def name(self) -> builtins.str:
        return jsii.get(self, "name")

    @name.setter # type: ignore
    def name(self, value: builtins.str) -> None:
        jsii.set(self, "name", value)

    @builtins.property # type: ignore
    @jsii.member(jsii_name="resourceGroupName")
    def resource_group_name(self) -> builtins.str:
        return jsii.get(self, "resourceGroupName")

    @resource_group_name.setter # type: ignore
    def resource_group_name(self, value: builtins.str) -> None:
        jsii.set(self, "resourceGroupName", value)

    @builtins.property # type: ignore
    @jsii.member(jsii_name="applicationInsights")
    def application_insights(
        self,
    ) -> typing.Optional[typing.List["ApiManagementLoggerApplicationInsights"]]:
        return jsii.get(self, "applicationInsights")

    @application_insights.setter # type: ignore
    def application_insights(
        self,
        value: typing.Optional[typing.List["ApiManagementLoggerApplicationInsights"]],
    ) -> None:
        jsii.set(self, "applicationInsights", value)

    @builtins.property # type: ignore
    @jsii.member(jsii_name="buffered")
    def buffered(self) -> typing.Optional[builtins.bool]:
        return jsii.get(self, "buffered")

    @buffered.setter # type: ignore
    def buffered(self, value: typing.Optional[builtins.bool]) -> None:
        jsii.set(self, "buffered", value)

    @builtins.property # type: ignore
    @jsii.member(jsii_name="description")
    def description(self) -> typing.Optional[builtins.str]:
        return jsii.get(self, "description")

    @description.setter # type: ignore
    def description(self, value: typing.Optional[builtins.str]) -> None:
        jsii.set(self, "description", value)

    @builtins.property # type: ignore
    @jsii.member(jsii_name="eventhub")
    def eventhub(self) -> typing.Optional[typing.List["ApiManagementLoggerEventhub"]]:
        return jsii.get(self, "eventhub")

    @eventhub.setter # type: ignore
    def eventhub(
        self,
        value: typing.Optional[typing.List["ApiManagementLoggerEventhub"]],
    ) -> None:
        jsii.set(self, "eventhub", value)

    @builtins.property # type: ignore
    @jsii.member(jsii_name="id")
    def id(self) -> typing.Optional[builtins.str]:
        return jsii.get(self, "id")

    @id.setter # type: ignore
    def id(self, value: typing.Optional[builtins.str]) -> None:
        jsii.set(self, "id", value)

    @builtins.property # type: ignore
    @jsii.member(jsii_name="timeouts")
    def timeouts(self) -> typing.Optional["ApiManagementLoggerTimeouts"]:
        return jsii.get(self, "timeouts")

    @timeouts.setter # type: ignore
    def timeouts(self, value: typing.Optional["ApiManagementLoggerTimeouts"]) -> None:
        jsii.set(self, "timeouts", value)


@jsii.data_type(
    jsii_type="@cdktf/provider-azurerm.ApiManagementLoggerApplicationInsights",
    jsii_struct_bases=[],
    name_mapping={"instrumentation_key": "instrumentationKey"},
)
class ApiManagementLoggerApplicationInsights:
    def __init__(self, *, instrumentation_key: builtins.str) -> None:
        """
        :param instrumentation_key: 
        """
        self._values: typing.Dict[str, typing.Any] = {
            "instrumentation_key": instrumentation_key,
        }

    @builtins.property
    def instrumentation_key(self) -> builtins.str:
        result = self._values.get("instrumentation_key")
        assert result is not None, "Required property 'instrumentation_key' is missing"
        return result

    def __eq__(self, rhs: typing.Any) -> builtins.bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs: typing.Any) -> builtins.bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return "ApiManagementLoggerApplicationInsights(%s)" % ", ".join(
            k + "=" + repr(v) for k, v in self._values.items()
        )


@jsii.data_type(
    jsii_type="@cdktf/provider-azurerm.ApiManagementLoggerConfig",
    jsii_struct_bases=[cdktf.TerraformMetaArguments],
    name_mapping={
        "count": "count",
        "depends_on": "dependsOn",
        "lifecycle": "lifecycle",
        "provider": "provider",
        "api_management_name": "apiManagementName",
        "name": "name",
        "resource_group_name": "resourceGroupName",
        "application_insights": "applicationInsights",
        "buffered": "buffered",
        "description": "description",
        "eventhub": "eventhub",
        "timeouts": "timeouts",
    },
)
class ApiManagementLoggerConfig(cdktf.TerraformMetaArguments):
    def __init__(
        self,
        *,
        count: typing.Optional[jsii.Number] = None,
        depends_on: typing.Optional[typing.List[cdktf.TerraformResource]] = None,
        lifecycle: typing.Optional[cdktf.TerraformResourceLifecycle] = None,
        provider: typing.Optional[cdktf.TerraformProvider] = None,
        api_management_name: builtins.str,
        name: builtins.str,
        resource_group_name: builtins.str,
        application_insights: typing.Optional[typing.List[ApiManagementLoggerApplicationInsights]] = None,
        buffered: typing.Optional[builtins.bool] = None,
        description: typing.Optional[builtins.str] = None,
        eventhub: typing.Optional[typing.List["ApiManagementLoggerEventhub"]] = None,
        timeouts: typing.Optional["ApiManagementLoggerTimeouts"] = None,
    ) -> None:
        """
        :param count: 
        :param depends_on: 
        :param lifecycle: 
        :param provider: 
        :param api_management_name: 
        :param name: 
        :param resource_group_name: 
        :param application_insights: application_insights block.
        :param buffered: 
        :param description: 
        :param eventhub: eventhub block.
        :param timeouts: timeouts block.
        """
        if isinstance(lifecycle, dict):
            lifecycle = cdktf.TerraformResourceLifecycle(**lifecycle)
        if isinstance(timeouts, dict):
            timeouts = ApiManagementLoggerTimeouts(**timeouts)
        self._values: typing.Dict[str, typing.Any] = {
            "api_management_name": api_management_name,
            "name": name,
            "resource_group_name": resource_group_name,
        }
        if count is not None:
            self._values["count"] = count
        if depends_on is not None:
            self._values["depends_on"] = depends_on
        if lifecycle is not None:
            self._values["lifecycle"] = lifecycle
        if provider is not None:
            self._values["provider"] = provider
        if application_insights is not None:
            self._values["application_insights"] = application_insights
        if buffered is not None:
            self._values["buffered"] = buffered
        if description is not None:
            self._values["description"] = description
        if eventhub is not None:
            self._values["eventhub"] = eventhub
        if timeouts is not None:
            self._values["timeouts"] = timeouts

    @builtins.property
    def count(self) -> typing.Optional[jsii.Number]:
        """
        :stability: experimental
        """
        result = self._values.get("count")
        return result

    @builtins.property
    def depends_on(self) -> typing.Optional[typing.List[cdktf.TerraformResource]]:
        """
        :stability: experimental
        """
        result = self._values.get("depends_on")
        return result

    @builtins.property
    def lifecycle(self) -> typing.Optional[cdktf.TerraformResourceLifecycle]:
        """
        :stability: experimental
        """
        result = self._values.get("lifecycle")
        return result

    @builtins.property
    def provider(self) -> typing.Optional[cdktf.TerraformProvider]:
        """
        :stability: experimental
        """
        result = self._values.get("provider")
        return result

    @builtins.property
    def api_management_name(self) -> builtins.str:
        result = self._values.get("api_management_name")
        assert result is not None, "Required property 'api_management_name' is missing"
        return result

    @builtins.property
    def name(self) -> builtins.str:
        result = self._values.get("name")
        assert result is not None, "Required property 'name' is missing"
        return result

    @builtins.property
    def resource_group_name(self) -> builtins.str:
        result = self._values.get("resource_group_name")
        assert result is not None, "Required property 'resource_group_name' is missing"
        return result

    @builtins.property
    def application_insights(
        self,
    ) -> typing.Optional[typing.List[ApiManagementLoggerApplicationInsights]]:
        """application_insights block."""
        result = self._values.get("application_insights")
        return result

    @builtins.property
    def buffered(self) -> typing.Optional[builtins.bool]:
        result = self._values.get("buffered")
        return result

    @builtins.property
    def description(self) -> typing.Optional[builtins.str]:
        result = self._values.get("description")
        return result

    @builtins.property
    def eventhub(self) -> typing.Optional[typing.List["ApiManagementLoggerEventhub"]]:
        """eventhub block."""
        result = self._values.get("eventhub")
        return result

    @builtins.property
    def timeouts(self) -> typing.Optional["ApiManagementLoggerTimeouts"]:
        """timeouts block."""
        result = self._values.get("timeouts")
        return result

    def __eq__(self, rhs: typing.Any) -> builtins.bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs: typing.Any) -> builtins.bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return "ApiManagementLoggerConfig(%s)" % ", ".join(
            k + "=" + repr(v) for k, v in self._values.items()
        )


@jsii.data_type(
    jsii_type="@cdktf/provider-azurerm.ApiManagementLoggerEventhub",
    jsii_struct_bases=[],
    name_mapping={"connection_string": "connectionString", "name": "name"},
)
class ApiManagementLoggerEventhub:
    def __init__(self, *, connection_string: builtins.str, name: builtins.str) -> None:
        """
        :param connection_string: 
        :param name: 
        """
        self._values: typing.Dict[str, typing.Any] = {
            "connection_string": connection_string,
            "name": name,
        }

    @builtins.property
    def connection_string(self) -> builtins.str:
        result = self._values.get("connection_string")
        assert result is not None, "Required property 'connection_string' is missing"
        return result

    @builtins.property
    def name(self) -> builtins.str:
        result = self._values.get("name")
        assert result is not None, "Required property 'name' is missing"
        return result

    def __eq__(self, rhs: typing.Any) -> builtins.bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs: typing.Any) -> builtins.bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return "ApiManagementLoggerEventhub(%s)" % ", ".join(
            k + "=" + repr(v) for k, v in self._values.items()
        )


@jsii.data_type(
    jsii_type="@cdktf/provider-azurerm.ApiManagementLoggerTimeouts",
    jsii_struct_bases=[],
    name_mapping={
        "create": "create",
        "delete": "delete",
        "read": "read",
        "update": "update",
    },
)
class ApiManagementLoggerTimeouts:
    def __init__(
        self,
        *,
        create: typing.Optional[builtins.str] = None,
        delete: typing.Optional[builtins.str] = None,
        read: typing.Optional[builtins.str] = None,
        update: typing.Optional[builtins.str] = None,
    ) -> None:
        """
        :param create: 
        :param delete: 
        :param read: 
        :param update: 
        """
        self._values: typing.Dict[str, typing.Any] = {}
        if create is not None:
            self._values["create"] = create
        if delete is not None:
            self._values["delete"] = delete
        if read is not None:
            self._values["read"] = read
        if update is not None:
            self._values["update"] = update

    @builtins.property
    def create(self) -> typing.Optional[builtins.str]:
        result = self._values.get("create")
        return result

    @builtins.property
    def delete(self) -> typing.Optional[builtins.str]:
        result = self._values.get("delete")
        return result

    @builtins.property
    def read(self) -> typing.Optional[builtins.str]:
        result = self._values.get("read")
        return result

    @builtins.property
    def update(self) -> typing.Optional[builtins.str]:
        result = self._values.get("update")
        return result

    def __eq__(self, rhs: typing.Any) -> builtins.bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs: typing.Any) -> builtins.bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return "ApiManagementLoggerTimeouts(%s)" % ", ".join(
            k + "=" + repr(v) for k, v in self._values.items()
        )


class ApiManagementOpenidConnectProvider(
    cdktf.TerraformResource,
    metaclass=jsii.JSIIMeta,
    jsii_type="@cdktf/provider-azurerm.ApiManagementOpenidConnectProvider",
):
    def __init__(
        self,
        scope: constructs.Construct,
        id: builtins.str,
        *,
        api_management_name: builtins.str,
        client_id: builtins.str,
        client_secret: builtins.str,
        display_name: builtins.str,
        metadata_endpoint: builtins.str,
        name: builtins.str,
        resource_group_name: builtins.str,
        description: typing.Optional[builtins.str] = None,
        timeouts: typing.Optional["ApiManagementOpenidConnectProviderTimeouts"] = None,
        count: typing.Optional[jsii.Number] = None,
        depends_on: typing.Optional[typing.List[cdktf.TerraformResource]] = None,
        lifecycle: typing.Optional[cdktf.TerraformResourceLifecycle] = None,
        provider: typing.Optional[cdktf.TerraformProvider] = None,
    ) -> None:
        """
        :param scope: -
        :param id: -
        :param api_management_name: 
        :param client_id: 
        :param client_secret: 
        :param display_name: 
        :param metadata_endpoint: 
        :param name: 
        :param resource_group_name: 
        :param description: 
        :param timeouts: timeouts block.
        :param count: 
        :param depends_on: 
        :param lifecycle: 
        :param provider: 
        """
        config = ApiManagementOpenidConnectProviderConfig(
            api_management_name=api_management_name,
            client_id=client_id,
            client_secret=client_secret,
            display_name=display_name,
            metadata_endpoint=metadata_endpoint,
            name=name,
            resource_group_name=resource_group_name,
            description=description,
            timeouts=timeouts,
            count=count,
            depends_on=depends_on,
            lifecycle=lifecycle,
            provider=provider,
        )

        jsii.create(ApiManagementOpenidConnectProvider, self, [scope, id, config])

    @jsii.member(jsii_name="synthesizeAttributes")
    def _synthesize_attributes(self) -> typing.Mapping[builtins.str, typing.Any]:
        return jsii.invoke(self, "synthesizeAttributes", [])

    @builtins.property # type: ignore
    @jsii.member(jsii_name="apiManagementName")
    def api_management_name(self) -> builtins.str:
        return jsii.get(self, "apiManagementName")

    @api_management_name.setter # type: ignore
    def api_management_name(self, value: builtins.str) -> None:
        jsii.set(self, "apiManagementName", value)

    @builtins.property # type: ignore
    @jsii.member(jsii_name="clientId")
    def client_id(self) -> builtins.str:
        return jsii.get(self, "clientId")

    @client_id.setter # type: ignore
    def client_id(self, value: builtins.str) -> None:
        jsii.set(self, "clientId", value)

    @builtins.property # type: ignore
    @jsii.member(jsii_name="clientSecret")
    def client_secret(self) -> builtins.str:
        return jsii.get(self, "clientSecret")

    @client_secret.setter # type: ignore
    def client_secret(self, value: builtins.str) -> None:
        jsii.set(self, "clientSecret", value)

    @builtins.property # type: ignore
    @jsii.member(jsii_name="displayName")
    def display_name(self) -> builtins.str:
        return jsii.get(self, "displayName")

    @display_name.setter # type: ignore
    def display_name(self, value: builtins.str) -> None:
        jsii.set(self, "displayName", value)

    @builtins.property # type: ignore
    @jsii.member(jsii_name="metadataEndpoint")
    def metadata_endpoint(self) -> builtins.str:
        return jsii.get(self, "metadataEndpoint")

    @metadata_endpoint.setter # type: ignore
    def metadata_endpoint(self, value: builtins.str) -> None:
        jsii.set(self, "metadataEndpoint", value)

    @builtins.property # type: ignore
    @jsii.member(jsii_name="name")
    def name(self) -> builtins.str:
        return jsii.get(self, "name")

    @name.setter # type: ignore
    def name(self, value: builtins.str) -> None:
        jsii.set(self, "name", value)

    @builtins.property # type: ignore
    @jsii.member(jsii_name="resourceGroupName")
    def resource_group_name(self) -> builtins.str:
        return jsii.get(self, "resourceGroupName")

    @resource_group_name.setter # type: ignore
    def resource_group_name(self, value: builtins.str) -> None:
        jsii.set(self, "resourceGroupName", value)

    @builtins.property # type: ignore
    @jsii.member(jsii_name="description")
    def description(self) -> typing.Optional[builtins.str]:
        return jsii.get(self, "description")

    @description.setter # type: ignore
    def description(self, value: typing.Optional[builtins.str]) -> None:
        jsii.set(self, "description", value)

    @builtins.property # type: ignore
    @jsii.member(jsii_name="id")
    def id(self) -> typing.Optional[builtins.str]:
        return jsii.get(self, "id")

    @id.setter # type: ignore
    def id(self, value: typing.Optional[builtins.str]) -> None:
        jsii.set(self, "id", value)

    @builtins.property # type: ignore
    @jsii.member(jsii_name="timeouts")
    def timeouts(self) -> typing.Optional["ApiManagementOpenidConnectProviderTimeouts"]:
        return jsii.get(self, "timeouts")

    @timeouts.setter # type: ignore
    def timeouts(
        self,
        value: typing.Optional["ApiManagementOpenidConnectProviderTimeouts"],
    ) -> None:
        jsii.set(self, "timeouts", value)


@jsii.data_type(
    jsii_type="@cdktf/provider-azurerm.ApiManagementOpenidConnectProviderConfig",
    jsii_struct_bases=[cdktf.TerraformMetaArguments],
    name_mapping={
        "count": "count",
        "depends_on": "dependsOn",
        "lifecycle": "lifecycle",
        "provider": "provider",
        "api_management_name": "apiManagementName",
        "client_id": "clientId",
        "client_secret": "clientSecret",
        "display_name": "displayName",
        "metadata_endpoint": "metadataEndpoint",
        "name": "name",
        "resource_group_name": "resourceGroupName",
        "description": "description",
        "timeouts": "timeouts",
    },
)
class ApiManagementOpenidConnectProviderConfig(cdktf.TerraformMetaArguments):
    def __init__(
        self,
        *,
        count: typing.Optional[jsii.Number] = None,
        depends_on: typing.Optional[typing.List[cdktf.TerraformResource]] = None,
        lifecycle: typing.Optional[cdktf.TerraformResourceLifecycle] = None,
        provider: typing.Optional[cdktf.TerraformProvider] = None,
        api_management_name: builtins.str,
        client_id: builtins.str,
        client_secret: builtins.str,
        display_name: builtins.str,
        metadata_endpoint: builtins.str,
        name: builtins.str,
        resource_group_name: builtins.str,
        description: typing.Optional[builtins.str] = None,
        timeouts: typing.Optional["ApiManagementOpenidConnectProviderTimeouts"] = None,
    ) -> None:
        """
        :param count: 
        :param depends_on: 
        :param lifecycle: 
        :param provider: 
        :param api_management_name: 
        :param client_id: 
        :param client_secret: 
        :param display_name: 
        :param metadata_endpoint: 
        :param name: 
        :param resource_group_name: 
        :param description: 
        :param timeouts: timeouts block.
        """
        if isinstance(lifecycle, dict):
            lifecycle = cdktf.TerraformResourceLifecycle(**lifecycle)
        if isinstance(timeouts, dict):
            timeouts = ApiManagementOpenidConnectProviderTimeouts(**timeouts)
        self._values: typing.Dict[str, typing.Any] = {
            "api_management_name": api_management_name,
            "client_id": client_id,
            "client_secret": client_secret,
            "display_name": display_name,
            "metadata_endpoint": metadata_endpoint,
            "name": name,
            "resource_group_name": resource_group_name,
        }
        if count is not None:
            self._values["count"] = count
        if depends_on is not None:
            self._values["depends_on"] = depends_on
        if lifecycle is not None:
            self._values["lifecycle"] = lifecycle
        if provider is not None:
            self._values["provider"] = provider
        if description is not None:
            self._values["description"] = description
        if timeouts is not None:
            self._values["timeouts"] = timeouts

    @builtins.property
    def count(self) -> typing.Optional[jsii.Number]:
        """
        :stability: experimental
        """
        result = self._values.get("count")
        return result

    @builtins.property
    def depends_on(self) -> typing.Optional[typing.List[cdktf.TerraformResource]]:
        """
        :stability: experimental
        """
        result = self._values.get("depends_on")
        return result

    @builtins.property
    def lifecycle(self) -> typing.Optional[cdktf.TerraformResourceLifecycle]:
        """
        :stability: experimental
        """
        result = self._values.get("lifecycle")
        return result

    @builtins.property
    def provider(self) -> typing.Optional[cdktf.TerraformProvider]:
        """
        :stability: experimental
        """
        result = self._values.get("provider")
        return result

    @builtins.property
    def api_management_name(self) -> builtins.str:
        result = self._values.get("api_management_name")
        assert result is not None, "Required property 'api_management_name' is missing"
        return result

    @builtins.property
    def client_id(self) -> builtins.str:
        result = self._values.get("client_id")
        assert result is not None, "Required property 'client_id' is missing"
        return result

    @builtins.property
    def client_secret(self) -> builtins.str:
        result = self._values.get("client_secret")
        assert result is not None, "Required property 'client_secret' is missing"
        return result

    @builtins.property
    def display_name(self) -> builtins.str:
        result = self._values.get("display_name")
        assert result is not None, "Required property 'display_name' is missing"
        return result

    @builtins.property
    def metadata_endpoint(self) -> builtins.str:
        result = self._values.get("metadata_endpoint")
        assert result is not None, "Required property 'metadata_endpoint' is missing"
        return result

    @builtins.property
    def name(self) -> builtins.str:
        result = self._values.get("name")
        assert result is not None, "Required property 'name' is missing"
        return result

    @builtins.property
    def resource_group_name(self) -> builtins.str:
        result = self._values.get("resource_group_name")
        assert result is not None, "Required property 'resource_group_name' is missing"
        return result

    @builtins.property
    def description(self) -> typing.Optional[builtins.str]:
        result = self._values.get("description")
        return result

    @builtins.property
    def timeouts(self) -> typing.Optional["ApiManagementOpenidConnectProviderTimeouts"]:
        """timeouts block."""
        result = self._values.get("timeouts")
        return result

    def __eq__(self, rhs: typing.Any) -> builtins.bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs: typing.Any) -> builtins.bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return "ApiManagementOpenidConnectProviderConfig(%s)" % ", ".join(
            k + "=" + repr(v) for k, v in self._values.items()
        )


@jsii.data_type(
    jsii_type="@cdktf/provider-azurerm.ApiManagementOpenidConnectProviderTimeouts",
    jsii_struct_bases=[],
    name_mapping={
        "create": "create",
        "delete": "delete",
        "read": "read",
        "update": "update",
    },
)
class ApiManagementOpenidConnectProviderTimeouts:
    def __init__(
        self,
        *,
        create: typing.Optional[builtins.str] = None,
        delete: typing.Optional[builtins.str] = None,
        read: typing.Optional[builtins.str] = None,
        update: typing.Optional[builtins.str] = None,
    ) -> None:
        """
        :param create: 
        :param delete: 
        :param read: 
        :param update: 
        """
        self._values: typing.Dict[str, typing.Any] = {}
        if create is not None:
            self._values["create"] = create
        if delete is not None:
            self._values["delete"] = delete
        if read is not None:
            self._values["read"] = read
        if update is not None:
            self._values["update"] = update

    @builtins.property
    def create(self) -> typing.Optional[builtins.str]:
        result = self._values.get("create")
        return result

    @builtins.property
    def delete(self) -> typing.Optional[builtins.str]:
        result = self._values.get("delete")
        return result

    @builtins.property
    def read(self) -> typing.Optional[builtins.str]:
        result = self._values.get("read")
        return result

    @builtins.property
    def update(self) -> typing.Optional[builtins.str]:
        result = self._values.get("update")
        return result

    def __eq__(self, rhs: typing.Any) -> builtins.bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs: typing.Any) -> builtins.bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return "ApiManagementOpenidConnectProviderTimeouts(%s)" % ", ".join(
            k + "=" + repr(v) for k, v in self._values.items()
        )


@jsii.data_type(
    jsii_type="@cdktf/provider-azurerm.ApiManagementPolicy",
    jsii_struct_bases=[],
    name_mapping={"xml_content": "xmlContent", "xml_link": "xmlLink"},
)
class ApiManagementPolicy:
    def __init__(
        self,
        *,
        xml_content: typing.Optional[builtins.str] = None,
        xml_link: typing.Optional[builtins.str] = None,
    ) -> None:
        """
        :param xml_content: 
        :param xml_link: 
        """
        self._values: typing.Dict[str, typing.Any] = {}
        if xml_content is not None:
            self._values["xml_content"] = xml_content
        if xml_link is not None:
            self._values["xml_link"] = xml_link

    @builtins.property
    def xml_content(self) -> typing.Optional[builtins.str]:
        result = self._values.get("xml_content")
        return result

    @builtins.property
    def xml_link(self) -> typing.Optional[builtins.str]:
        result = self._values.get("xml_link")
        return result

    def __eq__(self, rhs: typing.Any) -> builtins.bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs: typing.Any) -> builtins.bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return "ApiManagementPolicy(%s)" % ", ".join(
            k + "=" + repr(v) for k, v in self._values.items()
        )


class ApiManagementProduct(
    cdktf.TerraformResource,
    metaclass=jsii.JSIIMeta,
    jsii_type="@cdktf/provider-azurerm.ApiManagementProduct",
):
    def __init__(
        self,
        scope: constructs.Construct,
        id: builtins.str,
        *,
        api_management_name: builtins.str,
        display_name: builtins.str,
        product_id: builtins.str,
        published: builtins.bool,
        resource_group_name: builtins.str,
        subscription_required: builtins.bool,
        approval_required: typing.Optional[builtins.bool] = None,
        description: typing.Optional[builtins.str] = None,
        subscriptions_limit: typing.Optional[jsii.Number] = None,
        terms: typing.Optional[builtins.str] = None,
        timeouts: typing.Optional["ApiManagementProductTimeouts"] = None,
        count: typing.Optional[jsii.Number] = None,
        depends_on: typing.Optional[typing.List[cdktf.TerraformResource]] = None,
        lifecycle: typing.Optional[cdktf.TerraformResourceLifecycle] = None,
        provider: typing.Optional[cdktf.TerraformProvider] = None,
    ) -> None:
        """
        :param scope: -
        :param id: -
        :param api_management_name: 
        :param display_name: 
        :param product_id: 
        :param published: 
        :param resource_group_name: 
        :param subscription_required: 
        :param approval_required: 
        :param description: 
        :param subscriptions_limit: 
        :param terms: 
        :param timeouts: timeouts block.
        :param count: 
        :param depends_on: 
        :param lifecycle: 
        :param provider: 
        """
        config = ApiManagementProductConfig(
            api_management_name=api_management_name,
            display_name=display_name,
            product_id=product_id,
            published=published,
            resource_group_name=resource_group_name,
            subscription_required=subscription_required,
            approval_required=approval_required,
            description=description,
            subscriptions_limit=subscriptions_limit,
            terms=terms,
            timeouts=timeouts,
            count=count,
            depends_on=depends_on,
            lifecycle=lifecycle,
            provider=provider,
        )

        jsii.create(ApiManagementProduct, self, [scope, id, config])

    @jsii.member(jsii_name="synthesizeAttributes")
    def _synthesize_attributes(self) -> typing.Mapping[builtins.str, typing.Any]:
        return jsii.invoke(self, "synthesizeAttributes", [])

    @builtins.property # type: ignore
    @jsii.member(jsii_name="apiManagementName")
    def api_management_name(self) -> builtins.str:
        return jsii.get(self, "apiManagementName")

    @api_management_name.setter # type: ignore
    def api_management_name(self, value: builtins.str) -> None:
        jsii.set(self, "apiManagementName", value)

    @builtins.property # type: ignore
    @jsii.member(jsii_name="displayName")
    def display_name(self) -> builtins.str:
        return jsii.get(self, "displayName")

    @display_name.setter # type: ignore
    def display_name(self, value: builtins.str) -> None:
        jsii.set(self, "displayName", value)

    @builtins.property # type: ignore
    @jsii.member(jsii_name="productId")
    def product_id(self) -> builtins.str:
        return jsii.get(self, "productId")

    @product_id.setter # type: ignore
    def product_id(self, value: builtins.str) -> None:
        jsii.set(self, "productId", value)

    @builtins.property # type: ignore
    @jsii.member(jsii_name="published")
    def published(self) -> builtins.bool:
        return jsii.get(self, "published")

    @published.setter # type: ignore
    def published(self, value: builtins.bool) -> None:
        jsii.set(self, "published", value)

    @builtins.property # type: ignore
    @jsii.member(jsii_name="resourceGroupName")
    def resource_group_name(self) -> builtins.str:
        return jsii.get(self, "resourceGroupName")

    @resource_group_name.setter # type: ignore
    def resource_group_name(self, value: builtins.str) -> None:
        jsii.set(self, "resourceGroupName", value)

    @builtins.property # type: ignore
    @jsii.member(jsii_name="subscriptionRequired")
    def subscription_required(self) -> builtins.bool:
        return jsii.get(self, "subscriptionRequired")

    @subscription_required.setter # type: ignore
    def subscription_required(self, value: builtins.bool) -> None:
        jsii.set(self, "subscriptionRequired", value)

    @builtins.property # type: ignore
    @jsii.member(jsii_name="approvalRequired")
    def approval_required(self) -> typing.Optional[builtins.bool]:
        return jsii.get(self, "approvalRequired")

    @approval_required.setter # type: ignore
    def approval_required(self, value: typing.Optional[builtins.bool]) -> None:
        jsii.set(self, "approvalRequired", value)

    @builtins.property # type: ignore
    @jsii.member(jsii_name="description")
    def description(self) -> typing.Optional[builtins.str]:
        return jsii.get(self, "description")

    @description.setter # type: ignore
    def description(self, value: typing.Optional[builtins.str]) -> None:
        jsii.set(self, "description", value)

    @builtins.property # type: ignore
    @jsii.member(jsii_name="id")
    def id(self) -> typing.Optional[builtins.str]:
        return jsii.get(self, "id")

    @id.setter # type: ignore
    def id(self, value: typing.Optional[builtins.str]) -> None:
        jsii.set(self, "id", value)

    @builtins.property # type: ignore
    @jsii.member(jsii_name="subscriptionsLimit")
    def subscriptions_limit(self) -> typing.Optional[jsii.Number]:
        return jsii.get(self, "subscriptionsLimit")

    @subscriptions_limit.setter # type: ignore
    def subscriptions_limit(self, value: typing.Optional[jsii.Number]) -> None:
        jsii.set(self, "subscriptionsLimit", value)

    @builtins.property # type: ignore
    @jsii.member(jsii_name="terms")
    def terms(self) -> typing.Optional[builtins.str]:
        return jsii.get(self, "terms")

    @terms.setter # type: ignore
    def terms(self, value: typing.Optional[builtins.str]) -> None:
        jsii.set(self, "terms", value)

    @builtins.property # type: ignore
    @jsii.member(jsii_name="timeouts")
    def timeouts(self) -> typing.Optional["ApiManagementProductTimeouts"]:
        return jsii.get(self, "timeouts")

    @timeouts.setter # type: ignore
    def timeouts(self, value: typing.Optional["ApiManagementProductTimeouts"]) -> None:
        jsii.set(self, "timeouts", value)


class ApiManagementProductApi(
    cdktf.TerraformResource,
    metaclass=jsii.JSIIMeta,
    jsii_type="@cdktf/provider-azurerm.ApiManagementProductApi",
):
    def __init__(
        self,
        scope: constructs.Construct,
        id: builtins.str,
        *,
        api_management_name: builtins.str,
        api_name: builtins.str,
        product_id: builtins.str,
        resource_group_name: builtins.str,
        timeouts: typing.Optional["ApiManagementProductApiTimeouts"] = None,
        count: typing.Optional[jsii.Number] = None,
        depends_on: typing.Optional[typing.List[cdktf.TerraformResource]] = None,
        lifecycle: typing.Optional[cdktf.TerraformResourceLifecycle] = None,
        provider: typing.Optional[cdktf.TerraformProvider] = None,
    ) -> None:
        """
        :param scope: -
        :param id: -
        :param api_management_name: 
        :param api_name: 
        :param product_id: 
        :param resource_group_name: 
        :param timeouts: timeouts block.
        :param count: 
        :param depends_on: 
        :param lifecycle: 
        :param provider: 
        """
        config = ApiManagementProductApiConfig(
            api_management_name=api_management_name,
            api_name=api_name,
            product_id=product_id,
            resource_group_name=resource_group_name,
            timeouts=timeouts,
            count=count,
            depends_on=depends_on,
            lifecycle=lifecycle,
            provider=provider,
        )

        jsii.create(ApiManagementProductApi, self, [scope, id, config])

    @jsii.member(jsii_name="synthesizeAttributes")
    def _synthesize_attributes(self) -> typing.Mapping[builtins.str, typing.Any]:
        return jsii.invoke(self, "synthesizeAttributes", [])

    @builtins.property # type: ignore
    @jsii.member(jsii_name="apiManagementName")
    def api_management_name(self) -> builtins.str:
        return jsii.get(self, "apiManagementName")

    @api_management_name.setter # type: ignore
    def api_management_name(self, value: builtins.str) -> None:
        jsii.set(self, "apiManagementName", value)

    @builtins.property # type: ignore
    @jsii.member(jsii_name="apiName")
    def api_name(self) -> builtins.str:
        return jsii.get(self, "apiName")

    @api_name.setter # type: ignore
    def api_name(self, value: builtins.str) -> None:
        jsii.set(self, "apiName", value)

    @builtins.property # type: ignore
    @jsii.member(jsii_name="productId")
    def product_id(self) -> builtins.str:
        return jsii.get(self, "productId")

    @product_id.setter # type: ignore
    def product_id(self, value: builtins.str) -> None:
        jsii.set(self, "productId", value)

    @builtins.property # type: ignore
    @jsii.member(jsii_name="resourceGroupName")
    def resource_group_name(self) -> builtins.str:
        return jsii.get(self, "resourceGroupName")

    @resource_group_name.setter # type: ignore
    def resource_group_name(self, value: builtins.str) -> None:
        jsii.set(self, "resourceGroupName", value)

    @builtins.property # type: ignore
    @jsii.member(jsii_name="id")
    def id(self) -> typing.Optional[builtins.str]:
        return jsii.get(self, "id")

    @id.setter # type: ignore
    def id(self, value: typing.Optional[builtins.str]) -> None:
        jsii.set(self, "id", value)

    @builtins.property # type: ignore
    @jsii.member(jsii_name="timeouts")
    def timeouts(self) -> typing.Optional["ApiManagementProductApiTimeouts"]:
        return jsii.get(self, "timeouts")

    @timeouts.setter # type: ignore
    def timeouts(
        self,
        value: typing.Optional["ApiManagementProductApiTimeouts"],
    ) -> None:
        jsii.set(self, "timeouts", value)


@jsii.data_type(
    jsii_type="@cdktf/provider-azurerm.ApiManagementProductApiConfig",
    jsii_struct_bases=[cdktf.TerraformMetaArguments],
    name_mapping={
        "count": "count",
        "depends_on": "dependsOn",
        "lifecycle": "lifecycle",
        "provider": "provider",
        "api_management_name": "apiManagementName",
        "api_name": "apiName",
        "product_id": "productId",
        "resource_group_name": "resourceGroupName",
        "timeouts": "timeouts",
    },
)
class ApiManagementProductApiConfig(cdktf.TerraformMetaArguments):
    def __init__(
        self,
        *,
        count: typing.Optional[jsii.Number] = None,
        depends_on: typing.Optional[typing.List[cdktf.TerraformResource]] = None,
        lifecycle: typing.Optional[cdktf.TerraformResourceLifecycle] = None,
        provider: typing.Optional[cdktf.TerraformProvider] = None,
        api_management_name: builtins.str,
        api_name: builtins.str,
        product_id: builtins.str,
        resource_group_name: builtins.str,
        timeouts: typing.Optional["ApiManagementProductApiTimeouts"] = None,
    ) -> None:
        """
        :param count: 
        :param depends_on: 
        :param lifecycle: 
        :param provider: 
        :param api_management_name: 
        :param api_name: 
        :param product_id: 
        :param resource_group_name: 
        :param timeouts: timeouts block.
        """
        if isinstance(lifecycle, dict):
            lifecycle = cdktf.TerraformResourceLifecycle(**lifecycle)
        if isinstance(timeouts, dict):
            timeouts = ApiManagementProductApiTimeouts(**timeouts)
        self._values: typing.Dict[str, typing.Any] = {
            "api_management_name": api_management_name,
            "api_name": api_name,
            "product_id": product_id,
            "resource_group_name": resource_group_name,
        }
        if count is not None:
            self._values["count"] = count
        if depends_on is not None:
            self._values["depends_on"] = depends_on
        if lifecycle is not None:
            self._values["lifecycle"] = lifecycle
        if provider is not None:
            self._values["provider"] = provider
        if timeouts is not None:
            self._values["timeouts"] = timeouts

    @builtins.property
    def count(self) -> typing.Optional[jsii.Number]:
        """
        :stability: experimental
        """
        result = self._values.get("count")
        return result

    @builtins.property
    def depends_on(self) -> typing.Optional[typing.List[cdktf.TerraformResource]]:
        """
        :stability: experimental
        """
        result = self._values.get("depends_on")
        return result

    @builtins.property
    def lifecycle(self) -> typing.Optional[cdktf.TerraformResourceLifecycle]:
        """
        :stability: experimental
        """
        result = self._values.get("lifecycle")
        return result

    @builtins.property
    def provider(self) -> typing.Optional[cdktf.TerraformProvider]:
        """
        :stability: experimental
        """
        result = self._values.get("provider")
        return result

    @builtins.property
    def api_management_name(self) -> builtins.str:
        result = self._values.get("api_management_name")
        assert result is not None, "Required property 'api_management_name' is missing"
        return result

    @builtins.property
    def api_name(self) -> builtins.str:
        result = self._values.get("api_name")
        assert result is not None, "Required property 'api_name' is missing"
        return result

    @builtins.property
    def product_id(self) -> builtins.str:
        result = self._values.get("product_id")
        assert result is not None, "Required property 'product_id' is missing"
        return result

    @builtins.property
    def resource_group_name(self) -> builtins.str:
        result = self._values.get("resource_group_name")
        assert result is not None, "Required property 'resource_group_name' is missing"
        return result

    @builtins.property
    def timeouts(self) -> typing.Optional["ApiManagementProductApiTimeouts"]:
        """timeouts block."""
        result = self._values.get("timeouts")
        return result

    def __eq__(self, rhs: typing.Any) -> builtins.bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs: typing.Any) -> builtins.bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return "ApiManagementProductApiConfig(%s)" % ", ".join(
            k + "=" + repr(v) for k, v in self._values.items()
        )


@jsii.data_type(
    jsii_type="@cdktf/provider-azurerm.ApiManagementProductApiTimeouts",
    jsii_struct_bases=[],
    name_mapping={
        "create": "create",
        "delete": "delete",
        "read": "read",
        "update": "update",
    },
)
class ApiManagementProductApiTimeouts:
    def __init__(
        self,
        *,
        create: typing.Optional[builtins.str] = None,
        delete: typing.Optional[builtins.str] = None,
        read: typing.Optional[builtins.str] = None,
        update: typing.Optional[builtins.str] = None,
    ) -> None:
        """
        :param create: 
        :param delete: 
        :param read: 
        :param update: 
        """
        self._values: typing.Dict[str, typing.Any] = {}
        if create is not None:
            self._values["create"] = create
        if delete is not None:
            self._values["delete"] = delete
        if read is not None:
            self._values["read"] = read
        if update is not None:
            self._values["update"] = update

    @builtins.property
    def create(self) -> typing.Optional[builtins.str]:
        result = self._values.get("create")
        return result

    @builtins.property
    def delete(self) -> typing.Optional[builtins.str]:
        result = self._values.get("delete")
        return result

    @builtins.property
    def read(self) -> typing.Optional[builtins.str]:
        result = self._values.get("read")
        return result

    @builtins.property
    def update(self) -> typing.Optional[builtins.str]:
        result = self._values.get("update")
        return result

    def __eq__(self, rhs: typing.Any) -> builtins.bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs: typing.Any) -> builtins.bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return "ApiManagementProductApiTimeouts(%s)" % ", ".join(
            k + "=" + repr(v) for k, v in self._values.items()
        )


@jsii.data_type(
    jsii_type="@cdktf/provider-azurerm.ApiManagementProductConfig",
    jsii_struct_bases=[cdktf.TerraformMetaArguments],
    name_mapping={
        "count": "count",
        "depends_on": "dependsOn",
        "lifecycle": "lifecycle",
        "provider": "provider",
        "api_management_name": "apiManagementName",
        "display_name": "displayName",
        "product_id": "productId",
        "published": "published",
        "resource_group_name": "resourceGroupName",
        "subscription_required": "subscriptionRequired",
        "approval_required": "approvalRequired",
        "description": "description",
        "subscriptions_limit": "subscriptionsLimit",
        "terms": "terms",
        "timeouts": "timeouts",
    },
)
class ApiManagementProductConfig(cdktf.TerraformMetaArguments):
    def __init__(
        self,
        *,
        count: typing.Optional[jsii.Number] = None,
        depends_on: typing.Optional[typing.List[cdktf.TerraformResource]] = None,
        lifecycle: typing.Optional[cdktf.TerraformResourceLifecycle] = None,
        provider: typing.Optional[cdktf.TerraformProvider] = None,
        api_management_name: builtins.str,
        display_name: builtins.str,
        product_id: builtins.str,
        published: builtins.bool,
        resource_group_name: builtins.str,
        subscription_required: builtins.bool,
        approval_required: typing.Optional[builtins.bool] = None,
        description: typing.Optional[builtins.str] = None,
        subscriptions_limit: typing.Optional[jsii.Number] = None,
        terms: typing.Optional[builtins.str] = None,
        timeouts: typing.Optional["ApiManagementProductTimeouts"] = None,
    ) -> None:
        """
        :param count: 
        :param depends_on: 
        :param lifecycle: 
        :param provider: 
        :param api_management_name: 
        :param display_name: 
        :param product_id: 
        :param published: 
        :param resource_group_name: 
        :param subscription_required: 
        :param approval_required: 
        :param description: 
        :param subscriptions_limit: 
        :param terms: 
        :param timeouts: timeouts block.
        """
        if isinstance(lifecycle, dict):
            lifecycle = cdktf.TerraformResourceLifecycle(**lifecycle)
        if isinstance(timeouts, dict):
            timeouts = ApiManagementProductTimeouts(**timeouts)
        self._values: typing.Dict[str, typing.Any] = {
            "api_management_name": api_management_name,
            "display_name": display_name,
            "product_id": product_id,
            "published": published,
            "resource_group_name": resource_group_name,
            "subscription_required": subscription_required,
        }
        if count is not None:
            self._values["count"] = count
        if depends_on is not None:
            self._values["depends_on"] = depends_on
        if lifecycle is not None:
            self._values["lifecycle"] = lifecycle
        if provider is not None:
            self._values["provider"] = provider
        if approval_required is not None:
            self._values["approval_required"] = approval_required
        if description is not None:
            self._values["description"] = description
        if subscriptions_limit is not None:
            self._values["subscriptions_limit"] = subscriptions_limit
        if terms is not None:
            self._values["terms"] = terms
        if timeouts is not None:
            self._values["timeouts"] = timeouts

    @builtins.property
    def count(self) -> typing.Optional[jsii.Number]:
        """
        :stability: experimental
        """
        result = self._values.get("count")
        return result

    @builtins.property
    def depends_on(self) -> typing.Optional[typing.List[cdktf.TerraformResource]]:
        """
        :stability: experimental
        """
        result = self._values.get("depends_on")
        return result

    @builtins.property
    def lifecycle(self) -> typing.Optional[cdktf.TerraformResourceLifecycle]:
        """
        :stability: experimental
        """
        result = self._values.get("lifecycle")
        return result

    @builtins.property
    def provider(self) -> typing.Optional[cdktf.TerraformProvider]:
        """
        :stability: experimental
        """
        result = self._values.get("provider")
        return result

    @builtins.property
    def api_management_name(self) -> builtins.str:
        result = self._values.get("api_management_name")
        assert result is not None, "Required property 'api_management_name' is missing"
        return result

    @builtins.property
    def display_name(self) -> builtins.str:
        result = self._values.get("display_name")
        assert result is not None, "Required property 'display_name' is missing"
        return result

    @builtins.property
    def product_id(self) -> builtins.str:
        result = self._values.get("product_id")
        assert result is not None, "Required property 'product_id' is missing"
        return result

    @builtins.property
    def published(self) -> builtins.bool:
        result = self._values.get("published")
        assert result is not None, "Required property 'published' is missing"
        return result

    @builtins.property
    def resource_group_name(self) -> builtins.str:
        result = self._values.get("resource_group_name")
        assert result is not None, "Required property 'resource_group_name' is missing"
        return result

    @builtins.property
    def subscription_required(self) -> builtins.bool:
        result = self._values.get("subscription_required")
        assert result is not None, "Required property 'subscription_required' is missing"
        return result

    @builtins.property
    def approval_required(self) -> typing.Optional[builtins.bool]:
        result = self._values.get("approval_required")
        return result

    @builtins.property
    def description(self) -> typing.Optional[builtins.str]:
        result = self._values.get("description")
        return result

    @builtins.property
    def subscriptions_limit(self) -> typing.Optional[jsii.Number]:
        result = self._values.get("subscriptions_limit")
        return result

    @builtins.property
    def terms(self) -> typing.Optional[builtins.str]:
        result = self._values.get("terms")
        return result

    @builtins.property
    def timeouts(self) -> typing.Optional["ApiManagementProductTimeouts"]:
        """timeouts block."""
        result = self._values.get("timeouts")
        return result

    def __eq__(self, rhs: typing.Any) -> builtins.bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs: typing.Any) -> builtins.bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return "ApiManagementProductConfig(%s)" % ", ".join(
            k + "=" + repr(v) for k, v in self._values.items()
        )


class ApiManagementProductGroup(
    cdktf.TerraformResource,
    metaclass=jsii.JSIIMeta,
    jsii_type="@cdktf/provider-azurerm.ApiManagementProductGroup",
):
    def __init__(
        self,
        scope: constructs.Construct,
        id: builtins.str,
        *,
        api_management_name: builtins.str,
        group_name: builtins.str,
        product_id: builtins.str,
        resource_group_name: builtins.str,
        timeouts: typing.Optional["ApiManagementProductGroupTimeouts"] = None,
        count: typing.Optional[jsii.Number] = None,
        depends_on: typing.Optional[typing.List[cdktf.TerraformResource]] = None,
        lifecycle: typing.Optional[cdktf.TerraformResourceLifecycle] = None,
        provider: typing.Optional[cdktf.TerraformProvider] = None,
    ) -> None:
        """
        :param scope: -
        :param id: -
        :param api_management_name: 
        :param group_name: 
        :param product_id: 
        :param resource_group_name: 
        :param timeouts: timeouts block.
        :param count: 
        :param depends_on: 
        :param lifecycle: 
        :param provider: 
        """
        config = ApiManagementProductGroupConfig(
            api_management_name=api_management_name,
            group_name=group_name,
            product_id=product_id,
            resource_group_name=resource_group_name,
            timeouts=timeouts,
            count=count,
            depends_on=depends_on,
            lifecycle=lifecycle,
            provider=provider,
        )

        jsii.create(ApiManagementProductGroup, self, [scope, id, config])

    @jsii.member(jsii_name="synthesizeAttributes")
    def _synthesize_attributes(self) -> typing.Mapping[builtins.str, typing.Any]:
        return jsii.invoke(self, "synthesizeAttributes", [])

    @builtins.property # type: ignore
    @jsii.member(jsii_name="apiManagementName")
    def api_management_name(self) -> builtins.str:
        return jsii.get(self, "apiManagementName")

    @api_management_name.setter # type: ignore
    def api_management_name(self, value: builtins.str) -> None:
        jsii.set(self, "apiManagementName", value)

    @builtins.property # type: ignore
    @jsii.member(jsii_name="groupName")
    def group_name(self) -> builtins.str:
        return jsii.get(self, "groupName")

    @group_name.setter # type: ignore
    def group_name(self, value: builtins.str) -> None:
        jsii.set(self, "groupName", value)

    @builtins.property # type: ignore
    @jsii.member(jsii_name="productId")
    def product_id(self) -> builtins.str:
        return jsii.get(self, "productId")

    @product_id.setter # type: ignore
    def product_id(self, value: builtins.str) -> None:
        jsii.set(self, "productId", value)

    @builtins.property # type: ignore
    @jsii.member(jsii_name="resourceGroupName")
    def resource_group_name(self) -> builtins.str:
        return jsii.get(self, "resourceGroupName")

    @resource_group_name.setter # type: ignore
    def resource_group_name(self, value: builtins.str) -> None:
        jsii.set(self, "resourceGroupName", value)

    @builtins.property # type: ignore
    @jsii.member(jsii_name="id")
    def id(self) -> typing.Optional[builtins.str]:
        return jsii.get(self, "id")

    @id.setter # type: ignore
    def id(self, value: typing.Optional[builtins.str]) -> None:
        jsii.set(self, "id", value)

    @builtins.property # type: ignore
    @jsii.member(jsii_name="timeouts")
    def timeouts(self) -> typing.Optional["ApiManagementProductGroupTimeouts"]:
        return jsii.get(self, "timeouts")

    @timeouts.setter # type: ignore
    def timeouts(
        self,
        value: typing.Optional["ApiManagementProductGroupTimeouts"],
    ) -> None:
        jsii.set(self, "timeouts", value)


@jsii.data_type(
    jsii_type="@cdktf/provider-azurerm.ApiManagementProductGroupConfig",
    jsii_struct_bases=[cdktf.TerraformMetaArguments],
    name_mapping={
        "count": "count",
        "depends_on": "dependsOn",
        "lifecycle": "lifecycle",
        "provider": "provider",
        "api_management_name": "apiManagementName",
        "group_name": "groupName",
        "product_id": "productId",
        "resource_group_name": "resourceGroupName",
        "timeouts": "timeouts",
    },
)
class ApiManagementProductGroupConfig(cdktf.TerraformMetaArguments):
    def __init__(
        self,
        *,
        count: typing.Optional[jsii.Number] = None,
        depends_on: typing.Optional[typing.List[cdktf.TerraformResource]] = None,
        lifecycle: typing.Optional[cdktf.TerraformResourceLifecycle] = None,
        provider: typing.Optional[cdktf.TerraformProvider] = None,
        api_management_name: builtins.str,
        group_name: builtins.str,
        product_id: builtins.str,
        resource_group_name: builtins.str,
        timeouts: typing.Optional["ApiManagementProductGroupTimeouts"] = None,
    ) -> None:
        """
        :param count: 
        :param depends_on: 
        :param lifecycle: 
        :param provider: 
        :param api_management_name: 
        :param group_name: 
        :param product_id: 
        :param resource_group_name: 
        :param timeouts: timeouts block.
        """
        if isinstance(lifecycle, dict):
            lifecycle = cdktf.TerraformResourceLifecycle(**lifecycle)
        if isinstance(timeouts, dict):
            timeouts = ApiManagementProductGroupTimeouts(**timeouts)
        self._values: typing.Dict[str, typing.Any] = {
            "api_management_name": api_management_name,
            "group_name": group_name,
            "product_id": product_id,
            "resource_group_name": resource_group_name,
        }
        if count is not None:
            self._values["count"] = count
        if depends_on is not None:
            self._values["depends_on"] = depends_on
        if lifecycle is not None:
            self._values["lifecycle"] = lifecycle
        if provider is not None:
            self._values["provider"] = provider
        if timeouts is not None:
            self._values["timeouts"] = timeouts

    @builtins.property
    def count(self) -> typing.Optional[jsii.Number]:
        """
        :stability: experimental
        """
        result = self._values.get("count")
        return result

    @builtins.property
    def depends_on(self) -> typing.Optional[typing.List[cdktf.TerraformResource]]:
        """
        :stability: experimental
        """
        result = self._values.get("depends_on")
        return result

    @builtins.property
    def lifecycle(self) -> typing.Optional[cdktf.TerraformResourceLifecycle]:
        """
        :stability: experimental
        """
        result = self._values.get("lifecycle")
        return result

    @builtins.property
    def provider(self) -> typing.Optional[cdktf.TerraformProvider]:
        """
        :stability: experimental
        """
        result = self._values.get("provider")
        return result

    @builtins.property
    def api_management_name(self) -> builtins.str:
        result = self._values.get("api_management_name")
        assert result is not None, "Required property 'api_management_name' is missing"
        return result

    @builtins.property
    def group_name(self) -> builtins.str:
        result = self._values.get("group_name")
        assert result is not None, "Required property 'group_name' is missing"
        return result

    @builtins.property
    def product_id(self) -> builtins.str:
        result = self._values.get("product_id")
        assert result is not None, "Required property 'product_id' is missing"
        return result

    @builtins.property
    def resource_group_name(self) -> builtins.str:
        result = self._values.get("resource_group_name")
        assert result is not None, "Required property 'resource_group_name' is missing"
        return result

    @builtins.property
    def timeouts(self) -> typing.Optional["ApiManagementProductGroupTimeouts"]:
        """timeouts block."""
        result = self._values.get("timeouts")
        return result

    def __eq__(self, rhs: typing.Any) -> builtins.bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs: typing.Any) -> builtins.bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return "ApiManagementProductGroupConfig(%s)" % ", ".join(
            k + "=" + repr(v) for k, v in self._values.items()
        )


@jsii.data_type(
    jsii_type="@cdktf/provider-azurerm.ApiManagementProductGroupTimeouts",
    jsii_struct_bases=[],
    name_mapping={
        "create": "create",
        "delete": "delete",
        "read": "read",
        "update": "update",
    },
)
class ApiManagementProductGroupTimeouts:
    def __init__(
        self,
        *,
        create: typing.Optional[builtins.str] = None,
        delete: typing.Optional[builtins.str] = None,
        read: typing.Optional[builtins.str] = None,
        update: typing.Optional[builtins.str] = None,
    ) -> None:
        """
        :param create: 
        :param delete: 
        :param read: 
        :param update: 
        """
        self._values: typing.Dict[str, typing.Any] = {}
        if create is not None:
            self._values["create"] = create
        if delete is not None:
            self._values["delete"] = delete
        if read is not None:
            self._values["read"] = read
        if update is not None:
            self._values["update"] = update

    @builtins.property
    def create(self) -> typing.Optional[builtins.str]:
        result = self._values.get("create")
        return result

    @builtins.property
    def delete(self) -> typing.Optional[builtins.str]:
        result = self._values.get("delete")
        return result

    @builtins.property
    def read(self) -> typing.Optional[builtins.str]:
        result = self._values.get("read")
        return result

    @builtins.property
    def update(self) -> typing.Optional[builtins.str]:
        result = self._values.get("update")
        return result

    def __eq__(self, rhs: typing.Any) -> builtins.bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs: typing.Any) -> builtins.bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return "ApiManagementProductGroupTimeouts(%s)" % ", ".join(
            k + "=" + repr(v) for k, v in self._values.items()
        )


class ApiManagementProductPolicy(
    cdktf.TerraformResource,
    metaclass=jsii.JSIIMeta,
    jsii_type="@cdktf/provider-azurerm.ApiManagementProductPolicy",
):
    def __init__(
        self,
        scope: constructs.Construct,
        id: builtins.str,
        *,
        api_management_name: builtins.str,
        product_id: builtins.str,
        resource_group_name: builtins.str,
        timeouts: typing.Optional["ApiManagementProductPolicyTimeouts"] = None,
        xml_content: typing.Optional[builtins.str] = None,
        xml_link: typing.Optional[builtins.str] = None,
        count: typing.Optional[jsii.Number] = None,
        depends_on: typing.Optional[typing.List[cdktf.TerraformResource]] = None,
        lifecycle: typing.Optional[cdktf.TerraformResourceLifecycle] = None,
        provider: typing.Optional[cdktf.TerraformProvider] = None,
    ) -> None:
        """
        :param scope: -
        :param id: -
        :param api_management_name: 
        :param product_id: 
        :param resource_group_name: 
        :param timeouts: timeouts block.
        :param xml_content: 
        :param xml_link: 
        :param count: 
        :param depends_on: 
        :param lifecycle: 
        :param provider: 
        """
        config = ApiManagementProductPolicyConfig(
            api_management_name=api_management_name,
            product_id=product_id,
            resource_group_name=resource_group_name,
            timeouts=timeouts,
            xml_content=xml_content,
            xml_link=xml_link,
            count=count,
            depends_on=depends_on,
            lifecycle=lifecycle,
            provider=provider,
        )

        jsii.create(ApiManagementProductPolicy, self, [scope, id, config])

    @jsii.member(jsii_name="synthesizeAttributes")
    def _synthesize_attributes(self) -> typing.Mapping[builtins.str, typing.Any]:
        return jsii.invoke(self, "synthesizeAttributes", [])

    @builtins.property # type: ignore
    @jsii.member(jsii_name="apiManagementName")
    def api_management_name(self) -> builtins.str:
        return jsii.get(self, "apiManagementName")

    @api_management_name.setter # type: ignore
    def api_management_name(self, value: builtins.str) -> None:
        jsii.set(self, "apiManagementName", value)

    @builtins.property # type: ignore
    @jsii.member(jsii_name="productId")
    def product_id(self) -> builtins.str:
        return jsii.get(self, "productId")

    @product_id.setter # type: ignore
    def product_id(self, value: builtins.str) -> None:
        jsii.set(self, "productId", value)

    @builtins.property # type: ignore
    @jsii.member(jsii_name="resourceGroupName")
    def resource_group_name(self) -> builtins.str:
        return jsii.get(self, "resourceGroupName")

    @resource_group_name.setter # type: ignore
    def resource_group_name(self, value: builtins.str) -> None:
        jsii.set(self, "resourceGroupName", value)

    @builtins.property # type: ignore
    @jsii.member(jsii_name="id")
    def id(self) -> typing.Optional[builtins.str]:
        return jsii.get(self, "id")

    @id.setter # type: ignore
    def id(self, value: typing.Optional[builtins.str]) -> None:
        jsii.set(self, "id", value)

    @builtins.property # type: ignore
    @jsii.member(jsii_name="timeouts")
    def timeouts(self) -> typing.Optional["ApiManagementProductPolicyTimeouts"]:
        return jsii.get(self, "timeouts")

    @timeouts.setter # type: ignore
    def timeouts(
        self,
        value: typing.Optional["ApiManagementProductPolicyTimeouts"],
    ) -> None:
        jsii.set(self, "timeouts", value)

    @builtins.property # type: ignore
    @jsii.member(jsii_name="xmlContent")
    def xml_content(self) -> typing.Optional[builtins.str]:
        return jsii.get(self, "xmlContent")

    @xml_content.setter # type: ignore
    def xml_content(self, value: typing.Optional[builtins.str]) -> None:
        jsii.set(self, "xmlContent", value)

    @builtins.property # type: ignore
    @jsii.member(jsii_name="xmlLink")
    def xml_link(self) -> typing.Optional[builtins.str]:
        return jsii.get(self, "xmlLink")

    @xml_link.setter # type: ignore
    def xml_link(self, value: typing.Optional[builtins.str]) -> None:
        jsii.set(self, "xmlLink", value)


@jsii.data_type(
    jsii_type="@cdktf/provider-azurerm.ApiManagementProductPolicyConfig",
    jsii_struct_bases=[cdktf.TerraformMetaArguments],
    name_mapping={
        "count": "count",
        "depends_on": "dependsOn",
        "lifecycle": "lifecycle",
        "provider": "provider",
        "api_management_name": "apiManagementName",
        "product_id": "productId",
        "resource_group_name": "resourceGroupName",
        "timeouts": "timeouts",
        "xml_content": "xmlContent",
        "xml_link": "xmlLink",
    },
)
class ApiManagementProductPolicyConfig(cdktf.TerraformMetaArguments):
    def __init__(
        self,
        *,
        count: typing.Optional[jsii.Number] = None,
        depends_on: typing.Optional[typing.List[cdktf.TerraformResource]] = None,
        lifecycle: typing.Optional[cdktf.TerraformResourceLifecycle] = None,
        provider: typing.Optional[cdktf.TerraformProvider] = None,
        api_management_name: builtins.str,
        product_id: builtins.str,
        resource_group_name: builtins.str,
        timeouts: typing.Optional["ApiManagementProductPolicyTimeouts"] = None,
        xml_content: typing.Optional[builtins.str] = None,
        xml_link: typing.Optional[builtins.str] = None,
    ) -> None:
        """
        :param count: 
        :param depends_on: 
        :param lifecycle: 
        :param provider: 
        :param api_management_name: 
        :param product_id: 
        :param resource_group_name: 
        :param timeouts: timeouts block.
        :param xml_content: 
        :param xml_link: 
        """
        if isinstance(lifecycle, dict):
            lifecycle = cdktf.TerraformResourceLifecycle(**lifecycle)
        if isinstance(timeouts, dict):
            timeouts = ApiManagementProductPolicyTimeouts(**timeouts)
        self._values: typing.Dict[str, typing.Any] = {
            "api_management_name": api_management_name,
            "product_id": product_id,
            "resource_group_name": resource_group_name,
        }
        if count is not None:
            self._values["count"] = count
        if depends_on is not None:
            self._values["depends_on"] = depends_on
        if lifecycle is not None:
            self._values["lifecycle"] = lifecycle
        if provider is not None:
            self._values["provider"] = provider
        if timeouts is not None:
            self._values["timeouts"] = timeouts
        if xml_content is not None:
            self._values["xml_content"] = xml_content
        if xml_link is not None:
            self._values["xml_link"] = xml_link

    @builtins.property
    def count(self) -> typing.Optional[jsii.Number]:
        """
        :stability: experimental
        """
        result = self._values.get("count")
        return result

    @builtins.property
    def depends_on(self) -> typing.Optional[typing.List[cdktf.TerraformResource]]:
        """
        :stability: experimental
        """
        result = self._values.get("depends_on")
        return result

    @builtins.property
    def lifecycle(self) -> typing.Optional[cdktf.TerraformResourceLifecycle]:
        """
        :stability: experimental
        """
        result = self._values.get("lifecycle")
        return result

    @builtins.property
    def provider(self) -> typing.Optional[cdktf.TerraformProvider]:
        """
        :stability: experimental
        """
        result = self._values.get("provider")
        return result

    @builtins.property
    def api_management_name(self) -> builtins.str:
        result = self._values.get("api_management_name")
        assert result is not None, "Required property 'api_management_name' is missing"
        return result

    @builtins.property
    def product_id(self) -> builtins.str:
        result = self._values.get("product_id")
        assert result is not None, "Required property 'product_id' is missing"
        return result

    @builtins.property
    def resource_group_name(self) -> builtins.str:
        result = self._values.get("resource_group_name")
        assert result is not None, "Required property 'resource_group_name' is missing"
        return result

    @builtins.property
    def timeouts(self) -> typing.Optional["ApiManagementProductPolicyTimeouts"]:
        """timeouts block."""
        result = self._values.get("timeouts")
        return result

    @builtins.property
    def xml_content(self) -> typing.Optional[builtins.str]:
        result = self._values.get("xml_content")
        return result

    @builtins.property
    def xml_link(self) -> typing.Optional[builtins.str]:
        result = self._values.get("xml_link")
        return result

    def __eq__(self, rhs: typing.Any) -> builtins.bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs: typing.Any) -> builtins.bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return "ApiManagementProductPolicyConfig(%s)" % ", ".join(
            k + "=" + repr(v) for k, v in self._values.items()
        )


@jsii.data_type(
    jsii_type="@cdktf/provider-azurerm.ApiManagementProductPolicyTimeouts",
    jsii_struct_bases=[],
    name_mapping={
        "create": "create",
        "delete": "delete",
        "read": "read",
        "update": "update",
    },
)
class ApiManagementProductPolicyTimeouts:
    def __init__(
        self,
        *,
        create: typing.Optional[builtins.str] = None,
        delete: typing.Optional[builtins.str] = None,
        read: typing.Optional[builtins.str] = None,
        update: typing.Optional[builtins.str] = None,
    ) -> None:
        """
        :param create: 
        :param delete: 
        :param read: 
        :param update: 
        """
        self._values: typing.Dict[str, typing.Any] = {}
        if create is not None:
            self._values["create"] = create
        if delete is not None:
            self._values["delete"] = delete
        if read is not None:
            self._values["read"] = read
        if update is not None:
            self._values["update"] = update

    @builtins.property
    def create(self) -> typing.Optional[builtins.str]:
        result = self._values.get("create")
        return result

    @builtins.property
    def delete(self) -> typing.Optional[builtins.str]:
        result = self._values.get("delete")
        return result

    @builtins.property
    def read(self) -> typing.Optional[builtins.str]:
        result = self._values.get("read")
        return result

    @builtins.property
    def update(self) -> typing.Optional[builtins.str]:
        result = self._values.get("update")
        return result

    def __eq__(self, rhs: typing.Any) -> builtins.bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs: typing.Any) -> builtins.bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return "ApiManagementProductPolicyTimeouts(%s)" % ", ".join(
            k + "=" + repr(v) for k, v in self._values.items()
        )


@jsii.data_type(
    jsii_type="@cdktf/provider-azurerm.ApiManagementProductTimeouts",
    jsii_struct_bases=[],
    name_mapping={
        "create": "create",
        "delete": "delete",
        "read": "read",
        "update": "update",
    },
)
class ApiManagementProductTimeouts:
    def __init__(
        self,
        *,
        create: typing.Optional[builtins.str] = None,
        delete: typing.Optional[builtins.str] = None,
        read: typing.Optional[builtins.str] = None,
        update: typing.Optional[builtins.str] = None,
    ) -> None:
        """
        :param create: 
        :param delete: 
        :param read: 
        :param update: 
        """
        self._values: typing.Dict[str, typing.Any] = {}
        if create is not None:
            self._values["create"] = create
        if delete is not None:
            self._values["delete"] = delete
        if read is not None:
            self._values["read"] = read
        if update is not None:
            self._values["update"] = update

    @builtins.property
    def create(self) -> typing.Optional[builtins.str]:
        result = self._values.get("create")
        return result

    @builtins.property
    def delete(self) -> typing.Optional[builtins.str]:
        result = self._values.get("delete")
        return result

    @builtins.property
    def read(self) -> typing.Optional[builtins.str]:
        result = self._values.get("read")
        return result

    @builtins.property
    def update(self) -> typing.Optional[builtins.str]:
        result = self._values.get("update")
        return result

    def __eq__(self, rhs: typing.Any) -> builtins.bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs: typing.Any) -> builtins.bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return "ApiManagementProductTimeouts(%s)" % ", ".join(
            k + "=" + repr(v) for k, v in self._values.items()
        )


class ApiManagementProperty(
    cdktf.TerraformResource,
    metaclass=jsii.JSIIMeta,
    jsii_type="@cdktf/provider-azurerm.ApiManagementProperty",
):
    def __init__(
        self,
        scope: constructs.Construct,
        id: builtins.str,
        *,
        api_management_name: builtins.str,
        display_name: builtins.str,
        name: builtins.str,
        resource_group_name: builtins.str,
        value: builtins.str,
        secret: typing.Optional[builtins.bool] = None,
        tags: typing.Optional[typing.List[builtins.str]] = None,
        timeouts: typing.Optional["ApiManagementPropertyTimeouts"] = None,
        count: typing.Optional[jsii.Number] = None,
        depends_on: typing.Optional[typing.List[cdktf.TerraformResource]] = None,
        lifecycle: typing.Optional[cdktf.TerraformResourceLifecycle] = None,
        provider: typing.Optional[cdktf.TerraformProvider] = None,
    ) -> None:
        """
        :param scope: -
        :param id: -
        :param api_management_name: 
        :param display_name: 
        :param name: 
        :param resource_group_name: 
        :param value: 
        :param secret: 
        :param tags: 
        :param timeouts: timeouts block.
        :param count: 
        :param depends_on: 
        :param lifecycle: 
        :param provider: 
        """
        config = ApiManagementPropertyConfig(
            api_management_name=api_management_name,
            display_name=display_name,
            name=name,
            resource_group_name=resource_group_name,
            value=value,
            secret=secret,
            tags=tags,
            timeouts=timeouts,
            count=count,
            depends_on=depends_on,
            lifecycle=lifecycle,
            provider=provider,
        )

        jsii.create(ApiManagementProperty, self, [scope, id, config])

    @jsii.member(jsii_name="synthesizeAttributes")
    def _synthesize_attributes(self) -> typing.Mapping[builtins.str, typing.Any]:
        return jsii.invoke(self, "synthesizeAttributes", [])

    @builtins.property # type: ignore
    @jsii.member(jsii_name="apiManagementName")
    def api_management_name(self) -> builtins.str:
        return jsii.get(self, "apiManagementName")

    @api_management_name.setter # type: ignore
    def api_management_name(self, value: builtins.str) -> None:
        jsii.set(self, "apiManagementName", value)

    @builtins.property # type: ignore
    @jsii.member(jsii_name="displayName")
    def display_name(self) -> builtins.str:
        return jsii.get(self, "displayName")

    @display_name.setter # type: ignore
    def display_name(self, value: builtins.str) -> None:
        jsii.set(self, "displayName", value)

    @builtins.property # type: ignore
    @jsii.member(jsii_name="name")
    def name(self) -> builtins.str:
        return jsii.get(self, "name")

    @name.setter # type: ignore
    def name(self, value: builtins.str) -> None:
        jsii.set(self, "name", value)

    @builtins.property # type: ignore
    @jsii.member(jsii_name="resourceGroupName")
    def resource_group_name(self) -> builtins.str:
        return jsii.get(self, "resourceGroupName")

    @resource_group_name.setter # type: ignore
    def resource_group_name(self, value: builtins.str) -> None:
        jsii.set(self, "resourceGroupName", value)

    @builtins.property # type: ignore
    @jsii.member(jsii_name="value")
    def value(self) -> builtins.str:
        return jsii.get(self, "value")

    @value.setter # type: ignore
    def value(self, value: builtins.str) -> None:
        jsii.set(self, "value", value)

    @builtins.property # type: ignore
    @jsii.member(jsii_name="id")
    def id(self) -> typing.Optional[builtins.str]:
        return jsii.get(self, "id")

    @id.setter # type: ignore
    def id(self, value: typing.Optional[builtins.str]) -> None:
        jsii.set(self, "id", value)

    @builtins.property # type: ignore
    @jsii.member(jsii_name="secret")
    def secret(self) -> typing.Optional[builtins.bool]:
        return jsii.get(self, "secret")

    @secret.setter # type: ignore
    def secret(self, value: typing.Optional[builtins.bool]) -> None:
        jsii.set(self, "secret", value)

    @builtins.property # type: ignore
    @jsii.member(jsii_name="tags")
    def tags(self) -> typing.Optional[typing.List[builtins.str]]:
        return jsii.get(self, "tags")

    @tags.setter # type: ignore
    def tags(self, value: typing.Optional[typing.List[builtins.str]]) -> None:
        jsii.set(self, "tags", value)

    @builtins.property # type: ignore
    @jsii.member(jsii_name="timeouts")
    def timeouts(self) -> typing.Optional["ApiManagementPropertyTimeouts"]:
        return jsii.get(self, "timeouts")

    @timeouts.setter # type: ignore
    def timeouts(self, value: typing.Optional["ApiManagementPropertyTimeouts"]) -> None:
        jsii.set(self, "timeouts", value)


@jsii.data_type(
    jsii_type="@cdktf/provider-azurerm.ApiManagementPropertyConfig",
    jsii_struct_bases=[cdktf.TerraformMetaArguments],
    name_mapping={
        "count": "count",
        "depends_on": "dependsOn",
        "lifecycle": "lifecycle",
        "provider": "provider",
        "api_management_name": "apiManagementName",
        "display_name": "displayName",
        "name": "name",
        "resource_group_name": "resourceGroupName",
        "value": "value",
        "secret": "secret",
        "tags": "tags",
        "timeouts": "timeouts",
    },
)
class ApiManagementPropertyConfig(cdktf.TerraformMetaArguments):
    def __init__(
        self,
        *,
        count: typing.Optional[jsii.Number] = None,
        depends_on: typing.Optional[typing.List[cdktf.TerraformResource]] = None,
        lifecycle: typing.Optional[cdktf.TerraformResourceLifecycle] = None,
        provider: typing.Optional[cdktf.TerraformProvider] = None,
        api_management_name: builtins.str,
        display_name: builtins.str,
        name: builtins.str,
        resource_group_name: builtins.str,
        value: builtins.str,
        secret: typing.Optional[builtins.bool] = None,
        tags: typing.Optional[typing.List[builtins.str]] = None,
        timeouts: typing.Optional["ApiManagementPropertyTimeouts"] = None,
    ) -> None:
        """
        :param count: 
        :param depends_on: 
        :param lifecycle: 
        :param provider: 
        :param api_management_name: 
        :param display_name: 
        :param name: 
        :param resource_group_name: 
        :param value: 
        :param secret: 
        :param tags: 
        :param timeouts: timeouts block.
        """
        if isinstance(lifecycle, dict):
            lifecycle = cdktf.TerraformResourceLifecycle(**lifecycle)
        if isinstance(timeouts, dict):
            timeouts = ApiManagementPropertyTimeouts(**timeouts)
        self._values: typing.Dict[str, typing.Any] = {
            "api_management_name": api_management_name,
            "display_name": display_name,
            "name": name,
            "resource_group_name": resource_group_name,
            "value": value,
        }
        if count is not None:
            self._values["count"] = count
        if depends_on is not None:
            self._values["depends_on"] = depends_on
        if lifecycle is not None:
            self._values["lifecycle"] = lifecycle
        if provider is not None:
            self._values["provider"] = provider
        if secret is not None:
            self._values["secret"] = secret
        if tags is not None:
            self._values["tags"] = tags
        if timeouts is not None:
            self._values["timeouts"] = timeouts

    @builtins.property
    def count(self) -> typing.Optional[jsii.Number]:
        """
        :stability: experimental
        """
        result = self._values.get("count")
        return result

    @builtins.property
    def depends_on(self) -> typing.Optional[typing.List[cdktf.TerraformResource]]:
        """
        :stability: experimental
        """
        result = self._values.get("depends_on")
        return result

    @builtins.property
    def lifecycle(self) -> typing.Optional[cdktf.TerraformResourceLifecycle]:
        """
        :stability: experimental
        """
        result = self._values.get("lifecycle")
        return result

    @builtins.property
    def provider(self) -> typing.Optional[cdktf.TerraformProvider]:
        """
        :stability: experimental
        """
        result = self._values.get("provider")
        return result

    @builtins.property
    def api_management_name(self) -> builtins.str:
        result = self._values.get("api_management_name")
        assert result is not None, "Required property 'api_management_name' is missing"
        return result

    @builtins.property
    def display_name(self) -> builtins.str:
        result = self._values.get("display_name")
        assert result is not None, "Required property 'display_name' is missing"
        return result

    @builtins.property
    def name(self) -> builtins.str:
        result = self._values.get("name")
        assert result is not None, "Required property 'name' is missing"
        return result

    @builtins.property
    def resource_group_name(self) -> builtins.str:
        result = self._values.get("resource_group_name")
        assert result is not None, "Required property 'resource_group_name' is missing"
        return result

    @builtins.property
    def value(self) -> builtins.str:
        result = self._values.get("value")
        assert result is not None, "Required property 'value' is missing"
        return result

    @builtins.property
    def secret(self) -> typing.Optional[builtins.bool]:
        result = self._values.get("secret")
        return result

    @builtins.property
    def tags(self) -> typing.Optional[typing.List[builtins.str]]:
        result = self._values.get("tags")
        return result

    @builtins.property
    def timeouts(self) -> typing.Optional["ApiManagementPropertyTimeouts"]:
        """timeouts block."""
        result = self._values.get("timeouts")
        return result

    def __eq__(self, rhs: typing.Any) -> builtins.bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs: typing.Any) -> builtins.bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return "ApiManagementPropertyConfig(%s)" % ", ".join(
            k + "=" + repr(v) for k, v in self._values.items()
        )


@jsii.data_type(
    jsii_type="@cdktf/provider-azurerm.ApiManagementPropertyTimeouts",
    jsii_struct_bases=[],
    name_mapping={
        "create": "create",
        "delete": "delete",
        "read": "read",
        "update": "update",
    },
)
class ApiManagementPropertyTimeouts:
    def __init__(
        self,
        *,
        create: typing.Optional[builtins.str] = None,
        delete: typing.Optional[builtins.str] = None,
        read: typing.Optional[builtins.str] = None,
        update: typing.Optional[builtins.str] = None,
    ) -> None:
        """
        :param create: 
        :param delete: 
        :param read: 
        :param update: 
        """
        self._values: typing.Dict[str, typing.Any] = {}
        if create is not None:
            self._values["create"] = create
        if delete is not None:
            self._values["delete"] = delete
        if read is not None:
            self._values["read"] = read
        if update is not None:
            self._values["update"] = update

    @builtins.property
    def create(self) -> typing.Optional[builtins.str]:
        result = self._values.get("create")
        return result

    @builtins.property
    def delete(self) -> typing.Optional[builtins.str]:
        result = self._values.get("delete")
        return result

    @builtins.property
    def read(self) -> typing.Optional[builtins.str]:
        result = self._values.get("read")
        return result

    @builtins.property
    def update(self) -> typing.Optional[builtins.str]:
        result = self._values.get("update")
        return result

    def __eq__(self, rhs: typing.Any) -> builtins.bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs: typing.Any) -> builtins.bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return "ApiManagementPropertyTimeouts(%s)" % ", ".join(
            k + "=" + repr(v) for k, v in self._values.items()
        )


@jsii.data_type(
    jsii_type="@cdktf/provider-azurerm.ApiManagementProtocols",
    jsii_struct_bases=[],
    name_mapping={"enable_http2": "enableHttp2"},
)
class ApiManagementProtocols:
    def __init__(self, *, enable_http2: typing.Optional[builtins.bool] = None) -> None:
        """
        :param enable_http2: 
        """
        self._values: typing.Dict[str, typing.Any] = {}
        if enable_http2 is not None:
            self._values["enable_http2"] = enable_http2

    @builtins.property
    def enable_http2(self) -> typing.Optional[builtins.bool]:
        result = self._values.get("enable_http2")
        return result

    def __eq__(self, rhs: typing.Any) -> builtins.bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs: typing.Any) -> builtins.bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return "ApiManagementProtocols(%s)" % ", ".join(
            k + "=" + repr(v) for k, v in self._values.items()
        )


@jsii.data_type(
    jsii_type="@cdktf/provider-azurerm.ApiManagementSecurity",
    jsii_struct_bases=[],
    name_mapping={
        "enable_backend_ssl30": "enableBackendSsl30",
        "enable_backend_tls10": "enableBackendTls10",
        "enable_backend_tls11": "enableBackendTls11",
        "enable_frontend_ssl30": "enableFrontendSsl30",
        "enable_frontend_tls10": "enableFrontendTls10",
        "enable_frontend_tls11": "enableFrontendTls11",
        "enable_triple_des_ciphers": "enableTripleDesCiphers",
    },
)
class ApiManagementSecurity:
    def __init__(
        self,
        *,
        enable_backend_ssl30: typing.Optional[builtins.bool] = None,
        enable_backend_tls10: typing.Optional[builtins.bool] = None,
        enable_backend_tls11: typing.Optional[builtins.bool] = None,
        enable_frontend_ssl30: typing.Optional[builtins.bool] = None,
        enable_frontend_tls10: typing.Optional[builtins.bool] = None,
        enable_frontend_tls11: typing.Optional[builtins.bool] = None,
        enable_triple_des_ciphers: typing.Optional[builtins.bool] = None,
    ) -> None:
        """
        :param enable_backend_ssl30: 
        :param enable_backend_tls10: 
        :param enable_backend_tls11: 
        :param enable_frontend_ssl30: 
        :param enable_frontend_tls10: 
        :param enable_frontend_tls11: 
        :param enable_triple_des_ciphers: 
        """
        self._values: typing.Dict[str, typing.Any] = {}
        if enable_backend_ssl30 is not None:
            self._values["enable_backend_ssl30"] = enable_backend_ssl30
        if enable_backend_tls10 is not None:
            self._values["enable_backend_tls10"] = enable_backend_tls10
        if enable_backend_tls11 is not None:
            self._values["enable_backend_tls11"] = enable_backend_tls11
        if enable_frontend_ssl30 is not None:
            self._values["enable_frontend_ssl30"] = enable_frontend_ssl30
        if enable_frontend_tls10 is not None:
            self._values["enable_frontend_tls10"] = enable_frontend_tls10
        if enable_frontend_tls11 is not None:
            self._values["enable_frontend_tls11"] = enable_frontend_tls11
        if enable_triple_des_ciphers is not None:
            self._values["enable_triple_des_ciphers"] = enable_triple_des_ciphers

    @builtins.property
    def enable_backend_ssl30(self) -> typing.Optional[builtins.bool]:
        result = self._values.get("enable_backend_ssl30")
        return result

    @builtins.property
    def enable_backend_tls10(self) -> typing.Optional[builtins.bool]:
        result = self._values.get("enable_backend_tls10")
        return result

    @builtins.property
    def enable_backend_tls11(self) -> typing.Optional[builtins.bool]:
        result = self._values.get("enable_backend_tls11")
        return result

    @builtins.property
    def enable_frontend_ssl30(self) -> typing.Optional[builtins.bool]:
        result = self._values.get("enable_frontend_ssl30")
        return result

    @builtins.property
    def enable_frontend_tls10(self) -> typing.Optional[builtins.bool]:
        result = self._values.get("enable_frontend_tls10")
        return result

    @builtins.property
    def enable_frontend_tls11(self) -> typing.Optional[builtins.bool]:
        result = self._values.get("enable_frontend_tls11")
        return result

    @builtins.property
    def enable_triple_des_ciphers(self) -> typing.Optional[builtins.bool]:
        result = self._values.get("enable_triple_des_ciphers")
        return result

    def __eq__(self, rhs: typing.Any) -> builtins.bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs: typing.Any) -> builtins.bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return "ApiManagementSecurity(%s)" % ", ".join(
            k + "=" + repr(v) for k, v in self._values.items()
        )


@jsii.data_type(
    jsii_type="@cdktf/provider-azurerm.ApiManagementSignIn",
    jsii_struct_bases=[],
    name_mapping={"enabled": "enabled"},
)
class ApiManagementSignIn:
    def __init__(self, *, enabled: builtins.bool) -> None:
        """
        :param enabled: 
        """
        self._values: typing.Dict[str, typing.Any] = {
            "enabled": enabled,
        }

    @builtins.property
    def enabled(self) -> builtins.bool:
        result = self._values.get("enabled")
        assert result is not None, "Required property 'enabled' is missing"
        return result

    def __eq__(self, rhs: typing.Any) -> builtins.bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs: typing.Any) -> builtins.bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return "ApiManagementSignIn(%s)" % ", ".join(
            k + "=" + repr(v) for k, v in self._values.items()
        )


@jsii.data_type(
    jsii_type="@cdktf/provider-azurerm.ApiManagementSignUp",
    jsii_struct_bases=[],
    name_mapping={"enabled": "enabled", "terms_of_service": "termsOfService"},
)
class ApiManagementSignUp:
    def __init__(
        self,
        *,
        enabled: builtins.bool,
        terms_of_service: typing.List["ApiManagementSignUpTermsOfService"],
    ) -> None:
        """
        :param enabled: 
        :param terms_of_service: terms_of_service block.
        """
        self._values: typing.Dict[str, typing.Any] = {
            "enabled": enabled,
            "terms_of_service": terms_of_service,
        }

    @builtins.property
    def enabled(self) -> builtins.bool:
        result = self._values.get("enabled")
        assert result is not None, "Required property 'enabled' is missing"
        return result

    @builtins.property
    def terms_of_service(self) -> typing.List["ApiManagementSignUpTermsOfService"]:
        """terms_of_service block."""
        result = self._values.get("terms_of_service")
        assert result is not None, "Required property 'terms_of_service' is missing"
        return result

    def __eq__(self, rhs: typing.Any) -> builtins.bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs: typing.Any) -> builtins.bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return "ApiManagementSignUp(%s)" % ", ".join(
            k + "=" + repr(v) for k, v in self._values.items()
        )


@jsii.data_type(
    jsii_type="@cdktf/provider-azurerm.ApiManagementSignUpTermsOfService",
    jsii_struct_bases=[],
    name_mapping={
        "consent_required": "consentRequired",
        "enabled": "enabled",
        "text": "text",
    },
)
class ApiManagementSignUpTermsOfService:
    def __init__(
        self,
        *,
        consent_required: builtins.bool,
        enabled: builtins.bool,
        text: typing.Optional[builtins.str] = None,
    ) -> None:
        """
        :param consent_required: 
        :param enabled: 
        :param text: 
        """
        self._values: typing.Dict[str, typing.Any] = {
            "consent_required": consent_required,
            "enabled": enabled,
        }
        if text is not None:
            self._values["text"] = text

    @builtins.property
    def consent_required(self) -> builtins.bool:
        result = self._values.get("consent_required")
        assert result is not None, "Required property 'consent_required' is missing"
        return result

    @builtins.property
    def enabled(self) -> builtins.bool:
        result = self._values.get("enabled")
        assert result is not None, "Required property 'enabled' is missing"
        return result

    @builtins.property
    def text(self) -> typing.Optional[builtins.str]:
        result = self._values.get("text")
        return result

    def __eq__(self, rhs: typing.Any) -> builtins.bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs: typing.Any) -> builtins.bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return "ApiManagementSignUpTermsOfService(%s)" % ", ".join(
            k + "=" + repr(v) for k, v in self._values.items()
        )


class ApiManagementSubscription(
    cdktf.TerraformResource,
    metaclass=jsii.JSIIMeta,
    jsii_type="@cdktf/provider-azurerm.ApiManagementSubscription",
):
    def __init__(
        self,
        scope: constructs.Construct,
        id: builtins.str,
        *,
        api_management_name: builtins.str,
        display_name: builtins.str,
        product_id: builtins.str,
        resource_group_name: builtins.str,
        user_id: builtins.str,
        primary_key: typing.Optional[builtins.str] = None,
        secondary_key: typing.Optional[builtins.str] = None,
        state: typing.Optional[builtins.str] = None,
        subscription_id: typing.Optional[builtins.str] = None,
        timeouts: typing.Optional["ApiManagementSubscriptionTimeouts"] = None,
        count: typing.Optional[jsii.Number] = None,
        depends_on: typing.Optional[typing.List[cdktf.TerraformResource]] = None,
        lifecycle: typing.Optional[cdktf.TerraformResourceLifecycle] = None,
        provider: typing.Optional[cdktf.TerraformProvider] = None,
    ) -> None:
        """
        :param scope: -
        :param id: -
        :param api_management_name: 
        :param display_name: 
        :param product_id: 
        :param resource_group_name: 
        :param user_id: 
        :param primary_key: 
        :param secondary_key: 
        :param state: 
        :param subscription_id: 
        :param timeouts: timeouts block.
        :param count: 
        :param depends_on: 
        :param lifecycle: 
        :param provider: 
        """
        config = ApiManagementSubscriptionConfig(
            api_management_name=api_management_name,
            display_name=display_name,
            product_id=product_id,
            resource_group_name=resource_group_name,
            user_id=user_id,
            primary_key=primary_key,
            secondary_key=secondary_key,
            state=state,
            subscription_id=subscription_id,
            timeouts=timeouts,
            count=count,
            depends_on=depends_on,
            lifecycle=lifecycle,
            provider=provider,
        )

        jsii.create(ApiManagementSubscription, self, [scope, id, config])

    @jsii.member(jsii_name="synthesizeAttributes")
    def _synthesize_attributes(self) -> typing.Mapping[builtins.str, typing.Any]:
        return jsii.invoke(self, "synthesizeAttributes", [])

    @builtins.property # type: ignore
    @jsii.member(jsii_name="apiManagementName")
    def api_management_name(self) -> builtins.str:
        return jsii.get(self, "apiManagementName")

    @api_management_name.setter # type: ignore
    def api_management_name(self, value: builtins.str) -> None:
        jsii.set(self, "apiManagementName", value)

    @builtins.property # type: ignore
    @jsii.member(jsii_name="displayName")
    def display_name(self) -> builtins.str:
        return jsii.get(self, "displayName")

    @display_name.setter # type: ignore
    def display_name(self, value: builtins.str) -> None:
        jsii.set(self, "displayName", value)

    @builtins.property # type: ignore
    @jsii.member(jsii_name="productId")
    def product_id(self) -> builtins.str:
        return jsii.get(self, "productId")

    @product_id.setter # type: ignore
    def product_id(self, value: builtins.str) -> None:
        jsii.set(self, "productId", value)

    @builtins.property # type: ignore
    @jsii.member(jsii_name="resourceGroupName")
    def resource_group_name(self) -> builtins.str:
        return jsii.get(self, "resourceGroupName")

    @resource_group_name.setter # type: ignore
    def resource_group_name(self, value: builtins.str) -> None:
        jsii.set(self, "resourceGroupName", value)

    @builtins.property # type: ignore
    @jsii.member(jsii_name="userId")
    def user_id(self) -> builtins.str:
        return jsii.get(self, "userId")

    @user_id.setter # type: ignore
    def user_id(self, value: builtins.str) -> None:
        jsii.set(self, "userId", value)

    @builtins.property # type: ignore
    @jsii.member(jsii_name="id")
    def id(self) -> typing.Optional[builtins.str]:
        return jsii.get(self, "id")

    @id.setter # type: ignore
    def id(self, value: typing.Optional[builtins.str]) -> None:
        jsii.set(self, "id", value)

    @builtins.property # type: ignore
    @jsii.member(jsii_name="primaryKey")
    def primary_key(self) -> typing.Optional[builtins.str]:
        return jsii.get(self, "primaryKey")

    @primary_key.setter # type: ignore
    def primary_key(self, value: typing.Optional[builtins.str]) -> None:
        jsii.set(self, "primaryKey", value)

    @builtins.property # type: ignore
    @jsii.member(jsii_name="secondaryKey")
    def secondary_key(self) -> typing.Optional[builtins.str]:
        return jsii.get(self, "secondaryKey")

    @secondary_key.setter # type: ignore
    def secondary_key(self, value: typing.Optional[builtins.str]) -> None:
        jsii.set(self, "secondaryKey", value)

    @builtins.property # type: ignore
    @jsii.member(jsii_name="state")
    def state(self) -> typing.Optional[builtins.str]:
        return jsii.get(self, "state")

    @state.setter # type: ignore
    def state(self, value: typing.Optional[builtins.str]) -> None:
        jsii.set(self, "state", value)

    @builtins.property # type: ignore
    @jsii.member(jsii_name="subscriptionId")
    def subscription_id(self) -> typing.Optional[builtins.str]:
        return jsii.get(self, "subscriptionId")

    @subscription_id.setter # type: ignore
    def subscription_id(self, value: typing.Optional[builtins.str]) -> None:
        jsii.set(self, "subscriptionId", value)

    @builtins.property # type: ignore
    @jsii.member(jsii_name="timeouts")
    def timeouts(self) -> typing.Optional["ApiManagementSubscriptionTimeouts"]:
        return jsii.get(self, "timeouts")

    @timeouts.setter # type: ignore
    def timeouts(
        self,
        value: typing.Optional["ApiManagementSubscriptionTimeouts"],
    ) -> None:
        jsii.set(self, "timeouts", value)


@jsii.data_type(
    jsii_type="@cdktf/provider-azurerm.ApiManagementSubscriptionConfig",
    jsii_struct_bases=[cdktf.TerraformMetaArguments],
    name_mapping={
        "count": "count",
        "depends_on": "dependsOn",
        "lifecycle": "lifecycle",
        "provider": "provider",
        "api_management_name": "apiManagementName",
        "display_name": "displayName",
        "product_id": "productId",
        "resource_group_name": "resourceGroupName",
        "user_id": "userId",
        "primary_key": "primaryKey",
        "secondary_key": "secondaryKey",
        "state": "state",
        "subscription_id": "subscriptionId",
        "timeouts": "timeouts",
    },
)
class ApiManagementSubscriptionConfig(cdktf.TerraformMetaArguments):
    def __init__(
        self,
        *,
        count: typing.Optional[jsii.Number] = None,
        depends_on: typing.Optional[typing.List[cdktf.TerraformResource]] = None,
        lifecycle: typing.Optional[cdktf.TerraformResourceLifecycle] = None,
        provider: typing.Optional[cdktf.TerraformProvider] = None,
        api_management_name: builtins.str,
        display_name: builtins.str,
        product_id: builtins.str,
        resource_group_name: builtins.str,
        user_id: builtins.str,
        primary_key: typing.Optional[builtins.str] = None,
        secondary_key: typing.Optional[builtins.str] = None,
        state: typing.Optional[builtins.str] = None,
        subscription_id: typing.Optional[builtins.str] = None,
        timeouts: typing.Optional["ApiManagementSubscriptionTimeouts"] = None,
    ) -> None:
        """
        :param count: 
        :param depends_on: 
        :param lifecycle: 
        :param provider: 
        :param api_management_name: 
        :param display_name: 
        :param product_id: 
        :param resource_group_name: 
        :param user_id: 
        :param primary_key: 
        :param secondary_key: 
        :param state: 
        :param subscription_id: 
        :param timeouts: timeouts block.
        """
        if isinstance(lifecycle, dict):
            lifecycle = cdktf.TerraformResourceLifecycle(**lifecycle)
        if isinstance(timeouts, dict):
            timeouts = ApiManagementSubscriptionTimeouts(**timeouts)
        self._values: typing.Dict[str, typing.Any] = {
            "api_management_name": api_management_name,
            "display_name": display_name,
            "product_id": product_id,
            "resource_group_name": resource_group_name,
            "user_id": user_id,
        }
        if count is not None:
            self._values["count"] = count
        if depends_on is not None:
            self._values["depends_on"] = depends_on
        if lifecycle is not None:
            self._values["lifecycle"] = lifecycle
        if provider is not None:
            self._values["provider"] = provider
        if primary_key is not None:
            self._values["primary_key"] = primary_key
        if secondary_key is not None:
            self._values["secondary_key"] = secondary_key
        if state is not None:
            self._values["state"] = state
        if subscription_id is not None:
            self._values["subscription_id"] = subscription_id
        if timeouts is not None:
            self._values["timeouts"] = timeouts

    @builtins.property
    def count(self) -> typing.Optional[jsii.Number]:
        """
        :stability: experimental
        """
        result = self._values.get("count")
        return result

    @builtins.property
    def depends_on(self) -> typing.Optional[typing.List[cdktf.TerraformResource]]:
        """
        :stability: experimental
        """
        result = self._values.get("depends_on")
        return result

    @builtins.property
    def lifecycle(self) -> typing.Optional[cdktf.TerraformResourceLifecycle]:
        """
        :stability: experimental
        """
        result = self._values.get("lifecycle")
        return result

    @builtins.property
    def provider(self) -> typing.Optional[cdktf.TerraformProvider]:
        """
        :stability: experimental
        """
        result = self._values.get("provider")
        return result

    @builtins.property
    def api_management_name(self) -> builtins.str:
        result = self._values.get("api_management_name")
        assert result is not None, "Required property 'api_management_name' is missing"
        return result

    @builtins.property
    def display_name(self) -> builtins.str:
        result = self._values.get("display_name")
        assert result is not None, "Required property 'display_name' is missing"
        return result

    @builtins.property
    def product_id(self) -> builtins.str:
        result = self._values.get("product_id")
        assert result is not None, "Required property 'product_id' is missing"
        return result

    @builtins.property
    def resource_group_name(self) -> builtins.str:
        result = self._values.get("resource_group_name")
        assert result is not None, "Required property 'resource_group_name' is missing"
        return result

    @builtins.property
    def user_id(self) -> builtins.str:
        result = self._values.get("user_id")
        assert result is not None, "Required property 'user_id' is missing"
        return result

    @builtins.property
    def primary_key(self) -> typing.Optional[builtins.str]:
        result = self._values.get("primary_key")
        return result

    @builtins.property
    def secondary_key(self) -> typing.Optional[builtins.str]:
        result = self._values.get("secondary_key")
        return result

    @builtins.property
    def state(self) -> typing.Optional[builtins.str]:
        result = self._values.get("state")
        return result

    @builtins.property
    def subscription_id(self) -> typing.Optional[builtins.str]:
        result = self._values.get("subscription_id")
        return result

    @builtins.property
    def timeouts(self) -> typing.Optional["ApiManagementSubscriptionTimeouts"]:
        """timeouts block."""
        result = self._values.get("timeouts")
        return result

    def __eq__(self, rhs: typing.Any) -> builtins.bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs: typing.Any) -> builtins.bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return "ApiManagementSubscriptionConfig(%s)" % ", ".join(
            k + "=" + repr(v) for k, v in self._values.items()
        )


@jsii.data_type(
    jsii_type="@cdktf/provider-azurerm.ApiManagementSubscriptionTimeouts",
    jsii_struct_bases=[],
    name_mapping={
        "create": "create",
        "delete": "delete",
        "read": "read",
        "update": "update",
    },
)
class ApiManagementSubscriptionTimeouts:
    def __init__(
        self,
        *,
        create: typing.Optional[builtins.str] = None,
        delete: typing.Optional[builtins.str] = None,
        read: typing.Optional[builtins.str] = None,
        update: typing.Optional[builtins.str] = None,
    ) -> None:
        """
        :param create: 
        :param delete: 
        :param read: 
        :param update: 
        """
        self._values: typing.Dict[str, typing.Any] = {}
        if create is not None:
            self._values["create"] = create
        if delete is not None:
            self._values["delete"] = delete
        if read is not None:
            self._values["read"] = read
        if update is not None:
            self._values["update"] = update

    @builtins.property
    def create(self) -> typing.Optional[builtins.str]:
        result = self._values.get("create")
        return result

    @builtins.property
    def delete(self) -> typing.Optional[builtins.str]:
        result = self._values.get("delete")
        return result

    @builtins.property
    def read(self) -> typing.Optional[builtins.str]:
        result = self._values.get("read")
        return result

    @builtins.property
    def update(self) -> typing.Optional[builtins.str]:
        result = self._values.get("update")
        return result

    def __eq__(self, rhs: typing.Any) -> builtins.bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs: typing.Any) -> builtins.bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return "ApiManagementSubscriptionTimeouts(%s)" % ", ".join(
            k + "=" + repr(v) for k, v in self._values.items()
        )


@jsii.data_type(
    jsii_type="@cdktf/provider-azurerm.ApiManagementTimeouts",
    jsii_struct_bases=[],
    name_mapping={
        "create": "create",
        "delete": "delete",
        "read": "read",
        "update": "update",
    },
)
class ApiManagementTimeouts:
    def __init__(
        self,
        *,
        create: typing.Optional[builtins.str] = None,
        delete: typing.Optional[builtins.str] = None,
        read: typing.Optional[builtins.str] = None,
        update: typing.Optional[builtins.str] = None,
    ) -> None:
        """
        :param create: 
        :param delete: 
        :param read: 
        :param update: 
        """
        self._values: typing.Dict[str, typing.Any] = {}
        if create is not None:
            self._values["create"] = create
        if delete is not None:
            self._values["delete"] = delete
        if read is not None:
            self._values["read"] = read
        if update is not None:
            self._values["update"] = update

    @builtins.property
    def create(self) -> typing.Optional[builtins.str]:
        result = self._values.get("create")
        return result

    @builtins.property
    def delete(self) -> typing.Optional[builtins.str]:
        result = self._values.get("delete")
        return result

    @builtins.property
    def read(self) -> typing.Optional[builtins.str]:
        result = self._values.get("read")
        return result

    @builtins.property
    def update(self) -> typing.Optional[builtins.str]:
        result = self._values.get("update")
        return result

    def __eq__(self, rhs: typing.Any) -> builtins.bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs: typing.Any) -> builtins.bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return "ApiManagementTimeouts(%s)" % ", ".join(
            k + "=" + repr(v) for k, v in self._values.items()
        )


class ApiManagementUser(
    cdktf.TerraformResource,
    metaclass=jsii.JSIIMeta,
    jsii_type="@cdktf/provider-azurerm.ApiManagementUser",
):
    def __init__(
        self,
        scope: constructs.Construct,
        id: builtins.str,
        *,
        api_management_name: builtins.str,
        email: builtins.str,
        first_name: builtins.str,
        last_name: builtins.str,
        resource_group_name: builtins.str,
        user_id: builtins.str,
        confirmation: typing.Optional[builtins.str] = None,
        note: typing.Optional[builtins.str] = None,
        password: typing.Optional[builtins.str] = None,
        state: typing.Optional[builtins.str] = None,
        timeouts: typing.Optional["ApiManagementUserTimeouts"] = None,
        count: typing.Optional[jsii.Number] = None,
        depends_on: typing.Optional[typing.List[cdktf.TerraformResource]] = None,
        lifecycle: typing.Optional[cdktf.TerraformResourceLifecycle] = None,
        provider: typing.Optional[cdktf.TerraformProvider] = None,
    ) -> None:
        """
        :param scope: -
        :param id: -
        :param api_management_name: 
        :param email: 
        :param first_name: 
        :param last_name: 
        :param resource_group_name: 
        :param user_id: 
        :param confirmation: 
        :param note: 
        :param password: 
        :param state: 
        :param timeouts: timeouts block.
        :param count: 
        :param depends_on: 
        :param lifecycle: 
        :param provider: 
        """
        config = ApiManagementUserConfig(
            api_management_name=api_management_name,
            email=email,
            first_name=first_name,
            last_name=last_name,
            resource_group_name=resource_group_name,
            user_id=user_id,
            confirmation=confirmation,
            note=note,
            password=password,
            state=state,
            timeouts=timeouts,
            count=count,
            depends_on=depends_on,
            lifecycle=lifecycle,
            provider=provider,
        )

        jsii.create(ApiManagementUser, self, [scope, id, config])

    @jsii.member(jsii_name="synthesizeAttributes")
    def _synthesize_attributes(self) -> typing.Mapping[builtins.str, typing.Any]:
        return jsii.invoke(self, "synthesizeAttributes", [])

    @builtins.property # type: ignore
    @jsii.member(jsii_name="apiManagementName")
    def api_management_name(self) -> builtins.str:
        return jsii.get(self, "apiManagementName")

    @api_management_name.setter # type: ignore
    def api_management_name(self, value: builtins.str) -> None:
        jsii.set(self, "apiManagementName", value)

    @builtins.property # type: ignore
    @jsii.member(jsii_name="email")
    def email(self) -> builtins.str:
        return jsii.get(self, "email")

    @email.setter # type: ignore
    def email(self, value: builtins.str) -> None:
        jsii.set(self, "email", value)

    @builtins.property # type: ignore
    @jsii.member(jsii_name="firstName")
    def first_name(self) -> builtins.str:
        return jsii.get(self, "firstName")

    @first_name.setter # type: ignore
    def first_name(self, value: builtins.str) -> None:
        jsii.set(self, "firstName", value)

    @builtins.property # type: ignore
    @jsii.member(jsii_name="lastName")
    def last_name(self) -> builtins.str:
        return jsii.get(self, "lastName")

    @last_name.setter # type: ignore
    def last_name(self, value: builtins.str) -> None:
        jsii.set(self, "lastName", value)

    @builtins.property # type: ignore
    @jsii.member(jsii_name="resourceGroupName")
    def resource_group_name(self) -> builtins.str:
        return jsii.get(self, "resourceGroupName")

    @resource_group_name.setter # type: ignore
    def resource_group_name(self, value: builtins.str) -> None:
        jsii.set(self, "resourceGroupName", value)

    @builtins.property # type: ignore
    @jsii.member(jsii_name="userId")
    def user_id(self) -> builtins.str:
        return jsii.get(self, "userId")

    @user_id.setter # type: ignore
    def user_id(self, value: builtins.str) -> None:
        jsii.set(self, "userId", value)

    @builtins.property # type: ignore
    @jsii.member(jsii_name="confirmation")
    def confirmation(self) -> typing.Optional[builtins.str]:
        return jsii.get(self, "confirmation")

    @confirmation.setter # type: ignore
    def confirmation(self, value: typing.Optional[builtins.str]) -> None:
        jsii.set(self, "confirmation", value)

    @builtins.property # type: ignore
    @jsii.member(jsii_name="id")
    def id(self) -> typing.Optional[builtins.str]:
        return jsii.get(self, "id")

    @id.setter # type: ignore
    def id(self, value: typing.Optional[builtins.str]) -> None:
        jsii.set(self, "id", value)

    @builtins.property # type: ignore
    @jsii.member(jsii_name="note")
    def note(self) -> typing.Optional[builtins.str]:
        return jsii.get(self, "note")

    @note.setter # type: ignore
    def note(self, value: typing.Optional[builtins.str]) -> None:
        jsii.set(self, "note", value)

    @builtins.property # type: ignore
    @jsii.member(jsii_name="password")
    def password(self) -> typing.Optional[builtins.str]:
        return jsii.get(self, "password")

    @password.setter # type: ignore
    def password(self, value: typing.Optional[builtins.str]) -> None:
        jsii.set(self, "password", value)

    @builtins.property # type: ignore
    @jsii.member(jsii_name="state")
    def state(self) -> typing.Optional[builtins.str]:
        return jsii.get(self, "state")

    @state.setter # type: ignore
    def state(self, value: typing.Optional[builtins.str]) -> None:
        jsii.set(self, "state", value)

    @builtins.property # type: ignore
    @jsii.member(jsii_name="timeouts")
    def timeouts(self) -> typing.Optional["ApiManagementUserTimeouts"]:
        return jsii.get(self, "timeouts")

    @timeouts.setter # type: ignore
    def timeouts(self, value: typing.Optional["ApiManagementUserTimeouts"]) -> None:
        jsii.set(self, "timeouts", value)


@jsii.data_type(
    jsii_type="@cdktf/provider-azurerm.ApiManagementUserConfig",
    jsii_struct_bases=[cdktf.TerraformMetaArguments],
    name_mapping={
        "count": "count",
        "depends_on": "dependsOn",
        "lifecycle": "lifecycle",
        "provider": "provider",
        "api_management_name": "apiManagementName",
        "email": "email",
        "first_name": "firstName",
        "last_name": "lastName",
        "resource_group_name": "resourceGroupName",
        "user_id": "userId",
        "confirmation": "confirmation",
        "note": "note",
        "password": "password",
        "state": "state",
        "timeouts": "timeouts",
    },
)
class ApiManagementUserConfig(cdktf.TerraformMetaArguments):
    def __init__(
        self,
        *,
        count: typing.Optional[jsii.Number] = None,
        depends_on: typing.Optional[typing.List[cdktf.TerraformResource]] = None,
        lifecycle: typing.Optional[cdktf.TerraformResourceLifecycle] = None,
        provider: typing.Optional[cdktf.TerraformProvider] = None,
        api_management_name: builtins.str,
        email: builtins.str,
        first_name: builtins.str,
        last_name: builtins.str,
        resource_group_name: builtins.str,
        user_id: builtins.str,
        confirmation: typing.Optional[builtins.str] = None,
        note: typing.Optional[builtins.str] = None,
        password: typing.Optional[builtins.str] = None,
        state: typing.Optional[builtins.str] = None,
        timeouts: typing.Optional["ApiManagementUserTimeouts"] = None,
    ) -> None:
        """
        :param count: 
        :param depends_on: 
        :param lifecycle: 
        :param provider: 
        :param api_management_name: 
        :param email: 
        :param first_name: 
        :param last_name: 
        :param resource_group_name: 
        :param user_id: 
        :param confirmation: 
        :param note: 
        :param password: 
        :param state: 
        :param timeouts: timeouts block.
        """
        if isinstance(lifecycle, dict):
            lifecycle = cdktf.TerraformResourceLifecycle(**lifecycle)
        if isinstance(timeouts, dict):
            timeouts = ApiManagementUserTimeouts(**timeouts)
        self._values: typing.Dict[str, typing.Any] = {
            "api_management_name": api_management_name,
            "email": email,
            "first_name": first_name,
            "last_name": last_name,
            "resource_group_name": resource_group_name,
            "user_id": user_id,
        }
        if count is not None:
            self._values["count"] = count
        if depends_on is not None:
            self._values["depends_on"] = depends_on
        if lifecycle is not None:
            self._values["lifecycle"] = lifecycle
        if provider is not None:
            self._values["provider"] = provider
        if confirmation is not None:
            self._values["confirmation"] = confirmation
        if note is not None:
            self._values["note"] = note
        if password is not None:
            self._values["password"] = password
        if state is not None:
            self._values["state"] = state
        if timeouts is not None:
            self._values["timeouts"] = timeouts

    @builtins.property
    def count(self) -> typing.Optional[jsii.Number]:
        """
        :stability: experimental
        """
        result = self._values.get("count")
        return result

    @builtins.property
    def depends_on(self) -> typing.Optional[typing.List[cdktf.TerraformResource]]:
        """
        :stability: experimental
        """
        result = self._values.get("depends_on")
        return result

    @builtins.property
    def lifecycle(self) -> typing.Optional[cdktf.TerraformResourceLifecycle]:
        """
        :stability: experimental
        """
        result = self._values.get("lifecycle")
        return result

    @builtins.property
    def provider(self) -> typing.Optional[cdktf.TerraformProvider]:
        """
        :stability: experimental
        """
        result = self._values.get("provider")
        return result

    @builtins.property
    def api_management_name(self) -> builtins.str:
        result = self._values.get("api_management_name")
        assert result is not None, "Required property 'api_management_name' is missing"
        return result

    @builtins.property
    def email(self) -> builtins.str:
        result = self._values.get("email")
        assert result is not None, "Required property 'email' is missing"
        return result

    @builtins.property
    def first_name(self) -> builtins.str:
        result = self._values.get("first_name")
        assert result is not None, "Required property 'first_name' is missing"
        return result

    @builtins.property
    def last_name(self) -> builtins.str:
        result = self._values.get("last_name")
        assert result is not None, "Required property 'last_name' is missing"
        return result

    @builtins.property
    def resource_group_name(self) -> builtins.str:
        result = self._values.get("resource_group_name")
        assert result is not None, "Required property 'resource_group_name' is missing"
        return result

    @builtins.property
    def user_id(self) -> builtins.str:
        result = self._values.get("user_id")
        assert result is not None, "Required property 'user_id' is missing"
        return result

    @builtins.property
    def confirmation(self) -> typing.Optional[builtins.str]:
        result = self._values.get("confirmation")
        return result

    @builtins.property
    def note(self) -> typing.Optional[builtins.str]:
        result = self._values.get("note")
        return result

    @builtins.property
    def password(self) -> typing.Optional[builtins.str]:
        result = self._values.get("password")
        return result

    @builtins.property
    def state(self) -> typing.Optional[builtins.str]:
        result = self._values.get("state")
        return result

    @builtins.property
    def timeouts(self) -> typing.Optional["ApiManagementUserTimeouts"]:
        """timeouts block."""
        result = self._values.get("timeouts")
        return result

    def __eq__(self, rhs: typing.Any) -> builtins.bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs: typing.Any) -> builtins.bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return "ApiManagementUserConfig(%s)" % ", ".join(
            k + "=" + repr(v) for k, v in self._values.items()
        )


@jsii.data_type(
    jsii_type="@cdktf/provider-azurerm.ApiManagementUserTimeouts",
    jsii_struct_bases=[],
    name_mapping={
        "create": "create",
        "delete": "delete",
        "read": "read",
        "update": "update",
    },
)
class ApiManagementUserTimeouts:
    def __init__(
        self,
        *,
        create: typing.Optional[builtins.str] = None,
        delete: typing.Optional[builtins.str] = None,
        read: typing.Optional[builtins.str] = None,
        update: typing.Optional[builtins.str] = None,
    ) -> None:
        """
        :param create: 
        :param delete: 
        :param read: 
        :param update: 
        """
        self._values: typing.Dict[str, typing.Any] = {}
        if create is not None:
            self._values["create"] = create
        if delete is not None:
            self._values["delete"] = delete
        if read is not None:
            self._values["read"] = read
        if update is not None:
            self._values["update"] = update

    @builtins.property
    def create(self) -> typing.Optional[builtins.str]:
        result = self._values.get("create")
        return result

    @builtins.property
    def delete(self) -> typing.Optional[builtins.str]:
        result = self._values.get("delete")
        return result

    @builtins.property
    def read(self) -> typing.Optional[builtins.str]:
        result = self._values.get("read")
        return result

    @builtins.property
    def update(self) -> typing.Optional[builtins.str]:
        result = self._values.get("update")
        return result

    def __eq__(self, rhs: typing.Any) -> builtins.bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs: typing.Any) -> builtins.bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return "ApiManagementUserTimeouts(%s)" % ", ".join(
            k + "=" + repr(v) for k, v in self._values.items()
        )


class AppConfiguration(
    cdktf.TerraformResource,
    metaclass=jsii.JSIIMeta,
    jsii_type="@cdktf/provider-azurerm.AppConfiguration",
):
    def __init__(
        self,
        scope: constructs.Construct,
        id: builtins.str,
        *,
        location: builtins.str,
        name: builtins.str,
        resource_group_name: builtins.str,
        sku: typing.Optional[builtins.str] = None,
        tags: typing.Optional[typing.Mapping[builtins.str, builtins.str]] = None,
        timeouts: typing.Optional["AppConfigurationTimeouts"] = None,
        count: typing.Optional[jsii.Number] = None,
        depends_on: typing.Optional[typing.List[cdktf.TerraformResource]] = None,
        lifecycle: typing.Optional[cdktf.TerraformResourceLifecycle] = None,
        provider: typing.Optional[cdktf.TerraformProvider] = None,
    ) -> None:
        """
        :param scope: -
        :param id: -
        :param location: 
        :param name: 
        :param resource_group_name: 
        :param sku: 
        :param tags: 
        :param timeouts: timeouts block.
        :param count: 
        :param depends_on: 
        :param lifecycle: 
        :param provider: 
        """
        config = AppConfigurationConfig(
            location=location,
            name=name,
            resource_group_name=resource_group_name,
            sku=sku,
            tags=tags,
            timeouts=timeouts,
            count=count,
            depends_on=depends_on,
            lifecycle=lifecycle,
            provider=provider,
        )

        jsii.create(AppConfiguration, self, [scope, id, config])

    @jsii.member(jsii_name="primaryReadKey")
    def primary_read_key(self, index: builtins.str) -> "AppConfigurationPrimaryReadKey":
        """
        :param index: -
        """
        return jsii.invoke(self, "primaryReadKey", [index])

    @jsii.member(jsii_name="primaryWriteKey")
    def primary_write_key(
        self,
        index: builtins.str,
    ) -> "AppConfigurationPrimaryWriteKey":
        """
        :param index: -
        """
        return jsii.invoke(self, "primaryWriteKey", [index])

    @jsii.member(jsii_name="secondaryReadKey")
    def secondary_read_key(
        self,
        index: builtins.str,
    ) -> "AppConfigurationSecondaryReadKey":
        """
        :param index: -
        """
        return jsii.invoke(self, "secondaryReadKey", [index])

    @jsii.member(jsii_name="secondaryWriteKey")
    def secondary_write_key(
        self,
        index: builtins.str,
    ) -> "AppConfigurationSecondaryWriteKey":
        """
        :param index: -
        """
        return jsii.invoke(self, "secondaryWriteKey", [index])

    @jsii.member(jsii_name="synthesizeAttributes")
    def _synthesize_attributes(self) -> typing.Mapping[builtins.str, typing.Any]:
        return jsii.invoke(self, "synthesizeAttributes", [])

    @builtins.property # type: ignore
    @jsii.member(jsii_name="endpoint")
    def endpoint(self) -> builtins.str:
        return jsii.get(self, "endpoint")

    @builtins.property # type: ignore
    @jsii.member(jsii_name="location")
    def location(self) -> builtins.str:
        return jsii.get(self, "location")

    @location.setter # type: ignore
    def location(self, value: builtins.str) -> None:
        jsii.set(self, "location", value)

    @builtins.property # type: ignore
    @jsii.member(jsii_name="name")
    def name(self) -> builtins.str:
        return jsii.get(self, "name")

    @name.setter # type: ignore
    def name(self, value: builtins.str) -> None:
        jsii.set(self, "name", value)

    @builtins.property # type: ignore
    @jsii.member(jsii_name="resourceGroupName")
    def resource_group_name(self) -> builtins.str:
        return jsii.get(self, "resourceGroupName")

    @resource_group_name.setter # type: ignore
    def resource_group_name(self, value: builtins.str) -> None:
        jsii.set(self, "resourceGroupName", value)

    @builtins.property # type: ignore
    @jsii.member(jsii_name="id")
    def id(self) -> typing.Optional[builtins.str]:
        return jsii.get(self, "id")

    @id.setter # type: ignore
    def id(self, value: typing.Optional[builtins.str]) -> None:
        jsii.set(self, "id", value)

    @builtins.property # type: ignore
    @jsii.member(jsii_name="sku")
    def sku(self) -> typing.Optional[builtins.str]:
        return jsii.get(self, "sku")

    @sku.setter # type: ignore
    def sku(self, value: typing.Optional[builtins.str]) -> None:
        jsii.set(self, "sku", value)

    @builtins.property # type: ignore
    @jsii.member(jsii_name="tags")
    def tags(self) -> typing.Optional[typing.Mapping[builtins.str, builtins.str]]:
        return jsii.get(self, "tags")

    @tags.setter # type: ignore
    def tags(
        self,
        value: typing.Optional[typing.Mapping[builtins.str, builtins.str]],
    ) -> None:
        jsii.set(self, "tags", value)

    @builtins.property # type: ignore
    @jsii.member(jsii_name="timeouts")
    def timeouts(self) -> typing.Optional["AppConfigurationTimeouts"]:
        return jsii.get(self, "timeouts")

    @timeouts.setter # type: ignore
    def timeouts(self, value: typing.Optional["AppConfigurationTimeouts"]) -> None:
        jsii.set(self, "timeouts", value)


@jsii.data_type(
    jsii_type="@cdktf/provider-azurerm.AppConfigurationConfig",
    jsii_struct_bases=[cdktf.TerraformMetaArguments],
    name_mapping={
        "count": "count",
        "depends_on": "dependsOn",
        "lifecycle": "lifecycle",
        "provider": "provider",
        "location": "location",
        "name": "name",
        "resource_group_name": "resourceGroupName",
        "sku": "sku",
        "tags": "tags",
        "timeouts": "timeouts",
    },
)
class AppConfigurationConfig(cdktf.TerraformMetaArguments):
    def __init__(
        self,
        *,
        count: typing.Optional[jsii.Number] = None,
        depends_on: typing.Optional[typing.List[cdktf.TerraformResource]] = None,
        lifecycle: typing.Optional[cdktf.TerraformResourceLifecycle] = None,
        provider: typing.Optional[cdktf.TerraformProvider] = None,
        location: builtins.str,
        name: builtins.str,
        resource_group_name: builtins.str,
        sku: typing.Optional[builtins.str] = None,
        tags: typing.Optional[typing.Mapping[builtins.str, builtins.str]] = None,
        timeouts: typing.Optional["AppConfigurationTimeouts"] = None,
    ) -> None:
        """
        :param count: 
        :param depends_on: 
        :param lifecycle: 
        :param provider: 
        :param location: 
        :param name: 
        :param resource_group_name: 
        :param sku: 
        :param tags: 
        :param timeouts: timeouts block.
        """
        if isinstance(lifecycle, dict):
            lifecycle = cdktf.TerraformResourceLifecycle(**lifecycle)
        if isinstance(timeouts, dict):
            timeouts = AppConfigurationTimeouts(**timeouts)
        self._values: typing.Dict[str, typing.Any] = {
            "location": location,
            "name": name,
            "resource_group_name": resource_group_name,
        }
        if count is not None:
            self._values["count"] = count
        if depends_on is not None:
            self._values["depends_on"] = depends_on
        if lifecycle is not None:
            self._values["lifecycle"] = lifecycle
        if provider is not None:
            self._values["provider"] = provider
        if sku is not None:
            self._values["sku"] = sku
        if tags is not None:
            self._values["tags"] = tags
        if timeouts is not None:
            self._values["timeouts"] = timeouts

    @builtins.property
    def count(self) -> typing.Optional[jsii.Number]:
        """
        :stability: experimental
        """
        result = self._values.get("count")
        return result

    @builtins.property
    def depends_on(self) -> typing.Optional[typing.List[cdktf.TerraformResource]]:
        """
        :stability: experimental
        """
        result = self._values.get("depends_on")
        return result

    @builtins.property
    def lifecycle(self) -> typing.Optional[cdktf.TerraformResourceLifecycle]:
        """
        :stability: experimental
        """
        result = self._values.get("lifecycle")
        return result

    @builtins.property
    def provider(self) -> typing.Optional[cdktf.TerraformProvider]:
        """
        :stability: experimental
        """
        result = self._values.get("provider")
        return result

    @builtins.property
    def location(self) -> builtins.str:
        result = self._values.get("location")
        assert result is not None, "Required property 'location' is missing"
        return result

    @builtins.property
    def name(self) -> builtins.str:
        result = self._values.get("name")
        assert result is not None, "Required property 'name' is missing"
        return result

    @builtins.property
    def resource_group_name(self) -> builtins.str:
        result = self._values.get("resource_group_name")
        assert result is not None, "Required property 'resource_group_name' is missing"
        return result

    @builtins.property
    def sku(self) -> typing.Optional[builtins.str]:
        result = self._values.get("sku")
        return result

    @builtins.property
    def tags(self) -> typing.Optional[typing.Mapping[builtins.str, builtins.str]]:
        result = self._values.get("tags")
        return result

    @builtins.property
    def timeouts(self) -> typing.Optional["AppConfigurationTimeouts"]:
        """timeouts block."""
        result = self._values.get("timeouts")
        return result

    def __eq__(self, rhs: typing.Any) -> builtins.bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs: typing.Any) -> builtins.bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return "AppConfigurationConfig(%s)" % ", ".join(
            k + "=" + repr(v) for k, v in self._values.items()
        )


class AppConfigurationPrimaryReadKey(
    cdktf.ComplexComputedList,
    metaclass=jsii.JSIIMeta,
    jsii_type="@cdktf/provider-azurerm.AppConfigurationPrimaryReadKey",
):
    def __init__(
        self,
        terraform_resource: cdktf.ITerraformResource,
        terraform_attribute: builtins.str,
        index: builtins.str,
    ) -> None:
        """
        :param terraform_resource: -
        :param terraform_attribute: -
        :param index: -

        :stability: experimental
        """
        jsii.create(AppConfigurationPrimaryReadKey, self, [terraform_resource, terraform_attribute, index])

    @builtins.property # type: ignore
    @jsii.member(jsii_name="connectionString")
    def connection_string(self) -> builtins.str:
        return jsii.get(self, "connectionString")

    @builtins.property # type: ignore
    @jsii.member(jsii_name="id")
    def id(self) -> builtins.str:
        return jsii.get(self, "id")

    @builtins.property # type: ignore
    @jsii.member(jsii_name="secret")
    def secret(self) -> builtins.str:
        return jsii.get(self, "secret")


class AppConfigurationPrimaryWriteKey(
    cdktf.ComplexComputedList,
    metaclass=jsii.JSIIMeta,
    jsii_type="@cdktf/provider-azurerm.AppConfigurationPrimaryWriteKey",
):
    def __init__(
        self,
        terraform_resource: cdktf.ITerraformResource,
        terraform_attribute: builtins.str,
        index: builtins.str,
    ) -> None:
        """
        :param terraform_resource: -
        :param terraform_attribute: -
        :param index: -

        :stability: experimental
        """
        jsii.create(AppConfigurationPrimaryWriteKey, self, [terraform_resource, terraform_attribute, index])

    @builtins.property # type: ignore
    @jsii.member(jsii_name="connectionString")
    def connection_string(self) -> builtins.str:
        return jsii.get(self, "connectionString")

    @builtins.property # type: ignore
    @jsii.member(jsii_name="id")
    def id(self) -> builtins.str:
        return jsii.get(self, "id")

    @builtins.property # type: ignore
    @jsii.member(jsii_name="secret")
    def secret(self) -> builtins.str:
        return jsii.get(self, "secret")


class AppConfigurationSecondaryReadKey(
    cdktf.ComplexComputedList,
    metaclass=jsii.JSIIMeta,
    jsii_type="@cdktf/provider-azurerm.AppConfigurationSecondaryReadKey",
):
    def __init__(
        self,
        terraform_resource: cdktf.ITerraformResource,
        terraform_attribute: builtins.str,
        index: builtins.str,
    ) -> None:
        """
        :param terraform_resource: -
        :param terraform_attribute: -
        :param index: -

        :stability: experimental
        """
        jsii.create(AppConfigurationSecondaryReadKey, self, [terraform_resource, terraform_attribute, index])

    @builtins.property # type: ignore
    @jsii.member(jsii_name="connectionString")
    def connection_string(self) -> builtins.str:
        return jsii.get(self, "connectionString")

    @builtins.property # type: ignore
    @jsii.member(jsii_name="id")
    def id(self) -> builtins.str:
        return jsii.get(self, "id")

    @builtins.property # type: ignore
    @jsii.member(jsii_name="secret")
    def secret(self) -> builtins.str:
        return jsii.get(self, "secret")


class AppConfigurationSecondaryWriteKey(
    cdktf.ComplexComputedList,
    metaclass=jsii.JSIIMeta,
    jsii_type="@cdktf/provider-azurerm.AppConfigurationSecondaryWriteKey",
):
    def __init__(
        self,
        terraform_resource: cdktf.ITerraformResource,
        terraform_attribute: builtins.str,
        index: builtins.str,
    ) -> None:
        """
        :param terraform_resource: -
        :param terraform_attribute: -
        :param index: -

        :stability: experimental
        """
        jsii.create(AppConfigurationSecondaryWriteKey, self, [terraform_resource, terraform_attribute, index])

    @builtins.property # type: ignore
    @jsii.member(jsii_name="connectionString")
    def connection_string(self) -> builtins.str:
        return jsii.get(self, "connectionString")

    @builtins.property # type: ignore
    @jsii.member(jsii_name="id")
    def id(self) -> builtins.str:
        return jsii.get(self, "id")

    @builtins.property # type: ignore
    @jsii.member(jsii_name="secret")
    def secret(self) -> builtins.str:
        return jsii.get(self, "secret")


@jsii.data_type(
    jsii_type="@cdktf/provider-azurerm.AppConfigurationTimeouts",
    jsii_struct_bases=[],
    name_mapping={
        "create": "create",
        "delete": "delete",
        "read": "read",
        "update": "update",
    },
)
class AppConfigurationTimeouts:
    def __init__(
        self,
        *,
        create: typing.Optional[builtins.str] = None,
        delete: typing.Optional[builtins.str] = None,
        read: typing.Optional[builtins.str] = None,
        update: typing.Optional[builtins.str] = None,
    ) -> None:
        """
        :param create: 
        :param delete: 
        :param read: 
        :param update: 
        """
        self._values: typing.Dict[str, typing.Any] = {}
        if create is not None:
            self._values["create"] = create
        if delete is not None:
            self._values["delete"] = delete
        if read is not None:
            self._values["read"] = read
        if update is not None:
            self._values["update"] = update

    @builtins.property
    def create(self) -> typing.Optional[builtins.str]:
        result = self._values.get("create")
        return result

    @builtins.property
    def delete(self) -> typing.Optional[builtins.str]:
        result = self._values.get("delete")
        return result

    @builtins.property
    def read(self) -> typing.Optional[builtins.str]:
        result = self._values.get("read")
        return result

    @builtins.property
    def update(self) -> typing.Optional[builtins.str]:
        result = self._values.get("update")
        return result

    def __eq__(self, rhs: typing.Any) -> builtins.bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs: typing.Any) -> builtins.bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return "AppConfigurationTimeouts(%s)" % ", ".join(
            k + "=" + repr(v) for k, v in self._values.items()
        )


class AppService(
    cdktf.TerraformResource,
    metaclass=jsii.JSIIMeta,
    jsii_type="@cdktf/provider-azurerm.AppService",
):
    def __init__(
        self,
        scope: constructs.Construct,
        id: builtins.str,
        *,
        app_service_plan_id: builtins.str,
        location: builtins.str,
        name: builtins.str,
        resource_group_name: builtins.str,
        app_settings: typing.Optional[typing.Mapping[builtins.str, builtins.str]] = None,
        auth_settings: typing.Optional[typing.List["AppServiceAuthSettings"]] = None,
        backup: typing.Optional[typing.List["AppServiceBackup"]] = None,
        client_affinity_enabled: typing.Optional[builtins.bool] = None,
        client_cert_enabled: typing.Optional[builtins.bool] = None,
        connection_string: typing.Optional[typing.List["AppServiceConnectionString"]] = None,
        enabled: typing.Optional[builtins.bool] = None,
        https_only: typing.Optional[builtins.bool] = None,
        identity: typing.Optional[typing.List["AppServiceIdentity"]] = None,
        logs: typing.Optional[typing.List["AppServiceLogs"]] = None,
        site_config: typing.Optional[typing.List["AppServiceSiteConfig"]] = None,
        storage_account: typing.Optional[typing.List["AppServiceStorageAccount"]] = None,
        tags: typing.Optional[typing.Mapping[builtins.str, builtins.str]] = None,
        timeouts: typing.Optional["AppServiceTimeouts"] = None,
        count: typing.Optional[jsii.Number] = None,
        depends_on: typing.Optional[typing.List[cdktf.TerraformResource]] = None,
        lifecycle: typing.Optional[cdktf.TerraformResourceLifecycle] = None,
        provider: typing.Optional[cdktf.TerraformProvider] = None,
    ) -> None:
        """
        :param scope: -
        :param id: -
        :param app_service_plan_id: 
        :param location: 
        :param name: 
        :param resource_group_name: 
        :param app_settings: 
        :param auth_settings: auth_settings block.
        :param backup: backup block.
        :param client_affinity_enabled: 
        :param client_cert_enabled: 
        :param connection_string: connection_string block.
        :param enabled: 
        :param https_only: 
        :param identity: identity block.
        :param logs: logs block.
        :param site_config: site_config block.
        :param storage_account: storage_account block.
        :param tags: 
        :param timeouts: timeouts block.
        :param count: 
        :param depends_on: 
        :param lifecycle: 
        :param provider: 
        """
        config = AppServiceConfig(
            app_service_plan_id=app_service_plan_id,
            location=location,
            name=name,
            resource_group_name=resource_group_name,
            app_settings=app_settings,
            auth_settings=auth_settings,
            backup=backup,
            client_affinity_enabled=client_affinity_enabled,
            client_cert_enabled=client_cert_enabled,
            connection_string=connection_string,
            enabled=enabled,
            https_only=https_only,
            identity=identity,
            logs=logs,
            site_config=site_config,
            storage_account=storage_account,
            tags=tags,
            timeouts=timeouts,
            count=count,
            depends_on=depends_on,
            lifecycle=lifecycle,
            provider=provider,
        )

        jsii.create(AppService, self, [scope, id, config])

    @jsii.member(jsii_name="siteCredential")
    def site_credential(self, index: builtins.str) -> "AppServiceSiteCredential":
        """
        :param index: -
        """
        return jsii.invoke(self, "siteCredential", [index])

    @jsii.member(jsii_name="sourceControl")
    def source_control(self, index: builtins.str) -> "AppServiceSourceControl":
        """
        :param index: -
        """
        return jsii.invoke(self, "sourceControl", [index])

    @jsii.member(jsii_name="synthesizeAttributes")
    def _synthesize_attributes(self) -> typing.Mapping[builtins.str, typing.Any]:
        return jsii.invoke(self, "synthesizeAttributes", [])

    @builtins.property # type: ignore
    @jsii.member(jsii_name="defaultSiteHostname")
    def default_site_hostname(self) -> builtins.str:
        return jsii.get(self, "defaultSiteHostname")

    @builtins.property # type: ignore
    @jsii.member(jsii_name="outboundIpAddresses")
    def outbound_ip_addresses(self) -> builtins.str:
        return jsii.get(self, "outboundIpAddresses")

    @builtins.property # type: ignore
    @jsii.member(jsii_name="possibleOutboundIpAddresses")
    def possible_outbound_ip_addresses(self) -> builtins.str:
        return jsii.get(self, "possibleOutboundIpAddresses")

    @builtins.property # type: ignore
    @jsii.member(jsii_name="appServicePlanId")
    def app_service_plan_id(self) -> builtins.str:
        return jsii.get(self, "appServicePlanId")

    @app_service_plan_id.setter # type: ignore
    def app_service_plan_id(self, value: builtins.str) -> None:
        jsii.set(self, "appServicePlanId", value)

    @builtins.property # type: ignore
    @jsii.member(jsii_name="location")
    def location(self) -> builtins.str:
        return jsii.get(self, "location")

    @location.setter # type: ignore
    def location(self, value: builtins.str) -> None:
        jsii.set(self, "location", value)

    @builtins.property # type: ignore
    @jsii.member(jsii_name="name")
    def name(self) -> builtins.str:
        return jsii.get(self, "name")

    @name.setter # type: ignore
    def name(self, value: builtins.str) -> None:
        jsii.set(self, "name", value)

    @builtins.property # type: ignore
    @jsii.member(jsii_name="resourceGroupName")
    def resource_group_name(self) -> builtins.str:
        return jsii.get(self, "resourceGroupName")

    @resource_group_name.setter # type: ignore
    def resource_group_name(self, value: builtins.str) -> None:
        jsii.set(self, "resourceGroupName", value)

    @builtins.property # type: ignore
    @jsii.member(jsii_name="appSettings")
    def app_settings(
        self,
    ) -> typing.Optional[typing.Mapping[builtins.str, builtins.str]]:
        return jsii.get(self, "appSettings")

    @app_settings.setter # type: ignore
    def app_settings(
        self,
        value: typing.Optional[typing.Mapping[builtins.str, builtins.str]],
    ) -> None:
        jsii.set(self, "appSettings", value)

    @builtins.property # type: ignore
    @jsii.member(jsii_name="authSettings")
    def auth_settings(self) -> typing.Optional[typing.List["AppServiceAuthSettings"]]:
        return jsii.get(self, "authSettings")

    @auth_settings.setter # type: ignore
    def auth_settings(
        self,
        value: typing.Optional[typing.List["AppServiceAuthSettings"]],
    ) -> None:
        jsii.set(self, "authSettings", value)

    @builtins.property # type: ignore
    @jsii.member(jsii_name="backup")
    def backup(self) -> typing.Optional[typing.List["AppServiceBackup"]]:
        return jsii.get(self, "backup")

    @backup.setter # type: ignore
    def backup(self, value: typing.Optional[typing.List["AppServiceBackup"]]) -> None:
        jsii.set(self, "backup", value)

    @builtins.property # type: ignore
    @jsii.member(jsii_name="clientAffinityEnabled")
    def client_affinity_enabled(self) -> typing.Optional[builtins.bool]:
        return jsii.get(self, "clientAffinityEnabled")

    @client_affinity_enabled.setter # type: ignore
    def client_affinity_enabled(self, value: typing.Optional[builtins.bool]) -> None:
        jsii.set(self, "clientAffinityEnabled", value)

    @builtins.property # type: ignore
    @jsii.member(jsii_name="clientCertEnabled")
    def client_cert_enabled(self) -> typing.Optional[builtins.bool]:
        return jsii.get(self, "clientCertEnabled")

    @client_cert_enabled.setter # type: ignore
    def client_cert_enabled(self, value: typing.Optional[builtins.bool]) -> None:
        jsii.set(self, "clientCertEnabled", value)

    @builtins.property # type: ignore
    @jsii.member(jsii_name="connectionString")
    def connection_string(
        self,
    ) -> typing.Optional[typing.List["AppServiceConnectionString"]]:
        return jsii.get(self, "connectionString")

    @connection_string.setter # type: ignore
    def connection_string(
        self,
        value: typing.Optional[typing.List["AppServiceConnectionString"]],
    ) -> None:
        jsii.set(self, "connectionString", value)

    @builtins.property # type: ignore
    @jsii.member(jsii_name="enabled")
    def enabled(self) -> typing.Optional[builtins.bool]:
        return jsii.get(self, "enabled")

    @enabled.setter # type: ignore
    def enabled(self, value: typing.Optional[builtins.bool]) -> None:
        jsii.set(self, "enabled", value)

    @builtins.property # type: ignore
    @jsii.member(jsii_name="httpsOnly")
    def https_only(self) -> typing.Optional[builtins.bool]:
        return jsii.get(self, "httpsOnly")

    @https_only.setter # type: ignore
    def https_only(self, value: typing.Optional[builtins.bool]) -> None:
        jsii.set(self, "httpsOnly", value)

    @builtins.property # type: ignore
    @jsii.member(jsii_name="id")
    def id(self) -> typing.Optional[builtins.str]:
        return jsii.get(self, "id")

    @id.setter # type: ignore
    def id(self, value: typing.Optional[builtins.str]) -> None:
        jsii.set(self, "id", value)

    @builtins.property # type: ignore
    @jsii.member(jsii_name="identity")
    def identity(self) -> typing.Optional[typing.List["AppServiceIdentity"]]:
        return jsii.get(self, "identity")

    @identity.setter # type: ignore
    def identity(
        self,
        value: typing.Optional[typing.List["AppServiceIdentity"]],
    ) -> None:
        jsii.set(self, "identity", value)

    @builtins.property # type: ignore
    @jsii.member(jsii_name="logs")
    def logs(self) -> typing.Optional[typing.List["AppServiceLogs"]]:
        return jsii.get(self, "logs")

    @logs.setter # type: ignore
    def logs(self, value: typing.Optional[typing.List["AppServiceLogs"]]) -> None:
        jsii.set(self, "logs", value)

    @builtins.property # type: ignore
    @jsii.member(jsii_name="siteConfig")
    def site_config(self) -> typing.Optional[typing.List["AppServiceSiteConfig"]]:
        return jsii.get(self, "siteConfig")

    @site_config.setter # type: ignore
    def site_config(
        self,
        value: typing.Optional[typing.List["AppServiceSiteConfig"]],
    ) -> None:
        jsii.set(self, "siteConfig", value)

    @builtins.property # type: ignore
    @jsii.member(jsii_name="storageAccount")
    def storage_account(
        self,
    ) -> typing.Optional[typing.List["AppServiceStorageAccount"]]:
        return jsii.get(self, "storageAccount")

    @storage_account.setter # type: ignore
    def storage_account(
        self,
        value: typing.Optional[typing.List["AppServiceStorageAccount"]],
    ) -> None:
        jsii.set(self, "storageAccount", value)

    @builtins.property # type: ignore
    @jsii.member(jsii_name="tags")
    def tags(self) -> typing.Optional[typing.Mapping[builtins.str, builtins.str]]:
        return jsii.get(self, "tags")

    @tags.setter # type: ignore
    def tags(
        self,
        value: typing.Optional[typing.Mapping[builtins.str, builtins.str]],
    ) -> None:
        jsii.set(self, "tags", value)

    @builtins.property # type: ignore
    @jsii.member(jsii_name="timeouts")
    def timeouts(self) -> typing.Optional["AppServiceTimeouts"]:
        return jsii.get(self, "timeouts")

    @timeouts.setter # type: ignore
    def timeouts(self, value: typing.Optional["AppServiceTimeouts"]) -> None:
        jsii.set(self, "timeouts", value)


class AppServiceActiveSlot(
    cdktf.TerraformResource,
    metaclass=jsii.JSIIMeta,
    jsii_type="@cdktf/provider-azurerm.AppServiceActiveSlot",
):
    def __init__(
        self,
        scope: constructs.Construct,
        id: builtins.str,
        *,
        app_service_name: builtins.str,
        app_service_slot_name: builtins.str,
        resource_group_name: builtins.str,
        timeouts: typing.Optional["AppServiceActiveSlotTimeouts"] = None,
        count: typing.Optional[jsii.Number] = None,
        depends_on: typing.Optional[typing.List[cdktf.TerraformResource]] = None,
        lifecycle: typing.Optional[cdktf.TerraformResourceLifecycle] = None,
        provider: typing.Optional[cdktf.TerraformProvider] = None,
    ) -> None:
        """
        :param scope: -
        :param id: -
        :param app_service_name: 
        :param app_service_slot_name: 
        :param resource_group_name: 
        :param timeouts: timeouts block.
        :param count: 
        :param depends_on: 
        :param lifecycle: 
        :param provider: 
        """
        config = AppServiceActiveSlotConfig(
            app_service_name=app_service_name,
            app_service_slot_name=app_service_slot_name,
            resource_group_name=resource_group_name,
            timeouts=timeouts,
            count=count,
            depends_on=depends_on,
            lifecycle=lifecycle,
            provider=provider,
        )

        jsii.create(AppServiceActiveSlot, self, [scope, id, config])

    @jsii.member(jsii_name="synthesizeAttributes")
    def _synthesize_attributes(self) -> typing.Mapping[builtins.str, typing.Any]:
        return jsii.invoke(self, "synthesizeAttributes", [])

    @builtins.property # type: ignore
    @jsii.member(jsii_name="appServiceName")
    def app_service_name(self) -> builtins.str:
        return jsii.get(self, "appServiceName")

    @app_service_name.setter # type: ignore
    def app_service_name(self, value: builtins.str) -> None:
        jsii.set(self, "appServiceName", value)

    @builtins.property # type: ignore
    @jsii.member(jsii_name="appServiceSlotName")
    def app_service_slot_name(self) -> builtins.str:
        return jsii.get(self, "appServiceSlotName")

    @app_service_slot_name.setter # type: ignore
    def app_service_slot_name(self, value: builtins.str) -> None:
        jsii.set(self, "appServiceSlotName", value)

    @builtins.property # type: ignore
    @jsii.member(jsii_name="resourceGroupName")
    def resource_group_name(self) -> builtins.str:
        return jsii.get(self, "resourceGroupName")

    @resource_group_name.setter # type: ignore
    def resource_group_name(self, value: builtins.str) -> None:
        jsii.set(self, "resourceGroupName", value)

    @builtins.property # type: ignore
    @jsii.member(jsii_name="id")
    def id(self) -> typing.Optional[builtins.str]:
        return jsii.get(self, "id")

    @id.setter # type: ignore
    def id(self, value: typing.Optional[builtins.str]) -> None:
        jsii.set(self, "id", value)

    @builtins.property # type: ignore
    @jsii.member(jsii_name="timeouts")
    def timeouts(self) -> typing.Optional["AppServiceActiveSlotTimeouts"]:
        return jsii.get(self, "timeouts")

    @timeouts.setter # type: ignore
    def timeouts(self, value: typing.Optional["AppServiceActiveSlotTimeouts"]) -> None:
        jsii.set(self, "timeouts", value)


@jsii.data_type(
    jsii_type="@cdktf/provider-azurerm.AppServiceActiveSlotConfig",
    jsii_struct_bases=[cdktf.TerraformMetaArguments],
    name_mapping={
        "count": "count",
        "depends_on": "dependsOn",
        "lifecycle": "lifecycle",
        "provider": "provider",
        "app_service_name": "appServiceName",
        "app_service_slot_name": "appServiceSlotName",
        "resource_group_name": "resourceGroupName",
        "timeouts": "timeouts",
    },
)
class AppServiceActiveSlotConfig(cdktf.TerraformMetaArguments):
    def __init__(
        self,
        *,
        count: typing.Optional[jsii.Number] = None,
        depends_on: typing.Optional[typing.List[cdktf.TerraformResource]] = None,
        lifecycle: typing.Optional[cdktf.TerraformResourceLifecycle] = None,
        provider: typing.Optional[cdktf.TerraformProvider] = None,
        app_service_name: builtins.str,
        app_service_slot_name: builtins.str,
        resource_group_name: builtins.str,
        timeouts: typing.Optional["AppServiceActiveSlotTimeouts"] = None,
    ) -> None:
        """
        :param count: 
        :param depends_on: 
        :param lifecycle: 
        :param provider: 
        :param app_service_name: 
        :param app_service_slot_name: 
        :param resource_group_name: 
        :param timeouts: timeouts block.
        """
        if isinstance(lifecycle, dict):
            lifecycle = cdktf.TerraformResourceLifecycle(**lifecycle)
        if isinstance(timeouts, dict):
            timeouts = AppServiceActiveSlotTimeouts(**timeouts)
        self._values: typing.Dict[str, typing.Any] = {
            "app_service_name": app_service_name,
            "app_service_slot_name": app_service_slot_name,
            "resource_group_name": resource_group_name,
        }
        if count is not None:
            self._values["count"] = count
        if depends_on is not None:
            self._values["depends_on"] = depends_on
        if lifecycle is not None:
            self._values["lifecycle"] = lifecycle
        if provider is not None:
            self._values["provider"] = provider
        if timeouts is not None:
            self._values["timeouts"] = timeouts

    @builtins.property
    def count(self) -> typing.Optional[jsii.Number]:
        """
        :stability: experimental
        """
        result = self._values.get("count")
        return result

    @builtins.property
    def depends_on(self) -> typing.Optional[typing.List[cdktf.TerraformResource]]:
        """
        :stability: experimental
        """
        result = self._values.get("depends_on")
        return result

    @builtins.property
    def lifecycle(self) -> typing.Optional[cdktf.TerraformResourceLifecycle]:
        """
        :stability: experimental
        """
        result = self._values.get("lifecycle")
        return result

    @builtins.property
    def provider(self) -> typing.Optional[cdktf.TerraformProvider]:
        """
        :stability: experimental
        """
        result = self._values.get("provider")
        return result

    @builtins.property
    def app_service_name(self) -> builtins.str:
        result = self._values.get("app_service_name")
        assert result is not None, "Required property 'app_service_name' is missing"
        return result

    @builtins.property
    def app_service_slot_name(self) -> builtins.str:
        result = self._values.get("app_service_slot_name")
        assert result is not None, "Required property 'app_service_slot_name' is missing"
        return result

    @builtins.property
    def resource_group_name(self) -> builtins.str:
        result = self._values.get("resource_group_name")
        assert result is not None, "Required property 'resource_group_name' is missing"
        return result

    @builtins.property
    def timeouts(self) -> typing.Optional["AppServiceActiveSlotTimeouts"]:
        """timeouts block."""
        result = self._values.get("timeouts")
        return result

    def __eq__(self, rhs: typing.Any) -> builtins.bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs: typing.Any) -> builtins.bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return "AppServiceActiveSlotConfig(%s)" % ", ".join(
            k + "=" + repr(v) for k, v in self._values.items()
        )


@jsii.data_type(
    jsii_type="@cdktf/provider-azurerm.AppServiceActiveSlotTimeouts",
    jsii_struct_bases=[],
    name_mapping={
        "create": "create",
        "delete": "delete",
        "read": "read",
        "update": "update",
    },
)
class AppServiceActiveSlotTimeouts:
    def __init__(
        self,
        *,
        create: typing.Optional[builtins.str] = None,
        delete: typing.Optional[builtins.str] = None,
        read: typing.Optional[builtins.str] = None,
        update: typing.Optional[builtins.str] = None,
    ) -> None:
        """
        :param create: 
        :param delete: 
        :param read: 
        :param update: 
        """
        self._values: typing.Dict[str, typing.Any] = {}
        if create is not None:
            self._values["create"] = create
        if delete is not None:
            self._values["delete"] = delete
        if read is not None:
            self._values["read"] = read
        if update is not None:
            self._values["update"] = update

    @builtins.property
    def create(self) -> typing.Optional[builtins.str]:
        result = self._values.get("create")
        return result

    @builtins.property
    def delete(self) -> typing.Optional[builtins.str]:
        result = self._values.get("delete")
        return result

    @builtins.property
    def read(self) -> typing.Optional[builtins.str]:
        result = self._values.get("read")
        return result

    @builtins.property
    def update(self) -> typing.Optional[builtins.str]:
        result = self._values.get("update")
        return result

    def __eq__(self, rhs: typing.Any) -> builtins.bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs: typing.Any) -> builtins.bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return "AppServiceActiveSlotTimeouts(%s)" % ", ".join(
            k + "=" + repr(v) for k, v in self._values.items()
        )


@jsii.data_type(
    jsii_type="@cdktf/provider-azurerm.AppServiceAuthSettings",
    jsii_struct_bases=[],
    name_mapping={
        "enabled": "enabled",
        "active_directory": "activeDirectory",
        "additional_login_params": "additionalLoginParams",
        "allowed_external_redirect_urls": "allowedExternalRedirectUrls",
        "default_provider": "defaultProvider",
        "facebook": "facebook",
        "google": "google",
        "issuer": "issuer",
        "microsoft": "microsoft",
        "runtime_version": "runtimeVersion",
        "token_refresh_extension_hours": "tokenRefreshExtensionHours",
        "token_store_enabled": "tokenStoreEnabled",
        "twitter": "twitter",
        "unauthenticated_client_action": "unauthenticatedClientAction",
    },
)
class AppServiceAuthSettings:
    def __init__(
        self,
        *,
        enabled: builtins.bool,
        active_directory: typing.Optional[typing.List["AppServiceAuthSettingsActiveDirectory"]] = None,
        additional_login_params: typing.Optional[typing.Mapping[builtins.str, builtins.str]] = None,
        allowed_external_redirect_urls: typing.Optional[typing.List[builtins.str]] = None,
        default_provider: typing.Optional[builtins.str] = None,
        facebook: typing.Optional[typing.List["AppServiceAuthSettingsFacebook"]] = None,
        google: typing.Optional[typing.List["AppServiceAuthSettingsGoogle"]] = None,
        issuer: typing.Optional[builtins.str] = None,
        microsoft: typing.Optional[typing.List["AppServiceAuthSettingsMicrosoft"]] = None,
        runtime_version: typing.Optional[builtins.str] = None,
        token_refresh_extension_hours: typing.Optional[jsii.Number] = None,
        token_store_enabled: typing.Optional[builtins.bool] = None,
        twitter: typing.Optional[typing.List["AppServiceAuthSettingsTwitter"]] = None,
        unauthenticated_client_action: typing.Optional[builtins.str] = None,
    ) -> None:
        """
        :param enabled: 
        :param active_directory: active_directory block.
        :param additional_login_params: 
        :param allowed_external_redirect_urls: 
        :param default_provider: 
        :param facebook: facebook block.
        :param google: google block.
        :param issuer: 
        :param microsoft: microsoft block.
        :param runtime_version: 
        :param token_refresh_extension_hours: 
        :param token_store_enabled: 
        :param twitter: twitter block.
        :param unauthenticated_client_action: 
        """
        self._values: typing.Dict[str, typing.Any] = {
            "enabled": enabled,
        }
        if active_directory is not None:
            self._values["active_directory"] = active_directory
        if additional_login_params is not None:
            self._values["additional_login_params"] = additional_login_params
        if allowed_external_redirect_urls is not None:
            self._values["allowed_external_redirect_urls"] = allowed_external_redirect_urls
        if default_provider is not None:
            self._values["default_provider"] = default_provider
        if facebook is not None:
            self._values["facebook"] = facebook
        if google is not None:
            self._values["google"] = google
        if issuer is not None:
            self._values["issuer"] = issuer
        if microsoft is not None:
            self._values["microsoft"] = microsoft
        if runtime_version is not None:
            self._values["runtime_version"] = runtime_version
        if token_refresh_extension_hours is not None:
            self._values["token_refresh_extension_hours"] = token_refresh_extension_hours
        if token_store_enabled is not None:
            self._values["token_store_enabled"] = token_store_enabled
        if twitter is not None:
            self._values["twitter"] = twitter
        if unauthenticated_client_action is not None:
            self._values["unauthenticated_client_action"] = unauthenticated_client_action

    @builtins.property
    def enabled(self) -> builtins.bool:
        result = self._values.get("enabled")
        assert result is not None, "Required property 'enabled' is missing"
        return result

    @builtins.property
    def active_directory(
        self,
    ) -> typing.Optional[typing.List["AppServiceAuthSettingsActiveDirectory"]]:
        """active_directory block."""
        result = self._values.get("active_directory")
        return result

    @builtins.property
    def additional_login_params(
        self,
    ) -> typing.Optional[typing.Mapping[builtins.str, builtins.str]]:
        result = self._values.get("additional_login_params")
        return result

    @builtins.property
    def allowed_external_redirect_urls(
        self,
    ) -> typing.Optional[typing.List[builtins.str]]:
        result = self._values.get("allowed_external_redirect_urls")
        return result

    @builtins.property
    def default_provider(self) -> typing.Optional[builtins.str]:
        result = self._values.get("default_provider")
        return result

    @builtins.property
    def facebook(
        self,
    ) -> typing.Optional[typing.List["AppServiceAuthSettingsFacebook"]]:
        """facebook block."""
        result = self._values.get("facebook")
        return result

    @builtins.property
    def google(self) -> typing.Optional[typing.List["AppServiceAuthSettingsGoogle"]]:
        """google block."""
        result = self._values.get("google")
        return result

    @builtins.property
    def issuer(self) -> typing.Optional[builtins.str]:
        result = self._values.get("issuer")
        return result

    @builtins.property
    def microsoft(
        self,
    ) -> typing.Optional[typing.List["AppServiceAuthSettingsMicrosoft"]]:
        """microsoft block."""
        result = self._values.get("microsoft")
        return result

    @builtins.property
    def runtime_version(self) -> typing.Optional[builtins.str]:
        result = self._values.get("runtime_version")
        return result

    @builtins.property
    def token_refresh_extension_hours(self) -> typing.Optional[jsii.Number]:
        result = self._values.get("token_refresh_extension_hours")
        return result

    @builtins.property
    def token_store_enabled(self) -> typing.Optional[builtins.bool]:
        result = self._values.get("token_store_enabled")
        return result

    @builtins.property
    def twitter(self) -> typing.Optional[typing.List["AppServiceAuthSettingsTwitter"]]:
        """twitter block."""
        result = self._values.get("twitter")
        return result

    @builtins.property
    def unauthenticated_client_action(self) -> typing.Optional[builtins.str]:
        result = self._values.get("unauthenticated_client_action")
        return result

    def __eq__(self, rhs: typing.Any) -> builtins.bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs: typing.Any) -> builtins.bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return "AppServiceAuthSettings(%s)" % ", ".join(
            k + "=" + repr(v) for k, v in self._values.items()
        )


@jsii.data_type(
    jsii_type="@cdktf/provider-azurerm.AppServiceAuthSettingsActiveDirectory",
    jsii_struct_bases=[],
    name_mapping={
        "client_id": "clientId",
        "allowed_audiences": "allowedAudiences",
        "client_secret": "clientSecret",
    },
)
class AppServiceAuthSettingsActiveDirectory:
    def __init__(
        self,
        *,
        client_id: builtins.str,
        allowed_audiences: typing.Optional[typing.List[builtins.str]] = None,
        client_secret: typing.Optional[builtins.str] = None,
    ) -> None:
        """
        :param client_id: 
        :param allowed_audiences: 
        :param client_secret: 
        """
        self._values: typing.Dict[str, typing.Any] = {
            "client_id": client_id,
        }
        if allowed_audiences is not None:
            self._values["allowed_audiences"] = allowed_audiences
        if client_secret is not None:
            self._values["client_secret"] = client_secret

    @builtins.property
    def client_id(self) -> builtins.str:
        result = self._values.get("client_id")
        assert result is not None, "Required property 'client_id' is missing"
        return result

    @builtins.property
    def allowed_audiences(self) -> typing.Optional[typing.List[builtins.str]]:
        result = self._values.get("allowed_audiences")
        return result

    @builtins.property
    def client_secret(self) -> typing.Optional[builtins.str]:
        result = self._values.get("client_secret")
        return result

    def __eq__(self, rhs: typing.Any) -> builtins.bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs: typing.Any) -> builtins.bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return "AppServiceAuthSettingsActiveDirectory(%s)" % ", ".join(
            k + "=" + repr(v) for k, v in self._values.items()
        )


@jsii.data_type(
    jsii_type="@cdktf/provider-azurerm.AppServiceAuthSettingsFacebook",
    jsii_struct_bases=[],
    name_mapping={
        "app_id": "appId",
        "app_secret": "appSecret",
        "oauth_scopes": "oauthScopes",
    },
)
class AppServiceAuthSettingsFacebook:
    def __init__(
        self,
        *,
        app_id: builtins.str,
        app_secret: builtins.str,
        oauth_scopes: typing.Optional[typing.List[builtins.str]] = None,
    ) -> None:
        """
        :param app_id: 
        :param app_secret: 
        :param oauth_scopes: 
        """
        self._values: typing.Dict[str, typing.Any] = {
            "app_id": app_id,
            "app_secret": app_secret,
        }
        if oauth_scopes is not None:
            self._values["oauth_scopes"] = oauth_scopes

    @builtins.property
    def app_id(self) -> builtins.str:
        result = self._values.get("app_id")
        assert result is not None, "Required property 'app_id' is missing"
        return result

    @builtins.property
    def app_secret(self) -> builtins.str:
        result = self._values.get("app_secret")
        assert result is not None, "Required property 'app_secret' is missing"
        return result

    @builtins.property
    def oauth_scopes(self) -> typing.Optional[typing.List[builtins.str]]:
        result = self._values.get("oauth_scopes")
        return result

    def __eq__(self, rhs: typing.Any) -> builtins.bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs: typing.Any) -> builtins.bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return "AppServiceAuthSettingsFacebook(%s)" % ", ".join(
            k + "=" + repr(v) for k, v in self._values.items()
        )


@jsii.data_type(
    jsii_type="@cdktf/provider-azurerm.AppServiceAuthSettingsGoogle",
    jsii_struct_bases=[],
    name_mapping={
        "client_id": "clientId",
        "client_secret": "clientSecret",
        "oauth_scopes": "oauthScopes",
    },
)
class AppServiceAuthSettingsGoogle:
    def __init__(
        self,
        *,
        client_id: builtins.str,
        client_secret: builtins.str,
        oauth_scopes: typing.Optional[typing.List[builtins.str]] = None,
    ) -> None:
        """
        :param client_id: 
        :param client_secret: 
        :param oauth_scopes: 
        """
        self._values: typing.Dict[str, typing.Any] = {
            "client_id": client_id,
            "client_secret": client_secret,
        }
        if oauth_scopes is not None:
            self._values["oauth_scopes"] = oauth_scopes

    @builtins.property
    def client_id(self) -> builtins.str:
        result = self._values.get("client_id")
        assert result is not None, "Required property 'client_id' is missing"
        return result

    @builtins.property
    def client_secret(self) -> builtins.str:
        result = self._values.get("client_secret")
        assert result is not None, "Required property 'client_secret' is missing"
        return result

    @builtins.property
    def oauth_scopes(self) -> typing.Optional[typing.List[builtins.str]]:
        result = self._values.get("oauth_scopes")
        return result

    def __eq__(self, rhs: typing.Any) -> builtins.bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs: typing.Any) -> builtins.bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return "AppServiceAuthSettingsGoogle(%s)" % ", ".join(
            k + "=" + repr(v) for k, v in self._values.items()
        )


@jsii.data_type(
    jsii_type="@cdktf/provider-azurerm.AppServiceAuthSettingsMicrosoft",
    jsii_struct_bases=[],
    name_mapping={
        "client_id": "clientId",
        "client_secret": "clientSecret",
        "oauth_scopes": "oauthScopes",
    },
)
class AppServiceAuthSettingsMicrosoft:
    def __init__(
        self,
        *,
        client_id: builtins.str,
        client_secret: builtins.str,
        oauth_scopes: typing.Optional[typing.List[builtins.str]] = None,
    ) -> None:
        """
        :param client_id: 
        :param client_secret: 
        :param oauth_scopes: 
        """
        self._values: typing.Dict[str, typing.Any] = {
            "client_id": client_id,
            "client_secret": client_secret,
        }
        if oauth_scopes is not None:
            self._values["oauth_scopes"] = oauth_scopes

    @builtins.property
    def client_id(self) -> builtins.str:
        result = self._values.get("client_id")
        assert result is not None, "Required property 'client_id' is missing"
        return result

    @builtins.property
    def client_secret(self) -> builtins.str:
        result = self._values.get("client_secret")
        assert result is not None, "Required property 'client_secret' is missing"
        return result

    @builtins.property
    def oauth_scopes(self) -> typing.Optional[typing.List[builtins.str]]:
        result = self._values.get("oauth_scopes")
        return result

    def __eq__(self, rhs: typing.Any) -> builtins.bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs: typing.Any) -> builtins.bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return "AppServiceAuthSettingsMicrosoft(%s)" % ", ".join(
            k + "=" + repr(v) for k, v in self._values.items()
        )


@jsii.data_type(
    jsii_type="@cdktf/provider-azurerm.AppServiceAuthSettingsTwitter",
    jsii_struct_bases=[],
    name_mapping={"consumer_key": "consumerKey", "consumer_secret": "consumerSecret"},
)
class AppServiceAuthSettingsTwitter:
    def __init__(
        self,
        *,
        consumer_key: builtins.str,
        consumer_secret: builtins.str,
    ) -> None:
        """
        :param consumer_key: 
        :param consumer_secret: 
        """
        self._values: typing.Dict[str, typing.Any] = {
            "consumer_key": consumer_key,
            "consumer_secret": consumer_secret,
        }

    @builtins.property
    def consumer_key(self) -> builtins.str:
        result = self._values.get("consumer_key")
        assert result is not None, "Required property 'consumer_key' is missing"
        return result

    @builtins.property
    def consumer_secret(self) -> builtins.str:
        result = self._values.get("consumer_secret")
        assert result is not None, "Required property 'consumer_secret' is missing"
        return result

    def __eq__(self, rhs: typing.Any) -> builtins.bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs: typing.Any) -> builtins.bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return "AppServiceAuthSettingsTwitter(%s)" % ", ".join(
            k + "=" + repr(v) for k, v in self._values.items()
        )


@jsii.data_type(
    jsii_type="@cdktf/provider-azurerm.AppServiceBackup",
    jsii_struct_bases=[],
    name_mapping={
        "name": "name",
        "schedule": "schedule",
        "storage_account_url": "storageAccountUrl",
        "enabled": "enabled",
    },
)
class AppServiceBackup:
    def __init__(
        self,
        *,
        name: builtins.str,
        schedule: typing.List["AppServiceBackupSchedule"],
        storage_account_url: builtins.str,
        enabled: typing.Optional[builtins.bool] = None,
    ) -> None:
        """
        :param name: 
        :param schedule: schedule block.
        :param storage_account_url: 
        :param enabled: 
        """
        self._values: typing.Dict[str, typing.Any] = {
            "name": name,
            "schedule": schedule,
            "storage_account_url": storage_account_url,
        }
        if enabled is not None:
            self._values["enabled"] = enabled

    @builtins.property
    def name(self) -> builtins.str:
        result = self._values.get("name")
        assert result is not None, "Required property 'name' is missing"
        return result

    @builtins.property
    def schedule(self) -> typing.List["AppServiceBackupSchedule"]:
        """schedule block."""
        result = self._values.get("schedule")
        assert result is not None, "Required property 'schedule' is missing"
        return result

    @builtins.property
    def storage_account_url(self) -> builtins.str:
        result = self._values.get("storage_account_url")
        assert result is not None, "Required property 'storage_account_url' is missing"
        return result

    @builtins.property
    def enabled(self) -> typing.Optional[builtins.bool]:
        result = self._values.get("enabled")
        return result

    def __eq__(self, rhs: typing.Any) -> builtins.bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs: typing.Any) -> builtins.bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return "AppServiceBackup(%s)" % ", ".join(
            k + "=" + repr(v) for k, v in self._values.items()
        )


@jsii.data_type(
    jsii_type="@cdktf/provider-azurerm.AppServiceBackupSchedule",
    jsii_struct_bases=[],
    name_mapping={
        "frequency_interval": "frequencyInterval",
        "frequency_unit": "frequencyUnit",
        "keep_at_least_one_backup": "keepAtLeastOneBackup",
        "retention_period_in_days": "retentionPeriodInDays",
        "start_time": "startTime",
    },
)
class AppServiceBackupSchedule:
    def __init__(
        self,
        *,
        frequency_interval: jsii.Number,
        frequency_unit: builtins.str,
        keep_at_least_one_backup: typing.Optional[builtins.bool] = None,
        retention_period_in_days: typing.Optional[jsii.Number] = None,
        start_time: typing.Optional[builtins.str] = None,
    ) -> None:
        """
        :param frequency_interval: 
        :param frequency_unit: 
        :param keep_at_least_one_backup: 
        :param retention_period_in_days: 
        :param start_time: 
        """
        self._values: typing.Dict[str, typing.Any] = {
            "frequency_interval": frequency_interval,
            "frequency_unit": frequency_unit,
        }
        if keep_at_least_one_backup is not None:
            self._values["keep_at_least_one_backup"] = keep_at_least_one_backup
        if retention_period_in_days is not None:
            self._values["retention_period_in_days"] = retention_period_in_days
        if start_time is not None:
            self._values["start_time"] = start_time

    @builtins.property
    def frequency_interval(self) -> jsii.Number:
        result = self._values.get("frequency_interval")
        assert result is not None, "Required property 'frequency_interval' is missing"
        return result

    @builtins.property
    def frequency_unit(self) -> builtins.str:
        result = self._values.get("frequency_unit")
        assert result is not None, "Required property 'frequency_unit' is missing"
        return result

    @builtins.property
    def keep_at_least_one_backup(self) -> typing.Optional[builtins.bool]:
        result = self._values.get("keep_at_least_one_backup")
        return result

    @builtins.property
    def retention_period_in_days(self) -> typing.Optional[jsii.Number]:
        result = self._values.get("retention_period_in_days")
        return result

    @builtins.property
    def start_time(self) -> typing.Optional[builtins.str]:
        result = self._values.get("start_time")
        return result

    def __eq__(self, rhs: typing.Any) -> builtins.bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs: typing.Any) -> builtins.bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return "AppServiceBackupSchedule(%s)" % ", ".join(
            k + "=" + repr(v) for k, v in self._values.items()
        )


class AppServiceCertificate(
    cdktf.TerraformResource,
    metaclass=jsii.JSIIMeta,
    jsii_type="@cdktf/provider-azurerm.AppServiceCertificate",
):
    def __init__(
        self,
        scope: constructs.Construct,
        id: builtins.str,
        *,
        location: builtins.str,
        name: builtins.str,
        resource_group_name: builtins.str,
        key_vault_secret_id: typing.Optional[builtins.str] = None,
        password: typing.Optional[builtins.str] = None,
        pfx_blob: typing.Optional[builtins.str] = None,
        tags: typing.Optional[typing.Mapping[builtins.str, builtins.str]] = None,
        timeouts: typing.Optional["AppServiceCertificateTimeouts"] = None,
        count: typing.Optional[jsii.Number] = None,
        depends_on: typing.Optional[typing.List[cdktf.TerraformResource]] = None,
        lifecycle: typing.Optional[cdktf.TerraformResourceLifecycle] = None,
        provider: typing.Optional[cdktf.TerraformProvider] = None,
    ) -> None:
        """
        :param scope: -
        :param id: -
        :param location: 
        :param name: 
        :param resource_group_name: 
        :param key_vault_secret_id: 
        :param password: 
        :param pfx_blob: 
        :param tags: 
        :param timeouts: timeouts block.
        :param count: 
        :param depends_on: 
        :param lifecycle: 
        :param provider: 
        """
        config = AppServiceCertificateConfig(
            location=location,
            name=name,
            resource_group_name=resource_group_name,
            key_vault_secret_id=key_vault_secret_id,
            password=password,
            pfx_blob=pfx_blob,
            tags=tags,
            timeouts=timeouts,
            count=count,
            depends_on=depends_on,
            lifecycle=lifecycle,
            provider=provider,
        )

        jsii.create(AppServiceCertificate, self, [scope, id, config])

    @jsii.member(jsii_name="synthesizeAttributes")
    def _synthesize_attributes(self) -> typing.Mapping[builtins.str, typing.Any]:
        return jsii.invoke(self, "synthesizeAttributes", [])

    @builtins.property # type: ignore
    @jsii.member(jsii_name="expirationDate")
    def expiration_date(self) -> builtins.str:
        return jsii.get(self, "expirationDate")

    @builtins.property # type: ignore
    @jsii.member(jsii_name="friendlyName")
    def friendly_name(self) -> builtins.str:
        return jsii.get(self, "friendlyName")

    @builtins.property # type: ignore
    @jsii.member(jsii_name="hostNames")
    def host_names(self) -> typing.List[builtins.str]:
        return jsii.get(self, "hostNames")

    @builtins.property # type: ignore
    @jsii.member(jsii_name="issueDate")
    def issue_date(self) -> builtins.str:
        return jsii.get(self, "issueDate")

    @builtins.property # type: ignore
    @jsii.member(jsii_name="issuer")
    def issuer(self) -> builtins.str:
        return jsii.get(self, "issuer")

    @builtins.property # type: ignore
    @jsii.member(jsii_name="subjectName")
    def subject_name(self) -> builtins.str:
        return jsii.get(self, "subjectName")

    @builtins.property # type: ignore
    @jsii.member(jsii_name="thumbprint")
    def thumbprint(self) -> builtins.str:
        return jsii.get(self, "thumbprint")

    @builtins.property # type: ignore
    @jsii.member(jsii_name="location")
    def location(self) -> builtins.str:
        return jsii.get(self, "location")

    @location.setter # type: ignore
    def location(self, value: builtins.str) -> None:
        jsii.set(self, "location", value)

    @builtins.property # type: ignore
    @jsii.member(jsii_name="name")
    def name(self) -> builtins.str:
        return jsii.get(self, "name")

    @name.setter # type: ignore
    def name(self, value: builtins.str) -> None:
        jsii.set(self, "name", value)

    @builtins.property # type: ignore
    @jsii.member(jsii_name="resourceGroupName")
    def resource_group_name(self) -> builtins.str:
        return jsii.get(self, "resourceGroupName")

    @resource_group_name.setter # type: ignore
    def resource_group_name(self, value: builtins.str) -> None:
        jsii.set(self, "resourceGroupName", value)

    @builtins.property # type: ignore
    @jsii.member(jsii_name="id")
    def id(self) -> typing.Optional[builtins.str]:
        return jsii.get(self, "id")

    @id.setter # type: ignore
    def id(self, value: typing.Optional[builtins.str]) -> None:
        jsii.set(self, "id", value)

    @builtins.property # type: ignore
    @jsii.member(jsii_name="keyVaultSecretId")
    def key_vault_secret_id(self) -> typing.Optional[builtins.str]:
        return jsii.get(self, "keyVaultSecretId")

    @key_vault_secret_id.setter # type: ignore
    def key_vault_secret_id(self, value: typing.Optional[builtins.str]) -> None:
        jsii.set(self, "keyVaultSecretId", value)

    @builtins.property # type: ignore
    @jsii.member(jsii_name="password")
    def password(self) -> typing.Optional[builtins.str]:
        return jsii.get(self, "password")

    @password.setter # type: ignore
    def password(self, value: typing.Optional[builtins.str]) -> None:
        jsii.set(self, "password", value)

    @builtins.property # type: ignore
    @jsii.member(jsii_name="pfxBlob")
    def pfx_blob(self) -> typing.Optional[builtins.str]:
        return jsii.get(self, "pfxBlob")

    @pfx_blob.setter # type: ignore
    def pfx_blob(self, value: typing.Optional[builtins.str]) -> None:
        jsii.set(self, "pfxBlob", value)

    @builtins.property # type: ignore
    @jsii.member(jsii_name="tags")
    def tags(self) -> typing.Optional[typing.Mapping[builtins.str, builtins.str]]:
        return jsii.get(self, "tags")

    @tags.setter # type: ignore
    def tags(
        self,
        value: typing.Optional[typing.Mapping[builtins.str, builtins.str]],
    ) -> None:
        jsii.set(self, "tags", value)

    @builtins.property # type: ignore
    @jsii.member(jsii_name="timeouts")
    def timeouts(self) -> typing.Optional["AppServiceCertificateTimeouts"]:
        return jsii.get(self, "timeouts")

    @timeouts.setter # type: ignore
    def timeouts(self, value: typing.Optional["AppServiceCertificateTimeouts"]) -> None:
        jsii.set(self, "timeouts", value)


@jsii.data_type(
    jsii_type="@cdktf/provider-azurerm.AppServiceCertificateConfig",
    jsii_struct_bases=[cdktf.TerraformMetaArguments],
    name_mapping={
        "count": "count",
        "depends_on": "dependsOn",
        "lifecycle": "lifecycle",
        "provider": "provider",
        "location": "location",
        "name": "name",
        "resource_group_name": "resourceGroupName",
        "key_vault_secret_id": "keyVaultSecretId",
        "password": "password",
        "pfx_blob": "pfxBlob",
        "tags": "tags",
        "timeouts": "timeouts",
    },
)
class AppServiceCertificateConfig(cdktf.TerraformMetaArguments):
    def __init__(
        self,
        *,
        count: typing.Optional[jsii.Number] = None,
        depends_on: typing.Optional[typing.List[cdktf.TerraformResource]] = None,
        lifecycle: typing.Optional[cdktf.TerraformResourceLifecycle] = None,
        provider: typing.Optional[cdktf.TerraformProvider] = None,
        location: builtins.str,
        name: builtins.str,
        resource_group_name: builtins.str,
        key_vault_secret_id: typing.Optional[builtins.str] = None,
        password: typing.Optional[builtins.str] = None,
        pfx_blob: typing.Optional[builtins.str] = None,
        tags: typing.Optional[typing.Mapping[builtins.str, builtins.str]] = None,
        timeouts: typing.Optional["AppServiceCertificateTimeouts"] = None,
    ) -> None:
        """
        :param count: 
        :param depends_on: 
        :param lifecycle: 
        :param provider: 
        :param location: 
        :param name: 
        :param resource_group_name: 
        :param key_vault_secret_id: 
        :param password: 
        :param pfx_blob: 
        :param tags: 
        :param timeouts: timeouts block.
        """
        if isinstance(lifecycle, dict):
            lifecycle = cdktf.TerraformResourceLifecycle(**lifecycle)
        if isinstance(timeouts, dict):
            timeouts = AppServiceCertificateTimeouts(**timeouts)
        self._values: typing.Dict[str, typing.Any] = {
            "location": location,
            "name": name,
            "resource_group_name": resource_group_name,
        }
        if count is not None:
            self._values["count"] = count
        if depends_on is not None:
            self._values["depends_on"] = depends_on
        if lifecycle is not None:
            self._values["lifecycle"] = lifecycle
        if provider is not None:
            self._values["provider"] = provider
        if key_vault_secret_id is not None:
            self._values["key_vault_secret_id"] = key_vault_secret_id
        if password is not None:
            self._values["password"] = password
        if pfx_blob is not None:
            self._values["pfx_blob"] = pfx_blob
        if tags is not None:
            self._values["tags"] = tags
        if timeouts is not None:
            self._values["timeouts"] = timeouts

    @builtins.property
    def count(self) -> typing.Optional[jsii.Number]:
        """
        :stability: experimental
        """
        result = self._values.get("count")
        return result

    @builtins.property
    def depends_on(self) -> typing.Optional[typing.List[cdktf.TerraformResource]]:
        """
        :stability: experimental
        """
        result = self._values.get("depends_on")
        return result

    @builtins.property
    def lifecycle(self) -> typing.Optional[cdktf.TerraformResourceLifecycle]:
        """
        :stability: experimental
        """
        result = self._values.get("lifecycle")
        return result

    @builtins.property
    def provider(self) -> typing.Optional[cdktf.TerraformProvider]:
        """
        :stability: experimental
        """
        result = self._values.get("provider")
        return result

    @builtins.property
    def location(self) -> builtins.str:
        result = self._values.get("location")
        assert result is not None, "Required property 'location' is missing"
        return result

    @builtins.property
    def name(self) -> builtins.str:
        result = self._values.get("name")
        assert result is not None, "Required property 'name' is missing"
        return result

    @builtins.property
    def resource_group_name(self) -> builtins.str:
        result = self._values.get("resource_group_name")
        assert result is not None, "Required property 'resource_group_name' is missing"
        return result

    @builtins.property
    def key_vault_secret_id(self) -> typing.Optional[builtins.str]:
        result = self._values.get("key_vault_secret_id")
        return result

    @builtins.property
    def password(self) -> typing.Optional[builtins.str]:
        result = self._values.get("password")
        return result

    @builtins.property
    def pfx_blob(self) -> typing.Optional[builtins.str]:
        result = self._values.get("pfx_blob")
        return result

    @builtins.property
    def tags(self) -> typing.Optional[typing.Mapping[builtins.str, builtins.str]]:
        result = self._values.get("tags")
        return result

    @builtins.property
    def timeouts(self) -> typing.Optional["AppServiceCertificateTimeouts"]:
        """timeouts block."""
        result = self._values.get("timeouts")
        return result

    def __eq__(self, rhs: typing.Any) -> builtins.bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs: typing.Any) -> builtins.bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return "AppServiceCertificateConfig(%s)" % ", ".join(
            k + "=" + repr(v) for k, v in self._values.items()
        )


class AppServiceCertificateOrder(
    cdktf.TerraformResource,
    metaclass=jsii.JSIIMeta,
    jsii_type="@cdktf/provider-azurerm.AppServiceCertificateOrder",
):
    def __init__(
        self,
        scope: constructs.Construct,
        id: builtins.str,
        *,
        location: builtins.str,
        name: builtins.str,
        resource_group_name: builtins.str,
        auto_renew: typing.Optional[builtins.bool] = None,
        csr: typing.Optional[builtins.str] = None,
        distinguished_name: typing.Optional[builtins.str] = None,
        key_size: typing.Optional[jsii.Number] = None,
        product_type: typing.Optional[builtins.str] = None,
        tags: typing.Optional[typing.Mapping[builtins.str, builtins.str]] = None,
        timeouts: typing.Optional["AppServiceCertificateOrderTimeouts"] = None,
        validity_in_years: typing.Optional[jsii.Number] = None,
        count: typing.Optional[jsii.Number] = None,
        depends_on: typing.Optional[typing.List[cdktf.TerraformResource]] = None,
        lifecycle: typing.Optional[cdktf.TerraformResourceLifecycle] = None,
        provider: typing.Optional[cdktf.TerraformProvider] = None,
    ) -> None:
        """
        :param scope: -
        :param id: -
        :param location: 
        :param name: 
        :param resource_group_name: 
        :param auto_renew: 
        :param csr: 
        :param distinguished_name: 
        :param key_size: 
        :param product_type: 
        :param tags: 
        :param timeouts: timeouts block.
        :param validity_in_years: 
        :param count: 
        :param depends_on: 
        :param lifecycle: 
        :param provider: 
        """
        config = AppServiceCertificateOrderConfig(
            location=location,
            name=name,
            resource_group_name=resource_group_name,
            auto_renew=auto_renew,
            csr=csr,
            distinguished_name=distinguished_name,
            key_size=key_size,
            product_type=product_type,
            tags=tags,
            timeouts=timeouts,
            validity_in_years=validity_in_years,
            count=count,
            depends_on=depends_on,
            lifecycle=lifecycle,
            provider=provider,
        )

        jsii.create(AppServiceCertificateOrder, self, [scope, id, config])

    @jsii.member(jsii_name="certificates")
    def certificates(
        self,
        index: builtins.str,
    ) -> "AppServiceCertificateOrderCertificates":
        """
        :param index: -
        """
        return jsii.invoke(self, "certificates", [index])

    @jsii.member(jsii_name="synthesizeAttributes")
    def _synthesize_attributes(self) -> typing.Mapping[builtins.str, typing.Any]:
        return jsii.invoke(self, "synthesizeAttributes", [])

    @builtins.property # type: ignore
    @jsii.member(jsii_name="appServiceCertificateNotRenewableReasons")
    def app_service_certificate_not_renewable_reasons(
        self,
    ) -> typing.List[builtins.str]:
        return jsii.get(self, "appServiceCertificateNotRenewableReasons")

    @builtins.property # type: ignore
    @jsii.member(jsii_name="domainVerificationToken")
    def domain_verification_token(self) -> builtins.str:
        return jsii.get(self, "domainVerificationToken")

    @builtins.property # type: ignore
    @jsii.member(jsii_name="expirationTime")
    def expiration_time(self) -> builtins.str:
        return jsii.get(self, "expirationTime")

    @builtins.property # type: ignore
    @jsii.member(jsii_name="intermediateThumbprint")
    def intermediate_thumbprint(self) -> builtins.str:
        return jsii.get(self, "intermediateThumbprint")

    @builtins.property # type: ignore
    @jsii.member(jsii_name="isPrivateKeyExternal")
    def is_private_key_external(self) -> builtins.bool:
        return jsii.get(self, "isPrivateKeyExternal")

    @builtins.property # type: ignore
    @jsii.member(jsii_name="rootThumbprint")
    def root_thumbprint(self) -> builtins.str:
        return jsii.get(self, "rootThumbprint")

    @builtins.property # type: ignore
    @jsii.member(jsii_name="signedCertificateThumbprint")
    def signed_certificate_thumbprint(self) -> builtins.str:
        return jsii.get(self, "signedCertificateThumbprint")

    @builtins.property # type: ignore
    @jsii.member(jsii_name="status")
    def status(self) -> builtins.str:
        return jsii.get(self, "status")

    @builtins.property # type: ignore
    @jsii.member(jsii_name="location")
    def location(self) -> builtins.str:
        return jsii.get(self, "location")

    @location.setter # type: ignore
    def location(self, value: builtins.str) -> None:
        jsii.set(self, "location", value)

    @builtins.property # type: ignore
    @jsii.member(jsii_name="name")
    def name(self) -> builtins.str:
        return jsii.get(self, "name")

    @name.setter # type: ignore
    def name(self, value: builtins.str) -> None:
        jsii.set(self, "name", value)

    @builtins.property # type: ignore
    @jsii.member(jsii_name="resourceGroupName")
    def resource_group_name(self) -> builtins.str:
        return jsii.get(self, "resourceGroupName")

    @resource_group_name.setter # type: ignore
    def resource_group_name(self, value: builtins.str) -> None:
        jsii.set(self, "resourceGroupName", value)

    @builtins.property # type: ignore
    @jsii.member(jsii_name="autoRenew")
    def auto_renew(self) -> typing.Optional[builtins.bool]:
        return jsii.get(self, "autoRenew")

    @auto_renew.setter # type: ignore
    def auto_renew(self, value: typing.Optional[builtins.bool]) -> None:
        jsii.set(self, "autoRenew", value)

    @builtins.property # type: ignore
    @jsii.member(jsii_name="csr")
    def csr(self) -> typing.Optional[builtins.str]:
        return jsii.get(self, "csr")

    @csr.setter # type: ignore
    def csr(self, value: typing.Optional[builtins.str]) -> None:
        jsii.set(self, "csr", value)

    @builtins.property # type: ignore
    @jsii.member(jsii_name="distinguishedName")
    def distinguished_name(self) -> typing.Optional[builtins.str]:
        return jsii.get(self, "distinguishedName")

    @distinguished_name.setter # type: ignore
    def distinguished_name(self, value: typing.Optional[builtins.str]) -> None:
        jsii.set(self, "distinguishedName", value)

    @builtins.property # type: ignore
    @jsii.member(jsii_name="id")
    def id(self) -> typing.Optional[builtins.str]:
        return jsii.get(self, "id")

    @id.setter # type: ignore
    def id(self, value: typing.Optional[builtins.str]) -> None:
        jsii.set(self, "id", value)

    @builtins.property # type: ignore
    @jsii.member(jsii_name="keySize")
    def key_size(self) -> typing.Optional[jsii.Number]:
        return jsii.get(self, "keySize")

    @key_size.setter # type: ignore
    def key_size(self, value: typing.Optional[jsii.Number]) -> None:
        jsii.set(self, "keySize", value)

    @builtins.property # type: ignore
    @jsii.member(jsii_name="productType")
    def product_type(self) -> typing.Optional[builtins.str]:
        return jsii.get(self, "productType")

    @product_type.setter # type: ignore
    def product_type(self, value: typing.Optional[builtins.str]) -> None:
        jsii.set(self, "productType", value)

    @builtins.property # type: ignore
    @jsii.member(jsii_name="tags")
    def tags(self) -> typing.Optional[typing.Mapping[builtins.str, builtins.str]]:
        return jsii.get(self, "tags")

    @tags.setter # type: ignore
    def tags(
        self,
        value: typing.Optional[typing.Mapping[builtins.str, builtins.str]],
    ) -> None:
        jsii.set(self, "tags", value)

    @builtins.property # type: ignore
    @jsii.member(jsii_name="timeouts")
    def timeouts(self) -> typing.Optional["AppServiceCertificateOrderTimeouts"]:
        return jsii.get(self, "timeouts")

    @timeouts.setter # type: ignore
    def timeouts(
        self,
        value: typing.Optional["AppServiceCertificateOrderTimeouts"],
    ) -> None:
        jsii.set(self, "timeouts", value)

    @builtins.property # type: ignore
    @jsii.member(jsii_name="validityInYears")
    def validity_in_years(self) -> typing.Optional[jsii.Number]:
        return jsii.get(self, "validityInYears")

    @validity_in_years.setter # type: ignore
    def validity_in_years(self, value: typing.Optional[jsii.Number]) -> None:
        jsii.set(self, "validityInYears", value)


class AppServiceCertificateOrderCertificates(
    cdktf.ComplexComputedList,
    metaclass=jsii.JSIIMeta,
    jsii_type="@cdktf/provider-azurerm.AppServiceCertificateOrderCertificates",
):
    def __init__(
        self,
        terraform_resource: cdktf.ITerraformResource,
        terraform_attribute: builtins.str,
        index: builtins.str,
    ) -> None:
        """
        :param terraform_resource: -
        :param terraform_attribute: -
        :param index: -

        :stability: experimental
        """
        jsii.create(AppServiceCertificateOrderCertificates, self, [terraform_resource, terraform_attribute, index])

    @builtins.property # type: ignore
    @jsii.member(jsii_name="certificateName")
    def certificate_name(self) -> builtins.str:
        return jsii.get(self, "certificateName")

    @builtins.property # type: ignore
    @jsii.member(jsii_name="keyVaultId")
    def key_vault_id(self) -> builtins.str:
        return jsii.get(self, "keyVaultId")

    @builtins.property # type: ignore
    @jsii.member(jsii_name="keyVaultSecretName")
    def key_vault_secret_name(self) -> builtins.str:
        return jsii.get(self, "keyVaultSecretName")

    @builtins.property # type: ignore
    @jsii.member(jsii_name="provisioningState")
    def provisioning_state(self) -> builtins.str:
        return jsii.get(self, "provisioningState")


@jsii.data_type(
    jsii_type="@cdktf/provider-azurerm.AppServiceCertificateOrderConfig",
    jsii_struct_bases=[cdktf.TerraformMetaArguments],
    name_mapping={
        "count": "count",
        "depends_on": "dependsOn",
        "lifecycle": "lifecycle",
        "provider": "provider",
        "location": "location",
        "name": "name",
        "resource_group_name": "resourceGroupName",
        "auto_renew": "autoRenew",
        "csr": "csr",
        "distinguished_name": "distinguishedName",
        "key_size": "keySize",
        "product_type": "productType",
        "tags": "tags",
        "timeouts": "timeouts",
        "validity_in_years": "validityInYears",
    },
)
class AppServiceCertificateOrderConfig(cdktf.TerraformMetaArguments):
    def __init__(
        self,
        *,
        count: typing.Optional[jsii.Number] = None,
        depends_on: typing.Optional[typing.List[cdktf.TerraformResource]] = None,
        lifecycle: typing.Optional[cdktf.TerraformResourceLifecycle] = None,
        provider: typing.Optional[cdktf.TerraformProvider] = None,
        location: builtins.str,
        name: builtins.str,
        resource_group_name: builtins.str,
        auto_renew: typing.Optional[builtins.bool] = None,
        csr: typing.Optional[builtins.str] = None,
        distinguished_name: typing.Optional[builtins.str] = None,
        key_size: typing.Optional[jsii.Number] = None,
        product_type: typing.Optional[builtins.str] = None,
        tags: typing.Optional[typing.Mapping[builtins.str, builtins.str]] = None,
        timeouts: typing.Optional["AppServiceCertificateOrderTimeouts"] = None,
        validity_in_years: typing.Optional[jsii.Number] = None,
    ) -> None:
        """
        :param count: 
        :param depends_on: 
        :param lifecycle: 
        :param provider: 
        :param location: 
        :param name: 
        :param resource_group_name: 
        :param auto_renew: 
        :param csr: 
        :param distinguished_name: 
        :param key_size: 
        :param product_type: 
        :param tags: 
        :param timeouts: timeouts block.
        :param validity_in_years: 
        """
        if isinstance(lifecycle, dict):
            lifecycle = cdktf.TerraformResourceLifecycle(**lifecycle)
        if isinstance(timeouts, dict):
            timeouts = AppServiceCertificateOrderTimeouts(**timeouts)
        self._values: typing.Dict[str, typing.Any] = {
            "location": location,
            "name": name,
            "resource_group_name": resource_group_name,
        }
        if count is not None:
            self._values["count"] = count
        if depends_on is not None:
            self._values["depends_on"] = depends_on
        if lifecycle is not None:
            self._values["lifecycle"] = lifecycle
        if provider is not None:
            self._values["provider"] = provider
        if auto_renew is not None:
            self._values["auto_renew"] = auto_renew
        if csr is not None:
            self._values["csr"] = csr
        if distinguished_name is not None:
            self._values["distinguished_name"] = distinguished_name
        if key_size is not None:
            self._values["key_size"] = key_size
        if product_type is not None:
            self._values["product_type"] = product_type
        if tags is not None:
            self._values["tags"] = tags
        if timeouts is not None:
            self._values["timeouts"] = timeouts
        if validity_in_years is not None:
            self._values["validity_in_years"] = validity_in_years

    @builtins.property
    def count(self) -> typing.Optional[jsii.Number]:
        """
        :stability: experimental
        """
        result = self._values.get("count")
        return result

    @builtins.property
    def depends_on(self) -> typing.Optional[typing.List[cdktf.TerraformResource]]:
        """
        :stability: experimental
        """
        result = self._values.get("depends_on")
        return result

    @builtins.property
    def lifecycle(self) -> typing.Optional[cdktf.TerraformResourceLifecycle]:
        """
        :stability: experimental
        """
        result = self._values.get("lifecycle")
        return result

    @builtins.property
    def provider(self) -> typing.Optional[cdktf.TerraformProvider]:
        """
        :stability: experimental
        """
        result = self._values.get("provider")
        return result

    @builtins.property
    def location(self) -> builtins.str:
        result = self._values.get("location")
        assert result is not None, "Required property 'location' is missing"
        return result

    @builtins.property
    def name(self) -> builtins.str:
        result = self._values.get("name")
        assert result is not None, "Required property 'name' is missing"
        return result

    @builtins.property
    def resource_group_name(self) -> builtins.str:
        result = self._values.get("resource_group_name")
        assert result is not None, "Required property 'resource_group_name' is missing"
        return result

    @builtins.property
    def auto_renew(self) -> typing.Optional[builtins.bool]:
        result = self._values.get("auto_renew")
        return result

    @builtins.property
    def csr(self) -> typing.Optional[builtins.str]:
        result = self._values.get("csr")
        return result

    @builtins.property
    def distinguished_name(self) -> typing.Optional[builtins.str]:
        result = self._values.get("distinguished_name")
        return result

    @builtins.property
    def key_size(self) -> typing.Optional[jsii.Number]:
        result = self._values.get("key_size")
        return result

    @builtins.property
    def product_type(self) -> typing.Optional[builtins.str]:
        result = self._values.get("product_type")
        return result

    @builtins.property
    def tags(self) -> typing.Optional[typing.Mapping[builtins.str, builtins.str]]:
        result = self._values.get("tags")
        return result

    @builtins.property
    def timeouts(self) -> typing.Optional["AppServiceCertificateOrderTimeouts"]:
        """timeouts block."""
        result = self._values.get("timeouts")
        return result

    @builtins.property
    def validity_in_years(self) -> typing.Optional[jsii.Number]:
        result = self._values.get("validity_in_years")
        return result

    def __eq__(self, rhs: typing.Any) -> builtins.bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs: typing.Any) -> builtins.bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return "AppServiceCertificateOrderConfig(%s)" % ", ".join(
            k + "=" + repr(v) for k, v in self._values.items()
        )


@jsii.data_type(
    jsii_type="@cdktf/provider-azurerm.AppServiceCertificateOrderTimeouts",
    jsii_struct_bases=[],
    name_mapping={
        "create": "create",
        "delete": "delete",
        "read": "read",
        "update": "update",
    },
)
class AppServiceCertificateOrderTimeouts:
    def __init__(
        self,
        *,
        create: typing.Optional[builtins.str] = None,
        delete: typing.Optional[builtins.str] = None,
        read: typing.Optional[builtins.str] = None,
        update: typing.Optional[builtins.str] = None,
    ) -> None:
        """
        :param create: 
        :param delete: 
        :param read: 
        :param update: 
        """
        self._values: typing.Dict[str, typing.Any] = {}
        if create is not None:
            self._values["create"] = create
        if delete is not None:
            self._values["delete"] = delete
        if read is not None:
            self._values["read"] = read
        if update is not None:
            self._values["update"] = update

    @builtins.property
    def create(self) -> typing.Optional[builtins.str]:
        result = self._values.get("create")
        return result

    @builtins.property
    def delete(self) -> typing.Optional[builtins.str]:
        result = self._values.get("delete")
        return result

    @builtins.property
    def read(self) -> typing.Optional[builtins.str]:
        result = self._values.get("read")
        return result

    @builtins.property
    def update(self) -> typing.Optional[builtins.str]:
        result = self._values.get("update")
        return result

    def __eq__(self, rhs: typing.Any) -> builtins.bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs: typing.Any) -> builtins.bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return "AppServiceCertificateOrderTimeouts(%s)" % ", ".join(
            k + "=" + repr(v) for k, v in self._values.items()
        )


@jsii.data_type(
    jsii_type="@cdktf/provider-azurerm.AppServiceCertificateTimeouts",
    jsii_struct_bases=[],
    name_mapping={
        "create": "create",
        "delete": "delete",
        "read": "read",
        "update": "update",
    },
)
class AppServiceCertificateTimeouts:
    def __init__(
        self,
        *,
        create: typing.Optional[builtins.str] = None,
        delete: typing.Optional[builtins.str] = None,
        read: typing.Optional[builtins.str] = None,
        update: typing.Optional[builtins.str] = None,
    ) -> None:
        """
        :param create: 
        :param delete: 
        :param read: 
        :param update: 
        """
        self._values: typing.Dict[str, typing.Any] = {}
        if create is not None:
            self._values["create"] = create
        if delete is not None:
            self._values["delete"] = delete
        if read is not None:
            self._values["read"] = read
        if update is not None:
            self._values["update"] = update

    @builtins.property
    def create(self) -> typing.Optional[builtins.str]:
        result = self._values.get("create")
        return result

    @builtins.property
    def delete(self) -> typing.Optional[builtins.str]:
        result = self._values.get("delete")
        return result

    @builtins.property
    def read(self) -> typing.Optional[builtins.str]:
        result = self._values.get("read")
        return result

    @builtins.property
    def update(self) -> typing.Optional[builtins.str]:
        result = self._values.get("update")
        return result

    def __eq__(self, rhs: typing.Any) -> builtins.bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs: typing.Any) -> builtins.bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return "AppServiceCertificateTimeouts(%s)" % ", ".join(
            k + "=" + repr(v) for k, v in self._values.items()
        )


@jsii.data_type(
    jsii_type="@cdktf/provider-azurerm.AppServiceConfig",
    jsii_struct_bases=[cdktf.TerraformMetaArguments],
    name_mapping={
        "count": "count",
        "depends_on": "dependsOn",
        "lifecycle": "lifecycle",
        "provider": "provider",
        "app_service_plan_id": "appServicePlanId",
        "location": "location",
        "name": "name",
        "resource_group_name": "resourceGroupName",
        "app_settings": "appSettings",
        "auth_settings": "authSettings",
        "backup": "backup",
        "client_affinity_enabled": "clientAffinityEnabled",
        "client_cert_enabled": "clientCertEnabled",
        "connection_string": "connectionString",
        "enabled": "enabled",
        "https_only": "httpsOnly",
        "identity": "identity",
        "logs": "logs",
        "site_config": "siteConfig",
        "storage_account": "storageAccount",
        "tags": "tags",
        "timeouts": "timeouts",
    },
)
class AppServiceConfig(cdktf.TerraformMetaArguments):
    def __init__(
        self,
        *,
        count: typing.Optional[jsii.Number] = None,
        depends_on: typing.Optional[typing.List[cdktf.TerraformResource]] = None,
        lifecycle: typing.Optional[cdktf.TerraformResourceLifecycle] = None,
        provider: typing.Optional[cdktf.TerraformProvider] = None,
        app_service_plan_id: builtins.str,
        location: builtins.str,
        name: builtins.str,
        resource_group_name: builtins.str,
        app_settings: typing.Optional[typing.Mapping[builtins.str, builtins.str]] = None,
        auth_settings: typing.Optional[typing.List[AppServiceAuthSettings]] = None,
        backup: typing.Optional[typing.List[AppServiceBackup]] = None,
        client_affinity_enabled: typing.Optional[builtins.bool] = None,
        client_cert_enabled: typing.Optional[builtins.bool] = None,
        connection_string: typing.Optional[typing.List["AppServiceConnectionString"]] = None,
        enabled: typing.Optional[builtins.bool] = None,
        https_only: typing.Optional[builtins.bool] = None,
        identity: typing.Optional[typing.List["AppServiceIdentity"]] = None,
        logs: typing.Optional[typing.List["AppServiceLogs"]] = None,
        site_config: typing.Optional[typing.List["AppServiceSiteConfig"]] = None,
        storage_account: typing.Optional[typing.List["AppServiceStorageAccount"]] = None,
        tags: typing.Optional[typing.Mapping[builtins.str, builtins.str]] = None,
        timeouts: typing.Optional["AppServiceTimeouts"] = None,
    ) -> None:
        """
        :param count: 
        :param depends_on: 
        :param lifecycle: 
        :param provider: 
        :param app_service_plan_id: 
        :param location: 
        :param name: 
        :param resource_group_name: 
        :param app_settings: 
        :param auth_settings: auth_settings block.
        :param backup: backup block.
        :param client_affinity_enabled: 
        :param client_cert_enabled: 
        :param connection_string: connection_string block.
        :param enabled: 
        :param https_only: 
        :param identity: identity block.
        :param logs: logs block.
        :param site_config: site_config block.
        :param storage_account: storage_account block.
        :param tags: 
        :param timeouts: timeouts block.
        """
        if isinstance(lifecycle, dict):
            lifecycle = cdktf.TerraformResourceLifecycle(**lifecycle)
        if isinstance(timeouts, dict):
            timeouts = AppServiceTimeouts(**timeouts)
        self._values: typing.Dict[str, typing.Any] = {
            "app_service_plan_id": app_service_plan_id,
            "location": location,
            "name": name,
            "resource_group_name": resource_group_name,
        }
        if count is not None:
            self._values["count"] = count
        if depends_on is not None:
            self._values["depends_on"] = depends_on
        if lifecycle is not None:
            self._values["lifecycle"] = lifecycle
        if provider is not None:
            self._values["provider"] = provider
        if app_settings is not None:
            self._values["app_settings"] = app_settings
        if auth_settings is not None:
            self._values["auth_settings"] = auth_settings
        if backup is not None:
            self._values["backup"] = backup
        if client_affinity_enabled is not None:
            self._values["client_affinity_enabled"] = client_affinity_enabled
        if client_cert_enabled is not None:
            self._values["client_cert_enabled"] = client_cert_enabled
        if connection_string is not None:
            self._values["connection_string"] = connection_string
        if enabled is not None:
            self._values["enabled"] = enabled
        if https_only is not None:
            self._values["https_only"] = https_only
        if identity is not None:
            self._values["identity"] = identity
        if logs is not None:
            self._values["logs"] = logs
        if site_config is not None:
            self._values["site_config"] = site_config
        if storage_account is not None:
            self._values["storage_account"] = storage_account
        if tags is not None:
            self._values["tags"] = tags
        if timeouts is not None:
            self._values["timeouts"] = timeouts

    @builtins.property
    def count(self) -> typing.Optional[jsii.Number]:
        """
        :stability: experimental
        """
        result = self._values.get("count")
        return result

    @builtins.property
    def depends_on(self) -> typing.Optional[typing.List[cdktf.TerraformResource]]:
        """
        :stability: experimental
        """
        result = self._values.get("depends_on")
        return result

    @builtins.property
    def lifecycle(self) -> typing.Optional[cdktf.TerraformResourceLifecycle]:
        """
        :stability: experimental
        """
        result = self._values.get("lifecycle")
        return result

    @builtins.property
    def provider(self) -> typing.Optional[cdktf.TerraformProvider]:
        """
        :stability: experimental
        """
        result = self._values.get("provider")
        return result

    @builtins.property
    def app_service_plan_id(self) -> builtins.str:
        result = self._values.get("app_service_plan_id")
        assert result is not None, "Required property 'app_service_plan_id' is missing"
        return result

    @builtins.property
    def location(self) -> builtins.str:
        result = self._values.get("location")
        assert result is not None, "Required property 'location' is missing"
        return result

    @builtins.property
    def name(self) -> builtins.str:
        result = self._values.get("name")
        assert result is not None, "Required property 'name' is missing"
        return result

    @builtins.property
    def resource_group_name(self) -> builtins.str:
        result = self._values.get("resource_group_name")
        assert result is not None, "Required property 'resource_group_name' is missing"
        return result

    @builtins.property
    def app_settings(
        self,
    ) -> typing.Optional[typing.Mapping[builtins.str, builtins.str]]:
        result = self._values.get("app_settings")
        return result

    @builtins.property
    def auth_settings(self) -> typing.Optional[typing.List[AppServiceAuthSettings]]:
        """auth_settings block."""
        result = self._values.get("auth_settings")
        return result

    @builtins.property
    def backup(self) -> typing.Optional[typing.List[AppServiceBackup]]:
        """backup block."""
        result = self._values.get("backup")
        return result

    @builtins.property
    def client_affinity_enabled(self) -> typing.Optional[builtins.bool]:
        result = self._values.get("client_affinity_enabled")
        return result

    @builtins.property
    def client_cert_enabled(self) -> typing.Optional[builtins.bool]:
        result = self._values.get("client_cert_enabled")
        return result

    @builtins.property
    def connection_string(
        self,
    ) -> typing.Optional[typing.List["AppServiceConnectionString"]]:
        """connection_string block."""
        result = self._values.get("connection_string")
        return result

    @builtins.property
    def enabled(self) -> typing.Optional[builtins.bool]:
        result = self._values.get("enabled")
        return result

    @builtins.property
    def https_only(self) -> typing.Optional[builtins.bool]:
        result = self._values.get("https_only")
        return result

    @builtins.property
    def identity(self) -> typing.Optional[typing.List["AppServiceIdentity"]]:
        """identity block."""
        result = self._values.get("identity")
        return result

    @builtins.property
    def logs(self) -> typing.Optional[typing.List["AppServiceLogs"]]:
        """logs block."""
        result = self._values.get("logs")
        return result

    @builtins.property
    def site_config(self) -> typing.Optional[typing.List["AppServiceSiteConfig"]]:
        """site_config block."""
        result = self._values.get("site_config")
        return result

    @builtins.property
    def storage_account(
        self,
    ) -> typing.Optional[typing.List["AppServiceStorageAccount"]]:
        """storage_account block."""
        result = self._values.get("storage_account")
        return result

    @builtins.property
    def tags(self) -> typing.Optional[typing.Mapping[builtins.str, builtins.str]]:
        result = self._values.get("tags")
        return result

    @builtins.property
    def timeouts(self) -> typing.Optional["AppServiceTimeouts"]:
        """timeouts block."""
        result = self._values.get("timeouts")
        return result

    def __eq__(self, rhs: typing.Any) -> builtins.bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs: typing.Any) -> builtins.bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return "AppServiceConfig(%s)" % ", ".join(
            k + "=" + repr(v) for k, v in self._values.items()
        )


@jsii.data_type(
    jsii_type="@cdktf/provider-azurerm.AppServiceConnectionString",
    jsii_struct_bases=[],
    name_mapping={"name": "name", "type": "type", "value": "value"},
)
class AppServiceConnectionString:
    def __init__(
        self,
        *,
        name: builtins.str,
        type: builtins.str,
        value: builtins.str,
    ) -> None:
        """
        :param name: 
        :param type: 
        :param value: 
        """
        self._values: typing.Dict[str, typing.Any] = {
            "name": name,
            "type": type,
            "value": value,
        }

    @builtins.property
    def name(self) -> builtins.str:
        result = self._values.get("name")
        assert result is not None, "Required property 'name' is missing"
        return result

    @builtins.property
    def type(self) -> builtins.str:
        result = self._values.get("type")
        assert result is not None, "Required property 'type' is missing"
        return result

    @builtins.property
    def value(self) -> builtins.str:
        result = self._values.get("value")
        assert result is not None, "Required property 'value' is missing"
        return result

    def __eq__(self, rhs: typing.Any) -> builtins.bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs: typing.Any) -> builtins.bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return "AppServiceConnectionString(%s)" % ", ".join(
            k + "=" + repr(v) for k, v in self._values.items()
        )


class AppServiceCustomHostnameBinding(
    cdktf.TerraformResource,
    metaclass=jsii.JSIIMeta,
    jsii_type="@cdktf/provider-azurerm.AppServiceCustomHostnameBinding",
):
    def __init__(
        self,
        scope: constructs.Construct,
        id: builtins.str,
        *,
        app_service_name: builtins.str,
        hostname: builtins.str,
        resource_group_name: builtins.str,
        ssl_state: typing.Optional[builtins.str] = None,
        thumbprint: typing.Optional[builtins.str] = None,
        timeouts: typing.Optional["AppServiceCustomHostnameBindingTimeouts"] = None,
        count: typing.Optional[jsii.Number] = None,
        depends_on: typing.Optional[typing.List[cdktf.TerraformResource]] = None,
        lifecycle: typing.Optional[cdktf.TerraformResourceLifecycle] = None,
        provider: typing.Optional[cdktf.TerraformProvider] = None,
    ) -> None:
        """
        :param scope: -
        :param id: -
        :param app_service_name: 
        :param hostname: 
        :param resource_group_name: 
        :param ssl_state: 
        :param thumbprint: 
        :param timeouts: timeouts block.
        :param count: 
        :param depends_on: 
        :param lifecycle: 
        :param provider: 
        """
        config = AppServiceCustomHostnameBindingConfig(
            app_service_name=app_service_name,
            hostname=hostname,
            resource_group_name=resource_group_name,
            ssl_state=ssl_state,
            thumbprint=thumbprint,
            timeouts=timeouts,
            count=count,
            depends_on=depends_on,
            lifecycle=lifecycle,
            provider=provider,
        )

        jsii.create(AppServiceCustomHostnameBinding, self, [scope, id, config])

    @jsii.member(jsii_name="synthesizeAttributes")
    def _synthesize_attributes(self) -> typing.Mapping[builtins.str, typing.Any]:
        return jsii.invoke(self, "synthesizeAttributes", [])

    @builtins.property # type: ignore
    @jsii.member(jsii_name="virtualIp")
    def virtual_ip(self) -> builtins.str:
        return jsii.get(self, "virtualIp")

    @builtins.property # type: ignore
    @jsii.member(jsii_name="appServiceName")
    def app_service_name(self) -> builtins.str:
        return jsii.get(self, "appServiceName")

    @app_service_name.setter # type: ignore
    def app_service_name(self, value: builtins.str) -> None:
        jsii.set(self, "appServiceName", value)

    @builtins.property # type: ignore
    @jsii.member(jsii_name="hostname")
    def hostname(self) -> builtins.str:
        return jsii.get(self, "hostname")

    @hostname.setter # type: ignore
    def hostname(self, value: builtins.str) -> None:
        jsii.set(self, "hostname", value)

    @builtins.property # type: ignore
    @jsii.member(jsii_name="resourceGroupName")
    def resource_group_name(self) -> builtins.str:
        return jsii.get(self, "resourceGroupName")

    @resource_group_name.setter # type: ignore
    def resource_group_name(self, value: builtins.str) -> None:
        jsii.set(self, "resourceGroupName", value)

    @builtins.property # type: ignore
    @jsii.member(jsii_name="id")
    def id(self) -> typing.Optional[builtins.str]:
        return jsii.get(self, "id")

    @id.setter # type: ignore
    def id(self, value: typing.Optional[builtins.str]) -> None:
        jsii.set(self, "id", value)

    @builtins.property # type: ignore
    @jsii.member(jsii_name="sslState")
    def ssl_state(self) -> typing.Optional[builtins.str]:
        return jsii.get(self, "sslState")

    @ssl_state.setter # type: ignore
    def ssl_state(self, value: typing.Optional[builtins.str]) -> None:
        jsii.set(self, "sslState", value)

    @builtins.property # type: ignore
    @jsii.member(jsii_name="thumbprint")
    def thumbprint(self) -> typing.Optional[builtins.str]:
        return jsii.get(self, "thumbprint")

    @thumbprint.setter # type: ignore
    def thumbprint(self, value: typing.Optional[builtins.str]) -> None:
        jsii.set(self, "thumbprint", value)

    @builtins.property # type: ignore
    @jsii.member(jsii_name="timeouts")
    def timeouts(self) -> typing.Optional["AppServiceCustomHostnameBindingTimeouts"]:
        return jsii.get(self, "timeouts")

    @timeouts.setter # type: ignore
    def timeouts(
        self,
        value: typing.Optional["AppServiceCustomHostnameBindingTimeouts"],
    ) -> None:
        jsii.set(self, "timeouts", value)


@jsii.data_type(
    jsii_type="@cdktf/provider-azurerm.AppServiceCustomHostnameBindingConfig",
    jsii_struct_bases=[cdktf.TerraformMetaArguments],
    name_mapping={
        "count": "count",
        "depends_on": "dependsOn",
        "lifecycle": "lifecycle",
        "provider": "provider",
        "app_service_name": "appServiceName",
        "hostname": "hostname",
        "resource_group_name": "resourceGroupName",
        "ssl_state": "sslState",
        "thumbprint": "thumbprint",
        "timeouts": "timeouts",
    },
)
class AppServiceCustomHostnameBindingConfig(cdktf.TerraformMetaArguments):
    def __init__(
        self,
        *,
        count: typing.Optional[jsii.Number] = None,
        depends_on: typing.Optional[typing.List[cdktf.TerraformResource]] = None,
        lifecycle: typing.Optional[cdktf.TerraformResourceLifecycle] = None,
        provider: typing.Optional[cdktf.TerraformProvider] = None,
        app_service_name: builtins.str,
        hostname: builtins.str,
        resource_group_name: builtins.str,
        ssl_state: typing.Optional[builtins.str] = None,
        thumbprint: typing.Optional[builtins.str] = None,
        timeouts: typing.Optional["AppServiceCustomHostnameBindingTimeouts"] = None,
    ) -> None:
        """
        :param count: 
        :param depends_on: 
        :param lifecycle: 
        :param provider: 
        :param app_service_name: 
        :param hostname: 
        :param resource_group_name: 
        :param ssl_state: 
        :param thumbprint: 
        :param timeouts: timeouts block.
        """
        if isinstance(lifecycle, dict):
            lifecycle = cdktf.TerraformResourceLifecycle(**lifecycle)
        if isinstance(timeouts, dict):
            timeouts = AppServiceCustomHostnameBindingTimeouts(**timeouts)
        self._values: typing.Dict[str, typing.Any] = {
            "app_service_name": app_service_name,
            "hostname": hostname,
            "resource_group_name": resource_group_name,
        }
        if count is not None:
            self._values["count"] = count
        if depends_on is not None:
            self._values["depends_on"] = depends_on
        if lifecycle is not None:
            self._values["lifecycle"] = lifecycle
        if provider is not None:
            self._values["provider"] = provider
        if ssl_state is not None:
            self._values["ssl_state"] = ssl_state
        if thumbprint is not None:
            self._values["thumbprint"] = thumbprint
        if timeouts is not None:
            self._values["timeouts"] = timeouts

    @builtins.property
    def count(self) -> typing.Optional[jsii.Number]:
        """
        :stability: experimental
        """
        result = self._values.get("count")
        return result

    @builtins.property
    def depends_on(self) -> typing.Optional[typing.List[cdktf.TerraformResource]]:
        """
        :stability: experimental
        """
        result = self._values.get("depends_on")
        return result

    @builtins.property
    def lifecycle(self) -> typing.Optional[cdktf.TerraformResourceLifecycle]:
        """
        :stability: experimental
        """
        result = self._values.get("lifecycle")
        return result

    @builtins.property
    def provider(self) -> typing.Optional[cdktf.TerraformProvider]:
        """
        :stability: experimental
        """
        result = self._values.get("provider")
        return result

    @builtins.property
    def app_service_name(self) -> builtins.str:
        result = self._values.get("app_service_name")
        assert result is not None, "Required property 'app_service_name' is missing"
        return result

    @builtins.property
    def hostname(self) -> builtins.str:
        result = self._values.get("hostname")
        assert result is not None, "Required property 'hostname' is missing"
        return result

    @builtins.property
    def resource_group_name(self) -> builtins.str:
        result = self._values.get("resource_group_name")
        assert result is not None, "Required property 'resource_group_name' is missing"
        return result

    @builtins.property
    def ssl_state(self) -> typing.Optional[builtins.str]:
        result = self._values.get("ssl_state")
        return result

    @builtins.property
    def thumbprint(self) -> typing.Optional[builtins.str]:
        result = self._values.get("thumbprint")
        return result

    @builtins.property
    def timeouts(self) -> typing.Optional["AppServiceCustomHostnameBindingTimeouts"]:
        """timeouts block."""
        result = self._values.get("timeouts")
        return result

    def __eq__(self, rhs: typing.Any) -> builtins.bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs: typing.Any) -> builtins.bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return "AppServiceCustomHostnameBindingConfig(%s)" % ", ".join(
            k + "=" + repr(v) for k, v in self._values.items()
        )


@jsii.data_type(
    jsii_type="@cdktf/provider-azurerm.AppServiceCustomHostnameBindingTimeouts",
    jsii_struct_bases=[],
    name_mapping={
        "create": "create",
        "delete": "delete",
        "read": "read",
        "update": "update",
    },
)
class AppServiceCustomHostnameBindingTimeouts:
    def __init__(
        self,
        *,
        create: typing.Optional[builtins.str] = None,
        delete: typing.Optional[builtins.str] = None,
        read: typing.Optional[builtins.str] = None,
        update: typing.Optional[builtins.str] = None,
    ) -> None:
        """
        :param create: 
        :param delete: 
        :param read: 
        :param update: 
        """
        self._values: typing.Dict[str, typing.Any] = {}
        if create is not None:
            self._values["create"] = create
        if delete is not None:
            self._values["delete"] = delete
        if read is not None:
            self._values["read"] = read
        if update is not None:
            self._values["update"] = update

    @builtins.property
    def create(self) -> typing.Optional[builtins.str]:
        result = self._values.get("create")
        return result

    @builtins.property
    def delete(self) -> typing.Optional[builtins.str]:
        result = self._values.get("delete")
        return result

    @builtins.property
    def read(self) -> typing.Optional[builtins.str]:
        result = self._values.get("read")
        return result

    @builtins.property
    def update(self) -> typing.Optional[builtins.str]:
        result = self._values.get("update")
        return result

    def __eq__(self, rhs: typing.Any) -> builtins.bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs: typing.Any) -> builtins.bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return "AppServiceCustomHostnameBindingTimeouts(%s)" % ", ".join(
            k + "=" + repr(v) for k, v in self._values.items()
        )


class AppServiceEnvironment(
    cdktf.TerraformResource,
    metaclass=jsii.JSIIMeta,
    jsii_type="@cdktf/provider-azurerm.AppServiceEnvironment",
):
    def __init__(
        self,
        scope: constructs.Construct,
        id: builtins.str,
        *,
        name: builtins.str,
        subnet_id: builtins.str,
        front_end_scale_factor: typing.Optional[jsii.Number] = None,
        internal_load_balancing_mode: typing.Optional[builtins.str] = None,
        pricing_tier: typing.Optional[builtins.str] = None,
        tags: typing.Optional[typing.Mapping[builtins.str, builtins.str]] = None,
        timeouts: typing.Optional["AppServiceEnvironmentTimeouts"] = None,
        count: typing.Optional[jsii.Number] = None,
        depends_on: typing.Optional[typing.List[cdktf.TerraformResource]] = None,
        lifecycle: typing.Optional[cdktf.TerraformResourceLifecycle] = None,
        provider: typing.Optional[cdktf.TerraformProvider] = None,
    ) -> None:
        """
        :param scope: -
        :param id: -
        :param name: 
        :param subnet_id: 
        :param front_end_scale_factor: 
        :param internal_load_balancing_mode: 
        :param pricing_tier: 
        :param tags: 
        :param timeouts: timeouts block.
        :param count: 
        :param depends_on: 
        :param lifecycle: 
        :param provider: 
        """
        config = AppServiceEnvironmentConfig(
            name=name,
            subnet_id=subnet_id,
            front_end_scale_factor=front_end_scale_factor,
            internal_load_balancing_mode=internal_load_balancing_mode,
            pricing_tier=pricing_tier,
            tags=tags,
            timeouts=timeouts,
            count=count,
            depends_on=depends_on,
            lifecycle=lifecycle,
            provider=provider,
        )

        jsii.create(AppServiceEnvironment, self, [scope, id, config])

    @jsii.member(jsii_name="synthesizeAttributes")
    def _synthesize_attributes(self) -> typing.Mapping[builtins.str, typing.Any]:
        return jsii.invoke(self, "synthesizeAttributes", [])

    @builtins.property # type: ignore
    @jsii.member(jsii_name="location")
    def location(self) -> builtins.str:
        return jsii.get(self, "location")

    @builtins.property # type: ignore
    @jsii.member(jsii_name="resourceGroupName")
    def resource_group_name(self) -> builtins.str:
        return jsii.get(self, "resourceGroupName")

    @builtins.property # type: ignore
    @jsii.member(jsii_name="name")
    def name(self) -> builtins.str:
        return jsii.get(self, "name")

    @name.setter # type: ignore
    def name(self, value: builtins.str) -> None:
        jsii.set(self, "name", value)

    @builtins.property # type: ignore
    @jsii.member(jsii_name="subnetId")
    def subnet_id(self) -> builtins.str:
        return jsii.get(self, "subnetId")

    @subnet_id.setter # type: ignore
    def subnet_id(self, value: builtins.str) -> None:
        jsii.set(self, "subnetId", value)

    @builtins.property # type: ignore
    @jsii.member(jsii_name="frontEndScaleFactor")
    def front_end_scale_factor(self) -> typing.Optional[jsii.Number]:
        return jsii.get(self, "frontEndScaleFactor")

    @front_end_scale_factor.setter # type: ignore
    def front_end_scale_factor(self, value: typing.Optional[jsii.Number]) -> None:
        jsii.set(self, "frontEndScaleFactor", value)

    @builtins.property # type: ignore
    @jsii.member(jsii_name="id")
    def id(self) -> typing.Optional[builtins.str]:
        return jsii.get(self, "id")

    @id.setter # type: ignore
    def id(self, value: typing.Optional[builtins.str]) -> None:
        jsii.set(self, "id", value)

    @builtins.property # type: ignore
    @jsii.member(jsii_name="internalLoadBalancingMode")
    def internal_load_balancing_mode(self) -> typing.Optional[builtins.str]:
        return jsii.get(self, "internalLoadBalancingMode")

    @internal_load_balancing_mode.setter # type: ignore
    def internal_load_balancing_mode(
        self,
        value: typing.Optional[builtins.str],
    ) -> None:
        jsii.set(self, "internalLoadBalancingMode", value)

    @builtins.property # type: ignore
    @jsii.member(jsii_name="pricingTier")
    def pricing_tier(self) -> typing.Optional[builtins.str]:
        return jsii.get(self, "pricingTier")

    @pricing_tier.setter # type: ignore
    def pricing_tier(self, value: typing.Optional[builtins.str]) -> None:
        jsii.set(self, "pricingTier", value)

    @builtins.property # type: ignore
    @jsii.member(jsii_name="tags")
    def tags(self) -> typing.Optional[typing.Mapping[builtins.str, builtins.str]]:
        return jsii.get(self, "tags")

    @tags.setter # type: ignore
    def tags(
        self,
        value: typing.Optional[typing.Mapping[builtins.str, builtins.str]],
    ) -> None:
        jsii.set(self, "tags", value)

    @builtins.property # type: ignore
    @jsii.member(jsii_name="timeouts")
    def timeouts(self) -> typing.Optional["AppServiceEnvironmentTimeouts"]:
        return jsii.get(self, "timeouts")

    @timeouts.setter # type: ignore
    def timeouts(self, value: typing.Optional["AppServiceEnvironmentTimeouts"]) -> None:
        jsii.set(self, "timeouts", value)


@jsii.data_type(
    jsii_type="@cdktf/provider-azurerm.AppServiceEnvironmentConfig",
    jsii_struct_bases=[cdktf.TerraformMetaArguments],
    name_mapping={
        "count": "count",
        "depends_on": "dependsOn",
        "lifecycle": "lifecycle",
        "provider": "provider",
        "name": "name",
        "subnet_id": "subnetId",
        "front_end_scale_factor": "frontEndScaleFactor",
        "internal_load_balancing_mode": "internalLoadBalancingMode",
        "pricing_tier": "pricingTier",
        "tags": "tags",
        "timeouts": "timeouts",
    },
)
class AppServiceEnvironmentConfig(cdktf.TerraformMetaArguments):
    def __init__(
        self,
        *,
        count: typing.Optional[jsii.Number] = None,
        depends_on: typing.Optional[typing.List[cdktf.TerraformResource]] = None,
        lifecycle: typing.Optional[cdktf.TerraformResourceLifecycle] = None,
        provider: typing.Optional[cdktf.TerraformProvider] = None,
        name: builtins.str,
        subnet_id: builtins.str,
        front_end_scale_factor: typing.Optional[jsii.Number] = None,
        internal_load_balancing_mode: typing.Optional[builtins.str] = None,
        pricing_tier: typing.Optional[builtins.str] = None,
        tags: typing.Optional[typing.Mapping[builtins.str, builtins.str]] = None,
        timeouts: typing.Optional["AppServiceEnvironmentTimeouts"] = None,
    ) -> None:
        """
        :param count: 
        :param depends_on: 
        :param lifecycle: 
        :param provider: 
        :param name: 
        :param subnet_id: 
        :param front_end_scale_factor: 
        :param internal_load_balancing_mode: 
        :param pricing_tier: 
        :param tags: 
        :param timeouts: timeouts block.
        """
        if isinstance(lifecycle, dict):
            lifecycle = cdktf.TerraformResourceLifecycle(**lifecycle)
        if isinstance(timeouts, dict):
            timeouts = AppServiceEnvironmentTimeouts(**timeouts)
        self._values: typing.Dict[str, typing.Any] = {
            "name": name,
            "subnet_id": subnet_id,
        }
        if count is not None:
            self._values["count"] = count
        if depends_on is not None:
            self._values["depends_on"] = depends_on
        if lifecycle is not None:
            self._values["lifecycle"] = lifecycle
        if provider is not None:
            self._values["provider"] = provider
        if front_end_scale_factor is not None:
            self._values["front_end_scale_factor"] = front_end_scale_factor
        if internal_load_balancing_mode is not None:
            self._values["internal_load_balancing_mode"] = internal_load_balancing_mode
        if pricing_tier is not None:
            self._values["pricing_tier"] = pricing_tier
        if tags is not None:
            self._values["tags"] = tags
        if timeouts is not None:
            self._values["timeouts"] = timeouts

    @builtins.property
    def count(self) -> typing.Optional[jsii.Number]:
        """
        :stability: experimental
        """
        result = self._values.get("count")
        return result

    @builtins.property
    def depends_on(self) -> typing.Optional[typing.List[cdktf.TerraformResource]]:
        """
        :stability: experimental
        """
        result = self._values.get("depends_on")
        return result

    @builtins.property
    def lifecycle(self) -> typing.Optional[cdktf.TerraformResourceLifecycle]:
        """
        :stability: experimental
        """
        result = self._values.get("lifecycle")
        return result

    @builtins.property
    def provider(self) -> typing.Optional[cdktf.TerraformProvider]:
        """
        :stability: experimental
        """
        result = self._values.get("provider")
        return result

    @builtins.property
    def name(self) -> builtins.str:
        result = self._values.get("name")
        assert result is not None, "Required property 'name' is missing"
        return result

    @builtins.property
    def subnet_id(self) -> builtins.str:
        result = self._values.get("subnet_id")
        assert result is not None, "Required property 'subnet_id' is missing"
        return result

    @builtins.property
    def front_end_scale_factor(self) -> typing.Optional[jsii.Number]:
        result = self._values.get("front_end_scale_factor")
        return result

    @builtins.property
    def internal_load_balancing_mode(self) -> typing.Optional[builtins.str]:
        result = self._values.get("internal_load_balancing_mode")
        return result

    @builtins.property
    def pricing_tier(self) -> typing.Optional[builtins.str]:
        result = self._values.get("pricing_tier")
        return result

    @builtins.property
    def tags(self) -> typing.Optional[typing.Mapping[builtins.str, builtins.str]]:
        result = self._values.get("tags")
        return result

    @builtins.property
    def timeouts(self) -> typing.Optional["AppServiceEnvironmentTimeouts"]:
        """timeouts block."""
        result = self._values.get("timeouts")
        return result

    def __eq__(self, rhs: typing.Any) -> builtins.bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs: typing.Any) -> builtins.bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return "AppServiceEnvironmentConfig(%s)" % ", ".join(
            k + "=" + repr(v) for k, v in self._values.items()
        )


@jsii.data_type(
    jsii_type="@cdktf/provider-azurerm.AppServiceEnvironmentTimeouts",
    jsii_struct_bases=[],
    name_mapping={
        "create": "create",
        "delete": "delete",
        "read": "read",
        "update": "update",
    },
)
class AppServiceEnvironmentTimeouts:
    def __init__(
        self,
        *,
        create: typing.Optional[builtins.str] = None,
        delete: typing.Optional[builtins.str] = None,
        read: typing.Optional[builtins.str] = None,
        update: typing.Optional[builtins.str] = None,
    ) -> None:
        """
        :param create: 
        :param delete: 
        :param read: 
        :param update: 
        """
        self._values: typing.Dict[str, typing.Any] = {}
        if create is not None:
            self._values["create"] = create
        if delete is not None:
            self._values["delete"] = delete
        if read is not None:
            self._values["read"] = read
        if update is not None:
            self._values["update"] = update

    @builtins.property
    def create(self) -> typing.Optional[builtins.str]:
        result = self._values.get("create")
        return result

    @builtins.property
    def delete(self) -> typing.Optional[builtins.str]:
        result = self._values.get("delete")
        return result

    @builtins.property
    def read(self) -> typing.Optional[builtins.str]:
        result = self._values.get("read")
        return result

    @builtins.property
    def update(self) -> typing.Optional[builtins.str]:
        result = self._values.get("update")
        return result

    def __eq__(self, rhs: typing.Any) -> builtins.bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs: typing.Any) -> builtins.bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return "AppServiceEnvironmentTimeouts(%s)" % ", ".join(
            k + "=" + repr(v) for k, v in self._values.items()
        )


@jsii.data_type(
    jsii_type="@cdktf/provider-azurerm.AppServiceIdentity",
    jsii_struct_bases=[],
    name_mapping={"type": "type", "identity_ids": "identityIds"},
)
class AppServiceIdentity:
    def __init__(
        self,
        *,
        type: builtins.str,
        identity_ids: typing.Optional[typing.List[builtins.str]] = None,
    ) -> None:
        """
        :param type: 
        :param identity_ids: 
        """
        self._values: typing.Dict[str, typing.Any] = {
            "type": type,
        }
        if identity_ids is not None:
            self._values["identity_ids"] = identity_ids

    @builtins.property
    def type(self) -> builtins.str:
        result = self._values.get("type")
        assert result is not None, "Required property 'type' is missing"
        return result

    @builtins.property
    def identity_ids(self) -> typing.Optional[typing.List[builtins.str]]:
        result = self._values.get("identity_ids")
        return result

    def __eq__(self, rhs: typing.Any) -> builtins.bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs: typing.Any) -> builtins.bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return "AppServiceIdentity(%s)" % ", ".join(
            k + "=" + repr(v) for k, v in self._values.items()
        )


@jsii.data_type(
    jsii_type="@cdktf/provider-azurerm.AppServiceLogs",
    jsii_struct_bases=[],
    name_mapping={"application_logs": "applicationLogs", "http_logs": "httpLogs"},
)
class AppServiceLogs:
    def __init__(
        self,
        *,
        application_logs: typing.Optional[typing.List["AppServiceLogsApplicationLogs"]] = None,
        http_logs: typing.Optional[typing.List["AppServiceLogsHttpLogs"]] = None,
    ) -> None:
        """
        :param application_logs: application_logs block.
        :param http_logs: http_logs block.
        """
        self._values: typing.Dict[str, typing.Any] = {}
        if application_logs is not None:
            self._values["application_logs"] = application_logs
        if http_logs is not None:
            self._values["http_logs"] = http_logs

    @builtins.property
    def application_logs(
        self,
    ) -> typing.Optional[typing.List["AppServiceLogsApplicationLogs"]]:
        """application_logs block."""
        result = self._values.get("application_logs")
        return result

    @builtins.property
    def http_logs(self) -> typing.Optional[typing.List["AppServiceLogsHttpLogs"]]:
        """http_logs block."""
        result = self._values.get("http_logs")
        return result

    def __eq__(self, rhs: typing.Any) -> builtins.bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs: typing.Any) -> builtins.bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return "AppServiceLogs(%s)" % ", ".join(
            k + "=" + repr(v) for k, v in self._values.items()
        )


@jsii.data_type(
    jsii_type="@cdktf/provider-azurerm.AppServiceLogsApplicationLogs",
    jsii_struct_bases=[],
    name_mapping={"azure_blob_storage": "azureBlobStorage"},
)
class AppServiceLogsApplicationLogs:
    def __init__(
        self,
        *,
        azure_blob_storage: typing.Optional[typing.List["AppServiceLogsApplicationLogsAzureBlobStorage"]] = None,
    ) -> None:
        """
        :param azure_blob_storage: azure_blob_storage block.
        """
        self._values: typing.Dict[str, typing.Any] = {}
        if azure_blob_storage is not None:
            self._values["azure_blob_storage"] = azure_blob_storage

    @builtins.property
    def azure_blob_storage(
        self,
    ) -> typing.Optional[typing.List["AppServiceLogsApplicationLogsAzureBlobStorage"]]:
        """azure_blob_storage block."""
        result = self._values.get("azure_blob_storage")
        return result

    def __eq__(self, rhs: typing.Any) -> builtins.bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs: typing.Any) -> builtins.bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return "AppServiceLogsApplicationLogs(%s)" % ", ".join(
            k + "=" + repr(v) for k, v in self._values.items()
        )


@jsii.data_type(
    jsii_type="@cdktf/provider-azurerm.AppServiceLogsApplicationLogsAzureBlobStorage",
    jsii_struct_bases=[],
    name_mapping={
        "level": "level",
        "retention_in_days": "retentionInDays",
        "sas_url": "sasUrl",
    },
)
class AppServiceLogsApplicationLogsAzureBlobStorage:
    def __init__(
        self,
        *,
        level: builtins.str,
        retention_in_days: jsii.Number,
        sas_url: builtins.str,
    ) -> None:
        """
        :param level: 
        :param retention_in_days: 
        :param sas_url: 
        """
        self._values: typing.Dict[str, typing.Any] = {
            "level": level,
            "retention_in_days": retention_in_days,
            "sas_url": sas_url,
        }

    @builtins.property
    def level(self) -> builtins.str:
        result = self._values.get("level")
        assert result is not None, "Required property 'level' is missing"
        return result

    @builtins.property
    def retention_in_days(self) -> jsii.Number:
        result = self._values.get("retention_in_days")
        assert result is not None, "Required property 'retention_in_days' is missing"
        return result

    @builtins.property
    def sas_url(self) -> builtins.str:
        result = self._values.get("sas_url")
        assert result is not None, "Required property 'sas_url' is missing"
        return result

    def __eq__(self, rhs: typing.Any) -> builtins.bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs: typing.Any) -> builtins.bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return "AppServiceLogsApplicationLogsAzureBlobStorage(%s)" % ", ".join(
            k + "=" + repr(v) for k, v in self._values.items()
        )


@jsii.data_type(
    jsii_type="@cdktf/provider-azurerm.AppServiceLogsHttpLogs",
    jsii_struct_bases=[],
    name_mapping={
        "azure_blob_storage": "azureBlobStorage",
        "file_system": "fileSystem",
    },
)
class AppServiceLogsHttpLogs:
    def __init__(
        self,
        *,
        azure_blob_storage: typing.Optional[typing.List["AppServiceLogsHttpLogsAzureBlobStorage"]] = None,
        file_system: typing.Optional[typing.List["AppServiceLogsHttpLogsFileSystem"]] = None,
    ) -> None:
        """
        :param azure_blob_storage: azure_blob_storage block.
        :param file_system: file_system block.
        """
        self._values: typing.Dict[str, typing.Any] = {}
        if azure_blob_storage is not None:
            self._values["azure_blob_storage"] = azure_blob_storage
        if file_system is not None:
            self._values["file_system"] = file_system

    @builtins.property
    def azure_blob_storage(
        self,
    ) -> typing.Optional[typing.List["AppServiceLogsHttpLogsAzureBlobStorage"]]:
        """azure_blob_storage block."""
        result = self._values.get("azure_blob_storage")
        return result

    @builtins.property
    def file_system(
        self,
    ) -> typing.Optional[typing.List["AppServiceLogsHttpLogsFileSystem"]]:
        """file_system block."""
        result = self._values.get("file_system")
        return result

    def __eq__(self, rhs: typing.Any) -> builtins.bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs: typing.Any) -> builtins.bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return "AppServiceLogsHttpLogs(%s)" % ", ".join(
            k + "=" + repr(v) for k, v in self._values.items()
        )


@jsii.data_type(
    jsii_type="@cdktf/provider-azurerm.AppServiceLogsHttpLogsAzureBlobStorage",
    jsii_struct_bases=[],
    name_mapping={"retention_in_days": "retentionInDays", "sas_url": "sasUrl"},
)
class AppServiceLogsHttpLogsAzureBlobStorage:
    def __init__(
        self,
        *,
        retention_in_days: jsii.Number,
        sas_url: builtins.str,
    ) -> None:
        """
        :param retention_in_days: 
        :param sas_url: 
        """
        self._values: typing.Dict[str, typing.Any] = {
            "retention_in_days": retention_in_days,
            "sas_url": sas_url,
        }

    @builtins.property
    def retention_in_days(self) -> jsii.Number:
        result = self._values.get("retention_in_days")
        assert result is not None, "Required property 'retention_in_days' is missing"
        return result

    @builtins.property
    def sas_url(self) -> builtins.str:
        result = self._values.get("sas_url")
        assert result is not None, "Required property 'sas_url' is missing"
        return result

    def __eq__(self, rhs: typing.Any) -> builtins.bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs: typing.Any) -> builtins.bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return "AppServiceLogsHttpLogsAzureBlobStorage(%s)" % ", ".join(
            k + "=" + repr(v) for k, v in self._values.items()
        )


@jsii.data_type(
    jsii_type="@cdktf/provider-azurerm.AppServiceLogsHttpLogsFileSystem",
    jsii_struct_bases=[],
    name_mapping={
        "retention_in_days": "retentionInDays",
        "retention_in_mb": "retentionInMb",
    },
)
class AppServiceLogsHttpLogsFileSystem:
    def __init__(
        self,
        *,
        retention_in_days: jsii.Number,
        retention_in_mb: jsii.Number,
    ) -> None:
        """
        :param retention_in_days: 
        :param retention_in_mb: 
        """
        self._values: typing.Dict[str, typing.Any] = {
            "retention_in_days": retention_in_days,
            "retention_in_mb": retention_in_mb,
        }

    @builtins.property
    def retention_in_days(self) -> jsii.Number:
        result = self._values.get("retention_in_days")
        assert result is not None, "Required property 'retention_in_days' is missing"
        return result

    @builtins.property
    def retention_in_mb(self) -> jsii.Number:
        result = self._values.get("retention_in_mb")
        assert result is not None, "Required property 'retention_in_mb' is missing"
        return result

    def __eq__(self, rhs: typing.Any) -> builtins.bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs: typing.Any) -> builtins.bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return "AppServiceLogsHttpLogsFileSystem(%s)" % ", ".join(
            k + "=" + repr(v) for k, v in self._values.items()
        )


class AppServicePlan(
    cdktf.TerraformResource,
    metaclass=jsii.JSIIMeta,
    jsii_type="@cdktf/provider-azurerm.AppServicePlan",
):
    def __init__(
        self,
        scope: constructs.Construct,
        id: builtins.str,
        *,
        location: builtins.str,
        name: builtins.str,
        resource_group_name: builtins.str,
        sku: typing.List["AppServicePlanSku"],
        app_service_environment_id: typing.Optional[builtins.str] = None,
        is_xenon: typing.Optional[builtins.bool] = None,
        kind: typing.Optional[builtins.str] = None,
        maximum_elastic_worker_count: typing.Optional[jsii.Number] = None,
        per_site_scaling: typing.Optional[builtins.bool] = None,
        reserved: typing.Optional[builtins.bool] = None,
        tags: typing.Optional[typing.Mapping[builtins.str, builtins.str]] = None,
        timeouts: typing.Optional["AppServicePlanTimeouts"] = None,
        count: typing.Optional[jsii.Number] = None,
        depends_on: typing.Optional[typing.List[cdktf.TerraformResource]] = None,
        lifecycle: typing.Optional[cdktf.TerraformResourceLifecycle] = None,
        provider: typing.Optional[cdktf.TerraformProvider] = None,
    ) -> None:
        """
        :param scope: -
        :param id: -
        :param location: 
        :param name: 
        :param resource_group_name: 
        :param sku: sku block.
        :param app_service_environment_id: 
        :param is_xenon: 
        :param kind: 
        :param maximum_elastic_worker_count: 
        :param per_site_scaling: 
        :param reserved: 
        :param tags: 
        :param timeouts: timeouts block.
        :param count: 
        :param depends_on: 
        :param lifecycle: 
        :param provider: 
        """
        config = AppServicePlanConfig(
            location=location,
            name=name,
            resource_group_name=resource_group_name,
            sku=sku,
            app_service_environment_id=app_service_environment_id,
            is_xenon=is_xenon,
            kind=kind,
            maximum_elastic_worker_count=maximum_elastic_worker_count,
            per_site_scaling=per_site_scaling,
            reserved=reserved,
            tags=tags,
            timeouts=timeouts,
            count=count,
            depends_on=depends_on,
            lifecycle=lifecycle,
            provider=provider,
        )

        jsii.create(AppServicePlan, self, [scope, id, config])

    @jsii.member(jsii_name="synthesizeAttributes")
    def _synthesize_attributes(self) -> typing.Mapping[builtins.str, typing.Any]:
        return jsii.invoke(self, "synthesizeAttributes", [])

    @builtins.property # type: ignore
    @jsii.member(jsii_name="maximumNumberOfWorkers")
    def maximum_number_of_workers(self) -> jsii.Number:
        return jsii.get(self, "maximumNumberOfWorkers")

    @builtins.property # type: ignore
    @jsii.member(jsii_name="location")
    def location(self) -> builtins.str:
        return jsii.get(self, "location")

    @location.setter # type: ignore
    def location(self, value: builtins.str) -> None:
        jsii.set(self, "location", value)

    @builtins.property # type: ignore
    @jsii.member(jsii_name="name")
    def name(self) -> builtins.str:
        return jsii.get(self, "name")

    @name.setter # type: ignore
    def name(self, value: builtins.str) -> None:
        jsii.set(self, "name", value)

    @builtins.property # type: ignore
    @jsii.member(jsii_name="resourceGroupName")
    def resource_group_name(self) -> builtins.str:
        return jsii.get(self, "resourceGroupName")

    @resource_group_name.setter # type: ignore
    def resource_group_name(self, value: builtins.str) -> None:
        jsii.set(self, "resourceGroupName", value)

    @builtins.property # type: ignore
    @jsii.member(jsii_name="sku")
    def sku(self) -> typing.List["AppServicePlanSku"]:
        return jsii.get(self, "sku")

    @sku.setter # type: ignore
    def sku(self, value: typing.List["AppServicePlanSku"]) -> None:
        jsii.set(self, "sku", value)

    @builtins.property # type: ignore
    @jsii.member(jsii_name="appServiceEnvironmentId")
    def app_service_environment_id(self) -> typing.Optional[builtins.str]:
        return jsii.get(self, "appServiceEnvironmentId")

    @app_service_environment_id.setter # type: ignore
    def app_service_environment_id(self, value: typing.Optional[builtins.str]) -> None:
        jsii.set(self, "appServiceEnvironmentId", value)

    @builtins.property # type: ignore
    @jsii.member(jsii_name="id")
    def id(self) -> typing.Optional[builtins.str]:
        return jsii.get(self, "id")

    @id.setter # type: ignore
    def id(self, value: typing.Optional[builtins.str]) -> None:
        jsii.set(self, "id", value)

    @builtins.property # type: ignore
    @jsii.member(jsii_name="isXenon")
    def is_xenon(self) -> typing.Optional[builtins.bool]:
        return jsii.get(self, "isXenon")

    @is_xenon.setter # type: ignore
    def is_xenon(self, value: typing.Optional[builtins.bool]) -> None:
        jsii.set(self, "isXenon", value)

    @builtins.property # type: ignore
    @jsii.member(jsii_name="kind")
    def kind(self) -> typing.Optional[builtins.str]:
        return jsii.get(self, "kind")

    @kind.setter # type: ignore
    def kind(self, value: typing.Optional[builtins.str]) -> None:
        jsii.set(self, "kind", value)

    @builtins.property # type: ignore
    @jsii.member(jsii_name="maximumElasticWorkerCount")
    def maximum_elastic_worker_count(self) -> typing.Optional[jsii.Number]:
        return jsii.get(self, "maximumElasticWorkerCount")

    @maximum_elastic_worker_count.setter # type: ignore
    def maximum_elastic_worker_count(self, value: typing.Optional[jsii.Number]) -> None:
        jsii.set(self, "maximumElasticWorkerCount", value)

    @builtins.property # type: ignore
    @jsii.member(jsii_name="perSiteScaling")
    def per_site_scaling(self) -> typing.Optional[builtins.bool]:
        return jsii.get(self, "perSiteScaling")

    @per_site_scaling.setter # type: ignore
    def per_site_scaling(self, value: typing.Optional[builtins.bool]) -> None:
        jsii.set(self, "perSiteScaling", value)

    @builtins.property # type: ignore
    @jsii.member(jsii_name="reserved")
    def reserved(self) -> typing.Optional[builtins.bool]:
        return jsii.get(self, "reserved")

    @reserved.setter # type: ignore
    def reserved(self, value: typing.Optional[builtins.bool]) -> None:
        jsii.set(self, "reserved", value)

    @builtins.property # type: ignore
    @jsii.member(jsii_name="tags")
    def tags(self) -> typing.Optional[typing.Mapping[builtins.str, builtins.str]]:
        return jsii.get(self, "tags")

    @tags.setter # type: ignore
    def tags(
        self,
        value: typing.Optional[typing.Mapping[builtins.str, builtins.str]],
    ) -> None:
        jsii.set(self, "tags", value)

    @builtins.property # type: ignore
    @jsii.member(jsii_name="timeouts")
    def timeouts(self) -> typing.Optional["AppServicePlanTimeouts"]:
        return jsii.get(self, "timeouts")

    @timeouts.setter # type: ignore
    def timeouts(self, value: typing.Optional["AppServicePlanTimeouts"]) -> None:
        jsii.set(self, "timeouts", value)


@jsii.data_type(
    jsii_type="@cdktf/provider-azurerm.AppServicePlanConfig",
    jsii_struct_bases=[cdktf.TerraformMetaArguments],
    name_mapping={
        "count": "count",
        "depends_on": "dependsOn",
        "lifecycle": "lifecycle",
        "provider": "provider",
        "location": "location",
        "name": "name",
        "resource_group_name": "resourceGroupName",
        "sku": "sku",
        "app_service_environment_id": "appServiceEnvironmentId",
        "is_xenon": "isXenon",
        "kind": "kind",
        "maximum_elastic_worker_count": "maximumElasticWorkerCount",
        "per_site_scaling": "perSiteScaling",
        "reserved": "reserved",
        "tags": "tags",
        "timeouts": "timeouts",
    },
)
class AppServicePlanConfig(cdktf.TerraformMetaArguments):
    def __init__(
        self,
        *,
        count: typing.Optional[jsii.Number] = None,
        depends_on: typing.Optional[typing.List[cdktf.TerraformResource]] = None,
        lifecycle: typing.Optional[cdktf.TerraformResourceLifecycle] = None,
        provider: typing.Optional[cdktf.TerraformProvider] = None,
        location: builtins.str,
        name: builtins.str,
        resource_group_name: builtins.str,
        sku: typing.List["AppServicePlanSku"],
        app_service_environment_id: typing.Optional[builtins.str] = None,
        is_xenon: typing.Optional[builtins.bool] = None,
        kind: typing.Optional[builtins.str] = None,
        maximum_elastic_worker_count: typing.Optional[jsii.Number] = None,
        per_site_scaling: typing.Optional[builtins.bool] = None,
        reserved: typing.Optional[builtins.bool] = None,
        tags: typing.Optional[typing.Mapping[builtins.str, builtins.str]] = None,
        timeouts: typing.Optional["AppServicePlanTimeouts"] = None,
    ) -> None:
        """
        :param count: 
        :param depends_on: 
        :param lifecycle: 
        :param provider: 
        :param location: 
        :param name: 
        :param resource_group_name: 
        :param sku: sku block.
        :param app_service_environment_id: 
        :param is_xenon: 
        :param kind: 
        :param maximum_elastic_worker_count: 
        :param per_site_scaling: 
        :param reserved: 
        :param tags: 
        :param timeouts: timeouts block.
        """
        if isinstance(lifecycle, dict):
            lifecycle = cdktf.TerraformResourceLifecycle(**lifecycle)
        if isinstance(timeouts, dict):
            timeouts = AppServicePlanTimeouts(**timeouts)
        self._values: typing.Dict[str, typing.Any] = {
            "location": location,
            "name": name,
            "resource_group_name": resource_group_name,
            "sku": sku,
        }
        if count is not None:
            self._values["count"] = count
        if depends_on is not None:
            self._values["depends_on"] = depends_on
        if lifecycle is not None:
            self._values["lifecycle"] = lifecycle
        if provider is not None:
            self._values["provider"] = provider
        if app_service_environment_id is not None:
            self._values["app_service_environment_id"] = app_service_environment_id
        if is_xenon is not None:
            self._values["is_xenon"] = is_xenon
        if kind is not None:
            self._values["kind"] = kind
        if maximum_elastic_worker_count is not None:
            self._values["maximum_elastic_worker_count"] = maximum_elastic_worker_count
        if per_site_scaling is not None:
            self._values["per_site_scaling"] = per_site_scaling
        if reserved is not None:
            self._values["reserved"] = reserved
        if tags is not None:
            self._values["tags"] = tags
        if timeouts is not None:
            self._values["timeouts"] = timeouts

    @builtins.property
    def count(self) -> typing.Optional[jsii.Number]:
        """
        :stability: experimental
        """
        result = self._values.get("count")
        return result

    @builtins.property
    def depends_on(self) -> typing.Optional[typing.List[cdktf.TerraformResource]]:
        """
        :stability: experimental
        """
        result = self._values.get("depends_on")
        return result

    @builtins.property
    def lifecycle(self) -> typing.Optional[cdktf.TerraformResourceLifecycle]:
        """
        :stability: experimental
        """
        result = self._values.get("lifecycle")
        return result

    @builtins.property
    def provider(self) -> typing.Optional[cdktf.TerraformProvider]:
        """
        :stability: experimental
        """
        result = self._values.get("provider")
        return result

    @builtins.property
    def location(self) -> builtins.str:
        result = self._values.get("location")
        assert result is not None, "Required property 'location' is missing"
        return result

    @builtins.property
    def name(self) -> builtins.str:
        result = self._values.get("name")
        assert result is not None, "Required property 'name' is missing"
        return result

    @builtins.property
    def resource_group_name(self) -> builtins.str:
        result = self._values.get("resource_group_name")
        assert result is not None, "Required property 'resource_group_name' is missing"
        return result

    @builtins.property
    def sku(self) -> typing.List["AppServicePlanSku"]:
        """sku block."""
        result = self._values.get("sku")
        assert result is not None, "Required property 'sku' is missing"
        return result

    @builtins.property
    def app_service_environment_id(self) -> typing.Optional[builtins.str]:
        result = self._values.get("app_service_environment_id")
        return result

    @builtins.property
    def is_xenon(self) -> typing.Optional[builtins.bool]:
        result = self._values.get("is_xenon")
        return result

    @builtins.property
    def kind(self) -> typing.Optional[builtins.str]:
        result = self._values.get("kind")
        return result

    @builtins.property
    def maximum_elastic_worker_count(self) -> typing.Optional[jsii.Number]:
        result = self._values.get("maximum_elastic_worker_count")
        return result

    @builtins.property
    def per_site_scaling(self) -> typing.Optional[builtins.bool]:
        result = self._values.get("per_site_scaling")
        return result

    @builtins.property
    def reserved(self) -> typing.Optional[builtins.bool]:
        result = self._values.get("reserved")
        return result

    @builtins.property
    def tags(self) -> typing.Optional[typing.Mapping[builtins.str, builtins.str]]:
        result = self._values.get("tags")
        return result

    @builtins.property
    def timeouts(self) -> typing.Optional["AppServicePlanTimeouts"]:
        """timeouts block."""
        result = self._values.get("timeouts")
        return result

    def __eq__(self, rhs: typing.Any) -> builtins.bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs: typing.Any) -> builtins.bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return "AppServicePlanConfig(%s)" % ", ".join(
            k + "=" + repr(v) for k, v in self._values.items()
        )


@jsii.data_type(
    jsii_type="@cdktf/provider-azurerm.AppServicePlanSku",
    jsii_struct_bases=[],
    name_mapping={"size": "size", "tier": "tier", "capacity": "capacity"},
)
class AppServicePlanSku:
    def __init__(
        self,
        *,
        size: builtins.str,
        tier: builtins.str,
        capacity: typing.Optional[jsii.Number] = None,
    ) -> None:
        """
        :param size: 
        :param tier: 
        :param capacity: 
        """
        self._values: typing.Dict[str, typing.Any] = {
            "size": size,
            "tier": tier,
        }
        if capacity is not None:
            self._values["capacity"] = capacity

    @builtins.property
    def size(self) -> builtins.str:
        result = self._values.get("size")
        assert result is not None, "Required property 'size' is missing"
        return result

    @builtins.property
    def tier(self) -> builtins.str:
        result = self._values.get("tier")
        assert result is not None, "Required property 'tier' is missing"
        return result

    @builtins.property
    def capacity(self) -> typing.Optional[jsii.Number]:
        result = self._values.get("capacity")
        return result

    def __eq__(self, rhs: typing.Any) -> builtins.bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs: typing.Any) -> builtins.bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return "AppServicePlanSku(%s)" % ", ".join(
            k + "=" + repr(v) for k, v in self._values.items()
        )


@jsii.data_type(
    jsii_type="@cdktf/provider-azurerm.AppServicePlanTimeouts",
    jsii_struct_bases=[],
    name_mapping={
        "create": "create",
        "delete": "delete",
        "read": "read",
        "update": "update",
    },
)
class AppServicePlanTimeouts:
    def __init__(
        self,
        *,
        create: typing.Optional[builtins.str] = None,
        delete: typing.Optional[builtins.str] = None,
        read: typing.Optional[builtins.str] = None,
        update: typing.Optional[builtins.str] = None,
    ) -> None:
        """
        :param create: 
        :param delete: 
        :param read: 
        :param update: 
        """
        self._values: typing.Dict[str, typing.Any] = {}
        if create is not None:
            self._values["create"] = create
        if delete is not None:
            self._values["delete"] = delete
        if read is not None:
            self._values["read"] = read
        if update is not None:
            self._values["update"] = update

    @builtins.property
    def create(self) -> typing.Optional[builtins.str]:
        result = self._values.get("create")
        return result

    @builtins.property
    def delete(self) -> typing.Optional[builtins.str]:
        result = self._values.get("delete")
        return result

    @builtins.property
    def read(self) -> typing.Optional[builtins.str]:
        result = self._values.get("read")
        return result

    @builtins.property
    def update(self) -> typing.Optional[builtins.str]:
        result = self._values.get("update")
        return result

    def __eq__(self, rhs: typing.Any) -> builtins.bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs: typing.Any) -> builtins.bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return "AppServicePlanTimeouts(%s)" % ", ".join(
            k + "=" + repr(v) for k, v in self._values.items()
        )


@jsii.data_type(
    jsii_type="@cdktf/provider-azurerm.AppServiceSiteConfig",
    jsii_struct_bases=[],
    name_mapping={
        "always_on": "alwaysOn",
        "app_command_line": "appCommandLine",
        "auto_swap_slot_name": "autoSwapSlotName",
        "cors": "cors",
        "default_documents": "defaultDocuments",
        "dotnet_framework_version": "dotnetFrameworkVersion",
        "ftps_state": "ftpsState",
        "http2_enabled": "http2Enabled",
        "ip_restriction": "ipRestriction",
        "java_container": "javaContainer",
        "java_container_version": "javaContainerVersion",
        "java_version": "javaVersion",
        "linux_fx_version": "linuxFxVersion",
        "local_mysql_enabled": "localMysqlEnabled",
        "managed_pipeline_mode": "managedPipelineMode",
        "min_tls_version": "minTlsVersion",
        "php_version": "phpVersion",
        "python_version": "pythonVersion",
        "remote_debugging_enabled": "remoteDebuggingEnabled",
        "remote_debugging_version": "remoteDebuggingVersion",
        "scm_type": "scmType",
        "use32_bit_worker_process": "use32BitWorkerProcess",
        "websockets_enabled": "websocketsEnabled",
        "windows_fx_version": "windowsFxVersion",
    },
)
class AppServiceSiteConfig:
    def __init__(
        self,
        *,
        always_on: typing.Optional[builtins.bool] = None,
        app_command_line: typing.Optional[builtins.str] = None,
        auto_swap_slot_name: typing.Optional[builtins.str] = None,
        cors: typing.Optional[typing.List["AppServiceSiteConfigCors"]] = None,
        default_documents: typing.Optional[typing.List[builtins.str]] = None,
        dotnet_framework_version: typing.Optional[builtins.str] = None,
        ftps_state: typing.Optional[builtins.str] = None,
        http2_enabled: typing.Optional[builtins.bool] = None,
        ip_restriction: typing.Optional[typing.List["AppServiceSiteConfigIpRestriction"]] = None,
        java_container: typing.Optional[builtins.str] = None,
        java_container_version: typing.Optional[builtins.str] = None,
        java_version: typing.Optional[builtins.str] = None,
        linux_fx_version: typing.Optional[builtins.str] = None,
        local_mysql_enabled: typing.Optional[builtins.bool] = None,
        managed_pipeline_mode: typing.Optional[builtins.str] = None,
        min_tls_version: typing.Optional[builtins.str] = None,
        php_version: typing.Optional[builtins.str] = None,
        python_version: typing.Optional[builtins.str] = None,
        remote_debugging_enabled: typing.Optional[builtins.bool] = None,
        remote_debugging_version: typing.Optional[builtins.str] = None,
        scm_type: typing.Optional[builtins.str] = None,
        use32_bit_worker_process: typing.Optional[builtins.bool] = None,
        websockets_enabled: typing.Optional[builtins.bool] = None,
        windows_fx_version: typing.Optional[builtins.str] = None,
    ) -> None:
        """
        :param always_on: 
        :param app_command_line: 
        :param auto_swap_slot_name: 
        :param cors: cors block.
        :param default_documents: 
        :param dotnet_framework_version: 
        :param ftps_state: 
        :param http2_enabled: 
        :param ip_restriction: 
        :param java_container: 
        :param java_container_version: 
        :param java_version: 
        :param linux_fx_version: 
        :param local_mysql_enabled: 
        :param managed_pipeline_mode: 
        :param min_tls_version: 
        :param php_version: 
        :param python_version: 
        :param remote_debugging_enabled: 
        :param remote_debugging_version: 
        :param scm_type: 
        :param use32_bit_worker_process: 
        :param websockets_enabled: 
        :param windows_fx_version: 
        """
        self._values: typing.Dict[str, typing.Any] = {}
        if always_on is not None:
            self._values["always_on"] = always_on
        if app_command_line is not None:
            self._values["app_command_line"] = app_command_line
        if auto_swap_slot_name is not None:
            self._values["auto_swap_slot_name"] = auto_swap_slot_name
        if cors is not None:
            self._values["cors"] = cors
        if default_documents is not None:
            self._values["default_documents"] = default_documents
        if dotnet_framework_version is not None:
            self._values["dotnet_framework_version"] = dotnet_framework_version
        if ftps_state is not None:
            self._values["ftps_state"] = ftps_state
        if http2_enabled is not None:
            self._values["http2_enabled"] = http2_enabled
        if ip_restriction is not None:
            self._values["ip_restriction"] = ip_restriction
        if java_container is not None:
            self._values["java_container"] = java_container
        if java_container_version is not None:
            self._values["java_container_version"] = java_container_version
        if java_version is not None:
            self._values["java_version"] = java_version
        if linux_fx_version is not None:
            self._values["linux_fx_version"] = linux_fx_version
        if local_mysql_enabled is not None:
            self._values["local_mysql_enabled"] = local_mysql_enabled
        if managed_pipeline_mode is not None:
            self._values["managed_pipeline_mode"] = managed_pipeline_mode
        if min_tls_version is not None:
            self._values["min_tls_version"] = min_tls_version
        if php_version is not None:
            self._values["php_version"] = php_version
        if python_version is not None:
            self._values["python_version"] = python_version
        if remote_debugging_enabled is not None:
            self._values["remote_debugging_enabled"] = remote_debugging_enabled
        if remote_debugging_version is not None:
            self._values["remote_debugging_version"] = remote_debugging_version
        if scm_type is not None:
            self._values["scm_type"] = scm_type
        if use32_bit_worker_process is not None:
            self._values["use32_bit_worker_process"] = use32_bit_worker_process
        if websockets_enabled is not None:
            self._values["websockets_enabled"] = websockets_enabled
        if windows_fx_version is not None:
            self._values["windows_fx_version"] = windows_fx_version

    @builtins.property
    def always_on(self) -> typing.Optional[builtins.bool]:
        result = self._values.get("always_on")
        return result

    @builtins.property
    def app_command_line(self) -> typing.Optional[builtins.str]:
        result = self._values.get("app_command_line")
        return result

    @builtins.property
    def auto_swap_slot_name(self) -> typing.Optional[builtins.str]:
        result = self._values.get("auto_swap_slot_name")
        return result

    @builtins.property
    def cors(self) -> typing.Optional[typing.List["AppServiceSiteConfigCors"]]:
        """cors block."""
        result = self._values.get("cors")
        return result

    @builtins.property
    def default_documents(self) -> typing.Optional[typing.List[builtins.str]]:
        result = self._values.get("default_documents")
        return result

    @builtins.property
    def dotnet_framework_version(self) -> typing.Optional[builtins.str]:
        result = self._values.get("dotnet_framework_version")
        return result

    @builtins.property
    def ftps_state(self) -> typing.Optional[builtins.str]:
        result = self._values.get("ftps_state")
        return result

    @builtins.property
    def http2_enabled(self) -> typing.Optional[builtins.bool]:
        result = self._values.get("http2_enabled")
        return result

    @builtins.property
    def ip_restriction(
        self,
    ) -> typing.Optional[typing.List["AppServiceSiteConfigIpRestriction"]]:
        result = self._values.get("ip_restriction")
        return result

    @builtins.property
    def java_container(self) -> typing.Optional[builtins.str]:
        result = self._values.get("java_container")
        return result

    @builtins.property
    def java_container_version(self) -> typing.Optional[builtins.str]:
        result = self._values.get("java_container_version")
        return result

    @builtins.property
    def java_version(self) -> typing.Optional[builtins.str]:
        result = self._values.get("java_version")
        return result

    @builtins.property
    def linux_fx_version(self) -> typing.Optional[builtins.str]:
        result = self._values.get("linux_fx_version")
        return result

    @builtins.property
    def local_mysql_enabled(self) -> typing.Optional[builtins.bool]:
        result = self._values.get("local_mysql_enabled")
        return result

    @builtins.property
    def managed_pipeline_mode(self) -> typing.Optional[builtins.str]:
        result = self._values.get("managed_pipeline_mode")
        return result

    @builtins.property
    def min_tls_version(self) -> typing.Optional[builtins.str]:
        result = self._values.get("min_tls_version")
        return result

    @builtins.property
    def php_version(self) -> typing.Optional[builtins.str]:
        result = self._values.get("php_version")
        return result

    @builtins.property
    def python_version(self) -> typing.Optional[builtins.str]:
        result = self._values.get("python_version")
        return result

    @builtins.property
    def remote_debugging_enabled(self) -> typing.Optional[builtins.bool]:
        result = self._values.get("remote_debugging_enabled")
        return result

    @builtins.property
    def remote_debugging_version(self) -> typing.Optional[builtins.str]:
        result = self._values.get("remote_debugging_version")
        return result

    @builtins.property
    def scm_type(self) -> typing.Optional[builtins.str]:
        result = self._values.get("scm_type")
        return result

    @builtins.property
    def use32_bit_worker_process(self) -> typing.Optional[builtins.bool]:
        result = self._values.get("use32_bit_worker_process")
        return result

    @builtins.property
    def websockets_enabled(self) -> typing.Optional[builtins.bool]:
        result = self._values.get("websockets_enabled")
        return result

    @builtins.property
    def windows_fx_version(self) -> typing.Optional[builtins.str]:
        result = self._values.get("windows_fx_version")
        return result

    def __eq__(self, rhs: typing.Any) -> builtins.bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs: typing.Any) -> builtins.bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return "AppServiceSiteConfig(%s)" % ", ".join(
            k + "=" + repr(v) for k, v in self._values.items()
        )


@jsii.data_type(
    jsii_type="@cdktf/provider-azurerm.AppServiceSiteConfigCors",
    jsii_struct_bases=[],
    name_mapping={
        "allowed_origins": "allowedOrigins",
        "support_credentials": "supportCredentials",
    },
)
class AppServiceSiteConfigCors:
    def __init__(
        self,
        *,
        allowed_origins: typing.List[builtins.str],
        support_credentials: typing.Optional[builtins.bool] = None,
    ) -> None:
        """
        :param allowed_origins: 
        :param support_credentials: 
        """
        self._values: typing.Dict[str, typing.Any] = {
            "allowed_origins": allowed_origins,
        }
        if support_credentials is not None:
            self._values["support_credentials"] = support_credentials

    @builtins.property
    def allowed_origins(self) -> typing.List[builtins.str]:
        result = self._values.get("allowed_origins")
        assert result is not None, "Required property 'allowed_origins' is missing"
        return result

    @builtins.property
    def support_credentials(self) -> typing.Optional[builtins.bool]:
        result = self._values.get("support_credentials")
        return result

    def __eq__(self, rhs: typing.Any) -> builtins.bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs: typing.Any) -> builtins.bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return "AppServiceSiteConfigCors(%s)" % ", ".join(
            k + "=" + repr(v) for k, v in self._values.items()
        )


@jsii.data_type(
    jsii_type="@cdktf/provider-azurerm.AppServiceSiteConfigIpRestriction",
    jsii_struct_bases=[],
    name_mapping={
        "ip_address": "ipAddress",
        "virtual_network_subnet_id": "virtualNetworkSubnetId",
    },
)
class AppServiceSiteConfigIpRestriction:
    def __init__(
        self,
        *,
        ip_address: typing.Optional[builtins.str] = None,
        virtual_network_subnet_id: typing.Optional[builtins.str] = None,
    ) -> None:
        """
        :param ip_address: 
        :param virtual_network_subnet_id: 
        """
        self._values: typing.Dict[str, typing.Any] = {}
        if ip_address is not None:
            self._values["ip_address"] = ip_address
        if virtual_network_subnet_id is not None:
            self._values["virtual_network_subnet_id"] = virtual_network_subnet_id

    @builtins.property
    def ip_address(self) -> typing.Optional[builtins.str]:
        result = self._values.get("ip_address")
        return result

    @builtins.property
    def virtual_network_subnet_id(self) -> typing.Optional[builtins.str]:
        result = self._values.get("virtual_network_subnet_id")
        return result

    def __eq__(self, rhs: typing.Any) -> builtins.bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs: typing.Any) -> builtins.bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return "AppServiceSiteConfigIpRestriction(%s)" % ", ".join(
            k + "=" + repr(v) for k, v in self._values.items()
        )


class AppServiceSiteCredential(
    cdktf.ComplexComputedList,
    metaclass=jsii.JSIIMeta,
    jsii_type="@cdktf/provider-azurerm.AppServiceSiteCredential",
):
    def __init__(
        self,
        terraform_resource: cdktf.ITerraformResource,
        terraform_attribute: builtins.str,
        index: builtins.str,
    ) -> None:
        """
        :param terraform_resource: -
        :param terraform_attribute: -
        :param index: -

        :stability: experimental
        """
        jsii.create(AppServiceSiteCredential, self, [terraform_resource, terraform_attribute, index])

    @builtins.property # type: ignore
    @jsii.member(jsii_name="password")
    def password(self) -> builtins.str:
        return jsii.get(self, "password")

    @builtins.property # type: ignore
    @jsii.member(jsii_name="username")
    def username(self) -> builtins.str:
        return jsii.get(self, "username")


class AppServiceSlot(
    cdktf.TerraformResource,
    metaclass=jsii.JSIIMeta,
    jsii_type="@cdktf/provider-azurerm.AppServiceSlot",
):
    def __init__(
        self,
        scope: constructs.Construct,
        id: builtins.str,
        *,
        app_service_name: builtins.str,
        app_service_plan_id: builtins.str,
        location: builtins.str,
        name: builtins.str,
        resource_group_name: builtins.str,
        app_settings: typing.Optional[typing.Mapping[builtins.str, builtins.str]] = None,
        auth_settings: typing.Optional[typing.List["AppServiceSlotAuthSettings"]] = None,
        client_affinity_enabled: typing.Optional[builtins.bool] = None,
        connection_string: typing.Optional[typing.List["AppServiceSlotConnectionString"]] = None,
        enabled: typing.Optional[builtins.bool] = None,
        https_only: typing.Optional[builtins.bool] = None,
        identity: typing.Optional[typing.List["AppServiceSlotIdentity"]] = None,
        logs: typing.Optional[typing.List["AppServiceSlotLogs"]] = None,
        site_config: typing.Optional[typing.List["AppServiceSlotSiteConfig"]] = None,
        tags: typing.Optional[typing.Mapping[builtins.str, builtins.str]] = None,
        timeouts: typing.Optional["AppServiceSlotTimeouts"] = None,
        count: typing.Optional[jsii.Number] = None,
        depends_on: typing.Optional[typing.List[cdktf.TerraformResource]] = None,
        lifecycle: typing.Optional[cdktf.TerraformResourceLifecycle] = None,
        provider: typing.Optional[cdktf.TerraformProvider] = None,
    ) -> None:
        """
        :param scope: -
        :param id: -
        :param app_service_name: 
        :param app_service_plan_id: 
        :param location: 
        :param name: 
        :param resource_group_name: 
        :param app_settings: 
        :param auth_settings: auth_settings block.
        :param client_affinity_enabled: 
        :param connection_string: connection_string block.
        :param enabled: 
        :param https_only: 
        :param identity: identity block.
        :param logs: logs block.
        :param site_config: site_config block.
        :param tags: 
        :param timeouts: timeouts block.
        :param count: 
        :param depends_on: 
        :param lifecycle: 
        :param provider: 
        """
        config = AppServiceSlotConfig(
            app_service_name=app_service_name,
            app_service_plan_id=app_service_plan_id,
            location=location,
            name=name,
            resource_group_name=resource_group_name,
            app_settings=app_settings,
            auth_settings=auth_settings,
            client_affinity_enabled=client_affinity_enabled,
            connection_string=connection_string,
            enabled=enabled,
            https_only=https_only,
            identity=identity,
            logs=logs,
            site_config=site_config,
            tags=tags,
            timeouts=timeouts,
            count=count,
            depends_on=depends_on,
            lifecycle=lifecycle,
            provider=provider,
        )

        jsii.create(AppServiceSlot, self, [scope, id, config])

    @jsii.member(jsii_name="siteCredential")
    def site_credential(self, index: builtins.str) -> "AppServiceSlotSiteCredential":
        """
        :param index: -
        """
        return jsii.invoke(self, "siteCredential", [index])

    @jsii.member(jsii_name="synthesizeAttributes")
    def _synthesize_attributes(self) -> typing.Mapping[builtins.str, typing.Any]:
        return jsii.invoke(self, "synthesizeAttributes", [])

    @builtins.property # type: ignore
    @jsii.member(jsii_name="defaultSiteHostname")
    def default_site_hostname(self) -> builtins.str:
        return jsii.get(self, "defaultSiteHostname")

    @builtins.property # type: ignore
    @jsii.member(jsii_name="appServiceName")
    def app_service_name(self) -> builtins.str:
        return jsii.get(self, "appServiceName")

    @app_service_name.setter # type: ignore
    def app_service_name(self, value: builtins.str) -> None:
        jsii.set(self, "appServiceName", value)

    @builtins.property # type: ignore
    @jsii.member(jsii_name="appServicePlanId")
    def app_service_plan_id(self) -> builtins.str:
        return jsii.get(self, "appServicePlanId")

    @app_service_plan_id.setter # type: ignore
    def app_service_plan_id(self, value: builtins.str) -> None:
        jsii.set(self, "appServicePlanId", value)

    @builtins.property # type: ignore
    @jsii.member(jsii_name="location")
    def location(self) -> builtins.str:
        return jsii.get(self, "location")

    @location.setter # type: ignore
    def location(self, value: builtins.str) -> None:
        jsii.set(self, "location", value)

    @builtins.property # type: ignore
    @jsii.member(jsii_name="name")
    def name(self) -> builtins.str:
        return jsii.get(self, "name")

    @name.setter # type: ignore
    def name(self, value: builtins.str) -> None:
        jsii.set(self, "name", value)

    @builtins.property # type: ignore
    @jsii.member(jsii_name="resourceGroupName")
    def resource_group_name(self) -> builtins.str:
        return jsii.get(self, "resourceGroupName")

    @resource_group_name.setter # type: ignore
    def resource_group_name(self, value: builtins.str) -> None:
        jsii.set(self, "resourceGroupName", value)

    @builtins.property # type: ignore
    @jsii.member(jsii_name="appSettings")
    def app_settings(
        self,
    ) -> typing.Optional[typing.Mapping[builtins.str, builtins.str]]:
        return jsii.get(self, "appSettings")

    @app_settings.setter # type: ignore
    def app_settings(
        self,
        value: typing.Optional[typing.Mapping[builtins.str, builtins.str]],
    ) -> None:
        jsii.set(self, "appSettings", value)

    @builtins.property # type: ignore
    @jsii.member(jsii_name="authSettings")
    def auth_settings(
        self,
    ) -> typing.Optional[typing.List["AppServiceSlotAuthSettings"]]:
        return jsii.get(self, "authSettings")

    @auth_settings.setter # type: ignore
    def auth_settings(
        self,
        value: typing.Optional[typing.List["AppServiceSlotAuthSettings"]],
    ) -> None:
        jsii.set(self, "authSettings", value)

    @builtins.property # type: ignore
    @jsii.member(jsii_name="clientAffinityEnabled")
    def client_affinity_enabled(self) -> typing.Optional[builtins.bool]:
        return jsii.get(self, "clientAffinityEnabled")

    @client_affinity_enabled.setter # type: ignore
    def client_affinity_enabled(self, value: typing.Optional[builtins.bool]) -> None:
        jsii.set(self, "clientAffinityEnabled", value)

    @builtins.property # type: ignore
    @jsii.member(jsii_name="connectionString")
    def connection_string(
        self,
    ) -> typing.Optional[typing.List["AppServiceSlotConnectionString"]]:
        return jsii.get(self, "connectionString")

    @connection_string.setter # type: ignore
    def connection_string(
        self,
        value: typing.Optional[typing.List["AppServiceSlotConnectionString"]],
    ) -> None:
        jsii.set(self, "connectionString", value)

    @builtins.property # type: ignore
    @jsii.member(jsii_name="enabled")
    def enabled(self) -> typing.Optional[builtins.bool]:
        return jsii.get(self, "enabled")

    @enabled.setter # type: ignore
    def enabled(self, value: typing.Optional[builtins.bool]) -> None:
        jsii.set(self, "enabled", value)

    @builtins.property # type: ignore
    @jsii.member(jsii_name="httpsOnly")
    def https_only(self) -> typing.Optional[builtins.bool]:
        return jsii.get(self, "httpsOnly")

    @https_only.setter # type: ignore
    def https_only(self, value: typing.Optional[builtins.bool]) -> None:
        jsii.set(self, "httpsOnly", value)

    @builtins.property # type: ignore
    @jsii.member(jsii_name="id")
    def id(self) -> typing.Optional[builtins.str]:
        return jsii.get(self, "id")

    @id.setter # type: ignore
    def id(self, value: typing.Optional[builtins.str]) -> None:
        jsii.set(self, "id", value)

    @builtins.property # type: ignore
    @jsii.member(jsii_name="identity")
    def identity(self) -> typing.Optional[typing.List["AppServiceSlotIdentity"]]:
        return jsii.get(self, "identity")

    @identity.setter # type: ignore
    def identity(
        self,
        value: typing.Optional[typing.List["AppServiceSlotIdentity"]],
    ) -> None:
        jsii.set(self, "identity", value)

    @builtins.property # type: ignore
    @jsii.member(jsii_name="logs")
    def logs(self) -> typing.Optional[typing.List["AppServiceSlotLogs"]]:
        return jsii.get(self, "logs")

    @logs.setter # type: ignore
    def logs(self, value: typing.Optional[typing.List["AppServiceSlotLogs"]]) -> None:
        jsii.set(self, "logs", value)

    @builtins.property # type: ignore
    @jsii.member(jsii_name="siteConfig")
    def site_config(self) -> typing.Optional[typing.List["AppServiceSlotSiteConfig"]]:
        return jsii.get(self, "siteConfig")

    @site_config.setter # type: ignore
    def site_config(
        self,
        value: typing.Optional[typing.List["AppServiceSlotSiteConfig"]],
    ) -> None:
        jsii.set(self, "siteConfig", value)

    @builtins.property # type: ignore
    @jsii.member(jsii_name="tags")
    def tags(self) -> typing.Optional[typing.Mapping[builtins.str, builtins.str]]:
        return jsii.get(self, "tags")

    @tags.setter # type: ignore
    def tags(
        self,
        value: typing.Optional[typing.Mapping[builtins.str, builtins.str]],
    ) -> None:
        jsii.set(self, "tags", value)

    @builtins.property # type: ignore
    @jsii.member(jsii_name="timeouts")
    def timeouts(self) -> typing.Optional["AppServiceSlotTimeouts"]:
        return jsii.get(self, "timeouts")

    @timeouts.setter # type: ignore
    def timeouts(self, value: typing.Optional["AppServiceSlotTimeouts"]) -> None:
        jsii.set(self, "timeouts", value)


@jsii.data_type(
    jsii_type="@cdktf/provider-azurerm.AppServiceSlotAuthSettings",
    jsii_struct_bases=[],
    name_mapping={
        "enabled": "enabled",
        "active_directory": "activeDirectory",
        "additional_login_params": "additionalLoginParams",
        "allowed_external_redirect_urls": "allowedExternalRedirectUrls",
        "default_provider": "defaultProvider",
        "facebook": "facebook",
        "google": "google",
        "issuer": "issuer",
        "microsoft": "microsoft",
        "runtime_version": "runtimeVersion",
        "token_refresh_extension_hours": "tokenRefreshExtensionHours",
        "token_store_enabled": "tokenStoreEnabled",
        "twitter": "twitter",
        "unauthenticated_client_action": "unauthenticatedClientAction",
    },
)
class AppServiceSlotAuthSettings:
    def __init__(
        self,
        *,
        enabled: builtins.bool,
        active_directory: typing.Optional[typing.List["AppServiceSlotAuthSettingsActiveDirectory"]] = None,
        additional_login_params: typing.Optional[typing.Mapping[builtins.str, builtins.str]] = None,
        allowed_external_redirect_urls: typing.Optional[typing.List[builtins.str]] = None,
        default_provider: typing.Optional[builtins.str] = None,
        facebook: typing.Optional[typing.List["AppServiceSlotAuthSettingsFacebook"]] = None,
        google: typing.Optional[typing.List["AppServiceSlotAuthSettingsGoogle"]] = None,
        issuer: typing.Optional[builtins.str] = None,
        microsoft: typing.Optional[typing.List["AppServiceSlotAuthSettingsMicrosoft"]] = None,
        runtime_version: typing.Optional[builtins.str] = None,
        token_refresh_extension_hours: typing.Optional[jsii.Number] = None,
        token_store_enabled: typing.Optional[builtins.bool] = None,
        twitter: typing.Optional[typing.List["AppServiceSlotAuthSettingsTwitter"]] = None,
        unauthenticated_client_action: typing.Optional[builtins.str] = None,
    ) -> None:
        """
        :param enabled: 
        :param active_directory: active_directory block.
        :param additional_login_params: 
        :param allowed_external_redirect_urls: 
        :param default_provider: 
        :param facebook: facebook block.
        :param google: google block.
        :param issuer: 
        :param microsoft: microsoft block.
        :param runtime_version: 
        :param token_refresh_extension_hours: 
        :param token_store_enabled: 
        :param twitter: twitter block.
        :param unauthenticated_client_action: 
        """
        self._values: typing.Dict[str, typing.Any] = {
            "enabled": enabled,
        }
        if active_directory is not None:
            self._values["active_directory"] = active_directory
        if additional_login_params is not None:
            self._values["additional_login_params"] = additional_login_params
        if allowed_external_redirect_urls is not None:
            self._values["allowed_external_redirect_urls"] = allowed_external_redirect_urls
        if default_provider is not None:
            self._values["default_provider"] = default_provider
        if facebook is not None:
            self._values["facebook"] = facebook
        if google is not None:
            self._values["google"] = google
        if issuer is not None:
            self._values["issuer"] = issuer
        if microsoft is not None:
            self._values["microsoft"] = microsoft
        if runtime_version is not None:
            self._values["runtime_version"] = runtime_version
        if token_refresh_extension_hours is not None:
            self._values["token_refresh_extension_hours"] = token_refresh_extension_hours
        if token_store_enabled is not None:
            self._values["token_store_enabled"] = token_store_enabled
        if twitter is not None:
            self._values["twitter"] = twitter
        if unauthenticated_client_action is not None:
            self._values["unauthenticated_client_action"] = unauthenticated_client_action

    @builtins.property
    def enabled(self) -> builtins.bool:
        result = self._values.get("enabled")
        assert result is not None, "Required property 'enabled' is missing"
        return result

    @builtins.property
    def active_directory(
        self,
    ) -> typing.Optional[typing.List["AppServiceSlotAuthSettingsActiveDirectory"]]:
        """active_directory block."""
        result = self._values.get("active_directory")
        return result

    @builtins.property
    def additional_login_params(
        self,
    ) -> typing.Optional[typing.Mapping[builtins.str, builtins.str]]:
        result = self._values.get("additional_login_params")
        return result

    @builtins.property
    def allowed_external_redirect_urls(
        self,
    ) -> typing.Optional[typing.List[builtins.str]]:
        result = self._values.get("allowed_external_redirect_urls")
        return result

    @builtins.property
    def default_provider(self) -> typing.Optional[builtins.str]:
        result = self._values.get("default_provider")
        return result

    @builtins.property
    def facebook(
        self,
    ) -> typing.Optional[typing.List["AppServiceSlotAuthSettingsFacebook"]]:
        """facebook block."""
        result = self._values.get("facebook")
        return result

    @builtins.property
    def google(
        self,
    ) -> typing.Optional[typing.List["AppServiceSlotAuthSettingsGoogle"]]:
        """google block."""
        result = self._values.get("google")
        return result

    @builtins.property
    def issuer(self) -> typing.Optional[builtins.str]:
        result = self._values.get("issuer")
        return result

    @builtins.property
    def microsoft(
        self,
    ) -> typing.Optional[typing.List["AppServiceSlotAuthSettingsMicrosoft"]]:
        """microsoft block."""
        result = self._values.get("microsoft")
        return result

    @builtins.property
    def runtime_version(self) -> typing.Optional[builtins.str]:
        result = self._values.get("runtime_version")
        return result

    @builtins.property
    def token_refresh_extension_hours(self) -> typing.Optional[jsii.Number]:
        result = self._values.get("token_refresh_extension_hours")
        return result

    @builtins.property
    def token_store_enabled(self) -> typing.Optional[builtins.bool]:
        result = self._values.get("token_store_enabled")
        return result

    @builtins.property
    def twitter(
        self,
    ) -> typing.Optional[typing.List["AppServiceSlotAuthSettingsTwitter"]]:
        """twitter block."""
        result = self._values.get("twitter")
        return result

    @builtins.property
    def unauthenticated_client_action(self) -> typing.Optional[builtins.str]:
        result = self._values.get("unauthenticated_client_action")
        return result

    def __eq__(self, rhs: typing.Any) -> builtins.bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs: typing.Any) -> builtins.bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return "AppServiceSlotAuthSettings(%s)" % ", ".join(
            k + "=" + repr(v) for k, v in self._values.items()
        )


@jsii.data_type(
    jsii_type="@cdktf/provider-azurerm.AppServiceSlotAuthSettingsActiveDirectory",
    jsii_struct_bases=[],
    name_mapping={
        "client_id": "clientId",
        "allowed_audiences": "allowedAudiences",
        "client_secret": "clientSecret",
    },
)
class AppServiceSlotAuthSettingsActiveDirectory:
    def __init__(
        self,
        *,
        client_id: builtins.str,
        allowed_audiences: typing.Optional[typing.List[builtins.str]] = None,
        client_secret: typing.Optional[builtins.str] = None,
    ) -> None:
        """
        :param client_id: 
        :param allowed_audiences: 
        :param client_secret: 
        """
        self._values: typing.Dict[str, typing.Any] = {
            "client_id": client_id,
        }
        if allowed_audiences is not None:
            self._values["allowed_audiences"] = allowed_audiences
        if client_secret is not None:
            self._values["client_secret"] = client_secret

    @builtins.property
    def client_id(self) -> builtins.str:
        result = self._values.get("client_id")
        assert result is not None, "Required property 'client_id' is missing"
        return result

    @builtins.property
    def allowed_audiences(self) -> typing.Optional[typing.List[builtins.str]]:
        result = self._values.get("allowed_audiences")
        return result

    @builtins.property
    def client_secret(self) -> typing.Optional[builtins.str]:
        result = self._values.get("client_secret")
        return result

    def __eq__(self, rhs: typing.Any) -> builtins.bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs: typing.Any) -> builtins.bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return "AppServiceSlotAuthSettingsActiveDirectory(%s)" % ", ".join(
            k + "=" + repr(v) for k, v in self._values.items()
        )


@jsii.data_type(
    jsii_type="@cdktf/provider-azurerm.AppServiceSlotAuthSettingsFacebook",
    jsii_struct_bases=[],
    name_mapping={
        "app_id": "appId",
        "app_secret": "appSecret",
        "oauth_scopes": "oauthScopes",
    },
)
class AppServiceSlotAuthSettingsFacebook:
    def __init__(
        self,
        *,
        app_id: builtins.str,
        app_secret: builtins.str,
        oauth_scopes: typing.Optional[typing.List[builtins.str]] = None,
    ) -> None:
        """
        :param app_id: 
        :param app_secret: 
        :param oauth_scopes: 
        """
        self._values: typing.Dict[str, typing.Any] = {
            "app_id": app_id,
            "app_secret": app_secret,
        }
        if oauth_scopes is not None:
            self._values["oauth_scopes"] = oauth_scopes

    @builtins.property
    def app_id(self) -> builtins.str:
        result = self._values.get("app_id")
        assert result is not None, "Required property 'app_id' is missing"
        return result

    @builtins.property
    def app_secret(self) -> builtins.str:
        result = self._values.get("app_secret")
        assert result is not None, "Required property 'app_secret' is missing"
        return result

    @builtins.property
    def oauth_scopes(self) -> typing.Optional[typing.List[builtins.str]]:
        result = self._values.get("oauth_scopes")
        return result

    def __eq__(self, rhs: typing.Any) -> builtins.bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs: typing.Any) -> builtins.bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return "AppServiceSlotAuthSettingsFacebook(%s)" % ", ".join(
            k + "=" + repr(v) for k, v in self._values.items()
        )


@jsii.data_type(
    jsii_type="@cdktf/provider-azurerm.AppServiceSlotAuthSettingsGoogle",
    jsii_struct_bases=[],
    name_mapping={
        "client_id": "clientId",
        "client_secret": "clientSecret",
        "oauth_scopes": "oauthScopes",
    },
)
class AppServiceSlotAuthSettingsGoogle:
    def __init__(
        self,
        *,
        client_id: builtins.str,
        client_secret: builtins.str,
        oauth_scopes: typing.Optional[typing.List[builtins.str]] = None,
    ) -> None:
        """
        :param client_id: 
        :param client_secret: 
        :param oauth_scopes: 
        """
        self._values: typing.Dict[str, typing.Any] = {
            "client_id": client_id,
            "client_secret": client_secret,
        }
        if oauth_scopes is not None:
            self._values["oauth_scopes"] = oauth_scopes

    @builtins.property
    def client_id(self) -> builtins.str:
        result = self._values.get("client_id")
        assert result is not None, "Required property 'client_id' is missing"
        return result

    @builtins.property
    def client_secret(self) -> builtins.str:
        result = self._values.get("client_secret")
        assert result is not None, "Required property 'client_secret' is missing"
        return result

    @builtins.property
    def oauth_scopes(self) -> typing.Optional[typing.List[builtins.str]]:
        result = self._values.get("oauth_scopes")
        return result

    def __eq__(self, rhs: typing.Any) -> builtins.bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs: typing.Any) -> builtins.bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return "AppServiceSlotAuthSettingsGoogle(%s)" % ", ".join(
            k + "=" + repr(v) for k, v in self._values.items()
        )


@jsii.data_type(
    jsii_type="@cdktf/provider-azurerm.AppServiceSlotAuthSettingsMicrosoft",
    jsii_struct_bases=[],
    name_mapping={
        "client_id": "clientId",
        "client_secret": "clientSecret",
        "oauth_scopes": "oauthScopes",
    },
)
class AppServiceSlotAuthSettingsMicrosoft:
    def __init__(
        self,
        *,
        client_id: builtins.str,
        client_secret: builtins.str,
        oauth_scopes: typing.Optional[typing.List[builtins.str]] = None,
    ) -> None:
        """
        :param client_id: 
        :param client_secret: 
        :param oauth_scopes: 
        """
        self._values: typing.Dict[str, typing.Any] = {
            "client_id": client_id,
            "client_secret": client_secret,
        }
        if oauth_scopes is not None:
            self._values["oauth_scopes"] = oauth_scopes

    @builtins.property
    def client_id(self) -> builtins.str:
        result = self._values.get("client_id")
        assert result is not None, "Required property 'client_id' is missing"
        return result

    @builtins.property
    def client_secret(self) -> builtins.str:
        result = self._values.get("client_secret")
        assert result is not None, "Required property 'client_secret' is missing"
        return result

    @builtins.property
    def oauth_scopes(self) -> typing.Optional[typing.List[builtins.str]]:
        result = self._values.get("oauth_scopes")
        return result

    def __eq__(self, rhs: typing.Any) -> builtins.bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs: typing.Any) -> builtins.bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return "AppServiceSlotAuthSettingsMicrosoft(%s)" % ", ".join(
            k + "=" + repr(v) for k, v in self._values.items()
        )


@jsii.data_type(
    jsii_type="@cdktf/provider-azurerm.AppServiceSlotAuthSettingsTwitter",
    jsii_struct_bases=[],
    name_mapping={"consumer_key": "consumerKey", "consumer_secret": "consumerSecret"},
)
class AppServiceSlotAuthSettingsTwitter:
    def __init__(
        self,
        *,
        consumer_key: builtins.str,
        consumer_secret: builtins.str,
    ) -> None:
        """
        :param consumer_key: 
        :param consumer_secret: 
        """
        self._values: typing.Dict[str, typing.Any] = {
            "consumer_key": consumer_key,
            "consumer_secret": consumer_secret,
        }

    @builtins.property
    def consumer_key(self) -> builtins.str:
        result = self._values.get("consumer_key")
        assert result is not None, "Required property 'consumer_key' is missing"
        return result

    @builtins.property
    def consumer_secret(self) -> builtins.str:
        result = self._values.get("consumer_secret")
        assert result is not None, "Required property 'consumer_secret' is missing"
        return result

    def __eq__(self, rhs: typing.Any) -> builtins.bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs: typing.Any) -> builtins.bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return "AppServiceSlotAuthSettingsTwitter(%s)" % ", ".join(
            k + "=" + repr(v) for k, v in self._values.items()
        )


@jsii.data_type(
    jsii_type="@cdktf/provider-azurerm.AppServiceSlotConfig",
    jsii_struct_bases=[cdktf.TerraformMetaArguments],
    name_mapping={
        "count": "count",
        "depends_on": "dependsOn",
        "lifecycle": "lifecycle",
        "provider": "provider",
        "app_service_name": "appServiceName",
        "app_service_plan_id": "appServicePlanId",
        "location": "location",
        "name": "name",
        "resource_group_name": "resourceGroupName",
        "app_settings": "appSettings",
        "auth_settings": "authSettings",
        "client_affinity_enabled": "clientAffinityEnabled",
        "connection_string": "connectionString",
        "enabled": "enabled",
        "https_only": "httpsOnly",
        "identity": "identity",
        "logs": "logs",
        "site_config": "siteConfig",
        "tags": "tags",
        "timeouts": "timeouts",
    },
)
class AppServiceSlotConfig(cdktf.TerraformMetaArguments):
    def __init__(
        self,
        *,
        count: typing.Optional[jsii.Number] = None,
        depends_on: typing.Optional[typing.List[cdktf.TerraformResource]] = None,
        lifecycle: typing.Optional[cdktf.TerraformResourceLifecycle] = None,
        provider: typing.Optional[cdktf.TerraformProvider] = None,
        app_service_name: builtins.str,
        app_service_plan_id: builtins.str,
        location: builtins.str,
        name: builtins.str,
        resource_group_name: builtins.str,
        app_settings: typing.Optional[typing.Mapping[builtins.str, builtins.str]] = None,
        auth_settings: typing.Optional[typing.List[AppServiceSlotAuthSettings]] = None,
        client_affinity_enabled: typing.Optional[builtins.bool] = None,
        connection_string: typing.Optional[typing.List["AppServiceSlotConnectionString"]] = None,
        enabled: typing.Optional[builtins.bool] = None,
        https_only: typing.Optional[builtins.bool] = None,
        identity: typing.Optional[typing.List["AppServiceSlotIdentity"]] = None,
        logs: typing.Optional[typing.List["AppServiceSlotLogs"]] = None,
        site_config: typing.Optional[typing.List["AppServiceSlotSiteConfig"]] = None,
        tags: typing.Optional[typing.Mapping[builtins.str, builtins.str]] = None,
        timeouts: typing.Optional["AppServiceSlotTimeouts"] = None,
    ) -> None:
        """
        :param count: 
        :param depends_on: 
        :param lifecycle: 
        :param provider: 
        :param app_service_name: 
        :param app_service_plan_id: 
        :param location: 
        :param name: 
        :param resource_group_name: 
        :param app_settings: 
        :param auth_settings: auth_settings block.
        :param client_affinity_enabled: 
        :param connection_string: connection_string block.
        :param enabled: 
        :param https_only: 
        :param identity: identity block.
        :param logs: logs block.
        :param site_config: site_config block.
        :param tags: 
        :param timeouts: timeouts block.
        """
        if isinstance(lifecycle, dict):
            lifecycle = cdktf.TerraformResourceLifecycle(**lifecycle)
        if isinstance(timeouts, dict):
            timeouts = AppServiceSlotTimeouts(**timeouts)
        self._values: typing.Dict[str, typing.Any] = {
            "app_service_name": app_service_name,
            "app_service_plan_id": app_service_plan_id,
            "location": location,
            "name": name,
            "resource_group_name": resource_group_name,
        }
        if count is not None:
            self._values["count"] = count
        if depends_on is not None:
            self._values["depends_on"] = depends_on
        if lifecycle is not None:
            self._values["lifecycle"] = lifecycle
        if provider is not None:
            self._values["provider"] = provider
        if app_settings is not None:
            self._values["app_settings"] = app_settings
        if auth_settings is not None:
            self._values["auth_settings"] = auth_settings
        if client_affinity_enabled is not None:
            self._values["client_affinity_enabled"] = client_affinity_enabled
        if connection_string is not None:
            self._values["connection_string"] = connection_string
        if enabled is not None:
            self._values["enabled"] = enabled
        if https_only is not None:
            self._values["https_only"] = https_only
        if identity is not None:
            self._values["identity"] = identity
        if logs is not None:
            self._values["logs"] = logs
        if site_config is not None:
            self._values["site_config"] = site_config
        if tags is not None:
            self._values["tags"] = tags
        if timeouts is not None:
            self._values["timeouts"] = timeouts

    @builtins.property
    def count(self) -> typing.Optional[jsii.Number]:
        """
        :stability: experimental
        """
        result = self._values.get("count")
        return result

    @builtins.property
    def depends_on(self) -> typing.Optional[typing.List[cdktf.TerraformResource]]:
        """
        :stability: experimental
        """
        result = self._values.get("depends_on")
        return result

    @builtins.property
    def lifecycle(self) -> typing.Optional[cdktf.TerraformResourceLifecycle]:
        """
        :stability: experimental
        """
        result = self._values.get("lifecycle")
        return result

    @builtins.property
    def provider(self) -> typing.Optional[cdktf.TerraformProvider]:
        """
        :stability: experimental
        """
        result = self._values.get("provider")
        return result

    @builtins.property
    def app_service_name(self) -> builtins.str:
        result = self._values.get("app_service_name")
        assert result is not None, "Required property 'app_service_name' is missing"
        return result

    @builtins.property
    def app_service_plan_id(self) -> builtins.str:
        result = self._values.get("app_service_plan_id")
        assert result is not None, "Required property 'app_service_plan_id' is missing"
        return result

    @builtins.property
    def location(self) -> builtins.str:
        result = self._values.get("location")
        assert result is not None, "Required property 'location' is missing"
        return result

    @builtins.property
    def name(self) -> builtins.str:
        result = self._values.get("name")
        assert result is not None, "Required property 'name' is missing"
        return result

    @builtins.property
    def resource_group_name(self) -> builtins.str:
        result = self._values.get("resource_group_name")
        assert result is not None, "Required property 'resource_group_name' is missing"
        return result

    @builtins.property
    def app_settings(
        self,
    ) -> typing.Optional[typing.Mapping[builtins.str, builtins.str]]:
        result = self._values.get("app_settings")
        return result

    @builtins.property
    def auth_settings(self) -> typing.Optional[typing.List[AppServiceSlotAuthSettings]]:
        """auth_settings block."""
        result = self._values.get("auth_settings")
        return result

    @builtins.property
    def client_affinity_enabled(self) -> typing.Optional[builtins.bool]:
        result = self._values.get("client_affinity_enabled")
        return result

    @builtins.property
    def connection_string(
        self,
    ) -> typing.Optional[typing.List["AppServiceSlotConnectionString"]]:
        """connection_string block."""
        result = self._values.get("connection_string")
        return result

    @builtins.property
    def enabled(self) -> typing.Optional[builtins.bool]:
        result = self._values.get("enabled")
        return result

    @builtins.property
    def https_only(self) -> typing.Optional[builtins.bool]:
        result = self._values.get("https_only")
        return result

    @builtins.property
    def identity(self) -> typing.Optional[typing.List["AppServiceSlotIdentity"]]:
        """identity block."""
        result = self._values.get("identity")
        return result

    @builtins.property
    def logs(self) -> typing.Optional[typing.List["AppServiceSlotLogs"]]:
        """logs block."""
        result = self._values.get("logs")
        return result

    @builtins.property
    def site_config(self) -> typing.Optional[typing.List["AppServiceSlotSiteConfig"]]:
        """site_config block."""
        result = self._values.get("site_config")
        return result

    @builtins.property
    def tags(self) -> typing.Optional[typing.Mapping[builtins.str, builtins.str]]:
        result = self._values.get("tags")
        return result

    @builtins.property
    def timeouts(self) -> typing.Optional["AppServiceSlotTimeouts"]:
        """timeouts block."""
        result = self._values.get("timeouts")
        return result

    def __eq__(self, rhs: typing.Any) -> builtins.bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs: typing.Any) -> builtins.bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return "AppServiceSlotConfig(%s)" % ", ".join(
            k + "=" + repr(v) for k, v in self._values.items()
        )


@jsii.data_type(
    jsii_type="@cdktf/provider-azurerm.AppServiceSlotConnectionString",
    jsii_struct_bases=[],
    name_mapping={"name": "name", "type": "type", "value": "value"},
)
class AppServiceSlotConnectionString:
    def __init__(
        self,
        *,
        name: builtins.str,
        type: builtins.str,
        value: builtins.str,
    ) -> None:
        """
        :param name: 
        :param type: 
        :param value: 
        """
        self._values: typing.Dict[str, typing.Any] = {
            "name": name,
            "type": type,
            "value": value,
        }

    @builtins.property
    def name(self) -> builtins.str:
        result = self._values.get("name")
        assert result is not None, "Required property 'name' is missing"
        return result

    @builtins.property
    def type(self) -> builtins.str:
        result = self._values.get("type")
        assert result is not None, "Required property 'type' is missing"
        return result

    @builtins.property
    def value(self) -> builtins.str:
        result = self._values.get("value")
        assert result is not None, "Required property 'value' is missing"
        return result

    def __eq__(self, rhs: typing.Any) -> builtins.bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs: typing.Any) -> builtins.bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return "AppServiceSlotConnectionString(%s)" % ", ".join(
            k + "=" + repr(v) for k, v in self._values.items()
        )


@jsii.data_type(
    jsii_type="@cdktf/provider-azurerm.AppServiceSlotIdentity",
    jsii_struct_bases=[],
    name_mapping={"type": "type", "identity_ids": "identityIds"},
)
class AppServiceSlotIdentity:
    def __init__(
        self,
        *,
        type: builtins.str,
        identity_ids: typing.Optional[typing.List[builtins.str]] = None,
    ) -> None:
        """
        :param type: 
        :param identity_ids: 
        """
        self._values: typing.Dict[str, typing.Any] = {
            "type": type,
        }
        if identity_ids is not None:
            self._values["identity_ids"] = identity_ids

    @builtins.property
    def type(self) -> builtins.str:
        result = self._values.get("type")
        assert result is not None, "Required property 'type' is missing"
        return result

    @builtins.property
    def identity_ids(self) -> typing.Optional[typing.List[builtins.str]]:
        result = self._values.get("identity_ids")
        return result

    def __eq__(self, rhs: typing.Any) -> builtins.bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs: typing.Any) -> builtins.bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return "AppServiceSlotIdentity(%s)" % ", ".join(
            k + "=" + repr(v) for k, v in self._values.items()
        )


@jsii.data_type(
    jsii_type="@cdktf/provider-azurerm.AppServiceSlotLogs",
    jsii_struct_bases=[],
    name_mapping={"application_logs": "applicationLogs", "http_logs": "httpLogs"},
)
class AppServiceSlotLogs:
    def __init__(
        self,
        *,
        application_logs: typing.Optional[typing.List["AppServiceSlotLogsApplicationLogs"]] = None,
        http_logs: typing.Optional[typing.List["AppServiceSlotLogsHttpLogs"]] = None,
    ) -> None:
        """
        :param application_logs: application_logs block.
        :param http_logs: http_logs block.
        """
        self._values: typing.Dict[str, typing.Any] = {}
        if application_logs is not None:
            self._values["application_logs"] = application_logs
        if http_logs is not None:
            self._values["http_logs"] = http_logs

    @builtins.property
    def application_logs(
        self,
    ) -> typing.Optional[typing.List["AppServiceSlotLogsApplicationLogs"]]:
        """application_logs block."""
        result = self._values.get("application_logs")
        return result

    @builtins.property
    def http_logs(self) -> typing.Optional[typing.List["AppServiceSlotLogsHttpLogs"]]:
        """http_logs block."""
        result = self._values.get("http_logs")
        return result

    def __eq__(self, rhs: typing.Any) -> builtins.bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs: typing.Any) -> builtins.bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return "AppServiceSlotLogs(%s)" % ", ".join(
            k + "=" + repr(v) for k, v in self._values.items()
        )


@jsii.data_type(
    jsii_type="@cdktf/provider-azurerm.AppServiceSlotLogsApplicationLogs",
    jsii_struct_bases=[],
    name_mapping={"azure_blob_storage": "azureBlobStorage"},
)
class AppServiceSlotLogsApplicationLogs:
    def __init__(
        self,
        *,
        azure_blob_storage: typing.Optional[typing.List["AppServiceSlotLogsApplicationLogsAzureBlobStorage"]] = None,
    ) -> None:
        """
        :param azure_blob_storage: azure_blob_storage block.
        """
        self._values: typing.Dict[str, typing.Any] = {}
        if azure_blob_storage is not None:
            self._values["azure_blob_storage"] = azure_blob_storage

    @builtins.property
    def azure_blob_storage(
        self,
    ) -> typing.Optional[typing.List["AppServiceSlotLogsApplicationLogsAzureBlobStorage"]]:
        """azure_blob_storage block."""
        result = self._values.get("azure_blob_storage")
        return result

    def __eq__(self, rhs: typing.Any) -> builtins.bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs: typing.Any) -> builtins.bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return "AppServiceSlotLogsApplicationLogs(%s)" % ", ".join(
            k + "=" + repr(v) for k, v in self._values.items()
        )


@jsii.data_type(
    jsii_type="@cdktf/provider-azurerm.AppServiceSlotLogsApplicationLogsAzureBlobStorage",
    jsii_struct_bases=[],
    name_mapping={
        "level": "level",
        "retention_in_days": "retentionInDays",
        "sas_url": "sasUrl",
    },
)
class AppServiceSlotLogsApplicationLogsAzureBlobStorage:
    def __init__(
        self,
        *,
        level: builtins.str,
        retention_in_days: jsii.Number,
        sas_url: builtins.str,
    ) -> None:
        """
        :param level: 
        :param retention_in_days: 
        :param sas_url: 
        """
        self._values: typing.Dict[str, typing.Any] = {
            "level": level,
            "retention_in_days": retention_in_days,
            "sas_url": sas_url,
        }

    @builtins.property
    def level(self) -> builtins.str:
        result = self._values.get("level")
        assert result is not None, "Required property 'level' is missing"
        return result

    @builtins.property
    def retention_in_days(self) -> jsii.Number:
        result = self._values.get("retention_in_days")
        assert result is not None, "Required property 'retention_in_days' is missing"
        return result

    @builtins.property
    def sas_url(self) -> builtins.str:
        result = self._values.get("sas_url")
        assert result is not None, "Required property 'sas_url' is missing"
        return result

    def __eq__(self, rhs: typing.Any) -> builtins.bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs: typing.Any) -> builtins.bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return "AppServiceSlotLogsApplicationLogsAzureBlobStorage(%s)" % ", ".join(
            k + "=" + repr(v) for k, v in self._values.items()
        )


@jsii.data_type(
    jsii_type="@cdktf/provider-azurerm.AppServiceSlotLogsHttpLogs",
    jsii_struct_bases=[],
    name_mapping={
        "azure_blob_storage": "azureBlobStorage",
        "file_system": "fileSystem",
    },
)
class AppServiceSlotLogsHttpLogs:
    def __init__(
        self,
        *,
        azure_blob_storage: typing.Optional[typing.List["AppServiceSlotLogsHttpLogsAzureBlobStorage"]] = None,
        file_system: typing.Optional[typing.List["AppServiceSlotLogsHttpLogsFileSystem"]] = None,
    ) -> None:
        """
        :param azure_blob_storage: azure_blob_storage block.
        :param file_system: file_system block.
        """
        self._values: typing.Dict[str, typing.Any] = {}
        if azure_blob_storage is not None:
            self._values["azure_blob_storage"] = azure_blob_storage
        if file_system is not None:
            self._values["file_system"] = file_system

    @builtins.property
    def azure_blob_storage(
        self,
    ) -> typing.Optional[typing.List["AppServiceSlotLogsHttpLogsAzureBlobStorage"]]:
        """azure_blob_storage block."""
        result = self._values.get("azure_blob_storage")
        return result

    @builtins.property
    def file_system(
        self,
    ) -> typing.Optional[typing.List["AppServiceSlotLogsHttpLogsFileSystem"]]:
        """file_system block."""
        result = self._values.get("file_system")
        return result

    def __eq__(self, rhs: typing.Any) -> builtins.bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs: typing.Any) -> builtins.bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return "AppServiceSlotLogsHttpLogs(%s)" % ", ".join(
            k + "=" + repr(v) for k, v in self._values.items()
        )


@jsii.data_type(
    jsii_type="@cdktf/provider-azurerm.AppServiceSlotLogsHttpLogsAzureBlobStorage",
    jsii_struct_bases=[],
    name_mapping={"retention_in_days": "retentionInDays", "sas_url": "sasUrl"},
)
class AppServiceSlotLogsHttpLogsAzureBlobStorage:
    def __init__(
        self,
        *,
        retention_in_days: jsii.Number,
        sas_url: builtins.str,
    ) -> None:
        """
        :param retention_in_days: 
        :param sas_url: 
        """
        self._values: typing.Dict[str, typing.Any] = {
            "retention_in_days": retention_in_days,
            "sas_url": sas_url,
        }

    @builtins.property
    def retention_in_days(self) -> jsii.Number:
        result = self._values.get("retention_in_days")
        assert result is not None, "Required property 'retention_in_days' is missing"
        return result

    @builtins.property
    def sas_url(self) -> builtins.str:
        result = self._values.get("sas_url")
        assert result is not None, "Required property 'sas_url' is missing"
        return result

    def __eq__(self, rhs: typing.Any) -> builtins.bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs: typing.Any) -> builtins.bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return "AppServiceSlotLogsHttpLogsAzureBlobStorage(%s)" % ", ".join(
            k + "=" + repr(v) for k, v in self._values.items()
        )


@jsii.data_type(
    jsii_type="@cdktf/provider-azurerm.AppServiceSlotLogsHttpLogsFileSystem",
    jsii_struct_bases=[],
    name_mapping={
        "retention_in_days": "retentionInDays",
        "retention_in_mb": "retentionInMb",
    },
)
class AppServiceSlotLogsHttpLogsFileSystem:
    def __init__(
        self,
        *,
        retention_in_days: jsii.Number,
        retention_in_mb: jsii.Number,
    ) -> None:
        """
        :param retention_in_days: 
        :param retention_in_mb: 
        """
        self._values: typing.Dict[str, typing.Any] = {
            "retention_in_days": retention_in_days,
            "retention_in_mb": retention_in_mb,
        }

    @builtins.property
    def retention_in_days(self) -> jsii.Number:
        result = self._values.get("retention_in_days")
        assert result is not None, "Required property 'retention_in_days' is missing"
        return result

    @builtins.property
    def retention_in_mb(self) -> jsii.Number:
        result = self._values.get("retention_in_mb")
        assert result is not None, "Required property 'retention_in_mb' is missing"
        return result

    def __eq__(self, rhs: typing.Any) -> builtins.bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs: typing.Any) -> builtins.bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return "AppServiceSlotLogsHttpLogsFileSystem(%s)" % ", ".join(
            k + "=" + repr(v) for k, v in self._values.items()
        )


@jsii.data_type(
    jsii_type="@cdktf/provider-azurerm.AppServiceSlotSiteConfig",
    jsii_struct_bases=[],
    name_mapping={
        "always_on": "alwaysOn",
        "app_command_line": "appCommandLine",
        "auto_swap_slot_name": "autoSwapSlotName",
        "cors": "cors",
        "default_documents": "defaultDocuments",
        "dotnet_framework_version": "dotnetFrameworkVersion",
        "ftps_state": "ftpsState",
        "http2_enabled": "http2Enabled",
        "ip_restriction": "ipRestriction",
        "java_container": "javaContainer",
        "java_container_version": "javaContainerVersion",
        "java_version": "javaVersion",
        "linux_fx_version": "linuxFxVersion",
        "local_mysql_enabled": "localMysqlEnabled",
        "managed_pipeline_mode": "managedPipelineMode",
        "min_tls_version": "minTlsVersion",
        "php_version": "phpVersion",
        "python_version": "pythonVersion",
        "remote_debugging_enabled": "remoteDebuggingEnabled",
        "remote_debugging_version": "remoteDebuggingVersion",
        "scm_type": "scmType",
        "use32_bit_worker_process": "use32BitWorkerProcess",
        "websockets_enabled": "websocketsEnabled",
        "windows_fx_version": "windowsFxVersion",
    },
)
class AppServiceSlotSiteConfig:
    def __init__(
        self,
        *,
        always_on: typing.Optional[builtins.bool] = None,
        app_command_line: typing.Optional[builtins.str] = None,
        auto_swap_slot_name: typing.Optional[builtins.str] = None,
        cors: typing.Optional[typing.List["AppServiceSlotSiteConfigCors"]] = None,
        default_documents: typing.Optional[typing.List[builtins.str]] = None,
        dotnet_framework_version: typing.Optional[builtins.str] = None,
        ftps_state: typing.Optional[builtins.str] = None,
        http2_enabled: typing.Optional[builtins.bool] = None,
        ip_restriction: typing.Optional[typing.List["AppServiceSlotSiteConfigIpRestriction"]] = None,
        java_container: typing.Optional[builtins.str] = None,
        java_container_version: typing.Optional[builtins.str] = None,
        java_version: typing.Optional[builtins.str] = None,
        linux_fx_version: typing.Optional[builtins.str] = None,
        local_mysql_enabled: typing.Optional[builtins.bool] = None,
        managed_pipeline_mode: typing.Optional[builtins.str] = None,
        min_tls_version: typing.Optional[builtins.str] = None,
        php_version: typing.Optional[builtins.str] = None,
        python_version: typing.Optional[builtins.str] = None,
        remote_debugging_enabled: typing.Optional[builtins.bool] = None,
        remote_debugging_version: typing.Optional[builtins.str] = None,
        scm_type: typing.Optional[builtins.str] = None,
        use32_bit_worker_process: typing.Optional[builtins.bool] = None,
        websockets_enabled: typing.Optional[builtins.bool] = None,
        windows_fx_version: typing.Optional[builtins.str] = None,
    ) -> None:
        """
        :param always_on: 
        :param app_command_line: 
        :param auto_swap_slot_name: 
        :param cors: cors block.
        :param default_documents: 
        :param dotnet_framework_version: 
        :param ftps_state: 
        :param http2_enabled: 
        :param ip_restriction: 
        :param java_container: 
        :param java_container_version: 
        :param java_version: 
        :param linux_fx_version: 
        :param local_mysql_enabled: 
        :param managed_pipeline_mode: 
        :param min_tls_version: 
        :param php_version: 
        :param python_version: 
        :param remote_debugging_enabled: 
        :param remote_debugging_version: 
        :param scm_type: 
        :param use32_bit_worker_process: 
        :param websockets_enabled: 
        :param windows_fx_version: 
        """
        self._values: typing.Dict[str, typing.Any] = {}
        if always_on is not None:
            self._values["always_on"] = always_on
        if app_command_line is not None:
            self._values["app_command_line"] = app_command_line
        if auto_swap_slot_name is not None:
            self._values["auto_swap_slot_name"] = auto_swap_slot_name
        if cors is not None:
            self._values["cors"] = cors
        if default_documents is not None:
            self._values["default_documents"] = default_documents
        if dotnet_framework_version is not None:
            self._values["dotnet_framework_version"] = dotnet_framework_version
        if ftps_state is not None:
            self._values["ftps_state"] = ftps_state
        if http2_enabled is not None:
            self._values["http2_enabled"] = http2_enabled
        if ip_restriction is not None:
            self._values["ip_restriction"] = ip_restriction
        if java_container is not None:
            self._values["java_container"] = java_container
        if java_container_version is not None:
            self._values["java_container_version"] = java_container_version
        if java_version is not None:
            self._values["java_version"] = java_version
        if linux_fx_version is not None:
            self._values["linux_fx_version"] = linux_fx_version
        if local_mysql_enabled is not None:
            self._values["local_mysql_enabled"] = local_mysql_enabled
        if managed_pipeline_mode is not None:
            self._values["managed_pipeline_mode"] = managed_pipeline_mode
        if min_tls_version is not None:
            self._values["min_tls_version"] = min_tls_version
        if php_version is not None:
            self._values["php_version"] = php_version
        if python_version is not None:
            self._values["python_version"] = python_version
        if remote_debugging_enabled is not None:
            self._values["remote_debugging_enabled"] = remote_debugging_enabled
        if remote_debugging_version is not None:
            self._values["remote_debugging_version"] = remote_debugging_version
        if scm_type is not None:
            self._values["scm_type"] = scm_type
        if use32_bit_worker_process is not None:
            self._values["use32_bit_worker_process"] = use32_bit_worker_process
        if websockets_enabled is not None:
            self._values["websockets_enabled"] = websockets_enabled
        if windows_fx_version is not None:
            self._values["windows_fx_version"] = windows_fx_version

    @builtins.property
    def always_on(self) -> typing.Optional[builtins.bool]:
        result = self._values.get("always_on")
        return result

    @builtins.property
    def app_command_line(self) -> typing.Optional[builtins.str]:
        result = self._values.get("app_command_line")
        return result

    @builtins.property
    def auto_swap_slot_name(self) -> typing.Optional[builtins.str]:
        result = self._values.get("auto_swap_slot_name")
        return result

    @builtins.property
    def cors(self) -> typing.Optional[typing.List["AppServiceSlotSiteConfigCors"]]:
        """cors block."""
        result = self._values.get("cors")
        return result

    @builtins.property
    def default_documents(self) -> typing.Optional[typing.List[builtins.str]]:
        result = self._values.get("default_documents")
        return result

    @builtins.property
    def dotnet_framework_version(self) -> typing.Optional[builtins.str]:
        result = self._values.get("dotnet_framework_version")
        return result

    @builtins.property
    def ftps_state(self) -> typing.Optional[builtins.str]:
        result = self._values.get("ftps_state")
        return result

    @builtins.property
    def http2_enabled(self) -> typing.Optional[builtins.bool]:
        result = self._values.get("http2_enabled")
        return result

    @builtins.property
    def ip_restriction(
        self,
    ) -> typing.Optional[typing.List["AppServiceSlotSiteConfigIpRestriction"]]:
        result = self._values.get("ip_restriction")
        return result

    @builtins.property
    def java_container(self) -> typing.Optional[builtins.str]:
        result = self._values.get("java_container")
        return result

    @builtins.property
    def java_container_version(self) -> typing.Optional[builtins.str]:
        result = self._values.get("java_container_version")
        return result

    @builtins.property
    def java_version(self) -> typing.Optional[builtins.str]:
        result = self._values.get("java_version")
        return result

    @builtins.property
    def linux_fx_version(self) -> typing.Optional[builtins.str]:
        result = self._values.get("linux_fx_version")
        return result

    @builtins.property
    def local_mysql_enabled(self) -> typing.Optional[builtins.bool]:
        result = self._values.get("local_mysql_enabled")
        return result

    @builtins.property
    def managed_pipeline_mode(self) -> typing.Optional[builtins.str]:
        result = self._values.get("managed_pipeline_mode")
        return result

    @builtins.property
    def min_tls_version(self) -> typing.Optional[builtins.str]:
        result = self._values.get("min_tls_version")
        return result

    @builtins.property
    def php_version(self) -> typing.Optional[builtins.str]:
        result = self._values.get("php_version")
        return result

    @builtins.property
    def python_version(self) -> typing.Optional[builtins.str]:
        result = self._values.get("python_version")
        return result

    @builtins.property
    def remote_debugging_enabled(self) -> typing.Optional[builtins.bool]:
        result = self._values.get("remote_debugging_enabled")
        return result

    @builtins.property
    def remote_debugging_version(self) -> typing.Optional[builtins.str]:
        result = self._values.get("remote_debugging_version")
        return result

    @builtins.property
    def scm_type(self) -> typing.Optional[builtins.str]:
        result = self._values.get("scm_type")
        return result

    @builtins.property
    def use32_bit_worker_process(self) -> typing.Optional[builtins.bool]:
        result = self._values.get("use32_bit_worker_process")
        return result

    @builtins.property
    def websockets_enabled(self) -> typing.Optional[builtins.bool]:
        result = self._values.get("websockets_enabled")
        return result

    @builtins.property
    def windows_fx_version(self) -> typing.Optional[builtins.str]:
        result = self._values.get("windows_fx_version")
        return result

    def __eq__(self, rhs: typing.Any) -> builtins.bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs: typing.Any) -> builtins.bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return "AppServiceSlotSiteConfig(%s)" % ", ".join(
            k + "=" + repr(v) for k, v in self._values.items()
        )


@jsii.data_type(
    jsii_type="@cdktf/provider-azurerm.AppServiceSlotSiteConfigCors",
    jsii_struct_bases=[],
    name_mapping={
        "allowed_origins": "allowedOrigins",
        "support_credentials": "supportCredentials",
    },
)
class AppServiceSlotSiteConfigCors:
    def __init__(
        self,
        *,
        allowed_origins: typing.List[builtins.str],
        support_credentials: typing.Optional[builtins.bool] = None,
    ) -> None:
        """
        :param allowed_origins: 
        :param support_credentials: 
        """
        self._values: typing.Dict[str, typing.Any] = {
            "allowed_origins": allowed_origins,
        }
        if support_credentials is not None:
            self._values["support_credentials"] = support_credentials

    @builtins.property
    def allowed_origins(self) -> typing.List[builtins.str]:
        result = self._values.get("allowed_origins")
        assert result is not None, "Required property 'allowed_origins' is missing"
        return result

    @builtins.property
    def support_credentials(self) -> typing.Optional[builtins.bool]:
        result = self._values.get("support_credentials")
        return result

    def __eq__(self, rhs: typing.Any) -> builtins.bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs: typing.Any) -> builtins.bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return "AppServiceSlotSiteConfigCors(%s)" % ", ".join(
            k + "=" + repr(v) for k, v in self._values.items()
        )


@jsii.data_type(
    jsii_type="@cdktf/provider-azurerm.AppServiceSlotSiteConfigIpRestriction",
    jsii_struct_bases=[],
    name_mapping={
        "ip_address": "ipAddress",
        "virtual_network_subnet_id": "virtualNetworkSubnetId",
    },
)
class AppServiceSlotSiteConfigIpRestriction:
    def __init__(
        self,
        *,
        ip_address: typing.Optional[builtins.str] = None,
        virtual_network_subnet_id: typing.Optional[builtins.str] = None,
    ) -> None:
        """
        :param ip_address: 
        :param virtual_network_subnet_id: 
        """
        self._values: typing.Dict[str, typing.Any] = {}
        if ip_address is not None:
            self._values["ip_address"] = ip_address
        if virtual_network_subnet_id is not None:
            self._values["virtual_network_subnet_id"] = virtual_network_subnet_id

    @builtins.property
    def ip_address(self) -> typing.Optional[builtins.str]:
        result = self._values.get("ip_address")
        return result

    @builtins.property
    def virtual_network_subnet_id(self) -> typing.Optional[builtins.str]:
        result = self._values.get("virtual_network_subnet_id")
        return result

    def __eq__(self, rhs: typing.Any) -> builtins.bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs: typing.Any) -> builtins.bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return "AppServiceSlotSiteConfigIpRestriction(%s)" % ", ".join(
            k + "=" + repr(v) for k, v in self._values.items()
        )


class AppServiceSlotSiteCredential(
    cdktf.ComplexComputedList,
    metaclass=jsii.JSIIMeta,
    jsii_type="@cdktf/provider-azurerm.AppServiceSlotSiteCredential",
):
    def __init__(
        self,
        terraform_resource: cdktf.ITerraformResource,
        terraform_attribute: builtins.str,
        index: builtins.str,
    ) -> None:
        """
        :param terraform_resource: -
        :param terraform_attribute: -
        :param index: -

        :stability: experimental
        """
        jsii.create(AppServiceSlotSiteCredential, self, [terraform_resource, terraform_attribute, index])

    @builtins.property # type: ignore
    @jsii.member(jsii_name="password")
    def password(self) -> builtins.str:
        return jsii.get(self, "password")

    @builtins.property # type: ignore
    @jsii.member(jsii_name="username")
    def username(self) -> builtins.str:
        return jsii.get(self, "username")


@jsii.data_type(
    jsii_type="@cdktf/provider-azurerm.AppServiceSlotTimeouts",
    jsii_struct_bases=[],
    name_mapping={
        "create": "create",
        "delete": "delete",
        "read": "read",
        "update": "update",
    },
)
class AppServiceSlotTimeouts:
    def __init__(
        self,
        *,
        create: typing.Optional[builtins.str] = None,
        delete: typing.Optional[builtins.str] = None,
        read: typing.Optional[builtins.str] = None,
        update: typing.Optional[builtins.str] = None,
    ) -> None:
        """
        :param create: 
        :param delete: 
        :param read: 
        :param update: 
        """
        self._values: typing.Dict[str, typing.Any] = {}
        if create is not None:
            self._values["create"] = create
        if delete is not None:
            self._values["delete"] = delete
        if read is not None:
            self._values["read"] = read
        if update is not None:
            self._values["update"] = update

    @builtins.property
    def create(self) -> typing.Optional[builtins.str]:
        result = self._values.get("create")
        return result

    @builtins.property
    def delete(self) -> typing.Optional[builtins.str]:
        result = self._values.get("delete")
        return result

    @builtins.property
    def read(self) -> typing.Optional[builtins.str]:
        result = self._values.get("read")
        return result

    @builtins.property
    def update(self) -> typing.Optional[builtins.str]:
        result = self._values.get("update")
        return result

    def __eq__(self, rhs: typing.Any) -> builtins.bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs: typing.Any) -> builtins.bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return "AppServiceSlotTimeouts(%s)" % ", ".join(
            k + "=" + repr(v) for k, v in self._values.items()
        )


class AppServiceSourceControl(
    cdktf.ComplexComputedList,
    metaclass=jsii.JSIIMeta,
    jsii_type="@cdktf/provider-azurerm.AppServiceSourceControl",
):
    def __init__(
        self,
        terraform_resource: cdktf.ITerraformResource,
        terraform_attribute: builtins.str,
        index: builtins.str,
    ) -> None:
        """
        :param terraform_resource: -
        :param terraform_attribute: -
        :param index: -

        :stability: experimental
        """
        jsii.create(AppServiceSourceControl, self, [terraform_resource, terraform_attribute, index])

    @builtins.property # type: ignore
    @jsii.member(jsii_name="branch")
    def branch(self) -> builtins.str:
        return jsii.get(self, "branch")

    @builtins.property # type: ignore
    @jsii.member(jsii_name="repoUrl")
    def repo_url(self) -> builtins.str:
        return jsii.get(self, "repoUrl")


class AppServiceSourceControlToken(
    cdktf.TerraformResource,
    metaclass=jsii.JSIIMeta,
    jsii_type="@cdktf/provider-azurerm.AppServiceSourceControlToken",
):
    def __init__(
        self,
        scope: constructs.Construct,
        id: builtins.str,
        *,
        token: builtins.str,
        type: builtins.str,
        timeouts: typing.Optional["AppServiceSourceControlTokenTimeouts"] = None,
        token_secret: typing.Optional[builtins.str] = None,
        count: typing.Optional[jsii.Number] = None,
        depends_on: typing.Optional[typing.List[cdktf.TerraformResource]] = None,
        lifecycle: typing.Optional[cdktf.TerraformResourceLifecycle] = None,
        provider: typing.Optional[cdktf.TerraformProvider] = None,
    ) -> None:
        """
        :param scope: -
        :param id: -
        :param token: 
        :param type: 
        :param timeouts: timeouts block.
        :param token_secret: 
        :param count: 
        :param depends_on: 
        :param lifecycle: 
        :param provider: 
        """
        config = AppServiceSourceControlTokenConfig(
            token=token,
            type=type,
            timeouts=timeouts,
            token_secret=token_secret,
            count=count,
            depends_on=depends_on,
            lifecycle=lifecycle,
            provider=provider,
        )

        jsii.create(AppServiceSourceControlToken, self, [scope, id, config])

    @jsii.member(jsii_name="synthesizeAttributes")
    def _synthesize_attributes(self) -> typing.Mapping[builtins.str, typing.Any]:
        return jsii.invoke(self, "synthesizeAttributes", [])

    @builtins.property # type: ignore
    @jsii.member(jsii_name="token")
    def token(self) -> builtins.str:
        return jsii.get(self, "token")

    @token.setter # type: ignore
    def token(self, value: builtins.str) -> None:
        jsii.set(self, "token", value)

    @builtins.property # type: ignore
    @jsii.member(jsii_name="type")
    def type(self) -> builtins.str:
        return jsii.get(self, "type")

    @type.setter # type: ignore
    def type(self, value: builtins.str) -> None:
        jsii.set(self, "type", value)

    @builtins.property # type: ignore
    @jsii.member(jsii_name="id")
    def id(self) -> typing.Optional[builtins.str]:
        return jsii.get(self, "id")

    @id.setter # type: ignore
    def id(self, value: typing.Optional[builtins.str]) -> None:
        jsii.set(self, "id", value)

    @builtins.property # type: ignore
    @jsii.member(jsii_name="timeouts")
    def timeouts(self) -> typing.Optional["AppServiceSourceControlTokenTimeouts"]:
        return jsii.get(self, "timeouts")

    @timeouts.setter # type: ignore
    def timeouts(
        self,
        value: typing.Optional["AppServiceSourceControlTokenTimeouts"],
    ) -> None:
        jsii.set(self, "timeouts", value)

    @builtins.property # type: ignore
    @jsii.member(jsii_name="tokenSecret")
    def token_secret(self) -> typing.Optional[builtins.str]:
        return jsii.get(self, "tokenSecret")

    @token_secret.setter # type: ignore
    def token_secret(self, value: typing.Optional[builtins.str]) -> None:
        jsii.set(self, "tokenSecret", value)


@jsii.data_type(
    jsii_type="@cdktf/provider-azurerm.AppServiceSourceControlTokenConfig",
    jsii_struct_bases=[cdktf.TerraformMetaArguments],
    name_mapping={
        "count": "count",
        "depends_on": "dependsOn",
        "lifecycle": "lifecycle",
        "provider": "provider",
        "token": "token",
        "type": "type",
        "timeouts": "timeouts",
        "token_secret": "tokenSecret",
    },
)
class AppServiceSourceControlTokenConfig(cdktf.TerraformMetaArguments):
    def __init__(
        self,
        *,
        count: typing.Optional[jsii.Number] = None,
        depends_on: typing.Optional[typing.List[cdktf.TerraformResource]] = None,
        lifecycle: typing.Optional[cdktf.TerraformResourceLifecycle] = None,
        provider: typing.Optional[cdktf.TerraformProvider] = None,
        token: builtins.str,
        type: builtins.str,
        timeouts: typing.Optional["AppServiceSourceControlTokenTimeouts"] = None,
        token_secret: typing.Optional[builtins.str] = None,
    ) -> None:
        """
        :param count: 
        :param depends_on: 
        :param lifecycle: 
        :param provider: 
        :param token: 
        :param type: 
        :param timeouts: timeouts block.
        :param token_secret: 
        """
        if isinstance(lifecycle, dict):
            lifecycle = cdktf.TerraformResourceLifecycle(**lifecycle)
        if isinstance(timeouts, dict):
            timeouts = AppServiceSourceControlTokenTimeouts(**timeouts)
        self._values: typing.Dict[str, typing.Any] = {
            "token": token,
            "type": type,
        }
        if count is not None:
            self._values["count"] = count
        if depends_on is not None:
            self._values["depends_on"] = depends_on
        if lifecycle is not None:
            self._values["lifecycle"] = lifecycle
        if provider is not None:
            self._values["provider"] = provider
        if timeouts is not None:
            self._values["timeouts"] = timeouts
        if token_secret is not None:
            self._values["token_secret"] = token_secret

    @builtins.property
    def count(self) -> typing.Optional[jsii.Number]:
        """
        :stability: experimental
        """
        result = self._values.get("count")
        return result

    @builtins.property
    def depends_on(self) -> typing.Optional[typing.List[cdktf.TerraformResource]]:
        """
        :stability: experimental
        """
        result = self._values.get("depends_on")
        return result

    @builtins.property
    def lifecycle(self) -> typing.Optional[cdktf.TerraformResourceLifecycle]:
        """
        :stability: experimental
        """
        result = self._values.get("lifecycle")
        return result

    @builtins.property
    def provider(self) -> typing.Optional[cdktf.TerraformProvider]:
        """
        :stability: experimental
        """
        result = self._values.get("provider")
        return result

    @builtins.property
    def token(self) -> builtins.str:
        result = self._values.get("token")
        assert result is not None, "Required property 'token' is missing"
        return result

    @builtins.property
    def type(self) -> builtins.str:
        result = self._values.get("type")
        assert result is not None, "Required property 'type' is missing"
        return result

    @builtins.property
    def timeouts(self) -> typing.Optional["AppServiceSourceControlTokenTimeouts"]:
        """timeouts block."""
        result = self._values.get("timeouts")
        return result

    @builtins.property
    def token_secret(self) -> typing.Optional[builtins.str]:
        result = self._values.get("token_secret")
        return result

    def __eq__(self, rhs: typing.Any) -> builtins.bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs: typing.Any) -> builtins.bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return "AppServiceSourceControlTokenConfig(%s)" % ", ".join(
            k + "=" + repr(v) for k, v in self._values.items()
        )


@jsii.data_type(
    jsii_type="@cdktf/provider-azurerm.AppServiceSourceControlTokenTimeouts",
    jsii_struct_bases=[],
    name_mapping={
        "create": "create",
        "delete": "delete",
        "read": "read",
        "update": "update",
    },
)
class AppServiceSourceControlTokenTimeouts:
    def __init__(
        self,
        *,
        create: typing.Optional[builtins.str] = None,
        delete: typing.Optional[builtins.str] = None,
        read: typing.Optional[builtins.str] = None,
        update: typing.Optional[builtins.str] = None,
    ) -> None:
        """
        :param create: 
        :param delete: 
        :param read: 
        :param update: 
        """
        self._values: typing.Dict[str, typing.Any] = {}
        if create is not None:
            self._values["create"] = create
        if delete is not None:
            self._values["delete"] = delete
        if read is not None:
            self._values["read"] = read
        if update is not None:
            self._values["update"] = update

    @builtins.property
    def create(self) -> typing.Optional[builtins.str]:
        result = self._values.get("create")
        return result

    @builtins.property
    def delete(self) -> typing.Optional[builtins.str]:
        result = self._values.get("delete")
        return result

    @builtins.property
    def read(self) -> typing.Optional[builtins.str]:
        result = self._values.get("read")
        return result

    @builtins.property
    def update(self) -> typing.Optional[builtins.str]:
        result = self._values.get("update")
        return result

    def __eq__(self, rhs: typing.Any) -> builtins.bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs: typing.Any) -> builtins.bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return "AppServiceSourceControlTokenTimeouts(%s)" % ", ".join(
            k + "=" + repr(v) for k, v in self._values.items()
        )


@jsii.data_type(
    jsii_type="@cdktf/provider-azurerm.AppServiceStorageAccount",
    jsii_struct_bases=[],
    name_mapping={
        "access_key": "accessKey",
        "account_name": "accountName",
        "name": "name",
        "share_name": "shareName",
        "type": "type",
        "mount_path": "mountPath",
    },
)
class AppServiceStorageAccount:
    def __init__(
        self,
        *,
        access_key: builtins.str,
        account_name: builtins.str,
        name: builtins.str,
        share_name: builtins.str,
        type: builtins.str,
        mount_path: typing.Optional[builtins.str] = None,
    ) -> None:
        """
        :param access_key: 
        :param account_name: 
        :param name: 
        :param share_name: 
        :param type: 
        :param mount_path: 
        """
        self._values: typing.Dict[str, typing.Any] = {
            "access_key": access_key,
            "account_name": account_name,
            "name": name,
            "share_name": share_name,
            "type": type,
        }
        if mount_path is not None:
            self._values["mount_path"] = mount_path

    @builtins.property
    def access_key(self) -> builtins.str:
        result = self._values.get("access_key")
        assert result is not None, "Required property 'access_key' is missing"
        return result

    @builtins.property
    def account_name(self) -> builtins.str:
        result = self._values.get("account_name")
        assert result is not None, "Required property 'account_name' is missing"
        return result

    @builtins.property
    def name(self) -> builtins.str:
        result = self._values.get("name")
        assert result is not None, "Required property 'name' is missing"
        return result

    @builtins.property
    def share_name(self) -> builtins.str:
        result = self._values.get("share_name")
        assert result is not None, "Required property 'share_name' is missing"
        return result

    @builtins.property
    def type(self) -> builtins.str:
        result = self._values.get("type")
        assert result is not None, "Required property 'type' is missing"
        return result

    @builtins.property
    def mount_path(self) -> typing.Optional[builtins.str]:
        result = self._values.get("mount_path")
        return result

    def __eq__(self, rhs: typing.Any) -> builtins.bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs: typing.Any) -> builtins.bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return "AppServiceStorageAccount(%s)" % ", ".join(
            k + "=" + repr(v) for k, v in self._values.items()
        )


@jsii.data_type(
    jsii_type="@cdktf/provider-azurerm.AppServiceTimeouts",
    jsii_struct_bases=[],
    name_mapping={
        "create": "create",
        "delete": "delete",
        "read": "read",
        "update": "update",
    },
)
class AppServiceTimeouts:
    def __init__(
        self,
        *,
        create: typing.Optional[builtins.str] = None,
        delete: typing.Optional[builtins.str] = None,
        read: typing.Optional[builtins.str] = None,
        update: typing.Optional[builtins.str] = None,
    ) -> None:
        """
        :param create: 
        :param delete: 
        :param read: 
        :param update: 
        """
        self._values: typing.Dict[str, typing.Any] = {}
        if create is not None:
            self._values["create"] = create
        if delete is not None:
            self._values["delete"] = delete
        if read is not None:
            self._values["read"] = read
        if update is not None:
            self._values["update"] = update

    @builtins.property
    def create(self) -> typing.Optional[builtins.str]:
        result = self._values.get("create")
        return result

    @builtins.property
    def delete(self) -> typing.Optional[builtins.str]:
        result = self._values.get("delete")
        return result

    @builtins.property
    def read(self) -> typing.Optional[builtins.str]:
        result = self._values.get("read")
        return result

    @builtins.property
    def update(self) -> typing.Optional[builtins.str]:
        result = self._values.get("update")
        return result

    def __eq__(self, rhs: typing.Any) -> builtins.bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs: typing.Any) -> builtins.bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return "AppServiceTimeouts(%s)" % ", ".join(
            k + "=" + repr(v) for k, v in self._values.items()
        )


class AppServiceVirtualNetworkSwiftConnection(
    cdktf.TerraformResource,
    metaclass=jsii.JSIIMeta,
    jsii_type="@cdktf/provider-azurerm.AppServiceVirtualNetworkSwiftConnection",
):
    def __init__(
        self,
        scope: constructs.Construct,
        id: builtins.str,
        *,
        app_service_id: builtins.str,
        subnet_id: builtins.str,
        timeouts: typing.Optional["AppServiceVirtualNetworkSwiftConnectionTimeouts"] = None,
        count: typing.Optional[jsii.Number] = None,
        depends_on: typing.Optional[typing.List[cdktf.TerraformResource]] = None,
        lifecycle: typing.Optional[cdktf.TerraformResourceLifecycle] = None,
        provider: typing.Optional[cdktf.TerraformProvider] = None,
    ) -> None:
        """
        :param scope: -
        :param id: -
        :param app_service_id: 
        :param subnet_id: 
        :param timeouts: timeouts block.
        :param count: 
        :param depends_on: 
        :param lifecycle: 
        :param provider: 
        """
        config = AppServiceVirtualNetworkSwiftConnectionConfig(
            app_service_id=app_service_id,
            subnet_id=subnet_id,
            timeouts=timeouts,
            count=count,
            depends_on=depends_on,
            lifecycle=lifecycle,
            provider=provider,
        )

        jsii.create(AppServiceVirtualNetworkSwiftConnection, self, [scope, id, config])

    @jsii.member(jsii_name="synthesizeAttributes")
    def _synthesize_attributes(self) -> typing.Mapping[builtins.str, typing.Any]:
        return jsii.invoke(self, "synthesizeAttributes", [])

    @builtins.property # type: ignore
    @jsii.member(jsii_name="appServiceId")
    def app_service_id(self) -> builtins.str:
        return jsii.get(self, "appServiceId")

    @app_service_id.setter # type: ignore
    def app_service_id(self, value: builtins.str) -> None:
        jsii.set(self, "appServiceId", value)

    @builtins.property # type: ignore
    @jsii.member(jsii_name="subnetId")
    def subnet_id(self) -> builtins.str:
        return jsii.get(self, "subnetId")

    @subnet_id.setter # type: ignore
    def subnet_id(self, value: builtins.str) -> None:
        jsii.set(self, "subnetId", value)

    @builtins.property # type: ignore
    @jsii.member(jsii_name="id")
    def id(self) -> typing.Optional[builtins.str]:
        return jsii.get(self, "id")

    @id.setter # type: ignore
    def id(self, value: typing.Optional[builtins.str]) -> None:
        jsii.set(self, "id", value)

    @builtins.property # type: ignore
    @jsii.member(jsii_name="timeouts")
    def timeouts(
        self,
    ) -> typing.Optional["AppServiceVirtualNetworkSwiftConnectionTimeouts"]:
        return jsii.get(self, "timeouts")

    @timeouts.setter # type: ignore
    def timeouts(
        self,
        value: typing.Optional["AppServiceVirtualNetworkSwiftConnectionTimeouts"],
    ) -> None:
        jsii.set(self, "timeouts", value)


@jsii.data_type(
    jsii_type="@cdktf/provider-azurerm.AppServiceVirtualNetworkSwiftConnectionConfig",
    jsii_struct_bases=[cdktf.TerraformMetaArguments],
    name_mapping={
        "count": "count",
        "depends_on": "dependsOn",
        "lifecycle": "lifecycle",
        "provider": "provider",
        "app_service_id": "appServiceId",
        "subnet_id": "subnetId",
        "timeouts": "timeouts",
    },
)
class AppServiceVirtualNetworkSwiftConnectionConfig(cdktf.TerraformMetaArguments):
    def __init__(
        self,
        *,
        count: typing.Optional[jsii.Number] = None,
        depends_on: typing.Optional[typing.List[cdktf.TerraformResource]] = None,
        lifecycle: typing.Optional[cdktf.TerraformResourceLifecycle] = None,
        provider: typing.Optional[cdktf.TerraformProvider] = None,
        app_service_id: builtins.str,
        subnet_id: builtins.str,
        timeouts: typing.Optional["AppServiceVirtualNetworkSwiftConnectionTimeouts"] = None,
    ) -> None:
        """
        :param count: 
        :param depends_on: 
        :param lifecycle: 
        :param provider: 
        :param app_service_id: 
        :param subnet_id: 
        :param timeouts: timeouts block.
        """
        if isinstance(lifecycle, dict):
            lifecycle = cdktf.TerraformResourceLifecycle(**lifecycle)
        if isinstance(timeouts, dict):
            timeouts = AppServiceVirtualNetworkSwiftConnectionTimeouts(**timeouts)
        self._values: typing.Dict[str, typing.Any] = {
            "app_service_id": app_service_id,
            "subnet_id": subnet_id,
        }
        if count is not None:
            self._values["count"] = count
        if depends_on is not None:
            self._values["depends_on"] = depends_on
        if lifecycle is not None:
            self._values["lifecycle"] = lifecycle
        if provider is not None:
            self._values["provider"] = provider
        if timeouts is not None:
            self._values["timeouts"] = timeouts

    @builtins.property
    def count(self) -> typing.Optional[jsii.Number]:
        """
        :stability: experimental
        """
        result = self._values.get("count")
        return result

    @builtins.property
    def depends_on(self) -> typing.Optional[typing.List[cdktf.TerraformResource]]:
        """
        :stability: experimental
        """
        result = self._values.get("depends_on")
        return result

    @builtins.property
    def lifecycle(self) -> typing.Optional[cdktf.TerraformResourceLifecycle]:
        """
        :stability: experimental
        """
        result = self._values.get("lifecycle")
        return result

    @builtins.property
    def provider(self) -> typing.Optional[cdktf.TerraformProvider]:
        """
        :stability: experimental
        """
        result = self._values.get("provider")
        return result

    @builtins.property
    def app_service_id(self) -> builtins.str:
        result = self._values.get("app_service_id")
        assert result is not None, "Required property 'app_service_id' is missing"
        return result

    @builtins.property
    def subnet_id(self) -> builtins.str:
        result = self._values.get("subnet_id")
        assert result is not None, "Required property 'subnet_id' is missing"
        return result

    @builtins.property
    def timeouts(
        self,
    ) -> typing.Optional["AppServiceVirtualNetworkSwiftConnectionTimeouts"]:
        """timeouts block."""
        result = self._values.get("timeouts")
        return result

    def __eq__(self, rhs: typing.Any) -> builtins.bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs: typing.Any) -> builtins.bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return "AppServiceVirtualNetworkSwiftConnectionConfig(%s)" % ", ".join(
            k + "=" + repr(v) for k, v in self._values.items()
        )


@jsii.data_type(
    jsii_type="@cdktf/provider-azurerm.AppServiceVirtualNetworkSwiftConnectionTimeouts",
    jsii_struct_bases=[],
    name_mapping={
        "create": "create",
        "delete": "delete",
        "read": "read",
        "update": "update",
    },
)
class AppServiceVirtualNetworkSwiftConnectionTimeouts:
    def __init__(
        self,
        *,
        create: typing.Optional[builtins.str] = None,
        delete: typing.Optional[builtins.str] = None,
        read: typing.Optional[builtins.str] = None,
        update: typing.Optional[builtins.str] = None,
    ) -> None:
        """
        :param create: 
        :param delete: 
        :param read: 
        :param update: 
        """
        self._values: typing.Dict[str, typing.Any] = {}
        if create is not None:
            self._values["create"] = create
        if delete is not None:
            self._values["delete"] = delete
        if read is not None:
            self._values["read"] = read
        if update is not None:
            self._values["update"] = update

    @builtins.property
    def create(self) -> typing.Optional[builtins.str]:
        result = self._values.get("create")
        return result

    @builtins.property
    def delete(self) -> typing.Optional[builtins.str]:
        result = self._values.get("delete")
        return result

    @builtins.property
    def read(self) -> typing.Optional[builtins.str]:
        result = self._values.get("read")
        return result

    @builtins.property
    def update(self) -> typing.Optional[builtins.str]:
        result = self._values.get("update")
        return result

    def __eq__(self, rhs: typing.Any) -> builtins.bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs: typing.Any) -> builtins.bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return "AppServiceVirtualNetworkSwiftConnectionTimeouts(%s)" % ", ".join(
            k + "=" + repr(v) for k, v in self._values.items()
        )


class ApplicationGateway(
    cdktf.TerraformResource,
    metaclass=jsii.JSIIMeta,
    jsii_type="@cdktf/provider-azurerm.ApplicationGateway",
):
    def __init__(
        self,
        scope: constructs.Construct,
        id: builtins.str,
        *,
        backend_address_pool: typing.List["ApplicationGatewayBackendAddressPool"],
        backend_http_settings: typing.List["ApplicationGatewayBackendHttpSettings"],
        frontend_ip_configuration: typing.List["ApplicationGatewayFrontendIpConfiguration"],
        frontend_port: typing.List["ApplicationGatewayFrontendPort"],
        gateway_ip_configuration: typing.List["ApplicationGatewayGatewayIpConfiguration"],
        http_listener: typing.List["ApplicationGatewayHttpListener"],
        location: builtins.str,
        name: builtins.str,
        request_routing_rule: typing.List["ApplicationGatewayRequestRoutingRule"],
        resource_group_name: builtins.str,
        sku: typing.List["ApplicationGatewaySku"],
        authentication_certificate: typing.Optional[typing.List["ApplicationGatewayAuthenticationCertificate"]] = None,
        autoscale_configuration: typing.Optional[typing.List["ApplicationGatewayAutoscaleConfiguration"]] = None,
        custom_error_configuration: typing.Optional[typing.List["ApplicationGatewayCustomErrorConfiguration"]] = None,
        enable_http2: typing.Optional[builtins.bool] = None,
        identity: typing.Optional[typing.List["ApplicationGatewayIdentity"]] = None,
        probe: typing.Optional[typing.List["ApplicationGatewayProbe"]] = None,
        redirect_configuration: typing.Optional[typing.List["ApplicationGatewayRedirectConfiguration"]] = None,
        rewrite_rule_set: typing.Optional[typing.List["ApplicationGatewayRewriteRuleSet"]] = None,
        ssl_certificate: typing.Optional[typing.List["ApplicationGatewaySslCertificate"]] = None,
        ssl_policy: typing.Optional[typing.List["ApplicationGatewaySslPolicy"]] = None,
        tags: typing.Optional[typing.Mapping[builtins.str, builtins.str]] = None,
        timeouts: typing.Optional["ApplicationGatewayTimeouts"] = None,
        trusted_root_certificate: typing.Optional[typing.List["ApplicationGatewayTrustedRootCertificate"]] = None,
        url_path_map: typing.Optional[typing.List["ApplicationGatewayUrlPathMap"]] = None,
        waf_configuration: typing.Optional[typing.List["ApplicationGatewayWafConfiguration"]] = None,
        zones: typing.Optional[typing.List[builtins.str]] = None,
        count: typing.Optional[jsii.Number] = None,
        depends_on: typing.Optional[typing.List[cdktf.TerraformResource]] = None,
        lifecycle: typing.Optional[cdktf.TerraformResourceLifecycle] = None,
        provider: typing.Optional[cdktf.TerraformProvider] = None,
    ) -> None:
        """
        :param scope: -
        :param id: -
        :param backend_address_pool: backend_address_pool block.
        :param backend_http_settings: backend_http_settings block.
        :param frontend_ip_configuration: frontend_ip_configuration block.
        :param frontend_port: frontend_port block.
        :param gateway_ip_configuration: gateway_ip_configuration block.
        :param http_listener: http_listener block.
        :param location: 
        :param name: 
        :param request_routing_rule: request_routing_rule block.
        :param resource_group_name: 
        :param sku: sku block.
        :param authentication_certificate: authentication_certificate block.
        :param autoscale_configuration: autoscale_configuration block.
        :param custom_error_configuration: custom_error_configuration block.
        :param enable_http2: 
        :param identity: identity block.
        :param probe: probe block.
        :param redirect_configuration: redirect_configuration block.
        :param rewrite_rule_set: rewrite_rule_set block.
        :param ssl_certificate: ssl_certificate block.
        :param ssl_policy: ssl_policy block.
        :param tags: 
        :param timeouts: timeouts block.
        :param trusted_root_certificate: trusted_root_certificate block.
        :param url_path_map: url_path_map block.
        :param waf_configuration: waf_configuration block.
        :param zones: 
        :param count: 
        :param depends_on: 
        :param lifecycle: 
        :param provider: 
        """
        config = ApplicationGatewayConfig(
            backend_address_pool=backend_address_pool,
            backend_http_settings=backend_http_settings,
            frontend_ip_configuration=frontend_ip_configuration,
            frontend_port=frontend_port,
            gateway_ip_configuration=gateway_ip_configuration,
            http_listener=http_listener,
            location=location,
            name=name,
            request_routing_rule=request_routing_rule,
            resource_group_name=resource_group_name,
            sku=sku,
            authentication_certificate=authentication_certificate,
            autoscale_configuration=autoscale_configuration,
            custom_error_configuration=custom_error_configuration,
            enable_http2=enable_http2,
            identity=identity,
            probe=probe,
            redirect_configuration=redirect_configuration,
            rewrite_rule_set=rewrite_rule_set,
            ssl_certificate=ssl_certificate,
            ssl_policy=ssl_policy,
            tags=tags,
            timeouts=timeouts,
            trusted_root_certificate=trusted_root_certificate,
            url_path_map=url_path_map,
            waf_configuration=waf_configuration,
            zones=zones,
            count=count,
            depends_on=depends_on,
            lifecycle=lifecycle,
            provider=provider,
        )

        jsii.create(ApplicationGateway, self, [scope, id, config])

    @jsii.member(jsii_name="synthesizeAttributes")
    def _synthesize_attributes(self) -> typing.Mapping[builtins.str, typing.Any]:
        return jsii.invoke(self, "synthesizeAttributes", [])

    @builtins.property # type: ignore
    @jsii.member(jsii_name="backendAddressPool")
    def backend_address_pool(
        self,
    ) -> typing.List["ApplicationGatewayBackendAddressPool"]:
        return jsii.get(self, "backendAddressPool")

    @backend_address_pool.setter # type: ignore
    def backend_address_pool(
        self,
        value: typing.List["ApplicationGatewayBackendAddressPool"],
    ) -> None:
        jsii.set(self, "backendAddressPool", value)

    @builtins.property # type: ignore
    @jsii.member(jsii_name="backendHttpSettings")
    def backend_http_settings(
        self,
    ) -> typing.List["ApplicationGatewayBackendHttpSettings"]:
        return jsii.get(self, "backendHttpSettings")

    @backend_http_settings.setter # type: ignore
    def backend_http_settings(
        self,
        value: typing.List["ApplicationGatewayBackendHttpSettings"],
    ) -> None:
        jsii.set(self, "backendHttpSettings", value)

    @builtins.property # type: ignore
    @jsii.member(jsii_name="frontendIpConfiguration")
    def frontend_ip_configuration(
        self,
    ) -> typing.List["ApplicationGatewayFrontendIpConfiguration"]:
        return jsii.get(self, "frontendIpConfiguration")

    @frontend_ip_configuration.setter # type: ignore
    def frontend_ip_configuration(
        self,
        value: typing.List["ApplicationGatewayFrontendIpConfiguration"],
    ) -> None:
        jsii.set(self, "frontendIpConfiguration", value)

    @builtins.property # type: ignore
    @jsii.member(jsii_name="frontendPort")
    def frontend_port(self) -> typing.List["ApplicationGatewayFrontendPort"]:
        return jsii.get(self, "frontendPort")

    @frontend_port.setter # type: ignore
    def frontend_port(
        self,
        value: typing.List["ApplicationGatewayFrontendPort"],
    ) -> None:
        jsii.set(self, "frontendPort", value)

    @builtins.property # type: ignore
    @jsii.member(jsii_name="gatewayIpConfiguration")
    def gateway_ip_configuration(
        self,
    ) -> typing.List["ApplicationGatewayGatewayIpConfiguration"]:
        return jsii.get(self, "gatewayIpConfiguration")

    @gateway_ip_configuration.setter # type: ignore
    def gateway_ip_configuration(
        self,
        value: typing.List["ApplicationGatewayGatewayIpConfiguration"],
    ) -> None:
        jsii.set(self, "gatewayIpConfiguration", value)

    @builtins.property # type: ignore
    @jsii.member(jsii_name="httpListener")
    def http_listener(self) -> typing.List["ApplicationGatewayHttpListener"]:
        return jsii.get(self, "httpListener")

    @http_listener.setter # type: ignore
    def http_listener(
        self,
        value: typing.List["ApplicationGatewayHttpListener"],
    ) -> None:
        jsii.set(self, "httpListener", value)

    @builtins.property # type: ignore
    @jsii.member(jsii_name="location")
    def location(self) -> builtins.str:
        return jsii.get(self, "location")

    @location.setter # type: ignore
    def location(self, value: builtins.str) -> None:
        jsii.set(self, "location", value)

    @builtins.property # type: ignore
    @jsii.member(jsii_name="name")
    def name(self) -> builtins.str:
        return jsii.get(self, "name")

    @name.setter # type: ignore
    def name(self, value: builtins.str) -> None:
        jsii.set(self, "name", value)

    @builtins.property # type: ignore
    @jsii.member(jsii_name="requestRoutingRule")
    def request_routing_rule(
        self,
    ) -> typing.List["ApplicationGatewayRequestRoutingRule"]:
        return jsii.get(self, "requestRoutingRule")

    @request_routing_rule.setter # type: ignore
    def request_routing_rule(
        self,
        value: typing.List["ApplicationGatewayRequestRoutingRule"],
    ) -> None:
        jsii.set(self, "requestRoutingRule", value)

    @builtins.property # type: ignore
    @jsii.member(jsii_name="resourceGroupName")
    def resource_group_name(self) -> builtins.str:
        return jsii.get(self, "resourceGroupName")

    @resource_group_name.setter # type: ignore
    def resource_group_name(self, value: builtins.str) -> None:
        jsii.set(self, "resourceGroupName", value)

    @builtins.property # type: ignore
    @jsii.member(jsii_name="sku")
    def sku(self) -> typing.List["ApplicationGatewaySku"]:
        return jsii.get(self, "sku")

    @sku.setter # type: ignore
    def sku(self, value: typing.List["ApplicationGatewaySku"]) -> None:
        jsii.set(self, "sku", value)

    @builtins.property # type: ignore
    @jsii.member(jsii_name="authenticationCertificate")
    def authentication_certificate(
        self,
    ) -> typing.Optional[typing.List["ApplicationGatewayAuthenticationCertificate"]]:
        return jsii.get(self, "authenticationCertificate")

    @authentication_certificate.setter # type: ignore
    def authentication_certificate(
        self,
        value: typing.Optional[typing.List["ApplicationGatewayAuthenticationCertificate"]],
    ) -> None:
        jsii.set(self, "authenticationCertificate", value)

    @builtins.property # type: ignore
    @jsii.member(jsii_name="autoscaleConfiguration")
    def autoscale_configuration(
        self,
    ) -> typing.Optional[typing.List["ApplicationGatewayAutoscaleConfiguration"]]:
        return jsii.get(self, "autoscaleConfiguration")

    @autoscale_configuration.setter # type: ignore
    def autoscale_configuration(
        self,
        value: typing.Optional[typing.List["ApplicationGatewayAutoscaleConfiguration"]],
    ) -> None:
        jsii.set(self, "autoscaleConfiguration", value)

    @builtins.property # type: ignore
    @jsii.member(jsii_name="customErrorConfiguration")
    def custom_error_configuration(
        self,
    ) -> typing.Optional[typing.List["ApplicationGatewayCustomErrorConfiguration"]]:
        return jsii.get(self, "customErrorConfiguration")

    @custom_error_configuration.setter # type: ignore
    def custom_error_configuration(
        self,
        value: typing.Optional[typing.List["ApplicationGatewayCustomErrorConfiguration"]],
    ) -> None:
        jsii.set(self, "customErrorConfiguration", value)

    @builtins.property # type: ignore
    @jsii.member(jsii_name="enableHttp2")
    def enable_http2(self) -> typing.Optional[builtins.bool]:
        return jsii.get(self, "enableHttp2")

    @enable_http2.setter # type: ignore
    def enable_http2(self, value: typing.Optional[builtins.bool]) -> None:
        jsii.set(self, "enableHttp2", value)

    @builtins.property # type: ignore
    @jsii.member(jsii_name="id")
    def id(self) -> typing.Optional[builtins.str]:
        return jsii.get(self, "id")

    @id.setter # type: ignore
    def id(self, value: typing.Optional[builtins.str]) -> None:
        jsii.set(self, "id", value)

    @builtins.property # type: ignore
    @jsii.member(jsii_name="identity")
    def identity(self) -> typing.Optional[typing.List["ApplicationGatewayIdentity"]]:
        return jsii.get(self, "identity")

    @identity.setter # type: ignore
    def identity(
        self,
        value: typing.Optional[typing.List["ApplicationGatewayIdentity"]],
    ) -> None:
        jsii.set(self, "identity", value)

    @builtins.property # type: ignore
    @jsii.member(jsii_name="probe")
    def probe(self) -> typing.Optional[typing.List["ApplicationGatewayProbe"]]:
        return jsii.get(self, "probe")

    @probe.setter # type: ignore
    def probe(
        self,
        value: typing.Optional[typing.List["ApplicationGatewayProbe"]],
    ) -> None:
        jsii.set(self, "probe", value)

    @builtins.property # type: ignore
    @jsii.member(jsii_name="redirectConfiguration")
    def redirect_configuration(
        self,
    ) -> typing.Optional[typing.List["ApplicationGatewayRedirectConfiguration"]]:
        return jsii.get(self, "redirectConfiguration")

    @redirect_configuration.setter # type: ignore
    def redirect_configuration(
        self,
        value: typing.Optional[typing.List["ApplicationGatewayRedirectConfiguration"]],
    ) -> None:
        jsii.set(self, "redirectConfiguration", value)

    @builtins.property # type: ignore
    @jsii.member(jsii_name="rewriteRuleSet")
    def rewrite_rule_set(
        self,
    ) -> typing.Optional[typing.List["ApplicationGatewayRewriteRuleSet"]]:
        return jsii.get(self, "rewriteRuleSet")

    @rewrite_rule_set.setter # type: ignore
    def rewrite_rule_set(
        self,
        value: typing.Optional[typing.List["ApplicationGatewayRewriteRuleSet"]],
    ) -> None:
        jsii.set(self, "rewriteRuleSet", value)

    @builtins.property # type: ignore
    @jsii.member(jsii_name="sslCertificate")
    def ssl_certificate(
        self,
    ) -> typing.Optional[typing.List["ApplicationGatewaySslCertificate"]]:
        return jsii.get(self, "sslCertificate")

    @ssl_certificate.setter # type: ignore
    def ssl_certificate(
        self,
        value: typing.Optional[typing.List["ApplicationGatewaySslCertificate"]],
    ) -> None:
        jsii.set(self, "sslCertificate", value)

    @builtins.property # type: ignore
    @jsii.member(jsii_name="sslPolicy")
    def ssl_policy(self) -> typing.Optional[typing.List["ApplicationGatewaySslPolicy"]]:
        return jsii.get(self, "sslPolicy")

    @ssl_policy.setter # type: ignore
    def ssl_policy(
        self,
        value: typing.Optional[typing.List["ApplicationGatewaySslPolicy"]],
    ) -> None:
        jsii.set(self, "sslPolicy", value)

    @builtins.property # type: ignore
    @jsii.member(jsii_name="tags")
    def tags(self) -> typing.Optional[typing.Mapping[builtins.str, builtins.str]]:
        return jsii.get(self, "tags")

    @tags.setter # type: ignore
    def tags(
        self,
        value: typing.Optional[typing.Mapping[builtins.str, builtins.str]],
    ) -> None:
        jsii.set(self, "tags", value)

    @builtins.property # type: ignore
    @jsii.member(jsii_name="timeouts")
    def timeouts(self) -> typing.Optional["ApplicationGatewayTimeouts"]:
        return jsii.get(self, "timeouts")

    @timeouts.setter # type: ignore
    def timeouts(self, value: typing.Optional["ApplicationGatewayTimeouts"]) -> None:
        jsii.set(self, "timeouts", value)

    @builtins.property # type: ignore
    @jsii.member(jsii_name="trustedRootCertificate")
    def trusted_root_certificate(
        self,
    ) -> typing.Optional[typing.List["ApplicationGatewayTrustedRootCertificate"]]:
        return jsii.get(self, "trustedRootCertificate")

    @trusted_root_certificate.setter # type: ignore
    def trusted_root_certificate(
        self,
        value: typing.Optional[typing.List["ApplicationGatewayTrustedRootCertificate"]],
    ) -> None:
        jsii.set(self, "trustedRootCertificate", value)

    @builtins.property # type: ignore
    @jsii.member(jsii_name="urlPathMap")
    def url_path_map(
        self,
    ) -> typing.Optional[typing.List["ApplicationGatewayUrlPathMap"]]:
        return jsii.get(self, "urlPathMap")

    @url_path_map.setter # type: ignore
    def url_path_map(
        self,
        value: typing.Optional[typing.List["ApplicationGatewayUrlPathMap"]],
    ) -> None:
        jsii.set(self, "urlPathMap", value)

    @builtins.property # type: ignore
    @jsii.member(jsii_name="wafConfiguration")
    def waf_configuration(
        self,
    ) -> typing.Optional[typing.List["ApplicationGatewayWafConfiguration"]]:
        return jsii.get(self, "wafConfiguration")

    @waf_configuration.setter # type: ignore
    def waf_configuration(
        self,
        value: typing.Optional[typing.List["ApplicationGatewayWafConfiguration"]],
    ) -> None:
        jsii.set(self, "wafConfiguration", value)

    @builtins.property # type: ignore
    @jsii.member(jsii_name="zones")
    def zones(self) -> typing.Optional[typing.List[builtins.str]]:
        return jsii.get(self, "zones")

    @zones.setter # type: ignore
    def zones(self, value: typing.Optional[typing.List[builtins.str]]) -> None:
        jsii.set(self, "zones", value)


@jsii.data_type(
    jsii_type="@cdktf/provider-azurerm.ApplicationGatewayAuthenticationCertificate",
    jsii_struct_bases=[],
    name_mapping={"data": "data", "name": "name"},
)
class ApplicationGatewayAuthenticationCertificate:
    def __init__(self, *, data: builtins.str, name: builtins.str) -> None:
        """
        :param data: 
        :param name: 
        """
        self._values: typing.Dict[str, typing.Any] = {
            "data": data,
            "name": name,
        }

    @builtins.property
    def data(self) -> builtins.str:
        result = self._values.get("data")
        assert result is not None, "Required property 'data' is missing"
        return result

    @builtins.property
    def name(self) -> builtins.str:
        result = self._values.get("name")
        assert result is not None, "Required property 'name' is missing"
        return result

    def __eq__(self, rhs: typing.Any) -> builtins.bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs: typing.Any) -> builtins.bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return "ApplicationGatewayAuthenticationCertificate(%s)" % ", ".join(
            k + "=" + repr(v) for k, v in self._values.items()
        )


@jsii.data_type(
    jsii_type="@cdktf/provider-azurerm.ApplicationGatewayAutoscaleConfiguration",
    jsii_struct_bases=[],
    name_mapping={"min_capacity": "minCapacity", "max_capacity": "maxCapacity"},
)
class ApplicationGatewayAutoscaleConfiguration:
    def __init__(
        self,
        *,
        min_capacity: jsii.Number,
        max_capacity: typing.Optional[jsii.Number] = None,
    ) -> None:
        """
        :param min_capacity: 
        :param max_capacity: 
        """
        self._values: typing.Dict[str, typing.Any] = {
            "min_capacity": min_capacity,
        }
        if max_capacity is not None:
            self._values["max_capacity"] = max_capacity

    @builtins.property
    def min_capacity(self) -> jsii.Number:
        result = self._values.get("min_capacity")
        assert result is not None, "Required property 'min_capacity' is missing"
        return result

    @builtins.property
    def max_capacity(self) -> typing.Optional[jsii.Number]:
        result = self._values.get("max_capacity")
        return result

    def __eq__(self, rhs: typing.Any) -> builtins.bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs: typing.Any) -> builtins.bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return "ApplicationGatewayAutoscaleConfiguration(%s)" % ", ".join(
            k + "=" + repr(v) for k, v in self._values.items()
        )


@jsii.data_type(
    jsii_type="@cdktf/provider-azurerm.ApplicationGatewayBackendAddressPool",
    jsii_struct_bases=[],
    name_mapping={"name": "name", "fqdns": "fqdns", "ip_addresses": "ipAddresses"},
)
class ApplicationGatewayBackendAddressPool:
    def __init__(
        self,
        *,
        name: builtins.str,
        fqdns: typing.Optional[typing.List[builtins.str]] = None,
        ip_addresses: typing.Optional[typing.List[builtins.str]] = None,
    ) -> None:
        """
        :param name: 
        :param fqdns: 
        :param ip_addresses: 
        """
        self._values: typing.Dict[str, typing.Any] = {
            "name": name,
        }
        if fqdns is not None:
            self._values["fqdns"] = fqdns
        if ip_addresses is not None:
            self._values["ip_addresses"] = ip_addresses

    @builtins.property
    def name(self) -> builtins.str:
        result = self._values.get("name")
        assert result is not None, "Required property 'name' is missing"
        return result

    @builtins.property
    def fqdns(self) -> typing.Optional[typing.List[builtins.str]]:
        result = self._values.get("fqdns")
        return result

    @builtins.property
    def ip_addresses(self) -> typing.Optional[typing.List[builtins.str]]:
        result = self._values.get("ip_addresses")
        return result

    def __eq__(self, rhs: typing.Any) -> builtins.bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs: typing.Any) -> builtins.bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return "ApplicationGatewayBackendAddressPool(%s)" % ", ".join(
            k + "=" + repr(v) for k, v in self._values.items()
        )


@jsii.data_type(
    jsii_type="@cdktf/provider-azurerm.ApplicationGatewayBackendHttpSettings",
    jsii_struct_bases=[],
    name_mapping={
        "cookie_based_affinity": "cookieBasedAffinity",
        "name": "name",
        "port": "port",
        "protocol": "protocol",
        "affinity_cookie_name": "affinityCookieName",
        "authentication_certificate": "authenticationCertificate",
        "connection_draining": "connectionDraining",
        "host_name": "hostName",
        "path": "path",
        "pick_host_name_from_backend_address": "pickHostNameFromBackendAddress",
        "probe_name": "probeName",
        "request_timeout": "requestTimeout",
        "trusted_root_certificate_names": "trustedRootCertificateNames",
    },
)
class ApplicationGatewayBackendHttpSettings:
    def __init__(
        self,
        *,
        cookie_based_affinity: builtins.str,
        name: builtins.str,
        port: jsii.Number,
        protocol: builtins.str,
        affinity_cookie_name: typing.Optional[builtins.str] = None,
        authentication_certificate: typing.Optional[typing.List["ApplicationGatewayBackendHttpSettingsAuthenticationCertificate"]] = None,
        connection_draining: typing.Optional[typing.List["ApplicationGatewayBackendHttpSettingsConnectionDraining"]] = None,
        host_name: typing.Optional[builtins.str] = None,
        path: typing.Optional[builtins.str] = None,
        pick_host_name_from_backend_address: typing.Optional[builtins.bool] = None,
        probe_name: typing.Optional[builtins.str] = None,
        request_timeout: typing.Optional[jsii.Number] = None,
        trusted_root_certificate_names: typing.Optional[typing.List[builtins.str]] = None,
    ) -> None:
        """
        :param cookie_based_affinity: 
        :param name: 
        :param port: 
        :param protocol: 
        :param affinity_cookie_name: 
        :param authentication_certificate: authentication_certificate block.
        :param connection_draining: connection_draining block.
        :param host_name: 
        :param path: 
        :param pick_host_name_from_backend_address: 
        :param probe_name: 
        :param request_timeout: 
        :param trusted_root_certificate_names: 
        """
        self._values: typing.Dict[str, typing.Any] = {
            "cookie_based_affinity": cookie_based_affinity,
            "name": name,
            "port": port,
            "protocol": protocol,
        }
        if affinity_cookie_name is not None:
            self._values["affinity_cookie_name"] = affinity_cookie_name
        if authentication_certificate is not None:
            self._values["authentication_certificate"] = authentication_certificate
        if connection_draining is not None:
            self._values["connection_draining"] = connection_draining
        if host_name is not None:
            self._values["host_name"] = host_name
        if path is not None:
            self._values["path"] = path
        if pick_host_name_from_backend_address is not None:
            self._values["pick_host_name_from_backend_address"] = pick_host_name_from_backend_address
        if probe_name is not None:
            self._values["probe_name"] = probe_name
        if request_timeout is not None:
            self._values["request_timeout"] = request_timeout
        if trusted_root_certificate_names is not None:
            self._values["trusted_root_certificate_names"] = trusted_root_certificate_names

    @builtins.property
    def cookie_based_affinity(self) -> builtins.str:
        result = self._values.get("cookie_based_affinity")
        assert result is not None, "Required property 'cookie_based_affinity' is missing"
        return result

    @builtins.property
    def name(self) -> builtins.str:
        result = self._values.get("name")
        assert result is not None, "Required property 'name' is missing"
        return result

    @builtins.property
    def port(self) -> jsii.Number:
        result = self._values.get("port")
        assert result is not None, "Required property 'port' is missing"
        return result

    @builtins.property
    def protocol(self) -> builtins.str:
        result = self._values.get("protocol")
        assert result is not None, "Required property 'protocol' is missing"
        return result

    @builtins.property
    def affinity_cookie_name(self) -> typing.Optional[builtins.str]:
        result = self._values.get("affinity_cookie_name")
        return result

    @builtins.property
    def authentication_certificate(
        self,
    ) -> typing.Optional[typing.List["ApplicationGatewayBackendHttpSettingsAuthenticationCertificate"]]:
        """authentication_certificate block."""
        result = self._values.get("authentication_certificate")
        return result

    @builtins.property
    def connection_draining(
        self,
    ) -> typing.Optional[typing.List["ApplicationGatewayBackendHttpSettingsConnectionDraining"]]:
        """connection_draining block."""
        result = self._values.get("connection_draining")
        return result

    @builtins.property
    def host_name(self) -> typing.Optional[builtins.str]:
        result = self._values.get("host_name")
        return result

    @builtins.property
    def path(self) -> typing.Optional[builtins.str]:
        result = self._values.get("path")
        return result

    @builtins.property
    def pick_host_name_from_backend_address(self) -> typing.Optional[builtins.bool]:
        result = self._values.get("pick_host_name_from_backend_address")
        return result

    @builtins.property
    def probe_name(self) -> typing.Optional[builtins.str]:
        result = self._values.get("probe_name")
        return result

    @builtins.property
    def request_timeout(self) -> typing.Optional[jsii.Number]:
        result = self._values.get("request_timeout")
        return result

    @builtins.property
    def trusted_root_certificate_names(
        self,
    ) -> typing.Optional[typing.List[builtins.str]]:
        result = self._values.get("trusted_root_certificate_names")
        return result

    def __eq__(self, rhs: typing.Any) -> builtins.bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs: typing.Any) -> builtins.bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return "ApplicationGatewayBackendHttpSettings(%s)" % ", ".join(
            k + "=" + repr(v) for k, v in self._values.items()
        )


@jsii.data_type(
    jsii_type="@cdktf/provider-azurerm.ApplicationGatewayBackendHttpSettingsAuthenticationCertificate",
    jsii_struct_bases=[],
    name_mapping={"name": "name"},
)
class ApplicationGatewayBackendHttpSettingsAuthenticationCertificate:
    def __init__(self, *, name: builtins.str) -> None:
        """
        :param name: 
        """
        self._values: typing.Dict[str, typing.Any] = {
            "name": name,
        }

    @builtins.property
    def name(self) -> builtins.str:
        result = self._values.get("name")
        assert result is not None, "Required property 'name' is missing"
        return result

    def __eq__(self, rhs: typing.Any) -> builtins.bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs: typing.Any) -> builtins.bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return "ApplicationGatewayBackendHttpSettingsAuthenticationCertificate(%s)" % ", ".join(
            k + "=" + repr(v) for k, v in self._values.items()
        )


@jsii.data_type(
    jsii_type="@cdktf/provider-azurerm.ApplicationGatewayBackendHttpSettingsConnectionDraining",
    jsii_struct_bases=[],
    name_mapping={"drain_timeout_sec": "drainTimeoutSec", "enabled": "enabled"},
)
class ApplicationGatewayBackendHttpSettingsConnectionDraining:
    def __init__(
        self,
        *,
        drain_timeout_sec: jsii.Number,
        enabled: builtins.bool,
    ) -> None:
        """
        :param drain_timeout_sec: 
        :param enabled: 
        """
        self._values: typing.Dict[str, typing.Any] = {
            "drain_timeout_sec": drain_timeout_sec,
            "enabled": enabled,
        }

    @builtins.property
    def drain_timeout_sec(self) -> jsii.Number:
        result = self._values.get("drain_timeout_sec")
        assert result is not None, "Required property 'drain_timeout_sec' is missing"
        return result

    @builtins.property
    def enabled(self) -> builtins.bool:
        result = self._values.get("enabled")
        assert result is not None, "Required property 'enabled' is missing"
        return result

    def __eq__(self, rhs: typing.Any) -> builtins.bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs: typing.Any) -> builtins.bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return "ApplicationGatewayBackendHttpSettingsConnectionDraining(%s)" % ", ".join(
            k + "=" + repr(v) for k, v in self._values.items()
        )


@jsii.data_type(
    jsii_type="@cdktf/provider-azurerm.ApplicationGatewayConfig",
    jsii_struct_bases=[cdktf.TerraformMetaArguments],
    name_mapping={
        "count": "count",
        "depends_on": "dependsOn",
        "lifecycle": "lifecycle",
        "provider": "provider",
        "backend_address_pool": "backendAddressPool",
        "backend_http_settings": "backendHttpSettings",
        "frontend_ip_configuration": "frontendIpConfiguration",
        "frontend_port": "frontendPort",
        "gateway_ip_configuration": "gatewayIpConfiguration",
        "http_listener": "httpListener",
        "location": "location",
        "name": "name",
        "request_routing_rule": "requestRoutingRule",
        "resource_group_name": "resourceGroupName",
        "sku": "sku",
        "authentication_certificate": "authenticationCertificate",
        "autoscale_configuration": "autoscaleConfiguration",
        "custom_error_configuration": "customErrorConfiguration",
        "enable_http2": "enableHttp2",
        "identity": "identity",
        "probe": "probe",
        "redirect_configuration": "redirectConfiguration",
        "rewrite_rule_set": "rewriteRuleSet",
        "ssl_certificate": "sslCertificate",
        "ssl_policy": "sslPolicy",
        "tags": "tags",
        "timeouts": "timeouts",
        "trusted_root_certificate": "trustedRootCertificate",
        "url_path_map": "urlPathMap",
        "waf_configuration": "wafConfiguration",
        "zones": "zones",
    },
)
class ApplicationGatewayConfig(cdktf.TerraformMetaArguments):
    def __init__(
        self,
        *,
        count: typing.Optional[jsii.Number] = None,
        depends_on: typing.Optional[typing.List[cdktf.TerraformResource]] = None,
        lifecycle: typing.Optional[cdktf.TerraformResourceLifecycle] = None,
        provider: typing.Optional[cdktf.TerraformProvider] = None,
        backend_address_pool: typing.List[ApplicationGatewayBackendAddressPool],
        backend_http_settings: typing.List[ApplicationGatewayBackendHttpSettings],
        frontend_ip_configuration: typing.List["ApplicationGatewayFrontendIpConfiguration"],
        frontend_port: typing.List["ApplicationGatewayFrontendPort"],
        gateway_ip_configuration: typing.List["ApplicationGatewayGatewayIpConfiguration"],
        http_listener: typing.List["ApplicationGatewayHttpListener"],
        location: builtins.str,
        name: builtins.str,
        request_routing_rule: typing.List["ApplicationGatewayRequestRoutingRule"],
        resource_group_name: builtins.str,
        sku: typing.List["ApplicationGatewaySku"],
        authentication_certificate: typing.Optional[typing.List[ApplicationGatewayAuthenticationCertificate]] = None,
        autoscale_configuration: typing.Optional[typing.List[ApplicationGatewayAutoscaleConfiguration]] = None,
        custom_error_configuration: typing.Optional[typing.List["ApplicationGatewayCustomErrorConfiguration"]] = None,
        enable_http2: typing.Optional[builtins.bool] = None,
        identity: typing.Optional[typing.List["ApplicationGatewayIdentity"]] = None,
        probe: typing.Optional[typing.List["ApplicationGatewayProbe"]] = None,
        redirect_configuration: typing.Optional[typing.List["ApplicationGatewayRedirectConfiguration"]] = None,
        rewrite_rule_set: typing.Optional[typing.List["ApplicationGatewayRewriteRuleSet"]] = None,
        ssl_certificate: typing.Optional[typing.List["ApplicationGatewaySslCertificate"]] = None,
        ssl_policy: typing.Optional[typing.List["ApplicationGatewaySslPolicy"]] = None,
        tags: typing.Optional[typing.Mapping[builtins.str, builtins.str]] = None,
        timeouts: typing.Optional["ApplicationGatewayTimeouts"] = None,
        trusted_root_certificate: typing.Optional[typing.List["ApplicationGatewayTrustedRootCertificate"]] = None,
        url_path_map: typing.Optional[typing.List["ApplicationGatewayUrlPathMap"]] = None,
        waf_configuration: typing.Optional[typing.List["ApplicationGatewayWafConfiguration"]] = None,
        zones: typing.Optional[typing.List[builtins.str]] = None,
    ) -> None:
        """
        :param count: 
        :param depends_on: 
        :param lifecycle: 
        :param provider: 
        :param backend_address_pool: backend_address_pool block.
        :param backend_http_settings: backend_http_settings block.
        :param frontend_ip_configuration: frontend_ip_configuration block.
        :param frontend_port: frontend_port block.
        :param gateway_ip_configuration: gateway_ip_configuration block.
        :param http_listener: http_listener block.
        :param location: 
        :param name: 
        :param request_routing_rule: request_routing_rule block.
        :param resource_group_name: 
        :param sku: sku block.
        :param authentication_certificate: authentication_certificate block.
        :param autoscale_configuration: autoscale_configuration block.
        :param custom_error_configuration: custom_error_configuration block.
        :param enable_http2: 
        :param identity: identity block.
        :param probe: probe block.
        :param redirect_configuration: redirect_configuration block.
        :param rewrite_rule_set: rewrite_rule_set block.
        :param ssl_certificate: ssl_certificate block.
        :param ssl_policy: ssl_policy block.
        :param tags: 
        :param timeouts: timeouts block.
        :param trusted_root_certificate: trusted_root_certificate block.
        :param url_path_map: url_path_map block.
        :param waf_configuration: waf_configuration block.
        :param zones: 
        """
        if isinstance(lifecycle, dict):
            lifecycle = cdktf.TerraformResourceLifecycle(**lifecycle)
        if isinstance(timeouts, dict):
            timeouts = ApplicationGatewayTimeouts(**timeouts)
        self._values: typing.Dict[str, typing.Any] = {
            "backend_address_pool": backend_address_pool,
            "backend_http_settings": backend_http_settings,
            "frontend_ip_configuration": frontend_ip_configuration,
            "frontend_port": frontend_port,
            "gateway_ip_configuration": gateway_ip_configuration,
            "http_listener": http_listener,
            "location": location,
            "name": name,
            "request_routing_rule": request_routing_rule,
            "resource_group_name": resource_group_name,
            "sku": sku,
        }
        if count is not None:
            self._values["count"] = count
        if depends_on is not None:
            self._values["depends_on"] = depends_on
        if lifecycle is not None:
            self._values["lifecycle"] = lifecycle
        if provider is not None:
            self._values["provider"] = provider
        if authentication_certificate is not None:
            self._values["authentication_certificate"] = authentication_certificate
        if autoscale_configuration is not None:
            self._values["autoscale_configuration"] = autoscale_configuration
        if custom_error_configuration is not None:
            self._values["custom_error_configuration"] = custom_error_configuration
        if enable_http2 is not None:
            self._values["enable_http2"] = enable_http2
        if identity is not None:
            self._values["identity"] = identity
        if probe is not None:
            self._values["probe"] = probe
        if redirect_configuration is not None:
            self._values["redirect_configuration"] = redirect_configuration
        if rewrite_rule_set is not None:
            self._values["rewrite_rule_set"] = rewrite_rule_set
        if ssl_certificate is not None:
            self._values["ssl_certificate"] = ssl_certificate
        if ssl_policy is not None:
            self._values["ssl_policy"] = ssl_policy
        if tags is not None:
            self._values["tags"] = tags
        if timeouts is not None:
            self._values["timeouts"] = timeouts
        if trusted_root_certificate is not None:
            self._values["trusted_root_certificate"] = trusted_root_certificate
        if url_path_map is not None:
            self._values["url_path_map"] = url_path_map
        if waf_configuration is not None:
            self._values["waf_configuration"] = waf_configuration
        if zones is not None:
            self._values["zones"] = zones

    @builtins.property
    def count(self) -> typing.Optional[jsii.Number]:
        """
        :stability: experimental
        """
        result = self._values.get("count")
        return result

    @builtins.property
    def depends_on(self) -> typing.Optional[typing.List[cdktf.TerraformResource]]:
        """
        :stability: experimental
        """
        result = self._values.get("depends_on")
        return result

    @builtins.property
    def lifecycle(self) -> typing.Optional[cdktf.TerraformResourceLifecycle]:
        """
        :stability: experimental
        """
        result = self._values.get("lifecycle")
        return result

    @builtins.property
    def provider(self) -> typing.Optional[cdktf.TerraformProvider]:
        """
        :stability: experimental
        """
        result = self._values.get("provider")
        return result

    @builtins.property
    def backend_address_pool(self) -> typing.List[ApplicationGatewayBackendAddressPool]:
        """backend_address_pool block."""
        result = self._values.get("backend_address_pool")
        assert result is not None, "Required property 'backend_address_pool' is missing"
        return result

    @builtins.property
    def backend_http_settings(
        self,
    ) -> typing.List[ApplicationGatewayBackendHttpSettings]:
        """backend_http_settings block."""
        result = self._values.get("backend_http_settings")
        assert result is not None, "Required property 'backend_http_settings' is missing"
        return result

    @builtins.property
    def frontend_ip_configuration(
        self,
    ) -> typing.List["ApplicationGatewayFrontendIpConfiguration"]:
        """frontend_ip_configuration block."""
        result = self._values.get("frontend_ip_configuration")
        assert result is not None, "Required property 'frontend_ip_configuration' is missing"
        return result

    @builtins.property
    def frontend_port(self) -> typing.List["ApplicationGatewayFrontendPort"]:
        """frontend_port block."""
        result = self._values.get("frontend_port")
        assert result is not None, "Required property 'frontend_port' is missing"
        return result

    @builtins.property
    def gateway_ip_configuration(
        self,
    ) -> typing.List["ApplicationGatewayGatewayIpConfiguration"]:
        """gateway_ip_configuration block."""
        result = self._values.get("gateway_ip_configuration")
        assert result is not None, "Required property 'gateway_ip_configuration' is missing"
        return result

    @builtins.property
    def http_listener(self) -> typing.List["ApplicationGatewayHttpListener"]:
        """http_listener block."""
        result = self._values.get("http_listener")
        assert result is not None, "Required property 'http_listener' is missing"
        return result

    @builtins.property
    def location(self) -> builtins.str:
        result = self._values.get("location")
        assert result is not None, "Required property 'location' is missing"
        return result

    @builtins.property
    def name(self) -> builtins.str:
        result = self._values.get("name")
        assert result is not None, "Required property 'name' is missing"
        return result

    @builtins.property
    def request_routing_rule(
        self,
    ) -> typing.List["ApplicationGatewayRequestRoutingRule"]:
        """request_routing_rule block."""
        result = self._values.get("request_routing_rule")
        assert result is not None, "Required property 'request_routing_rule' is missing"
        return result

    @builtins.property
    def resource_group_name(self) -> builtins.str:
        result = self._values.get("resource_group_name")
        assert result is not None, "Required property 'resource_group_name' is missing"
        return result

    @builtins.property
    def sku(self) -> typing.List["ApplicationGatewaySku"]:
        """sku block."""
        result = self._values.get("sku")
        assert result is not None, "Required property 'sku' is missing"
        return result

    @builtins.property
    def authentication_certificate(
        self,
    ) -> typing.Optional[typing.List[ApplicationGatewayAuthenticationCertificate]]:
        """authentication_certificate block."""
        result = self._values.get("authentication_certificate")
        return result

    @builtins.property
    def autoscale_configuration(
        self,
    ) -> typing.Optional[typing.List[ApplicationGatewayAutoscaleConfiguration]]:
        """autoscale_configuration block."""
        result = self._values.get("autoscale_configuration")
        return result

    @builtins.property
    def custom_error_configuration(
        self,
    ) -> typing.Optional[typing.List["ApplicationGatewayCustomErrorConfiguration"]]:
        """custom_error_configuration block."""
        result = self._values.get("custom_error_configuration")
        return result

    @builtins.property
    def enable_http2(self) -> typing.Optional[builtins.bool]:
        result = self._values.get("enable_http2")
        return result

    @builtins.property
    def identity(self) -> typing.Optional[typing.List["ApplicationGatewayIdentity"]]:
        """identity block."""
        result = self._values.get("identity")
        return result

    @builtins.property
    def probe(self) -> typing.Optional[typing.List["ApplicationGatewayProbe"]]:
        """probe block."""
        result = self._values.get("probe")
        return result

    @builtins.property
    def redirect_configuration(
        self,
    ) -> typing.Optional[typing.List["ApplicationGatewayRedirectConfiguration"]]:
        """redirect_configuration block."""
        result = self._values.get("redirect_configuration")
        return result

    @builtins.property
    def rewrite_rule_set(
        self,
    ) -> typing.Optional[typing.List["ApplicationGatewayRewriteRuleSet"]]:
        """rewrite_rule_set block."""
        result = self._values.get("rewrite_rule_set")
        return result

    @builtins.property
    def ssl_certificate(
        self,
    ) -> typing.Optional[typing.List["ApplicationGatewaySslCertificate"]]:
        """ssl_certificate block."""
        result = self._values.get("ssl_certificate")
        return result

    @builtins.property
    def ssl_policy(self) -> typing.Optional[typing.List["ApplicationGatewaySslPolicy"]]:
        """ssl_policy block."""
        result = self._values.get("ssl_policy")
        return result

    @builtins.property
    def tags(self) -> typing.Optional[typing.Mapping[builtins.str, builtins.str]]:
        result = self._values.get("tags")
        return result

    @builtins.property
    def timeouts(self) -> typing.Optional["ApplicationGatewayTimeouts"]:
        """timeouts block."""
        result = self._values.get("timeouts")
        return result

    @builtins.property
    def trusted_root_certificate(
        self,
    ) -> typing.Optional[typing.List["ApplicationGatewayTrustedRootCertificate"]]:
        """trusted_root_certificate block."""
        result = self._values.get("trusted_root_certificate")
        return result

    @builtins.property
    def url_path_map(
        self,
    ) -> typing.Optional[typing.List["ApplicationGatewayUrlPathMap"]]:
        """url_path_map block."""
        result = self._values.get("url_path_map")
        return result

    @builtins.property
    def waf_configuration(
        self,
    ) -> typing.Optional[typing.List["ApplicationGatewayWafConfiguration"]]:
        """waf_configuration block."""
        result = self._values.get("waf_configuration")
        return result

    @builtins.property
    def zones(self) -> typing.Optional[typing.List[builtins.str]]:
        result = self._values.get("zones")
        return result

    def __eq__(self, rhs: typing.Any) -> builtins.bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs: typing.Any) -> builtins.bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return "ApplicationGatewayConfig(%s)" % ", ".join(
            k + "=" + repr(v) for k, v in self._values.items()
        )


@jsii.data_type(
    jsii_type="@cdktf/provider-azurerm.ApplicationGatewayCustomErrorConfiguration",
    jsii_struct_bases=[],
    name_mapping={
        "custom_error_page_url": "customErrorPageUrl",
        "status_code": "statusCode",
    },
)
class ApplicationGatewayCustomErrorConfiguration:
    def __init__(
        self,
        *,
        custom_error_page_url: builtins.str,
        status_code: builtins.str,
    ) -> None:
        """
        :param custom_error_page_url: 
        :param status_code: 
        """
        self._values: typing.Dict[str, typing.Any] = {
            "custom_error_page_url": custom_error_page_url,
            "status_code": status_code,
        }

    @builtins.property
    def custom_error_page_url(self) -> builtins.str:
        result = self._values.get("custom_error_page_url")
        assert result is not None, "Required property 'custom_error_page_url' is missing"
        return result

    @builtins.property
    def status_code(self) -> builtins.str:
        result = self._values.get("status_code")
        assert result is not None, "Required property 'status_code' is missing"
        return result

    def __eq__(self, rhs: typing.Any) -> builtins.bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs: typing.Any) -> builtins.bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return "ApplicationGatewayCustomErrorConfiguration(%s)" % ", ".join(
            k + "=" + repr(v) for k, v in self._values.items()
        )


@jsii.data_type(
    jsii_type="@cdktf/provider-azurerm.ApplicationGatewayFrontendIpConfiguration",
    jsii_struct_bases=[],
    name_mapping={
        "name": "name",
        "private_ip_address": "privateIpAddress",
        "private_ip_address_allocation": "privateIpAddressAllocation",
        "public_ip_address_id": "publicIpAddressId",
        "subnet_id": "subnetId",
    },
)
class ApplicationGatewayFrontendIpConfiguration:
    def __init__(
        self,
        *,
        name: builtins.str,
        private_ip_address: typing.Optional[builtins.str] = None,
        private_ip_address_allocation: typing.Optional[builtins.str] = None,
        public_ip_address_id: typing.Optional[builtins.str] = None,
        subnet_id: typing.Optional[builtins.str] = None,
    ) -> None:
        """
        :param name: 
        :param private_ip_address: 
        :param private_ip_address_allocation: 
        :param public_ip_address_id: 
        :param subnet_id: 
        """
        self._values: typing.Dict[str, typing.Any] = {
            "name": name,
        }
        if private_ip_address is not None:
            self._values["private_ip_address"] = private_ip_address
        if private_ip_address_allocation is not None:
            self._values["private_ip_address_allocation"] = private_ip_address_allocation
        if public_ip_address_id is not None:
            self._values["public_ip_address_id"] = public_ip_address_id
        if subnet_id is not None:
            self._values["subnet_id"] = subnet_id

    @builtins.property
    def name(self) -> builtins.str:
        result = self._values.get("name")
        assert result is not None, "Required property 'name' is missing"
        return result

    @builtins.property
    def private_ip_address(self) -> typing.Optional[builtins.str]:
        result = self._values.get("private_ip_address")
        return result

    @builtins.property
    def private_ip_address_allocation(self) -> typing.Optional[builtins.str]:
        result = self._values.get("private_ip_address_allocation")
        return result

    @builtins.property
    def public_ip_address_id(self) -> typing.Optional[builtins.str]:
        result = self._values.get("public_ip_address_id")
        return result

    @builtins.property
    def subnet_id(self) -> typing.Optional[builtins.str]:
        result = self._values.get("subnet_id")
        return result

    def __eq__(self, rhs: typing.Any) -> builtins.bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs: typing.Any) -> builtins.bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return "ApplicationGatewayFrontendIpConfiguration(%s)" % ", ".join(
            k + "=" + repr(v) for k, v in self._values.items()
        )


@jsii.data_type(
    jsii_type="@cdktf/provider-azurerm.ApplicationGatewayFrontendPort",
    jsii_struct_bases=[],
    name_mapping={"name": "name", "port": "port"},
)
class ApplicationGatewayFrontendPort:
    def __init__(self, *, name: builtins.str, port: jsii.Number) -> None:
        """
        :param name: 
        :param port: 
        """
        self._values: typing.Dict[str, typing.Any] = {
            "name": name,
            "port": port,
        }

    @builtins.property
    def name(self) -> builtins.str:
        result = self._values.get("name")
        assert result is not None, "Required property 'name' is missing"
        return result

    @builtins.property
    def port(self) -> jsii.Number:
        result = self._values.get("port")
        assert result is not None, "Required property 'port' is missing"
        return result

    def __eq__(self, rhs: typing.Any) -> builtins.bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs: typing.Any) -> builtins.bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return "ApplicationGatewayFrontendPort(%s)" % ", ".join(
            k + "=" + repr(v) for k, v in self._values.items()
        )


@jsii.data_type(
    jsii_type="@cdktf/provider-azurerm.ApplicationGatewayGatewayIpConfiguration",
    jsii_struct_bases=[],
    name_mapping={"name": "name", "subnet_id": "subnetId"},
)
class ApplicationGatewayGatewayIpConfiguration:
    def __init__(self, *, name: builtins.str, subnet_id: builtins.str) -> None:
        """
        :param name: 
        :param subnet_id: 
        """
        self._values: typing.Dict[str, typing.Any] = {
            "name": name,
            "subnet_id": subnet_id,
        }

    @builtins.property
    def name(self) -> builtins.str:
        result = self._values.get("name")
        assert result is not None, "Required property 'name' is missing"
        return result

    @builtins.property
    def subnet_id(self) -> builtins.str:
        result = self._values.get("subnet_id")
        assert result is not None, "Required property 'subnet_id' is missing"
        return result

    def __eq__(self, rhs: typing.Any) -> builtins.bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs: typing.Any) -> builtins.bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return "ApplicationGatewayGatewayIpConfiguration(%s)" % ", ".join(
            k + "=" + repr(v) for k, v in self._values.items()
        )


@jsii.data_type(
    jsii_type="@cdktf/provider-azurerm.ApplicationGatewayHttpListener",
    jsii_struct_bases=[],
    name_mapping={
        "frontend_ip_configuration_name": "frontendIpConfigurationName",
        "frontend_port_name": "frontendPortName",
        "name": "name",
        "protocol": "protocol",
        "custom_error_configuration": "customErrorConfiguration",
        "host_name": "hostName",
        "require_sni": "requireSni",
        "ssl_certificate_name": "sslCertificateName",
    },
)
class ApplicationGatewayHttpListener:
    def __init__(
        self,
        *,
        frontend_ip_configuration_name: builtins.str,
        frontend_port_name: builtins.str,
        name: builtins.str,
        protocol: builtins.str,
        custom_error_configuration: typing.Optional[typing.List["ApplicationGatewayHttpListenerCustomErrorConfiguration"]] = None,
        host_name: typing.Optional[builtins.str] = None,
        require_sni: typing.Optional[builtins.bool] = None,
        ssl_certificate_name: typing.Optional[builtins.str] = None,
    ) -> None:
        """
        :param frontend_ip_configuration_name: 
        :param frontend_port_name: 
        :param name: 
        :param protocol: 
        :param custom_error_configuration: custom_error_configuration block.
        :param host_name: 
        :param require_sni: 
        :param ssl_certificate_name: 
        """
        self._values: typing.Dict[str, typing.Any] = {
            "frontend_ip_configuration_name": frontend_ip_configuration_name,
            "frontend_port_name": frontend_port_name,
            "name": name,
            "protocol": protocol,
        }
        if custom_error_configuration is not None:
            self._values["custom_error_configuration"] = custom_error_configuration
        if host_name is not None:
            self._values["host_name"] = host_name
        if require_sni is not None:
            self._values["require_sni"] = require_sni
        if ssl_certificate_name is not None:
            self._values["ssl_certificate_name"] = ssl_certificate_name

    @builtins.property
    def frontend_ip_configuration_name(self) -> builtins.str:
        result = self._values.get("frontend_ip_configuration_name")
        assert result is not None, "Required property 'frontend_ip_configuration_name' is missing"
        return result

    @builtins.property
    def frontend_port_name(self) -> builtins.str:
        result = self._values.get("frontend_port_name")
        assert result is not None, "Required property 'frontend_port_name' is missing"
        return result

    @builtins.property
    def name(self) -> builtins.str:
        result = self._values.get("name")
        assert result is not None, "Required property 'name' is missing"
        return result

    @builtins.property
    def protocol(self) -> builtins.str:
        result = self._values.get("protocol")
        assert result is not None, "Required property 'protocol' is missing"
        return result

    @builtins.property
    def custom_error_configuration(
        self,
    ) -> typing.Optional[typing.List["ApplicationGatewayHttpListenerCustomErrorConfiguration"]]:
        """custom_error_configuration block."""
        result = self._values.get("custom_error_configuration")
        return result

    @builtins.property
    def host_name(self) -> typing.Optional[builtins.str]:
        result = self._values.get("host_name")
        return result

    @builtins.property
    def require_sni(self) -> typing.Optional[builtins.bool]:
        result = self._values.get("require_sni")
        return result

    @builtins.property
    def ssl_certificate_name(self) -> typing.Optional[builtins.str]:
        result = self._values.get("ssl_certificate_name")
        return result

    def __eq__(self, rhs: typing.Any) -> builtins.bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs: typing.Any) -> builtins.bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return "ApplicationGatewayHttpListener(%s)" % ", ".join(
            k + "=" + repr(v) for k, v in self._values.items()
        )


@jsii.data_type(
    jsii_type="@cdktf/provider-azurerm.ApplicationGatewayHttpListenerCustomErrorConfiguration",
    jsii_struct_bases=[],
    name_mapping={
        "custom_error_page_url": "customErrorPageUrl",
        "status_code": "statusCode",
    },
)
class ApplicationGatewayHttpListenerCustomErrorConfiguration:
    def __init__(
        self,
        *,
        custom_error_page_url: builtins.str,
        status_code: builtins.str,
    ) -> None:
        """
        :param custom_error_page_url: 
        :param status_code: 
        """
        self._values: typing.Dict[str, typing.Any] = {
            "custom_error_page_url": custom_error_page_url,
            "status_code": status_code,
        }

    @builtins.property
    def custom_error_page_url(self) -> builtins.str:
        result = self._values.get("custom_error_page_url")
        assert result is not None, "Required property 'custom_error_page_url' is missing"
        return result

    @builtins.property
    def status_code(self) -> builtins.str:
        result = self._values.get("status_code")
        assert result is not None, "Required property 'status_code' is missing"
        return result

    def __eq__(self, rhs: typing.Any) -> builtins.bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs: typing.Any) -> builtins.bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return "ApplicationGatewayHttpListenerCustomErrorConfiguration(%s)" % ", ".join(
            k + "=" + repr(v) for k, v in self._values.items()
        )


@jsii.data_type(
    jsii_type="@cdktf/provider-azurerm.ApplicationGatewayIdentity",
    jsii_struct_bases=[],
    name_mapping={"identity_ids": "identityIds", "type": "type"},
)
class ApplicationGatewayIdentity:
    def __init__(
        self,
        *,
        identity_ids: typing.List[builtins.str],
        type: typing.Optional[builtins.str] = None,
    ) -> None:
        """
        :param identity_ids: 
        :param type: 
        """
        self._values: typing.Dict[str, typing.Any] = {
            "identity_ids": identity_ids,
        }
        if type is not None:
            self._values["type"] = type

    @builtins.property
    def identity_ids(self) -> typing.List[builtins.str]:
        result = self._values.get("identity_ids")
        assert result is not None, "Required property 'identity_ids' is missing"
        return result

    @builtins.property
    def type(self) -> typing.Optional[builtins.str]:
        result = self._values.get("type")
        return result

    def __eq__(self, rhs: typing.Any) -> builtins.bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs: typing.Any) -> builtins.bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return "ApplicationGatewayIdentity(%s)" % ", ".join(
            k + "=" + repr(v) for k, v in self._values.items()
        )


@jsii.data_type(
    jsii_type="@cdktf/provider-azurerm.ApplicationGatewayProbe",
    jsii_struct_bases=[],
    name_mapping={
        "interval": "interval",
        "name": "name",
        "path": "path",
        "protocol": "protocol",
        "timeout": "timeout",
        "unhealthy_threshold": "unhealthyThreshold",
        "host": "host",
        "match": "match",
        "minimum_servers": "minimumServers",
        "pick_host_name_from_backend_http_settings": "pickHostNameFromBackendHttpSettings",
    },
)
class ApplicationGatewayProbe:
    def __init__(
        self,
        *,
        interval: jsii.Number,
        name: builtins.str,
        path: builtins.str,
        protocol: builtins.str,
        timeout: jsii.Number,
        unhealthy_threshold: jsii.Number,
        host: typing.Optional[builtins.str] = None,
        match: typing.Optional[typing.List["ApplicationGatewayProbeMatch"]] = None,
        minimum_servers: typing.Optional[jsii.Number] = None,
        pick_host_name_from_backend_http_settings: typing.Optional[builtins.bool] = None,
    ) -> None:
        """
        :param interval: 
        :param name: 
        :param path: 
        :param protocol: 
        :param timeout: 
        :param unhealthy_threshold: 
        :param host: 
        :param match: match block.
        :param minimum_servers: 
        :param pick_host_name_from_backend_http_settings: 
        """
        self._values: typing.Dict[str, typing.Any] = {
            "interval": interval,
            "name": name,
            "path": path,
            "protocol": protocol,
            "timeout": timeout,
            "unhealthy_threshold": unhealthy_threshold,
        }
        if host is not None:
            self._values["host"] = host
        if match is not None:
            self._values["match"] = match
        if minimum_servers is not None:
            self._values["minimum_servers"] = minimum_servers
        if pick_host_name_from_backend_http_settings is not None:
            self._values["pick_host_name_from_backend_http_settings"] = pick_host_name_from_backend_http_settings

    @builtins.property
    def interval(self) -> jsii.Number:
        result = self._values.get("interval")
        assert result is not None, "Required property 'interval' is missing"
        return result

    @builtins.property
    def name(self) -> builtins.str:
        result = self._values.get("name")
        assert result is not None, "Required property 'name' is missing"
        return result

    @builtins.property
    def path(self) -> builtins.str:
        result = self._values.get("path")
        assert result is not None, "Required property 'path' is missing"
        return result

    @builtins.property
    def protocol(self) -> builtins.str:
        result = self._values.get("protocol")
        assert result is not None, "Required property 'protocol' is missing"
        return result

    @builtins.property
    def timeout(self) -> jsii.Number:
        result = self._values.get("timeout")
        assert result is not None, "Required property 'timeout' is missing"
        return result

    @builtins.property
    def unhealthy_threshold(self) -> jsii.Number:
        result = self._values.get("unhealthy_threshold")
        assert result is not None, "Required property 'unhealthy_threshold' is missing"
        return result

    @builtins.property
    def host(self) -> typing.Optional[builtins.str]:
        result = self._values.get("host")
        return result

    @builtins.property
    def match(self) -> typing.Optional[typing.List["ApplicationGatewayProbeMatch"]]:
        """match block."""
        result = self._values.get("match")
        return result

    @builtins.property
    def minimum_servers(self) -> typing.Optional[jsii.Number]:
        result = self._values.get("minimum_servers")
        return result

    @builtins.property
    def pick_host_name_from_backend_http_settings(
        self,
    ) -> typing.Optional[builtins.bool]:
        result = self._values.get("pick_host_name_from_backend_http_settings")
        return result

    def __eq__(self, rhs: typing.Any) -> builtins.bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs: typing.Any) -> builtins.bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return "ApplicationGatewayProbe(%s)" % ", ".join(
            k + "=" + repr(v) for k, v in self._values.items()
        )


@jsii.data_type(
    jsii_type="@cdktf/provider-azurerm.ApplicationGatewayProbeMatch",
    jsii_struct_bases=[],
    name_mapping={"body": "body", "status_code": "statusCode"},
)
class ApplicationGatewayProbeMatch:
    def __init__(
        self,
        *,
        body: typing.Optional[builtins.str] = None,
        status_code: typing.Optional[typing.List[builtins.str]] = None,
    ) -> None:
        """
        :param body: 
        :param status_code: 
        """
        self._values: typing.Dict[str, typing.Any] = {}
        if body is not None:
            self._values["body"] = body
        if status_code is not None:
            self._values["status_code"] = status_code

    @builtins.property
    def body(self) -> typing.Optional[builtins.str]:
        result = self._values.get("body")
        return result

    @builtins.property
    def status_code(self) -> typing.Optional[typing.List[builtins.str]]:
        result = self._values.get("status_code")
        return result

    def __eq__(self, rhs: typing.Any) -> builtins.bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs: typing.Any) -> builtins.bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return "ApplicationGatewayProbeMatch(%s)" % ", ".join(
            k + "=" + repr(v) for k, v in self._values.items()
        )


@jsii.data_type(
    jsii_type="@cdktf/provider-azurerm.ApplicationGatewayRedirectConfiguration",
    jsii_struct_bases=[],
    name_mapping={
        "name": "name",
        "redirect_type": "redirectType",
        "include_path": "includePath",
        "include_query_string": "includeQueryString",
        "target_listener_name": "targetListenerName",
        "target_url": "targetUrl",
    },
)
class ApplicationGatewayRedirectConfiguration:
    def __init__(
        self,
        *,
        name: builtins.str,
        redirect_type: builtins.str,
        include_path: typing.Optional[builtins.bool] = None,
        include_query_string: typing.Optional[builtins.bool] = None,
        target_listener_name: typing.Optional[builtins.str] = None,
        target_url: typing.Optional[builtins.str] = None,
    ) -> None:
        """
        :param name: 
        :param redirect_type: 
        :param include_path: 
        :param include_query_string: 
        :param target_listener_name: 
        :param target_url: 
        """
        self._values: typing.Dict[str, typing.Any] = {
            "name": name,
            "redirect_type": redirect_type,
        }
        if include_path is not None:
            self._values["include_path"] = include_path
        if include_query_string is not None:
            self._values["include_query_string"] = include_query_string
        if target_listener_name is not None:
            self._values["target_listener_name"] = target_listener_name
        if target_url is not None:
            self._values["target_url"] = target_url

    @builtins.property
    def name(self) -> builtins.str:
        result = self._values.get("name")
        assert result is not None, "Required property 'name' is missing"
        return result

    @builtins.property
    def redirect_type(self) -> builtins.str:
        result = self._values.get("redirect_type")
        assert result is not None, "Required property 'redirect_type' is missing"
        return result

    @builtins.property
    def include_path(self) -> typing.Optional[builtins.bool]:
        result = self._values.get("include_path")
        return result

    @builtins.property
    def include_query_string(self) -> typing.Optional[builtins.bool]:
        result = self._values.get("include_query_string")
        return result

    @builtins.property
    def target_listener_name(self) -> typing.Optional[builtins.str]:
        result = self._values.get("target_listener_name")
        return result

    @builtins.property
    def target_url(self) -> typing.Optional[builtins.str]:
        result = self._values.get("target_url")
        return result

    def __eq__(self, rhs: typing.Any) -> builtins.bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs: typing.Any) -> builtins.bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return "ApplicationGatewayRedirectConfiguration(%s)" % ", ".join(
            k + "=" + repr(v) for k, v in self._values.items()
        )


@jsii.data_type(
    jsii_type="@cdktf/provider-azurerm.ApplicationGatewayRequestRoutingRule",
    jsii_struct_bases=[],
    name_mapping={
        "http_listener_name": "httpListenerName",
        "name": "name",
        "rule_type": "ruleType",
        "backend_address_pool_name": "backendAddressPoolName",
        "backend_http_settings_name": "backendHttpSettingsName",
        "redirect_configuration_name": "redirectConfigurationName",
        "rewrite_rule_set_name": "rewriteRuleSetName",
        "url_path_map_name": "urlPathMapName",
    },
)
class ApplicationGatewayRequestRoutingRule:
    def __init__(
        self,
        *,
        http_listener_name: builtins.str,
        name: builtins.str,
        rule_type: builtins.str,
        backend_address_pool_name: typing.Optional[builtins.str] = None,
        backend_http_settings_name: typing.Optional[builtins.str] = None,
        redirect_configuration_name: typing.Optional[builtins.str] = None,
        rewrite_rule_set_name: typing.Optional[builtins.str] = None,
        url_path_map_name: typing.Optional[builtins.str] = None,
    ) -> None:
        """
        :param http_listener_name: 
        :param name: 
        :param rule_type: 
        :param backend_address_pool_name: 
        :param backend_http_settings_name: 
        :param redirect_configuration_name: 
        :param rewrite_rule_set_name: 
        :param url_path_map_name: 
        """
        self._values: typing.Dict[str, typing.Any] = {
            "http_listener_name": http_listener_name,
            "name": name,
            "rule_type": rule_type,
        }
        if backend_address_pool_name is not None:
            self._values["backend_address_pool_name"] = backend_address_pool_name
        if backend_http_settings_name is not None:
            self._values["backend_http_settings_name"] = backend_http_settings_name
        if redirect_configuration_name is not None:
            self._values["redirect_configuration_name"] = redirect_configuration_name
        if rewrite_rule_set_name is not None:
            self._values["rewrite_rule_set_name"] = rewrite_rule_set_name
        if url_path_map_name is not None:
            self._values["url_path_map_name"] = url_path_map_name

    @builtins.property
    def http_listener_name(self) -> builtins.str:
        result = self._values.get("http_listener_name")
        assert result is not None, "Required property 'http_listener_name' is missing"
        return result

    @builtins.property
    def name(self) -> builtins.str:
        result = self._values.get("name")
        assert result is not None, "Required property 'name' is missing"
        return result

    @builtins.property
    def rule_type(self) -> builtins.str:
        result = self._values.get("rule_type")
        assert result is not None, "Required property 'rule_type' is missing"
        return result

    @builtins.property
    def backend_address_pool_name(self) -> typing.Optional[builtins.str]:
        result = self._values.get("backend_address_pool_name")
        return result

    @builtins.property
    def backend_http_settings_name(self) -> typing.Optional[builtins.str]:
        result = self._values.get("backend_http_settings_name")
        return result

    @builtins.property
    def redirect_configuration_name(self) -> typing.Optional[builtins.str]:
        result = self._values.get("redirect_configuration_name")
        return result

    @builtins.property
    def rewrite_rule_set_name(self) -> typing.Optional[builtins.str]:
        result = self._values.get("rewrite_rule_set_name")
        return result

    @builtins.property
    def url_path_map_name(self) -> typing.Optional[builtins.str]:
        result = self._values.get("url_path_map_name")
        return result

    def __eq__(self, rhs: typing.Any) -> builtins.bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs: typing.Any) -> builtins.bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return "ApplicationGatewayRequestRoutingRule(%s)" % ", ".join(
            k + "=" + repr(v) for k, v in self._values.items()
        )


@jsii.data_type(
    jsii_type="@cdktf/provider-azurerm.ApplicationGatewayRewriteRuleSet",
    jsii_struct_bases=[],
    name_mapping={"name": "name", "rewrite_rule": "rewriteRule"},
)
class ApplicationGatewayRewriteRuleSet:
    def __init__(
        self,
        *,
        name: builtins.str,
        rewrite_rule: typing.Optional[typing.List["ApplicationGatewayRewriteRuleSetRewriteRule"]] = None,
    ) -> None:
        """
        :param name: 
        :param rewrite_rule: rewrite_rule block.
        """
        self._values: typing.Dict[str, typing.Any] = {
            "name": name,
        }
        if rewrite_rule is not None:
            self._values["rewrite_rule"] = rewrite_rule

    @builtins.property
    def name(self) -> builtins.str:
        result = self._values.get("name")
        assert result is not None, "Required property 'name' is missing"
        return result

    @builtins.property
    def rewrite_rule(
        self,
    ) -> typing.Optional[typing.List["ApplicationGatewayRewriteRuleSetRewriteRule"]]:
        """rewrite_rule block."""
        result = self._values.get("rewrite_rule")
        return result

    def __eq__(self, rhs: typing.Any) -> builtins.bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs: typing.Any) -> builtins.bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return "ApplicationGatewayRewriteRuleSet(%s)" % ", ".join(
            k + "=" + repr(v) for k, v in self._values.items()
        )


@jsii.data_type(
    jsii_type="@cdktf/provider-azurerm.ApplicationGatewayRewriteRuleSetRewriteRule",
    jsii_struct_bases=[],
    name_mapping={
        "name": "name",
        "rule_sequence": "ruleSequence",
        "condition": "condition",
        "request_header_configuration": "requestHeaderConfiguration",
        "response_header_configuration": "responseHeaderConfiguration",
    },
)
class ApplicationGatewayRewriteRuleSetRewriteRule:
    def __init__(
        self,
        *,
        name: builtins.str,
        rule_sequence: jsii.Number,
        condition: typing.Optional[typing.List["ApplicationGatewayRewriteRuleSetRewriteRuleCondition"]] = None,
        request_header_configuration: typing.Optional[typing.List["ApplicationGatewayRewriteRuleSetRewriteRuleRequestHeaderConfiguration"]] = None,
        response_header_configuration: typing.Optional[typing.List["ApplicationGatewayRewriteRuleSetRewriteRuleResponseHeaderConfiguration"]] = None,
    ) -> None:
        """
        :param name: 
        :param rule_sequence: 
        :param condition: condition block.
        :param request_header_configuration: request_header_configuration block.
        :param response_header_configuration: response_header_configuration block.
        """
        self._values: typing.Dict[str, typing.Any] = {
            "name": name,
            "rule_sequence": rule_sequence,
        }
        if condition is not None:
            self._values["condition"] = condition
        if request_header_configuration is not None:
            self._values["request_header_configuration"] = request_header_configuration
        if response_header_configuration is not None:
            self._values["response_header_configuration"] = response_header_configuration

    @builtins.property
    def name(self) -> builtins.str:
        result = self._values.get("name")
        assert result is not None, "Required property 'name' is missing"
        return result

    @builtins.property
    def rule_sequence(self) -> jsii.Number:
        result = self._values.get("rule_sequence")
        assert result is not None, "Required property 'rule_sequence' is missing"
        return result

    @builtins.property
    def condition(
        self,
    ) -> typing.Optional[typing.List["ApplicationGatewayRewriteRuleSetRewriteRuleCondition"]]:
        """condition block."""
        result = self._values.get("condition")
        return result

    @builtins.property
    def request_header_configuration(
        self,
    ) -> typing.Optional[typing.List["ApplicationGatewayRewriteRuleSetRewriteRuleRequestHeaderConfiguration"]]:
        """request_header_configuration block."""
        result = self._values.get("request_header_configuration")
        return result

    @builtins.property
    def response_header_configuration(
        self,
    ) -> typing.Optional[typing.List["ApplicationGatewayRewriteRuleSetRewriteRuleResponseHeaderConfiguration"]]:
        """response_header_configuration block."""
        result = self._values.get("response_header_configuration")
        return result

    def __eq__(self, rhs: typing.Any) -> builtins.bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs: typing.Any) -> builtins.bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return "ApplicationGatewayRewriteRuleSetRewriteRule(%s)" % ", ".join(
            k + "=" + repr(v) for k, v in self._values.items()
        )


@jsii.data_type(
    jsii_type="@cdktf/provider-azurerm.ApplicationGatewayRewriteRuleSetRewriteRuleCondition",
    jsii_struct_bases=[],
    name_mapping={
        "pattern": "pattern",
        "variable": "variable",
        "ignore_case": "ignoreCase",
        "negate": "negate",
    },
)
class ApplicationGatewayRewriteRuleSetRewriteRuleCondition:
    def __init__(
        self,
        *,
        pattern: builtins.str,
        variable: builtins.str,
        ignore_case: typing.Optional[builtins.bool] = None,
        negate: typing.Optional[builtins.bool] = None,
    ) -> None:
        """
        :param pattern: 
        :param variable: 
        :param ignore_case: 
        :param negate: 
        """
        self._values: typing.Dict[str, typing.Any] = {
            "pattern": pattern,
            "variable": variable,
        }
        if ignore_case is not None:
            self._values["ignore_case"] = ignore_case
        if negate is not None:
            self._values["negate"] = negate

    @builtins.property
    def pattern(self) -> builtins.str:
        result = self._values.get("pattern")
        assert result is not None, "Required property 'pattern' is missing"
        return result

    @builtins.property
    def variable(self) -> builtins.str:
        result = self._values.get("variable")
        assert result is not None, "Required property 'variable' is missing"
        return result

    @builtins.property
    def ignore_case(self) -> typing.Optional[builtins.bool]:
        result = self._values.get("ignore_case")
        return result

    @builtins.property
    def negate(self) -> typing.Optional[builtins.bool]:
        result = self._values.get("negate")
        return result

    def __eq__(self, rhs: typing.Any) -> builtins.bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs: typing.Any) -> builtins.bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return "ApplicationGatewayRewriteRuleSetRewriteRuleCondition(%s)" % ", ".join(
            k + "=" + repr(v) for k, v in self._values.items()
        )


@jsii.data_type(
    jsii_type="@cdktf/provider-azurerm.ApplicationGatewayRewriteRuleSetRewriteRuleRequestHeaderConfiguration",
    jsii_struct_bases=[],
    name_mapping={"header_name": "headerName", "header_value": "headerValue"},
)
class ApplicationGatewayRewriteRuleSetRewriteRuleRequestHeaderConfiguration:
    def __init__(
        self,
        *,
        header_name: builtins.str,
        header_value: builtins.str,
    ) -> None:
        """
        :param header_name: 
        :param header_value: 
        """
        self._values: typing.Dict[str, typing.Any] = {
            "header_name": header_name,
            "header_value": header_value,
        }

    @builtins.property
    def header_name(self) -> builtins.str:
        result = self._values.get("header_name")
        assert result is not None, "Required property 'header_name' is missing"
        return result

    @builtins.property
    def header_value(self) -> builtins.str:
        result = self._values.get("header_value")
        assert result is not None, "Required property 'header_value' is missing"
        return result

    def __eq__(self, rhs: typing.Any) -> builtins.bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs: typing.Any) -> builtins.bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return "ApplicationGatewayRewriteRuleSetRewriteRuleRequestHeaderConfiguration(%s)" % ", ".join(
            k + "=" + repr(v) for k, v in self._values.items()
        )


@jsii.data_type(
    jsii_type="@cdktf/provider-azurerm.ApplicationGatewayRewriteRuleSetRewriteRuleResponseHeaderConfiguration",
    jsii_struct_bases=[],
    name_mapping={"header_name": "headerName", "header_value": "headerValue"},
)
class ApplicationGatewayRewriteRuleSetRewriteRuleResponseHeaderConfiguration:
    def __init__(
        self,
        *,
        header_name: builtins.str,
        header_value: builtins.str,
    ) -> None:
        """
        :param header_name: 
        :param header_value: 
        """
        self._values: typing.Dict[str, typing.Any] = {
            "header_name": header_name,
            "header_value": header_value,
        }

    @builtins.property
    def header_name(self) -> builtins.str:
        result = self._values.get("header_name")
        assert result is not None, "Required property 'header_name' is missing"
        return result

    @builtins.property
    def header_value(self) -> builtins.str:
        result = self._values.get("header_value")
        assert result is not None, "Required property 'header_value' is missing"
        return result

    def __eq__(self, rhs: typing.Any) -> builtins.bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs: typing.Any) -> builtins.bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return "ApplicationGatewayRewriteRuleSetRewriteRuleResponseHeaderConfiguration(%s)" % ", ".join(
            k + "=" + repr(v) for k, v in self._values.items()
        )


@jsii.data_type(
    jsii_type="@cdktf/provider-azurerm.ApplicationGatewaySku",
    jsii_struct_bases=[],
    name_mapping={"name": "name", "tier": "tier", "capacity": "capacity"},
)
class ApplicationGatewaySku:
    def __init__(
        self,
        *,
        name: builtins.str,
        tier: builtins.str,
        capacity: typing.Optional[jsii.Number] = None,
    ) -> None:
        """
        :param name: 
        :param tier: 
        :param capacity: 
        """
        self._values: typing.Dict[str, typing.Any] = {
            "name": name,
            "tier": tier,
        }
        if capacity is not None:
            self._values["capacity"] = capacity

    @builtins.property
    def name(self) -> builtins.str:
        result = self._values.get("name")
        assert result is not None, "Required property 'name' is missing"
        return result

    @builtins.property
    def tier(self) -> builtins.str:
        result = self._values.get("tier")
        assert result is not None, "Required property 'tier' is missing"
        return result

    @builtins.property
    def capacity(self) -> typing.Optional[jsii.Number]:
        result = self._values.get("capacity")
        return result

    def __eq__(self, rhs: typing.Any) -> builtins.bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs: typing.Any) -> builtins.bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return "ApplicationGatewaySku(%s)" % ", ".join(
            k + "=" + repr(v) for k, v in self._values.items()
        )


@jsii.data_type(
    jsii_type="@cdktf/provider-azurerm.ApplicationGatewaySslCertificate",
    jsii_struct_bases=[],
    name_mapping={"data": "data", "name": "name", "password": "password"},
)
class ApplicationGatewaySslCertificate:
    def __init__(
        self,
        *,
        data: builtins.str,
        name: builtins.str,
        password: builtins.str,
    ) -> None:
        """
        :param data: 
        :param name: 
        :param password: 
        """
        self._values: typing.Dict[str, typing.Any] = {
            "data": data,
            "name": name,
            "password": password,
        }

    @builtins.property
    def data(self) -> builtins.str:
        result = self._values.get("data")
        assert result is not None, "Required property 'data' is missing"
        return result

    @builtins.property
    def name(self) -> builtins.str:
        result = self._values.get("name")
        assert result is not None, "Required property 'name' is missing"
        return result

    @builtins.property
    def password(self) -> builtins.str:
        result = self._values.get("password")
        assert result is not None, "Required property 'password' is missing"
        return result

    def __eq__(self, rhs: typing.Any) -> builtins.bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs: typing.Any) -> builtins.bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return "ApplicationGatewaySslCertificate(%s)" % ", ".join(
            k + "=" + repr(v) for k, v in self._values.items()
        )


@jsii.data_type(
    jsii_type="@cdktf/provider-azurerm.ApplicationGatewaySslPolicy",
    jsii_struct_bases=[],
    name_mapping={
        "cipher_suites": "cipherSuites",
        "disabled_protocols": "disabledProtocols",
        "min_protocol_version": "minProtocolVersion",
        "policy_name": "policyName",
        "policy_type": "policyType",
    },
)
class ApplicationGatewaySslPolicy:
    def __init__(
        self,
        *,
        cipher_suites: typing.Optional[typing.List[builtins.str]] = None,
        disabled_protocols: typing.Optional[typing.List[builtins.str]] = None,
        min_protocol_version: typing.Optional[builtins.str] = None,
        policy_name: typing.Optional[builtins.str] = None,
        policy_type: typing.Optional[builtins.str] = None,
    ) -> None:
        """
        :param cipher_suites: 
        :param disabled_protocols: 
        :param min_protocol_version: 
        :param policy_name: 
        :param policy_type: 
        """
        self._values: typing.Dict[str, typing.Any] = {}
        if cipher_suites is not None:
            self._values["cipher_suites"] = cipher_suites
        if disabled_protocols is not None:
            self._values["disabled_protocols"] = disabled_protocols
        if min_protocol_version is not None:
            self._values["min_protocol_version"] = min_protocol_version
        if policy_name is not None:
            self._values["policy_name"] = policy_name
        if policy_type is not None:
            self._values["policy_type"] = policy_type

    @builtins.property
    def cipher_suites(self) -> typing.Optional[typing.List[builtins.str]]:
        result = self._values.get("cipher_suites")
        return result

    @builtins.property
    def disabled_protocols(self) -> typing.Optional[typing.List[builtins.str]]:
        result = self._values.get("disabled_protocols")
        return result

    @builtins.property
    def min_protocol_version(self) -> typing.Optional[builtins.str]:
        result = self._values.get("min_protocol_version")
        return result

    @builtins.property
    def policy_name(self) -> typing.Optional[builtins.str]:
        result = self._values.get("policy_name")
        return result

    @builtins.property
    def policy_type(self) -> typing.Optional[builtins.str]:
        result = self._values.get("policy_type")
        return result

    def __eq__(self, rhs: typing.Any) -> builtins.bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs: typing.Any) -> builtins.bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return "ApplicationGatewaySslPolicy(%s)" % ", ".join(
            k + "=" + repr(v) for k, v in self._values.items()
        )


@jsii.data_type(
    jsii_type="@cdktf/provider-azurerm.ApplicationGatewayTimeouts",
    jsii_struct_bases=[],
    name_mapping={
        "create": "create",
        "delete": "delete",
        "read": "read",
        "update": "update",
    },
)
class ApplicationGatewayTimeouts:
    def __init__(
        self,
        *,
        create: typing.Optional[builtins.str] = None,
        delete: typing.Optional[builtins.str] = None,
        read: typing.Optional[builtins.str] = None,
        update: typing.Optional[builtins.str] = None,
    ) -> None:
        """
        :param create: 
        :param delete: 
        :param read: 
        :param update: 
        """
        self._values: typing.Dict[str, typing.Any] = {}
        if create is not None:
            self._values["create"] = create
        if delete is not None:
            self._values["delete"] = delete
        if read is not None:
            self._values["read"] = read
        if update is not None:
            self._values["update"] = update

    @builtins.property
    def create(self) -> typing.Optional[builtins.str]:
        result = self._values.get("create")
        return result

    @builtins.property
    def delete(self) -> typing.Optional[builtins.str]:
        result = self._values.get("delete")
        return result

    @builtins.property
    def read(self) -> typing.Optional[builtins.str]:
        result = self._values.get("read")
        return result

    @builtins.property
    def update(self) -> typing.Optional[builtins.str]:
        result = self._values.get("update")
        return result

    def __eq__(self, rhs: typing.Any) -> builtins.bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs: typing.Any) -> builtins.bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return "ApplicationGatewayTimeouts(%s)" % ", ".join(
            k + "=" + repr(v) for k, v in self._values.items()
        )


@jsii.data_type(
    jsii_type="@cdktf/provider-azurerm.ApplicationGatewayTrustedRootCertificate",
    jsii_struct_bases=[],
    name_mapping={"data": "data", "name": "name"},
)
class ApplicationGatewayTrustedRootCertificate:
    def __init__(self, *, data: builtins.str, name: builtins.str) -> None:
        """
        :param data: 
        :param name: 
        """
        self._values: typing.Dict[str, typing.Any] = {
            "data": data,
            "name": name,
        }

    @builtins.property
    def data(self) -> builtins.str:
        result = self._values.get("data")
        assert result is not None, "Required property 'data' is missing"
        return result

    @builtins.property
    def name(self) -> builtins.str:
        result = self._values.get("name")
        assert result is not None, "Required property 'name' is missing"
        return result

    def __eq__(self, rhs: typing.Any) -> builtins.bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs: typing.Any) -> builtins.bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return "ApplicationGatewayTrustedRootCertificate(%s)" % ", ".join(
            k + "=" + repr(v) for k, v in self._values.items()
        )


@jsii.data_type(
    jsii_type="@cdktf/provider-azurerm.ApplicationGatewayUrlPathMap",
    jsii_struct_bases=[],
    name_mapping={
        "name": "name",
        "path_rule": "pathRule",
        "default_backend_address_pool_name": "defaultBackendAddressPoolName",
        "default_backend_http_settings_name": "defaultBackendHttpSettingsName",
        "default_redirect_configuration_name": "defaultRedirectConfigurationName",
        "default_rewrite_rule_set_name": "defaultRewriteRuleSetName",
    },
)
class ApplicationGatewayUrlPathMap:
    def __init__(
        self,
        *,
        name: builtins.str,
        path_rule: typing.List["ApplicationGatewayUrlPathMapPathRule"],
        default_backend_address_pool_name: typing.Optional[builtins.str] = None,
        default_backend_http_settings_name: typing.Optional[builtins.str] = None,
        default_redirect_configuration_name: typing.Optional[builtins.str] = None,
        default_rewrite_rule_set_name: typing.Optional[builtins.str] = None,
    ) -> None:
        """
        :param name: 
        :param path_rule: path_rule block.
        :param default_backend_address_pool_name: 
        :param default_backend_http_settings_name: 
        :param default_redirect_configuration_name: 
        :param default_rewrite_rule_set_name: 
        """
        self._values: typing.Dict[str, typing.Any] = {
            "name": name,
            "path_rule": path_rule,
        }
        if default_backend_address_pool_name is not None:
            self._values["default_backend_address_pool_name"] = default_backend_address_pool_name
        if default_backend_http_settings_name is not None:
            self._values["default_backend_http_settings_name"] = default_backend_http_settings_name
        if default_redirect_configuration_name is not None:
            self._values["default_redirect_configuration_name"] = default_redirect_configuration_name
        if default_rewrite_rule_set_name is not None:
            self._values["default_rewrite_rule_set_name"] = default_rewrite_rule_set_name

    @builtins.property
    def name(self) -> builtins.str:
        result = self._values.get("name")
        assert result is not None, "Required property 'name' is missing"
        return result

    @builtins.property
    def path_rule(self) -> typing.List["ApplicationGatewayUrlPathMapPathRule"]:
        """path_rule block."""
        result = self._values.get("path_rule")
        assert result is not None, "Required property 'path_rule' is missing"
        return result

    @builtins.property
    def default_backend_address_pool_name(self) -> typing.Optional[builtins.str]:
        result = self._values.get("default_backend_address_pool_name")
        return result

    @builtins.property
    def default_backend_http_settings_name(self) -> typing.Optional[builtins.str]:
        result = self._values.get("default_backend_http_settings_name")
        return result

    @builtins.property
    def default_redirect_configuration_name(self) -> typing.Optional[builtins.str]:
        result = self._values.get("default_redirect_configuration_name")
        return result

    @builtins.property
    def default_rewrite_rule_set_name(self) -> typing.Optional[builtins.str]:
        result = self._values.get("default_rewrite_rule_set_name")
        return result

    def __eq__(self, rhs: typing.Any) -> builtins.bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs: typing.Any) -> builtins.bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return "ApplicationGatewayUrlPathMap(%s)" % ", ".join(
            k + "=" + repr(v) for k, v in self._values.items()
        )


@jsii.data_type(
    jsii_type="@cdktf/provider-azurerm.ApplicationGatewayUrlPathMapPathRule",
    jsii_struct_bases=[],
    name_mapping={
        "name": "name",
        "paths": "paths",
        "backend_address_pool_name": "backendAddressPoolName",
        "backend_http_settings_name": "backendHttpSettingsName",
        "redirect_configuration_name": "redirectConfigurationName",
        "rewrite_rule_set_name": "rewriteRuleSetName",
    },
)
class ApplicationGatewayUrlPathMapPathRule:
    def __init__(
        self,
        *,
        name: builtins.str,
        paths: typing.List[builtins.str],
        backend_address_pool_name: typing.Optional[builtins.str] = None,
        backend_http_settings_name: typing.Optional[builtins.str] = None,
        redirect_configuration_name: typing.Optional[builtins.str] = None,
        rewrite_rule_set_name: typing.Optional[builtins.str] = None,
    ) -> None:
        """
        :param name: 
        :param paths: 
        :param backend_address_pool_name: 
        :param backend_http_settings_name: 
        :param redirect_configuration_name: 
        :param rewrite_rule_set_name: 
        """
        self._values: typing.Dict[str, typing.Any] = {
            "name": name,
            "paths": paths,
        }
        if backend_address_pool_name is not None:
            self._values["backend_address_pool_name"] = backend_address_pool_name
        if backend_http_settings_name is not None:
            self._values["backend_http_settings_name"] = backend_http_settings_name
        if redirect_configuration_name is not None:
            self._values["redirect_configuration_name"] = redirect_configuration_name
        if rewrite_rule_set_name is not None:
            self._values["rewrite_rule_set_name"] = rewrite_rule_set_name

    @builtins.property
    def name(self) -> builtins.str:
        result = self._values.get("name")
        assert result is not None, "Required property 'name' is missing"
        return result

    @builtins.property
    def paths(self) -> typing.List[builtins.str]:
        result = self._values.get("paths")
        assert result is not None, "Required property 'paths' is missing"
        return result

    @builtins.property
    def backend_address_pool_name(self) -> typing.Optional[builtins.str]:
        result = self._values.get("backend_address_pool_name")
        return result

    @builtins.property
    def backend_http_settings_name(self) -> typing.Optional[builtins.str]:
        result = self._values.get("backend_http_settings_name")
        return result

    @builtins.property
    def redirect_configuration_name(self) -> typing.Optional[builtins.str]:
        result = self._values.get("redirect_configuration_name")
        return result

    @builtins.property
    def rewrite_rule_set_name(self) -> typing.Optional[builtins.str]:
        result = self._values.get("rewrite_rule_set_name")
        return result

    def __eq__(self, rhs: typing.Any) -> builtins.bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs: typing.Any) -> builtins.bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return "ApplicationGatewayUrlPathMapPathRule(%s)" % ", ".join(
            k + "=" + repr(v) for k, v in self._values.items()
        )


@jsii.data_type(
    jsii_type="@cdktf/provider-azurerm.ApplicationGatewayWafConfiguration",
    jsii_struct_bases=[],
    name_mapping={
        "enabled": "enabled",
        "firewall_mode": "firewallMode",
        "rule_set_version": "ruleSetVersion",
        "disabled_rule_group": "disabledRuleGroup",
        "exclusion": "exclusion",
        "file_upload_limit_mb": "fileUploadLimitMb",
        "max_request_body_size_kb": "maxRequestBodySizeKb",
        "request_body_check": "requestBodyCheck",
        "rule_set_type": "ruleSetType",
    },
)
class ApplicationGatewayWafConfiguration:
    def __init__(
        self,
        *,
        enabled: builtins.bool,
        firewall_mode: builtins.str,
        rule_set_version: builtins.str,
        disabled_rule_group: typing.Optional[typing.List["ApplicationGatewayWafConfigurationDisabledRuleGroup"]] = None,
        exclusion: typing.Optional[typing.List["ApplicationGatewayWafConfigurationExclusion"]] = None,
        file_upload_limit_mb: typing.Optional[jsii.Number] = None,
        max_request_body_size_kb: typing.Optional[jsii.Number] = None,
        request_body_check: typing.Optional[builtins.bool] = None,
        rule_set_type: typing.Optional[builtins.str] = None,
    ) -> None:
        """
        :param enabled: 
        :param firewall_mode: 
        :param rule_set_version: 
        :param disabled_rule_group: disabled_rule_group block.
        :param exclusion: exclusion block.
        :param file_upload_limit_mb: 
        :param max_request_body_size_kb: 
        :param request_body_check: 
        :param rule_set_type: 
        """
        self._values: typing.Dict[str, typing.Any] = {
            "enabled": enabled,
            "firewall_mode": firewall_mode,
            "rule_set_version": rule_set_version,
        }
        if disabled_rule_group is not None:
            self._values["disabled_rule_group"] = disabled_rule_group
        if exclusion is not None:
            self._values["exclusion"] = exclusion
        if file_upload_limit_mb is not None:
            self._values["file_upload_limit_mb"] = file_upload_limit_mb
        if max_request_body_size_kb is not None:
            self._values["max_request_body_size_kb"] = max_request_body_size_kb
        if request_body_check is not None:
            self._values["request_body_check"] = request_body_check
        if rule_set_type is not None:
            self._values["rule_set_type"] = rule_set_type

    @builtins.property
    def enabled(self) -> builtins.bool:
        result = self._values.get("enabled")
        assert result is not None, "Required property 'enabled' is missing"
        return result

    @builtins.property
    def firewall_mode(self) -> builtins.str:
        result = self._values.get("firewall_mode")
        assert result is not None, "Required property 'firewall_mode' is missing"
        return result

    @builtins.property
    def rule_set_version(self) -> builtins.str:
        result = self._values.get("rule_set_version")
        assert result is not None, "Required property 'rule_set_version' is missing"
        return result

    @builtins.property
    def disabled_rule_group(
        self,
    ) -> typing.Optional[typing.List["ApplicationGatewayWafConfigurationDisabledRuleGroup"]]:
        """disabled_rule_group block."""
        result = self._values.get("disabled_rule_group")
        return result

    @builtins.property
    def exclusion(
        self,
    ) -> typing.Optional[typing.List["ApplicationGatewayWafConfigurationExclusion"]]:
        """exclusion block."""
        result = self._values.get("exclusion")
        return result

    @builtins.property
    def file_upload_limit_mb(self) -> typing.Optional[jsii.Number]:
        result = self._values.get("file_upload_limit_mb")
        return result

    @builtins.property
    def max_request_body_size_kb(self) -> typing.Optional[jsii.Number]:
        result = self._values.get("max_request_body_size_kb")
        return result

    @builtins.property
    def request_body_check(self) -> typing.Optional[builtins.bool]:
        result = self._values.get("request_body_check")
        return result

    @builtins.property
    def rule_set_type(self) -> typing.Optional[builtins.str]:
        result = self._values.get("rule_set_type")
        return result

    def __eq__(self, rhs: typing.Any) -> builtins.bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs: typing.Any) -> builtins.bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return "ApplicationGatewayWafConfiguration(%s)" % ", ".join(
            k + "=" + repr(v) for k, v in self._values.items()
        )


@jsii.data_type(
    jsii_type="@cdktf/provider-azurerm.ApplicationGatewayWafConfigurationDisabledRuleGroup",
    jsii_struct_bases=[],
    name_mapping={"rule_group_name": "ruleGroupName", "rules": "rules"},
)
class ApplicationGatewayWafConfigurationDisabledRuleGroup:
    def __init__(
        self,
        *,
        rule_group_name: builtins.str,
        rules: typing.Optional[typing.List[jsii.Number]] = None,
    ) -> None:
        """
        :param rule_group_name: 
        :param rules: 
        """
        self._values: typing.Dict[str, typing.Any] = {
            "rule_group_name": rule_group_name,
        }
        if rules is not None:
            self._values["rules"] = rules

    @builtins.property
    def rule_group_name(self) -> builtins.str:
        result = self._values.get("rule_group_name")
        assert result is not None, "Required property 'rule_group_name' is missing"
        return result

    @builtins.property
    def rules(self) -> typing.Optional[typing.List[jsii.Number]]:
        result = self._values.get("rules")
        return result

    def __eq__(self, rhs: typing.Any) -> builtins.bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs: typing.Any) -> builtins.bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return "ApplicationGatewayWafConfigurationDisabledRuleGroup(%s)" % ", ".join(
            k + "=" + repr(v) for k, v in self._values.items()
        )


@jsii.data_type(
    jsii_type="@cdktf/provider-azurerm.ApplicationGatewayWafConfigurationExclusion",
    jsii_struct_bases=[],
    name_mapping={
        "match_variable": "matchVariable",
        "selector": "selector",
        "selector_match_operator": "selectorMatchOperator",
    },
)
class ApplicationGatewayWafConfigurationExclusion:
    def __init__(
        self,
        *,
        match_variable: builtins.str,
        selector: typing.Optional[builtins.str] = None,
        selector_match_operator: typing.Optional[builtins.str] = None,
    ) -> None:
        """
        :param match_variable: 
        :param selector: 
        :param selector_match_operator: 
        """
        self._values: typing.Dict[str, typing.Any] = {
            "match_variable": match_variable,
        }
        if selector is not None:
            self._values["selector"] = selector
        if selector_match_operator is not None:
            self._values["selector_match_operator"] = selector_match_operator

    @builtins.property
    def match_variable(self) -> builtins.str:
        result = self._values.get("match_variable")
        assert result is not None, "Required property 'match_variable' is missing"
        return result

    @builtins.property
    def selector(self) -> typing.Optional[builtins.str]:
        result = self._values.get("selector")
        return result

    @builtins.property
    def selector_match_operator(self) -> typing.Optional[builtins.str]:
        result = self._values.get("selector_match_operator")
        return result

    def __eq__(self, rhs: typing.Any) -> builtins.bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs: typing.Any) -> builtins.bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return "ApplicationGatewayWafConfigurationExclusion(%s)" % ", ".join(
            k + "=" + repr(v) for k, v in self._values.items()
        )


class ApplicationInsights(
    cdktf.TerraformResource,
    metaclass=jsii.JSIIMeta,
    jsii_type="@cdktf/provider-azurerm.ApplicationInsights",
):
    def __init__(
        self,
        scope: constructs.Construct,
        id: builtins.str,
        *,
        application_type: builtins.str,
        location: builtins.str,
        name: builtins.str,
        resource_group_name: builtins.str,
        daily_data_cap_in_gb: typing.Optional[jsii.Number] = None,
        daily_data_cap_notifications_disabled: typing.Optional[builtins.bool] = None,
        retention_in_days: typing.Optional[jsii.Number] = None,
        sampling_percentage: typing.Optional[jsii.Number] = None,
        tags: typing.Optional[typing.Mapping[builtins.str, builtins.str]] = None,
        timeouts: typing.Optional["ApplicationInsightsTimeouts"] = None,
        count: typing.Optional[jsii.Number] = None,
        depends_on: typing.Optional[typing.List[cdktf.TerraformResource]] = None,
        lifecycle: typing.Optional[cdktf.TerraformResourceLifecycle] = None,
        provider: typing.Optional[cdktf.TerraformProvider] = None,
    ) -> None:
        """
        :param scope: -
        :param id: -
        :param application_type: 
        :param location: 
        :param name: 
        :param resource_group_name: 
        :param daily_data_cap_in_gb: 
        :param daily_data_cap_notifications_disabled: 
        :param retention_in_days: 
        :param sampling_percentage: 
        :param tags: 
        :param timeouts: timeouts block.
        :param count: 
        :param depends_on: 
        :param lifecycle: 
        :param provider: 
        """
        config = ApplicationInsightsConfig(
            application_type=application_type,
            location=location,
            name=name,
            resource_group_name=resource_group_name,
            daily_data_cap_in_gb=daily_data_cap_in_gb,
            daily_data_cap_notifications_disabled=daily_data_cap_notifications_disabled,
            retention_in_days=retention_in_days,
            sampling_percentage=sampling_percentage,
            tags=tags,
            timeouts=timeouts,
            count=count,
            depends_on=depends_on,
            lifecycle=lifecycle,
            provider=provider,
        )

        jsii.create(ApplicationInsights, self, [scope, id, config])

    @jsii.member(jsii_name="synthesizeAttributes")
    def _synthesize_attributes(self) -> typing.Mapping[builtins.str, typing.Any]:
        return jsii.invoke(self, "synthesizeAttributes", [])

    @builtins.property # type: ignore
    @jsii.member(jsii_name="appId")
    def app_id(self) -> builtins.str:
        return jsii.get(self, "appId")

    @builtins.property # type: ignore
    @jsii.member(jsii_name="instrumentationKey")
    def instrumentation_key(self) -> builtins.str:
        return jsii.get(self, "instrumentationKey")

    @builtins.property # type: ignore
    @jsii.member(jsii_name="applicationType")
    def application_type(self) -> builtins.str:
        return jsii.get(self, "applicationType")

    @application_type.setter # type: ignore
    def application_type(self, value: builtins.str) -> None:
        jsii.set(self, "applicationType", value)

    @builtins.property # type: ignore
    @jsii.member(jsii_name="location")
    def location(self) -> builtins.str:
        return jsii.get(self, "location")

    @location.setter # type: ignore
    def location(self, value: builtins.str) -> None:
        jsii.set(self, "location", value)

    @builtins.property # type: ignore
    @jsii.member(jsii_name="name")
    def name(self) -> builtins.str:
        return jsii.get(self, "name")

    @name.setter # type: ignore
    def name(self, value: builtins.str) -> None:
        jsii.set(self, "name", value)

    @builtins.property # type: ignore
    @jsii.member(jsii_name="resourceGroupName")
    def resource_group_name(self) -> builtins.str:
        return jsii.get(self, "resourceGroupName")

    @resource_group_name.setter # type: ignore
    def resource_group_name(self, value: builtins.str) -> None:
        jsii.set(self, "resourceGroupName", value)

    @builtins.property # type: ignore
    @jsii.member(jsii_name="dailyDataCapInGb")
    def daily_data_cap_in_gb(self) -> typing.Optional[jsii.Number]:
        return jsii.get(self, "dailyDataCapInGb")

    @daily_data_cap_in_gb.setter # type: ignore
    def daily_data_cap_in_gb(self, value: typing.Optional[jsii.Number]) -> None:
        jsii.set(self, "dailyDataCapInGb", value)

    @builtins.property # type: ignore
    @jsii.member(jsii_name="dailyDataCapNotificationsDisabled")
    def daily_data_cap_notifications_disabled(self) -> typing.Optional[builtins.bool]:
        return jsii.get(self, "dailyDataCapNotificationsDisabled")

    @daily_data_cap_notifications_disabled.setter # type: ignore
    def daily_data_cap_notifications_disabled(
        self,
        value: typing.Optional[builtins.bool],
    ) -> None:
        jsii.set(self, "dailyDataCapNotificationsDisabled", value)

    @builtins.property # type: ignore
    @jsii.member(jsii_name="id")
    def id(self) -> typing.Optional[builtins.str]:
        return jsii.get(self, "id")

    @id.setter # type: ignore
    def id(self, value: typing.Optional[builtins.str]) -> None:
        jsii.set(self, "id", value)

    @builtins.property # type: ignore
    @jsii.member(jsii_name="retentionInDays")
    def retention_in_days(self) -> typing.Optional[jsii.Number]:
        return jsii.get(self, "retentionInDays")

    @retention_in_days.setter # type: ignore
    def retention_in_days(self, value: typing.Optional[jsii.Number]) -> None:
        jsii.set(self, "retentionInDays", value)

    @builtins.property # type: ignore
    @jsii.member(jsii_name="samplingPercentage")
    def sampling_percentage(self) -> typing.Optional[jsii.Number]:
        return jsii.get(self, "samplingPercentage")

    @sampling_percentage.setter # type: ignore
    def sampling_percentage(self, value: typing.Optional[jsii.Number]) -> None:
        jsii.set(self, "samplingPercentage", value)

    @builtins.property # type: ignore
    @jsii.member(jsii_name="tags")
    def tags(self) -> typing.Optional[typing.Mapping[builtins.str, builtins.str]]:
        return jsii.get(self, "tags")

    @tags.setter # type: ignore
    def tags(
        self,
        value: typing.Optional[typing.Mapping[builtins.str, builtins.str]],
    ) -> None:
        jsii.set(self, "tags", value)

    @builtins.property # type: ignore
    @jsii.member(jsii_name="timeouts")
    def timeouts(self) -> typing.Optional["ApplicationInsightsTimeouts"]:
        return jsii.get(self, "timeouts")

    @timeouts.setter # type: ignore
    def timeouts(self, value: typing.Optional["ApplicationInsightsTimeouts"]) -> None:
        jsii.set(self, "timeouts", value)


class ApplicationInsightsAnalyticsItem(
    cdktf.TerraformResource,
    metaclass=jsii.JSIIMeta,
    jsii_type="@cdktf/provider-azurerm.ApplicationInsightsAnalyticsItem",
):
    def __init__(
        self,
        scope_: constructs.Construct,
        id: builtins.str,
        *,
        application_insights_id: builtins.str,
        content: builtins.str,
        name: builtins.str,
        scope: builtins.str,
        type: builtins.str,
        function_alias: typing.Optional[builtins.str] = None,
        timeouts: typing.Optional["ApplicationInsightsAnalyticsItemTimeouts"] = None,
        count: typing.Optional[jsii.Number] = None,
        depends_on: typing.Optional[typing.List[cdktf.TerraformResource]] = None,
        lifecycle: typing.Optional[cdktf.TerraformResourceLifecycle] = None,
        provider: typing.Optional[cdktf.TerraformProvider] = None,
    ) -> None:
        """
        :param scope_: -
        :param id: -
        :param application_insights_id: 
        :param content: 
        :param name: 
        :param scope: 
        :param type: 
        :param function_alias: 
        :param timeouts: timeouts block.
        :param count: 
        :param depends_on: 
        :param lifecycle: 
        :param provider: 
        """
        config = ApplicationInsightsAnalyticsItemConfig(
            application_insights_id=application_insights_id,
            content=content,
            name=name,
            scope=scope,
            type=type,
            function_alias=function_alias,
            timeouts=timeouts,
            count=count,
            depends_on=depends_on,
            lifecycle=lifecycle,
            provider=provider,
        )

        jsii.create(ApplicationInsightsAnalyticsItem, self, [scope_, id, config])

    @jsii.member(jsii_name="synthesizeAttributes")
    def _synthesize_attributes(self) -> typing.Mapping[builtins.str, typing.Any]:
        return jsii.invoke(self, "synthesizeAttributes", [])

    @builtins.property # type: ignore
    @jsii.member(jsii_name="timeCreated")
    def time_created(self) -> builtins.str:
        return jsii.get(self, "timeCreated")

    @builtins.property # type: ignore
    @jsii.member(jsii_name="timeModified")
    def time_modified(self) -> builtins.str:
        return jsii.get(self, "timeModified")

    @builtins.property # type: ignore
    @jsii.member(jsii_name="version")
    def version(self) -> builtins.str:
        return jsii.get(self, "version")

    @builtins.property # type: ignore
    @jsii.member(jsii_name="applicationInsightsId")
    def application_insights_id(self) -> builtins.str:
        return jsii.get(self, "applicationInsightsId")

    @application_insights_id.setter # type: ignore
    def application_insights_id(self, value: builtins.str) -> None:
        jsii.set(self, "applicationInsightsId", value)

    @builtins.property # type: ignore
    @jsii.member(jsii_name="content")
    def content(self) -> builtins.str:
        return jsii.get(self, "content")

    @content.setter # type: ignore
    def content(self, value: builtins.str) -> None:
        jsii.set(self, "content", value)

    @builtins.property # type: ignore
    @jsii.member(jsii_name="name")
    def name(self) -> builtins.str:
        return jsii.get(self, "name")

    @name.setter # type: ignore
    def name(self, value: builtins.str) -> None:
        jsii.set(self, "name", value)

    @builtins.property # type: ignore
    @jsii.member(jsii_name="scope")
    def scope(self) -> builtins.str:
        return jsii.get(self, "scope")

    @scope.setter # type: ignore
    def scope(self, value: builtins.str) -> None:
        jsii.set(self, "scope", value)

    @builtins.property # type: ignore
    @jsii.member(jsii_name="type")
    def type(self) -> builtins.str:
        return jsii.get(self, "type")

    @type.setter # type: ignore
    def type(self, value: builtins.str) -> None:
        jsii.set(self, "type", value)

    @builtins.property # type: ignore
    @jsii.member(jsii_name="functionAlias")
    def function_alias(self) -> typing.Optional[builtins.str]:
        return jsii.get(self, "functionAlias")

    @function_alias.setter # type: ignore
    def function_alias(self, value: typing.Optional[builtins.str]) -> None:
        jsii.set(self, "functionAlias", value)

    @builtins.property # type: ignore
    @jsii.member(jsii_name="id")
    def id(self) -> typing.Optional[builtins.str]:
        return jsii.get(self, "id")

    @id.setter # type: ignore
    def id(self, value: typing.Optional[builtins.str]) -> None:
        jsii.set(self, "id", value)

    @builtins.property # type: ignore
    @jsii.member(jsii_name="timeouts")
    def timeouts(self) -> typing.Optional["ApplicationInsightsAnalyticsItemTimeouts"]:
        return jsii.get(self, "timeouts")

    @timeouts.setter # type: ignore
    def timeouts(
        self,
        value: typing.Optional["ApplicationInsightsAnalyticsItemTimeouts"],
    ) -> None:
        jsii.set(self, "timeouts", value)


@jsii.data_type(
    jsii_type="@cdktf/provider-azurerm.ApplicationInsightsAnalyticsItemConfig",
    jsii_struct_bases=[cdktf.TerraformMetaArguments],
    name_mapping={
        "count": "count",
        "depends_on": "dependsOn",
        "lifecycle": "lifecycle",
        "provider": "provider",
        "application_insights_id": "applicationInsightsId",
        "content": "content",
        "name": "name",
        "scope": "scope",
        "type": "type",
        "function_alias": "functionAlias",
        "timeouts": "timeouts",
    },
)
class ApplicationInsightsAnalyticsItemConfig(cdktf.TerraformMetaArguments):
    def __init__(
        self,
        *,
        count: typing.Optional[jsii.Number] = None,
        depends_on: typing.Optional[typing.List[cdktf.TerraformResource]] = None,
        lifecycle: typing.Optional[cdktf.TerraformResourceLifecycle] = None,
        provider: typing.Optional[cdktf.TerraformProvider] = None,
        application_insights_id: builtins.str,
        content: builtins.str,
        name: builtins.str,
        scope: builtins.str,
        type: builtins.str,
        function_alias: typing.Optional[builtins.str] = None,
        timeouts: typing.Optional["ApplicationInsightsAnalyticsItemTimeouts"] = None,
    ) -> None:
        """
        :param count: 
        :param depends_on: 
        :param lifecycle: 
        :param provider: 
        :param application_insights_id: 
        :param content: 
        :param name: 
        :param scope: 
        :param type: 
        :param function_alias: 
        :param timeouts: timeouts block.
        """
        if isinstance(lifecycle, dict):
            lifecycle = cdktf.TerraformResourceLifecycle(**lifecycle)
        if isinstance(timeouts, dict):
            timeouts = ApplicationInsightsAnalyticsItemTimeouts(**timeouts)
        self._values: typing.Dict[str, typing.Any] = {
            "application_insights_id": application_insights_id,
            "content": content,
            "name": name,
            "scope": scope,
            "type": type,
        }
        if count is not None:
            self._values["count"] = count
        if depends_on is not None:
            self._values["depends_on"] = depends_on
        if lifecycle is not None:
            self._values["lifecycle"] = lifecycle
        if provider is not None:
            self._values["provider"] = provider
        if function_alias is not None:
            self._values["function_alias"] = function_alias
        if timeouts is not None:
            self._values["timeouts"] = timeouts

    @builtins.property
    def count(self) -> typing.Optional[jsii.Number]:
        """
        :stability: experimental
        """
        result = self._values.get("count")
        return result

    @builtins.property
    def depends_on(self) -> typing.Optional[typing.List[cdktf.TerraformResource]]:
        """
        :stability: experimental
        """
        result = self._values.get("depends_on")
        return result

    @builtins.property
    def lifecycle(self) -> typing.Optional[cdktf.TerraformResourceLifecycle]:
        """
        :stability: experimental
        """
        result = self._values.get("lifecycle")
        return result

    @builtins.property
    def provider(self) -> typing.Optional[cdktf.TerraformProvider]:
        """
        :stability: experimental
        """
        result = self._values.get("provider")
        return result

    @builtins.property
    def application_insights_id(self) -> builtins.str:
        result = self._values.get("application_insights_id")
        assert result is not None, "Required property 'application_insights_id' is missing"
        return result

    @builtins.property
    def content(self) -> builtins.str:
        result = self._values.get("content")
        assert result is not None, "Required property 'content' is missing"
        return result

    @builtins.property
    def name(self) -> builtins.str:
        result = self._values.get("name")
        assert result is not None, "Required property 'name' is missing"
        return result

    @builtins.property
    def scope(self) -> builtins.str:
        result = self._values.get("scope")
        assert result is not None, "Required property 'scope' is missing"
        return result

    @builtins.property
    def type(self) -> builtins.str:
        result = self._values.get("type")
        assert result is not None, "Required property 'type' is missing"
        return result

    @builtins.property
    def function_alias(self) -> typing.Optional[builtins.str]:
        result = self._values.get("function_alias")
        return result

    @builtins.property
    def timeouts(self) -> typing.Optional["ApplicationInsightsAnalyticsItemTimeouts"]:
        """timeouts block."""
        result = self._values.get("timeouts")
        return result

    def __eq__(self, rhs: typing.Any) -> builtins.bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs: typing.Any) -> builtins.bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return "ApplicationInsightsAnalyticsItemConfig(%s)" % ", ".join(
            k + "=" + repr(v) for k, v in self._values.items()
        )


@jsii.data_type(
    jsii_type="@cdktf/provider-azurerm.ApplicationInsightsAnalyticsItemTimeouts",
    jsii_struct_bases=[],
    name_mapping={
        "create": "create",
        "delete": "delete",
        "read": "read",
        "update": "update",
    },
)
class ApplicationInsightsAnalyticsItemTimeouts:
    def __init__(
        self,
        *,
        create: typing.Optional[builtins.str] = None,
        delete: typing.Optional[builtins.str] = None,
        read: typing.Optional[builtins.str] = None,
        update: typing.Optional[builtins.str] = None,
    ) -> None:
        """
        :param create: 
        :param delete: 
        :param read: 
        :param update: 
        """
        self._values: typing.Dict[str, typing.Any] = {}
        if create is not None:
            self._values["create"] = create
        if delete is not None:
            self._values["delete"] = delete
        if read is not None:
            self._values["read"] = read
        if update is not None:
            self._values["update"] = update

    @builtins.property
    def create(self) -> typing.Optional[builtins.str]:
        result = self._values.get("create")
        return result

    @builtins.property
    def delete(self) -> typing.Optional[builtins.str]:
        result = self._values.get("delete")
        return result

    @builtins.property
    def read(self) -> typing.Optional[builtins.str]:
        result = self._values.get("read")
        return result

    @builtins.property
    def update(self) -> typing.Optional[builtins.str]:
        result = self._values.get("update")
        return result

    def __eq__(self, rhs: typing.Any) -> builtins.bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs: typing.Any) -> builtins.bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return "ApplicationInsightsAnalyticsItemTimeouts(%s)" % ", ".join(
            k + "=" + repr(v) for k, v in self._values.items()
        )


class ApplicationInsightsApiKey(
    cdktf.TerraformResource,
    metaclass=jsii.JSIIMeta,
    jsii_type="@cdktf/provider-azurerm.ApplicationInsightsApiKey",
):
    def __init__(
        self,
        scope: constructs.Construct,
        id: builtins.str,
        *,
        application_insights_id: builtins.str,
        name: builtins.str,
        read_permissions: typing.Optional[typing.List[builtins.str]] = None,
        timeouts: typing.Optional["ApplicationInsightsApiKeyTimeouts"] = None,
        write_permissions: typing.Optional[typing.List[builtins.str]] = None,
        count: typing.Optional[jsii.Number] = None,
        depends_on: typing.Optional[typing.List[cdktf.TerraformResource]] = None,
        lifecycle: typing.Optional[cdktf.TerraformResourceLifecycle] = None,
        provider: typing.Optional[cdktf.TerraformProvider] = None,
    ) -> None:
        """
        :param scope: -
        :param id: -
        :param application_insights_id: 
        :param name: 
        :param read_permissions: 
        :param timeouts: timeouts block.
        :param write_permissions: 
        :param count: 
        :param depends_on: 
        :param lifecycle: 
        :param provider: 
        """
        config = ApplicationInsightsApiKeyConfig(
            application_insights_id=application_insights_id,
            name=name,
            read_permissions=read_permissions,
            timeouts=timeouts,
            write_permissions=write_permissions,
            count=count,
            depends_on=depends_on,
            lifecycle=lifecycle,
            provider=provider,
        )

        jsii.create(ApplicationInsightsApiKey, self, [scope, id, config])

    @jsii.member(jsii_name="synthesizeAttributes")
    def _synthesize_attributes(self) -> typing.Mapping[builtins.str, typing.Any]:
        return jsii.invoke(self, "synthesizeAttributes", [])

    @builtins.property # type: ignore
    @jsii.member(jsii_name="apiKey")
    def api_key(self) -> builtins.str:
        return jsii.get(self, "apiKey")

    @builtins.property # type: ignore
    @jsii.member(jsii_name="applicationInsightsId")
    def application_insights_id(self) -> builtins.str:
        return jsii.get(self, "applicationInsightsId")

    @application_insights_id.setter # type: ignore
    def application_insights_id(self, value: builtins.str) -> None:
        jsii.set(self, "applicationInsightsId", value)

    @builtins.property # type: ignore
    @jsii.member(jsii_name="name")
    def name(self) -> builtins.str:
        return jsii.get(self, "name")

    @name.setter # type: ignore
    def name(self, value: builtins.str) -> None:
        jsii.set(self, "name", value)

    @builtins.property # type: ignore
    @jsii.member(jsii_name="id")
    def id(self) -> typing.Optional[builtins.str]:
        return jsii.get(self, "id")

    @id.setter # type: ignore
    def id(self, value: typing.Optional[builtins.str]) -> None:
        jsii.set(self, "id", value)

    @builtins.property # type: ignore
    @jsii.member(jsii_name="readPermissions")
    def read_permissions(self) -> typing.Optional[typing.List[builtins.str]]:
        return jsii.get(self, "readPermissions")

    @read_permissions.setter # type: ignore
    def read_permissions(
        self,
        value: typing.Optional[typing.List[builtins.str]],
    ) -> None:
        jsii.set(self, "readPermissions", value)

    @builtins.property # type: ignore
    @jsii.member(jsii_name="timeouts")
    def timeouts(self) -> typing.Optional["ApplicationInsightsApiKeyTimeouts"]:
        return jsii.get(self, "timeouts")

    @timeouts.setter # type: ignore
    def timeouts(
        self,
        value: typing.Optional["ApplicationInsightsApiKeyTimeouts"],
    ) -> None:
        jsii.set(self, "timeouts", value)

    @builtins.property # type: ignore
    @jsii.member(jsii_name="writePermissions")
    def write_permissions(self) -> typing.Optional[typing.List[builtins.str]]:
        return jsii.get(self, "writePermissions")

    @write_permissions.setter # type: ignore
    def write_permissions(
        self,
        value: typing.Optional[typing.List[builtins.str]],
    ) -> None:
        jsii.set(self, "writePermissions", value)


@jsii.data_type(
    jsii_type="@cdktf/provider-azurerm.ApplicationInsightsApiKeyConfig",
    jsii_struct_bases=[cdktf.TerraformMetaArguments],
    name_mapping={
        "count": "count",
        "depends_on": "dependsOn",
        "lifecycle": "lifecycle",
        "provider": "provider",
        "application_insights_id": "applicationInsightsId",
        "name": "name",
        "read_permissions": "readPermissions",
        "timeouts": "timeouts",
        "write_permissions": "writePermissions",
    },
)
class ApplicationInsightsApiKeyConfig(cdktf.TerraformMetaArguments):
    def __init__(
        self,
        *,
        count: typing.Optional[jsii.Number] = None,
        depends_on: typing.Optional[typing.List[cdktf.TerraformResource]] = None,
        lifecycle: typing.Optional[cdktf.TerraformResourceLifecycle] = None,
        provider: typing.Optional[cdktf.TerraformProvider] = None,
        application_insights_id: builtins.str,
        name: builtins.str,
        read_permissions: typing.Optional[typing.List[builtins.str]] = None,
        timeouts: typing.Optional["ApplicationInsightsApiKeyTimeouts"] = None,
        write_permissions: typing.Optional[typing.List[builtins.str]] = None,
    ) -> None:
        """
        :param count: 
        :param depends_on: 
        :param lifecycle: 
        :param provider: 
        :param application_insights_id: 
        :param name: 
        :param read_permissions: 
        :param timeouts: timeouts block.
        :param write_permissions: 
        """
        if isinstance(lifecycle, dict):
            lifecycle = cdktf.TerraformResourceLifecycle(**lifecycle)
        if isinstance(timeouts, dict):
            timeouts = ApplicationInsightsApiKeyTimeouts(**timeouts)
        self._values: typing.Dict[str, typing.Any] = {
            "application_insights_id": application_insights_id,
            "name": name,
        }
        if count is not None:
            self._values["count"] = count
        if depends_on is not None:
            self._values["depends_on"] = depends_on
        if lifecycle is not None:
            self._values["lifecycle"] = lifecycle
        if provider is not None:
            self._values["provider"] = provider
        if read_permissions is not None:
            self._values["read_permissions"] = read_permissions
        if timeouts is not None:
            self._values["timeouts"] = timeouts
        if write_permissions is not None:
            self._values["write_permissions"] = write_permissions

    @builtins.property
    def count(self) -> typing.Optional[jsii.Number]:
        """
        :stability: experimental
        """
        result = self._values.get("count")
        return result

    @builtins.property
    def depends_on(self) -> typing.Optional[typing.List[cdktf.TerraformResource]]:
        """
        :stability: experimental
        """
        result = self._values.get("depends_on")
        return result

    @builtins.property
    def lifecycle(self) -> typing.Optional[cdktf.TerraformResourceLifecycle]:
        """
        :stability: experimental
        """
        result = self._values.get("lifecycle")
        return result

    @builtins.property
    def provider(self) -> typing.Optional[cdktf.TerraformProvider]:
        """
        :stability: experimental
        """
        result = self._values.get("provider")
        return result

    @builtins.property
    def application_insights_id(self) -> builtins.str:
        result = self._values.get("application_insights_id")
        assert result is not None, "Required property 'application_insights_id' is missing"
        return result

    @builtins.property
    def name(self) -> builtins.str:
        result = self._values.get("name")
        assert result is not None, "Required property 'name' is missing"
        return result

    @builtins.property
    def read_permissions(self) -> typing.Optional[typing.List[builtins.str]]:
        result = self._values.get("read_permissions")
        return result

    @builtins.property
    def timeouts(self) -> typing.Optional["ApplicationInsightsApiKeyTimeouts"]:
        """timeouts block."""
        result = self._values.get("timeouts")
        return result

    @builtins.property
    def write_permissions(self) -> typing.Optional[typing.List[builtins.str]]:
        result = self._values.get("write_permissions")
        return result

    def __eq__(self, rhs: typing.Any) -> builtins.bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs: typing.Any) -> builtins.bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return "ApplicationInsightsApiKeyConfig(%s)" % ", ".join(
            k + "=" + repr(v) for k, v in self._values.items()
        )


@jsii.data_type(
    jsii_type="@cdktf/provider-azurerm.ApplicationInsightsApiKeyTimeouts",
    jsii_struct_bases=[],
    name_mapping={
        "create": "create",
        "delete": "delete",
        "read": "read",
        "update": "update",
    },
)
class ApplicationInsightsApiKeyTimeouts:
    def __init__(
        self,
        *,
        create: typing.Optional[builtins.str] = None,
        delete: typing.Optional[builtins.str] = None,
        read: typing.Optional[builtins.str] = None,
        update: typing.Optional[builtins.str] = None,
    ) -> None:
        """
        :param create: 
        :param delete: 
        :param read: 
        :param update: 
        """
        self._values: typing.Dict[str, typing.Any] = {}
        if create is not None:
            self._values["create"] = create
        if delete is not None:
            self._values["delete"] = delete
        if read is not None:
            self._values["read"] = read
        if update is not None:
            self._values["update"] = update

    @builtins.property
    def create(self) -> typing.Optional[builtins.str]:
        result = self._values.get("create")
        return result

    @builtins.property
    def delete(self) -> typing.Optional[builtins.str]:
        result = self._values.get("delete")
        return result

    @builtins.property
    def read(self) -> typing.Optional[builtins.str]:
        result = self._values.get("read")
        return result

    @builtins.property
    def update(self) -> typing.Optional[builtins.str]:
        result = self._values.get("update")
        return result

    def __eq__(self, rhs: typing.Any) -> builtins.bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs: typing.Any) -> builtins.bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return "ApplicationInsightsApiKeyTimeouts(%s)" % ", ".join(
            k + "=" + repr(v) for k, v in self._values.items()
        )


@jsii.data_type(
    jsii_type="@cdktf/provider-azurerm.ApplicationInsightsConfig",
    jsii_struct_bases=[cdktf.TerraformMetaArguments],
    name_mapping={
        "count": "count",
        "depends_on": "dependsOn",
        "lifecycle": "lifecycle",
        "provider": "provider",
        "application_type": "applicationType",
        "location": "location",
        "name": "name",
        "resource_group_name": "resourceGroupName",
        "daily_data_cap_in_gb": "dailyDataCapInGb",
        "daily_data_cap_notifications_disabled": "dailyDataCapNotificationsDisabled",
        "retention_in_days": "retentionInDays",
        "sampling_percentage": "samplingPercentage",
        "tags": "tags",
        "timeouts": "timeouts",
    },
)
class ApplicationInsightsConfig(cdktf.TerraformMetaArguments):
    def __init__(
        self,
        *,
        count: typing.Optional[jsii.Number] = None,
        depends_on: typing.Optional[typing.List[cdktf.TerraformResource]] = None,
        lifecycle: typing.Optional[cdktf.TerraformResourceLifecycle] = None,
        provider: typing.Optional[cdktf.TerraformProvider] = None,
        application_type: builtins.str,
        location: builtins.str,
        name: builtins.str,
        resource_group_name: builtins.str,
        daily_data_cap_in_gb: typing.Optional[jsii.Number] = None,
        daily_data_cap_notifications_disabled: typing.Optional[builtins.bool] = None,
        retention_in_days: typing.Optional[jsii.Number] = None,
        sampling_percentage: typing.Optional[jsii.Number] = None,
        tags: typing.Optional[typing.Mapping[builtins.str, builtins.str]] = None,
        timeouts: typing.Optional["ApplicationInsightsTimeouts"] = None,
    ) -> None:
        """
        :param count: 
        :param depends_on: 
        :param lifecycle: 
        :param provider: 
        :param application_type: 
        :param location: 
        :param name: 
        :param resource_group_name: 
        :param daily_data_cap_in_gb: 
        :param daily_data_cap_notifications_disabled: 
        :param retention_in_days: 
        :param sampling_percentage: 
        :param tags: 
        :param timeouts: timeouts block.
        """
        if isinstance(lifecycle, dict):
            lifecycle = cdktf.TerraformResourceLifecycle(**lifecycle)
        if isinstance(timeouts, dict):
            timeouts = ApplicationInsightsTimeouts(**timeouts)
        self._values: typing.Dict[str, typing.Any] = {
            "application_type": application_type,
            "location": location,
            "name": name,
            "resource_group_name": resource_group_name,
        }
        if count is not None:
            self._values["count"] = count
        if depends_on is not None:
            self._values["depends_on"] = depends_on
        if lifecycle is not None:
            self._values["lifecycle"] = lifecycle
        if provider is not None:
            self._values["provider"] = provider
        if daily_data_cap_in_gb is not None:
            self._values["daily_data_cap_in_gb"] = daily_data_cap_in_gb
        if daily_data_cap_notifications_disabled is not None:
            self._values["daily_data_cap_notifications_disabled"] = daily_data_cap_notifications_disabled
        if retention_in_days is not None:
            self._values["retention_in_days"] = retention_in_days
        if sampling_percentage is not None:
            self._values["sampling_percentage"] = sampling_percentage
        if tags is not None:
            self._values["tags"] = tags
        if timeouts is not None:
            self._values["timeouts"] = timeouts

    @builtins.property
    def count(self) -> typing.Optional[jsii.Number]:
        """
        :stability: experimental
        """
        result = self._values.get("count")
        return result

    @builtins.property
    def depends_on(self) -> typing.Optional[typing.List[cdktf.TerraformResource]]:
        """
        :stability: experimental
        """
        result = self._values.get("depends_on")
        return result

    @builtins.property
    def lifecycle(self) -> typing.Optional[cdktf.TerraformResourceLifecycle]:
        """
        :stability: experimental
        """
        result = self._values.get("lifecycle")
        return result

    @builtins.property
    def provider(self) -> typing.Optional[cdktf.TerraformProvider]:
        """
        :stability: experimental
        """
        result = self._values.get("provider")
        return result

    @builtins.property
    def application_type(self) -> builtins.str:
        result = self._values.get("application_type")
        assert result is not None, "Required property 'application_type' is missing"
        return result

    @builtins.property
    def location(self) -> builtins.str:
        result = self._values.get("location")
        assert result is not None, "Required property 'location' is missing"
        return result

    @builtins.property
    def name(self) -> builtins.str:
        result = self._values.get("name")
        assert result is not None, "Required property 'name' is missing"
        return result

    @builtins.property
    def resource_group_name(self) -> builtins.str:
        result = self._values.get("resource_group_name")
        assert result is not None, "Required property 'resource_group_name' is missing"
        return result

    @builtins.property
    def daily_data_cap_in_gb(self) -> typing.Optional[jsii.Number]:
        result = self._values.get("daily_data_cap_in_gb")
        return result

    @builtins.property
    def daily_data_cap_notifications_disabled(self) -> typing.Optional[builtins.bool]:
        result = self._values.get("daily_data_cap_notifications_disabled")
        return result

    @builtins.property
    def retention_in_days(self) -> typing.Optional[jsii.Number]:
        result = self._values.get("retention_in_days")
        return result

    @builtins.property
    def sampling_percentage(self) -> typing.Optional[jsii.Number]:
        result = self._values.get("sampling_percentage")
        return result

    @builtins.property
    def tags(self) -> typing.Optional[typing.Mapping[builtins.str, builtins.str]]:
        result = self._values.get("tags")
        return result

    @builtins.property
    def timeouts(self) -> typing.Optional["ApplicationInsightsTimeouts"]:
        """timeouts block."""
        result = self._values.get("timeouts")
        return result

    def __eq__(self, rhs: typing.Any) -> builtins.bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs: typing.Any) -> builtins.bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return "ApplicationInsightsConfig(%s)" % ", ".join(
            k + "=" + repr(v) for k, v in self._values.items()
        )


@jsii.data_type(
    jsii_type="@cdktf/provider-azurerm.ApplicationInsightsTimeouts",
    jsii_struct_bases=[],
    name_mapping={
        "create": "create",
        "delete": "delete",
        "read": "read",
        "update": "update",
    },
)
class ApplicationInsightsTimeouts:
    def __init__(
        self,
        *,
        create: typing.Optional[builtins.str] = None,
        delete: typing.Optional[builtins.str] = None,
        read: typing.Optional[builtins.str] = None,
        update: typing.Optional[builtins.str] = None,
    ) -> None:
        """
        :param create: 
        :param delete: 
        :param read: 
        :param update: 
        """
        self._values: typing.Dict[str, typing.Any] = {}
        if create is not None:
            self._values["create"] = create
        if delete is not None:
            self._values["delete"] = delete
        if read is not None:
            self._values["read"] = read
        if update is not None:
            self._values["update"] = update

    @builtins.property
    def create(self) -> typing.Optional[builtins.str]:
        result = self._values.get("create")
        return result

    @builtins.property
    def delete(self) -> typing.Optional[builtins.str]:
        result = self._values.get("delete")
        return result

    @builtins.property
    def read(self) -> typing.Optional[builtins.str]:
        result = self._values.get("read")
        return result

    @builtins.property
    def update(self) -> typing.Optional[builtins.str]:
        result = self._values.get("update")
        return result

    def __eq__(self, rhs: typing.Any) -> builtins.bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs: typing.Any) -> builtins.bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return "ApplicationInsightsTimeouts(%s)" % ", ".join(
            k + "=" + repr(v) for k, v in self._values.items()
        )


class ApplicationInsightsWebTest(
    cdktf.TerraformResource,
    metaclass=jsii.JSIIMeta,
    jsii_type="@cdktf/provider-azurerm.ApplicationInsightsWebTest",
):
    def __init__(
        self,
        scope: constructs.Construct,
        id: builtins.str,
        *,
        application_insights_id: builtins.str,
        configuration: builtins.str,
        geo_locations: typing.List[builtins.str],
        kind: builtins.str,
        location: builtins.str,
        name: builtins.str,
        resource_group_name: builtins.str,
        description: typing.Optional[builtins.str] = None,
        enabled: typing.Optional[builtins.bool] = None,
        frequency: typing.Optional[jsii.Number] = None,
        retry_enabled: typing.Optional[builtins.bool] = None,
        tags: typing.Optional[typing.Mapping[builtins.str, builtins.str]] = None,
        timeout: typing.Optional[jsii.Number] = None,
        timeouts: typing.Optional["ApplicationInsightsWebTestTimeouts"] = None,
        count: typing.Optional[jsii.Number] = None,
        depends_on: typing.Optional[typing.List[cdktf.TerraformResource]] = None,
        lifecycle: typing.Optional[cdktf.TerraformResourceLifecycle] = None,
        provider: typing.Optional[cdktf.TerraformProvider] = None,
    ) -> None:
        """
        :param scope: -
        :param id: -
        :param application_insights_id: 
        :param configuration: 
        :param geo_locations: 
        :param kind: 
        :param location: 
        :param name: 
        :param resource_group_name: 
        :param description: 
        :param enabled: 
        :param frequency: 
        :param retry_enabled: 
        :param tags: 
        :param timeout: 
        :param timeouts: timeouts block.
        :param count: 
        :param depends_on: 
        :param lifecycle: 
        :param provider: 
        """
        config = ApplicationInsightsWebTestConfig(
            application_insights_id=application_insights_id,
            configuration=configuration,
            geo_locations=geo_locations,
            kind=kind,
            location=location,
            name=name,
            resource_group_name=resource_group_name,
            description=description,
            enabled=enabled,
            frequency=frequency,
            retry_enabled=retry_enabled,
            tags=tags,
            timeout=timeout,
            timeouts=timeouts,
            count=count,
            depends_on=depends_on,
            lifecycle=lifecycle,
            provider=provider,
        )

        jsii.create(ApplicationInsightsWebTest, self, [scope, id, config])

    @jsii.member(jsii_name="synthesizeAttributes")
    def _synthesize_attributes(self) -> typing.Mapping[builtins.str, typing.Any]:
        return jsii.invoke(self, "synthesizeAttributes", [])

    @builtins.property # type: ignore
    @jsii.member(jsii_name="syntheticMonitorId")
    def synthetic_monitor_id(self) -> builtins.str:
        return jsii.get(self, "syntheticMonitorId")

    @builtins.property # type: ignore
    @jsii.member(jsii_name="applicationInsightsId")
    def application_insights_id(self) -> builtins.str:
        return jsii.get(self, "applicationInsightsId")

    @application_insights_id.setter # type: ignore
    def application_insights_id(self, value: builtins.str) -> None:
        jsii.set(self, "applicationInsightsId", value)

    @builtins.property # type: ignore
    @jsii.member(jsii_name="configuration")
    def configuration(self) -> builtins.str:
        return jsii.get(self, "configuration")

    @configuration.setter # type: ignore
    def configuration(self, value: builtins.str) -> None:
        jsii.set(self, "configuration", value)

    @builtins.property # type: ignore
    @jsii.member(jsii_name="geoLocations")
    def geo_locations(self) -> typing.List[builtins.str]:
        return jsii.get(self, "geoLocations")

    @geo_locations.setter # type: ignore
    def geo_locations(self, value: typing.List[builtins.str]) -> None:
        jsii.set(self, "geoLocations", value)

    @builtins.property # type: ignore
    @jsii.member(jsii_name="kind")
    def kind(self) -> builtins.str:
        return jsii.get(self, "kind")

    @kind.setter # type: ignore
    def kind(self, value: builtins.str) -> None:
        jsii.set(self, "kind", value)

    @builtins.property # type: ignore
    @jsii.member(jsii_name="location")
    def location(self) -> builtins.str:
        return jsii.get(self, "location")

    @location.setter # type: ignore
    def location(self, value: builtins.str) -> None:
        jsii.set(self, "location", value)

    @builtins.property # type: ignore
    @jsii.member(jsii_name="name")
    def name(self) -> builtins.str:
        return jsii.get(self, "name")

    @name.setter # type: ignore
    def name(self, value: builtins.str) -> None:
        jsii.set(self, "name", value)

    @builtins.property # type: ignore
    @jsii.member(jsii_name="resourceGroupName")
    def resource_group_name(self) -> builtins.str:
        return jsii.get(self, "resourceGroupName")

    @resource_group_name.setter # type: ignore
    def resource_group_name(self, value: builtins.str) -> None:
        jsii.set(self, "resourceGroupName", value)

    @builtins.property # type: ignore
    @jsii.member(jsii_name="description")
    def description(self) -> typing.Optional[builtins.str]:
        return jsii.get(self, "description")

    @description.setter # type: ignore
    def description(self, value: typing.Optional[builtins.str]) -> None:
        jsii.set(self, "description", value)

    @builtins.property # type: ignore
    @jsii.member(jsii_name="enabled")
    def enabled(self) -> typing.Optional[builtins.bool]:
        return jsii.get(self, "enabled")

    @enabled.setter # type: ignore
    def enabled(self, value: typing.Optional[builtins.bool]) -> None:
        jsii.set(self, "enabled", value)

    @builtins.property # type: ignore
    @jsii.member(jsii_name="frequency")
    def frequency(self) -> typing.Optional[jsii.Number]:
        return jsii.get(self, "frequency")

    @frequency.setter # type: ignore
    def frequency(self, value: typing.Optional[jsii.Number]) -> None:
        jsii.set(self, "frequency", value)

    @builtins.property # type: ignore
    @jsii.member(jsii_name="id")
    def id(self) -> typing.Optional[builtins.str]:
        return jsii.get(self, "id")

    @id.setter # type: ignore
    def id(self, value: typing.Optional[builtins.str]) -> None:
        jsii.set(self, "id", value)

    @builtins.property # type: ignore
    @jsii.member(jsii_name="retryEnabled")
    def retry_enabled(self) -> typing.Optional[builtins.bool]:
        return jsii.get(self, "retryEnabled")

    @retry_enabled.setter # type: ignore
    def retry_enabled(self, value: typing.Optional[builtins.bool]) -> None:
        jsii.set(self, "retryEnabled", value)

    @builtins.property # type: ignore
    @jsii.member(jsii_name="tags")
    def tags(self) -> typing.Optional[typing.Mapping[builtins.str, builtins.str]]:
        return jsii.get(self, "tags")

    @tags.setter # type: ignore
    def tags(
        self,
        value: typing.Optional[typing.Mapping[builtins.str, builtins.str]],
    ) -> None:
        jsii.set(self, "tags", value)

    @builtins.property # type: ignore
    @jsii.member(jsii_name="timeout")
    def timeout(self) -> typing.Optional[jsii.Number]:
        return jsii.get(self, "timeout")

    @timeout.setter # type: ignore
    def timeout(self, value: typing.Optional[jsii.Number]) -> None:
        jsii.set(self, "timeout", value)

    @builtins.property # type: ignore
    @jsii.member(jsii_name="timeouts")
    def timeouts(self) -> typing.Optional["ApplicationInsightsWebTestTimeouts"]:
        return jsii.get(self, "timeouts")

    @timeouts.setter # type: ignore
    def timeouts(
        self,
        value: typing.Optional["ApplicationInsightsWebTestTimeouts"],
    ) -> None:
        jsii.set(self, "timeouts", value)


@jsii.data_type(
    jsii_type="@cdktf/provider-azurerm.ApplicationInsightsWebTestConfig",
    jsii_struct_bases=[cdktf.TerraformMetaArguments],
    name_mapping={
        "count": "count",
        "depends_on": "dependsOn",
        "lifecycle": "lifecycle",
        "provider": "provider",
        "application_insights_id": "applicationInsightsId",
        "configuration": "configuration",
        "geo_locations": "geoLocations",
        "kind": "kind",
        "location": "location",
        "name": "name",
        "resource_group_name": "resourceGroupName",
        "description": "description",
        "enabled": "enabled",
        "frequency": "frequency",
        "retry_enabled": "retryEnabled",
        "tags": "tags",
        "timeout": "timeout",
        "timeouts": "timeouts",
    },
)
class ApplicationInsightsWebTestConfig(cdktf.TerraformMetaArguments):
    def __init__(
        self,
        *,
        count: typing.Optional[jsii.Number] = None,
        depends_on: typing.Optional[typing.List[cdktf.TerraformResource]] = None,
        lifecycle: typing.Optional[cdktf.TerraformResourceLifecycle] = None,
        provider: typing.Optional[cdktf.TerraformProvider] = None,
        application_insights_id: builtins.str,
        configuration: builtins.str,
        geo_locations: typing.List[builtins.str],
        kind: builtins.str,
        location: builtins.str,
        name: builtins.str,
        resource_group_name: builtins.str,
        description: typing.Optional[builtins.str] = None,
        enabled: typing.Optional[builtins.bool] = None,
        frequency: typing.Optional[jsii.Number] = None,
        retry_enabled: typing.Optional[builtins.bool] = None,
        tags: typing.Optional[typing.Mapping[builtins.str, builtins.str]] = None,
        timeout: typing.Optional[jsii.Number] = None,
        timeouts: typing.Optional["ApplicationInsightsWebTestTimeouts"] = None,
    ) -> None:
        """
        :param count: 
        :param depends_on: 
        :param lifecycle: 
        :param provider: 
        :param application_insights_id: 
        :param configuration: 
        :param geo_locations: 
        :param kind: 
        :param location: 
        :param name: 
        :param resource_group_name: 
        :param description: 
        :param enabled: 
        :param frequency: 
        :param retry_enabled: 
        :param tags: 
        :param timeout: 
        :param timeouts: timeouts block.
        """
        if isinstance(lifecycle, dict):
            lifecycle = cdktf.TerraformResourceLifecycle(**lifecycle)
        if isinstance(timeouts, dict):
            timeouts = ApplicationInsightsWebTestTimeouts(**timeouts)
        self._values: typing.Dict[str, typing.Any] = {
            "application_insights_id": application_insights_id,
            "configuration": configuration,
            "geo_locations": geo_locations,
            "kind": kind,
            "location": location,
            "name": name,
            "resource_group_name": resource_group_name,
        }
        if count is not None:
            self._values["count"] = count
        if depends_on is not None:
            self._values["depends_on"] = depends_on
        if lifecycle is not None:
            self._values["lifecycle"] = lifecycle
        if provider is not None:
            self._values["provider"] = provider
        if description is not None:
            self._values["description"] = description
        if enabled is not None:
            self._values["enabled"] = enabled
        if frequency is not None:
            self._values["frequency"] = frequency
        if retry_enabled is not None:
            self._values["retry_enabled"] = retry_enabled
        if tags is not None:
            self._values["tags"] = tags
        if timeout is not None:
            self._values["timeout"] = timeout
        if timeouts is not None:
            self._values["timeouts"] = timeouts

    @builtins.property
    def count(self) -> typing.Optional[jsii.Number]:
        """
        :stability: experimental
        """
        result = self._values.get("count")
        return result

    @builtins.property
    def depends_on(self) -> typing.Optional[typing.List[cdktf.TerraformResource]]:
        """
        :stability: experimental
        """
        result = self._values.get("depends_on")
        return result

    @builtins.property
    def lifecycle(self) -> typing.Optional[cdktf.TerraformResourceLifecycle]:
        """
        :stability: experimental
        """
        result = self._values.get("lifecycle")
        return result

    @builtins.property
    def provider(self) -> typing.Optional[cdktf.TerraformProvider]:
        """
        :stability: experimental
        """
        result = self._values.get("provider")
        return result

    @builtins.property
    def application_insights_id(self) -> builtins.str:
        result = self._values.get("application_insights_id")
        assert result is not None, "Required property 'application_insights_id' is missing"
        return result

    @builtins.property
    def configuration(self) -> builtins.str:
        result = self._values.get("configuration")
        assert result is not None, "Required property 'configuration' is missing"
        return result

    @builtins.property
    def geo_locations(self) -> typing.List[builtins.str]:
        result = self._values.get("geo_locations")
        assert result is not None, "Required property 'geo_locations' is missing"
        return result

    @builtins.property
    def kind(self) -> builtins.str:
        result = self._values.get("kind")
        assert result is not None, "Required property 'kind' is missing"
        return result

    @builtins.property
    def location(self) -> builtins.str:
        result = self._values.get("location")
        assert result is not None, "Required property 'location' is missing"
        return result

    @builtins.property
    def name(self) -> builtins.str:
        result = self._values.get("name")
        assert result is not None, "Required property 'name' is missing"
        return result

    @builtins.property
    def resource_group_name(self) -> builtins.str:
        result = self._values.get("resource_group_name")
        assert result is not None, "Required property 'resource_group_name' is missing"
        return result

    @builtins.property
    def description(self) -> typing.Optional[builtins.str]:
        result = self._values.get("description")
        return result

    @builtins.property
    def enabled(self) -> typing.Optional[builtins.bool]:
        result = self._values.get("enabled")
        return result

    @builtins.property
    def frequency(self) -> typing.Optional[jsii.Number]:
        result = self._values.get("frequency")
        return result

    @builtins.property
    def retry_enabled(self) -> typing.Optional[builtins.bool]:
        result = self._values.get("retry_enabled")
        return result

    @builtins.property
    def tags(self) -> typing.Optional[typing.Mapping[builtins.str, builtins.str]]:
        result = self._values.get("tags")
        return result

    @builtins.property
    def timeout(self) -> typing.Optional[jsii.Number]:
        result = self._values.get("timeout")
        return result

    @builtins.property
    def timeouts(self) -> typing.Optional["ApplicationInsightsWebTestTimeouts"]:
        """timeouts block."""
        result = self._values.get("timeouts")
        return result

    def __eq__(self, rhs: typing.Any) -> builtins.bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs: typing.Any) -> builtins.bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return "ApplicationInsightsWebTestConfig(%s)" % ", ".join(
            k + "=" + repr(v) for k, v in self._values.items()
        )


@jsii.data_type(
    jsii_type="@cdktf/provider-azurerm.ApplicationInsightsWebTestTimeouts",
    jsii_struct_bases=[],
    name_mapping={
        "create": "create",
        "delete": "delete",
        "read": "read",
        "update": "update",
    },
)
class ApplicationInsightsWebTestTimeouts:
    def __init__(
        self,
        *,
        create: typing.Optional[builtins.str] = None,
        delete: typing.Optional[builtins.str] = None,
        read: typing.Optional[builtins.str] = None,
        update: typing.Optional[builtins.str] = None,
    ) -> None:
        """
        :param create: 
        :param delete: 
        :param read: 
        :param update: 
        """
        self._values: typing.Dict[str, typing.Any] = {}
        if create is not None:
            self._values["create"] = create
        if delete is not None:
            self._values["delete"] = delete
        if read is not None:
            self._values["read"] = read
        if update is not None:
            self._values["update"] = update

    @builtins.property
    def create(self) -> typing.Optional[builtins.str]:
        result = self._values.get("create")
        return result

    @builtins.property
    def delete(self) -> typing.Optional[builtins.str]:
        result = self._values.get("delete")
        return result

    @builtins.property
    def read(self) -> typing.Optional[builtins.str]:
        result = self._values.get("read")
        return result

    @builtins.property
    def update(self) -> typing.Optional[builtins.str]:
        result = self._values.get("update")
        return result

    def __eq__(self, rhs: typing.Any) -> builtins.bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs: typing.Any) -> builtins.bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return "ApplicationInsightsWebTestTimeouts(%s)" % ", ".join(
            k + "=" + repr(v) for k, v in self._values.items()
        )


class ApplicationSecurityGroup(
    cdktf.TerraformResource,
    metaclass=jsii.JSIIMeta,
    jsii_type="@cdktf/provider-azurerm.ApplicationSecurityGroup",
):
    def __init__(
        self,
        scope: constructs.Construct,
        id: builtins.str,
        *,
        location: builtins.str,
        name: builtins.str,
        resource_group_name: builtins.str,
        tags: typing.Optional[typing.Mapping[builtins.str, builtins.str]] = None,
        timeouts: typing.Optional["ApplicationSecurityGroupTimeouts"] = None,
        count: typing.Optional[jsii.Number] = None,
        depends_on: typing.Optional[typing.List[cdktf.TerraformResource]] = None,
        lifecycle: typing.Optional[cdktf.TerraformResourceLifecycle] = None,
        provider: typing.Optional[cdktf.TerraformProvider] = None,
    ) -> None:
        """
        :param scope: -
        :param id: -
        :param location: 
        :param name: 
        :param resource_group_name: 
        :param tags: 
        :param timeouts: timeouts block.
        :param count: 
        :param depends_on: 
        :param lifecycle: 
        :param provider: 
        """
        config = ApplicationSecurityGroupConfig(
            location=location,
            name=name,
            resource_group_name=resource_group_name,
            tags=tags,
            timeouts=timeouts,
            count=count,
            depends_on=depends_on,
            lifecycle=lifecycle,
            provider=provider,
        )

        jsii.create(ApplicationSecurityGroup, self, [scope, id, config])

    @jsii.member(jsii_name="synthesizeAttributes")
    def _synthesize_attributes(self) -> typing.Mapping[builtins.str, typing.Any]:
        return jsii.invoke(self, "synthesizeAttributes", [])

    @builtins.property # type: ignore
    @jsii.member(jsii_name="location")
    def location(self) -> builtins.str:
        return jsii.get(self, "location")

    @location.setter # type: ignore
    def location(self, value: builtins.str) -> None:
        jsii.set(self, "location", value)

    @builtins.property # type: ignore
    @jsii.member(jsii_name="name")
    def name(self) -> builtins.str:
        return jsii.get(self, "name")

    @name.setter # type: ignore
    def name(self, value: builtins.str) -> None:
        jsii.set(self, "name", value)

    @builtins.property # type: ignore
    @jsii.member(jsii_name="resourceGroupName")
    def resource_group_name(self) -> builtins.str:
        return jsii.get(self, "resourceGroupName")

    @resource_group_name.setter # type: ignore
    def resource_group_name(self, value: builtins.str) -> None:
        jsii.set(self, "resourceGroupName", value)

    @builtins.property # type: ignore
    @jsii.member(jsii_name="id")
    def id(self) -> typing.Optional[builtins.str]:
        return jsii.get(self, "id")

    @id.setter # type: ignore
    def id(self, value: typing.Optional[builtins.str]) -> None:
        jsii.set(self, "id", value)

    @builtins.property # type: ignore
    @jsii.member(jsii_name="tags")
    def tags(self) -> typing.Optional[typing.Mapping[builtins.str, builtins.str]]:
        return jsii.get(self, "tags")

    @tags.setter # type: ignore
    def tags(
        self,
        value: typing.Optional[typing.Mapping[builtins.str, builtins.str]],
    ) -> None:
        jsii.set(self, "tags", value)

    @builtins.property # type: ignore
    @jsii.member(jsii_name="timeouts")
    def timeouts(self) -> typing.Optional["ApplicationSecurityGroupTimeouts"]:
        return jsii.get(self, "timeouts")

    @timeouts.setter # type: ignore
    def timeouts(
        self,
        value: typing.Optional["ApplicationSecurityGroupTimeouts"],
    ) -> None:
        jsii.set(self, "timeouts", value)


@jsii.data_type(
    jsii_type="@cdktf/provider-azurerm.ApplicationSecurityGroupConfig",
    jsii_struct_bases=[cdktf.TerraformMetaArguments],
    name_mapping={
        "count": "count",
        "depends_on": "dependsOn",
        "lifecycle": "lifecycle",
        "provider": "provider",
        "location": "location",
        "name": "name",
        "resource_group_name": "resourceGroupName",
        "tags": "tags",
        "timeouts": "timeouts",
    },
)
class ApplicationSecurityGroupConfig(cdktf.TerraformMetaArguments):
    def __init__(
        self,
        *,
        count: typing.Optional[jsii.Number] = None,
        depends_on: typing.Optional[typing.List[cdktf.TerraformResource]] = None,
        lifecycle: typing.Optional[cdktf.TerraformResourceLifecycle] = None,
        provider: typing.Optional[cdktf.TerraformProvider] = None,
        location: builtins.str,
        name: builtins.str,
        resource_group_name: builtins.str,
        tags: typing.Optional[typing.Mapping[builtins.str, builtins.str]] = None,
        timeouts: typing.Optional["ApplicationSecurityGroupTimeouts"] = None,
    ) -> None:
        """
        :param count: 
        :param depends_on: 
        :param lifecycle: 
        :param provider: 
        :param location: 
        :param name: 
        :param resource_group_name: 
        :param tags: 
        :param timeouts: timeouts block.
        """
        if isinstance(lifecycle, dict):
            lifecycle = cdktf.TerraformResourceLifecycle(**lifecycle)
        if isinstance(timeouts, dict):
            timeouts = ApplicationSecurityGroupTimeouts(**timeouts)
        self._values: typing.Dict[str, typing.Any] = {
            "location": location,
            "name": name,
            "resource_group_name": resource_group_name,
        }
        if count is not None:
            self._values["count"] = count
        if depends_on is not None:
            self._values["depends_on"] = depends_on
        if lifecycle is not None:
            self._values["lifecycle"] = lifecycle
        if provider is not None:
            self._values["provider"] = provider
        if tags is not None:
            self._values["tags"] = tags
        if timeouts is not None:
            self._values["timeouts"] = timeouts

    @builtins.property
    def count(self) -> typing.Optional[jsii.Number]:
        """
        :stability: experimental
        """
        result = self._values.get("count")
        return result

    @builtins.property
    def depends_on(self) -> typing.Optional[typing.List[cdktf.TerraformResource]]:
        """
        :stability: experimental
        """
        result = self._values.get("depends_on")
        return result

    @builtins.property
    def lifecycle(self) -> typing.Optional[cdktf.TerraformResourceLifecycle]:
        """
        :stability: experimental
        """
        result = self._values.get("lifecycle")
        return result

    @builtins.property
    def provider(self) -> typing.Optional[cdktf.TerraformProvider]:
        """
        :stability: experimental
        """
        result = self._values.get("provider")
        return result

    @builtins.property
    def location(self) -> builtins.str:
        result = self._values.get("location")
        assert result is not None, "Required property 'location' is missing"
        return result

    @builtins.property
    def name(self) -> builtins.str:
        result = self._values.get("name")
        assert result is not None, "Required property 'name' is missing"
        return result

    @builtins.property
    def resource_group_name(self) -> builtins.str:
        result = self._values.get("resource_group_name")
        assert result is not None, "Required property 'resource_group_name' is missing"
        return result

    @builtins.property
    def tags(self) -> typing.Optional[typing.Mapping[builtins.str, builtins.str]]:
        result = self._values.get("tags")
        return result

    @builtins.property
    def timeouts(self) -> typing.Optional["ApplicationSecurityGroupTimeouts"]:
        """timeouts block."""
        result = self._values.get("timeouts")
        return result

    def __eq__(self, rhs: typing.Any) -> builtins.bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs: typing.Any) -> builtins.bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return "ApplicationSecurityGroupConfig(%s)" % ", ".join(
            k + "=" + repr(v) for k, v in self._values.items()
        )


@jsii.data_type(
    jsii_type="@cdktf/provider-azurerm.ApplicationSecurityGroupTimeouts",
    jsii_struct_bases=[],
    name_mapping={
        "create": "create",
        "delete": "delete",
        "read": "read",
        "update": "update",
    },
)
class ApplicationSecurityGroupTimeouts:
    def __init__(
        self,
        *,
        create: typing.Optional[builtins.str] = None,
        delete: typing.Optional[builtins.str] = None,
        read: typing.Optional[builtins.str] = None,
        update: typing.Optional[builtins.str] = None,
    ) -> None:
        """
        :param create: 
        :param delete: 
        :param read: 
        :param update: 
        """
        self._values: typing.Dict[str, typing.Any] = {}
        if create is not None:
            self._values["create"] = create
        if delete is not None:
            self._values["delete"] = delete
        if read is not None:
            self._values["read"] = read
        if update is not None:
            self._values["update"] = update

    @builtins.property
    def create(self) -> typing.Optional[builtins.str]:
        result = self._values.get("create")
        return result

    @builtins.property
    def delete(self) -> typing.Optional[builtins.str]:
        result = self._values.get("delete")
        return result

    @builtins.property
    def read(self) -> typing.Optional[builtins.str]:
        result = self._values.get("read")
        return result

    @builtins.property
    def update(self) -> typing.Optional[builtins.str]:
        result = self._values.get("update")
        return result

    def __eq__(self, rhs: typing.Any) -> builtins.bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs: typing.Any) -> builtins.bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return "ApplicationSecurityGroupTimeouts(%s)" % ", ".join(
            k + "=" + repr(v) for k, v in self._values.items()
        )


class AutomationAccount(
    cdktf.TerraformResource,
    metaclass=jsii.JSIIMeta,
    jsii_type="@cdktf/provider-azurerm.AutomationAccount",
):
    def __init__(
        self,
        scope: constructs.Construct,
        id: builtins.str,
        *,
        location: builtins.str,
        name: builtins.str,
        resource_group_name: builtins.str,
        sku_name: builtins.str,
        tags: typing.Optional[typing.Mapping[builtins.str, builtins.str]] = None,
        timeouts: typing.Optional["AutomationAccountTimeouts"] = None,
        count: typing.Optional[jsii.Number] = None,
        depends_on: typing.Optional[typing.List[cdktf.TerraformResource]] = None,
        lifecycle: typing.Optional[cdktf.TerraformResourceLifecycle] = None,
        provider: typing.Optional[cdktf.TerraformProvider] = None,
    ) -> None:
        """
        :param scope: -
        :param id: -
        :param location: 
        :param name: 
        :param resource_group_name: 
        :param sku_name: 
        :param tags: 
        :param timeouts: timeouts block.
        :param count: 
        :param depends_on: 
        :param lifecycle: 
        :param provider: 
        """
        config = AutomationAccountConfig(
            location=location,
            name=name,
            resource_group_name=resource_group_name,
            sku_name=sku_name,
            tags=tags,
            timeouts=timeouts,
            count=count,
            depends_on=depends_on,
            lifecycle=lifecycle,
            provider=provider,
        )

        jsii.create(AutomationAccount, self, [scope, id, config])

    @jsii.member(jsii_name="synthesizeAttributes")
    def _synthesize_attributes(self) -> typing.Mapping[builtins.str, typing.Any]:
        return jsii.invoke(self, "synthesizeAttributes", [])

    @builtins.property # type: ignore
    @jsii.member(jsii_name="dscPrimaryAccessKey")
    def dsc_primary_access_key(self) -> builtins.str:
        return jsii.get(self, "dscPrimaryAccessKey")

    @builtins.property # type: ignore
    @jsii.member(jsii_name="dscSecondaryAccessKey")
    def dsc_secondary_access_key(self) -> builtins.str:
        return jsii.get(self, "dscSecondaryAccessKey")

    @builtins.property # type: ignore
    @jsii.member(jsii_name="dscServerEndpoint")
    def dsc_server_endpoint(self) -> builtins.str:
        return jsii.get(self, "dscServerEndpoint")

    @builtins.property # type: ignore
    @jsii.member(jsii_name="location")
    def location(self) -> builtins.str:
        return jsii.get(self, "location")

    @location.setter # type: ignore
    def location(self, value: builtins.str) -> None:
        jsii.set(self, "location", value)

    @builtins.property # type: ignore
    @jsii.member(jsii_name="name")
    def name(self) -> builtins.str:
        return jsii.get(self, "name")

    @name.setter # type: ignore
    def name(self, value: builtins.str) -> None:
        jsii.set(self, "name", value)

    @builtins.property # type: ignore
    @jsii.member(jsii_name="resourceGroupName")
    def resource_group_name(self) -> builtins.str:
        return jsii.get(self, "resourceGroupName")

    @resource_group_name.setter # type: ignore
    def resource_group_name(self, value: builtins.str) -> None:
        jsii.set(self, "resourceGroupName", value)

    @builtins.property # type: ignore
    @jsii.member(jsii_name="skuName")
    def sku_name(self) -> builtins.str:
        return jsii.get(self, "skuName")

    @sku_name.setter # type: ignore
    def sku_name(self, value: builtins.str) -> None:
        jsii.set(self, "skuName", value)

    @builtins.property # type: ignore
    @jsii.member(jsii_name="id")
    def id(self) -> typing.Optional[builtins.str]:
        return jsii.get(self, "id")

    @id.setter # type: ignore
    def id(self, value: typing.Optional[builtins.str]) -> None:
        jsii.set(self, "id", value)

    @builtins.property # type: ignore
    @jsii.member(jsii_name="tags")
    def tags(self) -> typing.Optional[typing.Mapping[builtins.str, builtins.str]]:
        return jsii.get(self, "tags")

    @tags.setter # type: ignore
    def tags(
        self,
        value: typing.Optional[typing.Mapping[builtins.str, builtins.str]],
    ) -> None:
        jsii.set(self, "tags", value)

    @builtins.property # type: ignore
    @jsii.member(jsii_name="timeouts")
    def timeouts(self) -> typing.Optional["AutomationAccountTimeouts"]:
        return jsii.get(self, "timeouts")

    @timeouts.setter # type: ignore
    def timeouts(self, value: typing.Optional["AutomationAccountTimeouts"]) -> None:
        jsii.set(self, "timeouts", value)


@jsii.data_type(
    jsii_type="@cdktf/provider-azurerm.AutomationAccountConfig",
    jsii_struct_bases=[cdktf.TerraformMetaArguments],
    name_mapping={
        "count": "count",
        "depends_on": "dependsOn",
        "lifecycle": "lifecycle",
        "provider": "provider",
        "location": "location",
        "name": "name",
        "resource_group_name": "resourceGroupName",
        "sku_name": "skuName",
        "tags": "tags",
        "timeouts": "timeouts",
    },
)
class AutomationAccountConfig(cdktf.TerraformMetaArguments):
    def __init__(
        self,
        *,
        count: typing.Optional[jsii.Number] = None,
        depends_on: typing.Optional[typing.List[cdktf.TerraformResource]] = None,
        lifecycle: typing.Optional[cdktf.TerraformResourceLifecycle] = None,
        provider: typing.Optional[cdktf.TerraformProvider] = None,
        location: builtins.str,
        name: builtins.str,
        resource_group_name: builtins.str,
        sku_name: builtins.str,
        tags: typing.Optional[typing.Mapping[builtins.str, builtins.str]] = None,
        timeouts: typing.Optional["AutomationAccountTimeouts"] = None,
    ) -> None:
        """
        :param count: 
        :param depends_on: 
        :param lifecycle: 
        :param provider: 
        :param location: 
        :param name: 
        :param resource_group_name: 
        :param sku_name: 
        :param tags: 
        :param timeouts: timeouts block.
        """
        if isinstance(lifecycle, dict):
            lifecycle = cdktf.TerraformResourceLifecycle(**lifecycle)
        if isinstance(timeouts, dict):
            timeouts = AutomationAccountTimeouts(**timeouts)
        self._values: typing.Dict[str, typing.Any] = {
            "location": location,
            "name": name,
            "resource_group_name": resource_group_name,
            "sku_name": sku_name,
        }
        if count is not None:
            self._values["count"] = count
        if depends_on is not None:
            self._values["depends_on"] = depends_on
        if lifecycle is not None:
            self._values["lifecycle"] = lifecycle
        if provider is not None:
            self._values["provider"] = provider
        if tags is not None:
            self._values["tags"] = tags
        if timeouts is not None:
            self._values["timeouts"] = timeouts

    @builtins.property
    def count(self) -> typing.Optional[jsii.Number]:
        """
        :stability: experimental
        """
        result = self._values.get("count")
        return result

    @builtins.property
    def depends_on(self) -> typing.Optional[typing.List[cdktf.TerraformResource]]:
        """
        :stability: experimental
        """
        result = self._values.get("depends_on")
        return result

    @builtins.property
    def lifecycle(self) -> typing.Optional[cdktf.TerraformResourceLifecycle]:
        """
        :stability: experimental
        """
        result = self._values.get("lifecycle")
        return result

    @builtins.property
    def provider(self) -> typing.Optional[cdktf.TerraformProvider]:
        """
        :stability: experimental
        """
        result = self._values.get("provider")
        return result

    @builtins.property
    def location(self) -> builtins.str:
        result = self._values.get("location")
        assert result is not None, "Required property 'location' is missing"
        return result

    @builtins.property
    def name(self) -> builtins.str:
        result = self._values.get("name")
        assert result is not None, "Required property 'name' is missing"
        return result

    @builtins.property
    def resource_group_name(self) -> builtins.str:
        result = self._values.get("resource_group_name")
        assert result is not None, "Required property 'resource_group_name' is missing"
        return result

    @builtins.property
    def sku_name(self) -> builtins.str:
        result = self._values.get("sku_name")
        assert result is not None, "Required property 'sku_name' is missing"
        return result

    @builtins.property
    def tags(self) -> typing.Optional[typing.Mapping[builtins.str, builtins.str]]:
        result = self._values.get("tags")
        return result

    @builtins.property
    def timeouts(self) -> typing.Optional["AutomationAccountTimeouts"]:
        """timeouts block."""
        result = self._values.get("timeouts")
        return result

    def __eq__(self, rhs: typing.Any) -> builtins.bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs: typing.Any) -> builtins.bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return "AutomationAccountConfig(%s)" % ", ".join(
            k + "=" + repr(v) for k, v in self._values.items()
        )


@jsii.data_type(
    jsii_type="@cdktf/provider-azurerm.AutomationAccountTimeouts",
    jsii_struct_bases=[],
    name_mapping={
        "create": "create",
        "delete": "delete",
        "read": "read",
        "update": "update",
    },
)
class AutomationAccountTimeouts:
    def __init__(
        self,
        *,
        create: typing.Optional[builtins.str] = None,
        delete: typing.Optional[builtins.str] = None,
        read: typing.Optional[builtins.str] = None,
        update: typing.Optional[builtins.str] = None,
    ) -> None:
        """
        :param create: 
        :param delete: 
        :param read: 
        :param update: 
        """
        self._values: typing.Dict[str, typing.Any] = {}
        if create is not None:
            self._values["create"] = create
        if delete is not None:
            self._values["delete"] = delete
        if read is not None:
            self._values["read"] = read
        if update is not None:
            self._values["update"] = update

    @builtins.property
    def create(self) -> typing.Optional[builtins.str]:
        result = self._values.get("create")
        return result

    @builtins.property
    def delete(self) -> typing.Optional[builtins.str]:
        result = self._values.get("delete")
        return result

    @builtins.property
    def read(self) -> typing.Optional[builtins.str]:
        result = self._values.get("read")
        return result

    @builtins.property
    def update(self) -> typing.Optional[builtins.str]:
        result = self._values.get("update")
        return result

    def __eq__(self, rhs: typing.Any) -> builtins.bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs: typing.Any) -> builtins.bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return "AutomationAccountTimeouts(%s)" % ", ".join(
            k + "=" + repr(v) for k, v in self._values.items()
        )


class AutomationCertificate(
    cdktf.TerraformResource,
    metaclass=jsii.JSIIMeta,
    jsii_type="@cdktf/provider-azurerm.AutomationCertificate",
):
    def __init__(
        self,
        scope: constructs.Construct,
        id: builtins.str,
        *,
        automation_account_name: builtins.str,
        base64: builtins.str,
        name: builtins.str,
        resource_group_name: builtins.str,
        description: typing.Optional[builtins.str] = None,
        timeouts: typing.Optional["AutomationCertificateTimeouts"] = None,
        count: typing.Optional[jsii.Number] = None,
        depends_on: typing.Optional[typing.List[cdktf.TerraformResource]] = None,
        lifecycle: typing.Optional[cdktf.TerraformResourceLifecycle] = None,
        provider: typing.Optional[cdktf.TerraformProvider] = None,
    ) -> None:
        """
        :param scope: -
        :param id: -
        :param automation_account_name: 
        :param base64: 
        :param name: 
        :param resource_group_name: 
        :param description: 
        :param timeouts: timeouts block.
        :param count: 
        :param depends_on: 
        :param lifecycle: 
        :param provider: 
        """
        config = AutomationCertificateConfig(
            automation_account_name=automation_account_name,
            base64=base64,
            name=name,
            resource_group_name=resource_group_name,
            description=description,
            timeouts=timeouts,
            count=count,
            depends_on=depends_on,
            lifecycle=lifecycle,
            provider=provider,
        )

        jsii.create(AutomationCertificate, self, [scope, id, config])

    @jsii.member(jsii_name="synthesizeAttributes")
    def _synthesize_attributes(self) -> typing.Mapping[builtins.str, typing.Any]:
        return jsii.invoke(self, "synthesizeAttributes", [])

    @builtins.property # type: ignore
    @jsii.member(jsii_name="exportable")
    def exportable(self) -> builtins.bool:
        return jsii.get(self, "exportable")

    @builtins.property # type: ignore
    @jsii.member(jsii_name="thumbprint")
    def thumbprint(self) -> builtins.str:
        return jsii.get(self, "thumbprint")

    @builtins.property # type: ignore
    @jsii.member(jsii_name="automationAccountName")
    def automation_account_name(self) -> builtins.str:
        return jsii.get(self, "automationAccountName")

    @automation_account_name.setter # type: ignore
    def automation_account_name(self, value: builtins.str) -> None:
        jsii.set(self, "automationAccountName", value)

    @builtins.property # type: ignore
    @jsii.member(jsii_name="base64")
    def base64(self) -> builtins.str:
        return jsii.get(self, "base64")

    @base64.setter # type: ignore
    def base64(self, value: builtins.str) -> None:
        jsii.set(self, "base64", value)

    @builtins.property # type: ignore
    @jsii.member(jsii_name="name")
    def name(self) -> builtins.str:
        return jsii.get(self, "name")

    @name.setter # type: ignore
    def name(self, value: builtins.str) -> None:
        jsii.set(self, "name", value)

    @builtins.property # type: ignore
    @jsii.member(jsii_name="resourceGroupName")
    def resource_group_name(self) -> builtins.str:
        return jsii.get(self, "resourceGroupName")

    @resource_group_name.setter # type: ignore
    def resource_group_name(self, value: builtins.str) -> None:
        jsii.set(self, "resourceGroupName", value)

    @builtins.property # type: ignore
    @jsii.member(jsii_name="description")
    def description(self) -> typing.Optional[builtins.str]:
        return jsii.get(self, "description")

    @description.setter # type: ignore
    def description(self, value: typing.Optional[builtins.str]) -> None:
        jsii.set(self, "description", value)

    @builtins.property # type: ignore
    @jsii.member(jsii_name="id")
    def id(self) -> typing.Optional[builtins.str]:
        return jsii.get(self, "id")

    @id.setter # type: ignore
    def id(self, value: typing.Optional[builtins.str]) -> None:
        jsii.set(self, "id", value)

    @builtins.property # type: ignore
    @jsii.member(jsii_name="timeouts")
    def timeouts(self) -> typing.Optional["AutomationCertificateTimeouts"]:
        return jsii.get(self, "timeouts")

    @timeouts.setter # type: ignore
    def timeouts(self, value: typing.Optional["AutomationCertificateTimeouts"]) -> None:
        jsii.set(self, "timeouts", value)


@jsii.data_type(
    jsii_type="@cdktf/provider-azurerm.AutomationCertificateConfig",
    jsii_struct_bases=[cdktf.TerraformMetaArguments],
    name_mapping={
        "count": "count",
        "depends_on": "dependsOn",
        "lifecycle": "lifecycle",
        "provider": "provider",
        "automation_account_name": "automationAccountName",
        "base64": "base64",
        "name": "name",
        "resource_group_name": "resourceGroupName",
        "description": "description",
        "timeouts": "timeouts",
    },
)
class AutomationCertificateConfig(cdktf.TerraformMetaArguments):
    def __init__(
        self,
        *,
        count: typing.Optional[jsii.Number] = None,
        depends_on: typing.Optional[typing.List[cdktf.TerraformResource]] = None,
        lifecycle: typing.Optional[cdktf.TerraformResourceLifecycle] = None,
        provider: typing.Optional[cdktf.TerraformProvider] = None,
        automation_account_name: builtins.str,
        base64: builtins.str,
        name: builtins.str,
        resource_group_name: builtins.str,
        description: typing.Optional[builtins.str] = None,
        timeouts: typing.Optional["AutomationCertificateTimeouts"] = None,
    ) -> None:
        """
        :param count: 
        :param depends_on: 
        :param lifecycle: 
        :param provider: 
        :param automation_account_name: 
        :param base64: 
        :param name: 
        :param resource_group_name: 
        :param description: 
        :param timeouts: timeouts block.
        """
        if isinstance(lifecycle, dict):
            lifecycle = cdktf.TerraformResourceLifecycle(**lifecycle)
        if isinstance(timeouts, dict):
            timeouts = AutomationCertificateTimeouts(**timeouts)
        self._values: typing.Dict[str, typing.Any] = {
            "automation_account_name": automation_account_name,
            "base64": base64,
            "name": name,
            "resource_group_name": resource_group_name,
        }
        if count is not None:
            self._values["count"] = count
        if depends_on is not None:
            self._values["depends_on"] = depends_on
        if lifecycle is not None:
            self._values["lifecycle"] = lifecycle
        if provider is not None:
            self._values["provider"] = provider
        if description is not None:
            self._values["description"] = description
        if timeouts is not None:
            self._values["timeouts"] = timeouts

    @builtins.property
    def count(self) -> typing.Optional[jsii.Number]:
        """
        :stability: experimental
        """
        result = self._values.get("count")
        return result

    @builtins.property
    def depends_on(self) -> typing.Optional[typing.List[cdktf.TerraformResource]]:
        """
        :stability: experimental
        """
        result = self._values.get("depends_on")
        return result

    @builtins.property
    def lifecycle(self) -> typing.Optional[cdktf.TerraformResourceLifecycle]:
        """
        :stability: experimental
        """
        result = self._values.get("lifecycle")
        return result

    @builtins.property
    def provider(self) -> typing.Optional[cdktf.TerraformProvider]:
        """
        :stability: experimental
        """
        result = self._values.get("provider")
        return result

    @builtins.property
    def automation_account_name(self) -> builtins.str:
        result = self._values.get("automation_account_name")
        assert result is not None, "Required property 'automation_account_name' is missing"
        return result

    @builtins.property
    def base64(self) -> builtins.str:
        result = self._values.get("base64")
        assert result is not None, "Required property 'base64' is missing"
        return result

    @builtins.property
    def name(self) -> builtins.str:
        result = self._values.get("name")
        assert result is not None, "Required property 'name' is missing"
        return result

    @builtins.property
    def resource_group_name(self) -> builtins.str:
        result = self._values.get("resource_group_name")
        assert result is not None, "Required property 'resource_group_name' is missing"
        return result

    @builtins.property
    def description(self) -> typing.Optional[builtins.str]:
        result = self._values.get("description")
        return result

    @builtins.property
    def timeouts(self) -> typing.Optional["AutomationCertificateTimeouts"]:
        """timeouts block."""
        result = self._values.get("timeouts")
        return result

    def __eq__(self, rhs: typing.Any) -> builtins.bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs: typing.Any) -> builtins.bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return "AutomationCertificateConfig(%s)" % ", ".join(
            k + "=" + repr(v) for k, v in self._values.items()
        )


@jsii.data_type(
    jsii_type="@cdktf/provider-azurerm.AutomationCertificateTimeouts",
    jsii_struct_bases=[],
    name_mapping={
        "create": "create",
        "delete": "delete",
        "read": "read",
        "update": "update",
    },
)
class AutomationCertificateTimeouts:
    def __init__(
        self,
        *,
        create: typing.Optional[builtins.str] = None,
        delete: typing.Optional[builtins.str] = None,
        read: typing.Optional[builtins.str] = None,
        update: typing.Optional[builtins.str] = None,
    ) -> None:
        """
        :param create: 
        :param delete: 
        :param read: 
        :param update: 
        """
        self._values: typing.Dict[str, typing.Any] = {}
        if create is not None:
            self._values["create"] = create
        if delete is not None:
            self._values["delete"] = delete
        if read is not None:
            self._values["read"] = read
        if update is not None:
            self._values["update"] = update

    @builtins.property
    def create(self) -> typing.Optional[builtins.str]:
        result = self._values.get("create")
        return result

    @builtins.property
    def delete(self) -> typing.Optional[builtins.str]:
        result = self._values.get("delete")
        return result

    @builtins.property
    def read(self) -> typing.Optional[builtins.str]:
        result = self._values.get("read")
        return result

    @builtins.property
    def update(self) -> typing.Optional[builtins.str]:
        result = self._values.get("update")
        return result

    def __eq__(self, rhs: typing.Any) -> builtins.bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs: typing.Any) -> builtins.bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return "AutomationCertificateTimeouts(%s)" % ", ".join(
            k + "=" + repr(v) for k, v in self._values.items()
        )


class AutomationCredential(
    cdktf.TerraformResource,
    metaclass=jsii.JSIIMeta,
    jsii_type="@cdktf/provider-azurerm.AutomationCredential",
):
    def __init__(
        self,
        scope: constructs.Construct,
        id: builtins.str,
        *,
        automation_account_name: builtins.str,
        name: builtins.str,
        password: builtins.str,
        resource_group_name: builtins.str,
        username: builtins.str,
        description: typing.Optional[builtins.str] = None,
        timeouts: typing.Optional["AutomationCredentialTimeouts"] = None,
        count: typing.Optional[jsii.Number] = None,
        depends_on: typing.Optional[typing.List[cdktf.TerraformResource]] = None,
        lifecycle: typing.Optional[cdktf.TerraformResourceLifecycle] = None,
        provider: typing.Optional[cdktf.TerraformProvider] = None,
    ) -> None:
        """
        :param scope: -
        :param id: -
        :param automation_account_name: 
        :param name: 
        :param password: 
        :param resource_group_name: 
        :param username: 
        :param description: 
        :param timeouts: timeouts block.
        :param count: 
        :param depends_on: 
        :param lifecycle: 
        :param provider: 
        """
        config = AutomationCredentialConfig(
            automation_account_name=automation_account_name,
            name=name,
            password=password,
            resource_group_name=resource_group_name,
            username=username,
            description=description,
            timeouts=timeouts,
            count=count,
            depends_on=depends_on,
            lifecycle=lifecycle,
            provider=provider,
        )

        jsii.create(AutomationCredential, self, [scope, id, config])

    @jsii.member(jsii_name="synthesizeAttributes")
    def _synthesize_attributes(self) -> typing.Mapping[builtins.str, typing.Any]:
        return jsii.invoke(self, "synthesizeAttributes", [])

    @builtins.property # type: ignore
    @jsii.member(jsii_name="automationAccountName")
    def automation_account_name(self) -> builtins.str:
        return jsii.get(self, "automationAccountName")

    @automation_account_name.setter # type: ignore
    def automation_account_name(self, value: builtins.str) -> None:
        jsii.set(self, "automationAccountName", value)

    @builtins.property # type: ignore
    @jsii.member(jsii_name="name")
    def name(self) -> builtins.str:
        return jsii.get(self, "name")

    @name.setter # type: ignore
    def name(self, value: builtins.str) -> None:
        jsii.set(self, "name", value)

    @builtins.property # type: ignore
    @jsii.member(jsii_name="password")
    def password(self) -> builtins.str:
        return jsii.get(self, "password")

    @password.setter # type: ignore
    def password(self, value: builtins.str) -> None:
        jsii.set(self, "password", value)

    @builtins.property # type: ignore
    @jsii.member(jsii_name="resourceGroupName")
    def resource_group_name(self) -> builtins.str:
        return jsii.get(self, "resourceGroupName")

    @resource_group_name.setter # type: ignore
    def resource_group_name(self, value: builtins.str) -> None:
        jsii.set(self, "resourceGroupName", value)

    @builtins.property # type: ignore
    @jsii.member(jsii_name="username")
    def username(self) -> builtins.str:
        return jsii.get(self, "username")

    @username.setter # type: ignore
    def username(self, value: builtins.str) -> None:
        jsii.set(self, "username", value)

    @builtins.property # type: ignore
    @jsii.member(jsii_name="description")
    def description(self) -> typing.Optional[builtins.str]:
        return jsii.get(self, "description")

    @description.setter # type: ignore
    def description(self, value: typing.Optional[builtins.str]) -> None:
        jsii.set(self, "description", value)

    @builtins.property # type: ignore
    @jsii.member(jsii_name="id")
    def id(self) -> typing.Optional[builtins.str]:
        return jsii.get(self, "id")

    @id.setter # type: ignore
    def id(self, value: typing.Optional[builtins.str]) -> None:
        jsii.set(self, "id", value)

    @builtins.property # type: ignore
    @jsii.member(jsii_name="timeouts")
    def timeouts(self) -> typing.Optional["AutomationCredentialTimeouts"]:
        return jsii.get(self, "timeouts")

    @timeouts.setter # type: ignore
    def timeouts(self, value: typing.Optional["AutomationCredentialTimeouts"]) -> None:
        jsii.set(self, "timeouts", value)


@jsii.data_type(
    jsii_type="@cdktf/provider-azurerm.AutomationCredentialConfig",
    jsii_struct_bases=[cdktf.TerraformMetaArguments],
    name_mapping={
        "count": "count",
        "depends_on": "dependsOn",
        "lifecycle": "lifecycle",
        "provider": "provider",
        "automation_account_name": "automationAccountName",
        "name": "name",
        "password": "password",
        "resource_group_name": "resourceGroupName",
        "username": "username",
        "description": "description",
        "timeouts": "timeouts",
    },
)
class AutomationCredentialConfig(cdktf.TerraformMetaArguments):
    def __init__(
        self,
        *,
        count: typing.Optional[jsii.Number] = None,
        depends_on: typing.Optional[typing.List[cdktf.TerraformResource]] = None,
        lifecycle: typing.Optional[cdktf.TerraformResourceLifecycle] = None,
        provider: typing.Optional[cdktf.TerraformProvider] = None,
        automation_account_name: builtins.str,
        name: builtins.str,
        password: builtins.str,
        resource_group_name: builtins.str,
        username: builtins.str,
        description: typing.Optional[builtins.str] = None,
        timeouts: typing.Optional["AutomationCredentialTimeouts"] = None,
    ) -> None:
        """
        :param count: 
        :param depends_on: 
        :param lifecycle: 
        :param provider: 
        :param automation_account_name: 
        :param name: 
        :param password: 
        :param resource_group_name: 
        :param username: 
        :param description: 
        :param timeouts: timeouts block.
        """
        if isinstance(lifecycle, dict):
            lifecycle = cdktf.TerraformResourceLifecycle(**lifecycle)
        if isinstance(timeouts, dict):
            timeouts = AutomationCredentialTimeouts(**timeouts)
        self._values: typing.Dict[str, typing.Any] = {
            "automation_account_name": automation_account_name,
            "name": name,
            "password": password,
            "resource_group_name": resource_group_name,
            "username": username,
        }
        if count is not None:
            self._values["count"] = count
        if depends_on is not None:
            self._values["depends_on"] = depends_on
        if lifecycle is not None:
            self._values["lifecycle"] = lifecycle
        if provider is not None:
            self._values["provider"] = provider
        if description is not None:
            self._values["description"] = description
        if timeouts is not None:
            self._values["timeouts"] = timeouts

    @builtins.property
    def count(self) -> typing.Optional[jsii.Number]:
        """
        :stability: experimental
        """
        result = self._values.get("count")
        return result

    @builtins.property
    def depends_on(self) -> typing.Optional[typing.List[cdktf.TerraformResource]]:
        """
        :stability: experimental
        """
        result = self._values.get("depends_on")
        return result

    @builtins.property
    def lifecycle(self) -> typing.Optional[cdktf.TerraformResourceLifecycle]:
        """
        :stability: experimental
        """
        result = self._values.get("lifecycle")
        return result

    @builtins.property
    def provider(self) -> typing.Optional[cdktf.TerraformProvider]:
        """
        :stability: experimental
        """
        result = self._values.get("provider")
        return result

    @builtins.property
    def automation_account_name(self) -> builtins.str:
        result = self._values.get("automation_account_name")
        assert result is not None, "Required property 'automation_account_name' is missing"
        return result

    @builtins.property
    def name(self) -> builtins.str:
        result = self._values.get("name")
        assert result is not None, "Required property 'name' is missing"
        return result

    @builtins.property
    def password(self) -> builtins.str:
        result = self._values.get("password")
        assert result is not None, "Required property 'password' is missing"
        return result

    @builtins.property
    def resource_group_name(self) -> builtins.str:
        result = self._values.get("resource_group_name")
        assert result is not None, "Required property 'resource_group_name' is missing"
        return result

    @builtins.property
    def username(self) -> builtins.str:
        result = self._values.get("username")
        assert result is not None, "Required property 'username' is missing"
        return result

    @builtins.property
    def description(self) -> typing.Optional[builtins.str]:
        result = self._values.get("description")
        return result

    @builtins.property
    def timeouts(self) -> typing.Optional["AutomationCredentialTimeouts"]:
        """timeouts block."""
        result = self._values.get("timeouts")
        return result

    def __eq__(self, rhs: typing.Any) -> builtins.bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs: typing.Any) -> builtins.bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return "AutomationCredentialConfig(%s)" % ", ".join(
            k + "=" + repr(v) for k, v in self._values.items()
        )


@jsii.data_type(
    jsii_type="@cdktf/provider-azurerm.AutomationCredentialTimeouts",
    jsii_struct_bases=[],
    name_mapping={
        "create": "create",
        "delete": "delete",
        "read": "read",
        "update": "update",
    },
)
class AutomationCredentialTimeouts:
    def __init__(
        self,
        *,
        create: typing.Optional[builtins.str] = None,
        delete: typing.Optional[builtins.str] = None,
        read: typing.Optional[builtins.str] = None,
        update: typing.Optional[builtins.str] = None,
    ) -> None:
        """
        :param create: 
        :param delete: 
        :param read: 
        :param update: 
        """
        self._values: typing.Dict[str, typing.Any] = {}
        if create is not None:
            self._values["create"] = create
        if delete is not None:
            self._values["delete"] = delete
        if read is not None:
            self._values["read"] = read
        if update is not None:
            self._values["update"] = update

    @builtins.property
    def create(self) -> typing.Optional[builtins.str]:
        result = self._values.get("create")
        return result

    @builtins.property
    def delete(self) -> typing.Optional[builtins.str]:
        result = self._values.get("delete")
        return result

    @builtins.property
    def read(self) -> typing.Optional[builtins.str]:
        result = self._values.get("read")
        return result

    @builtins.property
    def update(self) -> typing.Optional[builtins.str]:
        result = self._values.get("update")
        return result

    def __eq__(self, rhs: typing.Any) -> builtins.bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs: typing.Any) -> builtins.bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return "AutomationCredentialTimeouts(%s)" % ", ".join(
            k + "=" + repr(v) for k, v in self._values.items()
        )


class AutomationDscConfiguration(
    cdktf.TerraformResource,
    metaclass=jsii.JSIIMeta,
    jsii_type="@cdktf/provider-azurerm.AutomationDscConfiguration",
):
    def __init__(
        self,
        scope: constructs.Construct,
        id: builtins.str,
        *,
        automation_account_name: builtins.str,
        content_embedded: builtins.str,
        location: builtins.str,
        name: builtins.str,
        resource_group_name: builtins.str,
        description: typing.Optional[builtins.str] = None,
        log_verbose: typing.Optional[builtins.bool] = None,
        timeouts: typing.Optional["AutomationDscConfigurationTimeouts"] = None,
        count: typing.Optional[jsii.Number] = None,
        depends_on: typing.Optional[typing.List[cdktf.TerraformResource]] = None,
        lifecycle: typing.Optional[cdktf.TerraformResourceLifecycle] = None,
        provider: typing.Optional[cdktf.TerraformProvider] = None,
    ) -> None:
        """
        :param scope: -
        :param id: -
        :param automation_account_name: 
        :param content_embedded: 
        :param location: 
        :param name: 
        :param resource_group_name: 
        :param description: 
        :param log_verbose: 
        :param timeouts: timeouts block.
        :param count: 
        :param depends_on: 
        :param lifecycle: 
        :param provider: 
        """
        config = AutomationDscConfigurationConfig(
            automation_account_name=automation_account_name,
            content_embedded=content_embedded,
            location=location,
            name=name,
            resource_group_name=resource_group_name,
            description=description,
            log_verbose=log_verbose,
            timeouts=timeouts,
            count=count,
            depends_on=depends_on,
            lifecycle=lifecycle,
            provider=provider,
        )

        jsii.create(AutomationDscConfiguration, self, [scope, id, config])

    @jsii.member(jsii_name="synthesizeAttributes")
    def _synthesize_attributes(self) -> typing.Mapping[builtins.str, typing.Any]:
        return jsii.invoke(self, "synthesizeAttributes", [])

    @builtins.property # type: ignore
    @jsii.member(jsii_name="state")
    def state(self) -> builtins.str:
        return jsii.get(self, "state")

    @builtins.property # type: ignore
    @jsii.member(jsii_name="automationAccountName")
    def automation_account_name(self) -> builtins.str:
        return jsii.get(self, "automationAccountName")

    @automation_account_name.setter # type: ignore
    def automation_account_name(self, value: builtins.str) -> None:
        jsii.set(self, "automationAccountName", value)

    @builtins.property # type: ignore
    @jsii.member(jsii_name="contentEmbedded")
    def content_embedded(self) -> builtins.str:
        return jsii.get(self, "contentEmbedded")

    @content_embedded.setter # type: ignore
    def content_embedded(self, value: builtins.str) -> None:
        jsii.set(self, "contentEmbedded", value)

    @builtins.property # type: ignore
    @jsii.member(jsii_name="location")
    def location(self) -> builtins.str:
        return jsii.get(self, "location")

    @location.setter # type: ignore
    def location(self, value: builtins.str) -> None:
        jsii.set(self, "location", value)

    @builtins.property # type: ignore
    @jsii.member(jsii_name="name")
    def name(self) -> builtins.str:
        return jsii.get(self, "name")

    @name.setter # type: ignore
    def name(self, value: builtins.str) -> None:
        jsii.set(self, "name", value)

    @builtins.property # type: ignore
    @jsii.member(jsii_name="resourceGroupName")
    def resource_group_name(self) -> builtins.str:
        return jsii.get(self, "resourceGroupName")

    @resource_group_name.setter # type: ignore
    def resource_group_name(self, value: builtins.str) -> None:
        jsii.set(self, "resourceGroupName", value)

    @builtins.property # type: ignore
    @jsii.member(jsii_name="description")
    def description(self) -> typing.Optional[builtins.str]:
        return jsii.get(self, "description")

    @description.setter # type: ignore
    def description(self, value: typing.Optional[builtins.str]) -> None:
        jsii.set(self, "description", value)

    @builtins.property # type: ignore
    @jsii.member(jsii_name="id")
    def id(self) -> typing.Optional[builtins.str]:
        return jsii.get(self, "id")

    @id.setter # type: ignore
    def id(self, value: typing.Optional[builtins.str]) -> None:
        jsii.set(self, "id", value)

    @builtins.property # type: ignore
    @jsii.member(jsii_name="logVerbose")
    def log_verbose(self) -> typing.Optional[builtins.bool]:
        return jsii.get(self, "logVerbose")

    @log_verbose.setter # type: ignore
    def log_verbose(self, value: typing.Optional[builtins.bool]) -> None:
        jsii.set(self, "logVerbose", value)

    @builtins.property # type: ignore
    @jsii.member(jsii_name="timeouts")
    def timeouts(self) -> typing.Optional["AutomationDscConfigurationTimeouts"]:
        return jsii.get(self, "timeouts")

    @timeouts.setter # type: ignore
    def timeouts(
        self,
        value: typing.Optional["AutomationDscConfigurationTimeouts"],
    ) -> None:
        jsii.set(self, "timeouts", value)


@jsii.data_type(
    jsii_type="@cdktf/provider-azurerm.AutomationDscConfigurationConfig",
    jsii_struct_bases=[cdktf.TerraformMetaArguments],
    name_mapping={
        "count": "count",
        "depends_on": "dependsOn",
        "lifecycle": "lifecycle",
        "provider": "provider",
        "automation_account_name": "automationAccountName",
        "content_embedded": "contentEmbedded",
        "location": "location",
        "name": "name",
        "resource_group_name": "resourceGroupName",
        "description": "description",
        "log_verbose": "logVerbose",
        "timeouts": "timeouts",
    },
)
class AutomationDscConfigurationConfig(cdktf.TerraformMetaArguments):
    def __init__(
        self,
        *,
        count: typing.Optional[jsii.Number] = None,
        depends_on: typing.Optional[typing.List[cdktf.TerraformResource]] = None,
        lifecycle: typing.Optional[cdktf.TerraformResourceLifecycle] = None,
        provider: typing.Optional[cdktf.TerraformProvider] = None,
        automation_account_name: builtins.str,
        content_embedded: builtins.str,
        location: builtins.str,
        name: builtins.str,
        resource_group_name: builtins.str,
        description: typing.Optional[builtins.str] = None,
        log_verbose: typing.Optional[builtins.bool] = None,
        timeouts: typing.Optional["AutomationDscConfigurationTimeouts"] = None,
    ) -> None:
        """
        :param count: 
        :param depends_on: 
        :param lifecycle: 
        :param provider: 
        :param automation_account_name: 
        :param content_embedded: 
        :param location: 
        :param name: 
        :param resource_group_name: 
        :param description: 
        :param log_verbose: 
        :param timeouts: timeouts block.
        """
        if isinstance(lifecycle, dict):
            lifecycle = cdktf.TerraformResourceLifecycle(**lifecycle)
        if isinstance(timeouts, dict):
            timeouts = AutomationDscConfigurationTimeouts(**timeouts)
        self._values: typing.Dict[str, typing.Any] = {
            "automation_account_name": automation_account_name,
            "content_embedded": content_embedded,
            "location": location,
            "name": name,
            "resource_group_name": resource_group_name,
        }
        if count is not None:
            self._values["count"] = count
        if depends_on is not None:
            self._values["depends_on"] = depends_on
        if lifecycle is not None:
            self._values["lifecycle"] = lifecycle
        if provider is not None:
            self._values["provider"] = provider
        if description is not None:
            self._values["description"] = description
        if log_verbose is not None:
            self._values["log_verbose"] = log_verbose
        if timeouts is not None:
            self._values["timeouts"] = timeouts

    @builtins.property
    def count(self) -> typing.Optional[jsii.Number]:
        """
        :stability: experimental
        """
        result = self._values.get("count")
        return result

    @builtins.property
    def depends_on(self) -> typing.Optional[typing.List[cdktf.TerraformResource]]:
        """
        :stability: experimental
        """
        result = self._values.get("depends_on")
        return result

    @builtins.property
    def lifecycle(self) -> typing.Optional[cdktf.TerraformResourceLifecycle]:
        """
        :stability: experimental
        """
        result = self._values.get("lifecycle")
        return result

    @builtins.property
    def provider(self) -> typing.Optional[cdktf.TerraformProvider]:
        """
        :stability: experimental
        """
        result = self._values.get("provider")
        return result

    @builtins.property
    def automation_account_name(self) -> builtins.str:
        result = self._values.get("automation_account_name")
        assert result is not None, "Required property 'automation_account_name' is missing"
        return result

    @builtins.property
    def content_embedded(self) -> builtins.str:
        result = self._values.get("content_embedded")
        assert result is not None, "Required property 'content_embedded' is missing"
        return result

    @builtins.property
    def location(self) -> builtins.str:
        result = self._values.get("location")
        assert result is not None, "Required property 'location' is missing"
        return result

    @builtins.property
    def name(self) -> builtins.str:
        result = self._values.get("name")
        assert result is not None, "Required property 'name' is missing"
        return result

    @builtins.property
    def resource_group_name(self) -> builtins.str:
        result = self._values.get("resource_group_name")
        assert result is not None, "Required property 'resource_group_name' is missing"
        return result

    @builtins.property
    def description(self) -> typing.Optional[builtins.str]:
        result = self._values.get("description")
        return result

    @builtins.property
    def log_verbose(self) -> typing.Optional[builtins.bool]:
        result = self._values.get("log_verbose")
        return result

    @builtins.property
    def timeouts(self) -> typing.Optional["AutomationDscConfigurationTimeouts"]:
        """timeouts block."""
        result = self._values.get("timeouts")
        return result

    def __eq__(self, rhs: typing.Any) -> builtins.bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs: typing.Any) -> builtins.bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return "AutomationDscConfigurationConfig(%s)" % ", ".join(
            k + "=" + repr(v) for k, v in self._values.items()
        )


@jsii.data_type(
    jsii_type="@cdktf/provider-azurerm.AutomationDscConfigurationTimeouts",
    jsii_struct_bases=[],
    name_mapping={
        "create": "create",
        "delete": "delete",
        "read": "read",
        "update": "update",
    },
)
class AutomationDscConfigurationTimeouts:
    def __init__(
        self,
        *,
        create: typing.Optional[builtins.str] = None,
        delete: typing.Optional[builtins.str] = None,
        read: typing.Optional[builtins.str] = None,
        update: typing.Optional[builtins.str] = None,
    ) -> None:
        """
        :param create: 
        :param delete: 
        :param read: 
        :param update: 
        """
        self._values: typing.Dict[str, typing.Any] = {}
        if create is not None:
            self._values["create"] = create
        if delete is not None:
            self._values["delete"] = delete
        if read is not None:
            self._values["read"] = read
        if update is not None:
            self._values["update"] = update

    @builtins.property
    def create(self) -> typing.Optional[builtins.str]:
        result = self._values.get("create")
        return result

    @builtins.property
    def delete(self) -> typing.Optional[builtins.str]:
        result = self._values.get("delete")
        return result

    @builtins.property
    def read(self) -> typing.Optional[builtins.str]:
        result = self._values.get("read")
        return result

    @builtins.property
    def update(self) -> typing.Optional[builtins.str]:
        result = self._values.get("update")
        return result

    def __eq__(self, rhs: typing.Any) -> builtins.bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs: typing.Any) -> builtins.bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return "AutomationDscConfigurationTimeouts(%s)" % ", ".join(
            k + "=" + repr(v) for k, v in self._values.items()
        )


class AutomationDscNodeconfiguration(
    cdktf.TerraformResource,
    metaclass=jsii.JSIIMeta,
    jsii_type="@cdktf/provider-azurerm.AutomationDscNodeconfiguration",
):
    def __init__(
        self,
        scope: constructs.Construct,
        id: builtins.str,
        *,
        automation_account_name: builtins.str,
        content_embedded: builtins.str,
        name: builtins.str,
        resource_group_name: builtins.str,
        timeouts: typing.Optional["AutomationDscNodeconfigurationTimeouts"] = None,
        count: typing.Optional[jsii.Number] = None,
        depends_on: typing.Optional[typing.List[cdktf.TerraformResource]] = None,
        lifecycle: typing.Optional[cdktf.TerraformResourceLifecycle] = None,
        provider: typing.Optional[cdktf.TerraformProvider] = None,
    ) -> None:
        """
        :param scope: -
        :param id: -
        :param automation_account_name: 
        :param content_embedded: 
        :param name: 
        :param resource_group_name: 
        :param timeouts: timeouts block.
        :param count: 
        :param depends_on: 
        :param lifecycle: 
        :param provider: 
        """
        config = AutomationDscNodeconfigurationConfig(
            automation_account_name=automation_account_name,
            content_embedded=content_embedded,
            name=name,
            resource_group_name=resource_group_name,
            timeouts=timeouts,
            count=count,
            depends_on=depends_on,
            lifecycle=lifecycle,
            provider=provider,
        )

        jsii.create(AutomationDscNodeconfiguration, self, [scope, id, config])

    @jsii.member(jsii_name="synthesizeAttributes")
    def _synthesize_attributes(self) -> typing.Mapping[builtins.str, typing.Any]:
        return jsii.invoke(self, "synthesizeAttributes", [])

    @builtins.property # type: ignore
    @jsii.member(jsii_name="configurationName")
    def configuration_name(self) -> builtins.str:
        return jsii.get(self, "configurationName")

    @builtins.property # type: ignore
    @jsii.member(jsii_name="automationAccountName")
    def automation_account_name(self) -> builtins.str:
        return jsii.get(self, "automationAccountName")

    @automation_account_name.setter # type: ignore
    def automation_account_name(self, value: builtins.str) -> None:
        jsii.set(self, "automationAccountName", value)

    @builtins.property # type: ignore
    @jsii.member(jsii_name="contentEmbedded")
    def content_embedded(self) -> builtins.str:
        return jsii.get(self, "contentEmbedded")

    @content_embedded.setter # type: ignore
    def content_embedded(self, value: builtins.str) -> None:
        jsii.set(self, "contentEmbedded", value)

    @builtins.property # type: ignore
    @jsii.member(jsii_name="name")
    def name(self) -> builtins.str:
        return jsii.get(self, "name")

    @name.setter # type: ignore
    def name(self, value: builtins.str) -> None:
        jsii.set(self, "name", value)

    @builtins.property # type: ignore
    @jsii.member(jsii_name="resourceGroupName")
    def resource_group_name(self) -> builtins.str:
        return jsii.get(self, "resourceGroupName")

    @resource_group_name.setter # type: ignore
    def resource_group_name(self, value: builtins.str) -> None:
        jsii.set(self, "resourceGroupName", value)

    @builtins.property # type: ignore
    @jsii.member(jsii_name="id")
    def id(self) -> typing.Optional[builtins.str]:
        return jsii.get(self, "id")

    @id.setter # type: ignore
    def id(self, value: typing.Optional[builtins.str]) -> None:
        jsii.set(self, "id", value)

    @builtins.property # type: ignore
    @jsii.member(jsii_name="timeouts")
    def timeouts(self) -> typing.Optional["AutomationDscNodeconfigurationTimeouts"]:
        return jsii.get(self, "timeouts")

    @timeouts.setter # type: ignore
    def timeouts(
        self,
        value: typing.Optional["AutomationDscNodeconfigurationTimeouts"],
    ) -> None:
        jsii.set(self, "timeouts", value)


@jsii.data_type(
    jsii_type="@cdktf/provider-azurerm.AutomationDscNodeconfigurationConfig",
    jsii_struct_bases=[cdktf.TerraformMetaArguments],
    name_mapping={
        "count": "count",
        "depends_on": "dependsOn",
        "lifecycle": "lifecycle",
        "provider": "provider",
        "automation_account_name": "automationAccountName",
        "content_embedded": "contentEmbedded",
        "name": "name",
        "resource_group_name": "resourceGroupName",
        "timeouts": "timeouts",
    },
)
class AutomationDscNodeconfigurationConfig(cdktf.TerraformMetaArguments):
    def __init__(
        self,
        *,
        count: typing.Optional[jsii.Number] = None,
        depends_on: typing.Optional[typing.List[cdktf.TerraformResource]] = None,
        lifecycle: typing.Optional[cdktf.TerraformResourceLifecycle] = None,
        provider: typing.Optional[cdktf.TerraformProvider] = None,
        automation_account_name: builtins.str,
        content_embedded: builtins.str,
        name: builtins.str,
        resource_group_name: builtins.str,
        timeouts: typing.Optional["AutomationDscNodeconfigurationTimeouts"] = None,
    ) -> None:
        """
        :param count: 
        :param depends_on: 
        :param lifecycle: 
        :param provider: 
        :param automation_account_name: 
        :param content_embedded: 
        :param name: 
        :param resource_group_name: 
        :param timeouts: timeouts block.
        """
        if isinstance(lifecycle, dict):
            lifecycle = cdktf.TerraformResourceLifecycle(**lifecycle)
        if isinstance(timeouts, dict):
            timeouts = AutomationDscNodeconfigurationTimeouts(**timeouts)
        self._values: typing.Dict[str, typing.Any] = {
            "automation_account_name": automation_account_name,
            "content_embedded": content_embedded,
            "name": name,
            "resource_group_name": resource_group_name,
        }
        if count is not None:
            self._values["count"] = count
        if depends_on is not None:
            self._values["depends_on"] = depends_on
        if lifecycle is not None:
            self._values["lifecycle"] = lifecycle
        if provider is not None:
            self._values["provider"] = provider
        if timeouts is not None:
            self._values["timeouts"] = timeouts

    @builtins.property
    def count(self) -> typing.Optional[jsii.Number]:
        """
        :stability: experimental
        """
        result = self._values.get("count")
        return result

    @builtins.property
    def depends_on(self) -> typing.Optional[typing.List[cdktf.TerraformResource]]:
        """
        :stability: experimental
        """
        result = self._values.get("depends_on")
        return result

    @builtins.property
    def lifecycle(self) -> typing.Optional[cdktf.TerraformResourceLifecycle]:
        """
        :stability: experimental
        """
        result = self._values.get("lifecycle")
        return result

    @builtins.property
    def provider(self) -> typing.Optional[cdktf.TerraformProvider]:
        """
        :stability: experimental
        """
        result = self._values.get("provider")
        return result

    @builtins.property
    def automation_account_name(self) -> builtins.str:
        result = self._values.get("automation_account_name")
        assert result is not None, "Required property 'automation_account_name' is missing"
        return result

    @builtins.property
    def content_embedded(self) -> builtins.str:
        result = self._values.get("content_embedded")
        assert result is not None, "Required property 'content_embedded' is missing"
        return result

    @builtins.property
    def name(self) -> builtins.str:
        result = self._values.get("name")
        assert result is not None, "Required property 'name' is missing"
        return result

    @builtins.property
    def resource_group_name(self) -> builtins.str:
        result = self._values.get("resource_group_name")
        assert result is not None, "Required property 'resource_group_name' is missing"
        return result

    @builtins.property
    def timeouts(self) -> typing.Optional["AutomationDscNodeconfigurationTimeouts"]:
        """timeouts block."""
        result = self._values.get("timeouts")
        return result

    def __eq__(self, rhs: typing.Any) -> builtins.bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs: typing.Any) -> builtins.bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return "AutomationDscNodeconfigurationConfig(%s)" % ", ".join(
            k + "=" + repr(v) for k, v in self._values.items()
        )


@jsii.data_type(
    jsii_type="@cdktf/provider-azurerm.AutomationDscNodeconfigurationTimeouts",
    jsii_struct_bases=[],
    name_mapping={
        "create": "create",
        "delete": "delete",
        "read": "read",
        "update": "update",
    },
)
class AutomationDscNodeconfigurationTimeouts:
    def __init__(
        self,
        *,
        create: typing.Optional[builtins.str] = None,
        delete: typing.Optional[builtins.str] = None,
        read: typing.Optional[builtins.str] = None,
        update: typing.Optional[builtins.str] = None,
    ) -> None:
        """
        :param create: 
        :param delete: 
        :param read: 
        :param update: 
        """
        self._values: typing.Dict[str, typing.Any] = {}
        if create is not None:
            self._values["create"] = create
        if delete is not None:
            self._values["delete"] = delete
        if read is not None:
            self._values["read"] = read
        if update is not None:
            self._values["update"] = update

    @builtins.property
    def create(self) -> typing.Optional[builtins.str]:
        result = self._values.get("create")
        return result

    @builtins.property
    def delete(self) -> typing.Optional[builtins.str]:
        result = self._values.get("delete")
        return result

    @builtins.property
    def read(self) -> typing.Optional[builtins.str]:
        result = self._values.get("read")
        return result

    @builtins.property
    def update(self) -> typing.Optional[builtins.str]:
        result = self._values.get("update")
        return result

    def __eq__(self, rhs: typing.Any) -> builtins.bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs: typing.Any) -> builtins.bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return "AutomationDscNodeconfigurationTimeouts(%s)" % ", ".join(
            k + "=" + repr(v) for k, v in self._values.items()
        )


class AutomationJobSchedule(
    cdktf.TerraformResource,
    metaclass=jsii.JSIIMeta,
    jsii_type="@cdktf/provider-azurerm.AutomationJobSchedule",
):
    def __init__(
        self,
        scope: constructs.Construct,
        id: builtins.str,
        *,
        automation_account_name: builtins.str,
        resource_group_name: builtins.str,
        runbook_name: builtins.str,
        schedule_name: builtins.str,
        job_schedule_id: typing.Optional[builtins.str] = None,
        parameters: typing.Optional[typing.Mapping[builtins.str, builtins.str]] = None,
        run_on: typing.Optional[builtins.str] = None,
        timeouts: typing.Optional["AutomationJobScheduleTimeouts"] = None,
        count: typing.Optional[jsii.Number] = None,
        depends_on: typing.Optional[typing.List[cdktf.TerraformResource]] = None,
        lifecycle: typing.Optional[cdktf.TerraformResourceLifecycle] = None,
        provider: typing.Optional[cdktf.TerraformProvider] = None,
    ) -> None:
        """
        :param scope: -
        :param id: -
        :param automation_account_name: 
        :param resource_group_name: 
        :param runbook_name: 
        :param schedule_name: 
        :param job_schedule_id: 
        :param parameters: 
        :param run_on: 
        :param timeouts: timeouts block.
        :param count: 
        :param depends_on: 
        :param lifecycle: 
        :param provider: 
        """
        config = AutomationJobScheduleConfig(
            automation_account_name=automation_account_name,
            resource_group_name=resource_group_name,
            runbook_name=runbook_name,
            schedule_name=schedule_name,
            job_schedule_id=job_schedule_id,
            parameters=parameters,
            run_on=run_on,
            timeouts=timeouts,
            count=count,
            depends_on=depends_on,
            lifecycle=lifecycle,
            provider=provider,
        )

        jsii.create(AutomationJobSchedule, self, [scope, id, config])

    @jsii.member(jsii_name="synthesizeAttributes")
    def _synthesize_attributes(self) -> typing.Mapping[builtins.str, typing.Any]:
        return jsii.invoke(self, "synthesizeAttributes", [])

    @builtins.property # type: ignore
    @jsii.member(jsii_name="automationAccountName")
    def automation_account_name(self) -> builtins.str:
        return jsii.get(self, "automationAccountName")

    @automation_account_name.setter # type: ignore
    def automation_account_name(self, value: builtins.str) -> None:
        jsii.set(self, "automationAccountName", value)

    @builtins.property # type: ignore
    @jsii.member(jsii_name="resourceGroupName")
    def resource_group_name(self) -> builtins.str:
        return jsii.get(self, "resourceGroupName")

    @resource_group_name.setter # type: ignore
    def resource_group_name(self, value: builtins.str) -> None:
        jsii.set(self, "resourceGroupName", value)

    @builtins.property # type: ignore
    @jsii.member(jsii_name="runbookName")
    def runbook_name(self) -> builtins.str:
        return jsii.get(self, "runbookName")

    @runbook_name.setter # type: ignore
    def runbook_name(self, value: builtins.str) -> None:
        jsii.set(self, "runbookName", value)

    @builtins.property # type: ignore
    @jsii.member(jsii_name="scheduleName")
    def schedule_name(self) -> builtins.str:
        return jsii.get(self, "scheduleName")

    @schedule_name.setter # type: ignore
    def schedule_name(self, value: builtins.str) -> None:
        jsii.set(self, "scheduleName", value)

    @builtins.property # type: ignore
    @jsii.member(jsii_name="id")
    def id(self) -> typing.Optional[builtins.str]:
        return jsii.get(self, "id")

    @id.setter # type: ignore
    def id(self, value: typing.Optional[builtins.str]) -> None:
        jsii.set(self, "id", value)

    @builtins.property # type: ignore
    @jsii.member(jsii_name="jobScheduleId")
    def job_schedule_id(self) -> typing.Optional[builtins.str]:
        return jsii.get(self, "jobScheduleId")

    @job_schedule_id.setter # type: ignore
    def job_schedule_id(self, value: typing.Optional[builtins.str]) -> None:
        jsii.set(self, "jobScheduleId", value)

    @builtins.property # type: ignore
    @jsii.member(jsii_name="parameters")
    def parameters(self) -> typing.Optional[typing.Mapping[builtins.str, builtins.str]]:
        return jsii.get(self, "parameters")

    @parameters.setter # type: ignore
    def parameters(
        self,
        value: typing.Optional[typing.Mapping[builtins.str, builtins.str]],
    ) -> None:
        jsii.set(self, "parameters", value)

    @builtins.property # type: ignore
    @jsii.member(jsii_name="runOn")
    def run_on(self) -> typing.Optional[builtins.str]:
        return jsii.get(self, "runOn")

    @run_on.setter # type: ignore
    def run_on(self, value: typing.Optional[builtins.str]) -> None:
        jsii.set(self, "runOn", value)

    @builtins.property # type: ignore
    @jsii.member(jsii_name="timeouts")
    def timeouts(self) -> typing.Optional["AutomationJobScheduleTimeouts"]:
        return jsii.get(self, "timeouts")

    @timeouts.setter # type: ignore
    def timeouts(self, value: typing.Optional["AutomationJobScheduleTimeouts"]) -> None:
        jsii.set(self, "timeouts", value)


@jsii.data_type(
    jsii_type="@cdktf/provider-azurerm.AutomationJobScheduleConfig",
    jsii_struct_bases=[cdktf.TerraformMetaArguments],
    name_mapping={
        "count": "count",
        "depends_on": "dependsOn",
        "lifecycle": "lifecycle",
        "provider": "provider",
        "automation_account_name": "automationAccountName",
        "resource_group_name": "resourceGroupName",
        "runbook_name": "runbookName",
        "schedule_name": "scheduleName",
        "job_schedule_id": "jobScheduleId",
        "parameters": "parameters",
        "run_on": "runOn",
        "timeouts": "timeouts",
    },
)
class AutomationJobScheduleConfig(cdktf.TerraformMetaArguments):
    def __init__(
        self,
        *,
        count: typing.Optional[jsii.Number] = None,
        depends_on: typing.Optional[typing.List[cdktf.TerraformResource]] = None,
        lifecycle: typing.Optional[cdktf.TerraformResourceLifecycle] = None,
        provider: typing.Optional[cdktf.TerraformProvider] = None,
        automation_account_name: builtins.str,
        resource_group_name: builtins.str,
        runbook_name: builtins.str,
        schedule_name: builtins.str,
        job_schedule_id: typing.Optional[builtins.str] = None,
        parameters: typing.Optional[typing.Mapping[builtins.str, builtins.str]] = None,
        run_on: typing.Optional[builtins.str] = None,
        timeouts: typing.Optional["AutomationJobScheduleTimeouts"] = None,
    ) -> None:
        """
        :param count: 
        :param depends_on: 
        :param lifecycle: 
        :param provider: 
        :param automation_account_name: 
        :param resource_group_name: 
        :param runbook_name: 
        :param schedule_name: 
        :param job_schedule_id: 
        :param parameters: 
        :param run_on: 
        :param timeouts: timeouts block.
        """
        if isinstance(lifecycle, dict):
            lifecycle = cdktf.TerraformResourceLifecycle(**lifecycle)
        if isinstance(timeouts, dict):
            timeouts = AutomationJobScheduleTimeouts(**timeouts)
        self._values: typing.Dict[str, typing.Any] = {
            "automation_account_name": automation_account_name,
            "resource_group_name": resource_group_name,
            "runbook_name": runbook_name,
            "schedule_name": schedule_name,
        }
        if count is not None:
            self._values["count"] = count
        if depends_on is not None:
            self._values["depends_on"] = depends_on
        if lifecycle is not None:
            self._values["lifecycle"] = lifecycle
        if provider is not None:
            self._values["provider"] = provider
        if job_schedule_id is not None:
            self._values["job_schedule_id"] = job_schedule_id
        if parameters is not None:
            self._values["parameters"] = parameters
        if run_on is not None:
            self._values["run_on"] = run_on
        if timeouts is not None:
            self._values["timeouts"] = timeouts

    @builtins.property
    def count(self) -> typing.Optional[jsii.Number]:
        """
        :stability: experimental
        """
        result = self._values.get("count")
        return result

    @builtins.property
    def depends_on(self) -> typing.Optional[typing.List[cdktf.TerraformResource]]:
        """
        :stability: experimental
        """
        result = self._values.get("depends_on")
        return result

    @builtins.property
    def lifecycle(self) -> typing.Optional[cdktf.TerraformResourceLifecycle]:
        """
        :stability: experimental
        """
        result = self._values.get("lifecycle")
        return result

    @builtins.property
    def provider(self) -> typing.Optional[cdktf.TerraformProvider]:
        """
        :stability: experimental
        """
        result = self._values.get("provider")
        return result

    @builtins.property
    def automation_account_name(self) -> builtins.str:
        result = self._values.get("automation_account_name")
        assert result is not None, "Required property 'automation_account_name' is missing"
        return result

    @builtins.property
    def resource_group_name(self) -> builtins.str:
        result = self._values.get("resource_group_name")
        assert result is not None, "Required property 'resource_group_name' is missing"
        return result

    @builtins.property
    def runbook_name(self) -> builtins.str:
        result = self._values.get("runbook_name")
        assert result is not None, "Required property 'runbook_name' is missing"
        return result

    @builtins.property
    def schedule_name(self) -> builtins.str:
        result = self._values.get("schedule_name")
        assert result is not None, "Required property 'schedule_name' is missing"
        return result

    @builtins.property
    def job_schedule_id(self) -> typing.Optional[builtins.str]:
        result = self._values.get("job_schedule_id")
        return result

    @builtins.property
    def parameters(self) -> typing.Optional[typing.Mapping[builtins.str, builtins.str]]:
        result = self._values.get("parameters")
        return result

    @builtins.property
    def run_on(self) -> typing.Optional[builtins.str]:
        result = self._values.get("run_on")
        return result

    @builtins.property
    def timeouts(self) -> typing.Optional["AutomationJobScheduleTimeouts"]:
        """timeouts block."""
        result = self._values.get("timeouts")
        return result

    def __eq__(self, rhs: typing.Any) -> builtins.bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs: typing.Any) -> builtins.bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return "AutomationJobScheduleConfig(%s)" % ", ".join(
            k + "=" + repr(v) for k, v in self._values.items()
        )


@jsii.data_type(
    jsii_type="@cdktf/provider-azurerm.AutomationJobScheduleTimeouts",
    jsii_struct_bases=[],
    name_mapping={
        "create": "create",
        "delete": "delete",
        "read": "read",
        "update": "update",
    },
)
class AutomationJobScheduleTimeouts:
    def __init__(
        self,
        *,
        create: typing.Optional[builtins.str] = None,
        delete: typing.Optional[builtins.str] = None,
        read: typing.Optional[builtins.str] = None,
        update: typing.Optional[builtins.str] = None,
    ) -> None:
        """
        :param create: 
        :param delete: 
        :param read: 
        :param update: 
        """
        self._values: typing.Dict[str, typing.Any] = {}
        if create is not None:
            self._values["create"] = create
        if delete is not None:
            self._values["delete"] = delete
        if read is not None:
            self._values["read"] = read
        if update is not None:
            self._values["update"] = update

    @builtins.property
    def create(self) -> typing.Optional[builtins.str]:
        result = self._values.get("create")
        return result

    @builtins.property
    def delete(self) -> typing.Optional[builtins.str]:
        result = self._values.get("delete")
        return result

    @builtins.property
    def read(self) -> typing.Optional[builtins.str]:
        result = self._values.get("read")
        return result

    @builtins.property
    def update(self) -> typing.Optional[builtins.str]:
        result = self._values.get("update")
        return result

    def __eq__(self, rhs: typing.Any) -> builtins.bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs: typing.Any) -> builtins.bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return "AutomationJobScheduleTimeouts(%s)" % ", ".join(
            k + "=" + repr(v) for k, v in self._values.items()
        )


class AutomationModule(
    cdktf.TerraformResource,
    metaclass=jsii.JSIIMeta,
    jsii_type="@cdktf/provider-azurerm.AutomationModule",
):
    def __init__(
        self,
        scope: constructs.Construct,
        id: builtins.str,
        *,
        automation_account_name: builtins.str,
        module_link: typing.List["AutomationModuleModuleLink"],
        name: builtins.str,
        resource_group_name: builtins.str,
        timeouts: typing.Optional["AutomationModuleTimeouts"] = None,
        count: typing.Optional[jsii.Number] = None,
        depends_on: typing.Optional[typing.List[cdktf.TerraformResource]] = None,
        lifecycle: typing.Optional[cdktf.TerraformResourceLifecycle] = None,
        provider: typing.Optional[cdktf.TerraformProvider] = None,
    ) -> None:
        """
        :param scope: -
        :param id: -
        :param automation_account_name: 
        :param module_link: module_link block.
        :param name: 
        :param resource_group_name: 
        :param timeouts: timeouts block.
        :param count: 
        :param depends_on: 
        :param lifecycle: 
        :param provider: 
        """
        config = AutomationModuleConfig(
            automation_account_name=automation_account_name,
            module_link=module_link,
            name=name,
            resource_group_name=resource_group_name,
            timeouts=timeouts,
            count=count,
            depends_on=depends_on,
            lifecycle=lifecycle,
            provider=provider,
        )

        jsii.create(AutomationModule, self, [scope, id, config])

    @jsii.member(jsii_name="synthesizeAttributes")
    def _synthesize_attributes(self) -> typing.Mapping[builtins.str, typing.Any]:
        return jsii.invoke(self, "synthesizeAttributes", [])

    @builtins.property # type: ignore
    @jsii.member(jsii_name="automationAccountName")
    def automation_account_name(self) -> builtins.str:
        return jsii.get(self, "automationAccountName")

    @automation_account_name.setter # type: ignore
    def automation_account_name(self, value: builtins.str) -> None:
        jsii.set(self, "automationAccountName", value)

    @builtins.property # type: ignore
    @jsii.member(jsii_name="moduleLink")
    def module_link(self) -> typing.List["AutomationModuleModuleLink"]:
        return jsii.get(self, "moduleLink")

    @module_link.setter # type: ignore
    def module_link(self, value: typing.List["AutomationModuleModuleLink"]) -> None:
        jsii.set(self, "moduleLink", value)

    @builtins.property # type: ignore
    @jsii.member(jsii_name="name")
    def name(self) -> builtins.str:
        return jsii.get(self, "name")

    @name.setter # type: ignore
    def name(self, value: builtins.str) -> None:
        jsii.set(self, "name", value)

    @builtins.property # type: ignore
    @jsii.member(jsii_name="resourceGroupName")
    def resource_group_name(self) -> builtins.str:
        return jsii.get(self, "resourceGroupName")

    @resource_group_name.setter # type: ignore
    def resource_group_name(self, value: builtins.str) -> None:
        jsii.set(self, "resourceGroupName", value)

    @builtins.property # type: ignore
    @jsii.member(jsii_name="id")
    def id(self) -> typing.Optional[builtins.str]:
        return jsii.get(self, "id")

    @id.setter # type: ignore
    def id(self, value: typing.Optional[builtins.str]) -> None:
        jsii.set(self, "id", value)

    @builtins.property # type: ignore
    @jsii.member(jsii_name="timeouts")
    def timeouts(self) -> typing.Optional["AutomationModuleTimeouts"]:
        return jsii.get(self, "timeouts")

    @timeouts.setter # type: ignore
    def timeouts(self, value: typing.Optional["AutomationModuleTimeouts"]) -> None:
        jsii.set(self, "timeouts", value)


@jsii.data_type(
    jsii_type="@cdktf/provider-azurerm.AutomationModuleConfig",
    jsii_struct_bases=[cdktf.TerraformMetaArguments],
    name_mapping={
        "count": "count",
        "depends_on": "dependsOn",
        "lifecycle": "lifecycle",
        "provider": "provider",
        "automation_account_name": "automationAccountName",
        "module_link": "moduleLink",
        "name": "name",
        "resource_group_name": "resourceGroupName",
        "timeouts": "timeouts",
    },
)
class AutomationModuleConfig(cdktf.TerraformMetaArguments):
    def __init__(
        self,
        *,
        count: typing.Optional[jsii.Number] = None,
        depends_on: typing.Optional[typing.List[cdktf.TerraformResource]] = None,
        lifecycle: typing.Optional[cdktf.TerraformResourceLifecycle] = None,
        provider: typing.Optional[cdktf.TerraformProvider] = None,
        automation_account_name: builtins.str,
        module_link: typing.List["AutomationModuleModuleLink"],
        name: builtins.str,
        resource_group_name: builtins.str,
        timeouts: typing.Optional["AutomationModuleTimeouts"] = None,
    ) -> None:
        """
        :param count: 
        :param depends_on: 
        :param lifecycle: 
        :param provider: 
        :param automation_account_name: 
        :param module_link: module_link block.
        :param name: 
        :param resource_group_name: 
        :param timeouts: timeouts block.
        """
        if isinstance(lifecycle, dict):
            lifecycle = cdktf.TerraformResourceLifecycle(**lifecycle)
        if isinstance(timeouts, dict):
            timeouts = AutomationModuleTimeouts(**timeouts)
        self._values: typing.Dict[str, typing.Any] = {
            "automation_account_name": automation_account_name,
            "module_link": module_link,
            "name": name,
            "resource_group_name": resource_group_name,
        }
        if count is not None:
            self._values["count"] = count
        if depends_on is not None:
            self._values["depends_on"] = depends_on
        if lifecycle is not None:
            self._values["lifecycle"] = lifecycle
        if provider is not None:
            self._values["provider"] = provider
        if timeouts is not None:
            self._values["timeouts"] = timeouts

    @builtins.property
    def count(self) -> typing.Optional[jsii.Number]:
        """
        :stability: experimental
        """
        result = self._values.get("count")
        return result

    @builtins.property
    def depends_on(self) -> typing.Optional[typing.List[cdktf.TerraformResource]]:
        """
        :stability: experimental
        """
        result = self._values.get("depends_on")
        return result

    @builtins.property
    def lifecycle(self) -> typing.Optional[cdktf.TerraformResourceLifecycle]:
        """
        :stability: experimental
        """
        result = self._values.get("lifecycle")
        return result

    @builtins.property
    def provider(self) -> typing.Optional[cdktf.TerraformProvider]:
        """
        :stability: experimental
        """
        result = self._values.get("provider")
        return result

    @builtins.property
    def automation_account_name(self) -> builtins.str:
        result = self._values.get("automation_account_name")
        assert result is not None, "Required property 'automation_account_name' is missing"
        return result

    @builtins.property
    def module_link(self) -> typing.List["AutomationModuleModuleLink"]:
        """module_link block."""
        result = self._values.get("module_link")
        assert result is not None, "Required property 'module_link' is missing"
        return result

    @builtins.property
    def name(self) -> builtins.str:
        result = self._values.get("name")
        assert result is not None, "Required property 'name' is missing"
        return result

    @builtins.property
    def resource_group_name(self) -> builtins.str:
        result = self._values.get("resource_group_name")
        assert result is not None, "Required property 'resource_group_name' is missing"
        return result

    @builtins.property
    def timeouts(self) -> typing.Optional["AutomationModuleTimeouts"]:
        """timeouts block."""
        result = self._values.get("timeouts")
        return result

    def __eq__(self, rhs: typing.Any) -> builtins.bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs: typing.Any) -> builtins.bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return "AutomationModuleConfig(%s)" % ", ".join(
            k + "=" + repr(v) for k, v in self._values.items()
        )


@jsii.data_type(
    jsii_type="@cdktf/provider-azurerm.AutomationModuleModuleLink",
    jsii_struct_bases=[],
    name_mapping={"uri": "uri", "hash": "hash"},
)
class AutomationModuleModuleLink:
    def __init__(
        self,
        *,
        uri: builtins.str,
        hash: typing.Optional[typing.List["AutomationModuleModuleLinkHash"]] = None,
    ) -> None:
        """
        :param uri: 
        :param hash: hash block.
        """
        self._values: typing.Dict[str, typing.Any] = {
            "uri": uri,
        }
        if hash is not None:
            self._values["hash"] = hash

    @builtins.property
    def uri(self) -> builtins.str:
        result = self._values.get("uri")
        assert result is not None, "Required property 'uri' is missing"
        return result

    @builtins.property
    def hash(self) -> typing.Optional[typing.List["AutomationModuleModuleLinkHash"]]:
        """hash block."""
        result = self._values.get("hash")
        return result

    def __eq__(self, rhs: typing.Any) -> builtins.bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs: typing.Any) -> builtins.bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return "AutomationModuleModuleLink(%s)" % ", ".join(
            k + "=" + repr(v) for k, v in self._values.items()
        )


@jsii.data_type(
    jsii_type="@cdktf/provider-azurerm.AutomationModuleModuleLinkHash",
    jsii_struct_bases=[],
    name_mapping={"algorithm": "algorithm", "value": "value"},
)
class AutomationModuleModuleLinkHash:
    def __init__(self, *, algorithm: builtins.str, value: builtins.str) -> None:
        """
        :param algorithm: 
        :param value: 
        """
        self._values: typing.Dict[str, typing.Any] = {
            "algorithm": algorithm,
            "value": value,
        }

    @builtins.property
    def algorithm(self) -> builtins.str:
        result = self._values.get("algorithm")
        assert result is not None, "Required property 'algorithm' is missing"
        return result

    @builtins.property
    def value(self) -> builtins.str:
        result = self._values.get("value")
        assert result is not None, "Required property 'value' is missing"
        return result

    def __eq__(self, rhs: typing.Any) -> builtins.bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs: typing.Any) -> builtins.bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return "AutomationModuleModuleLinkHash(%s)" % ", ".join(
            k + "=" + repr(v) for k, v in self._values.items()
        )


@jsii.data_type(
    jsii_type="@cdktf/provider-azurerm.AutomationModuleTimeouts",
    jsii_struct_bases=[],
    name_mapping={
        "create": "create",
        "delete": "delete",
        "read": "read",
        "update": "update",
    },
)
class AutomationModuleTimeouts:
    def __init__(
        self,
        *,
        create: typing.Optional[builtins.str] = None,
        delete: typing.Optional[builtins.str] = None,
        read: typing.Optional[builtins.str] = None,
        update: typing.Optional[builtins.str] = None,
    ) -> None:
        """
        :param create: 
        :param delete: 
        :param read: 
        :param update: 
        """
        self._values: typing.Dict[str, typing.Any] = {}
        if create is not None:
            self._values["create"] = create
        if delete is not None:
            self._values["delete"] = delete
        if read is not None:
            self._values["read"] = read
        if update is not None:
            self._values["update"] = update

    @builtins.property
    def create(self) -> typing.Optional[builtins.str]:
        result = self._values.get("create")
        return result

    @builtins.property
    def delete(self) -> typing.Optional[builtins.str]:
        result = self._values.get("delete")
        return result

    @builtins.property
    def read(self) -> typing.Optional[builtins.str]:
        result = self._values.get("read")
        return result

    @builtins.property
    def update(self) -> typing.Optional[builtins.str]:
        result = self._values.get("update")
        return result

    def __eq__(self, rhs: typing.Any) -> builtins.bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs: typing.Any) -> builtins.bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return "AutomationModuleTimeouts(%s)" % ", ".join(
            k + "=" + repr(v) for k, v in self._values.items()
        )


class AutomationRunbook(
    cdktf.TerraformResource,
    metaclass=jsii.JSIIMeta,
    jsii_type="@cdktf/provider-azurerm.AutomationRunbook",
):
    def __init__(
        self,
        scope: constructs.Construct,
        id: builtins.str,
        *,
        automation_account_name: builtins.str,
        location: builtins.str,
        log_progress: builtins.bool,
        log_verbose: builtins.bool,
        name: builtins.str,
        publish_content_link: typing.List["AutomationRunbookPublishContentLink"],
        resource_group_name: builtins.str,
        runbook_type: builtins.str,
        content: typing.Optional[builtins.str] = None,
        description: typing.Optional[builtins.str] = None,
        tags: typing.Optional[typing.Mapping[builtins.str, builtins.str]] = None,
        timeouts: typing.Optional["AutomationRunbookTimeouts"] = None,
        count: typing.Optional[jsii.Number] = None,
        depends_on: typing.Optional[typing.List[cdktf.TerraformResource]] = None,
        lifecycle: typing.Optional[cdktf.TerraformResourceLifecycle] = None,
        provider: typing.Optional[cdktf.TerraformProvider] = None,
    ) -> None:
        """
        :param scope: -
        :param id: -
        :param automation_account_name: 
        :param location: 
        :param log_progress: 
        :param log_verbose: 
        :param name: 
        :param publish_content_link: publish_content_link block.
        :param resource_group_name: 
        :param runbook_type: 
        :param content: 
        :param description: 
        :param tags: 
        :param timeouts: timeouts block.
        :param count: 
        :param depends_on: 
        :param lifecycle: 
        :param provider: 
        """
        config = AutomationRunbookConfig(
            automation_account_name=automation_account_name,
            location=location,
            log_progress=log_progress,
            log_verbose=log_verbose,
            name=name,
            publish_content_link=publish_content_link,
            resource_group_name=resource_group_name,
            runbook_type=runbook_type,
            content=content,
            description=description,
            tags=tags,
            timeouts=timeouts,
            count=count,
            depends_on=depends_on,
            lifecycle=lifecycle,
            provider=provider,
        )

        jsii.create(AutomationRunbook, self, [scope, id, config])

    @jsii.member(jsii_name="synthesizeAttributes")
    def _synthesize_attributes(self) -> typing.Mapping[builtins.str, typing.Any]:
        return jsii.invoke(self, "synthesizeAttributes", [])

    @builtins.property # type: ignore
    @jsii.member(jsii_name="automationAccountName")
    def automation_account_name(self) -> builtins.str:
        return jsii.get(self, "automationAccountName")

    @automation_account_name.setter # type: ignore
    def automation_account_name(self, value: builtins.str) -> None:
        jsii.set(self, "automationAccountName", value)

    @builtins.property # type: ignore
    @jsii.member(jsii_name="location")
    def location(self) -> builtins.str:
        return jsii.get(self, "location")

    @location.setter # type: ignore
    def location(self, value: builtins.str) -> None:
        jsii.set(self, "location", value)

    @builtins.property # type: ignore
    @jsii.member(jsii_name="logProgress")
    def log_progress(self) -> builtins.bool:
        return jsii.get(self, "logProgress")

    @log_progress.setter # type: ignore
    def log_progress(self, value: builtins.bool) -> None:
        jsii.set(self, "logProgress", value)

    @builtins.property # type: ignore
    @jsii.member(jsii_name="logVerbose")
    def log_verbose(self) -> builtins.bool:
        return jsii.get(self, "logVerbose")

    @log_verbose.setter # type: ignore
    def log_verbose(self, value: builtins.bool) -> None:
        jsii.set(self, "logVerbose", value)

    @builtins.property # type: ignore
    @jsii.member(jsii_name="name")
    def name(self) -> builtins.str:
        return jsii.get(self, "name")

    @name.setter # type: ignore
    def name(self, value: builtins.str) -> None:
        jsii.set(self, "name", value)

    @builtins.property # type: ignore
    @jsii.member(jsii_name="publishContentLink")
    def publish_content_link(
        self,
    ) -> typing.List["AutomationRunbookPublishContentLink"]:
        return jsii.get(self, "publishContentLink")

    @publish_content_link.setter # type: ignore
    def publish_content_link(
        self,
        value: typing.List["AutomationRunbookPublishContentLink"],
    ) -> None:
        jsii.set(self, "publishContentLink", value)

    @builtins.property # type: ignore
    @jsii.member(jsii_name="resourceGroupName")
    def resource_group_name(self) -> builtins.str:
        return jsii.get(self, "resourceGroupName")

    @resource_group_name.setter # type: ignore
    def resource_group_name(self, value: builtins.str) -> None:
        jsii.set(self, "resourceGroupName", value)

    @builtins.property # type: ignore
    @jsii.member(jsii_name="runbookType")
    def runbook_type(self) -> builtins.str:
        return jsii.get(self, "runbookType")

    @runbook_type.setter # type: ignore
    def runbook_type(self, value: builtins.str) -> None:
        jsii.set(self, "runbookType", value)

    @builtins.property # type: ignore
    @jsii.member(jsii_name="content")
    def content(self) -> typing.Optional[builtins.str]:
        return jsii.get(self, "content")

    @content.setter # type: ignore
    def content(self, value: typing.Optional[builtins.str]) -> None:
        jsii.set(self, "content", value)

    @builtins.property # type: ignore
    @jsii.member(jsii_name="description")
    def description(self) -> typing.Optional[builtins.str]:
        return jsii.get(self, "description")

    @description.setter # type: ignore
    def description(self, value: typing.Optional[builtins.str]) -> None:
        jsii.set(self, "description", value)

    @builtins.property # type: ignore
    @jsii.member(jsii_name="id")
    def id(self) -> typing.Optional[builtins.str]:
        return jsii.get(self, "id")

    @id.setter # type: ignore
    def id(self, value: typing.Optional[builtins.str]) -> None:
        jsii.set(self, "id", value)

    @builtins.property # type: ignore
    @jsii.member(jsii_name="tags")
    def tags(self) -> typing.Optional[typing.Mapping[builtins.str, builtins.str]]:
        return jsii.get(self, "tags")

    @tags.setter # type: ignore
    def tags(
        self,
        value: typing.Optional[typing.Mapping[builtins.str, builtins.str]],
    ) -> None:
        jsii.set(self, "tags", value)

    @builtins.property # type: ignore
    @jsii.member(jsii_name="timeouts")
    def timeouts(self) -> typing.Optional["AutomationRunbookTimeouts"]:
        return jsii.get(self, "timeouts")

    @timeouts.setter # type: ignore
    def timeouts(self, value: typing.Optional["AutomationRunbookTimeouts"]) -> None:
        jsii.set(self, "timeouts", value)


@jsii.data_type(
    jsii_type="@cdktf/provider-azurerm.AutomationRunbookConfig",
    jsii_struct_bases=[cdktf.TerraformMetaArguments],
    name_mapping={
        "count": "count",
        "depends_on": "dependsOn",
        "lifecycle": "lifecycle",
        "provider": "provider",
        "automation_account_name": "automationAccountName",
        "location": "location",
        "log_progress": "logProgress",
        "log_verbose": "logVerbose",
        "name": "name",
        "publish_content_link": "publishContentLink",
        "resource_group_name": "resourceGroupName",
        "runbook_type": "runbookType",
        "content": "content",
        "description": "description",
        "tags": "tags",
        "timeouts": "timeouts",
    },
)
class AutomationRunbookConfig(cdktf.TerraformMetaArguments):
    def __init__(
        self,
        *,
        count: typing.Optional[jsii.Number] = None,
        depends_on: typing.Optional[typing.List[cdktf.TerraformResource]] = None,
        lifecycle: typing.Optional[cdktf.TerraformResourceLifecycle] = None,
        provider: typing.Optional[cdktf.TerraformProvider] = None,
        automation_account_name: builtins.str,
        location: builtins.str,
        log_progress: builtins.bool,
        log_verbose: builtins.bool,
        name: builtins.str,
        publish_content_link: typing.List["AutomationRunbookPublishContentLink"],
        resource_group_name: builtins.str,
        runbook_type: builtins.str,
        content: typing.Optional[builtins.str] = None,
        description: typing.Optional[builtins.str] = None,
        tags: typing.Optional[typing.Mapping[builtins.str, builtins.str]] = None,
        timeouts: typing.Optional["AutomationRunbookTimeouts"] = None,
    ) -> None:
        """
        :param count: 
        :param depends_on: 
        :param lifecycle: 
        :param provider: 
        :param automation_account_name: 
        :param location: 
        :param log_progress: 
        :param log_verbose: 
        :param name: 
        :param publish_content_link: publish_content_link block.
        :param resource_group_name: 
        :param runbook_type: 
        :param content: 
        :param description: 
        :param tags: 
        :param timeouts: timeouts block.
        """
        if isinstance(lifecycle, dict):
            lifecycle = cdktf.TerraformResourceLifecycle(**lifecycle)
        if isinstance(timeouts, dict):
            timeouts = AutomationRunbookTimeouts(**timeouts)
        self._values: typing.Dict[str, typing.Any] = {
            "automation_account_name": automation_account_name,
            "location": location,
            "log_progress": log_progress,
            "log_verbose": log_verbose,
            "name": name,
            "publish_content_link": publish_content_link,
            "resource_group_name": resource_group_name,
            "runbook_type": runbook_type,
        }
        if count is not None:
            self._values["count"] = count
        if depends_on is not None:
            self._values["depends_on"] = depends_on
        if lifecycle is not None:
            self._values["lifecycle"] = lifecycle
        if provider is not None:
            self._values["provider"] = provider
        if content is not None:
            self._values["content"] = content
        if description is not None:
            self._values["description"] = description
        if tags is not None:
            self._values["tags"] = tags
        if timeouts is not None:
            self._values["timeouts"] = timeouts

    @builtins.property
    def count(self) -> typing.Optional[jsii.Number]:
        """
        :stability: experimental
        """
        result = self._values.get("count")
        return result

    @builtins.property
    def depends_on(self) -> typing.Optional[typing.List[cdktf.TerraformResource]]:
        """
        :stability: experimental
        """
        result = self._values.get("depends_on")
        return result

    @builtins.property
    def lifecycle(self) -> typing.Optional[cdktf.TerraformResourceLifecycle]:
        """
        :stability: experimental
        """
        result = self._values.get("lifecycle")
        return result

    @builtins.property
    def provider(self) -> typing.Optional[cdktf.TerraformProvider]:
        """
        :stability: experimental
        """
        result = self._values.get("provider")
        return result

    @builtins.property
    def automation_account_name(self) -> builtins.str:
        result = self._values.get("automation_account_name")
        assert result is not None, "Required property 'automation_account_name' is missing"
        return result

    @builtins.property
    def location(self) -> builtins.str:
        result = self._values.get("location")
        assert result is not None, "Required property 'location' is missing"
        return result

    @builtins.property
    def log_progress(self) -> builtins.bool:
        result = self._values.get("log_progress")
        assert result is not None, "Required property 'log_progress' is missing"
        return result

    @builtins.property
    def log_verbose(self) -> builtins.bool:
        result = self._values.get("log_verbose")
        assert result is not None, "Required property 'log_verbose' is missing"
        return result

    @builtins.property
    def name(self) -> builtins.str:
        result = self._values.get("name")
        assert result is not None, "Required property 'name' is missing"
        return result

    @builtins.property
    def publish_content_link(
        self,
    ) -> typing.List["AutomationRunbookPublishContentLink"]:
        """publish_content_link block."""
        result = self._values.get("publish_content_link")
        assert result is not None, "Required property 'publish_content_link' is missing"
        return result

    @builtins.property
    def resource_group_name(self) -> builtins.str:
        result = self._values.get("resource_group_name")
        assert result is not None, "Required property 'resource_group_name' is missing"
        return result

    @builtins.property
    def runbook_type(self) -> builtins.str:
        result = self._values.get("runbook_type")
        assert result is not None, "Required property 'runbook_type' is missing"
        return result

    @builtins.property
    def content(self) -> typing.Optional[builtins.str]:
        result = self._values.get("content")
        return result

    @builtins.property
    def description(self) -> typing.Optional[builtins.str]:
        result = self._values.get("description")
        return result

    @builtins.property
    def tags(self) -> typing.Optional[typing.Mapping[builtins.str, builtins.str]]:
        result = self._values.get("tags")
        return result

    @builtins.property
    def timeouts(self) -> typing.Optional["AutomationRunbookTimeouts"]:
        """timeouts block."""
        result = self._values.get("timeouts")
        return result

    def __eq__(self, rhs: typing.Any) -> builtins.bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs: typing.Any) -> builtins.bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return "AutomationRunbookConfig(%s)" % ", ".join(
            k + "=" + repr(v) for k, v in self._values.items()
        )


@jsii.data_type(
    jsii_type="@cdktf/provider-azurerm.AutomationRunbookPublishContentLink",
    jsii_struct_bases=[],
    name_mapping={"uri": "uri", "hash": "hash", "version": "version"},
)
class AutomationRunbookPublishContentLink:
    def __init__(
        self,
        *,
        uri: builtins.str,
        hash: typing.Optional[typing.List["AutomationRunbookPublishContentLinkHash"]] = None,
        version: typing.Optional[builtins.str] = None,
    ) -> None:
        """
        :param uri: 
        :param hash: hash block.
        :param version: 
        """
        self._values: typing.Dict[str, typing.Any] = {
            "uri": uri,
        }
        if hash is not None:
            self._values["hash"] = hash
        if version is not None:
            self._values["version"] = version

    @builtins.property
    def uri(self) -> builtins.str:
        result = self._values.get("uri")
        assert result is not None, "Required property 'uri' is missing"
        return result

    @builtins.property
    def hash(
        self,
    ) -> typing.Optional[typing.List["AutomationRunbookPublishContentLinkHash"]]:
        """hash block."""
        result = self._values.get("hash")
        return result

    @builtins.property
    def version(self) -> typing.Optional[builtins.str]:
        result = self._values.get("version")
        return result

    def __eq__(self, rhs: typing.Any) -> builtins.bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs: typing.Any) -> builtins.bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return "AutomationRunbookPublishContentLink(%s)" % ", ".join(
            k + "=" + repr(v) for k, v in self._values.items()
        )


@jsii.data_type(
    jsii_type="@cdktf/provider-azurerm.AutomationRunbookPublishContentLinkHash",
    jsii_struct_bases=[],
    name_mapping={"algorithm": "algorithm", "value": "value"},
)
class AutomationRunbookPublishContentLinkHash:
    def __init__(self, *, algorithm: builtins.str, value: builtins.str) -> None:
        """
        :param algorithm: 
        :param value: 
        """
        self._values: typing.Dict[str, typing.Any] = {
            "algorithm": algorithm,
            "value": value,
        }

    @builtins.property
    def algorithm(self) -> builtins.str:
        result = self._values.get("algorithm")
        assert result is not None, "Required property 'algorithm' is missing"
        return result

    @builtins.property
    def value(self) -> builtins.str:
        result = self._values.get("value")
        assert result is not None, "Required property 'value' is missing"
        return result

    def __eq__(self, rhs: typing.Any) -> builtins.bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs: typing.Any) -> builtins.bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return "AutomationRunbookPublishContentLinkHash(%s)" % ", ".join(
            k + "=" + repr(v) for k, v in self._values.items()
        )


@jsii.data_type(
    jsii_type="@cdktf/provider-azurerm.AutomationRunbookTimeouts",
    jsii_struct_bases=[],
    name_mapping={
        "create": "create",
        "delete": "delete",
        "read": "read",
        "update": "update",
    },
)
class AutomationRunbookTimeouts:
    def __init__(
        self,
        *,
        create: typing.Optional[builtins.str] = None,
        delete: typing.Optional[builtins.str] = None,
        read: typing.Optional[builtins.str] = None,
        update: typing.Optional[builtins.str] = None,
    ) -> None:
        """
        :param create: 
        :param delete: 
        :param read: 
        :param update: 
        """
        self._values: typing.Dict[str, typing.Any] = {}
        if create is not None:
            self._values["create"] = create
        if delete is not None:
            self._values["delete"] = delete
        if read is not None:
            self._values["read"] = read
        if update is not None:
            self._values["update"] = update

    @builtins.property
    def create(self) -> typing.Optional[builtins.str]:
        result = self._values.get("create")
        return result

    @builtins.property
    def delete(self) -> typing.Optional[builtins.str]:
        result = self._values.get("delete")
        return result

    @builtins.property
    def read(self) -> typing.Optional[builtins.str]:
        result = self._values.get("read")
        return result

    @builtins.property
    def update(self) -> typing.Optional[builtins.str]:
        result = self._values.get("update")
        return result

    def __eq__(self, rhs: typing.Any) -> builtins.bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs: typing.Any) -> builtins.bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return "AutomationRunbookTimeouts(%s)" % ", ".join(
            k + "=" + repr(v) for k, v in self._values.items()
        )


class AutomationSchedule(
    cdktf.TerraformResource,
    metaclass=jsii.JSIIMeta,
    jsii_type="@cdktf/provider-azurerm.AutomationSchedule",
):
    def __init__(
        self,
        scope: constructs.Construct,
        id: builtins.str,
        *,
        automation_account_name: builtins.str,
        frequency: builtins.str,
        name: builtins.str,
        resource_group_name: builtins.str,
        description: typing.Optional[builtins.str] = None,
        expiry_time: typing.Optional[builtins.str] = None,
        interval: typing.Optional[jsii.Number] = None,
        month_days: typing.Optional[typing.List[jsii.Number]] = None,
        monthly_occurrence: typing.Optional[typing.List["AutomationScheduleMonthlyOccurrence"]] = None,
        start_time: typing.Optional[builtins.str] = None,
        timeouts: typing.Optional["AutomationScheduleTimeouts"] = None,
        timezone: typing.Optional[builtins.str] = None,
        week_days: typing.Optional[typing.List[builtins.str]] = None,
        count: typing.Optional[jsii.Number] = None,
        depends_on: typing.Optional[typing.List[cdktf.TerraformResource]] = None,
        lifecycle: typing.Optional[cdktf.TerraformResourceLifecycle] = None,
        provider: typing.Optional[cdktf.TerraformProvider] = None,
    ) -> None:
        """
        :param scope: -
        :param id: -
        :param automation_account_name: 
        :param frequency: 
        :param name: 
        :param resource_group_name: 
        :param description: 
        :param expiry_time: 
        :param interval: 
        :param month_days: 
        :param monthly_occurrence: monthly_occurrence block.
        :param start_time: 
        :param timeouts: timeouts block.
        :param timezone: 
        :param week_days: 
        :param count: 
        :param depends_on: 
        :param lifecycle: 
        :param provider: 
        """
        config = AutomationScheduleConfig(
            automation_account_name=automation_account_name,
            frequency=frequency,
            name=name,
            resource_group_name=resource_group_name,
            description=description,
            expiry_time=expiry_time,
            interval=interval,
            month_days=month_days,
            monthly_occurrence=monthly_occurrence,
            start_time=start_time,
            timeouts=timeouts,
            timezone=timezone,
            week_days=week_days,
            count=count,
            depends_on=depends_on,
            lifecycle=lifecycle,
            provider=provider,
        )

        jsii.create(AutomationSchedule, self, [scope, id, config])

    @jsii.member(jsii_name="synthesizeAttributes")
    def _synthesize_attributes(self) -> typing.Mapping[builtins.str, typing.Any]:
        return jsii.invoke(self, "synthesizeAttributes", [])

    @builtins.property # type: ignore
    @jsii.member(jsii_name="automationAccountName")
    def automation_account_name(self) -> builtins.str:
        return jsii.get(self, "automationAccountName")

    @automation_account_name.setter # type: ignore
    def automation_account_name(self, value: builtins.str) -> None:
        jsii.set(self, "automationAccountName", value)

    @builtins.property # type: ignore
    @jsii.member(jsii_name="frequency")
    def frequency(self) -> builtins.str:
        return jsii.get(self, "frequency")

    @frequency.setter # type: ignore
    def frequency(self, value: builtins.str) -> None:
        jsii.set(self, "frequency", value)

    @builtins.property # type: ignore
    @jsii.member(jsii_name="name")
    def name(self) -> builtins.str:
        return jsii.get(self, "name")

    @name.setter # type: ignore
    def name(self, value: builtins.str) -> None:
        jsii.set(self, "name", value)

    @builtins.property # type: ignore
    @jsii.member(jsii_name="resourceGroupName")
    def resource_group_name(self) -> builtins.str:
        return jsii.get(self, "resourceGroupName")

    @resource_group_name.setter # type: ignore
    def resource_group_name(self, value: builtins.str) -> None:
        jsii.set(self, "resourceGroupName", value)

    @builtins.property # type: ignore
    @jsii.member(jsii_name="description")
    def description(self) -> typing.Optional[builtins.str]:
        return jsii.get(self, "description")

    @description.setter # type: ignore
    def description(self, value: typing.Optional[builtins.str]) -> None:
        jsii.set(self, "description", value)

    @builtins.property # type: ignore
    @jsii.member(jsii_name="expiryTime")
    def expiry_time(self) -> typing.Optional[builtins.str]:
        return jsii.get(self, "expiryTime")

    @expiry_time.setter # type: ignore
    def expiry_time(self, value: typing.Optional[builtins.str]) -> None:
        jsii.set(self, "expiryTime", value)

    @builtins.property # type: ignore
    @jsii.member(jsii_name="id")
    def id(self) -> typing.Optional[builtins.str]:
        return jsii.get(self, "id")

    @id.setter # type: ignore
    def id(self, value: typing.Optional[builtins.str]) -> None:
        jsii.set(self, "id", value)

    @builtins.property # type: ignore
    @jsii.member(jsii_name="interval")
    def interval(self) -> typing.Optional[jsii.Number]:
        return jsii.get(self, "interval")

    @interval.setter # type: ignore
    def interval(self, value: typing.Optional[jsii.Number]) -> None:
        jsii.set(self, "interval", value)

    @builtins.property # type: ignore
    @jsii.member(jsii_name="monthDays")
    def month_days(self) -> typing.Optional[typing.List[jsii.Number]]:
        return jsii.get(self, "monthDays")

    @month_days.setter # type: ignore
    def month_days(self, value: typing.Optional[typing.List[jsii.Number]]) -> None:
        jsii.set(self, "monthDays", value)

    @builtins.property # type: ignore
    @jsii.member(jsii_name="monthlyOccurrence")
    def monthly_occurrence(
        self,
    ) -> typing.Optional[typing.List["AutomationScheduleMonthlyOccurrence"]]:
        return jsii.get(self, "monthlyOccurrence")

    @monthly_occurrence.setter # type: ignore
    def monthly_occurrence(
        self,
        value: typing.Optional[typing.List["AutomationScheduleMonthlyOccurrence"]],
    ) -> None:
        jsii.set(self, "monthlyOccurrence", value)

    @builtins.property # type: ignore
    @jsii.member(jsii_name="startTime")
    def start_time(self) -> typing.Optional[builtins.str]:
        return jsii.get(self, "startTime")

    @start_time.setter # type: ignore
    def start_time(self, value: typing.Optional[builtins.str]) -> None:
        jsii.set(self, "startTime", value)

    @builtins.property # type: ignore
    @jsii.member(jsii_name="timeouts")
    def timeouts(self) -> typing.Optional["AutomationScheduleTimeouts"]:
        return jsii.get(self, "timeouts")

    @timeouts.setter # type: ignore
    def timeouts(self, value: typing.Optional["AutomationScheduleTimeouts"]) -> None:
        jsii.set(self, "timeouts", value)

    @builtins.property # type: ignore
    @jsii.member(jsii_name="timezone")
    def timezone(self) -> typing.Optional[builtins.str]:
        return jsii.get(self, "timezone")

    @timezone.setter # type: ignore
    def timezone(self, value: typing.Optional[builtins.str]) -> None:
        jsii.set(self, "timezone", value)

    @builtins.property # type: ignore
    @jsii.member(jsii_name="weekDays")
    def week_days(self) -> typing.Optional[typing.List[builtins.str]]:
        return jsii.get(self, "weekDays")

    @week_days.setter # type: ignore
    def week_days(self, value: typing.Optional[typing.List[builtins.str]]) -> None:
        jsii.set(self, "weekDays", value)


@jsii.data_type(
    jsii_type="@cdktf/provider-azurerm.AutomationScheduleConfig",
    jsii_struct_bases=[cdktf.TerraformMetaArguments],
    name_mapping={
        "count": "count",
        "depends_on": "dependsOn",
        "lifecycle": "lifecycle",
        "provider": "provider",
        "automation_account_name": "automationAccountName",
        "frequency": "frequency",
        "name": "name",
        "resource_group_name": "resourceGroupName",
        "description": "description",
        "expiry_time": "expiryTime",
        "interval": "interval",
        "month_days": "monthDays",
        "monthly_occurrence": "monthlyOccurrence",
        "start_time": "startTime",
        "timeouts": "timeouts",
        "timezone": "timezone",
        "week_days": "weekDays",
    },
)
class AutomationScheduleConfig(cdktf.TerraformMetaArguments):
    def __init__(
        self,
        *,
        count: typing.Optional[jsii.Number] = None,
        depends_on: typing.Optional[typing.List[cdktf.TerraformResource]] = None,
        lifecycle: typing.Optional[cdktf.TerraformResourceLifecycle] = None,
        provider: typing.Optional[cdktf.TerraformProvider] = None,
        automation_account_name: builtins.str,
        frequency: builtins.str,
        name: builtins.str,
        resource_group_name: builtins.str,
        description: typing.Optional[builtins.str] = None,
        expiry_time: typing.Optional[builtins.str] = None,
        interval: typing.Optional[jsii.Number] = None,
        month_days: typing.Optional[typing.List[jsii.Number]] = None,
        monthly_occurrence: typing.Optional[typing.List["AutomationScheduleMonthlyOccurrence"]] = None,
        start_time: typing.Optional[builtins.str] = None,
        timeouts: typing.Optional["AutomationScheduleTimeouts"] = None,
        timezone: typing.Optional[builtins.str] = None,
        week_days: typing.Optional[typing.List[builtins.str]] = None,
    ) -> None:
        """
        :param count: 
        :param depends_on: 
        :param lifecycle: 
        :param provider: 
        :param automation_account_name: 
        :param frequency: 
        :param name: 
        :param resource_group_name: 
        :param description: 
        :param expiry_time: 
        :param interval: 
        :param month_days: 
        :param monthly_occurrence: monthly_occurrence block.
        :param start_time: 
        :param timeouts: timeouts block.
        :param timezone: 
        :param week_days: 
        """
        if isinstance(lifecycle, dict):
            lifecycle = cdktf.TerraformResourceLifecycle(**lifecycle)
        if isinstance(timeouts, dict):
            timeouts = AutomationScheduleTimeouts(**timeouts)
        self._values: typing.Dict[str, typing.Any] = {
            "automation_account_name": automation_account_name,
            "frequency": frequency,
            "name": name,
            "resource_group_name": resource_group_name,
        }
        if count is not None:
            self._values["count"] = count
        if depends_on is not None:
            self._values["depends_on"] = depends_on
        if lifecycle is not None:
            self._values["lifecycle"] = lifecycle
        if provider is not None:
            self._values["provider"] = provider
        if description is not None:
            self._values["description"] = description
        if expiry_time is not None:
            self._values["expiry_time"] = expiry_time
        if interval is not None:
            self._values["interval"] = interval
        if month_days is not None:
            self._values["month_days"] = month_days
        if monthly_occurrence is not None:
            self._values["monthly_occurrence"] = monthly_occurrence
        if start_time is not None:
            self._values["start_time"] = start_time
        if timeouts is not None:
            self._values["timeouts"] = timeouts
        if timezone is not None:
            self._values["timezone"] = timezone
        if week_days is not None:
            self._values["week_days"] = week_days

    @builtins.property
    def count(self) -> typing.Optional[jsii.Number]:
        """
        :stability: experimental
        """
        result = self._values.get("count")
        return result

    @builtins.property
    def depends_on(self) -> typing.Optional[typing.List[cdktf.TerraformResource]]:
        """
        :stability: experimental
        """
        result = self._values.get("depends_on")
        return result

    @builtins.property
    def lifecycle(self) -> typing.Optional[cdktf.TerraformResourceLifecycle]:
        """
        :stability: experimental
        """
        result = self._values.get("lifecycle")
        return result

    @builtins.property
    def provider(self) -> typing.Optional[cdktf.TerraformProvider]:
        """
        :stability: experimental
        """
        result = self._values.get("provider")
        return result

    @builtins.property
    def automation_account_name(self) -> builtins.str:
        result = self._values.get("automation_account_name")
        assert result is not None, "Required property 'automation_account_name' is missing"
        return result

    @builtins.property
    def frequency(self) -> builtins.str:
        result = self._values.get("frequency")
        assert result is not None, "Required property 'frequency' is missing"
        return result

    @builtins.property
    def name(self) -> builtins.str:
        result = self._values.get("name")
        assert result is not None, "Required property 'name' is missing"
        return result

    @builtins.property
    def resource_group_name(self) -> builtins.str:
        result = self._values.get("resource_group_name")
        assert result is not None, "Required property 'resource_group_name' is missing"
        return result

    @builtins.property
    def description(self) -> typing.Optional[builtins.str]:
        result = self._values.get("description")
        return result

    @builtins.property
    def expiry_time(self) -> typing.Optional[builtins.str]:
        result = self._values.get("expiry_time")
        return result

    @builtins.property
    def interval(self) -> typing.Optional[jsii.Number]:
        result = self._values.get("interval")
        return result

    @builtins.property
    def month_days(self) -> typing.Optional[typing.List[jsii.Number]]:
        result = self._values.get("month_days")
        return result

    @builtins.property
    def monthly_occurrence(
        self,
    ) -> typing.Optional[typing.List["AutomationScheduleMonthlyOccurrence"]]:
        """monthly_occurrence block."""
        result = self._values.get("monthly_occurrence")
        return result

    @builtins.property
    def start_time(self) -> typing.Optional[builtins.str]:
        result = self._values.get("start_time")
        return result

    @builtins.property
    def timeouts(self) -> typing.Optional["AutomationScheduleTimeouts"]:
        """timeouts block."""
        result = self._values.get("timeouts")
        return result

    @builtins.property
    def timezone(self) -> typing.Optional[builtins.str]:
        result = self._values.get("timezone")
        return result

    @builtins.property
    def week_days(self) -> typing.Optional[typing.List[builtins.str]]:
        result = self._values.get("week_days")
        return result

    def __eq__(self, rhs: typing.Any) -> builtins.bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs: typing.Any) -> builtins.bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return "AutomationScheduleConfig(%s)" % ", ".join(
            k + "=" + repr(v) for k, v in self._values.items()
        )


@jsii.data_type(
    jsii_type="@cdktf/provider-azurerm.AutomationScheduleMonthlyOccurrence",
    jsii_struct_bases=[],
    name_mapping={"day": "day", "occurrence": "occurrence"},
)
class AutomationScheduleMonthlyOccurrence:
    def __init__(self, *, day: builtins.str, occurrence: jsii.Number) -> None:
        """
        :param day: 
        :param occurrence: 
        """
        self._values: typing.Dict[str, typing.Any] = {
            "day": day,
            "occurrence": occurrence,
        }

    @builtins.property
    def day(self) -> builtins.str:
        result = self._values.get("day")
        assert result is not None, "Required property 'day' is missing"
        return result

    @builtins.property
    def occurrence(self) -> jsii.Number:
        result = self._values.get("occurrence")
        assert result is not None, "Required property 'occurrence' is missing"
        return result

    def __eq__(self, rhs: typing.Any) -> builtins.bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs: typing.Any) -> builtins.bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return "AutomationScheduleMonthlyOccurrence(%s)" % ", ".join(
            k + "=" + repr(v) for k, v in self._values.items()
        )


@jsii.data_type(
    jsii_type="@cdktf/provider-azurerm.AutomationScheduleTimeouts",
    jsii_struct_bases=[],
    name_mapping={
        "create": "create",
        "delete": "delete",
        "read": "read",
        "update": "update",
    },
)
class AutomationScheduleTimeouts:
    def __init__(
        self,
        *,
        create: typing.Optional[builtins.str] = None,
        delete: typing.Optional[builtins.str] = None,
        read: typing.Optional[builtins.str] = None,
        update: typing.Optional[builtins.str] = None,
    ) -> None:
        """
        :param create: 
        :param delete: 
        :param read: 
        :param update: 
        """
        self._values: typing.Dict[str, typing.Any] = {}
        if create is not None:
            self._values["create"] = create
        if delete is not None:
            self._values["delete"] = delete
        if read is not None:
            self._values["read"] = read
        if update is not None:
            self._values["update"] = update

    @builtins.property
    def create(self) -> typing.Optional[builtins.str]:
        result = self._values.get("create")
        return result

    @builtins.property
    def delete(self) -> typing.Optional[builtins.str]:
        result = self._values.get("delete")
        return result

    @builtins.property
    def read(self) -> typing.Optional[builtins.str]:
        result = self._values.get("read")
        return result

    @builtins.property
    def update(self) -> typing.Optional[builtins.str]:
        result = self._values.get("update")
        return result

    def __eq__(self, rhs: typing.Any) -> builtins.bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs: typing.Any) -> builtins.bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return "AutomationScheduleTimeouts(%s)" % ", ".join(
            k + "=" + repr(v) for k, v in self._values.items()
        )


class AutomationVariableBool(
    cdktf.TerraformResource,
    metaclass=jsii.JSIIMeta,
    jsii_type="@cdktf/provider-azurerm.AutomationVariableBool",
):
    def __init__(
        self,
        scope: constructs.Construct,
        id: builtins.str,
        *,
        automation_account_name: builtins.str,
        name: builtins.str,
        resource_group_name: builtins.str,
        description: typing.Optional[builtins.str] = None,
        encrypted: typing.Optional[builtins.bool] = None,
        timeouts: typing.Optional["AutomationVariableBoolTimeouts"] = None,
        value: typing.Optional[builtins.bool] = None,
        count: typing.Optional[jsii.Number] = None,
        depends_on: typing.Optional[typing.List[cdktf.TerraformResource]] = None,
        lifecycle: typing.Optional[cdktf.TerraformResourceLifecycle] = None,
        provider: typing.Optional[cdktf.TerraformProvider] = None,
    ) -> None:
        """
        :param scope: -
        :param id: -
        :param automation_account_name: 
        :param name: 
        :param resource_group_name: 
        :param description: 
        :param encrypted: 
        :param timeouts: timeouts block.
        :param value: 
        :param count: 
        :param depends_on: 
        :param lifecycle: 
        :param provider: 
        """
        config = AutomationVariableBoolConfig(
            automation_account_name=automation_account_name,
            name=name,
            resource_group_name=resource_group_name,
            description=description,
            encrypted=encrypted,
            timeouts=timeouts,
            value=value,
            count=count,
            depends_on=depends_on,
            lifecycle=lifecycle,
            provider=provider,
        )

        jsii.create(AutomationVariableBool, self, [scope, id, config])

    @jsii.member(jsii_name="synthesizeAttributes")
    def _synthesize_attributes(self) -> typing.Mapping[builtins.str, typing.Any]:
        return jsii.invoke(self, "synthesizeAttributes", [])

    @builtins.property # type: ignore
    @jsii.member(jsii_name="automationAccountName")
    def automation_account_name(self) -> builtins.str:
        return jsii.get(self, "automationAccountName")

    @automation_account_name.setter # type: ignore
    def automation_account_name(self, value: builtins.str) -> None:
        jsii.set(self, "automationAccountName", value)

    @builtins.property # type: ignore
    @jsii.member(jsii_name="name")
    def name(self) -> builtins.str:
        return jsii.get(self, "name")

    @name.setter # type: ignore
    def name(self, value: builtins.str) -> None:
        jsii.set(self, "name", value)

    @builtins.property # type: ignore
    @jsii.member(jsii_name="resourceGroupName")
    def resource_group_name(self) -> builtins.str:
        return jsii.get(self, "resourceGroupName")

    @resource_group_name.setter # type: ignore
    def resource_group_name(self, value: builtins.str) -> None:
        jsii.set(self, "resourceGroupName", value)

    @builtins.property # type: ignore
    @jsii.member(jsii_name="description")
    def description(self) -> typing.Optional[builtins.str]:
        return jsii.get(self, "description")

    @description.setter # type: ignore
    def description(self, value: typing.Optional[builtins.str]) -> None:
        jsii.set(self, "description", value)

    @builtins.property # type: ignore
    @jsii.member(jsii_name="encrypted")
    def encrypted(self) -> typing.Optional[builtins.bool]:
        return jsii.get(self, "encrypted")

    @encrypted.setter # type: ignore
    def encrypted(self, value: typing.Optional[builtins.bool]) -> None:
        jsii.set(self, "encrypted", value)

    @builtins.property # type: ignore
    @jsii.member(jsii_name="id")
    def id(self) -> typing.Optional[builtins.str]:
        return jsii.get(self, "id")

    @id.setter # type: ignore
    def id(self, value: typing.Optional[builtins.str]) -> None:
        jsii.set(self, "id", value)

    @builtins.property # type: ignore
    @jsii.member(jsii_name="timeouts")
    def timeouts(self) -> typing.Optional["AutomationVariableBoolTimeouts"]:
        return jsii.get(self, "timeouts")

    @timeouts.setter # type: ignore
    def timeouts(
        self,
        value: typing.Optional["AutomationVariableBoolTimeouts"],
    ) -> None:
        jsii.set(self, "timeouts", value)

    @builtins.property # type: ignore
    @jsii.member(jsii_name="value")
    def value(self) -> typing.Optional[builtins.bool]:
        return jsii.get(self, "value")

    @value.setter # type: ignore
    def value(self, value: typing.Optional[builtins.bool]) -> None:
        jsii.set(self, "value", value)


@jsii.data_type(
    jsii_type="@cdktf/provider-azurerm.AutomationVariableBoolConfig",
    jsii_struct_bases=[cdktf.TerraformMetaArguments],
    name_mapping={
        "count": "count",
        "depends_on": "dependsOn",
        "lifecycle": "lifecycle",
        "provider": "provider",
        "automation_account_name": "automationAccountName",
        "name": "name",
        "resource_group_name": "resourceGroupName",
        "description": "description",
        "encrypted": "encrypted",
        "timeouts": "timeouts",
        "value": "value",
    },
)
class AutomationVariableBoolConfig(cdktf.TerraformMetaArguments):
    def __init__(
        self,
        *,
        count: typing.Optional[jsii.Number] = None,
        depends_on: typing.Optional[typing.List[cdktf.TerraformResource]] = None,
        lifecycle: typing.Optional[cdktf.TerraformResourceLifecycle] = None,
        provider: typing.Optional[cdktf.TerraformProvider] = None,
        automation_account_name: builtins.str,
        name: builtins.str,
        resource_group_name: builtins.str,
        description: typing.Optional[builtins.str] = None,
        encrypted: typing.Optional[builtins.bool] = None,
        timeouts: typing.Optional["AutomationVariableBoolTimeouts"] = None,
        value: typing.Optional[builtins.bool] = None,
    ) -> None:
        """
        :param count: 
        :param depends_on: 
        :param lifecycle: 
        :param provider: 
        :param automation_account_name: 
        :param name: 
        :param resource_group_name: 
        :param description: 
        :param encrypted: 
        :param timeouts: timeouts block.
        :param value: 
        """
        if isinstance(lifecycle, dict):
            lifecycle = cdktf.TerraformResourceLifecycle(**lifecycle)
        if isinstance(timeouts, dict):
            timeouts = AutomationVariableBoolTimeouts(**timeouts)
        self._values: typing.Dict[str, typing.Any] = {
            "automation_account_name": automation_account_name,
            "name": name,
            "resource_group_name": resource_group_name,
        }
        if count is not None:
            self._values["count"] = count
        if depends_on is not None:
            self._values["depends_on"] = depends_on
        if lifecycle is not None:
            self._values["lifecycle"] = lifecycle
        if provider is not None:
            self._values["provider"] = provider
        if description is not None:
            self._values["description"] = description
        if encrypted is not None:
            self._values["encrypted"] = encrypted
        if timeouts is not None:
            self._values["timeouts"] = timeouts
        if value is not None:
            self._values["value"] = value

    @builtins.property
    def count(self) -> typing.Optional[jsii.Number]:
        """
        :stability: experimental
        """
        result = self._values.get("count")
        return result

    @builtins.property
    def depends_on(self) -> typing.Optional[typing.List[cdktf.TerraformResource]]:
        """
        :stability: experimental
        """
        result = self._values.get("depends_on")
        return result

    @builtins.property
    def lifecycle(self) -> typing.Optional[cdktf.TerraformResourceLifecycle]:
        """
        :stability: experimental
        """
        result = self._values.get("lifecycle")
        return result

    @builtins.property
    def provider(self) -> typing.Optional[cdktf.TerraformProvider]:
        """
        :stability: experimental
        """
        result = self._values.get("provider")
        return result

    @builtins.property
    def automation_account_name(self) -> builtins.str:
        result = self._values.get("automation_account_name")
        assert result is not None, "Required property 'automation_account_name' is missing"
        return result

    @builtins.property
    def name(self) -> builtins.str:
        result = self._values.get("name")
        assert result is not None, "Required property 'name' is missing"
        return result

    @builtins.property
    def resource_group_name(self) -> builtins.str:
        result = self._values.get("resource_group_name")
        assert result is not None, "Required property 'resource_group_name' is missing"
        return result

    @builtins.property
    def description(self) -> typing.Optional[builtins.str]:
        result = self._values.get("description")
        return result

    @builtins.property
    def encrypted(self) -> typing.Optional[builtins.bool]:
        result = self._values.get("encrypted")
        return result

    @builtins.property
    def timeouts(self) -> typing.Optional["AutomationVariableBoolTimeouts"]:
        """timeouts block."""
        result = self._values.get("timeouts")
        return result

    @builtins.property
    def value(self) -> typing.Optional[builtins.bool]:
        result = self._values.get("value")
        return result

    def __eq__(self, rhs: typing.Any) -> builtins.bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs: typing.Any) -> builtins.bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return "AutomationVariableBoolConfig(%s)" % ", ".join(
            k + "=" + repr(v) for k, v in self._values.items()
        )


@jsii.data_type(
    jsii_type="@cdktf/provider-azurerm.AutomationVariableBoolTimeouts",
    jsii_struct_bases=[],
    name_mapping={
        "create": "create",
        "delete": "delete",
        "read": "read",
        "update": "update",
    },
)
class AutomationVariableBoolTimeouts:
    def __init__(
        self,
        *,
        create: typing.Optional[builtins.str] = None,
        delete: typing.Optional[builtins.str] = None,
        read: typing.Optional[builtins.str] = None,
        update: typing.Optional[builtins.str] = None,
    ) -> None:
        """
        :param create: 
        :param delete: 
        :param read: 
        :param update: 
        """
        self._values: typing.Dict[str, typing.Any] = {}
        if create is not None:
            self._values["create"] = create
        if delete is not None:
            self._values["delete"] = delete
        if read is not None:
            self._values["read"] = read
        if update is not None:
            self._values["update"] = update

    @builtins.property
    def create(self) -> typing.Optional[builtins.str]:
        result = self._values.get("create")
        return result

    @builtins.property
    def delete(self) -> typing.Optional[builtins.str]:
        result = self._values.get("delete")
        return result

    @builtins.property
    def read(self) -> typing.Optional[builtins.str]:
        result = self._values.get("read")
        return result

    @builtins.property
    def update(self) -> typing.Optional[builtins.str]:
        result = self._values.get("update")
        return result

    def __eq__(self, rhs: typing.Any) -> builtins.bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs: typing.Any) -> builtins.bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return "AutomationVariableBoolTimeouts(%s)" % ", ".join(
            k + "=" + repr(v) for k, v in self._values.items()
        )


class AutomationVariableDatetime(
    cdktf.TerraformResource,
    metaclass=jsii.JSIIMeta,
    jsii_type="@cdktf/provider-azurerm.AutomationVariableDatetime",
):
    def __init__(
        self,
        scope: constructs.Construct,
        id: builtins.str,
        *,
        automation_account_name: builtins.str,
        name: builtins.str,
        resource_group_name: builtins.str,
        description: typing.Optional[builtins.str] = None,
        encrypted: typing.Optional[builtins.bool] = None,
        timeouts: typing.Optional["AutomationVariableDatetimeTimeouts"] = None,
        value: typing.Optional[builtins.str] = None,
        count: typing.Optional[jsii.Number] = None,
        depends_on: typing.Optional[typing.List[cdktf.TerraformResource]] = None,
        lifecycle: typing.Optional[cdktf.TerraformResourceLifecycle] = None,
        provider: typing.Optional[cdktf.TerraformProvider] = None,
    ) -> None:
        """
        :param scope: -
        :param id: -
        :param automation_account_name: 
        :param name: 
        :param resource_group_name: 
        :param description: 
        :param encrypted: 
        :param timeouts: timeouts block.
        :param value: 
        :param count: 
        :param depends_on: 
        :param lifecycle: 
        :param provider: 
        """
        config = AutomationVariableDatetimeConfig(
            automation_account_name=automation_account_name,
            name=name,
            resource_group_name=resource_group_name,
            description=description,
            encrypted=encrypted,
            timeouts=timeouts,
            value=value,
            count=count,
            depends_on=depends_on,
            lifecycle=lifecycle,
            provider=provider,
        )

        jsii.create(AutomationVariableDatetime, self, [scope, id, config])

    @jsii.member(jsii_name="synthesizeAttributes")
    def _synthesize_attributes(self) -> typing.Mapping[builtins.str, typing.Any]:
        return jsii.invoke(self, "synthesizeAttributes", [])

    @builtins.property # type: ignore
    @jsii.member(jsii_name="automationAccountName")
    def automation_account_name(self) -> builtins.str:
        return jsii.get(self, "automationAccountName")

    @automation_account_name.setter # type: ignore
    def automation_account_name(self, value: builtins.str) -> None:
        jsii.set(self, "automationAccountName", value)

    @builtins.property # type: ignore
    @jsii.member(jsii_name="name")
    def name(self) -> builtins.str:
        return jsii.get(self, "name")

    @name.setter # type: ignore
    def name(self, value: builtins.str) -> None:
        jsii.set(self, "name", value)

    @builtins.property # type: ignore
    @jsii.member(jsii_name="resourceGroupName")
    def resource_group_name(self) -> builtins.str:
        return jsii.get(self, "resourceGroupName")

    @resource_group_name.setter # type: ignore
    def resource_group_name(self, value: builtins.str) -> None:
        jsii.set(self, "resourceGroupName", value)

    @builtins.property # type: ignore
    @jsii.member(jsii_name="description")
    def description(self) -> typing.Optional[builtins.str]:
        return jsii.get(self, "description")

    @description.setter # type: ignore
    def description(self, value: typing.Optional[builtins.str]) -> None:
        jsii.set(self, "description", value)

    @builtins.property # type: ignore
    @jsii.member(jsii_name="encrypted")
    def encrypted(self) -> typing.Optional[builtins.bool]:
        return jsii.get(self, "encrypted")

    @encrypted.setter # type: ignore
    def encrypted(self, value: typing.Optional[builtins.bool]) -> None:
        jsii.set(self, "encrypted", value)

    @builtins.property # type: ignore
    @jsii.member(jsii_name="id")
    def id(self) -> typing.Optional[builtins.str]:
        return jsii.get(self, "id")

    @id.setter # type: ignore
    def id(self, value: typing.Optional[builtins.str]) -> None:
        jsii.set(self, "id", value)

    @builtins.property # type: ignore
    @jsii.member(jsii_name="timeouts")
    def timeouts(self) -> typing.Optional["AutomationVariableDatetimeTimeouts"]:
        return jsii.get(self, "timeouts")

    @timeouts.setter # type: ignore
    def timeouts(
        self,
        value: typing.Optional["AutomationVariableDatetimeTimeouts"],
    ) -> None:
        jsii.set(self, "timeouts", value)

    @builtins.property # type: ignore
    @jsii.member(jsii_name="value")
    def value(self) -> typing.Optional[builtins.str]:
        return jsii.get(self, "value")

    @value.setter # type: ignore
    def value(self, value: typing.Optional[builtins.str]) -> None:
        jsii.set(self, "value", value)


@jsii.data_type(
    jsii_type="@cdktf/provider-azurerm.AutomationVariableDatetimeConfig",
    jsii_struct_bases=[cdktf.TerraformMetaArguments],
    name_mapping={
        "count": "count",
        "depends_on": "dependsOn",
        "lifecycle": "lifecycle",
        "provider": "provider",
        "automation_account_name": "automationAccountName",
        "name": "name",
        "resource_group_name": "resourceGroupName",
        "description": "description",
        "encrypted": "encrypted",
        "timeouts": "timeouts",
        "value": "value",
    },
)
class AutomationVariableDatetimeConfig(cdktf.TerraformMetaArguments):
    def __init__(
        self,
        *,
        count: typing.Optional[jsii.Number] = None,
        depends_on: typing.Optional[typing.List[cdktf.TerraformResource]] = None,
        lifecycle: typing.Optional[cdktf.TerraformResourceLifecycle] = None,
        provider: typing.Optional[cdktf.TerraformProvider] = None,
        automation_account_name: builtins.str,
        name: builtins.str,
        resource_group_name: builtins.str,
        description: typing.Optional[builtins.str] = None,
        encrypted: typing.Optional[builtins.bool] = None,
        timeouts: typing.Optional["AutomationVariableDatetimeTimeouts"] = None,
        value: typing.Optional[builtins.str] = None,
    ) -> None:
        """
        :param count: 
        :param depends_on: 
        :param lifecycle: 
        :param provider: 
        :param automation_account_name: 
        :param name: 
        :param resource_group_name: 
        :param description: 
        :param encrypted: 
        :param timeouts: timeouts block.
        :param value: 
        """
        if isinstance(lifecycle, dict):
            lifecycle = cdktf.TerraformResourceLifecycle(**lifecycle)
        if isinstance(timeouts, dict):
            timeouts = AutomationVariableDatetimeTimeouts(**timeouts)
        self._values: typing.Dict[str, typing.Any] = {
            "automation_account_name": automation_account_name,
            "name": name,
            "resource_group_name": resource_group_name,
        }
        if count is not None:
            self._values["count"] = count
        if depends_on is not None:
            self._values["depends_on"] = depends_on
        if lifecycle is not None:
            self._values["lifecycle"] = lifecycle
        if provider is not None:
            self._values["provider"] = provider
        if description is not None:
            self._values["description"] = description
        if encrypted is not None:
            self._values["encrypted"] = encrypted
        if timeouts is not None:
            self._values["timeouts"] = timeouts
        if value is not None:
            self._values["value"] = value

    @builtins.property
    def count(self) -> typing.Optional[jsii.Number]:
        """
        :stability: experimental
        """
        result = self._values.get("count")
        return result

    @builtins.property
    def depends_on(self) -> typing.Optional[typing.List[cdktf.TerraformResource]]:
        """
        :stability: experimental
        """
        result = self._values.get("depends_on")
        return result

    @builtins.property
    def lifecycle(self) -> typing.Optional[cdktf.TerraformResourceLifecycle]:
        """
        :stability: experimental
        """
        result = self._values.get("lifecycle")
        return result

    @builtins.property
    def provider(self) -> typing.Optional[cdktf.TerraformProvider]:
        """
        :stability: experimental
        """
        result = self._values.get("provider")
        return result

    @builtins.property
    def automation_account_name(self) -> builtins.str:
        result = self._values.get("automation_account_name")
        assert result is not None, "Required property 'automation_account_name' is missing"
        return result

    @builtins.property
    def name(self) -> builtins.str:
        result = self._values.get("name")
        assert result is not None, "Required property 'name' is missing"
        return result

    @builtins.property
    def resource_group_name(self) -> builtins.str:
        result = self._values.get("resource_group_name")
        assert result is not None, "Required property 'resource_group_name' is missing"
        return result

    @builtins.property
    def description(self) -> typing.Optional[builtins.str]:
        result = self._values.get("description")
        return result

    @builtins.property
    def encrypted(self) -> typing.Optional[builtins.bool]:
        result = self._values.get("encrypted")
        return result

    @builtins.property
    def timeouts(self) -> typing.Optional["AutomationVariableDatetimeTimeouts"]:
        """timeouts block."""
        result = self._values.get("timeouts")
        return result

    @builtins.property
    def value(self) -> typing.Optional[builtins.str]:
        result = self._values.get("value")
        return result

    def __eq__(self, rhs: typing.Any) -> builtins.bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs: typing.Any) -> builtins.bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return "AutomationVariableDatetimeConfig(%s)" % ", ".join(
            k + "=" + repr(v) for k, v in self._values.items()
        )


@jsii.data_type(
    jsii_type="@cdktf/provider-azurerm.AutomationVariableDatetimeTimeouts",
    jsii_struct_bases=[],
    name_mapping={
        "create": "create",
        "delete": "delete",
        "read": "read",
        "update": "update",
    },
)
class AutomationVariableDatetimeTimeouts:
    def __init__(
        self,
        *,
        create: typing.Optional[builtins.str] = None,
        delete: typing.Optional[builtins.str] = None,
        read: typing.Optional[builtins.str] = None,
        update: typing.Optional[builtins.str] = None,
    ) -> None:
        """
        :param create: 
        :param delete: 
        :param read: 
        :param update: 
        """
        self._values: typing.Dict[str, typing.Any] = {}
        if create is not None:
            self._values["create"] = create
        if delete is not None:
            self._values["delete"] = delete
        if read is not None:
            self._values["read"] = read
        if update is not None:
            self._values["update"] = update

    @builtins.property
    def create(self) -> typing.Optional[builtins.str]:
        result = self._values.get("create")
        return result

    @builtins.property
    def delete(self) -> typing.Optional[builtins.str]:
        result = self._values.get("delete")
        return result

    @builtins.property
    def read(self) -> typing.Optional[builtins.str]:
        result = self._values.get("read")
        return result

    @builtins.property
    def update(self) -> typing.Optional[builtins.str]:
        result = self._values.get("update")
        return result

    def __eq__(self, rhs: typing.Any) -> builtins.bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs: typing.Any) -> builtins.bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return "AutomationVariableDatetimeTimeouts(%s)" % ", ".join(
            k + "=" + repr(v) for k, v in self._values.items()
        )


class AutomationVariableInt(
    cdktf.TerraformResource,
    metaclass=jsii.JSIIMeta,
    jsii_type="@cdktf/provider-azurerm.AutomationVariableInt",
):
    def __init__(
        self,
        scope: constructs.Construct,
        id: builtins.str,
        *,
        automation_account_name: builtins.str,
        name: builtins.str,
        resource_group_name: builtins.str,
        description: typing.Optional[builtins.str] = None,
        encrypted: typing.Optional[builtins.bool] = None,
        timeouts: typing.Optional["AutomationVariableIntTimeouts"] = None,
        value: typing.Optional[jsii.Number] = None,
        count: typing.Optional[jsii.Number] = None,
        depends_on: typing.Optional[typing.List[cdktf.TerraformResource]] = None,
        lifecycle: typing.Optional[cdktf.TerraformResourceLifecycle] = None,
        provider: typing.Optional[cdktf.TerraformProvider] = None,
    ) -> None:
        """
        :param scope: -
        :param id: -
        :param automation_account_name: 
        :param name: 
        :param resource_group_name: 
        :param description: 
        :param encrypted: 
        :param timeouts: timeouts block.
        :param value: 
        :param count: 
        :param depends_on: 
        :param lifecycle: 
        :param provider: 
        """
        config = AutomationVariableIntConfig(
            automation_account_name=automation_account_name,
            name=name,
            resource_group_name=resource_group_name,
            description=description,
            encrypted=encrypted,
            timeouts=timeouts,
            value=value,
            count=count,
            depends_on=depends_on,
            lifecycle=lifecycle,
            provider=provider,
        )

        jsii.create(AutomationVariableInt, self, [scope, id, config])

    @jsii.member(jsii_name="synthesizeAttributes")
    def _synthesize_attributes(self) -> typing.Mapping[builtins.str, typing.Any]:
        return jsii.invoke(self, "synthesizeAttributes", [])

    @builtins.property # type: ignore
    @jsii.member(jsii_name="automationAccountName")
    def automation_account_name(self) -> builtins.str:
        return jsii.get(self, "automationAccountName")

    @automation_account_name.setter # type: ignore
    def automation_account_name(self, value: builtins.str) -> None:
        jsii.set(self, "automationAccountName", value)

    @builtins.property # type: ignore
    @jsii.member(jsii_name="name")
    def name(self) -> builtins.str:
        return jsii.get(self, "name")

    @name.setter # type: ignore
    def name(self, value: builtins.str) -> None:
        jsii.set(self, "name", value)

    @builtins.property # type: ignore
    @jsii.member(jsii_name="resourceGroupName")
    def resource_group_name(self) -> builtins.str:
        return jsii.get(self, "resourceGroupName")

    @resource_group_name.setter # type: ignore
    def resource_group_name(self, value: builtins.str) -> None:
        jsii.set(self, "resourceGroupName", value)

    @builtins.property # type: ignore
    @jsii.member(jsii_name="description")
    def description(self) -> typing.Optional[builtins.str]:
        return jsii.get(self, "description")

    @description.setter # type: ignore
    def description(self, value: typing.Optional[builtins.str]) -> None:
        jsii.set(self, "description", value)

    @builtins.property # type: ignore
    @jsii.member(jsii_name="encrypted")
    def encrypted(self) -> typing.Optional[builtins.bool]:
        return jsii.get(self, "encrypted")

    @encrypted.setter # type: ignore
    def encrypted(self, value: typing.Optional[builtins.bool]) -> None:
        jsii.set(self, "encrypted", value)

    @builtins.property # type: ignore
    @jsii.member(jsii_name="id")
    def id(self) -> typing.Optional[builtins.str]:
        return jsii.get(self, "id")

    @id.setter # type: ignore
    def id(self, value: typing.Optional[builtins.str]) -> None:
        jsii.set(self, "id", value)

    @builtins.property # type: ignore
    @jsii.member(jsii_name="timeouts")
    def timeouts(self) -> typing.Optional["AutomationVariableIntTimeouts"]:
        return jsii.get(self, "timeouts")

    @timeouts.setter # type: ignore
    def timeouts(self, value: typing.Optional["AutomationVariableIntTimeouts"]) -> None:
        jsii.set(self, "timeouts", value)

    @builtins.property # type: ignore
    @jsii.member(jsii_name="value")
    def value(self) -> typing.Optional[jsii.Number]:
        return jsii.get(self, "value")

    @value.setter # type: ignore
    def value(self, value: typing.Optional[jsii.Number]) -> None:
        jsii.set(self, "value", value)


@jsii.data_type(
    jsii_type="@cdktf/provider-azurerm.AutomationVariableIntConfig",
    jsii_struct_bases=[cdktf.TerraformMetaArguments],
    name_mapping={
        "count": "count",
        "depends_on": "dependsOn",
        "lifecycle": "lifecycle",
        "provider": "provider",
        "automation_account_name": "automationAccountName",
        "name": "name",
        "resource_group_name": "resourceGroupName",
        "description": "description",
        "encrypted": "encrypted",
        "timeouts": "timeouts",
        "value": "value",
    },
)
class AutomationVariableIntConfig(cdktf.TerraformMetaArguments):
    def __init__(
        self,
        *,
        count: typing.Optional[jsii.Number] = None,
        depends_on: typing.Optional[typing.List[cdktf.TerraformResource]] = None,
        lifecycle: typing.Optional[cdktf.TerraformResourceLifecycle] = None,
        provider: typing.Optional[cdktf.TerraformProvider] = None,
        automation_account_name: builtins.str,
        name: builtins.str,
        resource_group_name: builtins.str,
        description: typing.Optional[builtins.str] = None,
        encrypted: typing.Optional[builtins.bool] = None,
        timeouts: typing.Optional["AutomationVariableIntTimeouts"] = None,
        value: typing.Optional[jsii.Number] = None,
    ) -> None:
        """
        :param count: 
        :param depends_on: 
        :param lifecycle: 
        :param provider: 
        :param automation_account_name: 
        :param name: 
        :param resource_group_name: 
        :param description: 
        :param encrypted: 
        :param timeouts: timeouts block.
        :param value: 
        """
        if isinstance(lifecycle, dict):
            lifecycle = cdktf.TerraformResourceLifecycle(**lifecycle)
        if isinstance(timeouts, dict):
            timeouts = AutomationVariableIntTimeouts(**timeouts)
        self._values: typing.Dict[str, typing.Any] = {
            "automation_account_name": automation_account_name,
            "name": name,
            "resource_group_name": resource_group_name,
        }
        if count is not None:
            self._values["count"] = count
        if depends_on is not None:
            self._values["depends_on"] = depends_on
        if lifecycle is not None:
            self._values["lifecycle"] = lifecycle
        if provider is not None:
            self._values["provider"] = provider
        if description is not None:
            self._values["description"] = description
        if encrypted is not None:
            self._values["encrypted"] = encrypted
        if timeouts is not None:
            self._values["timeouts"] = timeouts
        if value is not None:
            self._values["value"] = value

    @builtins.property
    def count(self) -> typing.Optional[jsii.Number]:
        """
        :stability: experimental
        """
        result = self._values.get("count")
        return result

    @builtins.property
    def depends_on(self) -> typing.Optional[typing.List[cdktf.TerraformResource]]:
        """
        :stability: experimental
        """
        result = self._values.get("depends_on")
        return result

    @builtins.property
    def lifecycle(self) -> typing.Optional[cdktf.TerraformResourceLifecycle]:
        """
        :stability: experimental
        """
        result = self._values.get("lifecycle")
        return result

    @builtins.property
    def provider(self) -> typing.Optional[cdktf.TerraformProvider]:
        """
        :stability: experimental
        """
        result = self._values.get("provider")
        return result

    @builtins.property
    def automation_account_name(self) -> builtins.str:
        result = self._values.get("automation_account_name")
        assert result is not None, "Required property 'automation_account_name' is missing"
        return result

    @builtins.property
    def name(self) -> builtins.str:
        result = self._values.get("name")
        assert result is not None, "Required property 'name' is missing"
        return result

    @builtins.property
    def resource_group_name(self) -> builtins.str:
        result = self._values.get("resource_group_name")
        assert result is not None, "Required property 'resource_group_name' is missing"
        return result

    @builtins.property
    def description(self) -> typing.Optional[builtins.str]:
        result = self._values.get("description")
        return result

    @builtins.property
    def encrypted(self) -> typing.Optional[builtins.bool]:
        result = self._values.get("encrypted")
        return result

    @builtins.property
    def timeouts(self) -> typing.Optional["AutomationVariableIntTimeouts"]:
        """timeouts block."""
        result = self._values.get("timeouts")
        return result

    @builtins.property
    def value(self) -> typing.Optional[jsii.Number]:
        result = self._values.get("value")
        return result

    def __eq__(self, rhs: typing.Any) -> builtins.bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs: typing.Any) -> builtins.bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return "AutomationVariableIntConfig(%s)" % ", ".join(
            k + "=" + repr(v) for k, v in self._values.items()
        )


@jsii.data_type(
    jsii_type="@cdktf/provider-azurerm.AutomationVariableIntTimeouts",
    jsii_struct_bases=[],
    name_mapping={
        "create": "create",
        "delete": "delete",
        "read": "read",
        "update": "update",
    },
)
class AutomationVariableIntTimeouts:
    def __init__(
        self,
        *,
        create: typing.Optional[builtins.str] = None,
        delete: typing.Optional[builtins.str] = None,
        read: typing.Optional[builtins.str] = None,
        update: typing.Optional[builtins.str] = None,
    ) -> None:
        """
        :param create: 
        :param delete: 
        :param read: 
        :param update: 
        """
        self._values: typing.Dict[str, typing.Any] = {}
        if create is not None:
            self._values["create"] = create
        if delete is not None:
            self._values["delete"] = delete
        if read is not None:
            self._values["read"] = read
        if update is not None:
            self._values["update"] = update

    @builtins.property
    def create(self) -> typing.Optional[builtins.str]:
        result = self._values.get("create")
        return result

    @builtins.property
    def delete(self) -> typing.Optional[builtins.str]:
        result = self._values.get("delete")
        return result

    @builtins.property
    def read(self) -> typing.Optional[builtins.str]:
        result = self._values.get("read")
        return result

    @builtins.property
    def update(self) -> typing.Optional[builtins.str]:
        result = self._values.get("update")
        return result

    def __eq__(self, rhs: typing.Any) -> builtins.bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs: typing.Any) -> builtins.bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return "AutomationVariableIntTimeouts(%s)" % ", ".join(
            k + "=" + repr(v) for k, v in self._values.items()
        )


class AutomationVariableString(
    cdktf.TerraformResource,
    metaclass=jsii.JSIIMeta,
    jsii_type="@cdktf/provider-azurerm.AutomationVariableString",
):
    def __init__(
        self,
        scope: constructs.Construct,
        id: builtins.str,
        *,
        automation_account_name: builtins.str,
        name: builtins.str,
        resource_group_name: builtins.str,
        description: typing.Optional[builtins.str] = None,
        encrypted: typing.Optional[builtins.bool] = None,
        timeouts: typing.Optional["AutomationVariableStringTimeouts"] = None,
        value: typing.Optional[builtins.str] = None,
        count: typing.Optional[jsii.Number] = None,
        depends_on: typing.Optional[typing.List[cdktf.TerraformResource]] = None,
        lifecycle: typing.Optional[cdktf.TerraformResourceLifecycle] = None,
        provider: typing.Optional[cdktf.TerraformProvider] = None,
    ) -> None:
        """
        :param scope: -
        :param id: -
        :param automation_account_name: 
        :param name: 
        :param resource_group_name: 
        :param description: 
        :param encrypted: 
        :param timeouts: timeouts block.
        :param value: 
        :param count: 
        :param depends_on: 
        :param lifecycle: 
        :param provider: 
        """
        config = AutomationVariableStringConfig(
            automation_account_name=automation_account_name,
            name=name,
            resource_group_name=resource_group_name,
            description=description,
            encrypted=encrypted,
            timeouts=timeouts,
            value=value,
            count=count,
            depends_on=depends_on,
            lifecycle=lifecycle,
            provider=provider,
        )

        jsii.create(AutomationVariableString, self, [scope, id, config])

    @jsii.member(jsii_name="synthesizeAttributes")
    def _synthesize_attributes(self) -> typing.Mapping[builtins.str, typing.Any]:
        return jsii.invoke(self, "synthesizeAttributes", [])

    @builtins.property # type: ignore
    @jsii.member(jsii_name="automationAccountName")
    def automation_account_name(self) -> builtins.str:
        return jsii.get(self, "automationAccountName")

    @automation_account_name.setter # type: ignore
    def automation_account_name(self, value: builtins.str) -> None:
        jsii.set(self, "automationAccountName", value)

    @builtins.property # type: ignore
    @jsii.member(jsii_name="name")
    def name(self) -> builtins.str:
        return jsii.get(self, "name")

    @name.setter # type: ignore
    def name(self, value: builtins.str) -> None:
        jsii.set(self, "name", value)

    @builtins.property # type: ignore
    @jsii.member(jsii_name="resourceGroupName")
    def resource_group_name(self) -> builtins.str:
        return jsii.get(self, "resourceGroupName")

    @resource_group_name.setter # type: ignore
    def resource_group_name(self, value: builtins.str) -> None:
        jsii.set(self, "resourceGroupName", value)

    @builtins.property # type: ignore
    @jsii.member(jsii_name="description")
    def description(self) -> typing.Optional[builtins.str]:
        return jsii.get(self, "description")

    @description.setter # type: ignore
    def description(self, value: typing.Optional[builtins.str]) -> None:
        jsii.set(self, "description", value)

    @builtins.property # type: ignore
    @jsii.member(jsii_name="encrypted")
    def encrypted(self) -> typing.Optional[builtins.bool]:
        return jsii.get(self, "encrypted")

    @encrypted.setter # type: ignore
    def encrypted(self, value: typing.Optional[builtins.bool]) -> None:
        jsii.set(self, "encrypted", value)

    @builtins.property # type: ignore
    @jsii.member(jsii_name="id")
    def id(self) -> typing.Optional[builtins.str]:
        return jsii.get(self, "id")

    @id.setter # type: ignore
    def id(self, value: typing.Optional[builtins.str]) -> None:
        jsii.set(self, "id", value)

    @builtins.property # type: ignore
    @jsii.member(jsii_name="timeouts")
    def timeouts(self) -> typing.Optional["AutomationVariableStringTimeouts"]:
        return jsii.get(self, "timeouts")

    @timeouts.setter # type: ignore
    def timeouts(
        self,
        value: typing.Optional["AutomationVariableStringTimeouts"],
    ) -> None:
        jsii.set(self, "timeouts", value)

    @builtins.property # type: ignore
    @jsii.member(jsii_name="value")
    def value(self) -> typing.Optional[builtins.str]:
        return jsii.get(self, "value")

    @value.setter # type: ignore
    def value(self, value: typing.Optional[builtins.str]) -> None:
        jsii.set(self, "value", value)


@jsii.data_type(
    jsii_type="@cdktf/provider-azurerm.AutomationVariableStringConfig",
    jsii_struct_bases=[cdktf.TerraformMetaArguments],
    name_mapping={
        "count": "count",
        "depends_on": "dependsOn",
        "lifecycle": "lifecycle",
        "provider": "provider",
        "automation_account_name": "automationAccountName",
        "name": "name",
        "resource_group_name": "resourceGroupName",
        "description": "description",
        "encrypted": "encrypted",
        "timeouts": "timeouts",
        "value": "value",
    },
)
class AutomationVariableStringConfig(cdktf.TerraformMetaArguments):
    def __init__(
        self,
        *,
        count: typing.Optional[jsii.Number] = None,
        depends_on: typing.Optional[typing.List[cdktf.TerraformResource]] = None,
        lifecycle: typing.Optional[cdktf.TerraformResourceLifecycle] = None,
        provider: typing.Optional[cdktf.TerraformProvider] = None,
        automation_account_name: builtins.str,
        name: builtins.str,
        resource_group_name: builtins.str,
        description: typing.Optional[builtins.str] = None,
        encrypted: typing.Optional[builtins.bool] = None,
        timeouts: typing.Optional["AutomationVariableStringTimeouts"] = None,
        value: typing.Optional[builtins.str] = None,
    ) -> None:
        """
        :param count: 
        :param depends_on: 
        :param lifecycle: 
        :param provider: 
        :param automation_account_name: 
        :param name: 
        :param resource_group_name: 
        :param description: 
        :param encrypted: 
        :param timeouts: timeouts block.
        :param value: 
        """
        if isinstance(lifecycle, dict):
            lifecycle = cdktf.TerraformResourceLifecycle(**lifecycle)
        if isinstance(timeouts, dict):
            timeouts = AutomationVariableStringTimeouts(**timeouts)
        self._values: typing.Dict[str, typing.Any] = {
            "automation_account_name": automation_account_name,
            "name": name,
            "resource_group_name": resource_group_name,
        }
        if count is not None:
            self._values["count"] = count
        if depends_on is not None:
            self._values["depends_on"] = depends_on
        if lifecycle is not None:
            self._values["lifecycle"] = lifecycle
        if provider is not None:
            self._values["provider"] = provider
        if description is not None:
            self._values["description"] = description
        if encrypted is not None:
            self._values["encrypted"] = encrypted
        if timeouts is not None:
            self._values["timeouts"] = timeouts
        if value is not None:
            self._values["value"] = value

    @builtins.property
    def count(self) -> typing.Optional[jsii.Number]:
        """
        :stability: experimental
        """
        result = self._values.get("count")
        return result

    @builtins.property
    def depends_on(self) -> typing.Optional[typing.List[cdktf.TerraformResource]]:
        """
        :stability: experimental
        """
        result = self._values.get("depends_on")
        return result

    @builtins.property
    def lifecycle(self) -> typing.Optional[cdktf.TerraformResourceLifecycle]:
        """
        :stability: experimental
        """
        result = self._values.get("lifecycle")
        return result

    @builtins.property
    def provider(self) -> typing.Optional[cdktf.TerraformProvider]:
        """
        :stability: experimental
        """
        result = self._values.get("provider")
        return result

    @builtins.property
    def automation_account_name(self) -> builtins.str:
        result = self._values.get("automation_account_name")
        assert result is not None, "Required property 'automation_account_name' is missing"
        return result

    @builtins.property
    def name(self) -> builtins.str:
        result = self._values.get("name")
        assert result is not None, "Required property 'name' is missing"
        return result

    @builtins.property
    def resource_group_name(self) -> builtins.str:
        result = self._values.get("resource_group_name")
        assert result is not None, "Required property 'resource_group_name' is missing"
        return result

    @builtins.property
    def description(self) -> typing.Optional[builtins.str]:
        result = self._values.get("description")
        return result

    @builtins.property
    def encrypted(self) -> typing.Optional[builtins.bool]:
        result = self._values.get("encrypted")
        return result

    @builtins.property
    def timeouts(self) -> typing.Optional["AutomationVariableStringTimeouts"]:
        """timeouts block."""
        result = self._values.get("timeouts")
        return result

    @builtins.property
    def value(self) -> typing.Optional[builtins.str]:
        result = self._values.get("value")
        return result

    def __eq__(self, rhs: typing.Any) -> builtins.bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs: typing.Any) -> builtins.bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return "AutomationVariableStringConfig(%s)" % ", ".join(
            k + "=" + repr(v) for k, v in self._values.items()
        )


@jsii.data_type(
    jsii_type="@cdktf/provider-azurerm.AutomationVariableStringTimeouts",
    jsii_struct_bases=[],
    name_mapping={
        "create": "create",
        "delete": "delete",
        "read": "read",
        "update": "update",
    },
)
class AutomationVariableStringTimeouts:
    def __init__(
        self,
        *,
        create: typing.Optional[builtins.str] = None,
        delete: typing.Optional[builtins.str] = None,
        read: typing.Optional[builtins.str] = None,
        update: typing.Optional[builtins.str] = None,
    ) -> None:
        """
        :param create: 
        :param delete: 
        :param read: 
        :param update: 
        """
        self._values: typing.Dict[str, typing.Any] = {}
        if create is not None:
            self._values["create"] = create
        if delete is not None:
            self._values["delete"] = delete
        if read is not None:
            self._values["read"] = read
        if update is not None:
            self._values["update"] = update

    @builtins.property
    def create(self) -> typing.Optional[builtins.str]:
        result = self._values.get("create")
        return result

    @builtins.property
    def delete(self) -> typing.Optional[builtins.str]:
        result = self._values.get("delete")
        return result

    @builtins.property
    def read(self) -> typing.Optional[builtins.str]:
        result = self._values.get("read")
        return result

    @builtins.property
    def update(self) -> typing.Optional[builtins.str]:
        result = self._values.get("update")
        return result

    def __eq__(self, rhs: typing.Any) -> builtins.bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs: typing.Any) -> builtins.bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return "AutomationVariableStringTimeouts(%s)" % ", ".join(
            k + "=" + repr(v) for k, v in self._values.items()
        )


class AvailabilitySet(
    cdktf.TerraformResource,
    metaclass=jsii.JSIIMeta,
    jsii_type="@cdktf/provider-azurerm.AvailabilitySet",
):
    def __init__(
        self,
        scope: constructs.Construct,
        id: builtins.str,
        *,
        location: builtins.str,
        name: builtins.str,
        resource_group_name: builtins.str,
        managed: typing.Optional[builtins.bool] = None,
        platform_fault_domain_count: typing.Optional[jsii.Number] = None,
        platform_update_domain_count: typing.Optional[jsii.Number] = None,
        proximity_placement_group_id: typing.Optional[builtins.str] = None,
        tags: typing.Optional[typing.Mapping[builtins.str, builtins.str]] = None,
        timeouts: typing.Optional["AvailabilitySetTimeouts"] = None,
        count: typing.Optional[jsii.Number] = None,
        depends_on: typing.Optional[typing.List[cdktf.TerraformResource]] = None,
        lifecycle: typing.Optional[cdktf.TerraformResourceLifecycle] = None,
        provider: typing.Optional[cdktf.TerraformProvider] = None,
    ) -> None:
        """
        :param scope: -
        :param id: -
        :param location: 
        :param name: 
        :param resource_group_name: 
        :param managed: 
        :param platform_fault_domain_count: 
        :param platform_update_domain_count: 
        :param proximity_placement_group_id: 
        :param tags: 
        :param timeouts: timeouts block.
        :param count: 
        :param depends_on: 
        :param lifecycle: 
        :param provider: 
        """
        config = AvailabilitySetConfig(
            location=location,
            name=name,
            resource_group_name=resource_group_name,
            managed=managed,
            platform_fault_domain_count=platform_fault_domain_count,
            platform_update_domain_count=platform_update_domain_count,
            proximity_placement_group_id=proximity_placement_group_id,
            tags=tags,
            timeouts=timeouts,
            count=count,
            depends_on=depends_on,
            lifecycle=lifecycle,
            provider=provider,
        )

        jsii.create(AvailabilitySet, self, [scope, id, config])

    @jsii.member(jsii_name="synthesizeAttributes")
    def _synthesize_attributes(self) -> typing.Mapping[builtins.str, typing.Any]:
        return jsii.invoke(self, "synthesizeAttributes", [])

    @builtins.property # type: ignore
    @jsii.member(jsii_name="location")
    def location(self) -> builtins.str:
        return jsii.get(self, "location")

    @location.setter # type: ignore
    def location(self, value: builtins.str) -> None:
        jsii.set(self, "location", value)

    @builtins.property # type: ignore
    @jsii.member(jsii_name="name")
    def name(self) -> builtins.str:
        return jsii.get(self, "name")

    @name.setter # type: ignore
    def name(self, value: builtins.str) -> None:
        jsii.set(self, "name", value)

    @builtins.property # type: ignore
    @jsii.member(jsii_name="resourceGroupName")
    def resource_group_name(self) -> builtins.str:
        return jsii.get(self, "resourceGroupName")

    @resource_group_name.setter # type: ignore
    def resource_group_name(self, value: builtins.str) -> None:
        jsii.set(self, "resourceGroupName", value)

    @builtins.property # type: ignore
    @jsii.member(jsii_name="id")
    def id(self) -> typing.Optional[builtins.str]:
        return jsii.get(self, "id")

    @id.setter # type: ignore
    def id(self, value: typing.Optional[builtins.str]) -> None:
        jsii.set(self, "id", value)

    @builtins.property # type: ignore
    @jsii.member(jsii_name="managed")
    def managed(self) -> typing.Optional[builtins.bool]:
        return jsii.get(self, "managed")

    @managed.setter # type: ignore
    def managed(self, value: typing.Optional[builtins.bool]) -> None:
        jsii.set(self, "managed", value)

    @builtins.property # type: ignore
    @jsii.member(jsii_name="platformFaultDomainCount")
    def platform_fault_domain_count(self) -> typing.Optional[jsii.Number]:
        return jsii.get(self, "platformFaultDomainCount")

    @platform_fault_domain_count.setter # type: ignore
    def platform_fault_domain_count(self, value: typing.Optional[jsii.Number]) -> None:
        jsii.set(self, "platformFaultDomainCount", value)

    @builtins.property # type: ignore
    @jsii.member(jsii_name="platformUpdateDomainCount")
    def platform_update_domain_count(self) -> typing.Optional[jsii.Number]:
        return jsii.get(self, "platformUpdateDomainCount")

    @platform_update_domain_count.setter # type: ignore
    def platform_update_domain_count(self, value: typing.Optional[jsii.Number]) -> None:
        jsii.set(self, "platformUpdateDomainCount", value)

    @builtins.property # type: ignore
    @jsii.member(jsii_name="proximityPlacementGroupId")
    def proximity_placement_group_id(self) -> typing.Optional[builtins.str]:
        return jsii.get(self, "proximityPlacementGroupId")

    @proximity_placement_group_id.setter # type: ignore
    def proximity_placement_group_id(
        self,
        value: typing.Optional[builtins.str],
    ) -> None:
        jsii.set(self, "proximityPlacementGroupId", value)

    @builtins.property # type: ignore
    @jsii.member(jsii_name="tags")
    def tags(self) -> typing.Optional[typing.Mapping[builtins.str, builtins.str]]:
        return jsii.get(self, "tags")

    @tags.setter # type: ignore
    def tags(
        self,
        value: typing.Optional[typing.Mapping[builtins.str, builtins.str]],
    ) -> None:
        jsii.set(self, "tags", value)

    @builtins.property # type: ignore
    @jsii.member(jsii_name="timeouts")
    def timeouts(self) -> typing.Optional["AvailabilitySetTimeouts"]:
        return jsii.get(self, "timeouts")

    @timeouts.setter # type: ignore
    def timeouts(self, value: typing.Optional["AvailabilitySetTimeouts"]) -> None:
        jsii.set(self, "timeouts", value)


@jsii.data_type(
    jsii_type="@cdktf/provider-azurerm.AvailabilitySetConfig",
    jsii_struct_bases=[cdktf.TerraformMetaArguments],
    name_mapping={
        "count": "count",
        "depends_on": "dependsOn",
        "lifecycle": "lifecycle",
        "provider": "provider",
        "location": "location",
        "name": "name",
        "resource_group_name": "resourceGroupName",
        "managed": "managed",
        "platform_fault_domain_count": "platformFaultDomainCount",
        "platform_update_domain_count": "platformUpdateDomainCount",
        "proximity_placement_group_id": "proximityPlacementGroupId",
        "tags": "tags",
        "timeouts": "timeouts",
    },
)
class AvailabilitySetConfig(cdktf.TerraformMetaArguments):
    def __init__(
        self,
        *,
        count: typing.Optional[jsii.Number] = None,
        depends_on: typing.Optional[typing.List[cdktf.TerraformResource]] = None,
        lifecycle: typing.Optional[cdktf.TerraformResourceLifecycle] = None,
        provider: typing.Optional[cdktf.TerraformProvider] = None,
        location: builtins.str,
        name: builtins.str,
        resource_group_name: builtins.str,
        managed: typing.Optional[builtins.bool] = None,
        platform_fault_domain_count: typing.Optional[jsii.Number] = None,
        platform_update_domain_count: typing.Optional[jsii.Number] = None,
        proximity_placement_group_id: typing.Optional[builtins.str] = None,
        tags: typing.Optional[typing.Mapping[builtins.str, builtins.str]] = None,
        timeouts: typing.Optional["AvailabilitySetTimeouts"] = None,
    ) -> None:
        """
        :param count: 
        :param depends_on: 
        :param lifecycle: 
        :param provider: 
        :param location: 
        :param name: 
        :param resource_group_name: 
        :param managed: 
        :param platform_fault_domain_count: 
        :param platform_update_domain_count: 
        :param proximity_placement_group_id: 
        :param tags: 
        :param timeouts: timeouts block.
        """
        if isinstance(lifecycle, dict):
            lifecycle = cdktf.TerraformResourceLifecycle(**lifecycle)
        if isinstance(timeouts, dict):
            timeouts = AvailabilitySetTimeouts(**timeouts)
        self._values: typing.Dict[str, typing.Any] = {
            "location": location,
            "name": name,
            "resource_group_name": resource_group_name,
        }
        if count is not None:
            self._values["count"] = count
        if depends_on is not None:
            self._values["depends_on"] = depends_on
        if lifecycle is not None:
            self._values["lifecycle"] = lifecycle
        if provider is not None:
            self._values["provider"] = provider
        if managed is not None:
            self._values["managed"] = managed
        if platform_fault_domain_count is not None:
            self._values["platform_fault_domain_count"] = platform_fault_domain_count
        if platform_update_domain_count is not None:
            self._values["platform_update_domain_count"] = platform_update_domain_count
        if proximity_placement_group_id is not None:
            self._values["proximity_placement_group_id"] = proximity_placement_group_id
        if tags is not None:
            self._values["tags"] = tags
        if timeouts is not None:
            self._values["timeouts"] = timeouts

    @builtins.property
    def count(self) -> typing.Optional[jsii.Number]:
        """
        :stability: experimental
        """
        result = self._values.get("count")
        return result

    @builtins.property
    def depends_on(self) -> typing.Optional[typing.List[cdktf.TerraformResource]]:
        """
        :stability: experimental
        """
        result = self._values.get("depends_on")
        return result

    @builtins.property
    def lifecycle(self) -> typing.Optional[cdktf.TerraformResourceLifecycle]:
        """
        :stability: experimental
        """
        result = self._values.get("lifecycle")
        return result

    @builtins.property
    def provider(self) -> typing.Optional[cdktf.TerraformProvider]:
        """
        :stability: experimental
        """
        result = self._values.get("provider")
        return result

    @builtins.property
    def location(self) -> builtins.str:
        result = self._values.get("location")
        assert result is not None, "Required property 'location' is missing"
        return result

    @builtins.property
    def name(self) -> builtins.str:
        result = self._values.get("name")
        assert result is not None, "Required property 'name' is missing"
        return result

    @builtins.property
    def resource_group_name(self) -> builtins.str:
        result = self._values.get("resource_group_name")
        assert result is not None, "Required property 'resource_group_name' is missing"
        return result

    @builtins.property
    def managed(self) -> typing.Optional[builtins.bool]:
        result = self._values.get("managed")
        return result

    @builtins.property
    def platform_fault_domain_count(self) -> typing.Optional[jsii.Number]:
        result = self._values.get("platform_fault_domain_count")
        return result

    @builtins.property
    def platform_update_domain_count(self) -> typing.Optional[jsii.Number]:
        result = self._values.get("platform_update_domain_count")
        return result

    @builtins.property
    def proximity_placement_group_id(self) -> typing.Optional[builtins.str]:
        result = self._values.get("proximity_placement_group_id")
        return result

    @builtins.property
    def tags(self) -> typing.Optional[typing.Mapping[builtins.str, builtins.str]]:
        result = self._values.get("tags")
        return result

    @builtins.property
    def timeouts(self) -> typing.Optional["AvailabilitySetTimeouts"]:
        """timeouts block."""
        result = self._values.get("timeouts")
        return result

    def __eq__(self, rhs: typing.Any) -> builtins.bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs: typing.Any) -> builtins.bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return "AvailabilitySetConfig(%s)" % ", ".join(
            k + "=" + repr(v) for k, v in self._values.items()
        )


@jsii.data_type(
    jsii_type="@cdktf/provider-azurerm.AvailabilitySetTimeouts",
    jsii_struct_bases=[],
    name_mapping={
        "create": "create",
        "delete": "delete",
        "read": "read",
        "update": "update",
    },
)
class AvailabilitySetTimeouts:
    def __init__(
        self,
        *,
        create: typing.Optional[builtins.str] = None,
        delete: typing.Optional[builtins.str] = None,
        read: typing.Optional[builtins.str] = None,
        update: typing.Optional[builtins.str] = None,
    ) -> None:
        """
        :param create: 
        :param delete: 
        :param read: 
        :param update: 
        """
        self._values: typing.Dict[str, typing.Any] = {}
        if create is not None:
            self._values["create"] = create
        if delete is not None:
            self._values["delete"] = delete
        if read is not None:
            self._values["read"] = read
        if update is not None:
            self._values["update"] = update

    @builtins.property
    def create(self) -> typing.Optional[builtins.str]:
        result = self._values.get("create")
        return result

    @builtins.property
    def delete(self) -> typing.Optional[builtins.str]:
        result = self._values.get("delete")
        return result

    @builtins.property
    def read(self) -> typing.Optional[builtins.str]:
        result = self._values.get("read")
        return result

    @builtins.property
    def update(self) -> typing.Optional[builtins.str]:
        result = self._values.get("update")
        return result

    def __eq__(self, rhs: typing.Any) -> builtins.bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs: typing.Any) -> builtins.bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return "AvailabilitySetTimeouts(%s)" % ", ".join(
            k + "=" + repr(v) for k, v in self._values.items()
        )


class AzurermProvider(
    cdktf.TerraformProvider,
    metaclass=jsii.JSIIMeta,
    jsii_type="@cdktf/provider-azurerm.AzurermProvider",
):
    def __init__(
        self,
        scope: constructs.Construct,
        id: builtins.str,
        *,
        features: typing.List["AzurermProviderFeatures"],
        alias: typing.Optional[builtins.str] = None,
        auxiliary_tenant_ids: typing.Optional[typing.List[builtins.str]] = None,
        client_certificate_password: typing.Optional[builtins.str] = None,
        client_certificate_path: typing.Optional[builtins.str] = None,
        client_id: typing.Optional[builtins.str] = None,
        client_secret: typing.Optional[builtins.str] = None,
        disable_correlation_request_id: typing.Optional[builtins.bool] = None,
        disable_terraform_partner_id: typing.Optional[builtins.bool] = None,
        environment: typing.Optional[builtins.str] = None,
        msi_endpoint: typing.Optional[builtins.str] = None,
        partner_id: typing.Optional[builtins.str] = None,
        skip_credentials_validation: typing.Optional[builtins.bool] = None,
        skip_provider_registration: typing.Optional[builtins.bool] = None,
        storage_use_azuread: typing.Optional[builtins.bool] = None,
        subscription_id: typing.Optional[builtins.str] = None,
        tenant_id: typing.Optional[builtins.str] = None,
        use_msi: typing.Optional[builtins.bool] = None,
    ) -> None:
        """
        :param scope: -
        :param id: -
        :param features: features block.
        :param alias: Alias name.
        :param auxiliary_tenant_ids: 
        :param client_certificate_password: The password associated with the Client Certificate. For use when authenticating as a Service Principal using a Client Certificate
        :param client_certificate_path: The path to the Client Certificate associated with the Service Principal for use when authenticating as a Service Principal using a Client Certificate.
        :param client_id: The Client ID which should be used.
        :param client_secret: The Client Secret which should be used. For use When authenticating as a Service Principal using a Client Secret.
        :param disable_correlation_request_id: This will disable the x-ms-correlation-request-id header.
        :param disable_terraform_partner_id: This will disable the Terraform Partner ID which is used if a custom ``partner_id`` isn't specified.
        :param environment: The Cloud Environment which should be used. Possible values are public, usgovernment, german, and china. Defaults to public.
        :param msi_endpoint: The path to a custom endpoint for Managed Service Identity - in most circumstances this should be detected automatically.
        :param partner_id: A GUID/UUID that is registered with Microsoft to facilitate partner resource usage attribution.
        :param skip_credentials_validation: This will cause the AzureRM Provider to skip verifying the credentials being used are valid.
        :param skip_provider_registration: Should the AzureRM Provider skip registering all of the Resource Providers that it supports, if they're not already registered?
        :param storage_use_azuread: Should the AzureRM Provider use AzureAD to access the Storage Data Plane API's?
        :param subscription_id: The Subscription ID which should be used.
        :param tenant_id: The Tenant ID which should be used.
        :param use_msi: Allowed Managed Service Identity be used for Authentication.
        """
        config = AzurermProviderConfig(
            features=features,
            alias=alias,
            auxiliary_tenant_ids=auxiliary_tenant_ids,
            client_certificate_password=client_certificate_password,
            client_certificate_path=client_certificate_path,
            client_id=client_id,
            client_secret=client_secret,
            disable_correlation_request_id=disable_correlation_request_id,
            disable_terraform_partner_id=disable_terraform_partner_id,
            environment=environment,
            msi_endpoint=msi_endpoint,
            partner_id=partner_id,
            skip_credentials_validation=skip_credentials_validation,
            skip_provider_registration=skip_provider_registration,
            storage_use_azuread=storage_use_azuread,
            subscription_id=subscription_id,
            tenant_id=tenant_id,
            use_msi=use_msi,
        )

        jsii.create(AzurermProvider, self, [scope, id, config])

    @jsii.member(jsii_name="synthesizeAttributes")
    def _synthesize_attributes(self) -> typing.Mapping[builtins.str, typing.Any]:
        return jsii.invoke(self, "synthesizeAttributes", [])

    @builtins.property # type: ignore
    @jsii.member(jsii_name="features")
    def features(self) -> typing.List["AzurermProviderFeatures"]:
        return jsii.get(self, "features")

    @features.setter # type: ignore
    def features(self, value: typing.List["AzurermProviderFeatures"]) -> None:
        jsii.set(self, "features", value)

    @builtins.property # type: ignore
    @jsii.member(jsii_name="alias")
    def alias(self) -> typing.Optional[builtins.str]:
        return jsii.get(self, "alias")

    @alias.setter # type: ignore
    def alias(self, value: typing.Optional[builtins.str]) -> None:
        jsii.set(self, "alias", value)

    @builtins.property # type: ignore
    @jsii.member(jsii_name="auxiliaryTenantIds")
    def auxiliary_tenant_ids(self) -> typing.Optional[typing.List[builtins.str]]:
        return jsii.get(self, "auxiliaryTenantIds")

    @auxiliary_tenant_ids.setter # type: ignore
    def auxiliary_tenant_ids(
        self,
        value: typing.Optional[typing.List[builtins.str]],
    ) -> None:
        jsii.set(self, "auxiliaryTenantIds", value)

    @builtins.property # type: ignore
    @jsii.member(jsii_name="clientCertificatePassword")
    def client_certificate_password(self) -> typing.Optional[builtins.str]:
        return jsii.get(self, "clientCertificatePassword")

    @client_certificate_password.setter # type: ignore
    def client_certificate_password(self, value: typing.Optional[builtins.str]) -> None:
        jsii.set(self, "clientCertificatePassword", value)

    @builtins.property # type: ignore
    @jsii.member(jsii_name="clientCertificatePath")
    def client_certificate_path(self) -> typing.Optional[builtins.str]:
        return jsii.get(self, "clientCertificatePath")

    @client_certificate_path.setter # type: ignore
    def client_certificate_path(self, value: typing.Optional[builtins.str]) -> None:
        jsii.set(self, "clientCertificatePath", value)

    @builtins.property # type: ignore
    @jsii.member(jsii_name="clientId")
    def client_id(self) -> typing.Optional[builtins.str]:
        return jsii.get(self, "clientId")

    @client_id.setter # type: ignore
    def client_id(self, value: typing.Optional[builtins.str]) -> None:
        jsii.set(self, "clientId", value)

    @builtins.property # type: ignore
    @jsii.member(jsii_name="clientSecret")
    def client_secret(self) -> typing.Optional[builtins.str]:
        return jsii.get(self, "clientSecret")

    @client_secret.setter # type: ignore
    def client_secret(self, value: typing.Optional[builtins.str]) -> None:
        jsii.set(self, "clientSecret", value)

    @builtins.property # type: ignore
    @jsii.member(jsii_name="disableCorrelationRequestId")
    def disable_correlation_request_id(self) -> typing.Optional[builtins.bool]:
        return jsii.get(self, "disableCorrelationRequestId")

    @disable_correlation_request_id.setter # type: ignore
    def disable_correlation_request_id(
        self,
        value: typing.Optional[builtins.bool],
    ) -> None:
        jsii.set(self, "disableCorrelationRequestId", value)

    @builtins.property # type: ignore
    @jsii.member(jsii_name="disableTerraformPartnerId")
    def disable_terraform_partner_id(self) -> typing.Optional[builtins.bool]:
        return jsii.get(self, "disableTerraformPartnerId")

    @disable_terraform_partner_id.setter # type: ignore
    def disable_terraform_partner_id(
        self,
        value: typing.Optional[builtins.bool],
    ) -> None:
        jsii.set(self, "disableTerraformPartnerId", value)

    @builtins.property # type: ignore
    @jsii.member(jsii_name="environment")
    def environment(self) -> typing.Optional[builtins.str]:
        return jsii.get(self, "environment")

    @environment.setter # type: ignore
    def environment(self, value: typing.Optional[builtins.str]) -> None:
        jsii.set(self, "environment", value)

    @builtins.property # type: ignore
    @jsii.member(jsii_name="msiEndpoint")
    def msi_endpoint(self) -> typing.Optional[builtins.str]:
        return jsii.get(self, "msiEndpoint")

    @msi_endpoint.setter # type: ignore
    def msi_endpoint(self, value: typing.Optional[builtins.str]) -> None:
        jsii.set(self, "msiEndpoint", value)

    @builtins.property # type: ignore
    @jsii.member(jsii_name="partnerId")
    def partner_id(self) -> typing.Optional[builtins.str]:
        return jsii.get(self, "partnerId")

    @partner_id.setter # type: ignore
    def partner_id(self, value: typing.Optional[builtins.str]) -> None:
        jsii.set(self, "partnerId", value)

    @builtins.property # type: ignore
    @jsii.member(jsii_name="skipCredentialsValidation")
    def skip_credentials_validation(self) -> typing.Optional[builtins.bool]:
        return jsii.get(self, "skipCredentialsValidation")

    @skip_credentials_validation.setter # type: ignore
    def skip_credentials_validation(
        self,
        value: typing.Optional[builtins.bool],
    ) -> None:
        jsii.set(self, "skipCredentialsValidation", value)

    @builtins.property # type: ignore
    @jsii.member(jsii_name="skipProviderRegistration")
    def skip_provider_registration(self) -> typing.Optional[builtins.bool]:
        return jsii.get(self, "skipProviderRegistration")

    @skip_provider_registration.setter # type: ignore
    def skip_provider_registration(self, value: typing.Optional[builtins.bool]) -> None:
        jsii.set(self, "skipProviderRegistration", value)

    @builtins.property # type: ignore
    @jsii.member(jsii_name="storageUseAzuread")
    def storage_use_azuread(self) -> typing.Optional[builtins.bool]:
        return jsii.get(self, "storageUseAzuread")

    @storage_use_azuread.setter # type: ignore
    def storage_use_azuread(self, value: typing.Optional[builtins.bool]) -> None:
        jsii.set(self, "storageUseAzuread", value)

    @builtins.property # type: ignore
    @jsii.member(jsii_name="subscriptionId")
    def subscription_id(self) -> typing.Optional[builtins.str]:
        return jsii.get(self, "subscriptionId")

    @subscription_id.setter # type: ignore
    def subscription_id(self, value: typing.Optional[builtins.str]) -> None:
        jsii.set(self, "subscriptionId", value)

    @builtins.property # type: ignore
    @jsii.member(jsii_name="tenantId")
    def tenant_id(self) -> typing.Optional[builtins.str]:
        return jsii.get(self, "tenantId")

    @tenant_id.setter # type: ignore
    def tenant_id(self, value: typing.Optional[builtins.str]) -> None:
        jsii.set(self, "tenantId", value)

    @builtins.property # type: ignore
    @jsii.member(jsii_name="useMsi")
    def use_msi(self) -> typing.Optional[builtins.bool]:
        return jsii.get(self, "useMsi")

    @use_msi.setter # type: ignore
    def use_msi(self, value: typing.Optional[builtins.bool]) -> None:
        jsii.set(self, "useMsi", value)


@jsii.data_type(
    jsii_type="@cdktf/provider-azurerm.AzurermProviderConfig",
    jsii_struct_bases=[],
    name_mapping={
        "features": "features",
        "alias": "alias",
        "auxiliary_tenant_ids": "auxiliaryTenantIds",
        "client_certificate_password": "clientCertificatePassword",
        "client_certificate_path": "clientCertificatePath",
        "client_id": "clientId",
        "client_secret": "clientSecret",
        "disable_correlation_request_id": "disableCorrelationRequestId",
        "disable_terraform_partner_id": "disableTerraformPartnerId",
        "environment": "environment",
        "msi_endpoint": "msiEndpoint",
        "partner_id": "partnerId",
        "skip_credentials_validation": "skipCredentialsValidation",
        "skip_provider_registration": "skipProviderRegistration",
        "storage_use_azuread": "storageUseAzuread",
        "subscription_id": "subscriptionId",
        "tenant_id": "tenantId",
        "use_msi": "useMsi",
    },
)
class AzurermProviderConfig:
    def __init__(
        self,
        *,
        features: typing.List["AzurermProviderFeatures"],
        alias: typing.Optional[builtins.str] = None,
        auxiliary_tenant_ids: typing.Optional[typing.List[builtins.str]] = None,
        client_certificate_password: typing.Optional[builtins.str] = None,
        client_certificate_path: typing.Optional[builtins.str] = None,
        client_id: typing.Optional[builtins.str] = None,
        client_secret: typing.Optional[builtins.str] = None,
        disable_correlation_request_id: typing.Optional[builtins.bool] = None,
        disable_terraform_partner_id: typing.Optional[builtins.bool] = None,
        environment: typing.Optional[builtins.str] = None,
        msi_endpoint: typing.Optional[builtins.str] = None,
        partner_id: typing.Optional[builtins.str] = None,
        skip_credentials_validation: typing.Optional[builtins.bool] = None,
        skip_provider_registration: typing.Optional[builtins.bool] = None,
        storage_use_azuread: typing.Optional[builtins.bool] = None,
        subscription_id: typing.Optional[builtins.str] = None,
        tenant_id: typing.Optional[builtins.str] = None,
        use_msi: typing.Optional[builtins.bool] = None,
    ) -> None:
        """
        :param features: features block.
        :param alias: Alias name.
        :param auxiliary_tenant_ids: 
        :param client_certificate_password: The password associated with the Client Certificate. For use when authenticating as a Service Principal using a Client Certificate
        :param client_certificate_path: The path to the Client Certificate associated with the Service Principal for use when authenticating as a Service Principal using a Client Certificate.
        :param client_id: The Client ID which should be used.
        :param client_secret: The Client Secret which should be used. For use When authenticating as a Service Principal using a Client Secret.
        :param disable_correlation_request_id: This will disable the x-ms-correlation-request-id header.
        :param disable_terraform_partner_id: This will disable the Terraform Partner ID which is used if a custom ``partner_id`` isn't specified.
        :param environment: The Cloud Environment which should be used. Possible values are public, usgovernment, german, and china. Defaults to public.
        :param msi_endpoint: The path to a custom endpoint for Managed Service Identity - in most circumstances this should be detected automatically.
        :param partner_id: A GUID/UUID that is registered with Microsoft to facilitate partner resource usage attribution.
        :param skip_credentials_validation: This will cause the AzureRM Provider to skip verifying the credentials being used are valid.
        :param skip_provider_registration: Should the AzureRM Provider skip registering all of the Resource Providers that it supports, if they're not already registered?
        :param storage_use_azuread: Should the AzureRM Provider use AzureAD to access the Storage Data Plane API's?
        :param subscription_id: The Subscription ID which should be used.
        :param tenant_id: The Tenant ID which should be used.
        :param use_msi: Allowed Managed Service Identity be used for Authentication.
        """
        self._values: typing.Dict[str, typing.Any] = {
            "features": features,
        }
        if alias is not None:
            self._values["alias"] = alias
        if auxiliary_tenant_ids is not None:
            self._values["auxiliary_tenant_ids"] = auxiliary_tenant_ids
        if client_certificate_password is not None:
            self._values["client_certificate_password"] = client_certificate_password
        if client_certificate_path is not None:
            self._values["client_certificate_path"] = client_certificate_path
        if client_id is not None:
            self._values["client_id"] = client_id
        if client_secret is not None:
            self._values["client_secret"] = client_secret
        if disable_correlation_request_id is not None:
            self._values["disable_correlation_request_id"] = disable_correlation_request_id
        if disable_terraform_partner_id is not None:
            self._values["disable_terraform_partner_id"] = disable_terraform_partner_id
        if environment is not None:
            self._values["environment"] = environment
        if msi_endpoint is not None:
            self._values["msi_endpoint"] = msi_endpoint
        if partner_id is not None:
            self._values["partner_id"] = partner_id
        if skip_credentials_validation is not None:
            self._values["skip_credentials_validation"] = skip_credentials_validation
        if skip_provider_registration is not None:
            self._values["skip_provider_registration"] = skip_provider_registration
        if storage_use_azuread is not None:
            self._values["storage_use_azuread"] = storage_use_azuread
        if subscription_id is not None:
            self._values["subscription_id"] = subscription_id
        if tenant_id is not None:
            self._values["tenant_id"] = tenant_id
        if use_msi is not None:
            self._values["use_msi"] = use_msi

    @builtins.property
    def features(self) -> typing.List["AzurermProviderFeatures"]:
        """features block."""
        result = self._values.get("features")
        assert result is not None, "Required property 'features' is missing"
        return result

    @builtins.property
    def alias(self) -> typing.Optional[builtins.str]:
        """Alias name."""
        result = self._values.get("alias")
        return result

    @builtins.property
    def auxiliary_tenant_ids(self) -> typing.Optional[typing.List[builtins.str]]:
        result = self._values.get("auxiliary_tenant_ids")
        return result

    @builtins.property
    def client_certificate_password(self) -> typing.Optional[builtins.str]:
        """The password associated with the Client Certificate.

        For use when authenticating as a Service Principal using a Client Certificate
        """
        result = self._values.get("client_certificate_password")
        return result

    @builtins.property
    def client_certificate_path(self) -> typing.Optional[builtins.str]:
        """The path to the Client Certificate associated with the Service Principal for use when authenticating as a Service Principal using a Client Certificate."""
        result = self._values.get("client_certificate_path")
        return result

    @builtins.property
    def client_id(self) -> typing.Optional[builtins.str]:
        """The Client ID which should be used."""
        result = self._values.get("client_id")
        return result

    @builtins.property
    def client_secret(self) -> typing.Optional[builtins.str]:
        """The Client Secret which should be used.

        For use When authenticating as a Service Principal using a Client Secret.
        """
        result = self._values.get("client_secret")
        return result

    @builtins.property
    def disable_correlation_request_id(self) -> typing.Optional[builtins.bool]:
        """This will disable the x-ms-correlation-request-id header."""
        result = self._values.get("disable_correlation_request_id")
        return result

    @builtins.property
    def disable_terraform_partner_id(self) -> typing.Optional[builtins.bool]:
        """This will disable the Terraform Partner ID which is used if a custom ``partner_id`` isn't specified."""
        result = self._values.get("disable_terraform_partner_id")
        return result

    @builtins.property
    def environment(self) -> typing.Optional[builtins.str]:
        """The Cloud Environment which should be used.

        Possible values are public, usgovernment, german, and china. Defaults to public.
        """
        result = self._values.get("environment")
        return result

    @builtins.property
    def msi_endpoint(self) -> typing.Optional[builtins.str]:
        """The path to a custom endpoint for Managed Service Identity - in most circumstances this should be detected automatically."""
        result = self._values.get("msi_endpoint")
        return result

    @builtins.property
    def partner_id(self) -> typing.Optional[builtins.str]:
        """A GUID/UUID that is registered with Microsoft to facilitate partner resource usage attribution."""
        result = self._values.get("partner_id")
        return result

    @builtins.property
    def skip_credentials_validation(self) -> typing.Optional[builtins.bool]:
        """This will cause the AzureRM Provider to skip verifying the credentials being used are valid."""
        result = self._values.get("skip_credentials_validation")
        return result

    @builtins.property
    def skip_provider_registration(self) -> typing.Optional[builtins.bool]:
        """Should the AzureRM Provider skip registering all of the Resource Providers that it supports, if they're not already registered?"""
        result = self._values.get("skip_provider_registration")
        return result

    @builtins.property
    def storage_use_azuread(self) -> typing.Optional[builtins.bool]:
        """Should the AzureRM Provider use AzureAD to access the Storage Data Plane API's?"""
        result = self._values.get("storage_use_azuread")
        return result

    @builtins.property
    def subscription_id(self) -> typing.Optional[builtins.str]:
        """The Subscription ID which should be used."""
        result = self._values.get("subscription_id")
        return result

    @builtins.property
    def tenant_id(self) -> typing.Optional[builtins.str]:
        """The Tenant ID which should be used."""
        result = self._values.get("tenant_id")
        return result

    @builtins.property
    def use_msi(self) -> typing.Optional[builtins.bool]:
        """Allowed Managed Service Identity be used for Authentication."""
        result = self._values.get("use_msi")
        return result

    def __eq__(self, rhs: typing.Any) -> builtins.bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs: typing.Any) -> builtins.bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return "AzurermProviderConfig(%s)" % ", ".join(
            k + "=" + repr(v) for k, v in self._values.items()
        )


@jsii.data_type(
    jsii_type="@cdktf/provider-azurerm.AzurermProviderFeatures",
    jsii_struct_bases=[],
    name_mapping={
        "key_vault": "keyVault",
        "virtual_machine": "virtualMachine",
        "virtual_machine_scale_set": "virtualMachineScaleSet",
    },
)
class AzurermProviderFeatures:
    def __init__(
        self,
        *,
        key_vault: typing.Optional[typing.List["AzurermProviderFeaturesKeyVault"]] = None,
        virtual_machine: typing.Optional[typing.List["AzurermProviderFeaturesVirtualMachine"]] = None,
        virtual_machine_scale_set: typing.Optional[typing.List["AzurermProviderFeaturesVirtualMachineScaleSet"]] = None,
    ) -> None:
        """
        :param key_vault: key_vault block.
        :param virtual_machine: virtual_machine block.
        :param virtual_machine_scale_set: virtual_machine_scale_set block.
        """
        self._values: typing.Dict[str, typing.Any] = {}
        if key_vault is not None:
            self._values["key_vault"] = key_vault
        if virtual_machine is not None:
            self._values["virtual_machine"] = virtual_machine
        if virtual_machine_scale_set is not None:
            self._values["virtual_machine_scale_set"] = virtual_machine_scale_set

    @builtins.property
    def key_vault(
        self,
    ) -> typing.Optional[typing.List["AzurermProviderFeaturesKeyVault"]]:
        """key_vault block."""
        result = self._values.get("key_vault")
        return result

    @builtins.property
    def virtual_machine(
        self,
    ) -> typing.Optional[typing.List["AzurermProviderFeaturesVirtualMachine"]]:
        """virtual_machine block."""
        result = self._values.get("virtual_machine")
        return result

    @builtins.property
    def virtual_machine_scale_set(
        self,
    ) -> typing.Optional[typing.List["AzurermProviderFeaturesVirtualMachineScaleSet"]]:
        """virtual_machine_scale_set block."""
        result = self._values.get("virtual_machine_scale_set")
        return result

    def __eq__(self, rhs: typing.Any) -> builtins.bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs: typing.Any) -> builtins.bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return "AzurermProviderFeatures(%s)" % ", ".join(
            k + "=" + repr(v) for k, v in self._values.items()
        )


@jsii.data_type(
    jsii_type="@cdktf/provider-azurerm.AzurermProviderFeaturesKeyVault",
    jsii_struct_bases=[],
    name_mapping={
        "purge_soft_delete_on_destroy": "purgeSoftDeleteOnDestroy",
        "recover_soft_deleted_key_vaults": "recoverSoftDeletedKeyVaults",
    },
)
class AzurermProviderFeaturesKeyVault:
    def __init__(
        self,
        *,
        purge_soft_delete_on_destroy: typing.Optional[builtins.bool] = None,
        recover_soft_deleted_key_vaults: typing.Optional[builtins.bool] = None,
    ) -> None:
        """
        :param purge_soft_delete_on_destroy: 
        :param recover_soft_deleted_key_vaults: 
        """
        self._values: typing.Dict[str, typing.Any] = {}
        if purge_soft_delete_on_destroy is not None:
            self._values["purge_soft_delete_on_destroy"] = purge_soft_delete_on_destroy
        if recover_soft_deleted_key_vaults is not None:
            self._values["recover_soft_deleted_key_vaults"] = recover_soft_deleted_key_vaults

    @builtins.property
    def purge_soft_delete_on_destroy(self) -> typing.Optional[builtins.bool]:
        result = self._values.get("purge_soft_delete_on_destroy")
        return result

    @builtins.property
    def recover_soft_deleted_key_vaults(self) -> typing.Optional[builtins.bool]:
        result = self._values.get("recover_soft_deleted_key_vaults")
        return result

    def __eq__(self, rhs: typing.Any) -> builtins.bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs: typing.Any) -> builtins.bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return "AzurermProviderFeaturesKeyVault(%s)" % ", ".join(
            k + "=" + repr(v) for k, v in self._values.items()
        )


@jsii.data_type(
    jsii_type="@cdktf/provider-azurerm.AzurermProviderFeaturesVirtualMachine",
    jsii_struct_bases=[],
    name_mapping={"delete_os_disk_on_deletion": "deleteOsDiskOnDeletion"},
)
class AzurermProviderFeaturesVirtualMachine:
    def __init__(self, *, delete_os_disk_on_deletion: builtins.bool) -> None:
        """
        :param delete_os_disk_on_deletion: 
        """
        self._values: typing.Dict[str, typing.Any] = {
            "delete_os_disk_on_deletion": delete_os_disk_on_deletion,
        }

    @builtins.property
    def delete_os_disk_on_deletion(self) -> builtins.bool:
        result = self._values.get("delete_os_disk_on_deletion")
        assert result is not None, "Required property 'delete_os_disk_on_deletion' is missing"
        return result

    def __eq__(self, rhs: typing.Any) -> builtins.bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs: typing.Any) -> builtins.bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return "AzurermProviderFeaturesVirtualMachine(%s)" % ", ".join(
            k + "=" + repr(v) for k, v in self._values.items()
        )


@jsii.data_type(
    jsii_type="@cdktf/provider-azurerm.AzurermProviderFeaturesVirtualMachineScaleSet",
    jsii_struct_bases=[],
    name_mapping={"roll_instances_when_required": "rollInstancesWhenRequired"},
)
class AzurermProviderFeaturesVirtualMachineScaleSet:
    def __init__(self, *, roll_instances_when_required: builtins.bool) -> None:
        """
        :param roll_instances_when_required: 
        """
        self._values: typing.Dict[str, typing.Any] = {
            "roll_instances_when_required": roll_instances_when_required,
        }

    @builtins.property
    def roll_instances_when_required(self) -> builtins.bool:
        result = self._values.get("roll_instances_when_required")
        assert result is not None, "Required property 'roll_instances_when_required' is missing"
        return result

    def __eq__(self, rhs: typing.Any) -> builtins.bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs: typing.Any) -> builtins.bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return "AzurermProviderFeaturesVirtualMachineScaleSet(%s)" % ", ".join(
            k + "=" + repr(v) for k, v in self._values.items()
        )


class BackupContainerStorageAccount(
    cdktf.TerraformResource,
    metaclass=jsii.JSIIMeta,
    jsii_type="@cdktf/provider-azurerm.BackupContainerStorageAccount",
):
    def __init__(
        self,
        scope: constructs.Construct,
        id: builtins.str,
        *,
        recovery_vault_name: builtins.str,
        resource_group_name: builtins.str,
        storage_account_id: builtins.str,
        timeouts: typing.Optional["BackupContainerStorageAccountTimeouts"] = None,
        count: typing.Optional[jsii.Number] = None,
        depends_on: typing.Optional[typing.List[cdktf.TerraformResource]] = None,
        lifecycle: typing.Optional[cdktf.TerraformResourceLifecycle] = None,
        provider: typing.Optional[cdktf.TerraformProvider] = None,
    ) -> None:
        """
        :param scope: -
        :param id: -
        :param recovery_vault_name: 
        :param resource_group_name: 
        :param storage_account_id: 
        :param timeouts: timeouts block.
        :param count: 
        :param depends_on: 
        :param lifecycle: 
        :param provider: 
        """
        config = BackupContainerStorageAccountConfig(
            recovery_vault_name=recovery_vault_name,
            resource_group_name=resource_group_name,
            storage_account_id=storage_account_id,
            timeouts=timeouts,
            count=count,
            depends_on=depends_on,
            lifecycle=lifecycle,
            provider=provider,
        )

        jsii.create(BackupContainerStorageAccount, self, [scope, id, config])

    @jsii.member(jsii_name="synthesizeAttributes")
    def _synthesize_attributes(self) -> typing.Mapping[builtins.str, typing.Any]:
        return jsii.invoke(self, "synthesizeAttributes", [])

    @builtins.property # type: ignore
    @jsii.member(jsii_name="recoveryVaultName")
    def recovery_vault_name(self) -> builtins.str:
        return jsii.get(self, "recoveryVaultName")

    @recovery_vault_name.setter # type: ignore
    def recovery_vault_name(self, value: builtins.str) -> None:
        jsii.set(self, "recoveryVaultName", value)

    @builtins.property # type: ignore
    @jsii.member(jsii_name="resourceGroupName")
    def resource_group_name(self) -> builtins.str:
        return jsii.get(self, "resourceGroupName")

    @resource_group_name.setter # type: ignore
    def resource_group_name(self, value: builtins.str) -> None:
        jsii.set(self, "resourceGroupName", value)

    @builtins.property # type: ignore
    @jsii.member(jsii_name="storageAccountId")
    def storage_account_id(self) -> builtins.str:
        return jsii.get(self, "storageAccountId")

    @storage_account_id.setter # type: ignore
    def storage_account_id(self, value: builtins.str) -> None:
        jsii.set(self, "storageAccountId", value)

    @builtins.property # type: ignore
    @jsii.member(jsii_name="id")
    def id(self) -> typing.Optional[builtins.str]:
        return jsii.get(self, "id")

    @id.setter # type: ignore
    def id(self, value: typing.Optional[builtins.str]) -> None:
        jsii.set(self, "id", value)

    @builtins.property # type: ignore
    @jsii.member(jsii_name="timeouts")
    def timeouts(self) -> typing.Optional["BackupContainerStorageAccountTimeouts"]:
        return jsii.get(self, "timeouts")

    @timeouts.setter # type: ignore
    def timeouts(
        self,
        value: typing.Optional["BackupContainerStorageAccountTimeouts"],
    ) -> None:
        jsii.set(self, "timeouts", value)


@jsii.data_type(
    jsii_type="@cdktf/provider-azurerm.BackupContainerStorageAccountConfig",
    jsii_struct_bases=[cdktf.TerraformMetaArguments],
    name_mapping={
        "count": "count",
        "depends_on": "dependsOn",
        "lifecycle": "lifecycle",
        "provider": "provider",
        "recovery_vault_name": "recoveryVaultName",
        "resource_group_name": "resourceGroupName",
        "storage_account_id": "storageAccountId",
        "timeouts": "timeouts",
    },
)
class BackupContainerStorageAccountConfig(cdktf.TerraformMetaArguments):
    def __init__(
        self,
        *,
        count: typing.Optional[jsii.Number] = None,
        depends_on: typing.Optional[typing.List[cdktf.TerraformResource]] = None,
        lifecycle: typing.Optional[cdktf.TerraformResourceLifecycle] = None,
        provider: typing.Optional[cdktf.TerraformProvider] = None,
        recovery_vault_name: builtins.str,
        resource_group_name: builtins.str,
        storage_account_id: builtins.str,
        timeouts: typing.Optional["BackupContainerStorageAccountTimeouts"] = None,
    ) -> None:
        """
        :param count: 
        :param depends_on: 
        :param lifecycle: 
        :param provider: 
        :param recovery_vault_name: 
        :param resource_group_name: 
        :param storage_account_id: 
        :param timeouts: timeouts block.
        """
        if isinstance(lifecycle, dict):
            lifecycle = cdktf.TerraformResourceLifecycle(**lifecycle)
        if isinstance(timeouts, dict):
            timeouts = BackupContainerStorageAccountTimeouts(**timeouts)
        self._values: typing.Dict[str, typing.Any] = {
            "recovery_vault_name": recovery_vault_name,
            "resource_group_name": resource_group_name,
            "storage_account_id": storage_account_id,
        }
        if count is not None:
            self._values["count"] = count
        if depends_on is not None:
            self._values["depends_on"] = depends_on
        if lifecycle is not None:
            self._values["lifecycle"] = lifecycle
        if provider is not None:
            self._values["provider"] = provider
        if timeouts is not None:
            self._values["timeouts"] = timeouts

    @builtins.property
    def count(self) -> typing.Optional[jsii.Number]:
        """
        :stability: experimental
        """
        result = self._values.get("count")
        return result

    @builtins.property
    def depends_on(self) -> typing.Optional[typing.List[cdktf.TerraformResource]]:
        """
        :stability: experimental
        """
        result = self._values.get("depends_on")
        return result

    @builtins.property
    def lifecycle(self) -> typing.Optional[cdktf.TerraformResourceLifecycle]:
        """
        :stability: experimental
        """
        result = self._values.get("lifecycle")
        return result

    @builtins.property
    def provider(self) -> typing.Optional[cdktf.TerraformProvider]:
        """
        :stability: experimental
        """
        result = self._values.get("provider")
        return result

    @builtins.property
    def recovery_vault_name(self) -> builtins.str:
        result = self._values.get("recovery_vault_name")
        assert result is not None, "Required property 'recovery_vault_name' is missing"
        return result

    @builtins.property
    def resource_group_name(self) -> builtins.str:
        result = self._values.get("resource_group_name")
        assert result is not None, "Required property 'resource_group_name' is missing"
        return result

    @builtins.property
    def storage_account_id(self) -> builtins.str:
        result = self._values.get("storage_account_id")
        assert result is not None, "Required property 'storage_account_id' is missing"
        return result

    @builtins.property
    def timeouts(self) -> typing.Optional["BackupContainerStorageAccountTimeouts"]:
        """timeouts block."""
        result = self._values.get("timeouts")
        return result

    def __eq__(self, rhs: typing.Any) -> builtins.bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs: typing.Any) -> builtins.bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return "BackupContainerStorageAccountConfig(%s)" % ", ".join(
            k + "=" + repr(v) for k, v in self._values.items()
        )


@jsii.data_type(
    jsii_type="@cdktf/provider-azurerm.BackupContainerStorageAccountTimeouts",
    jsii_struct_bases=[],
    name_mapping={
        "create": "create",
        "delete": "delete",
        "read": "read",
        "update": "update",
    },
)
class BackupContainerStorageAccountTimeouts:
    def __init__(
        self,
        *,
        create: typing.Optional[builtins.str] = None,
        delete: typing.Optional[builtins.str] = None,
        read: typing.Optional[builtins.str] = None,
        update: typing.Optional[builtins.str] = None,
    ) -> None:
        """
        :param create: 
        :param delete: 
        :param read: 
        :param update: 
        """
        self._values: typing.Dict[str, typing.Any] = {}
        if create is not None:
            self._values["create"] = create
        if delete is not None:
            self._values["delete"] = delete
        if read is not None:
            self._values["read"] = read
        if update is not None:
            self._values["update"] = update

    @builtins.property
    def create(self) -> typing.Optional[builtins.str]:
        result = self._values.get("create")
        return result

    @builtins.property
    def delete(self) -> typing.Optional[builtins.str]:
        result = self._values.get("delete")
        return result

    @builtins.property
    def read(self) -> typing.Optional[builtins.str]:
        result = self._values.get("read")
        return result

    @builtins.property
    def update(self) -> typing.Optional[builtins.str]:
        result = self._values.get("update")
        return result

    def __eq__(self, rhs: typing.Any) -> builtins.bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs: typing.Any) -> builtins.bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return "BackupContainerStorageAccountTimeouts(%s)" % ", ".join(
            k + "=" + repr(v) for k, v in self._values.items()
        )


class BackupPolicyFileShare(
    cdktf.TerraformResource,
    metaclass=jsii.JSIIMeta,
    jsii_type="@cdktf/provider-azurerm.BackupPolicyFileShare",
):
    def __init__(
        self,
        scope: constructs.Construct,
        id: builtins.str,
        *,
        backup: typing.List["BackupPolicyFileShareBackup"],
        name: builtins.str,
        recovery_vault_name: builtins.str,
        resource_group_name: builtins.str,
        retention_daily: typing.List["BackupPolicyFileShareRetentionDaily"],
        timeouts: typing.Optional["BackupPolicyFileShareTimeouts"] = None,
        timezone: typing.Optional[builtins.str] = None,
        count: typing.Optional[jsii.Number] = None,
        depends_on: typing.Optional[typing.List[cdktf.TerraformResource]] = None,
        lifecycle: typing.Optional[cdktf.TerraformResourceLifecycle] = None,
        provider: typing.Optional[cdktf.TerraformProvider] = None,
    ) -> None:
        """
        :param scope: -
        :param id: -
        :param backup: backup block.
        :param name: 
        :param recovery_vault_name: 
        :param resource_group_name: 
        :param retention_daily: retention_daily block.
        :param timeouts: timeouts block.
        :param timezone: 
        :param count: 
        :param depends_on: 
        :param lifecycle: 
        :param provider: 
        """
        config = BackupPolicyFileShareConfig(
            backup=backup,
            name=name,
            recovery_vault_name=recovery_vault_name,
            resource_group_name=resource_group_name,
            retention_daily=retention_daily,
            timeouts=timeouts,
            timezone=timezone,
            count=count,
            depends_on=depends_on,
            lifecycle=lifecycle,
            provider=provider,
        )

        jsii.create(BackupPolicyFileShare, self, [scope, id, config])

    @jsii.member(jsii_name="synthesizeAttributes")
    def _synthesize_attributes(self) -> typing.Mapping[builtins.str, typing.Any]:
        return jsii.invoke(self, "synthesizeAttributes", [])

    @builtins.property # type: ignore
    @jsii.member(jsii_name="backup")
    def backup(self) -> typing.List["BackupPolicyFileShareBackup"]:
        return jsii.get(self, "backup")

    @backup.setter # type: ignore
    def backup(self, value: typing.List["BackupPolicyFileShareBackup"]) -> None:
        jsii.set(self, "backup", value)

    @builtins.property # type: ignore
    @jsii.member(jsii_name="name")
    def name(self) -> builtins.str:
        return jsii.get(self, "name")

    @name.setter # type: ignore
    def name(self, value: builtins.str) -> None:
        jsii.set(self, "name", value)

    @builtins.property # type: ignore
    @jsii.member(jsii_name="recoveryVaultName")
    def recovery_vault_name(self) -> builtins.str:
        return jsii.get(self, "recoveryVaultName")

    @recovery_vault_name.setter # type: ignore
    def recovery_vault_name(self, value: builtins.str) -> None:
        jsii.set(self, "recoveryVaultName", value)

    @builtins.property # type: ignore
    @jsii.member(jsii_name="resourceGroupName")
    def resource_group_name(self) -> builtins.str:
        return jsii.get(self, "resourceGroupName")

    @resource_group_name.setter # type: ignore
    def resource_group_name(self, value: builtins.str) -> None:
        jsii.set(self, "resourceGroupName", value)

    @builtins.property # type: ignore
    @jsii.member(jsii_name="retentionDaily")
    def retention_daily(self) -> typing.List["BackupPolicyFileShareRetentionDaily"]:
        return jsii.get(self, "retentionDaily")

    @retention_daily.setter # type: ignore
    def retention_daily(
        self,
        value: typing.List["BackupPolicyFileShareRetentionDaily"],
    ) -> None:
        jsii.set(self, "retentionDaily", value)

    @builtins.property # type: ignore
    @jsii.member(jsii_name="id")
    def id(self) -> typing.Optional[builtins.str]:
        return jsii.get(self, "id")

    @id.setter # type: ignore
    def id(self, value: typing.Optional[builtins.str]) -> None:
        jsii.set(self, "id", value)

    @builtins.property # type: ignore
    @jsii.member(jsii_name="timeouts")
    def timeouts(self) -> typing.Optional["BackupPolicyFileShareTimeouts"]:
        return jsii.get(self, "timeouts")

    @timeouts.setter # type: ignore
    def timeouts(self, value: typing.Optional["BackupPolicyFileShareTimeouts"]) -> None:
        jsii.set(self, "timeouts", value)

    @builtins.property # type: ignore
    @jsii.member(jsii_name="timezone")
    def timezone(self) -> typing.Optional[builtins.str]:
        return jsii.get(self, "timezone")

    @timezone.setter # type: ignore
    def timezone(self, value: typing.Optional[builtins.str]) -> None:
        jsii.set(self, "timezone", value)


@jsii.data_type(
    jsii_type="@cdktf/provider-azurerm.BackupPolicyFileShareBackup",
    jsii_struct_bases=[],
    name_mapping={"frequency": "frequency", "time": "time"},
)
class BackupPolicyFileShareBackup:
    def __init__(self, *, frequency: builtins.str, time: builtins.str) -> None:
        """
        :param frequency: 
        :param time: 
        """
        self._values: typing.Dict[str, typing.Any] = {
            "frequency": frequency,
            "time": time,
        }

    @builtins.property
    def frequency(self) -> builtins.str:
        result = self._values.get("frequency")
        assert result is not None, "Required property 'frequency' is missing"
        return result

    @builtins.property
    def time(self) -> builtins.str:
        result = self._values.get("time")
        assert result is not None, "Required property 'time' is missing"
        return result

    def __eq__(self, rhs: typing.Any) -> builtins.bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs: typing.Any) -> builtins.bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return "BackupPolicyFileShareBackup(%s)" % ", ".join(
            k + "=" + repr(v) for k, v in self._values.items()
        )


@jsii.data_type(
    jsii_type="@cdktf/provider-azurerm.BackupPolicyFileShareConfig",
    jsii_struct_bases=[cdktf.TerraformMetaArguments],
    name_mapping={
        "count": "count",
        "depends_on": "dependsOn",
        "lifecycle": "lifecycle",
        "provider": "provider",
        "backup": "backup",
        "name": "name",
        "recovery_vault_name": "recoveryVaultName",
        "resource_group_name": "resourceGroupName",
        "retention_daily": "retentionDaily",
        "timeouts": "timeouts",
        "timezone": "timezone",
    },
)
class BackupPolicyFileShareConfig(cdktf.TerraformMetaArguments):
    def __init__(
        self,
        *,
        count: typing.Optional[jsii.Number] = None,
        depends_on: typing.Optional[typing.List[cdktf.TerraformResource]] = None,
        lifecycle: typing.Optional[cdktf.TerraformResourceLifecycle] = None,
        provider: typing.Optional[cdktf.TerraformProvider] = None,
        backup: typing.List[BackupPolicyFileShareBackup],
        name: builtins.str,
        recovery_vault_name: builtins.str,
        resource_group_name: builtins.str,
        retention_daily: typing.List["BackupPolicyFileShareRetentionDaily"],
        timeouts: typing.Optional["BackupPolicyFileShareTimeouts"] = None,
        timezone: typing.Optional[builtins.str] = None,
    ) -> None:
        """
        :param count: 
        :param depends_on: 
        :param lifecycle: 
        :param provider: 
        :param backup: backup block.
        :param name: 
        :param recovery_vault_name: 
        :param resource_group_name: 
        :param retention_daily: retention_daily block.
        :param timeouts: timeouts block.
        :param timezone: 
        """
        if isinstance(lifecycle, dict):
            lifecycle = cdktf.TerraformResourceLifecycle(**lifecycle)
        if isinstance(timeouts, dict):
            timeouts = BackupPolicyFileShareTimeouts(**timeouts)
        self._values: typing.Dict[str, typing.Any] = {
            "backup": backup,
            "name": name,
            "recovery_vault_name": recovery_vault_name,
            "resource_group_name": resource_group_name,
            "retention_daily": retention_daily,
        }
        if count is not None:
            self._values["count"] = count
        if depends_on is not None:
            self._values["depends_on"] = depends_on
        if lifecycle is not None:
            self._values["lifecycle"] = lifecycle
        if provider is not None:
            self._values["provider"] = provider
        if timeouts is not None:
            self._values["timeouts"] = timeouts
        if timezone is not None:
            self._values["timezone"] = timezone

    @builtins.property
    def count(self) -> typing.Optional[jsii.Number]:
        """
        :stability: experimental
        """
        result = self._values.get("count")
        return result

    @builtins.property
    def depends_on(self) -> typing.Optional[typing.List[cdktf.TerraformResource]]:
        """
        :stability: experimental
        """
        result = self._values.get("depends_on")
        return result

    @builtins.property
    def lifecycle(self) -> typing.Optional[cdktf.TerraformResourceLifecycle]:
        """
        :stability: experimental
        """
        result = self._values.get("lifecycle")
        return result

    @builtins.property
    def provider(self) -> typing.Optional[cdktf.TerraformProvider]:
        """
        :stability: experimental
        """
        result = self._values.get("provider")
        return result

    @builtins.property
    def backup(self) -> typing.List[BackupPolicyFileShareBackup]:
        """backup block."""
        result = self._values.get("backup")
        assert result is not None, "Required property 'backup' is missing"
        return result

    @builtins.property
    def name(self) -> builtins.str:
        result = self._values.get("name")
        assert result is not None, "Required property 'name' is missing"
        return result

    @builtins.property
    def recovery_vault_name(self) -> builtins.str:
        result = self._values.get("recovery_vault_name")
        assert result is not None, "Required property 'recovery_vault_name' is missing"
        return result

    @builtins.property
    def resource_group_name(self) -> builtins.str:
        result = self._values.get("resource_group_name")
        assert result is not None, "Required property 'resource_group_name' is missing"
        return result

    @builtins.property
    def retention_daily(self) -> typing.List["BackupPolicyFileShareRetentionDaily"]:
        """retention_daily block."""
        result = self._values.get("retention_daily")
        assert result is not None, "Required property 'retention_daily' is missing"
        return result

    @builtins.property
    def timeouts(self) -> typing.Optional["BackupPolicyFileShareTimeouts"]:
        """timeouts block."""
        result = self._values.get("timeouts")
        return result

    @builtins.property
    def timezone(self) -> typing.Optional[builtins.str]:
        result = self._values.get("timezone")
        return result

    def __eq__(self, rhs: typing.Any) -> builtins.bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs: typing.Any) -> builtins.bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return "BackupPolicyFileShareConfig(%s)" % ", ".join(
            k + "=" + repr(v) for k, v in self._values.items()
        )


@jsii.data_type(
    jsii_type="@cdktf/provider-azurerm.BackupPolicyFileShareRetentionDaily",
    jsii_struct_bases=[],
    name_mapping={"count": "count"},
)
class BackupPolicyFileShareRetentionDaily:
    def __init__(self, *, count: jsii.Number) -> None:
        """
        :param count: 
        """
        self._values: typing.Dict[str, typing.Any] = {
            "count": count,
        }

    @builtins.property
    def count(self) -> jsii.Number:
        result = self._values.get("count")
        assert result is not None, "Required property 'count' is missing"
        return result

    def __eq__(self, rhs: typing.Any) -> builtins.bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs: typing.Any) -> builtins.bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return "BackupPolicyFileShareRetentionDaily(%s)" % ", ".join(
            k + "=" + repr(v) for k, v in self._values.items()
        )


@jsii.data_type(
    jsii_type="@cdktf/provider-azurerm.BackupPolicyFileShareTimeouts",
    jsii_struct_bases=[],
    name_mapping={
        "create": "create",
        "delete": "delete",
        "read": "read",
        "update": "update",
    },
)
class BackupPolicyFileShareTimeouts:
    def __init__(
        self,
        *,
        create: typing.Optional[builtins.str] = None,
        delete: typing.Optional[builtins.str] = None,
        read: typing.Optional[builtins.str] = None,
        update: typing.Optional[builtins.str] = None,
    ) -> None:
        """
        :param create: 
        :param delete: 
        :param read: 
        :param update: 
        """
        self._values: typing.Dict[str, typing.Any] = {}
        if create is not None:
            self._values["create"] = create
        if delete is not None:
            self._values["delete"] = delete
        if read is not None:
            self._values["read"] = read
        if update is not None:
            self._values["update"] = update

    @builtins.property
    def create(self) -> typing.Optional[builtins.str]:
        result = self._values.get("create")
        return result

    @builtins.property
    def delete(self) -> typing.Optional[builtins.str]:
        result = self._values.get("delete")
        return result

    @builtins.property
    def read(self) -> typing.Optional[builtins.str]:
        result = self._values.get("read")
        return result

    @builtins.property
    def update(self) -> typing.Optional[builtins.str]:
        result = self._values.get("update")
        return result

    def __eq__(self, rhs: typing.Any) -> builtins.bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs: typing.Any) -> builtins.bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return "BackupPolicyFileShareTimeouts(%s)" % ", ".join(
            k + "=" + repr(v) for k, v in self._values.items()
        )


class BackupPolicyVm(
    cdktf.TerraformResource,
    metaclass=jsii.JSIIMeta,
    jsii_type="@cdktf/provider-azurerm.BackupPolicyVm",
):
    def __init__(
        self,
        scope: constructs.Construct,
        id: builtins.str,
        *,
        backup: typing.List["BackupPolicyVmBackup"],
        name: builtins.str,
        recovery_vault_name: builtins.str,
        resource_group_name: builtins.str,
        retention_daily: typing.Optional[typing.List["BackupPolicyVmRetentionDaily"]] = None,
        retention_monthly: typing.Optional[typing.List["BackupPolicyVmRetentionMonthly"]] = None,
        retention_weekly: typing.Optional[typing.List["BackupPolicyVmRetentionWeekly"]] = None,
        retention_yearly: typing.Optional[typing.List["BackupPolicyVmRetentionYearly"]] = None,
        tags: typing.Optional[typing.Mapping[builtins.str, builtins.str]] = None,
        timeouts: typing.Optional["BackupPolicyVmTimeouts"] = None,
        timezone: typing.Optional[builtins.str] = None,
        count: typing.Optional[jsii.Number] = None,
        depends_on: typing.Optional[typing.List[cdktf.TerraformResource]] = None,
        lifecycle: typing.Optional[cdktf.TerraformResourceLifecycle] = None,
        provider: typing.Optional[cdktf.TerraformProvider] = None,
    ) -> None:
        """
        :param scope: -
        :param id: -
        :param backup: backup block.
        :param name: 
        :param recovery_vault_name: 
        :param resource_group_name: 
        :param retention_daily: retention_daily block.
        :param retention_monthly: retention_monthly block.
        :param retention_weekly: retention_weekly block.
        :param retention_yearly: retention_yearly block.
        :param tags: 
        :param timeouts: timeouts block.
        :param timezone: 
        :param count: 
        :param depends_on: 
        :param lifecycle: 
        :param provider: 
        """
        config = BackupPolicyVmConfig(
            backup=backup,
            name=name,
            recovery_vault_name=recovery_vault_name,
            resource_group_name=resource_group_name,
            retention_daily=retention_daily,
            retention_monthly=retention_monthly,
            retention_weekly=retention_weekly,
            retention_yearly=retention_yearly,
            tags=tags,
            timeouts=timeouts,
            timezone=timezone,
            count=count,
            depends_on=depends_on,
            lifecycle=lifecycle,
            provider=provider,
        )

        jsii.create(BackupPolicyVm, self, [scope, id, config])

    @jsii.member(jsii_name="synthesizeAttributes")
    def _synthesize_attributes(self) -> typing.Mapping[builtins.str, typing.Any]:
        return jsii.invoke(self, "synthesizeAttributes", [])

    @builtins.property # type: ignore
    @jsii.member(jsii_name="backup")
    def backup(self) -> typing.List["BackupPolicyVmBackup"]:
        return jsii.get(self, "backup")

    @backup.setter # type: ignore
    def backup(self, value: typing.List["BackupPolicyVmBackup"]) -> None:
        jsii.set(self, "backup", value)

    @builtins.property # type: ignore
    @jsii.member(jsii_name="name")
    def name(self) -> builtins.str:
        return jsii.get(self, "name")

    @name.setter # type: ignore
    def name(self, value: builtins.str) -> None:
        jsii.set(self, "name", value)

    @builtins.property # type: ignore
    @jsii.member(jsii_name="recoveryVaultName")
    def recovery_vault_name(self) -> builtins.str:
        return jsii.get(self, "recoveryVaultName")

    @recovery_vault_name.setter # type: ignore
    def recovery_vault_name(self, value: builtins.str) -> None:
        jsii.set(self, "recoveryVaultName", value)

    @builtins.property # type: ignore
    @jsii.member(jsii_name="resourceGroupName")
    def resource_group_name(self) -> builtins.str:
        return jsii.get(self, "resourceGroupName")

    @resource_group_name.setter # type: ignore
    def resource_group_name(self, value: builtins.str) -> None:
        jsii.set(self, "resourceGroupName", value)

    @builtins.property # type: ignore
    @jsii.member(jsii_name="id")
    def id(self) -> typing.Optional[builtins.str]:
        return jsii.get(self, "id")

    @id.setter # type: ignore
    def id(self, value: typing.Optional[builtins.str]) -> None:
        jsii.set(self, "id", value)

    @builtins.property # type: ignore
    @jsii.member(jsii_name="retentionDaily")
    def retention_daily(
        self,
    ) -> typing.Optional[typing.List["BackupPolicyVmRetentionDaily"]]:
        return jsii.get(self, "retentionDaily")

    @retention_daily.setter # type: ignore
    def retention_daily(
        self,
        value: typing.Optional[typing.List["BackupPolicyVmRetentionDaily"]],
    ) -> None:
        jsii.set(self, "retentionDaily", value)

    @builtins.property # type: ignore
    @jsii.member(jsii_name="retentionMonthly")
    def retention_monthly(
        self,
    ) -> typing.Optional[typing.List["BackupPolicyVmRetentionMonthly"]]:
        return jsii.get(self, "retentionMonthly")

    @retention_monthly.setter # type: ignore
    def retention_monthly(
        self,
        value: typing.Optional[typing.List["BackupPolicyVmRetentionMonthly"]],
    ) -> None:
        jsii.set(self, "retentionMonthly", value)

    @builtins.property # type: ignore
    @jsii.member(jsii_name="retentionWeekly")
    def retention_weekly(
        self,
    ) -> typing.Optional[typing.List["BackupPolicyVmRetentionWeekly"]]:
        return jsii.get(self, "retentionWeekly")

    @retention_weekly.setter # type: ignore
    def retention_weekly(
        self,
        value: typing.Optional[typing.List["BackupPolicyVmRetentionWeekly"]],
    ) -> None:
        jsii.set(self, "retentionWeekly", value)

    @builtins.property # type: ignore
    @jsii.member(jsii_name="retentionYearly")
    def retention_yearly(
        self,
    ) -> typing.Optional[typing.List["BackupPolicyVmRetentionYearly"]]:
        return jsii.get(self, "retentionYearly")

    @retention_yearly.setter # type: ignore
    def retention_yearly(
        self,
        value: typing.Optional[typing.List["BackupPolicyVmRetentionYearly"]],
    ) -> None:
        jsii.set(self, "retentionYearly", value)

    @builtins.property # type: ignore
    @jsii.member(jsii_name="tags")
    def tags(self) -> typing.Optional[typing.Mapping[builtins.str, builtins.str]]:
        return jsii.get(self, "tags")

    @tags.setter # type: ignore
    def tags(
        self,
        value: typing.Optional[typing.Mapping[builtins.str, builtins.str]],
    ) -> None:
        jsii.set(self, "tags", value)

    @builtins.property # type: ignore
    @jsii.member(jsii_name="timeouts")
    def timeouts(self) -> typing.Optional["BackupPolicyVmTimeouts"]:
        return jsii.get(self, "timeouts")

    @timeouts.setter # type: ignore
    def timeouts(self, value: typing.Optional["BackupPolicyVmTimeouts"]) -> None:
        jsii.set(self, "timeouts", value)

    @builtins.property # type: ignore
    @jsii.member(jsii_name="timezone")
    def timezone(self) -> typing.Optional[builtins.str]:
        return jsii.get(self, "timezone")

    @timezone.setter # type: ignore
    def timezone(self, value: typing.Optional[builtins.str]) -> None:
        jsii.set(self, "timezone", value)


@jsii.data_type(
    jsii_type="@cdktf/provider-azurerm.BackupPolicyVmBackup",
    jsii_struct_bases=[],
    name_mapping={"frequency": "frequency", "time": "time", "weekdays": "weekdays"},
)
class BackupPolicyVmBackup:
    def __init__(
        self,
        *,
        frequency: builtins.str,
        time: builtins.str,
        weekdays: typing.Optional[typing.List[builtins.str]] = None,
    ) -> None:
        """
        :param frequency: 
        :param time: 
        :param weekdays: 
        """
        self._values: typing.Dict[str, typing.Any] = {
            "frequency": frequency,
            "time": time,
        }
        if weekdays is not None:
            self._values["weekdays"] = weekdays

    @builtins.property
    def frequency(self) -> builtins.str:
        result = self._values.get("frequency")
        assert result is not None, "Required property 'frequency' is missing"
        return result

    @builtins.property
    def time(self) -> builtins.str:
        result = self._values.get("time")
        assert result is not None, "Required property 'time' is missing"
        return result

    @builtins.property
    def weekdays(self) -> typing.Optional[typing.List[builtins.str]]:
        result = self._values.get("weekdays")
        return result

    def __eq__(self, rhs: typing.Any) -> builtins.bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs: typing.Any) -> builtins.bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return "BackupPolicyVmBackup(%s)" % ", ".join(
            k + "=" + repr(v) for k, v in self._values.items()
        )


@jsii.data_type(
    jsii_type="@cdktf/provider-azurerm.BackupPolicyVmConfig",
    jsii_struct_bases=[cdktf.TerraformMetaArguments],
    name_mapping={
        "count": "count",
        "depends_on": "dependsOn",
        "lifecycle": "lifecycle",
        "provider": "provider",
        "backup": "backup",
        "name": "name",
        "recovery_vault_name": "recoveryVaultName",
        "resource_group_name": "resourceGroupName",
        "retention_daily": "retentionDaily",
        "retention_monthly": "retentionMonthly",
        "retention_weekly": "retentionWeekly",
        "retention_yearly": "retentionYearly",
        "tags": "tags",
        "timeouts": "timeouts",
        "timezone": "timezone",
    },
)
class BackupPolicyVmConfig(cdktf.TerraformMetaArguments):
    def __init__(
        self,
        *,
        count: typing.Optional[jsii.Number] = None,
        depends_on: typing.Optional[typing.List[cdktf.TerraformResource]] = None,
        lifecycle: typing.Optional[cdktf.TerraformResourceLifecycle] = None,
        provider: typing.Optional[cdktf.TerraformProvider] = None,
        backup: typing.List[BackupPolicyVmBackup],
        name: builtins.str,
        recovery_vault_name: builtins.str,
        resource_group_name: builtins.str,
        retention_daily: typing.Optional[typing.List["BackupPolicyVmRetentionDaily"]] = None,
        retention_monthly: typing.Optional[typing.List["BackupPolicyVmRetentionMonthly"]] = None,
        retention_weekly: typing.Optional[typing.List["BackupPolicyVmRetentionWeekly"]] = None,
        retention_yearly: typing.Optional[typing.List["BackupPolicyVmRetentionYearly"]] = None,
        tags: typing.Optional[typing.Mapping[builtins.str, builtins.str]] = None,
        timeouts: typing.Optional["BackupPolicyVmTimeouts"] = None,
        timezone: typing.Optional[builtins.str] = None,
    ) -> None:
        """
        :param count: 
        :param depends_on: 
        :param lifecycle: 
        :param provider: 
        :param backup: backup block.
        :param name: 
        :param recovery_vault_name: 
        :param resource_group_name: 
        :param retention_daily: retention_daily block.
        :param retention_monthly: retention_monthly block.
        :param retention_weekly: retention_weekly block.
        :param retention_yearly: retention_yearly block.
        :param tags: 
        :param timeouts: timeouts block.
        :param timezone: 
        """
        if isinstance(lifecycle, dict):
            lifecycle = cdktf.TerraformResourceLifecycle(**lifecycle)
        if isinstance(timeouts, dict):
            timeouts = BackupPolicyVmTimeouts(**timeouts)
        self._values: typing.Dict[str, typing.Any] = {
            "backup": backup,
            "name": name,
            "recovery_vault_name": recovery_vault_name,
            "resource_group_name": resource_group_name,
        }
        if count is not None:
            self._values["count"] = count
        if depends_on is not None:
            self._values["depends_on"] = depends_on
        if lifecycle is not None:
            self._values["lifecycle"] = lifecycle
        if provider is not None:
            self._values["provider"] = provider
        if retention_daily is not None:
            self._values["retention_daily"] = retention_daily
        if retention_monthly is not None:
            self._values["retention_monthly"] = retention_monthly
        if retention_weekly is not None:
            self._values["retention_weekly"] = retention_weekly
        if retention_yearly is not None:
            self._values["retention_yearly"] = retention_yearly
        if tags is not None:
            self._values["tags"] = tags
        if timeouts is not None:
            self._values["timeouts"] = timeouts
        if timezone is not None:
            self._values["timezone"] = timezone

    @builtins.property
    def count(self) -> typing.Optional[jsii.Number]:
        """
        :stability: experimental
        """
        result = self._values.get("count")
        return result

    @builtins.property
    def depends_on(self) -> typing.Optional[typing.List[cdktf.TerraformResource]]:
        """
        :stability: experimental
        """
        result = self._values.get("depends_on")
        return result

    @builtins.property
    def lifecycle(self) -> typing.Optional[cdktf.TerraformResourceLifecycle]:
        """
        :stability: experimental
        """
        result = self._values.get("lifecycle")
        return result

    @builtins.property
    def provider(self) -> typing.Optional[cdktf.TerraformProvider]:
        """
        :stability: experimental
        """
        result = self._values.get("provider")
        return result

    @builtins.property
    def backup(self) -> typing.List[BackupPolicyVmBackup]:
        """backup block."""
        result = self._values.get("backup")
        assert result is not None, "Required property 'backup' is missing"
        return result

    @builtins.property
    def name(self) -> builtins.str:
        result = self._values.get("name")
        assert result is not None, "Required property 'name' is missing"
        return result

    @builtins.property
    def recovery_vault_name(self) -> builtins.str:
        result = self._values.get("recovery_vault_name")
        assert result is not None, "Required property 'recovery_vault_name' is missing"
        return result

    @builtins.property
    def resource_group_name(self) -> builtins.str:
        result = self._values.get("resource_group_name")
        assert result is not None, "Required property 'resource_group_name' is missing"
        return result

    @builtins.property
    def retention_daily(
        self,
    ) -> typing.Optional[typing.List["BackupPolicyVmRetentionDaily"]]:
        """retention_daily block."""
        result = self._values.get("retention_daily")
        return result

    @builtins.property
    def retention_monthly(
        self,
    ) -> typing.Optional[typing.List["BackupPolicyVmRetentionMonthly"]]:
        """retention_monthly block."""
        result = self._values.get("retention_monthly")
        return result

    @builtins.property
    def retention_weekly(
        self,
    ) -> typing.Optional[typing.List["BackupPolicyVmRetentionWeekly"]]:
        """retention_weekly block."""
        result = self._values.get("retention_weekly")
        return result

    @builtins.property
    def retention_yearly(
        self,
    ) -> typing.Optional[typing.List["BackupPolicyVmRetentionYearly"]]:
        """retention_yearly block."""
        result = self._values.get("retention_yearly")
        return result

    @builtins.property
    def tags(self) -> typing.Optional[typing.Mapping[builtins.str, builtins.str]]:
        result = self._values.get("tags")
        return result

    @builtins.property
    def timeouts(self) -> typing.Optional["BackupPolicyVmTimeouts"]:
        """timeouts block."""
        result = self._values.get("timeouts")
        return result

    @builtins.property
    def timezone(self) -> typing.Optional[builtins.str]:
        result = self._values.get("timezone")
        return result

    def __eq__(self, rhs: typing.Any) -> builtins.bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs: typing.Any) -> builtins.bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return "BackupPolicyVmConfig(%s)" % ", ".join(
            k + "=" + repr(v) for k, v in self._values.items()
        )


@jsii.data_type(
    jsii_type="@cdktf/provider-azurerm.BackupPolicyVmRetentionDaily",
    jsii_struct_bases=[],
    name_mapping={"count": "count"},
)
class BackupPolicyVmRetentionDaily:
    def __init__(self, *, count: jsii.Number) -> None:
        """
        :param count: 
        """
        self._values: typing.Dict[str, typing.Any] = {
            "count": count,
        }

    @builtins.property
    def count(self) -> jsii.Number:
        result = self._values.get("count")
        assert result is not None, "Required property 'count' is missing"
        return result

    def __eq__(self, rhs: typing.Any) -> builtins.bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs: typing.Any) -> builtins.bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return "BackupPolicyVmRetentionDaily(%s)" % ", ".join(
            k + "=" + repr(v) for k, v in self._values.items()
        )


@jsii.data_type(
    jsii_type="@cdktf/provider-azurerm.BackupPolicyVmRetentionMonthly",
    jsii_struct_bases=[],
    name_mapping={"count": "count", "weekdays": "weekdays", "weeks": "weeks"},
)
class BackupPolicyVmRetentionMonthly:
    def __init__(
        self,
        *,
        count: jsii.Number,
        weekdays: typing.List[builtins.str],
        weeks: typing.List[builtins.str],
    ) -> None:
        """
        :param count: 
        :param weekdays: 
        :param weeks: 
        """
        self._values: typing.Dict[str, typing.Any] = {
            "count": count,
            "weekdays": weekdays,
            "weeks": weeks,
        }

    @builtins.property
    def count(self) -> jsii.Number:
        result = self._values.get("count")
        assert result is not None, "Required property 'count' is missing"
        return result

    @builtins.property
    def weekdays(self) -> typing.List[builtins.str]:
        result = self._values.get("weekdays")
        assert result is not None, "Required property 'weekdays' is missing"
        return result

    @builtins.property
    def weeks(self) -> typing.List[builtins.str]:
        result = self._values.get("weeks")
        assert result is not None, "Required property 'weeks' is missing"
        return result

    def __eq__(self, rhs: typing.Any) -> builtins.bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs: typing.Any) -> builtins.bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return "BackupPolicyVmRetentionMonthly(%s)" % ", ".join(
            k + "=" + repr(v) for k, v in self._values.items()
        )


@jsii.data_type(
    jsii_type="@cdktf/provider-azurerm.BackupPolicyVmRetentionWeekly",
    jsii_struct_bases=[],
    name_mapping={"count": "count", "weekdays": "weekdays"},
)
class BackupPolicyVmRetentionWeekly:
    def __init__(
        self,
        *,
        count: jsii.Number,
        weekdays: typing.List[builtins.str],
    ) -> None:
        """
        :param count: 
        :param weekdays: 
        """
        self._values: typing.Dict[str, typing.Any] = {
            "count": count,
            "weekdays": weekdays,
        }

    @builtins.property
    def count(self) -> jsii.Number:
        result = self._values.get("count")
        assert result is not None, "Required property 'count' is missing"
        return result

    @builtins.property
    def weekdays(self) -> typing.List[builtins.str]:
        result = self._values.get("weekdays")
        assert result is not None, "Required property 'weekdays' is missing"
        return result

    def __eq__(self, rhs: typing.Any) -> builtins.bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs: typing.Any) -> builtins.bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return "BackupPolicyVmRetentionWeekly(%s)" % ", ".join(
            k + "=" + repr(v) for k, v in self._values.items()
        )


@jsii.data_type(
    jsii_type="@cdktf/provider-azurerm.BackupPolicyVmRetentionYearly",
    jsii_struct_bases=[],
    name_mapping={
        "count": "count",
        "months": "months",
        "weekdays": "weekdays",
        "weeks": "weeks",
    },
)
class BackupPolicyVmRetentionYearly:
    def __init__(
        self,
        *,
        count: jsii.Number,
        months: typing.List[builtins.str],
        weekdays: typing.List[builtins.str],
        weeks: typing.List[builtins.str],
    ) -> None:
        """
        :param count: 
        :param months: 
        :param weekdays: 
        :param weeks: 
        """
        self._values: typing.Dict[str, typing.Any] = {
            "count": count,
            "months": months,
            "weekdays": weekdays,
            "weeks": weeks,
        }

    @builtins.property
    def count(self) -> jsii.Number:
        result = self._values.get("count")
        assert result is not None, "Required property 'count' is missing"
        return result

    @builtins.property
    def months(self) -> typing.List[builtins.str]:
        result = self._values.get("months")
        assert result is not None, "Required property 'months' is missing"
        return result

    @builtins.property
    def weekdays(self) -> typing.List[builtins.str]:
        result = self._values.get("weekdays")
        assert result is not None, "Required property 'weekdays' is missing"
        return result

    @builtins.property
    def weeks(self) -> typing.List[builtins.str]:
        result = self._values.get("weeks")
        assert result is not None, "Required property 'weeks' is missing"
        return result

    def __eq__(self, rhs: typing.Any) -> builtins.bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs: typing.Any) -> builtins.bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return "BackupPolicyVmRetentionYearly(%s)" % ", ".join(
            k + "=" + repr(v) for k, v in self._values.items()
        )


@jsii.data_type(
    jsii_type="@cdktf/provider-azurerm.BackupPolicyVmTimeouts",
    jsii_struct_bases=[],
    name_mapping={
        "create": "create",
        "delete": "delete",
        "read": "read",
        "update": "update",
    },
)
class BackupPolicyVmTimeouts:
    def __init__(
        self,
        *,
        create: typing.Optional[builtins.str] = None,
        delete: typing.Optional[builtins.str] = None,
        read: typing.Optional[builtins.str] = None,
        update: typing.Optional[builtins.str] = None,
    ) -> None:
        """
        :param create: 
        :param delete: 
        :param read: 
        :param update: 
        """
        self._values: typing.Dict[str, typing.Any] = {}
        if create is not None:
            self._values["create"] = create
        if delete is not None:
            self._values["delete"] = delete
        if read is not None:
            self._values["read"] = read
        if update is not None:
            self._values["update"] = update

    @builtins.property
    def create(self) -> typing.Optional[builtins.str]:
        result = self._values.get("create")
        return result

    @builtins.property
    def delete(self) -> typing.Optional[builtins.str]:
        result = self._values.get("delete")
        return result

    @builtins.property
    def read(self) -> typing.Optional[builtins.str]:
        result = self._values.get("read")
        return result

    @builtins.property
    def update(self) -> typing.Optional[builtins.str]:
        result = self._values.get("update")
        return result

    def __eq__(self, rhs: typing.Any) -> builtins.bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs: typing.Any) -> builtins.bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return "BackupPolicyVmTimeouts(%s)" % ", ".join(
            k + "=" + repr(v) for k, v in self._values.items()
        )


class BackupProtectedFileShare(
    cdktf.TerraformResource,
    metaclass=jsii.JSIIMeta,
    jsii_type="@cdktf/provider-azurerm.BackupProtectedFileShare",
):
    def __init__(
        self,
        scope: constructs.Construct,
        id: builtins.str,
        *,
        backup_policy_id: builtins.str,
        recovery_vault_name: builtins.str,
        resource_group_name: builtins.str,
        source_file_share_name: builtins.str,
        source_storage_account_id: builtins.str,
        timeouts: typing.Optional["BackupProtectedFileShareTimeouts"] = None,
        count: typing.Optional[jsii.Number] = None,
        depends_on: typing.Optional[typing.List[cdktf.TerraformResource]] = None,
        lifecycle: typing.Optional[cdktf.TerraformResourceLifecycle] = None,
        provider: typing.Optional[cdktf.TerraformProvider] = None,
    ) -> None:
        """
        :param scope: -
        :param id: -
        :param backup_policy_id: 
        :param recovery_vault_name: 
        :param resource_group_name: 
        :param source_file_share_name: 
        :param source_storage_account_id: 
        :param timeouts: timeouts block.
        :param count: 
        :param depends_on: 
        :param lifecycle: 
        :param provider: 
        """
        config = BackupProtectedFileShareConfig(
            backup_policy_id=backup_policy_id,
            recovery_vault_name=recovery_vault_name,
            resource_group_name=resource_group_name,
            source_file_share_name=source_file_share_name,
            source_storage_account_id=source_storage_account_id,
            timeouts=timeouts,
            count=count,
            depends_on=depends_on,
            lifecycle=lifecycle,
            provider=provider,
        )

        jsii.create(BackupProtectedFileShare, self, [scope, id, config])

    @jsii.member(jsii_name="synthesizeAttributes")
    def _synthesize_attributes(self) -> typing.Mapping[builtins.str, typing.Any]:
        return jsii.invoke(self, "synthesizeAttributes", [])

    @builtins.property # type: ignore
    @jsii.member(jsii_name="backupPolicyId")
    def backup_policy_id(self) -> builtins.str:
        return jsii.get(self, "backupPolicyId")

    @backup_policy_id.setter # type: ignore
    def backup_policy_id(self, value: builtins.str) -> None:
        jsii.set(self, "backupPolicyId", value)

    @builtins.property # type: ignore
    @jsii.member(jsii_name="recoveryVaultName")
    def recovery_vault_name(self) -> builtins.str:
        return jsii.get(self, "recoveryVaultName")

    @recovery_vault_name.setter # type: ignore
    def recovery_vault_name(self, value: builtins.str) -> None:
        jsii.set(self, "recoveryVaultName", value)

    @builtins.property # type: ignore
    @jsii.member(jsii_name="resourceGroupName")
    def resource_group_name(self) -> builtins.str:
        return jsii.get(self, "resourceGroupName")

    @resource_group_name.setter # type: ignore
    def resource_group_name(self, value: builtins.str) -> None:
        jsii.set(self, "resourceGroupName", value)

    @builtins.property # type: ignore
    @jsii.member(jsii_name="sourceFileShareName")
    def source_file_share_name(self) -> builtins.str:
        return jsii.get(self, "sourceFileShareName")

    @source_file_share_name.setter # type: ignore
    def source_file_share_name(self, value: builtins.str) -> None:
        jsii.set(self, "sourceFileShareName", value)

    @builtins.property # type: ignore
    @jsii.member(jsii_name="sourceStorageAccountId")
    def source_storage_account_id(self) -> builtins.str:
        return jsii.get(self, "sourceStorageAccountId")

    @source_storage_account_id.setter # type: ignore
    def source_storage_account_id(self, value: builtins.str) -> None:
        jsii.set(self, "sourceStorageAccountId", value)

    @builtins.property # type: ignore
    @jsii.member(jsii_name="id")
    def id(self) -> typing.Optional[builtins.str]:
        return jsii.get(self, "id")

    @id.setter # type: ignore
    def id(self, value: typing.Optional[builtins.str]) -> None:
        jsii.set(self, "id", value)

    @builtins.property # type: ignore
    @jsii.member(jsii_name="timeouts")
    def timeouts(self) -> typing.Optional["BackupProtectedFileShareTimeouts"]:
        return jsii.get(self, "timeouts")

    @timeouts.setter # type: ignore
    def timeouts(
        self,
        value: typing.Optional["BackupProtectedFileShareTimeouts"],
    ) -> None:
        jsii.set(self, "timeouts", value)


@jsii.data_type(
    jsii_type="@cdktf/provider-azurerm.BackupProtectedFileShareConfig",
    jsii_struct_bases=[cdktf.TerraformMetaArguments],
    name_mapping={
        "count": "count",
        "depends_on": "dependsOn",
        "lifecycle": "lifecycle",
        "provider": "provider",
        "backup_policy_id": "backupPolicyId",
        "recovery_vault_name": "recoveryVaultName",
        "resource_group_name": "resourceGroupName",
        "source_file_share_name": "sourceFileShareName",
        "source_storage_account_id": "sourceStorageAccountId",
        "timeouts": "timeouts",
    },
)
class BackupProtectedFileShareConfig(cdktf.TerraformMetaArguments):
    def __init__(
        self,
        *,
        count: typing.Optional[jsii.Number] = None,
        depends_on: typing.Optional[typing.List[cdktf.TerraformResource]] = None,
        lifecycle: typing.Optional[cdktf.TerraformResourceLifecycle] = None,
        provider: typing.Optional[cdktf.TerraformProvider] = None,
        backup_policy_id: builtins.str,
        recovery_vault_name: builtins.str,
        resource_group_name: builtins.str,
        source_file_share_name: builtins.str,
        source_storage_account_id: builtins.str,
        timeouts: typing.Optional["BackupProtectedFileShareTimeouts"] = None,
    ) -> None:
        """
        :param count: 
        :param depends_on: 
        :param lifecycle: 
        :param provider: 
        :param backup_policy_id: 
        :param recovery_vault_name: 
        :param resource_group_name: 
        :param source_file_share_name: 
        :param source_storage_account_id: 
        :param timeouts: timeouts block.
        """
        if isinstance(lifecycle, dict):
            lifecycle = cdktf.TerraformResourceLifecycle(**lifecycle)
        if isinstance(timeouts, dict):
            timeouts = BackupProtectedFileShareTimeouts(**timeouts)
        self._values: typing.Dict[str, typing.Any] = {
            "backup_policy_id": backup_policy_id,
            "recovery_vault_name": recovery_vault_name,
            "resource_group_name": resource_group_name,
            "source_file_share_name": source_file_share_name,
            "source_storage_account_id": source_storage_account_id,
        }
        if count is not None:
            self._values["count"] = count
        if depends_on is not None:
            self._values["depends_on"] = depends_on
        if lifecycle is not None:
            self._values["lifecycle"] = lifecycle
        if provider is not None:
            self._values["provider"] = provider
        if timeouts is not None:
            self._values["timeouts"] = timeouts

    @builtins.property
    def count(self) -> typing.Optional[jsii.Number]:
        """
        :stability: experimental
        """
        result = self._values.get("count")
        return result

    @builtins.property
    def depends_on(self) -> typing.Optional[typing.List[cdktf.TerraformResource]]:
        """
        :stability: experimental
        """
        result = self._values.get("depends_on")
        return result

    @builtins.property
    def lifecycle(self) -> typing.Optional[cdktf.TerraformResourceLifecycle]:
        """
        :stability: experimental
        """
        result = self._values.get("lifecycle")
        return result

    @builtins.property
    def provider(self) -> typing.Optional[cdktf.TerraformProvider]:
        """
        :stability: experimental
        """
        result = self._values.get("provider")
        return result

    @builtins.property
    def backup_policy_id(self) -> builtins.str:
        result = self._values.get("backup_policy_id")
        assert result is not None, "Required property 'backup_policy_id' is missing"
        return result

    @builtins.property
    def recovery_vault_name(self) -> builtins.str:
        result = self._values.get("recovery_vault_name")
        assert result is not None, "Required property 'recovery_vault_name' is missing"
        return result

    @builtins.property
    def resource_group_name(self) -> builtins.str:
        result = self._values.get("resource_group_name")
        assert result is not None, "Required property 'resource_group_name' is missing"
        return result

    @builtins.property
    def source_file_share_name(self) -> builtins.str:
        result = self._values.get("source_file_share_name")
        assert result is not None, "Required property 'source_file_share_name' is missing"
        return result

    @builtins.property
    def source_storage_account_id(self) -> builtins.str:
        result = self._values.get("source_storage_account_id")
        assert result is not None, "Required property 'source_storage_account_id' is missing"
        return result

    @builtins.property
    def timeouts(self) -> typing.Optional["BackupProtectedFileShareTimeouts"]:
        """timeouts block."""
        result = self._values.get("timeouts")
        return result

    def __eq__(self, rhs: typing.Any) -> builtins.bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs: typing.Any) -> builtins.bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return "BackupProtectedFileShareConfig(%s)" % ", ".join(
            k + "=" + repr(v) for k, v in self._values.items()
        )


@jsii.data_type(
    jsii_type="@cdktf/provider-azurerm.BackupProtectedFileShareTimeouts",
    jsii_struct_bases=[],
    name_mapping={
        "create": "create",
        "delete": "delete",
        "read": "read",
        "update": "update",
    },
)
class BackupProtectedFileShareTimeouts:
    def __init__(
        self,
        *,
        create: typing.Optional[builtins.str] = None,
        delete: typing.Optional[builtins.str] = None,
        read: typing.Optional[builtins.str] = None,
        update: typing.Optional[builtins.str] = None,
    ) -> None:
        """
        :param create: 
        :param delete: 
        :param read: 
        :param update: 
        """
        self._values: typing.Dict[str, typing.Any] = {}
        if create is not None:
            self._values["create"] = create
        if delete is not None:
            self._values["delete"] = delete
        if read is not None:
            self._values["read"] = read
        if update is not None:
            self._values["update"] = update

    @builtins.property
    def create(self) -> typing.Optional[builtins.str]:
        result = self._values.get("create")
        return result

    @builtins.property
    def delete(self) -> typing.Optional[builtins.str]:
        result = self._values.get("delete")
        return result

    @builtins.property
    def read(self) -> typing.Optional[builtins.str]:
        result = self._values.get("read")
        return result

    @builtins.property
    def update(self) -> typing.Optional[builtins.str]:
        result = self._values.get("update")
        return result

    def __eq__(self, rhs: typing.Any) -> builtins.bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs: typing.Any) -> builtins.bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return "BackupProtectedFileShareTimeouts(%s)" % ", ".join(
            k + "=" + repr(v) for k, v in self._values.items()
        )


class BackupProtectedVm(
    cdktf.TerraformResource,
    metaclass=jsii.JSIIMeta,
    jsii_type="@cdktf/provider-azurerm.BackupProtectedVm",
):
    def __init__(
        self,
        scope: constructs.Construct,
        id: builtins.str,
        *,
        backup_policy_id: builtins.str,
        recovery_vault_name: builtins.str,
        resource_group_name: builtins.str,
        source_vm_id: builtins.str,
        tags: typing.Optional[typing.Mapping[builtins.str, builtins.str]] = None,
        timeouts: typing.Optional["BackupProtectedVmTimeouts"] = None,
        count: typing.Optional[jsii.Number] = None,
        depends_on: typing.Optional[typing.List[cdktf.TerraformResource]] = None,
        lifecycle: typing.Optional[cdktf.TerraformResourceLifecycle] = None,
        provider: typing.Optional[cdktf.TerraformProvider] = None,
    ) -> None:
        """
        :param scope: -
        :param id: -
        :param backup_policy_id: 
        :param recovery_vault_name: 
        :param resource_group_name: 
        :param source_vm_id: 
        :param tags: 
        :param timeouts: timeouts block.
        :param count: 
        :param depends_on: 
        :param lifecycle: 
        :param provider: 
        """
        config = BackupProtectedVmConfig(
            backup_policy_id=backup_policy_id,
            recovery_vault_name=recovery_vault_name,
            resource_group_name=resource_group_name,
            source_vm_id=source_vm_id,
            tags=tags,
            timeouts=timeouts,
            count=count,
            depends_on=depends_on,
            lifecycle=lifecycle,
            provider=provider,
        )

        jsii.create(BackupProtectedVm, self, [scope, id, config])

    @jsii.member(jsii_name="synthesizeAttributes")
    def _synthesize_attributes(self) -> typing.Mapping[builtins.str, typing.Any]:
        return jsii.invoke(self, "synthesizeAttributes", [])

    @builtins.property # type: ignore
    @jsii.member(jsii_name="backupPolicyId")
    def backup_policy_id(self) -> builtins.str:
        return jsii.get(self, "backupPolicyId")

    @backup_policy_id.setter # type: ignore
    def backup_policy_id(self, value: builtins.str) -> None:
        jsii.set(self, "backupPolicyId", value)

    @builtins.property # type: ignore
    @jsii.member(jsii_name="recoveryVaultName")
    def recovery_vault_name(self) -> builtins.str:
        return jsii.get(self, "recoveryVaultName")

    @recovery_vault_name.setter # type: ignore
    def recovery_vault_name(self, value: builtins.str) -> None:
        jsii.set(self, "recoveryVaultName", value)

    @builtins.property # type: ignore
    @jsii.member(jsii_name="resourceGroupName")
    def resource_group_name(self) -> builtins.str:
        return jsii.get(self, "resourceGroupName")

    @resource_group_name.setter # type: ignore
    def resource_group_name(self, value: builtins.str) -> None:
        jsii.set(self, "resourceGroupName", value)

    @builtins.property # type: ignore
    @jsii.member(jsii_name="sourceVmId")
    def source_vm_id(self) -> builtins.str:
        return jsii.get(self, "sourceVmId")

    @source_vm_id.setter # type: ignore
    def source_vm_id(self, value: builtins.str) -> None:
        jsii.set(self, "sourceVmId", value)

    @builtins.property # type: ignore
    @jsii.member(jsii_name="id")
    def id(self) -> typing.Optional[builtins.str]:
        return jsii.get(self, "id")

    @id.setter # type: ignore
    def id(self, value: typing.Optional[builtins.str]) -> None:
        jsii.set(self, "id", value)

    @builtins.property # type: ignore
    @jsii.member(jsii_name="tags")
    def tags(self) -> typing.Optional[typing.Mapping[builtins.str, builtins.str]]:
        return jsii.get(self, "tags")

    @tags.setter # type: ignore
    def tags(
        self,
        value: typing.Optional[typing.Mapping[builtins.str, builtins.str]],
    ) -> None:
        jsii.set(self, "tags", value)

    @builtins.property # type: ignore
    @jsii.member(jsii_name="timeouts")
    def timeouts(self) -> typing.Optional["BackupProtectedVmTimeouts"]:
        return jsii.get(self, "timeouts")

    @timeouts.setter # type: ignore
    def timeouts(self, value: typing.Optional["BackupProtectedVmTimeouts"]) -> None:
        jsii.set(self, "timeouts", value)


@jsii.data_type(
    jsii_type="@cdktf/provider-azurerm.BackupProtectedVmConfig",
    jsii_struct_bases=[cdktf.TerraformMetaArguments],
    name_mapping={
        "count": "count",
        "depends_on": "dependsOn",
        "lifecycle": "lifecycle",
        "provider": "provider",
        "backup_policy_id": "backupPolicyId",
        "recovery_vault_name": "recoveryVaultName",
        "resource_group_name": "resourceGroupName",
        "source_vm_id": "sourceVmId",
        "tags": "tags",
        "timeouts": "timeouts",
    },
)
class BackupProtectedVmConfig(cdktf.TerraformMetaArguments):
    def __init__(
        self,
        *,
        count: typing.Optional[jsii.Number] = None,
        depends_on: typing.Optional[typing.List[cdktf.TerraformResource]] = None,
        lifecycle: typing.Optional[cdktf.TerraformResourceLifecycle] = None,
        provider: typing.Optional[cdktf.TerraformProvider] = None,
        backup_policy_id: builtins.str,
        recovery_vault_name: builtins.str,
        resource_group_name: builtins.str,
        source_vm_id: builtins.str,
        tags: typing.Optional[typing.Mapping[builtins.str, builtins.str]] = None,
        timeouts: typing.Optional["BackupProtectedVmTimeouts"] = None,
    ) -> None:
        """
        :param count: 
        :param depends_on: 
        :param lifecycle: 
        :param provider: 
        :param backup_policy_id: 
        :param recovery_vault_name: 
        :param resource_group_name: 
        :param source_vm_id: 
        :param tags: 
        :param timeouts: timeouts block.
        """
        if isinstance(lifecycle, dict):
            lifecycle = cdktf.TerraformResourceLifecycle(**lifecycle)
        if isinstance(timeouts, dict):
            timeouts = BackupProtectedVmTimeouts(**timeouts)
        self._values: typing.Dict[str, typing.Any] = {
            "backup_policy_id": backup_policy_id,
            "recovery_vault_name": recovery_vault_name,
            "resource_group_name": resource_group_name,
            "source_vm_id": source_vm_id,
        }
        if count is not None:
            self._values["count"] = count
        if depends_on is not None:
            self._values["depends_on"] = depends_on
        if lifecycle is not None:
            self._values["lifecycle"] = lifecycle
        if provider is not None:
            self._values["provider"] = provider
        if tags is not None:
            self._values["tags"] = tags
        if timeouts is not None:
            self._values["timeouts"] = timeouts

    @builtins.property
    def count(self) -> typing.Optional[jsii.Number]:
        """
        :stability: experimental
        """
        result = self._values.get("count")
        return result

    @builtins.property
    def depends_on(self) -> typing.Optional[typing.List[cdktf.TerraformResource]]:
        """
        :stability: experimental
        """
        result = self._values.get("depends_on")
        return result

    @builtins.property
    def lifecycle(self) -> typing.Optional[cdktf.TerraformResourceLifecycle]:
        """
        :stability: experimental
        """
        result = self._values.get("lifecycle")
        return result

    @builtins.property
    def provider(self) -> typing.Optional[cdktf.TerraformProvider]:
        """
        :stability: experimental
        """
        result = self._values.get("provider")
        return result

    @builtins.property
    def backup_policy_id(self) -> builtins.str:
        result = self._values.get("backup_policy_id")
        assert result is not None, "Required property 'backup_policy_id' is missing"
        return result

    @builtins.property
    def recovery_vault_name(self) -> builtins.str:
        result = self._values.get("recovery_vault_name")
        assert result is not None, "Required property 'recovery_vault_name' is missing"
        return result

    @builtins.property
    def resource_group_name(self) -> builtins.str:
        result = self._values.get("resource_group_name")
        assert result is not None, "Required property 'resource_group_name' is missing"
        return result

    @builtins.property
    def source_vm_id(self) -> builtins.str:
        result = self._values.get("source_vm_id")
        assert result is not None, "Required property 'source_vm_id' is missing"
        return result

    @builtins.property
    def tags(self) -> typing.Optional[typing.Mapping[builtins.str, builtins.str]]:
        result = self._values.get("tags")
        return result

    @builtins.property
    def timeouts(self) -> typing.Optional["BackupProtectedVmTimeouts"]:
        """timeouts block."""
        result = self._values.get("timeouts")
        return result

    def __eq__(self, rhs: typing.Any) -> builtins.bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs: typing.Any) -> builtins.bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return "BackupProtectedVmConfig(%s)" % ", ".join(
            k + "=" + repr(v) for k, v in self._values.items()
        )


@jsii.data_type(
    jsii_type="@cdktf/provider-azurerm.BackupProtectedVmTimeouts",
    jsii_struct_bases=[],
    name_mapping={
        "create": "create",
        "delete": "delete",
        "read": "read",
        "update": "update",
    },
)
class BackupProtectedVmTimeouts:
    def __init__(
        self,
        *,
        create: typing.Optional[builtins.str] = None,
        delete: typing.Optional[builtins.str] = None,
        read: typing.Optional[builtins.str] = None,
        update: typing.Optional[builtins.str] = None,
    ) -> None:
        """
        :param create: 
        :param delete: 
        :param read: 
        :param update: 
        """
        self._values: typing.Dict[str, typing.Any] = {}
        if create is not None:
            self._values["create"] = create
        if delete is not None:
            self._values["delete"] = delete
        if read is not None:
            self._values["read"] = read
        if update is not None:
            self._values["update"] = update

    @builtins.property
    def create(self) -> typing.Optional[builtins.str]:
        result = self._values.get("create")
        return result

    @builtins.property
    def delete(self) -> typing.Optional[builtins.str]:
        result = self._values.get("delete")
        return result

    @builtins.property
    def read(self) -> typing.Optional[builtins.str]:
        result = self._values.get("read")
        return result

    @builtins.property
    def update(self) -> typing.Optional[builtins.str]:
        result = self._values.get("update")
        return result

    def __eq__(self, rhs: typing.Any) -> builtins.bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs: typing.Any) -> builtins.bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return "BackupProtectedVmTimeouts(%s)" % ", ".join(
            k + "=" + repr(v) for k, v in self._values.items()
        )


class BastionHost(
    cdktf.TerraformResource,
    metaclass=jsii.JSIIMeta,
    jsii_type="@cdktf/provider-azurerm.BastionHost",
):
    def __init__(
        self,
        scope: constructs.Construct,
        id: builtins.str,
        *,
        location: builtins.str,
        name: builtins.str,
        resource_group_name: builtins.str,
        ip_configuration: typing.Optional[typing.List["BastionHostIpConfiguration"]] = None,
        tags: typing.Optional[typing.Mapping[builtins.str, builtins.str]] = None,
        timeouts: typing.Optional["BastionHostTimeouts"] = None,
        count: typing.Optional[jsii.Number] = None,
        depends_on: typing.Optional[typing.List[cdktf.TerraformResource]] = None,
        lifecycle: typing.Optional[cdktf.TerraformResourceLifecycle] = None,
        provider: typing.Optional[cdktf.TerraformProvider] = None,
    ) -> None:
        """
        :param scope: -
        :param id: -
        :param location: 
        :param name: 
        :param resource_group_name: 
        :param ip_configuration: ip_configuration block.
        :param tags: 
        :param timeouts: timeouts block.
        :param count: 
        :param depends_on: 
        :param lifecycle: 
        :param provider: 
        """
        config = BastionHostConfig(
            location=location,
            name=name,
            resource_group_name=resource_group_name,
            ip_configuration=ip_configuration,
            tags=tags,
            timeouts=timeouts,
            count=count,
            depends_on=depends_on,
            lifecycle=lifecycle,
            provider=provider,
        )

        jsii.create(BastionHost, self, [scope, id, config])

    @jsii.member(jsii_name="synthesizeAttributes")
    def _synthesize_attributes(self) -> typing.Mapping[builtins.str, typing.Any]:
        return jsii.invoke(self, "synthesizeAttributes", [])

    @builtins.property # type: ignore
    @jsii.member(jsii_name="dnsName")
    def dns_name(self) -> builtins.str:
        return jsii.get(self, "dnsName")

    @builtins.property # type: ignore
    @jsii.member(jsii_name="location")
    def location(self) -> builtins.str:
        return jsii.get(self, "location")

    @location.setter # type: ignore
    def location(self, value: builtins.str) -> None:
        jsii.set(self, "location", value)

    @builtins.property # type: ignore
    @jsii.member(jsii_name="name")
    def name(self) -> builtins.str:
        return jsii.get(self, "name")

    @name.setter # type: ignore
    def name(self, value: builtins.str) -> None:
        jsii.set(self, "name", value)

    @builtins.property # type: ignore
    @jsii.member(jsii_name="resourceGroupName")
    def resource_group_name(self) -> builtins.str:
        return jsii.get(self, "resourceGroupName")

    @resource_group_name.setter # type: ignore
    def resource_group_name(self, value: builtins.str) -> None:
        jsii.set(self, "resourceGroupName", value)

    @builtins.property # type: ignore
    @jsii.member(jsii_name="id")
    def id(self) -> typing.Optional[builtins.str]:
        return jsii.get(self, "id")

    @id.setter # type: ignore
    def id(self, value: typing.Optional[builtins.str]) -> None:
        jsii.set(self, "id", value)

    @builtins.property # type: ignore
    @jsii.member(jsii_name="ipConfiguration")
    def ip_configuration(
        self,
    ) -> typing.Optional[typing.List["BastionHostIpConfiguration"]]:
        return jsii.get(self, "ipConfiguration")

    @ip_configuration.setter # type: ignore
    def ip_configuration(
        self,
        value: typing.Optional[typing.List["BastionHostIpConfiguration"]],
    ) -> None:
        jsii.set(self, "ipConfiguration", value)

    @builtins.property # type: ignore
    @jsii.member(jsii_name="tags")
    def tags(self) -> typing.Optional[typing.Mapping[builtins.str, builtins.str]]:
        return jsii.get(self, "tags")

    @tags.setter # type: ignore
    def tags(
        self,
        value: typing.Optional[typing.Mapping[builtins.str, builtins.str]],
    ) -> None:
        jsii.set(self, "tags", value)

    @builtins.property # type: ignore
    @jsii.member(jsii_name="timeouts")
    def timeouts(self) -> typing.Optional["BastionHostTimeouts"]:
        return jsii.get(self, "timeouts")

    @timeouts.setter # type: ignore
    def timeouts(self, value: typing.Optional["BastionHostTimeouts"]) -> None:
        jsii.set(self, "timeouts", value)


@jsii.data_type(
    jsii_type="@cdktf/provider-azurerm.BastionHostConfig",
    jsii_struct_bases=[cdktf.TerraformMetaArguments],
    name_mapping={
        "count": "count",
        "depends_on": "dependsOn",
        "lifecycle": "lifecycle",
        "provider": "provider",
        "location": "location",
        "name": "name",
        "resource_group_name": "resourceGroupName",
        "ip_configuration": "ipConfiguration",
        "tags": "tags",
        "timeouts": "timeouts",
    },
)
class BastionHostConfig(cdktf.TerraformMetaArguments):
    def __init__(
        self,
        *,
        count: typing.Optional[jsii.Number] = None,
        depends_on: typing.Optional[typing.List[cdktf.TerraformResource]] = None,
        lifecycle: typing.Optional[cdktf.TerraformResourceLifecycle] = None,
        provider: typing.Optional[cdktf.TerraformProvider] = None,
        location: builtins.str,
        name: builtins.str,
        resource_group_name: builtins.str,
        ip_configuration: typing.Optional[typing.List["BastionHostIpConfiguration"]] = None,
        tags: typing.Optional[typing.Mapping[builtins.str, builtins.str]] = None,
        timeouts: typing.Optional["BastionHostTimeouts"] = None,
    ) -> None:
        """
        :param count: 
        :param depends_on: 
        :param lifecycle: 
        :param provider: 
        :param location: 
        :param name: 
        :param resource_group_name: 
        :param ip_configuration: ip_configuration block.
        :param tags: 
        :param timeouts: timeouts block.
        """
        if isinstance(lifecycle, dict):
            lifecycle = cdktf.TerraformResourceLifecycle(**lifecycle)
        if isinstance(timeouts, dict):
            timeouts = BastionHostTimeouts(**timeouts)
        self._values: typing.Dict[str, typing.Any] = {
            "location": location,
            "name": name,
            "resource_group_name": resource_group_name,
        }
        if count is not None:
            self._values["count"] = count
        if depends_on is not None:
            self._values["depends_on"] = depends_on
        if lifecycle is not None:
            self._values["lifecycle"] = lifecycle
        if provider is not None:
            self._values["provider"] = provider
        if ip_configuration is not None:
            self._values["ip_configuration"] = ip_configuration
        if tags is not None:
            self._values["tags"] = tags
        if timeouts is not None:
            self._values["timeouts"] = timeouts

    @builtins.property
    def count(self) -> typing.Optional[jsii.Number]:
        """
        :stability: experimental
        """
        result = self._values.get("count")
        return result

    @builtins.property
    def depends_on(self) -> typing.Optional[typing.List[cdktf.TerraformResource]]:
        """
        :stability: experimental
        """
        result = self._values.get("depends_on")
        return result

    @builtins.property
    def lifecycle(self) -> typing.Optional[cdktf.TerraformResourceLifecycle]:
        """
        :stability: experimental
        """
        result = self._values.get("lifecycle")
        return result

    @builtins.property
    def provider(self) -> typing.Optional[cdktf.TerraformProvider]:
        """
        :stability: experimental
        """
        result = self._values.get("provider")
        return result

    @builtins.property
    def location(self) -> builtins.str:
        result = self._values.get("location")
        assert result is not None, "Required property 'location' is missing"
        return result

    @builtins.property
    def name(self) -> builtins.str:
        result = self._values.get("name")
        assert result is not None, "Required property 'name' is missing"
        return result

    @builtins.property
    def resource_group_name(self) -> builtins.str:
        result = self._values.get("resource_group_name")
        assert result is not None, "Required property 'resource_group_name' is missing"
        return result

    @builtins.property
    def ip_configuration(
        self,
    ) -> typing.Optional[typing.List["BastionHostIpConfiguration"]]:
        """ip_configuration block."""
        result = self._values.get("ip_configuration")
        return result

    @builtins.property
    def tags(self) -> typing.Optional[typing.Mapping[builtins.str, builtins.str]]:
        result = self._values.get("tags")
        return result

    @builtins.property
    def timeouts(self) -> typing.Optional["BastionHostTimeouts"]:
        """timeouts block."""
        result = self._values.get("timeouts")
        return result

    def __eq__(self, rhs: typing.Any) -> builtins.bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs: typing.Any) -> builtins.bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return "BastionHostConfig(%s)" % ", ".join(
            k + "=" + repr(v) for k, v in self._values.items()
        )


@jsii.data_type(
    jsii_type="@cdktf/provider-azurerm.BastionHostIpConfiguration",
    jsii_struct_bases=[],
    name_mapping={
        "name": "name",
        "public_ip_address_id": "publicIpAddressId",
        "subnet_id": "subnetId",
    },
)
class BastionHostIpConfiguration:
    def __init__(
        self,
        *,
        name: builtins.str,
        public_ip_address_id: builtins.str,
        subnet_id: builtins.str,
    ) -> None:
        """
        :param name: 
        :param public_ip_address_id: 
        :param subnet_id: 
        """
        self._values: typing.Dict[str, typing.Any] = {
            "name": name,
            "public_ip_address_id": public_ip_address_id,
            "subnet_id": subnet_id,
        }

    @builtins.property
    def name(self) -> builtins.str:
        result = self._values.get("name")
        assert result is not None, "Required property 'name' is missing"
        return result

    @builtins.property
    def public_ip_address_id(self) -> builtins.str:
        result = self._values.get("public_ip_address_id")
        assert result is not None, "Required property 'public_ip_address_id' is missing"
        return result

    @builtins.property
    def subnet_id(self) -> builtins.str:
        result = self._values.get("subnet_id")
        assert result is not None, "Required property 'subnet_id' is missing"
        return result

    def __eq__(self, rhs: typing.Any) -> builtins.bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs: typing.Any) -> builtins.bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return "BastionHostIpConfiguration(%s)" % ", ".join(
            k + "=" + repr(v) for k, v in self._values.items()
        )


@jsii.data_type(
    jsii_type="@cdktf/provider-azurerm.BastionHostTimeouts",
    jsii_struct_bases=[],
    name_mapping={
        "create": "create",
        "delete": "delete",
        "read": "read",
        "update": "update",
    },
)
class BastionHostTimeouts:
    def __init__(
        self,
        *,
        create: typing.Optional[builtins.str] = None,
        delete: typing.Optional[builtins.str] = None,
        read: typing.Optional[builtins.str] = None,
        update: typing.Optional[builtins.str] = None,
    ) -> None:
        """
        :param create: 
        :param delete: 
        :param read: 
        :param update: 
        """
        self._values: typing.Dict[str, typing.Any] = {}
        if create is not None:
            self._values["create"] = create
        if delete is not None:
            self._values["delete"] = delete
        if read is not None:
            self._values["read"] = read
        if update is not None:
            self._values["update"] = update

    @builtins.property
    def create(self) -> typing.Optional[builtins.str]:
        result = self._values.get("create")
        return result

    @builtins.property
    def delete(self) -> typing.Optional[builtins.str]:
        result = self._values.get("delete")
        return result

    @builtins.property
    def read(self) -> typing.Optional[builtins.str]:
        result = self._values.get("read")
        return result

    @builtins.property
    def update(self) -> typing.Optional[builtins.str]:
        result = self._values.get("update")
        return result

    def __eq__(self, rhs: typing.Any) -> builtins.bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs: typing.Any) -> builtins.bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return "BastionHostTimeouts(%s)" % ", ".join(
            k + "=" + repr(v) for k, v in self._values.items()
        )


class BatchAccount(
    cdktf.TerraformResource,
    metaclass=jsii.JSIIMeta,
    jsii_type="@cdktf/provider-azurerm.BatchAccount",
):
    def __init__(
        self,
        scope: constructs.Construct,
        id: builtins.str,
        *,
        location: builtins.str,
        name: builtins.str,
        resource_group_name: builtins.str,
        key_vault_reference: typing.Optional[typing.List["BatchAccountKeyVaultReference"]] = None,
        pool_allocation_mode: typing.Optional[builtins.str] = None,
        storage_account_id: typing.Optional[builtins.str] = None,
        tags: typing.Optional[typing.Mapping[builtins.str, builtins.str]] = None,
        timeouts: typing.Optional["BatchAccountTimeouts"] = None,
        count: typing.Optional[jsii.Number] = None,
        depends_on: typing.Optional[typing.List[cdktf.TerraformResource]] = None,
        lifecycle: typing.Optional[cdktf.TerraformResourceLifecycle] = None,
        provider: typing.Optional[cdktf.TerraformProvider] = None,
    ) -> None:
        """
        :param scope: -
        :param id: -
        :param location: 
        :param name: 
        :param resource_group_name: 
        :param key_vault_reference: key_vault_reference block.
        :param pool_allocation_mode: 
        :param storage_account_id: 
        :param tags: 
        :param timeouts: timeouts block.
        :param count: 
        :param depends_on: 
        :param lifecycle: 
        :param provider: 
        """
        config = BatchAccountConfig(
            location=location,
            name=name,
            resource_group_name=resource_group_name,
            key_vault_reference=key_vault_reference,
            pool_allocation_mode=pool_allocation_mode,
            storage_account_id=storage_account_id,
            tags=tags,
            timeouts=timeouts,
            count=count,
            depends_on=depends_on,
            lifecycle=lifecycle,
            provider=provider,
        )

        jsii.create(BatchAccount, self, [scope, id, config])

    @jsii.member(jsii_name="synthesizeAttributes")
    def _synthesize_attributes(self) -> typing.Mapping[builtins.str, typing.Any]:
        return jsii.invoke(self, "synthesizeAttributes", [])

    @builtins.property # type: ignore
    @jsii.member(jsii_name="accountEndpoint")
    def account_endpoint(self) -> builtins.str:
        return jsii.get(self, "accountEndpoint")

    @builtins.property # type: ignore
    @jsii.member(jsii_name="primaryAccessKey")
    def primary_access_key(self) -> builtins.str:
        return jsii.get(self, "primaryAccessKey")

    @builtins.property # type: ignore
    @jsii.member(jsii_name="secondaryAccessKey")
    def secondary_access_key(self) -> builtins.str:
        return jsii.get(self, "secondaryAccessKey")

    @builtins.property # type: ignore
    @jsii.member(jsii_name="location")
    def location(self) -> builtins.str:
        return jsii.get(self, "location")

    @location.setter # type: ignore
    def location(self, value: builtins.str) -> None:
        jsii.set(self, "location", value)

    @builtins.property # type: ignore
    @jsii.member(jsii_name="name")
    def name(self) -> builtins.str:
        return jsii.get(self, "name")

    @name.setter # type: ignore
    def name(self, value: builtins.str) -> None:
        jsii.set(self, "name", value)

    @builtins.property # type: ignore
    @jsii.member(jsii_name="resourceGroupName")
    def resource_group_name(self) -> builtins.str:
        return jsii.get(self, "resourceGroupName")

    @resource_group_name.setter # type: ignore
    def resource_group_name(self, value: builtins.str) -> None:
        jsii.set(self, "resourceGroupName", value)

    @builtins.property # type: ignore
    @jsii.member(jsii_name="id")
    def id(self) -> typing.Optional[builtins.str]:
        return jsii.get(self, "id")

    @id.setter # type: ignore
    def id(self, value: typing.Optional[builtins.str]) -> None:
        jsii.set(self, "id", value)

    @builtins.property # type: ignore
    @jsii.member(jsii_name="keyVaultReference")
    def key_vault_reference(
        self,
    ) -> typing.Optional[typing.List["BatchAccountKeyVaultReference"]]:
        return jsii.get(self, "keyVaultReference")

    @key_vault_reference.setter # type: ignore
    def key_vault_reference(
        self,
        value: typing.Optional[typing.List["BatchAccountKeyVaultReference"]],
    ) -> None:
        jsii.set(self, "keyVaultReference", value)

    @builtins.property # type: ignore
    @jsii.member(jsii_name="poolAllocationMode")
    def pool_allocation_mode(self) -> typing.Optional[builtins.str]:
        return jsii.get(self, "poolAllocationMode")

    @pool_allocation_mode.setter # type: ignore
    def pool_allocation_mode(self, value: typing.Optional[builtins.str]) -> None:
        jsii.set(self, "poolAllocationMode", value)

    @builtins.property # type: ignore
    @jsii.member(jsii_name="storageAccountId")
    def storage_account_id(self) -> typing.Optional[builtins.str]:
        return jsii.get(self, "storageAccountId")

    @storage_account_id.setter # type: ignore
    def storage_account_id(self, value: typing.Optional[builtins.str]) -> None:
        jsii.set(self, "storageAccountId", value)

    @builtins.property # type: ignore
    @jsii.member(jsii_name="tags")
    def tags(self) -> typing.Optional[typing.Mapping[builtins.str, builtins.str]]:
        return jsii.get(self, "tags")

    @tags.setter # type: ignore
    def tags(
        self,
        value: typing.Optional[typing.Mapping[builtins.str, builtins.str]],
    ) -> None:
        jsii.set(self, "tags", value)

    @builtins.property # type: ignore
    @jsii.member(jsii_name="timeouts")
    def timeouts(self) -> typing.Optional["BatchAccountTimeouts"]:
        return jsii.get(self, "timeouts")

    @timeouts.setter # type: ignore
    def timeouts(self, value: typing.Optional["BatchAccountTimeouts"]) -> None:
        jsii.set(self, "timeouts", value)


@jsii.data_type(
    jsii_type="@cdktf/provider-azurerm.BatchAccountConfig",
    jsii_struct_bases=[cdktf.TerraformMetaArguments],
    name_mapping={
        "count": "count",
        "depends_on": "dependsOn",
        "lifecycle": "lifecycle",
        "provider": "provider",
        "location": "location",
        "name": "name",
        "resource_group_name": "resourceGroupName",
        "key_vault_reference": "keyVaultReference",
        "pool_allocation_mode": "poolAllocationMode",
        "storage_account_id": "storageAccountId",
        "tags": "tags",
        "timeouts": "timeouts",
    },
)
class BatchAccountConfig(cdktf.TerraformMetaArguments):
    def __init__(
        self,
        *,
        count: typing.Optional[jsii.Number] = None,
        depends_on: typing.Optional[typing.List[cdktf.TerraformResource]] = None,
        lifecycle: typing.Optional[cdktf.TerraformResourceLifecycle] = None,
        provider: typing.Optional[cdktf.TerraformProvider] = None,
        location: builtins.str,
        name: builtins.str,
        resource_group_name: builtins.str,
        key_vault_reference: typing.Optional[typing.List["BatchAccountKeyVaultReference"]] = None,
        pool_allocation_mode: typing.Optional[builtins.str] = None,
        storage_account_id: typing.Optional[builtins.str] = None,
        tags: typing.Optional[typing.Mapping[builtins.str, builtins.str]] = None,
        timeouts: typing.Optional["BatchAccountTimeouts"] = None,
    ) -> None:
        """
        :param count: 
        :param depends_on: 
        :param lifecycle: 
        :param provider: 
        :param location: 
        :param name: 
        :param resource_group_name: 
        :param key_vault_reference: key_vault_reference block.
        :param pool_allocation_mode: 
        :param storage_account_id: 
        :param tags: 
        :param timeouts: timeouts block.
        """
        if isinstance(lifecycle, dict):
            lifecycle = cdktf.TerraformResourceLifecycle(**lifecycle)
        if isinstance(timeouts, dict):
            timeouts = BatchAccountTimeouts(**timeouts)
        self._values: typing.Dict[str, typing.Any] = {
            "location": location,
            "name": name,
            "resource_group_name": resource_group_name,
        }
        if count is not None:
            self._values["count"] = count
        if depends_on is not None:
            self._values["depends_on"] = depends_on
        if lifecycle is not None:
            self._values["lifecycle"] = lifecycle
        if provider is not None:
            self._values["provider"] = provider
        if key_vault_reference is not None:
            self._values["key_vault_reference"] = key_vault_reference
        if pool_allocation_mode is not None:
            self._values["pool_allocation_mode"] = pool_allocation_mode
        if storage_account_id is not None:
            self._values["storage_account_id"] = storage_account_id
        if tags is not None:
            self._values["tags"] = tags
        if timeouts is not None:
            self._values["timeouts"] = timeouts

    @builtins.property
    def count(self) -> typing.Optional[jsii.Number]:
        """
        :stability: experimental
        """
        result = self._values.get("count")
        return result

    @builtins.property
    def depends_on(self) -> typing.Optional[typing.List[cdktf.TerraformResource]]:
        """
        :stability: experimental
        """
        result = self._values.get("depends_on")
        return result

    @builtins.property
    def lifecycle(self) -> typing.Optional[cdktf.TerraformResourceLifecycle]:
        """
        :stability: experimental
        """
        result = self._values.get("lifecycle")
        return result

    @builtins.property
    def provider(self) -> typing.Optional[cdktf.TerraformProvider]:
        """
        :stability: experimental
        """
        result = self._values.get("provider")
        return result

    @builtins.property
    def location(self) -> builtins.str:
        result = self._values.get("location")
        assert result is not None, "Required property 'location' is missing"
        return result

    @builtins.property
    def name(self) -> builtins.str:
        result = self._values.get("name")
        assert result is not None, "Required property 'name' is missing"
        return result

    @builtins.property
    def resource_group_name(self) -> builtins.str:
        result = self._values.get("resource_group_name")
        assert result is not None, "Required property 'resource_group_name' is missing"
        return result

    @builtins.property
    def key_vault_reference(
        self,
    ) -> typing.Optional[typing.List["BatchAccountKeyVaultReference"]]:
        """key_vault_reference block."""
        result = self._values.get("key_vault_reference")
        return result

    @builtins.property
    def pool_allocation_mode(self) -> typing.Optional[builtins.str]:
        result = self._values.get("pool_allocation_mode")
        return result

    @builtins.property
    def storage_account_id(self) -> typing.Optional[builtins.str]:
        result = self._values.get("storage_account_id")
        return result

    @builtins.property
    def tags(self) -> typing.Optional[typing.Mapping[builtins.str, builtins.str]]:
        result = self._values.get("tags")
        return result

    @builtins.property
    def timeouts(self) -> typing.Optional["BatchAccountTimeouts"]:
        """timeouts block."""
        result = self._values.get("timeouts")
        return result

    def __eq__(self, rhs: typing.Any) -> builtins.bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs: typing.Any) -> builtins.bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return "BatchAccountConfig(%s)" % ", ".join(
            k + "=" + repr(v) for k, v in self._values.items()
        )


@jsii.data_type(
    jsii_type="@cdktf/provider-azurerm.BatchAccountKeyVaultReference",
    jsii_struct_bases=[],
    name_mapping={"id": "id", "url": "url"},
)
class BatchAccountKeyVaultReference:
    def __init__(self, *, id: builtins.str, url: builtins.str) -> None:
        """
        :param id: 
        :param url: 
        """
        self._values: typing.Dict[str, typing.Any] = {
            "id": id,
            "url": url,
        }

    @builtins.property
    def id(self) -> builtins.str:
        result = self._values.get("id")
        assert result is not None, "Required property 'id' is missing"
        return result

    @builtins.property
    def url(self) -> builtins.str:
        result = self._values.get("url")
        assert result is not None, "Required property 'url' is missing"
        return result

    def __eq__(self, rhs: typing.Any) -> builtins.bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs: typing.Any) -> builtins.bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return "BatchAccountKeyVaultReference(%s)" % ", ".join(
            k + "=" + repr(v) for k, v in self._values.items()
        )


@jsii.data_type(
    jsii_type="@cdktf/provider-azurerm.BatchAccountTimeouts",
    jsii_struct_bases=[],
    name_mapping={
        "create": "create",
        "delete": "delete",
        "read": "read",
        "update": "update",
    },
)
class BatchAccountTimeouts:
    def __init__(
        self,
        *,
        create: typing.Optional[builtins.str] = None,
        delete: typing.Optional[builtins.str] = None,
        read: typing.Optional[builtins.str] = None,
        update: typing.Optional[builtins.str] = None,
    ) -> None:
        """
        :param create: 
        :param delete: 
        :param read: 
        :param update: 
        """
        self._values: typing.Dict[str, typing.Any] = {}
        if create is not None:
            self._values["create"] = create
        if delete is not None:
            self._values["delete"] = delete
        if read is not None:
            self._values["read"] = read
        if update is not None:
            self._values["update"] = update

    @builtins.property
    def create(self) -> typing.Optional[builtins.str]:
        result = self._values.get("create")
        return result

    @builtins.property
    def delete(self) -> typing.Optional[builtins.str]:
        result = self._values.get("delete")
        return result

    @builtins.property
    def read(self) -> typing.Optional[builtins.str]:
        result = self._values.get("read")
        return result

    @builtins.property
    def update(self) -> typing.Optional[builtins.str]:
        result = self._values.get("update")
        return result

    def __eq__(self, rhs: typing.Any) -> builtins.bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs: typing.Any) -> builtins.bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return "BatchAccountTimeouts(%s)" % ", ".join(
            k + "=" + repr(v) for k, v in self._values.items()
        )


class BatchApplication(
    cdktf.TerraformResource,
    metaclass=jsii.JSIIMeta,
    jsii_type="@cdktf/provider-azurerm.BatchApplication",
):
    def __init__(
        self,
        scope: constructs.Construct,
        id: builtins.str,
        *,
        account_name: builtins.str,
        name: builtins.str,
        resource_group_name: builtins.str,
        allow_updates: typing.Optional[builtins.bool] = None,
        default_version: typing.Optional[builtins.str] = None,
        display_name: typing.Optional[builtins.str] = None,
        timeouts: typing.Optional["BatchApplicationTimeouts"] = None,
        count: typing.Optional[jsii.Number] = None,
        depends_on: typing.Optional[typing.List[cdktf.TerraformResource]] = None,
        lifecycle: typing.Optional[cdktf.TerraformResourceLifecycle] = None,
        provider: typing.Optional[cdktf.TerraformProvider] = None,
    ) -> None:
        """
        :param scope: -
        :param id: -
        :param account_name: 
        :param name: 
        :param resource_group_name: 
        :param allow_updates: 
        :param default_version: 
        :param display_name: 
        :param timeouts: timeouts block.
        :param count: 
        :param depends_on: 
        :param lifecycle: 
        :param provider: 
        """
        config = BatchApplicationConfig(
            account_name=account_name,
            name=name,
            resource_group_name=resource_group_name,
            allow_updates=allow_updates,
            default_version=default_version,
            display_name=display_name,
            timeouts=timeouts,
            count=count,
            depends_on=depends_on,
            lifecycle=lifecycle,
            provider=provider,
        )

        jsii.create(BatchApplication, self, [scope, id, config])

    @jsii.member(jsii_name="synthesizeAttributes")
    def _synthesize_attributes(self) -> typing.Mapping[builtins.str, typing.Any]:
        return jsii.invoke(self, "synthesizeAttributes", [])

    @builtins.property # type: ignore
    @jsii.member(jsii_name="accountName")
    def account_name(self) -> builtins.str:
        return jsii.get(self, "accountName")

    @account_name.setter # type: ignore
    def account_name(self, value: builtins.str) -> None:
        jsii.set(self, "accountName", value)

    @builtins.property # type: ignore
    @jsii.member(jsii_name="name")
    def name(self) -> builtins.str:
        return jsii.get(self, "name")

    @name.setter # type: ignore
    def name(self, value: builtins.str) -> None:
        jsii.set(self, "name", value)

    @builtins.property # type: ignore
    @jsii.member(jsii_name="resourceGroupName")
    def resource_group_name(self) -> builtins.str:
        return jsii.get(self, "resourceGroupName")

    @resource_group_name.setter # type: ignore
    def resource_group_name(self, value: builtins.str) -> None:
        jsii.set(self, "resourceGroupName", value)

    @builtins.property # type: ignore
    @jsii.member(jsii_name="allowUpdates")
    def allow_updates(self) -> typing.Optional[builtins.bool]:
        return jsii.get(self, "allowUpdates")

    @allow_updates.setter # type: ignore
    def allow_updates(self, value: typing.Optional[builtins.bool]) -> None:
        jsii.set(self, "allowUpdates", value)

    @builtins.property # type: ignore
    @jsii.member(jsii_name="defaultVersion")
    def default_version(self) -> typing.Optional[builtins.str]:
        return jsii.get(self, "defaultVersion")

    @default_version.setter # type: ignore
    def default_version(self, value: typing.Optional[builtins.str]) -> None:
        jsii.set(self, "defaultVersion", value)

    @builtins.property # type: ignore
    @jsii.member(jsii_name="displayName")
    def display_name(self) -> typing.Optional[builtins.str]:
        return jsii.get(self, "displayName")

    @display_name.setter # type: ignore
    def display_name(self, value: typing.Optional[builtins.str]) -> None:
        jsii.set(self, "displayName", value)

    @builtins.property # type: ignore
    @jsii.member(jsii_name="id")
    def id(self) -> typing.Optional[builtins.str]:
        return jsii.get(self, "id")

    @id.setter # type: ignore
    def id(self, value: typing.Optional[builtins.str]) -> None:
        jsii.set(self, "id", value)

    @builtins.property # type: ignore
    @jsii.member(jsii_name="timeouts")
    def timeouts(self) -> typing.Optional["BatchApplicationTimeouts"]:
        return jsii.get(self, "timeouts")

    @timeouts.setter # type: ignore
    def timeouts(self, value: typing.Optional["BatchApplicationTimeouts"]) -> None:
        jsii.set(self, "timeouts", value)


@jsii.data_type(
    jsii_type="@cdktf/provider-azurerm.BatchApplicationConfig",
    jsii_struct_bases=[cdktf.TerraformMetaArguments],
    name_mapping={
        "count": "count",
        "depends_on": "dependsOn",
        "lifecycle": "lifecycle",
        "provider": "provider",
        "account_name": "accountName",
        "name": "name",
        "resource_group_name": "resourceGroupName",
        "allow_updates": "allowUpdates",
        "default_version": "defaultVersion",
        "display_name": "displayName",
        "timeouts": "timeouts",
    },
)
class BatchApplicationConfig(cdktf.TerraformMetaArguments):
    def __init__(
        self,
        *,
        count: typing.Optional[jsii.Number] = None,
        depends_on: typing.Optional[typing.List[cdktf.TerraformResource]] = None,
        lifecycle: typing.Optional[cdktf.TerraformResourceLifecycle] = None,
        provider: typing.Optional[cdktf.TerraformProvider] = None,
        account_name: builtins.str,
        name: builtins.str,
        resource_group_name: builtins.str,
        allow_updates: typing.Optional[builtins.bool] = None,
        default_version: typing.Optional[builtins.str] = None,
        display_name: typing.Optional[builtins.str] = None,
        timeouts: typing.Optional["BatchApplicationTimeouts"] = None,
    ) -> None:
        """
        :param count: 
        :param depends_on: 
        :param lifecycle: 
        :param provider: 
        :param account_name: 
        :param name: 
        :param resource_group_name: 
        :param allow_updates: 
        :param default_version: 
        :param display_name: 
        :param timeouts: timeouts block.
        """
        if isinstance(lifecycle, dict):
            lifecycle = cdktf.TerraformResourceLifecycle(**lifecycle)
        if isinstance(timeouts, dict):
            timeouts = BatchApplicationTimeouts(**timeouts)
        self._values: typing.Dict[str, typing.Any] = {
            "account_name": account_name,
            "name": name,
            "resource_group_name": resource_group_name,
        }
        if count is not None:
            self._values["count"] = count
        if depends_on is not None:
            self._values["depends_on"] = depends_on
        if lifecycle is not None:
            self._values["lifecycle"] = lifecycle
        if provider is not None:
            self._values["provider"] = provider
        if allow_updates is not None:
            self._values["allow_updates"] = allow_updates
        if default_version is not None:
            self._values["default_version"] = default_version
        if display_name is not None:
            self._values["display_name"] = display_name
        if timeouts is not None:
            self._values["timeouts"] = timeouts

    @builtins.property
    def count(self) -> typing.Optional[jsii.Number]:
        """
        :stability: experimental
        """
        result = self._values.get("count")
        return result

    @builtins.property
    def depends_on(self) -> typing.Optional[typing.List[cdktf.TerraformResource]]:
        """
        :stability: experimental
        """
        result = self._values.get("depends_on")
        return result

    @builtins.property
    def lifecycle(self) -> typing.Optional[cdktf.TerraformResourceLifecycle]:
        """
        :stability: experimental
        """
        result = self._values.get("lifecycle")
        return result

    @builtins.property
    def provider(self) -> typing.Optional[cdktf.TerraformProvider]:
        """
        :stability: experimental
        """
        result = self._values.get("provider")
        return result

    @builtins.property
    def account_name(self) -> builtins.str:
        result = self._values.get("account_name")
        assert result is not None, "Required property 'account_name' is missing"
        return result

    @builtins.property
    def name(self) -> builtins.str:
        result = self._values.get("name")
        assert result is not None, "Required property 'name' is missing"
        return result

    @builtins.property
    def resource_group_name(self) -> builtins.str:
        result = self._values.get("resource_group_name")
        assert result is not None, "Required property 'resource_group_name' is missing"
        return result

    @builtins.property
    def allow_updates(self) -> typing.Optional[builtins.bool]:
        result = self._values.get("allow_updates")
        return result

    @builtins.property
    def default_version(self) -> typing.Optional[builtins.str]:
        result = self._values.get("default_version")
        return result

    @builtins.property
    def display_name(self) -> typing.Optional[builtins.str]:
        result = self._values.get("display_name")
        return result

    @builtins.property
    def timeouts(self) -> typing.Optional["BatchApplicationTimeouts"]:
        """timeouts block."""
        result = self._values.get("timeouts")
        return result

    def __eq__(self, rhs: typing.Any) -> builtins.bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs: typing.Any) -> builtins.bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return "BatchApplicationConfig(%s)" % ", ".join(
            k + "=" + repr(v) for k, v in self._values.items()
        )


@jsii.data_type(
    jsii_type="@cdktf/provider-azurerm.BatchApplicationTimeouts",
    jsii_struct_bases=[],
    name_mapping={
        "create": "create",
        "delete": "delete",
        "read": "read",
        "update": "update",
    },
)
class BatchApplicationTimeouts:
    def __init__(
        self,
        *,
        create: typing.Optional[builtins.str] = None,
        delete: typing.Optional[builtins.str] = None,
        read: typing.Optional[builtins.str] = None,
        update: typing.Optional[builtins.str] = None,
    ) -> None:
        """
        :param create: 
        :param delete: 
        :param read: 
        :param update: 
        """
        self._values: typing.Dict[str, typing.Any] = {}
        if create is not None:
            self._values["create"] = create
        if delete is not None:
            self._values["delete"] = delete
        if read is not None:
            self._values["read"] = read
        if update is not None:
            self._values["update"] = update

    @builtins.property
    def create(self) -> typing.Optional[builtins.str]:
        result = self._values.get("create")
        return result

    @builtins.property
    def delete(self) -> typing.Optional[builtins.str]:
        result = self._values.get("delete")
        return result

    @builtins.property
    def read(self) -> typing.Optional[builtins.str]:
        result = self._values.get("read")
        return result

    @builtins.property
    def update(self) -> typing.Optional[builtins.str]:
        result = self._values.get("update")
        return result

    def __eq__(self, rhs: typing.Any) -> builtins.bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs: typing.Any) -> builtins.bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return "BatchApplicationTimeouts(%s)" % ", ".join(
            k + "=" + repr(v) for k, v in self._values.items()
        )


class BatchCertificate(
    cdktf.TerraformResource,
    metaclass=jsii.JSIIMeta,
    jsii_type="@cdktf/provider-azurerm.BatchCertificate",
):
    def __init__(
        self,
        scope: constructs.Construct,
        id: builtins.str,
        *,
        account_name: builtins.str,
        certificate: builtins.str,
        format: builtins.str,
        resource_group_name: builtins.str,
        thumbprint: builtins.str,
        thumbprint_algorithm: builtins.str,
        password: typing.Optional[builtins.str] = None,
        timeouts: typing.Optional["BatchCertificateTimeouts"] = None,
        count: typing.Optional[jsii.Number] = None,
        depends_on: typing.Optional[typing.List[cdktf.TerraformResource]] = None,
        lifecycle: typing.Optional[cdktf.TerraformResourceLifecycle] = None,
        provider: typing.Optional[cdktf.TerraformProvider] = None,
    ) -> None:
        """
        :param scope: -
        :param id: -
        :param account_name: 
        :param certificate: 
        :param format: 
        :param resource_group_name: 
        :param thumbprint: 
        :param thumbprint_algorithm: 
        :param password: 
        :param timeouts: timeouts block.
        :param count: 
        :param depends_on: 
        :param lifecycle: 
        :param provider: 
        """
        config = BatchCertificateConfig(
            account_name=account_name,
            certificate=certificate,
            format=format,
            resource_group_name=resource_group_name,
            thumbprint=thumbprint,
            thumbprint_algorithm=thumbprint_algorithm,
            password=password,
            timeouts=timeouts,
            count=count,
            depends_on=depends_on,
            lifecycle=lifecycle,
            provider=provider,
        )

        jsii.create(BatchCertificate, self, [scope, id, config])

    @jsii.member(jsii_name="synthesizeAttributes")
    def _synthesize_attributes(self) -> typing.Mapping[builtins.str, typing.Any]:
        return jsii.invoke(self, "synthesizeAttributes", [])

    @builtins.property # type: ignore
    @jsii.member(jsii_name="name")
    def name(self) -> builtins.str:
        return jsii.get(self, "name")

    @builtins.property # type: ignore
    @jsii.member(jsii_name="publicData")
    def public_data(self) -> builtins.str:
        return jsii.get(self, "publicData")

    @builtins.property # type: ignore
    @jsii.member(jsii_name="accountName")
    def account_name(self) -> builtins.str:
        return jsii.get(self, "accountName")

    @account_name.setter # type: ignore
    def account_name(self, value: builtins.str) -> None:
        jsii.set(self, "accountName", value)

    @builtins.property # type: ignore
    @jsii.member(jsii_name="certificate")
    def certificate(self) -> builtins.str:
        return jsii.get(self, "certificate")

    @certificate.setter # type: ignore
    def certificate(self, value: builtins.str) -> None:
        jsii.set(self, "certificate", value)

    @builtins.property # type: ignore
    @jsii.member(jsii_name="format")
    def format(self) -> builtins.str:
        return jsii.get(self, "format")

    @format.setter # type: ignore
    def format(self, value: builtins.str) -> None:
        jsii.set(self, "format", value)

    @builtins.property # type: ignore
    @jsii.member(jsii_name="resourceGroupName")
    def resource_group_name(self) -> builtins.str:
        return jsii.get(self, "resourceGroupName")

    @resource_group_name.setter # type: ignore
    def resource_group_name(self, value: builtins.str) -> None:
        jsii.set(self, "resourceGroupName", value)

    @builtins.property # type: ignore
    @jsii.member(jsii_name="thumbprint")
    def thumbprint(self) -> builtins.str:
        return jsii.get(self, "thumbprint")

    @thumbprint.setter # type: ignore
    def thumbprint(self, value: builtins.str) -> None:
        jsii.set(self, "thumbprint", value)

    @builtins.property # type: ignore
    @jsii.member(jsii_name="thumbprintAlgorithm")
    def thumbprint_algorithm(self) -> builtins.str:
        return jsii.get(self, "thumbprintAlgorithm")

    @thumbprint_algorithm.setter # type: ignore
    def thumbprint_algorithm(self, value: builtins.str) -> None:
        jsii.set(self, "thumbprintAlgorithm", value)

    @builtins.property # type: ignore
    @jsii.member(jsii_name="id")
    def id(self) -> typing.Optional[builtins.str]:
        return jsii.get(self, "id")

    @id.setter # type: ignore
    def id(self, value: typing.Optional[builtins.str]) -> None:
        jsii.set(self, "id", value)

    @builtins.property # type: ignore
    @jsii.member(jsii_name="password")
    def password(self) -> typing.Optional[builtins.str]:
        return jsii.get(self, "password")

    @password.setter # type: ignore
    def password(self, value: typing.Optional[builtins.str]) -> None:
        jsii.set(self, "password", value)

    @builtins.property # type: ignore
    @jsii.member(jsii_name="timeouts")
    def timeouts(self) -> typing.Optional["BatchCertificateTimeouts"]:
        return jsii.get(self, "timeouts")

    @timeouts.setter # type: ignore
    def timeouts(self, value: typing.Optional["BatchCertificateTimeouts"]) -> None:
        jsii.set(self, "timeouts", value)


@jsii.data_type(
    jsii_type="@cdktf/provider-azurerm.BatchCertificateConfig",
    jsii_struct_bases=[cdktf.TerraformMetaArguments],
    name_mapping={
        "count": "count",
        "depends_on": "dependsOn",
        "lifecycle": "lifecycle",
        "provider": "provider",
        "account_name": "accountName",
        "certificate": "certificate",
        "format": "format",
        "resource_group_name": "resourceGroupName",
        "thumbprint": "thumbprint",
        "thumbprint_algorithm": "thumbprintAlgorithm",
        "password": "password",
        "timeouts": "timeouts",
    },
)
class BatchCertificateConfig(cdktf.TerraformMetaArguments):
    def __init__(
        self,
        *,
        count: typing.Optional[jsii.Number] = None,
        depends_on: typing.Optional[typing.List[cdktf.TerraformResource]] = None,
        lifecycle: typing.Optional[cdktf.TerraformResourceLifecycle] = None,
        provider: typing.Optional[cdktf.TerraformProvider] = None,
        account_name: builtins.str,
        certificate: builtins.str,
        format: builtins.str,
        resource_group_name: builtins.str,
        thumbprint: builtins.str,
        thumbprint_algorithm: builtins.str,
        password: typing.Optional[builtins.str] = None,
        timeouts: typing.Optional["BatchCertificateTimeouts"] = None,
    ) -> None:
        """
        :param count: 
        :param depends_on: 
        :param lifecycle: 
        :param provider: 
        :param account_name: 
        :param certificate: 
        :param format: 
        :param resource_group_name: 
        :param thumbprint: 
        :param thumbprint_algorithm: 
        :param password: 
        :param timeouts: timeouts block.
        """
        if isinstance(lifecycle, dict):
            lifecycle = cdktf.TerraformResourceLifecycle(**lifecycle)
        if isinstance(timeouts, dict):
            timeouts = BatchCertificateTimeouts(**timeouts)
        self._values: typing.Dict[str, typing.Any] = {
            "account_name": account_name,
            "certificate": certificate,
            "format": format,
            "resource_group_name": resource_group_name,
            "thumbprint": thumbprint,
            "thumbprint_algorithm": thumbprint_algorithm,
        }
        if count is not None:
            self._values["count"] = count
        if depends_on is not None:
            self._values["depends_on"] = depends_on
        if lifecycle is not None:
            self._values["lifecycle"] = lifecycle
        if provider is not None:
            self._values["provider"] = provider
        if password is not None:
            self._values["password"] = password
        if timeouts is not None:
            self._values["timeouts"] = timeouts

    @builtins.property
    def count(self) -> typing.Optional[jsii.Number]:
        """
        :stability: experimental
        """
        result = self._values.get("count")
        return result

    @builtins.property
    def depends_on(self) -> typing.Optional[typing.List[cdktf.TerraformResource]]:
        """
        :stability: experimental
        """
        result = self._values.get("depends_on")
        return result

    @builtins.property
    def lifecycle(self) -> typing.Optional[cdktf.TerraformResourceLifecycle]:
        """
        :stability: experimental
        """
        result = self._values.get("lifecycle")
        return result

    @builtins.property
    def provider(self) -> typing.Optional[cdktf.TerraformProvider]:
        """
        :stability: experimental
        """
        result = self._values.get("provider")
        return result

    @builtins.property
    def account_name(self) -> builtins.str:
        result = self._values.get("account_name")
        assert result is not None, "Required property 'account_name' is missing"
        return result

    @builtins.property
    def certificate(self) -> builtins.str:
        result = self._values.get("certificate")
        assert result is not None, "Required property 'certificate' is missing"
        return result

    @builtins.property
    def format(self) -> builtins.str:
        result = self._values.get("format")
        assert result is not None, "Required property 'format' is missing"
        return result

    @builtins.property
    def resource_group_name(self) -> builtins.str:
        result = self._values.get("resource_group_name")
        assert result is not None, "Required property 'resource_group_name' is missing"
        return result

    @builtins.property
    def thumbprint(self) -> builtins.str:
        result = self._values.get("thumbprint")
        assert result is not None, "Required property 'thumbprint' is missing"
        return result

    @builtins.property
    def thumbprint_algorithm(self) -> builtins.str:
        result = self._values.get("thumbprint_algorithm")
        assert result is not None, "Required property 'thumbprint_algorithm' is missing"
        return result

    @builtins.property
    def password(self) -> typing.Optional[builtins.str]:
        result = self._values.get("password")
        return result

    @builtins.property
    def timeouts(self) -> typing.Optional["BatchCertificateTimeouts"]:
        """timeouts block."""
        result = self._values.get("timeouts")
        return result

    def __eq__(self, rhs: typing.Any) -> builtins.bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs: typing.Any) -> builtins.bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return "BatchCertificateConfig(%s)" % ", ".join(
            k + "=" + repr(v) for k, v in self._values.items()
        )


@jsii.data_type(
    jsii_type="@cdktf/provider-azurerm.BatchCertificateTimeouts",
    jsii_struct_bases=[],
    name_mapping={
        "create": "create",
        "delete": "delete",
        "read": "read",
        "update": "update",
    },
)
class BatchCertificateTimeouts:
    def __init__(
        self,
        *,
        create: typing.Optional[builtins.str] = None,
        delete: typing.Optional[builtins.str] = None,
        read: typing.Optional[builtins.str] = None,
        update: typing.Optional[builtins.str] = None,
    ) -> None:
        """
        :param create: 
        :param delete: 
        :param read: 
        :param update: 
        """
        self._values: typing.Dict[str, typing.Any] = {}
        if create is not None:
            self._values["create"] = create
        if delete is not None:
            self._values["delete"] = delete
        if read is not None:
            self._values["read"] = read
        if update is not None:
            self._values["update"] = update

    @builtins.property
    def create(self) -> typing.Optional[builtins.str]:
        result = self._values.get("create")
        return result

    @builtins.property
    def delete(self) -> typing.Optional[builtins.str]:
        result = self._values.get("delete")
        return result

    @builtins.property
    def read(self) -> typing.Optional[builtins.str]:
        result = self._values.get("read")
        return result

    @builtins.property
    def update(self) -> typing.Optional[builtins.str]:
        result = self._values.get("update")
        return result

    def __eq__(self, rhs: typing.Any) -> builtins.bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs: typing.Any) -> builtins.bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return "BatchCertificateTimeouts(%s)" % ", ".join(
            k + "=" + repr(v) for k, v in self._values.items()
        )


class BatchPool(
    cdktf.TerraformResource,
    metaclass=jsii.JSIIMeta,
    jsii_type="@cdktf/provider-azurerm.BatchPool",
):
    def __init__(
        self,
        scope: constructs.Construct,
        id: builtins.str,
        *,
        account_name: builtins.str,
        name: builtins.str,
        node_agent_sku_id: builtins.str,
        resource_group_name: builtins.str,
        storage_image_reference: typing.List["BatchPoolStorageImageReference"],
        vm_size: builtins.str,
        auto_scale: typing.Optional[typing.List["BatchPoolAutoScale"]] = None,
        certificate: typing.Optional[typing.List["BatchPoolCertificate"]] = None,
        container_configuration: typing.Optional[typing.List["BatchPoolContainerConfiguration"]] = None,
        display_name: typing.Optional[builtins.str] = None,
        fixed_scale: typing.Optional[typing.List["BatchPoolFixedScale"]] = None,
        max_tasks_per_node: typing.Optional[jsii.Number] = None,
        metadata: typing.Optional[typing.Mapping[builtins.str, builtins.str]] = None,
        network_configuration: typing.Optional[typing.List["BatchPoolNetworkConfiguration"]] = None,
        start_task: typing.Optional[typing.List["BatchPoolStartTask"]] = None,
        stop_pending_resize_operation: typing.Optional[builtins.bool] = None,
        timeouts: typing.Optional["BatchPoolTimeouts"] = None,
        count: typing.Optional[jsii.Number] = None,
        depends_on: typing.Optional[typing.List[cdktf.TerraformResource]] = None,
        lifecycle: typing.Optional[cdktf.TerraformResourceLifecycle] = None,
        provider: typing.Optional[cdktf.TerraformProvider] = None,
    ) -> None:
        """
        :param scope: -
        :param id: -
        :param account_name: 
        :param name: 
        :param node_agent_sku_id: 
        :param resource_group_name: 
        :param storage_image_reference: storage_image_reference block.
        :param vm_size: 
        :param auto_scale: auto_scale block.
        :param certificate: certificate block.
        :param container_configuration: container_configuration block.
        :param display_name: 
        :param fixed_scale: fixed_scale block.
        :param max_tasks_per_node: 
        :param metadata: 
        :param network_configuration: network_configuration block.
        :param start_task: start_task block.
        :param stop_pending_resize_operation: 
        :param timeouts: timeouts block.
        :param count: 
        :param depends_on: 
        :param lifecycle: 
        :param provider: 
        """
        config = BatchPoolConfig(
            account_name=account_name,
            name=name,
            node_agent_sku_id=node_agent_sku_id,
            resource_group_name=resource_group_name,
            storage_image_reference=storage_image_reference,
            vm_size=vm_size,
            auto_scale=auto_scale,
            certificate=certificate,
            container_configuration=container_configuration,
            display_name=display_name,
            fixed_scale=fixed_scale,
            max_tasks_per_node=max_tasks_per_node,
            metadata=metadata,
            network_configuration=network_configuration,
            start_task=start_task,
            stop_pending_resize_operation=stop_pending_resize_operation,
            timeouts=timeouts,
            count=count,
            depends_on=depends_on,
            lifecycle=lifecycle,
            provider=provider,
        )

        jsii.create(BatchPool, self, [scope, id, config])

    @jsii.member(jsii_name="synthesizeAttributes")
    def _synthesize_attributes(self) -> typing.Mapping[builtins.str, typing.Any]:
        return jsii.invoke(self, "synthesizeAttributes", [])

    @builtins.property # type: ignore
    @jsii.member(jsii_name="accountName")
    def account_name(self) -> builtins.str:
        return jsii.get(self, "accountName")

    @account_name.setter # type: ignore
    def account_name(self, value: builtins.str) -> None:
        jsii.set(self, "accountName", value)

    @builtins.property # type: ignore
    @jsii.member(jsii_name="name")
    def name(self) -> builtins.str:
        return jsii.get(self, "name")

    @name.setter # type: ignore
    def name(self, value: builtins.str) -> None:
        jsii.set(self, "name", value)

    @builtins.property # type: ignore
    @jsii.member(jsii_name="nodeAgentSkuId")
    def node_agent_sku_id(self) -> builtins.str:
        return jsii.get(self, "nodeAgentSkuId")

    @node_agent_sku_id.setter # type: ignore
    def node_agent_sku_id(self, value: builtins.str) -> None:
        jsii.set(self, "nodeAgentSkuId", value)

    @builtins.property # type: ignore
    @jsii.member(jsii_name="resourceGroupName")
    def resource_group_name(self) -> builtins.str:
        return jsii.get(self, "resourceGroupName")

    @resource_group_name.setter # type: ignore
    def resource_group_name(self, value: builtins.str) -> None:
        jsii.set(self, "resourceGroupName", value)

    @builtins.property # type: ignore
    @jsii.member(jsii_name="storageImageReference")
    def storage_image_reference(self) -> typing.List["BatchPoolStorageImageReference"]:
        return jsii.get(self, "storageImageReference")

    @storage_image_reference.setter # type: ignore
    def storage_image_reference(
        self,
        value: typing.List["BatchPoolStorageImageReference"],
    ) -> None:
        jsii.set(self, "storageImageReference", value)

    @builtins.property # type: ignore
    @jsii.member(jsii_name="vmSize")
    def vm_size(self) -> builtins.str:
        return jsii.get(self, "vmSize")

    @vm_size.setter # type: ignore
    def vm_size(self, value: builtins.str) -> None:
        jsii.set(self, "vmSize", value)

    @builtins.property # type: ignore
    @jsii.member(jsii_name="autoScale")
    def auto_scale(self) -> typing.Optional[typing.List["BatchPoolAutoScale"]]:
        return jsii.get(self, "autoScale")

    @auto_scale.setter # type: ignore
    def auto_scale(
        self,
        value: typing.Optional[typing.List["BatchPoolAutoScale"]],
    ) -> None:
        jsii.set(self, "autoScale", value)

    @builtins.property # type: ignore
    @jsii.member(jsii_name="certificate")
    def certificate(self) -> typing.Optional[typing.List["BatchPoolCertificate"]]:
        return jsii.get(self, "certificate")

    @certificate.setter # type: ignore
    def certificate(
        self,
        value: typing.Optional[typing.List["BatchPoolCertificate"]],
    ) -> None:
        jsii.set(self, "certificate", value)

    @builtins.property # type: ignore
    @jsii.member(jsii_name="containerConfiguration")
    def container_configuration(
        self,
    ) -> typing.Optional[typing.List["BatchPoolContainerConfiguration"]]:
        return jsii.get(self, "containerConfiguration")

    @container_configuration.setter # type: ignore
    def container_configuration(
        self,
        value: typing.Optional[typing.List["BatchPoolContainerConfiguration"]],
    ) -> None:
        jsii.set(self, "containerConfiguration", value)

    @builtins.property # type: ignore
    @jsii.member(jsii_name="displayName")
    def display_name(self) -> typing.Optional[builtins.str]:
        return jsii.get(self, "displayName")

    @display_name.setter # type: ignore
    def display_name(self, value: typing.Optional[builtins.str]) -> None:
        jsii.set(self, "displayName", value)

    @builtins.property # type: ignore
    @jsii.member(jsii_name="fixedScale")
    def fixed_scale(self) -> typing.Optional[typing.List["BatchPoolFixedScale"]]:
        return jsii.get(self, "fixedScale")

    @fixed_scale.setter # type: ignore
    def fixed_scale(
        self,
        value: typing.Optional[typing.List["BatchPoolFixedScale"]],
    ) -> None:
        jsii.set(self, "fixedScale", value)

    @builtins.property # type: ignore
    @jsii.member(jsii_name="id")
    def id(self) -> typing.Optional[builtins.str]:
        return jsii.get(self, "id")

    @id.setter # type: ignore
    def id(self, value: typing.Optional[builtins.str]) -> None:
        jsii.set(self, "id", value)

    @builtins.property # type: ignore
    @jsii.member(jsii_name="maxTasksPerNode")
    def max_tasks_per_node(self) -> typing.Optional[jsii.Number]:
        return jsii.get(self, "maxTasksPerNode")

    @max_tasks_per_node.setter # type: ignore
    def max_tasks_per_node(self, value: typing.Optional[jsii.Number]) -> None:
        jsii.set(self, "maxTasksPerNode", value)

    @builtins.property # type: ignore
    @jsii.member(jsii_name="metadata")
    def metadata(self) -> typing.Optional[typing.Mapping[builtins.str, builtins.str]]:
        return jsii.get(self, "metadata")

    @metadata.setter # type: ignore
    def metadata(
        self,
        value: typing.Optional[typing.Mapping[builtins.str, builtins.str]],
    ) -> None:
        jsii.set(self, "metadata", value)

    @builtins.property # type: ignore
    @jsii.member(jsii_name="networkConfiguration")
    def network_configuration(
        self,
    ) -> typing.Optional[typing.List["BatchPoolNetworkConfiguration"]]:
        return jsii.get(self, "networkConfiguration")

    @network_configuration.setter # type: ignore
    def network_configuration(
        self,
        value: typing.Optional[typing.List["BatchPoolNetworkConfiguration"]],
    ) -> None:
        jsii.set(self, "networkConfiguration", value)

    @builtins.property # type: ignore
    @jsii.member(jsii_name="startTask")
    def start_task(self) -> typing.Optional[typing.List["BatchPoolStartTask"]]:
        return jsii.get(self, "startTask")

    @start_task.setter # type: ignore
    def start_task(
        self,
        value: typing.Optional[typing.List["BatchPoolStartTask"]],
    ) -> None:
        jsii.set(self, "startTask", value)

    @builtins.property # type: ignore
    @jsii.member(jsii_name="stopPendingResizeOperation")
    def stop_pending_resize_operation(self) -> typing.Optional[builtins.bool]:
        return jsii.get(self, "stopPendingResizeOperation")

    @stop_pending_resize_operation.setter # type: ignore
    def stop_pending_resize_operation(
        self,
        value: typing.Optional[builtins.bool],
    ) -> None:
        jsii.set(self, "stopPendingResizeOperation", value)

    @builtins.property # type: ignore
    @jsii.member(jsii_name="timeouts")
    def timeouts(self) -> typing.Optional["BatchPoolTimeouts"]:
        return jsii.get(self, "timeouts")

    @timeouts.setter # type: ignore
    def timeouts(self, value: typing.Optional["BatchPoolTimeouts"]) -> None:
        jsii.set(self, "timeouts", value)


@jsii.data_type(
    jsii_type="@cdktf/provider-azurerm.BatchPoolAutoScale",
    jsii_struct_bases=[],
    name_mapping={"formula": "formula", "evaluation_interval": "evaluationInterval"},
)
class BatchPoolAutoScale:
    def __init__(
        self,
        *,
        formula: builtins.str,
        evaluation_interval: typing.Optional[builtins.str] = None,
    ) -> None:
        """
        :param formula: 
        :param evaluation_interval: 
        """
        self._values: typing.Dict[str, typing.Any] = {
            "formula": formula,
        }
        if evaluation_interval is not None:
            self._values["evaluation_interval"] = evaluation_interval

    @builtins.property
    def formula(self) -> builtins.str:
        result = self._values.get("formula")
        assert result is not None, "Required property 'formula' is missing"
        return result

    @builtins.property
    def evaluation_interval(self) -> typing.Optional[builtins.str]:
        result = self._values.get("evaluation_interval")
        return result

    def __eq__(self, rhs: typing.Any) -> builtins.bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs: typing.Any) -> builtins.bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return "BatchPoolAutoScale(%s)" % ", ".join(
            k + "=" + repr(v) for k, v in self._values.items()
        )


@jsii.data_type(
    jsii_type="@cdktf/provider-azurerm.BatchPoolCertificate",
    jsii_struct_bases=[],
    name_mapping={
        "id": "id",
        "store_location": "storeLocation",
        "store_name": "storeName",
        "visibility": "visibility",
    },
)
class BatchPoolCertificate:
    def __init__(
        self,
        *,
        id: builtins.str,
        store_location: builtins.str,
        store_name: typing.Optional[builtins.str] = None,
        visibility: typing.Optional[typing.List[builtins.str]] = None,
    ) -> None:
        """
        :param id: 
        :param store_location: 
        :param store_name: 
        :param visibility: 
        """
        self._values: typing.Dict[str, typing.Any] = {
            "id": id,
            "store_location": store_location,
        }
        if store_name is not None:
            self._values["store_name"] = store_name
        if visibility is not None:
            self._values["visibility"] = visibility

    @builtins.property
    def id(self) -> builtins.str:
        result = self._values.get("id")
        assert result is not None, "Required property 'id' is missing"
        return result

    @builtins.property
    def store_location(self) -> builtins.str:
        result = self._values.get("store_location")
        assert result is not None, "Required property 'store_location' is missing"
        return result

    @builtins.property
    def store_name(self) -> typing.Optional[builtins.str]:
        result = self._values.get("store_name")
        return result

    @builtins.property
    def visibility(self) -> typing.Optional[typing.List[builtins.str]]:
        result = self._values.get("visibility")
        return result

    def __eq__(self, rhs: typing.Any) -> builtins.bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs: typing.Any) -> builtins.bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return "BatchPoolCertificate(%s)" % ", ".join(
            k + "=" + repr(v) for k, v in self._values.items()
        )


@jsii.data_type(
    jsii_type="@cdktf/provider-azurerm.BatchPoolConfig",
    jsii_struct_bases=[cdktf.TerraformMetaArguments],
    name_mapping={
        "count": "count",
        "depends_on": "dependsOn",
        "lifecycle": "lifecycle",
        "provider": "provider",
        "account_name": "accountName",
        "name": "name",
        "node_agent_sku_id": "nodeAgentSkuId",
        "resource_group_name": "resourceGroupName",
        "storage_image_reference": "storageImageReference",
        "vm_size": "vmSize",
        "auto_scale": "autoScale",
        "certificate": "certificate",
        "container_configuration": "containerConfiguration",
        "display_name": "displayName",
        "fixed_scale": "fixedScale",
        "max_tasks_per_node": "maxTasksPerNode",
        "metadata": "metadata",
        "network_configuration": "networkConfiguration",
        "start_task": "startTask",
        "stop_pending_resize_operation": "stopPendingResizeOperation",
        "timeouts": "timeouts",
    },
)
class BatchPoolConfig(cdktf.TerraformMetaArguments):
    def __init__(
        self,
        *,
        count: typing.Optional[jsii.Number] = None,
        depends_on: typing.Optional[typing.List[cdktf.TerraformResource]] = None,
        lifecycle: typing.Optional[cdktf.TerraformResourceLifecycle] = None,
        provider: typing.Optional[cdktf.TerraformProvider] = None,
        account_name: builtins.str,
        name: builtins.str,
        node_agent_sku_id: builtins.str,
        resource_group_name: builtins.str,
        storage_image_reference: typing.List["BatchPoolStorageImageReference"],
        vm_size: builtins.str,
        auto_scale: typing.Optional[typing.List[BatchPoolAutoScale]] = None,
        certificate: typing.Optional[typing.List[BatchPoolCertificate]] = None,
        container_configuration: typing.Optional[typing.List["BatchPoolContainerConfiguration"]] = None,
        display_name: typing.Optional[builtins.str] = None,
        fixed_scale: typing.Optional[typing.List["BatchPoolFixedScale"]] = None,
        max_tasks_per_node: typing.Optional[jsii.Number] = None,
        metadata: typing.Optional[typing.Mapping[builtins.str, builtins.str]] = None,
        network_configuration: typing.Optional[typing.List["BatchPoolNetworkConfiguration"]] = None,
        start_task: typing.Optional[typing.List["BatchPoolStartTask"]] = None,
        stop_pending_resize_operation: typing.Optional[builtins.bool] = None,
        timeouts: typing.Optional["BatchPoolTimeouts"] = None,
    ) -> None:
        """
        :param count: 
        :param depends_on: 
        :param lifecycle: 
        :param provider: 
        :param account_name: 
        :param name: 
        :param node_agent_sku_id: 
        :param resource_group_name: 
        :param storage_image_reference: storage_image_reference block.
        :param vm_size: 
        :param auto_scale: auto_scale block.
        :param certificate: certificate block.
        :param container_configuration: container_configuration block.
        :param display_name: 
        :param fixed_scale: fixed_scale block.
        :param max_tasks_per_node: 
        :param metadata: 
        :param network_configuration: network_configuration block.
        :param start_task: start_task block.
        :param stop_pending_resize_operation: 
        :param timeouts: timeouts block.
        """
        if isinstance(lifecycle, dict):
            lifecycle = cdktf.TerraformResourceLifecycle(**lifecycle)
        if isinstance(timeouts, dict):
            timeouts = BatchPoolTimeouts(**timeouts)
        self._values: typing.Dict[str, typing.Any] = {
            "account_name": account_name,
            "name": name,
            "node_agent_sku_id": node_agent_sku_id,
            "resource_group_name": resource_group_name,
            "storage_image_reference": storage_image_reference,
            "vm_size": vm_size,
        }
        if count is not None:
            self._values["count"] = count
        if depends_on is not None:
            self._values["depends_on"] = depends_on
        if lifecycle is not None:
            self._values["lifecycle"] = lifecycle
        if provider is not None:
            self._values["provider"] = provider
        if auto_scale is not None:
            self._values["auto_scale"] = auto_scale
        if certificate is not None:
            self._values["certificate"] = certificate
        if container_configuration is not None:
            self._values["container_configuration"] = container_configuration
        if display_name is not None:
            self._values["display_name"] = display_name
        if fixed_scale is not None:
            self._values["fixed_scale"] = fixed_scale
        if max_tasks_per_node is not None:
            self._values["max_tasks_per_node"] = max_tasks_per_node
        if metadata is not None:
            self._values["metadata"] = metadata
        if network_configuration is not None:
            self._values["network_configuration"] = network_configuration
        if start_task is not None:
            self._values["start_task"] = start_task
        if stop_pending_resize_operation is not None:
            self._values["stop_pending_resize_operation"] = stop_pending_resize_operation
        if timeouts is not None:
            self._values["timeouts"] = timeouts

    @builtins.property
    def count(self) -> typing.Optional[jsii.Number]:
        """
        :stability: experimental
        """
        result = self._values.get("count")
        return result

    @builtins.property
    def depends_on(self) -> typing.Optional[typing.List[cdktf.TerraformResource]]:
        """
        :stability: experimental
        """
        result = self._values.get("depends_on")
        return result

    @builtins.property
    def lifecycle(self) -> typing.Optional[cdktf.TerraformResourceLifecycle]:
        """
        :stability: experimental
        """
        result = self._values.get("lifecycle")
        return result

    @builtins.property
    def provider(self) -> typing.Optional[cdktf.TerraformProvider]:
        """
        :stability: experimental
        """
        result = self._values.get("provider")
        return result

    @builtins.property
    def account_name(self) -> builtins.str:
        result = self._values.get("account_name")
        assert result is not None, "Required property 'account_name' is missing"
        return result

    @builtins.property
    def name(self) -> builtins.str:
        result = self._values.get("name")
        assert result is not None, "Required property 'name' is missing"
        return result

    @builtins.property
    def node_agent_sku_id(self) -> builtins.str:
        result = self._values.get("node_agent_sku_id")
        assert result is not None, "Required property 'node_agent_sku_id' is missing"
        return result

    @builtins.property
    def resource_group_name(self) -> builtins.str:
        result = self._values.get("resource_group_name")
        assert result is not None, "Required property 'resource_group_name' is missing"
        return result

    @builtins.property
    def storage_image_reference(self) -> typing.List["BatchPoolStorageImageReference"]:
        """storage_image_reference block."""
        result = self._values.get("storage_image_reference")
        assert result is not None, "Required property 'storage_image_reference' is missing"
        return result

    @builtins.property
    def vm_size(self) -> builtins.str:
        result = self._values.get("vm_size")
        assert result is not None, "Required property 'vm_size' is missing"
        return result

    @builtins.property
    def auto_scale(self) -> typing.Optional[typing.List[BatchPoolAutoScale]]:
        """auto_scale block."""
        result = self._values.get("auto_scale")
        return result

    @builtins.property
    def certificate(self) -> typing.Optional[typing.List[BatchPoolCertificate]]:
        """certificate block."""
        result = self._values.get("certificate")
        return result

    @builtins.property
    def container_configuration(
        self,
    ) -> typing.Optional[typing.List["BatchPoolContainerConfiguration"]]:
        """container_configuration block."""
        result = self._values.get("container_configuration")
        return result

    @builtins.property
    def display_name(self) -> typing.Optional[builtins.str]:
        result = self._values.get("display_name")
        return result

    @builtins.property
    def fixed_scale(self) -> typing.Optional[typing.List["BatchPoolFixedScale"]]:
        """fixed_scale block."""
        result = self._values.get("fixed_scale")
        return result

    @builtins.property
    def max_tasks_per_node(self) -> typing.Optional[jsii.Number]:
        result = self._values.get("max_tasks_per_node")
        return result

    @builtins.property
    def metadata(self) -> typing.Optional[typing.Mapping[builtins.str, builtins.str]]:
        result = self._values.get("metadata")
        return result

    @builtins.property
    def network_configuration(
        self,
    ) -> typing.Optional[typing.List["BatchPoolNetworkConfiguration"]]:
        """network_configuration block."""
        result = self._values.get("network_configuration")
        return result

    @builtins.property
    def start_task(self) -> typing.Optional[typing.List["BatchPoolStartTask"]]:
        """start_task block."""
        result = self._values.get("start_task")
        return result

    @builtins.property
    def stop_pending_resize_operation(self) -> typing.Optional[builtins.bool]:
        result = self._values.get("stop_pending_resize_operation")
        return result

    @builtins.property
    def timeouts(self) -> typing.Optional["BatchPoolTimeouts"]:
        """timeouts block."""
        result = self._values.get("timeouts")
        return result

    def __eq__(self, rhs: typing.Any) -> builtins.bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs: typing.Any) -> builtins.bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return "BatchPoolConfig(%s)" % ", ".join(
            k + "=" + repr(v) for k, v in self._values.items()
        )


@jsii.data_type(
    jsii_type="@cdktf/provider-azurerm.BatchPoolContainerConfiguration",
    jsii_struct_bases=[],
    name_mapping={"container_registries": "containerRegistries", "type": "type"},
)
class BatchPoolContainerConfiguration:
    def __init__(
        self,
        *,
        container_registries: typing.Optional[typing.List["BatchPoolContainerConfigurationContainerRegistries"]] = None,
        type: typing.Optional[builtins.str] = None,
    ) -> None:
        """
        :param container_registries: 
        :param type: 
        """
        self._values: typing.Dict[str, typing.Any] = {}
        if container_registries is not None:
            self._values["container_registries"] = container_registries
        if type is not None:
            self._values["type"] = type

    @builtins.property
    def container_registries(
        self,
    ) -> typing.Optional[typing.List["BatchPoolContainerConfigurationContainerRegistries"]]:
        result = self._values.get("container_registries")
        return result

    @builtins.property
    def type(self) -> typing.Optional[builtins.str]:
        result = self._values.get("type")
        return result

    def __eq__(self, rhs: typing.Any) -> builtins.bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs: typing.Any) -> builtins.bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return "BatchPoolContainerConfiguration(%s)" % ", ".join(
            k + "=" + repr(v) for k, v in self._values.items()
        )


@jsii.data_type(
    jsii_type="@cdktf/provider-azurerm.BatchPoolContainerConfigurationContainerRegistries",
    jsii_struct_bases=[],
    name_mapping={
        "password": "password",
        "registry_server": "registryServer",
        "user_name": "userName",
    },
)
class BatchPoolContainerConfigurationContainerRegistries:
    def __init__(
        self,
        *,
        password: typing.Optional[builtins.str] = None,
        registry_server: typing.Optional[builtins.str] = None,
        user_name: typing.Optional[builtins.str] = None,
    ) -> None:
        """
        :param password: 
        :param registry_server: 
        :param user_name: 
        """
        self._values: typing.Dict[str, typing.Any] = {}
        if password is not None:
            self._values["password"] = password
        if registry_server is not None:
            self._values["registry_server"] = registry_server
        if user_name is not None:
            self._values["user_name"] = user_name

    @builtins.property
    def password(self) -> typing.Optional[builtins.str]:
        result = self._values.get("password")
        return result

    @builtins.property
    def registry_server(self) -> typing.Optional[builtins.str]:
        result = self._values.get("registry_server")
        return result

    @builtins.property
    def user_name(self) -> typing.Optional[builtins.str]:
        result = self._values.get("user_name")
        return result

    def __eq__(self, rhs: typing.Any) -> builtins.bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs: typing.Any) -> builtins.bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return "BatchPoolContainerConfigurationContainerRegistries(%s)" % ", ".join(
            k + "=" + repr(v) for k, v in self._values.items()
        )


@jsii.data_type(
    jsii_type="@cdktf/provider-azurerm.BatchPoolFixedScale",
    jsii_struct_bases=[],
    name_mapping={
        "resize_timeout": "resizeTimeout",
        "target_dedicated_nodes": "targetDedicatedNodes",
        "target_low_priority_nodes": "targetLowPriorityNodes",
    },
)
class BatchPoolFixedScale:
    def __init__(
        self,
        *,
        resize_timeout: typing.Optional[builtins.str] = None,
        target_dedicated_nodes: typing.Optional[jsii.Number] = None,
        target_low_priority_nodes: typing.Optional[jsii.Number] = None,
    ) -> None:
        """
        :param resize_timeout: 
        :param target_dedicated_nodes: 
        :param target_low_priority_nodes: 
        """
        self._values: typing.Dict[str, typing.Any] = {}
        if resize_timeout is not None:
            self._values["resize_timeout"] = resize_timeout
        if target_dedicated_nodes is not None:
            self._values["target_dedicated_nodes"] = target_dedicated_nodes
        if target_low_priority_nodes is not None:
            self._values["target_low_priority_nodes"] = target_low_priority_nodes

    @builtins.property
    def resize_timeout(self) -> typing.Optional[builtins.str]:
        result = self._values.get("resize_timeout")
        return result

    @builtins.property
    def target_dedicated_nodes(self) -> typing.Optional[jsii.Number]:
        result = self._values.get("target_dedicated_nodes")
        return result

    @builtins.property
    def target_low_priority_nodes(self) -> typing.Optional[jsii.Number]:
        result = self._values.get("target_low_priority_nodes")
        return result

    def __eq__(self, rhs: typing.Any) -> builtins.bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs: typing.Any) -> builtins.bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return "BatchPoolFixedScale(%s)" % ", ".join(
            k + "=" + repr(v) for k, v in self._values.items()
        )


@jsii.data_type(
    jsii_type="@cdktf/provider-azurerm.BatchPoolNetworkConfiguration",
    jsii_struct_bases=[],
    name_mapping={
        "subnet_id": "subnetId",
        "endpoint_configuration": "endpointConfiguration",
    },
)
class BatchPoolNetworkConfiguration:
    def __init__(
        self,
        *,
        subnet_id: builtins.str,
        endpoint_configuration: typing.Optional[typing.List["BatchPoolNetworkConfigurationEndpointConfiguration"]] = None,
    ) -> None:
        """
        :param subnet_id: 
        :param endpoint_configuration: endpoint_configuration block.
        """
        self._values: typing.Dict[str, typing.Any] = {
            "subnet_id": subnet_id,
        }
        if endpoint_configuration is not None:
            self._values["endpoint_configuration"] = endpoint_configuration

    @builtins.property
    def subnet_id(self) -> builtins.str:
        result = self._values.get("subnet_id")
        assert result is not None, "Required property 'subnet_id' is missing"
        return result

    @builtins.property
    def endpoint_configuration(
        self,
    ) -> typing.Optional[typing.List["BatchPoolNetworkConfigurationEndpointConfiguration"]]:
        """endpoint_configuration block."""
        result = self._values.get("endpoint_configuration")
        return result

    def __eq__(self, rhs: typing.Any) -> builtins.bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs: typing.Any) -> builtins.bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return "BatchPoolNetworkConfiguration(%s)" % ", ".join(
            k + "=" + repr(v) for k, v in self._values.items()
        )


@jsii.data_type(
    jsii_type="@cdktf/provider-azurerm.BatchPoolNetworkConfigurationEndpointConfiguration",
    jsii_struct_bases=[],
    name_mapping={
        "backend_port": "backendPort",
        "frontend_port_range": "frontendPortRange",
        "name": "name",
        "protocol": "protocol",
        "network_security_group_rules": "networkSecurityGroupRules",
    },
)
class BatchPoolNetworkConfigurationEndpointConfiguration:
    def __init__(
        self,
        *,
        backend_port: jsii.Number,
        frontend_port_range: builtins.str,
        name: builtins.str,
        protocol: builtins.str,
        network_security_group_rules: typing.Optional[typing.List["BatchPoolNetworkConfigurationEndpointConfigurationNetworkSecurityGroupRules"]] = None,
    ) -> None:
        """
        :param backend_port: 
        :param frontend_port_range: 
        :param name: 
        :param protocol: 
        :param network_security_group_rules: network_security_group_rules block.
        """
        self._values: typing.Dict[str, typing.Any] = {
            "backend_port": backend_port,
            "frontend_port_range": frontend_port_range,
            "name": name,
            "protocol": protocol,
        }
        if network_security_group_rules is not None:
            self._values["network_security_group_rules"] = network_security_group_rules

    @builtins.property
    def backend_port(self) -> jsii.Number:
        result = self._values.get("backend_port")
        assert result is not None, "Required property 'backend_port' is missing"
        return result

    @builtins.property
    def frontend_port_range(self) -> builtins.str:
        result = self._values.get("frontend_port_range")
        assert result is not None, "Required property 'frontend_port_range' is missing"
        return result

    @builtins.property
    def name(self) -> builtins.str:
        result = self._values.get("name")
        assert result is not None, "Required property 'name' is missing"
        return result

    @builtins.property
    def protocol(self) -> builtins.str:
        result = self._values.get("protocol")
        assert result is not None, "Required property 'protocol' is missing"
        return result

    @builtins.property
    def network_security_group_rules(
        self,
    ) -> typing.Optional[typing.List["BatchPoolNetworkConfigurationEndpointConfigurationNetworkSecurityGroupRules"]]:
        """network_security_group_rules block."""
        result = self._values.get("network_security_group_rules")
        return result

    def __eq__(self, rhs: typing.Any) -> builtins.bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs: typing.Any) -> builtins.bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return "BatchPoolNetworkConfigurationEndpointConfiguration(%s)" % ", ".join(
            k + "=" + repr(v) for k, v in self._values.items()
        )


@jsii.data_type(
    jsii_type="@cdktf/provider-azurerm.BatchPoolNetworkConfigurationEndpointConfigurationNetworkSecurityGroupRules",
    jsii_struct_bases=[],
    name_mapping={
        "access": "access",
        "priority": "priority",
        "source_address_prefix": "sourceAddressPrefix",
    },
)
class BatchPoolNetworkConfigurationEndpointConfigurationNetworkSecurityGroupRules:
    def __init__(
        self,
        *,
        access: builtins.str,
        priority: jsii.Number,
        source_address_prefix: builtins.str,
    ) -> None:
        """
        :param access: 
        :param priority: 
        :param source_address_prefix: 
        """
        self._values: typing.Dict[str, typing.Any] = {
            "access": access,
            "priority": priority,
            "source_address_prefix": source_address_prefix,
        }

    @builtins.property
    def access(self) -> builtins.str:
        result = self._values.get("access")
        assert result is not None, "Required property 'access' is missing"
        return result

    @builtins.property
    def priority(self) -> jsii.Number:
        result = self._values.get("priority")
        assert result is not None, "Required property 'priority' is missing"
        return result

    @builtins.property
    def source_address_prefix(self) -> builtins.str:
        result = self._values.get("source_address_prefix")
        assert result is not None, "Required property 'source_address_prefix' is missing"
        return result

    def __eq__(self, rhs: typing.Any) -> builtins.bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs: typing.Any) -> builtins.bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return "BatchPoolNetworkConfigurationEndpointConfigurationNetworkSecurityGroupRules(%s)" % ", ".join(
            k + "=" + repr(v) for k, v in self._values.items()
        )


@jsii.data_type(
    jsii_type="@cdktf/provider-azurerm.BatchPoolStartTask",
    jsii_struct_bases=[],
    name_mapping={
        "command_line": "commandLine",
        "user_identity": "userIdentity",
        "environment": "environment",
        "max_task_retry_count": "maxTaskRetryCount",
        "resource_file": "resourceFile",
        "wait_for_success": "waitForSuccess",
    },
)
class BatchPoolStartTask:
    def __init__(
        self,
        *,
        command_line: builtins.str,
        user_identity: typing.List["BatchPoolStartTaskUserIdentity"],
        environment: typing.Optional[typing.Mapping[builtins.str, builtins.str]] = None,
        max_task_retry_count: typing.Optional[jsii.Number] = None,
        resource_file: typing.Optional[typing.List["BatchPoolStartTaskResourceFile"]] = None,
        wait_for_success: typing.Optional[builtins.bool] = None,
    ) -> None:
        """
        :param command_line: 
        :param user_identity: user_identity block.
        :param environment: 
        :param max_task_retry_count: 
        :param resource_file: resource_file block.
        :param wait_for_success: 
        """
        self._values: typing.Dict[str, typing.Any] = {
            "command_line": command_line,
            "user_identity": user_identity,
        }
        if environment is not None:
            self._values["environment"] = environment
        if max_task_retry_count is not None:
            self._values["max_task_retry_count"] = max_task_retry_count
        if resource_file is not None:
            self._values["resource_file"] = resource_file
        if wait_for_success is not None:
            self._values["wait_for_success"] = wait_for_success

    @builtins.property
    def command_line(self) -> builtins.str:
        result = self._values.get("command_line")
        assert result is not None, "Required property 'command_line' is missing"
        return result

    @builtins.property
    def user_identity(self) -> typing.List["BatchPoolStartTaskUserIdentity"]:
        """user_identity block."""
        result = self._values.get("user_identity")
        assert result is not None, "Required property 'user_identity' is missing"
        return result

    @builtins.property
    def environment(
        self,
    ) -> typing.Optional[typing.Mapping[builtins.str, builtins.str]]:
        result = self._values.get("environment")
        return result

    @builtins.property
    def max_task_retry_count(self) -> typing.Optional[jsii.Number]:
        result = self._values.get("max_task_retry_count")
        return result

    @builtins.property
    def resource_file(
        self,
    ) -> typing.Optional[typing.List["BatchPoolStartTaskResourceFile"]]:
        """resource_file block."""
        result = self._values.get("resource_file")
        return result

    @builtins.property
    def wait_for_success(self) -> typing.Optional[builtins.bool]:
        result = self._values.get("wait_for_success")
        return result

    def __eq__(self, rhs: typing.Any) -> builtins.bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs: typing.Any) -> builtins.bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return "BatchPoolStartTask(%s)" % ", ".join(
            k + "=" + repr(v) for k, v in self._values.items()
        )


@jsii.data_type(
    jsii_type="@cdktf/provider-azurerm.BatchPoolStartTaskResourceFile",
    jsii_struct_bases=[],
    name_mapping={
        "auto_storage_container_name": "autoStorageContainerName",
        "blob_prefix": "blobPrefix",
        "file_mode": "fileMode",
        "file_path": "filePath",
        "http_url": "httpUrl",
        "storage_container_url": "storageContainerUrl",
    },
)
class BatchPoolStartTaskResourceFile:
    def __init__(
        self,
        *,
        auto_storage_container_name: typing.Optional[builtins.str] = None,
        blob_prefix: typing.Optional[builtins.str] = None,
        file_mode: typing.Optional[builtins.str] = None,
        file_path: typing.Optional[builtins.str] = None,
        http_url: typing.Optional[builtins.str] = None,
        storage_container_url: typing.Optional[builtins.str] = None,
    ) -> None:
        """
        :param auto_storage_container_name: 
        :param blob_prefix: 
        :param file_mode: 
        :param file_path: 
        :param http_url: 
        :param storage_container_url: 
        """
        self._values: typing.Dict[str, typing.Any] = {}
        if auto_storage_container_name is not None:
            self._values["auto_storage_container_name"] = auto_storage_container_name
        if blob_prefix is not None:
            self._values["blob_prefix"] = blob_prefix
        if file_mode is not None:
            self._values["file_mode"] = file_mode
        if file_path is not None:
            self._values["file_path"] = file_path
        if http_url is not None:
            self._values["http_url"] = http_url
        if storage_container_url is not None:
            self._values["storage_container_url"] = storage_container_url

    @builtins.property
    def auto_storage_container_name(self) -> typing.Optional[builtins.str]:
        result = self._values.get("auto_storage_container_name")
        return result

    @builtins.property
    def blob_prefix(self) -> typing.Optional[builtins.str]:
        result = self._values.get("blob_prefix")
        return result

    @builtins.property
    def file_mode(self) -> typing.Optional[builtins.str]:
        result = self._values.get("file_mode")
        return result

    @builtins.property
    def file_path(self) -> typing.Optional[builtins.str]:
        result = self._values.get("file_path")
        return result

    @builtins.property
    def http_url(self) -> typing.Optional[builtins.str]:
        result = self._values.get("http_url")
        return result

    @builtins.property
    def storage_container_url(self) -> typing.Optional[builtins.str]:
        result = self._values.get("storage_container_url")
        return result

    def __eq__(self, rhs: typing.Any) -> builtins.bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs: typing.Any) -> builtins.bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return "BatchPoolStartTaskResourceFile(%s)" % ", ".join(
            k + "=" + repr(v) for k, v in self._values.items()
        )


@jsii.data_type(
    jsii_type="@cdktf/provider-azurerm.BatchPoolStartTaskUserIdentity",
    jsii_struct_bases=[],
    name_mapping={"auto_user": "autoUser", "user_name": "userName"},
)
class BatchPoolStartTaskUserIdentity:
    def __init__(
        self,
        *,
        auto_user: typing.Optional[typing.List["BatchPoolStartTaskUserIdentityAutoUser"]] = None,
        user_name: typing.Optional[builtins.str] = None,
    ) -> None:
        """
        :param auto_user: auto_user block.
        :param user_name: 
        """
        self._values: typing.Dict[str, typing.Any] = {}
        if auto_user is not None:
            self._values["auto_user"] = auto_user
        if user_name is not None:
            self._values["user_name"] = user_name

    @builtins.property
    def auto_user(
        self,
    ) -> typing.Optional[typing.List["BatchPoolStartTaskUserIdentityAutoUser"]]:
        """auto_user block."""
        result = self._values.get("auto_user")
        return result

    @builtins.property
    def user_name(self) -> typing.Optional[builtins.str]:
        result = self._values.get("user_name")
        return result

    def __eq__(self, rhs: typing.Any) -> builtins.bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs: typing.Any) -> builtins.bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return "BatchPoolStartTaskUserIdentity(%s)" % ", ".join(
            k + "=" + repr(v) for k, v in self._values.items()
        )


@jsii.data_type(
    jsii_type="@cdktf/provider-azurerm.BatchPoolStartTaskUserIdentityAutoUser",
    jsii_struct_bases=[],
    name_mapping={"elevation_level": "elevationLevel", "scope": "scope"},
)
class BatchPoolStartTaskUserIdentityAutoUser:
    def __init__(
        self,
        *,
        elevation_level: typing.Optional[builtins.str] = None,
        scope: typing.Optional[builtins.str] = None,
    ) -> None:
        """
        :param elevation_level: 
        :param scope: 
        """
        self._values: typing.Dict[str, typing.Any] = {}
        if elevation_level is not None:
            self._values["elevation_level"] = elevation_level
        if scope is not None:
            self._values["scope"] = scope

    @builtins.property
    def elevation_level(self) -> typing.Optional[builtins.str]:
        result = self._values.get("elevation_level")
        return result

    @builtins.property
    def scope(self) -> typing.Optional[builtins.str]:
        result = self._values.get("scope")
        return result

    def __eq__(self, rhs: typing.Any) -> builtins.bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs: typing.Any) -> builtins.bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return "BatchPoolStartTaskUserIdentityAutoUser(%s)" % ", ".join(
            k + "=" + repr(v) for k, v in self._values.items()
        )


@jsii.data_type(
    jsii_type="@cdktf/provider-azurerm.BatchPoolStorageImageReference",
    jsii_struct_bases=[],
    name_mapping={
        "id": "id",
        "offer": "offer",
        "publisher": "publisher",
        "sku": "sku",
        "version": "version",
    },
)
class BatchPoolStorageImageReference:
    def __init__(
        self,
        *,
        id: typing.Optional[builtins.str] = None,
        offer: typing.Optional[builtins.str] = None,
        publisher: typing.Optional[builtins.str] = None,
        sku: typing.Optional[builtins.str] = None,
        version: typing.Optional[builtins.str] = None,
    ) -> None:
        """
        :param id: 
        :param offer: 
        :param publisher: 
        :param sku: 
        :param version: 
        """
        self._values: typing.Dict[str, typing.Any] = {}
        if id is not None:
            self._values["id"] = id
        if offer is not None:
            self._values["offer"] = offer
        if publisher is not None:
            self._values["publisher"] = publisher
        if sku is not None:
            self._values["sku"] = sku
        if version is not None:
            self._values["version"] = version

    @builtins.property
    def id(self) -> typing.Optional[builtins.str]:
        result = self._values.get("id")
        return result

    @builtins.property
    def offer(self) -> typing.Optional[builtins.str]:
        result = self._values.get("offer")
        return result

    @builtins.property
    def publisher(self) -> typing.Optional[builtins.str]:
        result = self._values.get("publisher")
        return result

    @builtins.property
    def sku(self) -> typing.Optional[builtins.str]:
        result = self._values.get("sku")
        return result

    @builtins.property
    def version(self) -> typing.Optional[builtins.str]:
        result = self._values.get("version")
        return result

    def __eq__(self, rhs: typing.Any) -> builtins.bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs: typing.Any) -> builtins.bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return "BatchPoolStorageImageReference(%s)" % ", ".join(
            k + "=" + repr(v) for k, v in self._values.items()
        )


@jsii.data_type(
    jsii_type="@cdktf/provider-azurerm.BatchPoolTimeouts",
    jsii_struct_bases=[],
    name_mapping={
        "create": "create",
        "delete": "delete",
        "read": "read",
        "update": "update",
    },
)
class BatchPoolTimeouts:
    def __init__(
        self,
        *,
        create: typing.Optional[builtins.str] = None,
        delete: typing.Optional[builtins.str] = None,
        read: typing.Optional[builtins.str] = None,
        update: typing.Optional[builtins.str] = None,
    ) -> None:
        """
        :param create: 
        :param delete: 
        :param read: 
        :param update: 
        """
        self._values: typing.Dict[str, typing.Any] = {}
        if create is not None:
            self._values["create"] = create
        if delete is not None:
            self._values["delete"] = delete
        if read is not None:
            self._values["read"] = read
        if update is not None:
            self._values["update"] = update

    @builtins.property
    def create(self) -> typing.Optional[builtins.str]:
        result = self._values.get("create")
        return result

    @builtins.property
    def delete(self) -> typing.Optional[builtins.str]:
        result = self._values.get("delete")
        return result

    @builtins.property
    def read(self) -> typing.Optional[builtins.str]:
        result = self._values.get("read")
        return result

    @builtins.property
    def update(self) -> typing.Optional[builtins.str]:
        result = self._values.get("update")
        return result

    def __eq__(self, rhs: typing.Any) -> builtins.bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs: typing.Any) -> builtins.bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return "BatchPoolTimeouts(%s)" % ", ".join(
            k + "=" + repr(v) for k, v in self._values.items()
        )


class BotChannelEmail(
    cdktf.TerraformResource,
    metaclass=jsii.JSIIMeta,
    jsii_type="@cdktf/provider-azurerm.BotChannelEmail",
):
    def __init__(
        self,
        scope: constructs.Construct,
        id: builtins.str,
        *,
        bot_name: builtins.str,
        email_address: builtins.str,
        email_password: builtins.str,
        location: builtins.str,
        resource_group_name: builtins.str,
        timeouts: typing.Optional["BotChannelEmailTimeouts"] = None,
        count: typing.Optional[jsii.Number] = None,
        depends_on: typing.Optional[typing.List[cdktf.TerraformResource]] = None,
        lifecycle: typing.Optional[cdktf.TerraformResourceLifecycle] = None,
        provider: typing.Optional[cdktf.TerraformProvider] = None,
    ) -> None:
        """
        :param scope: -
        :param id: -
        :param bot_name: 
        :param email_address: 
        :param email_password: 
        :param location: 
        :param resource_group_name: 
        :param timeouts: timeouts block.
        :param count: 
        :param depends_on: 
        :param lifecycle: 
        :param provider: 
        """
        config = BotChannelEmailConfig(
            bot_name=bot_name,
            email_address=email_address,
            email_password=email_password,
            location=location,
            resource_group_name=resource_group_name,
            timeouts=timeouts,
            count=count,
            depends_on=depends_on,
            lifecycle=lifecycle,
            provider=provider,
        )

        jsii.create(BotChannelEmail, self, [scope, id, config])

    @jsii.member(jsii_name="synthesizeAttributes")
    def _synthesize_attributes(self) -> typing.Mapping[builtins.str, typing.Any]:
        return jsii.invoke(self, "synthesizeAttributes", [])

    @builtins.property # type: ignore
    @jsii.member(jsii_name="botName")
    def bot_name(self) -> builtins.str:
        return jsii.get(self, "botName")

    @bot_name.setter # type: ignore
    def bot_name(self, value: builtins.str) -> None:
        jsii.set(self, "botName", value)

    @builtins.property # type: ignore
    @jsii.member(jsii_name="emailAddress")
    def email_address(self) -> builtins.str:
        return jsii.get(self, "emailAddress")

    @email_address.setter # type: ignore
    def email_address(self, value: builtins.str) -> None:
        jsii.set(self, "emailAddress", value)

    @builtins.property # type: ignore
    @jsii.member(jsii_name="emailPassword")
    def email_password(self) -> builtins.str:
        return jsii.get(self, "emailPassword")

    @email_password.setter # type: ignore
    def email_password(self, value: builtins.str) -> None:
        jsii.set(self, "emailPassword", value)

    @builtins.property # type: ignore
    @jsii.member(jsii_name="location")
    def location(self) -> builtins.str:
        return jsii.get(self, "location")

    @location.setter # type: ignore
    def location(self, value: builtins.str) -> None:
        jsii.set(self, "location", value)

    @builtins.property # type: ignore
    @jsii.member(jsii_name="resourceGroupName")
    def resource_group_name(self) -> builtins.str:
        return jsii.get(self, "resourceGroupName")

    @resource_group_name.setter # type: ignore
    def resource_group_name(self, value: builtins.str) -> None:
        jsii.set(self, "resourceGroupName", value)

    @builtins.property # type: ignore
    @jsii.member(jsii_name="id")
    def id(self) -> typing.Optional[builtins.str]:
        return jsii.get(self, "id")

    @id.setter # type: ignore
    def id(self, value: typing.Optional[builtins.str]) -> None:
        jsii.set(self, "id", value)

    @builtins.property # type: ignore
    @jsii.member(jsii_name="timeouts")
    def timeouts(self) -> typing.Optional["BotChannelEmailTimeouts"]:
        return jsii.get(self, "timeouts")

    @timeouts.setter # type: ignore
    def timeouts(self, value: typing.Optional["BotChannelEmailTimeouts"]) -> None:
        jsii.set(self, "timeouts", value)


@jsii.data_type(
    jsii_type="@cdktf/provider-azurerm.BotChannelEmailConfig",
    jsii_struct_bases=[cdktf.TerraformMetaArguments],
    name_mapping={
        "count": "count",
        "depends_on": "dependsOn",
        "lifecycle": "lifecycle",
        "provider": "provider",
        "bot_name": "botName",
        "email_address": "emailAddress",
        "email_password": "emailPassword",
        "location": "location",
        "resource_group_name": "resourceGroupName",
        "timeouts": "timeouts",
    },
)
class BotChannelEmailConfig(cdktf.TerraformMetaArguments):
    def __init__(
        self,
        *,
        count: typing.Optional[jsii.Number] = None,
        depends_on: typing.Optional[typing.List[cdktf.TerraformResource]] = None,
        lifecycle: typing.Optional[cdktf.TerraformResourceLifecycle] = None,
        provider: typing.Optional[cdktf.TerraformProvider] = None,
        bot_name: builtins.str,
        email_address: builtins.str,
        email_password: builtins.str,
        location: builtins.str,
        resource_group_name: builtins.str,
        timeouts: typing.Optional["BotChannelEmailTimeouts"] = None,
    ) -> None:
        """
        :param count: 
        :param depends_on: 
        :param lifecycle: 
        :param provider: 
        :param bot_name: 
        :param email_address: 
        :param email_password: 
        :param location: 
        :param resource_group_name: 
        :param timeouts: timeouts block.
        """
        if isinstance(lifecycle, dict):
            lifecycle = cdktf.TerraformResourceLifecycle(**lifecycle)
        if isinstance(timeouts, dict):
            timeouts = BotChannelEmailTimeouts(**timeouts)
        self._values: typing.Dict[str, typing.Any] = {
            "bot_name": bot_name,
            "email_address": email_address,
            "email_password": email_password,
            "location": location,
            "resource_group_name": resource_group_name,
        }
        if count is not None:
            self._values["count"] = count
        if depends_on is not None:
            self._values["depends_on"] = depends_on
        if lifecycle is not None:
            self._values["lifecycle"] = lifecycle
        if provider is not None:
            self._values["provider"] = provider
        if timeouts is not None:
            self._values["timeouts"] = timeouts

    @builtins.property
    def count(self) -> typing.Optional[jsii.Number]:
        """
        :stability: experimental
        """
        result = self._values.get("count")
        return result

    @builtins.property
    def depends_on(self) -> typing.Optional[typing.List[cdktf.TerraformResource]]:
        """
        :stability: experimental
        """
        result = self._values.get("depends_on")
        return result

    @builtins.property
    def lifecycle(self) -> typing.Optional[cdktf.TerraformResourceLifecycle]:
        """
        :stability: experimental
        """
        result = self._values.get("lifecycle")
        return result

    @builtins.property
    def provider(self) -> typing.Optional[cdktf.TerraformProvider]:
        """
        :stability: experimental
        """
        result = self._values.get("provider")
        return result

    @builtins.property
    def bot_name(self) -> builtins.str:
        result = self._values.get("bot_name")
        assert result is not None, "Required property 'bot_name' is missing"
        return result

    @builtins.property
    def email_address(self) -> builtins.str:
        result = self._values.get("email_address")
        assert result is not None, "Required property 'email_address' is missing"
        return result

    @builtins.property
    def email_password(self) -> builtins.str:
        result = self._values.get("email_password")
        assert result is not None, "Required property 'email_password' is missing"
        return result

    @builtins.property
    def location(self) -> builtins.str:
        result = self._values.get("location")
        assert result is not None, "Required property 'location' is missing"
        return result

    @builtins.property
    def resource_group_name(self) -> builtins.str:
        result = self._values.get("resource_group_name")
        assert result is not None, "Required property 'resource_group_name' is missing"
        return result

    @builtins.property
    def timeouts(self) -> typing.Optional["BotChannelEmailTimeouts"]:
        """timeouts block."""
        result = self._values.get("timeouts")
        return result

    def __eq__(self, rhs: typing.Any) -> builtins.bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs: typing.Any) -> builtins.bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return "BotChannelEmailConfig(%s)" % ", ".join(
            k + "=" + repr(v) for k, v in self._values.items()
        )


@jsii.data_type(
    jsii_type="@cdktf/provider-azurerm.BotChannelEmailTimeouts",
    jsii_struct_bases=[],
    name_mapping={
        "create": "create",
        "delete": "delete",
        "read": "read",
        "update": "update",
    },
)
class BotChannelEmailTimeouts:
    def __init__(
        self,
        *,
        create: typing.Optional[builtins.str] = None,
        delete: typing.Optional[builtins.str] = None,
        read: typing.Optional[builtins.str] = None,
        update: typing.Optional[builtins.str] = None,
    ) -> None:
        """
        :param create: 
        :param delete: 
        :param read: 
        :param update: 
        """
        self._values: typing.Dict[str, typing.Any] = {}
        if create is not None:
            self._values["create"] = create
        if delete is not None:
            self._values["delete"] = delete
        if read is not None:
            self._values["read"] = read
        if update is not None:
            self._values["update"] = update

    @builtins.property
    def create(self) -> typing.Optional[builtins.str]:
        result = self._values.get("create")
        return result

    @builtins.property
    def delete(self) -> typing.Optional[builtins.str]:
        result = self._values.get("delete")
        return result

    @builtins.property
    def read(self) -> typing.Optional[builtins.str]:
        result = self._values.get("read")
        return result

    @builtins.property
    def update(self) -> typing.Optional[builtins.str]:
        result = self._values.get("update")
        return result

    def __eq__(self, rhs: typing.Any) -> builtins.bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs: typing.Any) -> builtins.bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return "BotChannelEmailTimeouts(%s)" % ", ".join(
            k + "=" + repr(v) for k, v in self._values.items()
        )


class BotChannelMsTeams(
    cdktf.TerraformResource,
    metaclass=jsii.JSIIMeta,
    jsii_type="@cdktf/provider-azurerm.BotChannelMsTeams",
):
    def __init__(
        self,
        scope: constructs.Construct,
        id: builtins.str,
        *,
        bot_name: builtins.str,
        location: builtins.str,
        resource_group_name: builtins.str,
        calling_web_hook: typing.Optional[builtins.str] = None,
        enable_calling: typing.Optional[builtins.bool] = None,
        timeouts: typing.Optional["BotChannelMsTeamsTimeouts"] = None,
        count: typing.Optional[jsii.Number] = None,
        depends_on: typing.Optional[typing.List[cdktf.TerraformResource]] = None,
        lifecycle: typing.Optional[cdktf.TerraformResourceLifecycle] = None,
        provider: typing.Optional[cdktf.TerraformProvider] = None,
    ) -> None:
        """
        :param scope: -
        :param id: -
        :param bot_name: 
        :param location: 
        :param resource_group_name: 
        :param calling_web_hook: 
        :param enable_calling: 
        :param timeouts: timeouts block.
        :param count: 
        :param depends_on: 
        :param lifecycle: 
        :param provider: 
        """
        config = BotChannelMsTeamsConfig(
            bot_name=bot_name,
            location=location,
            resource_group_name=resource_group_name,
            calling_web_hook=calling_web_hook,
            enable_calling=enable_calling,
            timeouts=timeouts,
            count=count,
            depends_on=depends_on,
            lifecycle=lifecycle,
            provider=provider,
        )

        jsii.create(BotChannelMsTeams, self, [scope, id, config])

    @jsii.member(jsii_name="synthesizeAttributes")
    def _synthesize_attributes(self) -> typing.Mapping[builtins.str, typing.Any]:
        return jsii.invoke(self, "synthesizeAttributes", [])

    @builtins.property # type: ignore
    @jsii.member(jsii_name="botName")
    def bot_name(self) -> builtins.str:
        return jsii.get(self, "botName")

    @bot_name.setter # type: ignore
    def bot_name(self, value: builtins.str) -> None:
        jsii.set(self, "botName", value)

    @builtins.property # type: ignore
    @jsii.member(jsii_name="location")
    def location(self) -> builtins.str:
        return jsii.get(self, "location")

    @location.setter # type: ignore
    def location(self, value: builtins.str) -> None:
        jsii.set(self, "location", value)

    @builtins.property # type: ignore
    @jsii.member(jsii_name="resourceGroupName")
    def resource_group_name(self) -> builtins.str:
        return jsii.get(self, "resourceGroupName")

    @resource_group_name.setter # type: ignore
    def resource_group_name(self, value: builtins.str) -> None:
        jsii.set(self, "resourceGroupName", value)

    @builtins.property # type: ignore
    @jsii.member(jsii_name="callingWebHook")
    def calling_web_hook(self) -> typing.Optional[builtins.str]:
        return jsii.get(self, "callingWebHook")

    @calling_web_hook.setter # type: ignore
    def calling_web_hook(self, value: typing.Optional[builtins.str]) -> None:
        jsii.set(self, "callingWebHook", value)

    @builtins.property # type: ignore
    @jsii.member(jsii_name="enableCalling")
    def enable_calling(self) -> typing.Optional[builtins.bool]:
        return jsii.get(self, "enableCalling")

    @enable_calling.setter # type: ignore
    def enable_calling(self, value: typing.Optional[builtins.bool]) -> None:
        jsii.set(self, "enableCalling", value)

    @builtins.property # type: ignore
    @jsii.member(jsii_name="id")
    def id(self) -> typing.Optional[builtins.str]:
        return jsii.get(self, "id")

    @id.setter # type: ignore
    def id(self, value: typing.Optional[builtins.str]) -> None:
        jsii.set(self, "id", value)

    @builtins.property # type: ignore
    @jsii.member(jsii_name="timeouts")
    def timeouts(self) -> typing.Optional["BotChannelMsTeamsTimeouts"]:
        return jsii.get(self, "timeouts")

    @timeouts.setter # type: ignore
    def timeouts(self, value: typing.Optional["BotChannelMsTeamsTimeouts"]) -> None:
        jsii.set(self, "timeouts", value)


@jsii.data_type(
    jsii_type="@cdktf/provider-azurerm.BotChannelMsTeamsConfig",
    jsii_struct_bases=[cdktf.TerraformMetaArguments],
    name_mapping={
        "count": "count",
        "depends_on": "dependsOn",
        "lifecycle": "lifecycle",
        "provider": "provider",
        "bot_name": "botName",
        "location": "location",
        "resource_group_name": "resourceGroupName",
        "calling_web_hook": "callingWebHook",
        "enable_calling": "enableCalling",
        "timeouts": "timeouts",
    },
)
class BotChannelMsTeamsConfig(cdktf.TerraformMetaArguments):
    def __init__(
        self,
        *,
        count: typing.Optional[jsii.Number] = None,
        depends_on: typing.Optional[typing.List[cdktf.TerraformResource]] = None,
        lifecycle: typing.Optional[cdktf.TerraformResourceLifecycle] = None,
        provider: typing.Optional[cdktf.TerraformProvider] = None,
        bot_name: builtins.str,
        location: builtins.str,
        resource_group_name: builtins.str,
        calling_web_hook: typing.Optional[builtins.str] = None,
        enable_calling: typing.Optional[builtins.bool] = None,
        timeouts: typing.Optional["BotChannelMsTeamsTimeouts"] = None,
    ) -> None:
        """
        :param count: 
        :param depends_on: 
        :param lifecycle: 
        :param provider: 
        :param bot_name: 
        :param location: 
        :param resource_group_name: 
        :param calling_web_hook: 
        :param enable_calling: 
        :param timeouts: timeouts block.
        """
        if isinstance(lifecycle, dict):
            lifecycle = cdktf.TerraformResourceLifecycle(**lifecycle)
        if isinstance(timeouts, dict):
            timeouts = BotChannelMsTeamsTimeouts(**timeouts)
        self._values: typing.Dict[str, typing.Any] = {
            "bot_name": bot_name,
            "location": location,
            "resource_group_name": resource_group_name,
        }
        if count is not None:
            self._values["count"] = count
        if depends_on is not None:
            self._values["depends_on"] = depends_on
        if lifecycle is not None:
            self._values["lifecycle"] = lifecycle
        if provider is not None:
            self._values["provider"] = provider
        if calling_web_hook is not None:
            self._values["calling_web_hook"] = calling_web_hook
        if enable_calling is not None:
            self._values["enable_calling"] = enable_calling
        if timeouts is not None:
            self._values["timeouts"] = timeouts

    @builtins.property
    def count(self) -> typing.Optional[jsii.Number]:
        """
        :stability: experimental
        """
        result = self._values.get("count")
        return result

    @builtins.property
    def depends_on(self) -> typing.Optional[typing.List[cdktf.TerraformResource]]:
        """
        :stability: experimental
        """
        result = self._values.get("depends_on")
        return result

    @builtins.property
    def lifecycle(self) -> typing.Optional[cdktf.TerraformResourceLifecycle]:
        """
        :stability: experimental
        """
        result = self._values.get("lifecycle")
        return result

    @builtins.property
    def provider(self) -> typing.Optional[cdktf.TerraformProvider]:
        """
        :stability: experimental
        """
        result = self._values.get("provider")
        return result

    @builtins.property
    def bot_name(self) -> builtins.str:
        result = self._values.get("bot_name")
        assert result is not None, "Required property 'bot_name' is missing"
        return result

    @builtins.property
    def location(self) -> builtins.str:
        result = self._values.get("location")
        assert result is not None, "Required property 'location' is missing"
        return result

    @builtins.property
    def resource_group_name(self) -> builtins.str:
        result = self._values.get("resource_group_name")
        assert result is not None, "Required property 'resource_group_name' is missing"
        return result

    @builtins.property
    def calling_web_hook(self) -> typing.Optional[builtins.str]:
        result = self._values.get("calling_web_hook")
        return result

    @builtins.property
    def enable_calling(self) -> typing.Optional[builtins.bool]:
        result = self._values.get("enable_calling")
        return result

    @builtins.property
    def timeouts(self) -> typing.Optional["BotChannelMsTeamsTimeouts"]:
        """timeouts block."""
        result = self._values.get("timeouts")
        return result

    def __eq__(self, rhs: typing.Any) -> builtins.bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs: typing.Any) -> builtins.bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return "BotChannelMsTeamsConfig(%s)" % ", ".join(
            k + "=" + repr(v) for k, v in self._values.items()
        )


@jsii.data_type(
    jsii_type="@cdktf/provider-azurerm.BotChannelMsTeamsTimeouts",
    jsii_struct_bases=[],
    name_mapping={
        "create": "create",
        "delete": "delete",
        "read": "read",
        "update": "update",
    },
)
class BotChannelMsTeamsTimeouts:
    def __init__(
        self,
        *,
        create: typing.Optional[builtins.str] = None,
        delete: typing.Optional[builtins.str] = None,
        read: typing.Optional[builtins.str] = None,
        update: typing.Optional[builtins.str] = None,
    ) -> None:
        """
        :param create: 
        :param delete: 
        :param read: 
        :param update: 
        """
        self._values: typing.Dict[str, typing.Any] = {}
        if create is not None:
            self._values["create"] = create
        if delete is not None:
            self._values["delete"] = delete
        if read is not None:
            self._values["read"] = read
        if update is not None:
            self._values["update"] = update

    @builtins.property
    def create(self) -> typing.Optional[builtins.str]:
        result = self._values.get("create")
        return result

    @builtins.property
    def delete(self) -> typing.Optional[builtins.str]:
        result = self._values.get("delete")
        return result

    @builtins.property
    def read(self) -> typing.Optional[builtins.str]:
        result = self._values.get("read")
        return result

    @builtins.property
    def update(self) -> typing.Optional[builtins.str]:
        result = self._values.get("update")
        return result

    def __eq__(self, rhs: typing.Any) -> builtins.bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs: typing.Any) -> builtins.bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return "BotChannelMsTeamsTimeouts(%s)" % ", ".join(
            k + "=" + repr(v) for k, v in self._values.items()
        )


class BotChannelSlack(
    cdktf.TerraformResource,
    metaclass=jsii.JSIIMeta,
    jsii_type="@cdktf/provider-azurerm.BotChannelSlack",
):
    def __init__(
        self,
        scope: constructs.Construct,
        id: builtins.str,
        *,
        bot_name: builtins.str,
        client_id: builtins.str,
        client_secret: builtins.str,
        location: builtins.str,
        resource_group_name: builtins.str,
        verification_token: builtins.str,
        landing_page_url: typing.Optional[builtins.str] = None,
        timeouts: typing.Optional["BotChannelSlackTimeouts"] = None,
        count: typing.Optional[jsii.Number] = None,
        depends_on: typing.Optional[typing.List[cdktf.TerraformResource]] = None,
        lifecycle: typing.Optional[cdktf.TerraformResourceLifecycle] = None,
        provider: typing.Optional[cdktf.TerraformProvider] = None,
    ) -> None:
        """
        :param scope: -
        :param id: -
        :param bot_name: 
        :param client_id: 
        :param client_secret: 
        :param location: 
        :param resource_group_name: 
        :param verification_token: 
        :param landing_page_url: 
        :param timeouts: timeouts block.
        :param count: 
        :param depends_on: 
        :param lifecycle: 
        :param provider: 
        """
        config = BotChannelSlackConfig(
            bot_name=bot_name,
            client_id=client_id,
            client_secret=client_secret,
            location=location,
            resource_group_name=resource_group_name,
            verification_token=verification_token,
            landing_page_url=landing_page_url,
            timeouts=timeouts,
            count=count,
            depends_on=depends_on,
            lifecycle=lifecycle,
            provider=provider,
        )

        jsii.create(BotChannelSlack, self, [scope, id, config])

    @jsii.member(jsii_name="synthesizeAttributes")
    def _synthesize_attributes(self) -> typing.Mapping[builtins.str, typing.Any]:
        return jsii.invoke(self, "synthesizeAttributes", [])

    @builtins.property # type: ignore
    @jsii.member(jsii_name="botName")
    def bot_name(self) -> builtins.str:
        return jsii.get(self, "botName")

    @bot_name.setter # type: ignore
    def bot_name(self, value: builtins.str) -> None:
        jsii.set(self, "botName", value)

    @builtins.property # type: ignore
    @jsii.member(jsii_name="clientId")
    def client_id(self) -> builtins.str:
        return jsii.get(self, "clientId")

    @client_id.setter # type: ignore
    def client_id(self, value: builtins.str) -> None:
        jsii.set(self, "clientId", value)

    @builtins.property # type: ignore
    @jsii.member(jsii_name="clientSecret")
    def client_secret(self) -> builtins.str:
        return jsii.get(self, "clientSecret")

    @client_secret.setter # type: ignore
    def client_secret(self, value: builtins.str) -> None:
        jsii.set(self, "clientSecret", value)

    @builtins.property # type: ignore
    @jsii.member(jsii_name="location")
    def location(self) -> builtins.str:
        return jsii.get(self, "location")

    @location.setter # type: ignore
    def location(self, value: builtins.str) -> None:
        jsii.set(self, "location", value)

    @builtins.property # type: ignore
    @jsii.member(jsii_name="resourceGroupName")
    def resource_group_name(self) -> builtins.str:
        return jsii.get(self, "resourceGroupName")

    @resource_group_name.setter # type: ignore
    def resource_group_name(self, value: builtins.str) -> None:
        jsii.set(self, "resourceGroupName", value)

    @builtins.property # type: ignore
    @jsii.member(jsii_name="verificationToken")
    def verification_token(self) -> builtins.str:
        return jsii.get(self, "verificationToken")

    @verification_token.setter # type: ignore
    def verification_token(self, value: builtins.str) -> None:
        jsii.set(self, "verificationToken", value)

    @builtins.property # type: ignore
    @jsii.member(jsii_name="id")
    def id(self) -> typing.Optional[builtins.str]:
        return jsii.get(self, "id")

    @id.setter # type: ignore
    def id(self, value: typing.Optional[builtins.str]) -> None:
        jsii.set(self, "id", value)

    @builtins.property # type: ignore
    @jsii.member(jsii_name="landingPageUrl")
    def landing_page_url(self) -> typing.Optional[builtins.str]:
        return jsii.get(self, "landingPageUrl")

    @landing_page_url.setter # type: ignore
    def landing_page_url(self, value: typing.Optional[builtins.str]) -> None:
        jsii.set(self, "landingPageUrl", value)

    @builtins.property # type: ignore
    @jsii.member(jsii_name="timeouts")
    def timeouts(self) -> typing.Optional["BotChannelSlackTimeouts"]:
        return jsii.get(self, "timeouts")

    @timeouts.setter # type: ignore
    def timeouts(self, value: typing.Optional["BotChannelSlackTimeouts"]) -> None:
        jsii.set(self, "timeouts", value)


@jsii.data_type(
    jsii_type="@cdktf/provider-azurerm.BotChannelSlackConfig",
    jsii_struct_bases=[cdktf.TerraformMetaArguments],
    name_mapping={
        "count": "count",
        "depends_on": "dependsOn",
        "lifecycle": "lifecycle",
        "provider": "provider",
        "bot_name": "botName",
        "client_id": "clientId",
        "client_secret": "clientSecret",
        "location": "location",
        "resource_group_name": "resourceGroupName",
        "verification_token": "verificationToken",
        "landing_page_url": "landingPageUrl",
        "timeouts": "timeouts",
    },
)
class BotChannelSlackConfig(cdktf.TerraformMetaArguments):
    def __init__(
        self,
        *,
        count: typing.Optional[jsii.Number] = None,
        depends_on: typing.Optional[typing.List[cdktf.TerraformResource]] = None,
        lifecycle: typing.Optional[cdktf.TerraformResourceLifecycle] = None,
        provider: typing.Optional[cdktf.TerraformProvider] = None,
        bot_name: builtins.str,
        client_id: builtins.str,
        client_secret: builtins.str,
        location: builtins.str,
        resource_group_name: builtins.str,
        verification_token: builtins.str,
        landing_page_url: typing.Optional[builtins.str] = None,
        timeouts: typing.Optional["BotChannelSlackTimeouts"] = None,
    ) -> None:
        """
        :param count: 
        :param depends_on: 
        :param lifecycle: 
        :param provider: 
        :param bot_name: 
        :param client_id: 
        :param client_secret: 
        :param location: 
        :param resource_group_name: 
        :param verification_token: 
        :param landing_page_url: 
        :param timeouts: timeouts block.
        """
        if isinstance(lifecycle, dict):
            lifecycle = cdktf.TerraformResourceLifecycle(**lifecycle)
        if isinstance(timeouts, dict):
            timeouts = BotChannelSlackTimeouts(**timeouts)
        self._values: typing.Dict[str, typing.Any] = {
            "bot_name": bot_name,
            "client_id": client_id,
            "client_secret": client_secret,
            "location": location,
            "resource_group_name": resource_group_name,
            "verification_token": verification_token,
        }
        if count is not None:
            self._values["count"] = count
        if depends_on is not None:
            self._values["depends_on"] = depends_on
        if lifecycle is not None:
            self._values["lifecycle"] = lifecycle
        if provider is not None:
            self._values["provider"] = provider
        if landing_page_url is not None:
            self._values["landing_page_url"] = landing_page_url
        if timeouts is not None:
            self._values["timeouts"] = timeouts

    @builtins.property
    def count(self) -> typing.Optional[jsii.Number]:
        """
        :stability: experimental
        """
        result = self._values.get("count")
        return result

    @builtins.property
    def depends_on(self) -> typing.Optional[typing.List[cdktf.TerraformResource]]:
        """
        :stability: experimental
        """
        result = self._values.get("depends_on")
        return result

    @builtins.property
    def lifecycle(self) -> typing.Optional[cdktf.TerraformResourceLifecycle]:
        """
        :stability: experimental
        """
        result = self._values.get("lifecycle")
        return result

    @builtins.property
    def provider(self) -> typing.Optional[cdktf.TerraformProvider]:
        """
        :stability: experimental
        """
        result = self._values.get("provider")
        return result

    @builtins.property
    def bot_name(self) -> builtins.str:
        result = self._values.get("bot_name")
        assert result is not None, "Required property 'bot_name' is missing"
        return result

    @builtins.property
    def client_id(self) -> builtins.str:
        result = self._values.get("client_id")
        assert result is not None, "Required property 'client_id' is missing"
        return result

    @builtins.property
    def client_secret(self) -> builtins.str:
        result = self._values.get("client_secret")
        assert result is not None, "Required property 'client_secret' is missing"
        return result

    @builtins.property
    def location(self) -> builtins.str:
        result = self._values.get("location")
        assert result is not None, "Required property 'location' is missing"
        return result

    @builtins.property
    def resource_group_name(self) -> builtins.str:
        result = self._values.get("resource_group_name")
        assert result is not None, "Required property 'resource_group_name' is missing"
        return result

    @builtins.property
    def verification_token(self) -> builtins.str:
        result = self._values.get("verification_token")
        assert result is not None, "Required property 'verification_token' is missing"
        return result

    @builtins.property
    def landing_page_url(self) -> typing.Optional[builtins.str]:
        result = self._values.get("landing_page_url")
        return result

    @builtins.property
    def timeouts(self) -> typing.Optional["BotChannelSlackTimeouts"]:
        """timeouts block."""
        result = self._values.get("timeouts")
        return result

    def __eq__(self, rhs: typing.Any) -> builtins.bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs: typing.Any) -> builtins.bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return "BotChannelSlackConfig(%s)" % ", ".join(
            k + "=" + repr(v) for k, v in self._values.items()
        )


@jsii.data_type(
    jsii_type="@cdktf/provider-azurerm.BotChannelSlackTimeouts",
    jsii_struct_bases=[],
    name_mapping={
        "create": "create",
        "delete": "delete",
        "read": "read",
        "update": "update",
    },
)
class BotChannelSlackTimeouts:
    def __init__(
        self,
        *,
        create: typing.Optional[builtins.str] = None,
        delete: typing.Optional[builtins.str] = None,
        read: typing.Optional[builtins.str] = None,
        update: typing.Optional[builtins.str] = None,
    ) -> None:
        """
        :param create: 
        :param delete: 
        :param read: 
        :param update: 
        """
        self._values: typing.Dict[str, typing.Any] = {}
        if create is not None:
            self._values["create"] = create
        if delete is not None:
            self._values["delete"] = delete
        if read is not None:
            self._values["read"] = read
        if update is not None:
            self._values["update"] = update

    @builtins.property
    def create(self) -> typing.Optional[builtins.str]:
        result = self._values.get("create")
        return result

    @builtins.property
    def delete(self) -> typing.Optional[builtins.str]:
        result = self._values.get("delete")
        return result

    @builtins.property
    def read(self) -> typing.Optional[builtins.str]:
        result = self._values.get("read")
        return result

    @builtins.property
    def update(self) -> typing.Optional[builtins.str]:
        result = self._values.get("update")
        return result

    def __eq__(self, rhs: typing.Any) -> builtins.bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs: typing.Any) -> builtins.bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return "BotChannelSlackTimeouts(%s)" % ", ".join(
            k + "=" + repr(v) for k, v in self._values.items()
        )


class BotChannelsRegistration(
    cdktf.TerraformResource,
    metaclass=jsii.JSIIMeta,
    jsii_type="@cdktf/provider-azurerm.BotChannelsRegistration",
):
    def __init__(
        self,
        scope: constructs.Construct,
        id: builtins.str,
        *,
        location: builtins.str,
        microsoft_app_id: builtins.str,
        name: builtins.str,
        resource_group_name: builtins.str,
        sku: builtins.str,
        developer_app_insights_api_key: typing.Optional[builtins.str] = None,
        developer_app_insights_application_id: typing.Optional[builtins.str] = None,
        developer_app_insights_key: typing.Optional[builtins.str] = None,
        display_name: typing.Optional[builtins.str] = None,
        endpoint: typing.Optional[builtins.str] = None,
        tags: typing.Optional[typing.Mapping[builtins.str, builtins.str]] = None,
        timeouts: typing.Optional["BotChannelsRegistrationTimeouts"] = None,
        count: typing.Optional[jsii.Number] = None,
        depends_on: typing.Optional[typing.List[cdktf.TerraformResource]] = None,
        lifecycle: typing.Optional[cdktf.TerraformResourceLifecycle] = None,
        provider: typing.Optional[cdktf.TerraformProvider] = None,
    ) -> None:
        """
        :param scope: -
        :param id: -
        :param location: 
        :param microsoft_app_id: 
        :param name: 
        :param resource_group_name: 
        :param sku: 
        :param developer_app_insights_api_key: 
        :param developer_app_insights_application_id: 
        :param developer_app_insights_key: 
        :param display_name: 
        :param endpoint: 
        :param tags: 
        :param timeouts: timeouts block.
        :param count: 
        :param depends_on: 
        :param lifecycle: 
        :param provider: 
        """
        config = BotChannelsRegistrationConfig(
            location=location,
            microsoft_app_id=microsoft_app_id,
            name=name,
            resource_group_name=resource_group_name,
            sku=sku,
            developer_app_insights_api_key=developer_app_insights_api_key,
            developer_app_insights_application_id=developer_app_insights_application_id,
            developer_app_insights_key=developer_app_insights_key,
            display_name=display_name,
            endpoint=endpoint,
            tags=tags,
            timeouts=timeouts,
            count=count,
            depends_on=depends_on,
            lifecycle=lifecycle,
            provider=provider,
        )

        jsii.create(BotChannelsRegistration, self, [scope, id, config])

    @jsii.member(jsii_name="synthesizeAttributes")
    def _synthesize_attributes(self) -> typing.Mapping[builtins.str, typing.Any]:
        return jsii.invoke(self, "synthesizeAttributes", [])

    @builtins.property # type: ignore
    @jsii.member(jsii_name="location")
    def location(self) -> builtins.str:
        return jsii.get(self, "location")

    @location.setter # type: ignore
    def location(self, value: builtins.str) -> None:
        jsii.set(self, "location", value)

    @builtins.property # type: ignore
    @jsii.member(jsii_name="microsoftAppId")
    def microsoft_app_id(self) -> builtins.str:
        return jsii.get(self, "microsoftAppId")

    @microsoft_app_id.setter # type: ignore
    def microsoft_app_id(self, value: builtins.str) -> None:
        jsii.set(self, "microsoftAppId", value)

    @builtins.property # type: ignore
    @jsii.member(jsii_name="name")
    def name(self) -> builtins.str:
        return jsii.get(self, "name")

    @name.setter # type: ignore
    def name(self, value: builtins.str) -> None:
        jsii.set(self, "name", value)

    @builtins.property # type: ignore
    @jsii.member(jsii_name="resourceGroupName")
    def resource_group_name(self) -> builtins.str:
        return jsii.get(self, "resourceGroupName")

    @resource_group_name.setter # type: ignore
    def resource_group_name(self, value: builtins.str) -> None:
        jsii.set(self, "resourceGroupName", value)

    @builtins.property # type: ignore
    @jsii.member(jsii_name="sku")
    def sku(self) -> builtins.str:
        return jsii.get(self, "sku")

    @sku.setter # type: ignore
    def sku(self, value: builtins.str) -> None:
        jsii.set(self, "sku", value)

    @builtins.property # type: ignore
    @jsii.member(jsii_name="developerAppInsightsApiKey")
    def developer_app_insights_api_key(self) -> typing.Optional[builtins.str]:
        return jsii.get(self, "developerAppInsightsApiKey")

    @developer_app_insights_api_key.setter # type: ignore
    def developer_app_insights_api_key(
        self,
        value: typing.Optional[builtins.str],
    ) -> None:
        jsii.set(self, "developerAppInsightsApiKey", value)

    @builtins.property # type: ignore
    @jsii.member(jsii_name="developerAppInsightsApplicationId")
    def developer_app_insights_application_id(self) -> typing.Optional[builtins.str]:
        return jsii.get(self, "developerAppInsightsApplicationId")

    @developer_app_insights_application_id.setter # type: ignore
    def developer_app_insights_application_id(
        self,
        value: typing.Optional[builtins.str],
    ) -> None:
        jsii.set(self, "developerAppInsightsApplicationId", value)

    @builtins.property # type: ignore
    @jsii.member(jsii_name="developerAppInsightsKey")
    def developer_app_insights_key(self) -> typing.Optional[builtins.str]:
        return jsii.get(self, "developerAppInsightsKey")

    @developer_app_insights_key.setter # type: ignore
    def developer_app_insights_key(self, value: typing.Optional[builtins.str]) -> None:
        jsii.set(self, "developerAppInsightsKey", value)

    @builtins.property # type: ignore
    @jsii.member(jsii_name="displayName")
    def display_name(self) -> typing.Optional[builtins.str]:
        return jsii.get(self, "displayName")

    @display_name.setter # type: ignore
    def display_name(self, value: typing.Optional[builtins.str]) -> None:
        jsii.set(self, "displayName", value)

    @builtins.property # type: ignore
    @jsii.member(jsii_name="endpoint")
    def endpoint(self) -> typing.Optional[builtins.str]:
        return jsii.get(self, "endpoint")

    @endpoint.setter # type: ignore
    def endpoint(self, value: typing.Optional[builtins.str]) -> None:
        jsii.set(self, "endpoint", value)

    @builtins.property # type: ignore
    @jsii.member(jsii_name="id")
    def id(self) -> typing.Optional[builtins.str]:
        return jsii.get(self, "id")

    @id.setter # type: ignore
    def id(self, value: typing.Optional[builtins.str]) -> None:
        jsii.set(self, "id", value)

    @builtins.property # type: ignore
    @jsii.member(jsii_name="tags")
    def tags(self) -> typing.Optional[typing.Mapping[builtins.str, builtins.str]]:
        return jsii.get(self, "tags")

    @tags.setter # type: ignore
    def tags(
        self,
        value: typing.Optional[typing.Mapping[builtins.str, builtins.str]],
    ) -> None:
        jsii.set(self, "tags", value)

    @builtins.property # type: ignore
    @jsii.member(jsii_name="timeouts")
    def timeouts(self) -> typing.Optional["BotChannelsRegistrationTimeouts"]:
        return jsii.get(self, "timeouts")

    @timeouts.setter # type: ignore
    def timeouts(
        self,
        value: typing.Optional["BotChannelsRegistrationTimeouts"],
    ) -> None:
        jsii.set(self, "timeouts", value)


@jsii.data_type(
    jsii_type="@cdktf/provider-azurerm.BotChannelsRegistrationConfig",
    jsii_struct_bases=[cdktf.TerraformMetaArguments],
    name_mapping={
        "count": "count",
        "depends_on": "dependsOn",
        "lifecycle": "lifecycle",
        "provider": "provider",
        "location": "location",
        "microsoft_app_id": "microsoftAppId",
        "name": "name",
        "resource_group_name": "resourceGroupName",
        "sku": "sku",
        "developer_app_insights_api_key": "developerAppInsightsApiKey",
        "developer_app_insights_application_id": "developerAppInsightsApplicationId",
        "developer_app_insights_key": "developerAppInsightsKey",
        "display_name": "displayName",
        "endpoint": "endpoint",
        "tags": "tags",
        "timeouts": "timeouts",
    },
)
class BotChannelsRegistrationConfig(cdktf.TerraformMetaArguments):
    def __init__(
        self,
        *,
        count: typing.Optional[jsii.Number] = None,
        depends_on: typing.Optional[typing.List[cdktf.TerraformResource]] = None,
        lifecycle: typing.Optional[cdktf.TerraformResourceLifecycle] = None,
        provider: typing.Optional[cdktf.TerraformProvider] = None,
        location: builtins.str,
        microsoft_app_id: builtins.str,
        name: builtins.str,
        resource_group_name: builtins.str,
        sku: builtins.str,
        developer_app_insights_api_key: typing.Optional[builtins.str] = None,
        developer_app_insights_application_id: typing.Optional[builtins.str] = None,
        developer_app_insights_key: typing.Optional[builtins.str] = None,
        display_name: typing.Optional[builtins.str] = None,
        endpoint: typing.Optional[builtins.str] = None,
        tags: typing.Optional[typing.Mapping[builtins.str, builtins.str]] = None,
        timeouts: typing.Optional["BotChannelsRegistrationTimeouts"] = None,
    ) -> None:
        """
        :param count: 
        :param depends_on: 
        :param lifecycle: 
        :param provider: 
        :param location: 
        :param microsoft_app_id: 
        :param name: 
        :param resource_group_name: 
        :param sku: 
        :param developer_app_insights_api_key: 
        :param developer_app_insights_application_id: 
        :param developer_app_insights_key: 
        :param display_name: 
        :param endpoint: 
        :param tags: 
        :param timeouts: timeouts block.
        """
        if isinstance(lifecycle, dict):
            lifecycle = cdktf.TerraformResourceLifecycle(**lifecycle)
        if isinstance(timeouts, dict):
            timeouts = BotChannelsRegistrationTimeouts(**timeouts)
        self._values: typing.Dict[str, typing.Any] = {
            "location": location,
            "microsoft_app_id": microsoft_app_id,
            "name": name,
            "resource_group_name": resource_group_name,
            "sku": sku,
        }
        if count is not None:
            self._values["count"] = count
        if depends_on is not None:
            self._values["depends_on"] = depends_on
        if lifecycle is not None:
            self._values["lifecycle"] = lifecycle
        if provider is not None:
            self._values["provider"] = provider
        if developer_app_insights_api_key is not None:
            self._values["developer_app_insights_api_key"] = developer_app_insights_api_key
        if developer_app_insights_application_id is not None:
            self._values["developer_app_insights_application_id"] = developer_app_insights_application_id
        if developer_app_insights_key is not None:
            self._values["developer_app_insights_key"] = developer_app_insights_key
        if display_name is not None:
            self._values["display_name"] = display_name
        if endpoint is not None:
            self._values["endpoint"] = endpoint
        if tags is not None:
            self._values["tags"] = tags
        if timeouts is not None:
            self._values["timeouts"] = timeouts

    @builtins.property
    def count(self) -> typing.Optional[jsii.Number]:
        """
        :stability: experimental
        """
        result = self._values.get("count")
        return result

    @builtins.property
    def depends_on(self) -> typing.Optional[typing.List[cdktf.TerraformResource]]:
        """
        :stability: experimental
        """
        result = self._values.get("depends_on")
        return result

    @builtins.property
    def lifecycle(self) -> typing.Optional[cdktf.TerraformResourceLifecycle]:
        """
        :stability: experimental
        """
        result = self._values.get("lifecycle")
        return result

    @builtins.property
    def provider(self) -> typing.Optional[cdktf.TerraformProvider]:
        """
        :stability: experimental
        """
        result = self._values.get("provider")
        return result

    @builtins.property
    def location(self) -> builtins.str:
        result = self._values.get("location")
        assert result is not None, "Required property 'location' is missing"
        return result

    @builtins.property
    def microsoft_app_id(self) -> builtins.str:
        result = self._values.get("microsoft_app_id")
        assert result is not None, "Required property 'microsoft_app_id' is missing"
        return result

    @builtins.property
    def name(self) -> builtins.str:
        result = self._values.get("name")
        assert result is not None, "Required property 'name' is missing"
        return result

    @builtins.property
    def resource_group_name(self) -> builtins.str:
        result = self._values.get("resource_group_name")
        assert result is not None, "Required property 'resource_group_name' is missing"
        return result

    @builtins.property
    def sku(self) -> builtins.str:
        result = self._values.get("sku")
        assert result is not None, "Required property 'sku' is missing"
        return result

    @builtins.property
    def developer_app_insights_api_key(self) -> typing.Optional[builtins.str]:
        result = self._values.get("developer_app_insights_api_key")
        return result

    @builtins.property
    def developer_app_insights_application_id(self) -> typing.Optional[builtins.str]:
        result = self._values.get("developer_app_insights_application_id")
        return result

    @builtins.property
    def developer_app_insights_key(self) -> typing.Optional[builtins.str]:
        result = self._values.get("developer_app_insights_key")
        return result

    @builtins.property
    def display_name(self) -> typing.Optional[builtins.str]:
        result = self._values.get("display_name")
        return result

    @builtins.property
    def endpoint(self) -> typing.Optional[builtins.str]:
        result = self._values.get("endpoint")
        return result

    @builtins.property
    def tags(self) -> typing.Optional[typing.Mapping[builtins.str, builtins.str]]:
        result = self._values.get("tags")
        return result

    @builtins.property
    def timeouts(self) -> typing.Optional["BotChannelsRegistrationTimeouts"]:
        """timeouts block."""
        result = self._values.get("timeouts")
        return result

    def __eq__(self, rhs: typing.Any) -> builtins.bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs: typing.Any) -> builtins.bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return "BotChannelsRegistrationConfig(%s)" % ", ".join(
            k + "=" + repr(v) for k, v in self._values.items()
        )


@jsii.data_type(
    jsii_type="@cdktf/provider-azurerm.BotChannelsRegistrationTimeouts",
    jsii_struct_bases=[],
    name_mapping={
        "create": "create",
        "delete": "delete",
        "read": "read",
        "update": "update",
    },
)
class BotChannelsRegistrationTimeouts:
    def __init__(
        self,
        *,
        create: typing.Optional[builtins.str] = None,
        delete: typing.Optional[builtins.str] = None,
        read: typing.Optional[builtins.str] = None,
        update: typing.Optional[builtins.str] = None,
    ) -> None:
        """
        :param create: 
        :param delete: 
        :param read: 
        :param update: 
        """
        self._values: typing.Dict[str, typing.Any] = {}
        if create is not None:
            self._values["create"] = create
        if delete is not None:
            self._values["delete"] = delete
        if read is not None:
            self._values["read"] = read
        if update is not None:
            self._values["update"] = update

    @builtins.property
    def create(self) -> typing.Optional[builtins.str]:
        result = self._values.get("create")
        return result

    @builtins.property
    def delete(self) -> typing.Optional[builtins.str]:
        result = self._values.get("delete")
        return result

    @builtins.property
    def read(self) -> typing.Optional[builtins.str]:
        result = self._values.get("read")
        return result

    @builtins.property
    def update(self) -> typing.Optional[builtins.str]:
        result = self._values.get("update")
        return result

    def __eq__(self, rhs: typing.Any) -> builtins.bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs: typing.Any) -> builtins.bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return "BotChannelsRegistrationTimeouts(%s)" % ", ".join(
            k + "=" + repr(v) for k, v in self._values.items()
        )


class BotConnection(
    cdktf.TerraformResource,
    metaclass=jsii.JSIIMeta,
    jsii_type="@cdktf/provider-azurerm.BotConnection",
):
    def __init__(
        self,
        scope: constructs.Construct,
        id: builtins.str,
        *,
        bot_name: builtins.str,
        client_id: builtins.str,
        client_secret: builtins.str,
        location: builtins.str,
        name: builtins.str,
        resource_group_name: builtins.str,
        service_provider_name: builtins.str,
        parameters: typing.Optional[typing.Mapping[builtins.str, builtins.str]] = None,
        scopes: typing.Optional[builtins.str] = None,
        tags: typing.Optional[typing.Mapping[builtins.str, builtins.str]] = None,
        timeouts: typing.Optional["BotConnectionTimeouts"] = None,
        count: typing.Optional[jsii.Number] = None,
        depends_on: typing.Optional[typing.List[cdktf.TerraformResource]] = None,
        lifecycle: typing.Optional[cdktf.TerraformResourceLifecycle] = None,
        provider: typing.Optional[cdktf.TerraformProvider] = None,
    ) -> None:
        """
        :param scope: -
        :param id: -
        :param bot_name: 
        :param client_id: 
        :param client_secret: 
        :param location: 
        :param name: 
        :param resource_group_name: 
        :param service_provider_name: 
        :param parameters: 
        :param scopes: 
        :param tags: 
        :param timeouts: timeouts block.
        :param count: 
        :param depends_on: 
        :param lifecycle: 
        :param provider: 
        """
        config = BotConnectionConfig(
            bot_name=bot_name,
            client_id=client_id,
            client_secret=client_secret,
            location=location,
            name=name,
            resource_group_name=resource_group_name,
            service_provider_name=service_provider_name,
            parameters=parameters,
            scopes=scopes,
            tags=tags,
            timeouts=timeouts,
            count=count,
            depends_on=depends_on,
            lifecycle=lifecycle,
            provider=provider,
        )

        jsii.create(BotConnection, self, [scope, id, config])

    @jsii.member(jsii_name="synthesizeAttributes")
    def _synthesize_attributes(self) -> typing.Mapping[builtins.str, typing.Any]:
        return jsii.invoke(self, "synthesizeAttributes", [])

    @builtins.property # type: ignore
    @jsii.member(jsii_name="botName")
    def bot_name(self) -> builtins.str:
        return jsii.get(self, "botName")

    @bot_name.setter # type: ignore
    def bot_name(self, value: builtins.str) -> None:
        jsii.set(self, "botName", value)

    @builtins.property # type: ignore
    @jsii.member(jsii_name="clientId")
    def client_id(self) -> builtins.str:
        return jsii.get(self, "clientId")

    @client_id.setter # type: ignore
    def client_id(self, value: builtins.str) -> None:
        jsii.set(self, "clientId", value)

    @builtins.property # type: ignore
    @jsii.member(jsii_name="clientSecret")
    def client_secret(self) -> builtins.str:
        return jsii.get(self, "clientSecret")

    @client_secret.setter # type: ignore
    def client_secret(self, value: builtins.str) -> None:
        jsii.set(self, "clientSecret", value)

    @builtins.property # type: ignore
    @jsii.member(jsii_name="location")
    def location(self) -> builtins.str:
        return jsii.get(self, "location")

    @location.setter # type: ignore
    def location(self, value: builtins.str) -> None:
        jsii.set(self, "location", value)

    @builtins.property # type: ignore
    @jsii.member(jsii_name="name")
    def name(self) -> builtins.str:
        return jsii.get(self, "name")

    @name.setter # type: ignore
    def name(self, value: builtins.str) -> None:
        jsii.set(self, "name", value)

    @builtins.property # type: ignore
    @jsii.member(jsii_name="resourceGroupName")
    def resource_group_name(self) -> builtins.str:
        return jsii.get(self, "resourceGroupName")

    @resource_group_name.setter # type: ignore
    def resource_group_name(self, value: builtins.str) -> None:
        jsii.set(self, "resourceGroupName", value)

    @builtins.property # type: ignore
    @jsii.member(jsii_name="serviceProviderName")
    def service_provider_name(self) -> builtins.str:
        return jsii.get(self, "serviceProviderName")

    @service_provider_name.setter # type: ignore
    def service_provider_name(self, value: builtins.str) -> None:
        jsii.set(self, "serviceProviderName", value)

    @builtins.property # type: ignore
    @jsii.member(jsii_name="id")
    def id(self) -> typing.Optional[builtins.str]:
        return jsii.get(self, "id")

    @id.setter # type: ignore
    def id(self, value: typing.Optional[builtins.str]) -> None:
        jsii.set(self, "id", value)

    @builtins.property # type: ignore
    @jsii.member(jsii_name="parameters")
    def parameters(self) -> typing.Optional[typing.Mapping[builtins.str, builtins.str]]:
        return jsii.get(self, "parameters")

    @parameters.setter # type: ignore
    def parameters(
        self,
        value: typing.Optional[typing.Mapping[builtins.str, builtins.str]],
    ) -> None:
        jsii.set(self, "parameters", value)

    @builtins.property # type: ignore
    @jsii.member(jsii_name="scopes")
    def scopes(self) -> typing.Optional[builtins.str]:
        return jsii.get(self, "scopes")

    @scopes.setter # type: ignore
    def scopes(self, value: typing.Optional[builtins.str]) -> None:
        jsii.set(self, "scopes", value)

    @builtins.property # type: ignore
    @jsii.member(jsii_name="tags")
    def tags(self) -> typing.Optional[typing.Mapping[builtins.str, builtins.str]]:
        return jsii.get(self, "tags")

    @tags.setter # type: ignore
    def tags(
        self,
        value: typing.Optional[typing.Mapping[builtins.str, builtins.str]],
    ) -> None:
        jsii.set(self, "tags", value)

    @builtins.property # type: ignore
    @jsii.member(jsii_name="timeouts")
    def timeouts(self) -> typing.Optional["BotConnectionTimeouts"]:
        return jsii.get(self, "timeouts")

    @timeouts.setter # type: ignore
    def timeouts(self, value: typing.Optional["BotConnectionTimeouts"]) -> None:
        jsii.set(self, "timeouts", value)


@jsii.data_type(
    jsii_type="@cdktf/provider-azurerm.BotConnectionConfig",
    jsii_struct_bases=[cdktf.TerraformMetaArguments],
    name_mapping={
        "count": "count",
        "depends_on": "dependsOn",
        "lifecycle": "lifecycle",
        "provider": "provider",
        "bot_name": "botName",
        "client_id": "clientId",
        "client_secret": "clientSecret",
        "location": "location",
        "name": "name",
        "resource_group_name": "resourceGroupName",
        "service_provider_name": "serviceProviderName",
        "parameters": "parameters",
        "scopes": "scopes",
        "tags": "tags",
        "timeouts": "timeouts",
    },
)
class BotConnectionConfig(cdktf.TerraformMetaArguments):
    def __init__(
        self,
        *,
        count: typing.Optional[jsii.Number] = None,
        depends_on: typing.Optional[typing.List[cdktf.TerraformResource]] = None,
        lifecycle: typing.Optional[cdktf.TerraformResourceLifecycle] = None,
        provider: typing.Optional[cdktf.TerraformProvider] = None,
        bot_name: builtins.str,
        client_id: builtins.str,
        client_secret: builtins.str,
        location: builtins.str,
        name: builtins.str,
        resource_group_name: builtins.str,
        service_provider_name: builtins.str,
        parameters: typing.Optional[typing.Mapping[builtins.str, builtins.str]] = None,
        scopes: typing.Optional[builtins.str] = None,
        tags: typing.Optional[typing.Mapping[builtins.str, builtins.str]] = None,
        timeouts: typing.Optional["BotConnectionTimeouts"] = None,
    ) -> None:
        """
        :param count: 
        :param depends_on: 
        :param lifecycle: 
        :param provider: 
        :param bot_name: 
        :param client_id: 
        :param client_secret: 
        :param location: 
        :param name: 
        :param resource_group_name: 
        :param service_provider_name: 
        :param parameters: 
        :param scopes: 
        :param tags: 
        :param timeouts: timeouts block.
        """
        if isinstance(lifecycle, dict):
            lifecycle = cdktf.TerraformResourceLifecycle(**lifecycle)
        if isinstance(timeouts, dict):
            timeouts = BotConnectionTimeouts(**timeouts)
        self._values: typing.Dict[str, typing.Any] = {
            "bot_name": bot_name,
            "client_id": client_id,
            "client_secret": client_secret,
            "location": location,
            "name": name,
            "resource_group_name": resource_group_name,
            "service_provider_name": service_provider_name,
        }
        if count is not None:
            self._values["count"] = count
        if depends_on is not None:
            self._values["depends_on"] = depends_on
        if lifecycle is not None:
            self._values["lifecycle"] = lifecycle
        if provider is not None:
            self._values["provider"] = provider
        if parameters is not None:
            self._values["parameters"] = parameters
        if scopes is not None:
            self._values["scopes"] = scopes
        if tags is not None:
            self._values["tags"] = tags
        if timeouts is not None:
            self._values["timeouts"] = timeouts

    @builtins.property
    def count(self) -> typing.Optional[jsii.Number]:
        """
        :stability: experimental
        """
        result = self._values.get("count")
        return result

    @builtins.property
    def depends_on(self) -> typing.Optional[typing.List[cdktf.TerraformResource]]:
        """
        :stability: experimental
        """
        result = self._values.get("depends_on")
        return result

    @builtins.property
    def lifecycle(self) -> typing.Optional[cdktf.TerraformResourceLifecycle]:
        """
        :stability: experimental
        """
        result = self._values.get("lifecycle")
        return result

    @builtins.property
    def provider(self) -> typing.Optional[cdktf.TerraformProvider]:
        """
        :stability: experimental
        """
        result = self._values.get("provider")
        return result

    @builtins.property
    def bot_name(self) -> builtins.str:
        result = self._values.get("bot_name")
        assert result is not None, "Required property 'bot_name' is missing"
        return result

    @builtins.property
    def client_id(self) -> builtins.str:
        result = self._values.get("client_id")
        assert result is not None, "Required property 'client_id' is missing"
        return result

    @builtins.property
    def client_secret(self) -> builtins.str:
        result = self._values.get("client_secret")
        assert result is not None, "Required property 'client_secret' is missing"
        return result

    @builtins.property
    def location(self) -> builtins.str:
        result = self._values.get("location")
        assert result is not None, "Required property 'location' is missing"
        return result

    @builtins.property
    def name(self) -> builtins.str:
        result = self._values.get("name")
        assert result is not None, "Required property 'name' is missing"
        return result

    @builtins.property
    def resource_group_name(self) -> builtins.str:
        result = self._values.get("resource_group_name")
        assert result is not None, "Required property 'resource_group_name' is missing"
        return result

    @builtins.property
    def service_provider_name(self) -> builtins.str:
        result = self._values.get("service_provider_name")
        assert result is not None, "Required property 'service_provider_name' is missing"
        return result

    @builtins.property
    def parameters(self) -> typing.Optional[typing.Mapping[builtins.str, builtins.str]]:
        result = self._values.get("parameters")
        return result

    @builtins.property
    def scopes(self) -> typing.Optional[builtins.str]:
        result = self._values.get("scopes")
        return result

    @builtins.property
    def tags(self) -> typing.Optional[typing.Mapping[builtins.str, builtins.str]]:
        result = self._values.get("tags")
        return result

    @builtins.property
    def timeouts(self) -> typing.Optional["BotConnectionTimeouts"]:
        """timeouts block."""
        result = self._values.get("timeouts")
        return result

    def __eq__(self, rhs: typing.Any) -> builtins.bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs: typing.Any) -> builtins.bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return "BotConnectionConfig(%s)" % ", ".join(
            k + "=" + repr(v) for k, v in self._values.items()
        )


@jsii.data_type(
    jsii_type="@cdktf/provider-azurerm.BotConnectionTimeouts",
    jsii_struct_bases=[],
    name_mapping={
        "create": "create",
        "delete": "delete",
        "read": "read",
        "update": "update",
    },
)
class BotConnectionTimeouts:
    def __init__(
        self,
        *,
        create: typing.Optional[builtins.str] = None,
        delete: typing.Optional[builtins.str] = None,
        read: typing.Optional[builtins.str] = None,
        update: typing.Optional[builtins.str] = None,
    ) -> None:
        """
        :param create: 
        :param delete: 
        :param read: 
        :param update: 
        """
        self._values: typing.Dict[str, typing.Any] = {}
        if create is not None:
            self._values["create"] = create
        if delete is not None:
            self._values["delete"] = delete
        if read is not None:
            self._values["read"] = read
        if update is not None:
            self._values["update"] = update

    @builtins.property
    def create(self) -> typing.Optional[builtins.str]:
        result = self._values.get("create")
        return result

    @builtins.property
    def delete(self) -> typing.Optional[builtins.str]:
        result = self._values.get("delete")
        return result

    @builtins.property
    def read(self) -> typing.Optional[builtins.str]:
        result = self._values.get("read")
        return result

    @builtins.property
    def update(self) -> typing.Optional[builtins.str]:
        result = self._values.get("update")
        return result

    def __eq__(self, rhs: typing.Any) -> builtins.bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs: typing.Any) -> builtins.bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return "BotConnectionTimeouts(%s)" % ", ".join(
            k + "=" + repr(v) for k, v in self._values.items()
        )


class BotWebApp(
    cdktf.TerraformResource,
    metaclass=jsii.JSIIMeta,
    jsii_type="@cdktf/provider-azurerm.BotWebApp",
):
    def __init__(
        self,
        scope: constructs.Construct,
        id: builtins.str,
        *,
        location: builtins.str,
        microsoft_app_id: builtins.str,
        name: builtins.str,
        resource_group_name: builtins.str,
        sku: builtins.str,
        developer_app_insights_api_key: typing.Optional[builtins.str] = None,
        developer_app_insights_application_id: typing.Optional[builtins.str] = None,
        developer_app_insights_key: typing.Optional[builtins.str] = None,
        display_name: typing.Optional[builtins.str] = None,
        endpoint: typing.Optional[builtins.str] = None,
        luis_app_ids: typing.Optional[typing.List[builtins.str]] = None,
        luis_key: typing.Optional[builtins.str] = None,
        tags: typing.Optional[typing.Mapping[builtins.str, builtins.str]] = None,
        timeouts: typing.Optional["BotWebAppTimeouts"] = None,
        count: typing.Optional[jsii.Number] = None,
        depends_on: typing.Optional[typing.List[cdktf.TerraformResource]] = None,
        lifecycle: typing.Optional[cdktf.TerraformResourceLifecycle] = None,
        provider: typing.Optional[cdktf.TerraformProvider] = None,
    ) -> None:
        """
        :param scope: -
        :param id: -
        :param location: 
        :param microsoft_app_id: 
        :param name: 
        :param resource_group_name: 
        :param sku: 
        :param developer_app_insights_api_key: 
        :param developer_app_insights_application_id: 
        :param developer_app_insights_key: 
        :param display_name: 
        :param endpoint: 
        :param luis_app_ids: 
        :param luis_key: 
        :param tags: 
        :param timeouts: timeouts block.
        :param count: 
        :param depends_on: 
        :param lifecycle: 
        :param provider: 
        """
        config = BotWebAppConfig(
            location=location,
            microsoft_app_id=microsoft_app_id,
            name=name,
            resource_group_name=resource_group_name,
            sku=sku,
            developer_app_insights_api_key=developer_app_insights_api_key,
            developer_app_insights_application_id=developer_app_insights_application_id,
            developer_app_insights_key=developer_app_insights_key,
            display_name=display_name,
            endpoint=endpoint,
            luis_app_ids=luis_app_ids,
            luis_key=luis_key,
            tags=tags,
            timeouts=timeouts,
            count=count,
            depends_on=depends_on,
            lifecycle=lifecycle,
            provider=provider,
        )

        jsii.create(BotWebApp, self, [scope, id, config])

    @jsii.member(jsii_name="synthesizeAttributes")
    def _synthesize_attributes(self) -> typing.Mapping[builtins.str, typing.Any]:
        return jsii.invoke(self, "synthesizeAttributes", [])

    @builtins.property # type: ignore
    @jsii.member(jsii_name="location")
    def location(self) -> builtins.str:
        return jsii.get(self, "location")

    @location.setter # type: ignore
    def location(self, value: builtins.str) -> None:
        jsii.set(self, "location", value)

    @builtins.property # type: ignore
    @jsii.member(jsii_name="microsoftAppId")
    def microsoft_app_id(self) -> builtins.str:
        return jsii.get(self, "microsoftAppId")

    @microsoft_app_id.setter # type: ignore
    def microsoft_app_id(self, value: builtins.str) -> None:
        jsii.set(self, "microsoftAppId", value)

    @builtins.property # type: ignore
    @jsii.member(jsii_name="name")
    def name(self) -> builtins.str:
        return jsii.get(self, "name")

    @name.setter # type: ignore
    def name(self, value: builtins.str) -> None:
        jsii.set(self, "name", value)

    @builtins.property # type: ignore
    @jsii.member(jsii_name="resourceGroupName")
    def resource_group_name(self) -> builtins.str:
        return jsii.get(self, "resourceGroupName")

    @resource_group_name.setter # type: ignore
    def resource_group_name(self, value: builtins.str) -> None:
        jsii.set(self, "resourceGroupName", value)

    @builtins.property # type: ignore
    @jsii.member(jsii_name="sku")
    def sku(self) -> builtins.str:
        return jsii.get(self, "sku")

    @sku.setter # type: ignore
    def sku(self, value: builtins.str) -> None:
        jsii.set(self, "sku", value)

    @builtins.property # type: ignore
    @jsii.member(jsii_name="developerAppInsightsApiKey")
    def developer_app_insights_api_key(self) -> typing.Optional[builtins.str]:
        return jsii.get(self, "developerAppInsightsApiKey")

    @developer_app_insights_api_key.setter # type: ignore
    def developer_app_insights_api_key(
        self,
        value: typing.Optional[builtins.str],
    ) -> None:
        jsii.set(self, "developerAppInsightsApiKey", value)

    @builtins.property # type: ignore
    @jsii.member(jsii_name="developerAppInsightsApplicationId")
    def developer_app_insights_application_id(self) -> typing.Optional[builtins.str]:
        return jsii.get(self, "developerAppInsightsApplicationId")

    @developer_app_insights_application_id.setter # type: ignore
    def developer_app_insights_application_id(
        self,
        value: typing.Optional[builtins.str],
    ) -> None:
        jsii.set(self, "developerAppInsightsApplicationId", value)

    @builtins.property # type: ignore
    @jsii.member(jsii_name="developerAppInsightsKey")
    def developer_app_insights_key(self) -> typing.Optional[builtins.str]:
        return jsii.get(self, "developerAppInsightsKey")

    @developer_app_insights_key.setter # type: ignore
    def developer_app_insights_key(self, value: typing.Optional[builtins.str]) -> None:
        jsii.set(self, "developerAppInsightsKey", value)

    @builtins.property # type: ignore
    @jsii.member(jsii_name="displayName")
    def display_name(self) -> typing.Optional[builtins.str]:
        return jsii.get(self, "displayName")

    @display_name.setter # type: ignore
    def display_name(self, value: typing.Optional[builtins.str]) -> None:
        jsii.set(self, "displayName", value)

    @builtins.property # type: ignore
    @jsii.member(jsii_name="endpoint")
    def endpoint(self) -> typing.Optional[builtins.str]:
        return jsii.get(self, "endpoint")

    @endpoint.setter # type: ignore
    def endpoint(self, value: typing.Optional[builtins.str]) -> None:
        jsii.set(self, "endpoint", value)

    @builtins.property # type: ignore
    @jsii.member(jsii_name="id")
    def id(self) -> typing.Optional[builtins.str]:
        return jsii.get(self, "id")

    @id.setter # type: ignore
    def id(self, value: typing.Optional[builtins.str]) -> None:
        jsii.set(self, "id", value)

    @builtins.property # type: ignore
    @jsii.member(jsii_name="luisAppIds")
    def luis_app_ids(self) -> typing.Optional[typing.List[builtins.str]]:
        return jsii.get(self, "luisAppIds")

    @luis_app_ids.setter # type: ignore
    def luis_app_ids(self, value: typing.Optional[typing.List[builtins.str]]) -> None:
        jsii.set(self, "luisAppIds", value)

    @builtins.property # type: ignore
    @jsii.member(jsii_name="luisKey")
    def luis_key(self) -> typing.Optional[builtins.str]:
        return jsii.get(self, "luisKey")

    @luis_key.setter # type: ignore
    def luis_key(self, value: typing.Optional[builtins.str]) -> None:
        jsii.set(self, "luisKey", value)

    @builtins.property # type: ignore
    @jsii.member(jsii_name="tags")
    def tags(self) -> typing.Optional[typing.Mapping[builtins.str, builtins.str]]:
        return jsii.get(self, "tags")

    @tags.setter # type: ignore
    def tags(
        self,
        value: typing.Optional[typing.Mapping[builtins.str, builtins.str]],
    ) -> None:
        jsii.set(self, "tags", value)

    @builtins.property # type: ignore
    @jsii.member(jsii_name="timeouts")
    def timeouts(self) -> typing.Optional["BotWebAppTimeouts"]:
        return jsii.get(self, "timeouts")

    @timeouts.setter # type: ignore
    def timeouts(self, value: typing.Optional["BotWebAppTimeouts"]) -> None:
        jsii.set(self, "timeouts", value)


@jsii.data_type(
    jsii_type="@cdktf/provider-azurerm.BotWebAppConfig",
    jsii_struct_bases=[cdktf.TerraformMetaArguments],
    name_mapping={
        "count": "count",
        "depends_on": "dependsOn",
        "lifecycle": "lifecycle",
        "provider": "provider",
        "location": "location",
        "microsoft_app_id": "microsoftAppId",
        "name": "name",
        "resource_group_name": "resourceGroupName",
        "sku": "sku",
        "developer_app_insights_api_key": "developerAppInsightsApiKey",
        "developer_app_insights_application_id": "developerAppInsightsApplicationId",
        "developer_app_insights_key": "developerAppInsightsKey",
        "display_name": "displayName",
        "endpoint": "endpoint",
        "luis_app_ids": "luisAppIds",
        "luis_key": "luisKey",
        "tags": "tags",
        "timeouts": "timeouts",
    },
)
class BotWebAppConfig(cdktf.TerraformMetaArguments):
    def __init__(
        self,
        *,
        count: typing.Optional[jsii.Number] = None,
        depends_on: typing.Optional[typing.List[cdktf.TerraformResource]] = None,
        lifecycle: typing.Optional[cdktf.TerraformResourceLifecycle] = None,
        provider: typing.Optional[cdktf.TerraformProvider] = None,
        location: builtins.str,
        microsoft_app_id: builtins.str,
        name: builtins.str,
        resource_group_name: builtins.str,
        sku: builtins.str,
        developer_app_insights_api_key: typing.Optional[builtins.str] = None,
        developer_app_insights_application_id: typing.Optional[builtins.str] = None,
        developer_app_insights_key: typing.Optional[builtins.str] = None,
        display_name: typing.Optional[builtins.str] = None,
        endpoint: typing.Optional[builtins.str] = None,
        luis_app_ids: typing.Optional[typing.List[builtins.str]] = None,
        luis_key: typing.Optional[builtins.str] = None,
        tags: typing.Optional[typing.Mapping[builtins.str, builtins.str]] = None,
        timeouts: typing.Optional["BotWebAppTimeouts"] = None,
    ) -> None:
        """
        :param count: 
        :param depends_on: 
        :param lifecycle: 
        :param provider: 
        :param location: 
        :param microsoft_app_id: 
        :param name: 
        :param resource_group_name: 
        :param sku: 
        :param developer_app_insights_api_key: 
        :param developer_app_insights_application_id: 
        :param developer_app_insights_key: 
        :param display_name: 
        :param endpoint: 
        :param luis_app_ids: 
        :param luis_key: 
        :param tags: 
        :param timeouts: timeouts block.
        """
        if isinstance(lifecycle, dict):
            lifecycle = cdktf.TerraformResourceLifecycle(**lifecycle)
        if isinstance(timeouts, dict):
            timeouts = BotWebAppTimeouts(**timeouts)
        self._values: typing.Dict[str, typing.Any] = {
            "location": location,
            "microsoft_app_id": microsoft_app_id,
            "name": name,
            "resource_group_name": resource_group_name,
            "sku": sku,
        }
        if count is not None:
            self._values["count"] = count
        if depends_on is not None:
            self._values["depends_on"] = depends_on
        if lifecycle is not None:
            self._values["lifecycle"] = lifecycle
        if provider is not None:
            self._values["provider"] = provider
        if developer_app_insights_api_key is not None:
            self._values["developer_app_insights_api_key"] = developer_app_insights_api_key
        if developer_app_insights_application_id is not None:
            self._values["developer_app_insights_application_id"] = developer_app_insights_application_id
        if developer_app_insights_key is not None:
            self._values["developer_app_insights_key"] = developer_app_insights_key
        if display_name is not None:
            self._values["display_name"] = display_name
        if endpoint is not None:
            self._values["endpoint"] = endpoint
        if luis_app_ids is not None:
            self._values["luis_app_ids"] = luis_app_ids
        if luis_key is not None:
            self._values["luis_key"] = luis_key
        if tags is not None:
            self._values["tags"] = tags
        if timeouts is not None:
            self._values["timeouts"] = timeouts

    @builtins.property
    def count(self) -> typing.Optional[jsii.Number]:
        """
        :stability: experimental
        """
        result = self._values.get("count")
        return result

    @builtins.property
    def depends_on(self) -> typing.Optional[typing.List[cdktf.TerraformResource]]:
        """
        :stability: experimental
        """
        result = self._values.get("depends_on")
        return result

    @builtins.property
    def lifecycle(self) -> typing.Optional[cdktf.TerraformResourceLifecycle]:
        """
        :stability: experimental
        """
        result = self._values.get("lifecycle")
        return result

    @builtins.property
    def provider(self) -> typing.Optional[cdktf.TerraformProvider]:
        """
        :stability: experimental
        """
        result = self._values.get("provider")
        return result

    @builtins.property
    def location(self) -> builtins.str:
        result = self._values.get("location")
        assert result is not None, "Required property 'location' is missing"
        return result

    @builtins.property
    def microsoft_app_id(self) -> builtins.str:
        result = self._values.get("microsoft_app_id")
        assert result is not None, "Required property 'microsoft_app_id' is missing"
        return result

    @builtins.property
    def name(self) -> builtins.str:
        result = self._values.get("name")
        assert result is not None, "Required property 'name' is missing"
        return result

    @builtins.property
    def resource_group_name(self) -> builtins.str:
        result = self._values.get("resource_group_name")
        assert result is not None, "Required property 'resource_group_name' is missing"
        return result

    @builtins.property
    def sku(self) -> builtins.str:
        result = self._values.get("sku")
        assert result is not None, "Required property 'sku' is missing"
        return result

    @builtins.property
    def developer_app_insights_api_key(self) -> typing.Optional[builtins.str]:
        result = self._values.get("developer_app_insights_api_key")
        return result

    @builtins.property
    def developer_app_insights_application_id(self) -> typing.Optional[builtins.str]:
        result = self._values.get("developer_app_insights_application_id")
        return result

    @builtins.property
    def developer_app_insights_key(self) -> typing.Optional[builtins.str]:
        result = self._values.get("developer_app_insights_key")
        return result

    @builtins.property
    def display_name(self) -> typing.Optional[builtins.str]:
        result = self._values.get("display_name")
        return result

    @builtins.property
    def endpoint(self) -> typing.Optional[builtins.str]:
        result = self._values.get("endpoint")
        return result

    @builtins.property
    def luis_app_ids(self) -> typing.Optional[typing.List[builtins.str]]:
        result = self._values.get("luis_app_ids")
        return result

    @builtins.property
    def luis_key(self) -> typing.Optional[builtins.str]:
        result = self._values.get("luis_key")
        return result

    @builtins.property
    def tags(self) -> typing.Optional[typing.Mapping[builtins.str, builtins.str]]:
        result = self._values.get("tags")
        return result

    @builtins.property
    def timeouts(self) -> typing.Optional["BotWebAppTimeouts"]:
        """timeouts block."""
        result = self._values.get("timeouts")
        return result

    def __eq__(self, rhs: typing.Any) -> builtins.bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs: typing.Any) -> builtins.bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return "BotWebAppConfig(%s)" % ", ".join(
            k + "=" + repr(v) for k, v in self._values.items()
        )


@jsii.data_type(
    jsii_type="@cdktf/provider-azurerm.BotWebAppTimeouts",
    jsii_struct_bases=[],
    name_mapping={
        "create": "create",
        "delete": "delete",
        "read": "read",
        "update": "update",
    },
)
class BotWebAppTimeouts:
    def __init__(
        self,
        *,
        create: typing.Optional[builtins.str] = None,
        delete: typing.Optional[builtins.str] = None,
        read: typing.Optional[builtins.str] = None,
        update: typing.Optional[builtins.str] = None,
    ) -> None:
        """
        :param create: 
        :param delete: 
        :param read: 
        :param update: 
        """
        self._values: typing.Dict[str, typing.Any] = {}
        if create is not None:
            self._values["create"] = create
        if delete is not None:
            self._values["delete"] = delete
        if read is not None:
            self._values["read"] = read
        if update is not None:
            self._values["update"] = update

    @builtins.property
    def create(self) -> typing.Optional[builtins.str]:
        result = self._values.get("create")
        return result

    @builtins.property
    def delete(self) -> typing.Optional[builtins.str]:
        result = self._values.get("delete")
        return result

    @builtins.property
    def read(self) -> typing.Optional[builtins.str]:
        result = self._values.get("read")
        return result

    @builtins.property
    def update(self) -> typing.Optional[builtins.str]:
        result = self._values.get("update")
        return result

    def __eq__(self, rhs: typing.Any) -> builtins.bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs: typing.Any) -> builtins.bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return "BotWebAppTimeouts(%s)" % ", ".join(
            k + "=" + repr(v) for k, v in self._values.items()
        )


class CdnEndpoint(
    cdktf.TerraformResource,
    metaclass=jsii.JSIIMeta,
    jsii_type="@cdktf/provider-azurerm.CdnEndpoint",
):
    def __init__(
        self,
        scope: constructs.Construct,
        id: builtins.str,
        *,
        location: builtins.str,
        name: builtins.str,
        origin: typing.List["CdnEndpointOrigin"],
        profile_name: builtins.str,
        resource_group_name: builtins.str,
        content_types_to_compress: typing.Optional[typing.List[builtins.str]] = None,
        geo_filter: typing.Optional[typing.List["CdnEndpointGeoFilter"]] = None,
        is_compression_enabled: typing.Optional[builtins.bool] = None,
        is_http_allowed: typing.Optional[builtins.bool] = None,
        is_https_allowed: typing.Optional[builtins.bool] = None,
        optimization_type: typing.Optional[builtins.str] = None,
        origin_host_header: typing.Optional[builtins.str] = None,
        origin_path: typing.Optional[builtins.str] = None,
        probe_path: typing.Optional[builtins.str] = None,
        querystring_caching_behaviour: typing.Optional[builtins.str] = None,
        tags: typing.Optional[typing.Mapping[builtins.str, builtins.str]] = None,
        timeouts: typing.Optional["CdnEndpointTimeouts"] = None,
        count: typing.Optional[jsii.Number] = None,
        depends_on: typing.Optional[typing.List[cdktf.TerraformResource]] = None,
        lifecycle: typing.Optional[cdktf.TerraformResourceLifecycle] = None,
        provider: typing.Optional[cdktf.TerraformProvider] = None,
    ) -> None:
        """
        :param scope: -
        :param id: -
        :param location: 
        :param name: 
        :param origin: origin block.
        :param profile_name: 
        :param resource_group_name: 
        :param content_types_to_compress: 
        :param geo_filter: geo_filter block.
        :param is_compression_enabled: 
        :param is_http_allowed: 
        :param is_https_allowed: 
        :param optimization_type: 
        :param origin_host_header: 
        :param origin_path: 
        :param probe_path: 
        :param querystring_caching_behaviour: 
        :param tags: 
        :param timeouts: timeouts block.
        :param count: 
        :param depends_on: 
        :param lifecycle: 
        :param provider: 
        """
        config = CdnEndpointConfig(
            location=location,
            name=name,
            origin=origin,
            profile_name=profile_name,
            resource_group_name=resource_group_name,
            content_types_to_compress=content_types_to_compress,
            geo_filter=geo_filter,
            is_compression_enabled=is_compression_enabled,
            is_http_allowed=is_http_allowed,
            is_https_allowed=is_https_allowed,
            optimization_type=optimization_type,
            origin_host_header=origin_host_header,
            origin_path=origin_path,
            probe_path=probe_path,
            querystring_caching_behaviour=querystring_caching_behaviour,
            tags=tags,
            timeouts=timeouts,
            count=count,
            depends_on=depends_on,
            lifecycle=lifecycle,
            provider=provider,
        )

        jsii.create(CdnEndpoint, self, [scope, id, config])

    @jsii.member(jsii_name="synthesizeAttributes")
    def _synthesize_attributes(self) -> typing.Mapping[builtins.str, typing.Any]:
        return jsii.invoke(self, "synthesizeAttributes", [])

    @builtins.property # type: ignore
    @jsii.member(jsii_name="hostName")
    def host_name(self) -> builtins.str:
        return jsii.get(self, "hostName")

    @builtins.property # type: ignore
    @jsii.member(jsii_name="location")
    def location(self) -> builtins.str:
        return jsii.get(self, "location")

    @location.setter # type: ignore
    def location(self, value: builtins.str) -> None:
        jsii.set(self, "location", value)

    @builtins.property # type: ignore
    @jsii.member(jsii_name="name")
    def name(self) -> builtins.str:
        return jsii.get(self, "name")

    @name.setter # type: ignore
    def name(self, value: builtins.str) -> None:
        jsii.set(self, "name", value)

    @builtins.property # type: ignore
    @jsii.member(jsii_name="origin")
    def origin(self) -> typing.List["CdnEndpointOrigin"]:
        return jsii.get(self, "origin")

    @origin.setter # type: ignore
    def origin(self, value: typing.List["CdnEndpointOrigin"]) -> None:
        jsii.set(self, "origin", value)

    @builtins.property # type: ignore
    @jsii.member(jsii_name="profileName")
    def profile_name(self) -> builtins.str:
        return jsii.get(self, "profileName")

    @profile_name.setter # type: ignore
    def profile_name(self, value: builtins.str) -> None:
        jsii.set(self, "profileName", value)

    @builtins.property # type: ignore
    @jsii.member(jsii_name="resourceGroupName")
    def resource_group_name(self) -> builtins.str:
        return jsii.get(self, "resourceGroupName")

    @resource_group_name.setter # type: ignore
    def resource_group_name(self, value: builtins.str) -> None:
        jsii.set(self, "resourceGroupName", value)

    @builtins.property # type: ignore
    @jsii.member(jsii_name="contentTypesToCompress")
    def content_types_to_compress(self) -> typing.Optional[typing.List[builtins.str]]:
        return jsii.get(self, "contentTypesToCompress")

    @content_types_to_compress.setter # type: ignore
    def content_types_to_compress(
        self,
        value: typing.Optional[typing.List[builtins.str]],
    ) -> None:
        jsii.set(self, "contentTypesToCompress", value)

    @builtins.property # type: ignore
    @jsii.member(jsii_name="geoFilter")
    def geo_filter(self) -> typing.Optional[typing.List["CdnEndpointGeoFilter"]]:
        return jsii.get(self, "geoFilter")

    @geo_filter.setter # type: ignore
    def geo_filter(
        self,
        value: typing.Optional[typing.List["CdnEndpointGeoFilter"]],
    ) -> None:
        jsii.set(self, "geoFilter", value)

    @builtins.property # type: ignore
    @jsii.member(jsii_name="id")
    def id(self) -> typing.Optional[builtins.str]:
        return jsii.get(self, "id")

    @id.setter # type: ignore
    def id(self, value: typing.Optional[builtins.str]) -> None:
        jsii.set(self, "id", value)

    @builtins.property # type: ignore
    @jsii.member(jsii_name="isCompressionEnabled")
    def is_compression_enabled(self) -> typing.Optional[builtins.bool]:
        return jsii.get(self, "isCompressionEnabled")

    @is_compression_enabled.setter # type: ignore
    def is_compression_enabled(self, value: typing.Optional[builtins.bool]) -> None:
        jsii.set(self, "isCompressionEnabled", value)

    @builtins.property # type: ignore
    @jsii.member(jsii_name="isHttpAllowed")
    def is_http_allowed(self) -> typing.Optional[builtins.bool]:
        return jsii.get(self, "isHttpAllowed")

    @is_http_allowed.setter # type: ignore
    def is_http_allowed(self, value: typing.Optional[builtins.bool]) -> None:
        jsii.set(self, "isHttpAllowed", value)

    @builtins.property # type: ignore
    @jsii.member(jsii_name="isHttpsAllowed")
    def is_https_allowed(self) -> typing.Optional[builtins.bool]:
        return jsii.get(self, "isHttpsAllowed")

    @is_https_allowed.setter # type: ignore
    def is_https_allowed(self, value: typing.Optional[builtins.bool]) -> None:
        jsii.set(self, "isHttpsAllowed", value)

    @builtins.property # type: ignore
    @jsii.member(jsii_name="optimizationType")
    def optimization_type(self) -> typing.Optional[builtins.str]:
        return jsii.get(self, "optimizationType")

    @optimization_type.setter # type: ignore
    def optimization_type(self, value: typing.Optional[builtins.str]) -> None:
        jsii.set(self, "optimizationType", value)

    @builtins.property # type: ignore
    @jsii.member(jsii_name="originHostHeader")
    def origin_host_header(self) -> typing.Optional[builtins.str]:
        return jsii.get(self, "originHostHeader")

    @origin_host_header.setter # type: ignore
    def origin_host_header(self, value: typing.Optional[builtins.str]) -> None:
        jsii.set(self, "originHostHeader", value)

    @builtins.property # type: ignore
    @jsii.member(jsii_name="originPath")
    def origin_path(self) -> typing.Optional[builtins.str]:
        return jsii.get(self, "originPath")

    @origin_path.setter # type: ignore
    def origin_path(self, value: typing.Optional[builtins.str]) -> None:
        jsii.set(self, "originPath", value)

    @builtins.property # type: ignore
    @jsii.member(jsii_name="probePath")
    def probe_path(self) -> typing.Optional[builtins.str]:
        return jsii.get(self, "probePath")

    @probe_path.setter # type: ignore
    def probe_path(self, value: typing.Optional[builtins.str]) -> None:
        jsii.set(self, "probePath", value)

    @builtins.property # type: ignore
    @jsii.member(jsii_name="querystringCachingBehaviour")
    def querystring_caching_behaviour(self) -> typing.Optional[builtins.str]:
        return jsii.get(self, "querystringCachingBehaviour")

    @querystring_caching_behaviour.setter # type: ignore
    def querystring_caching_behaviour(
        self,
        value: typing.Optional[builtins.str],
    ) -> None:
        jsii.set(self, "querystringCachingBehaviour", value)

    @builtins.property # type: ignore
    @jsii.member(jsii_name="tags")
    def tags(self) -> typing.Optional[typing.Mapping[builtins.str, builtins.str]]:
        return jsii.get(self, "tags")

    @tags.setter # type: ignore
    def tags(
        self,
        value: typing.Optional[typing.Mapping[builtins.str, builtins.str]],
    ) -> None:
        jsii.set(self, "tags", value)

    @builtins.property # type: ignore
    @jsii.member(jsii_name="timeouts")
    def timeouts(self) -> typing.Optional["CdnEndpointTimeouts"]:
        return jsii.get(self, "timeouts")

    @timeouts.setter # type: ignore
    def timeouts(self, value: typing.Optional["CdnEndpointTimeouts"]) -> None:
        jsii.set(self, "timeouts", value)


@jsii.data_type(
    jsii_type="@cdktf/provider-azurerm.CdnEndpointConfig",
    jsii_struct_bases=[cdktf.TerraformMetaArguments],
    name_mapping={
        "count": "count",
        "depends_on": "dependsOn",
        "lifecycle": "lifecycle",
        "provider": "provider",
        "location": "location",
        "name": "name",
        "origin": "origin",
        "profile_name": "profileName",
        "resource_group_name": "resourceGroupName",
        "content_types_to_compress": "contentTypesToCompress",
        "geo_filter": "geoFilter",
        "is_compression_enabled": "isCompressionEnabled",
        "is_http_allowed": "isHttpAllowed",
        "is_https_allowed": "isHttpsAllowed",
        "optimization_type": "optimizationType",
        "origin_host_header": "originHostHeader",
        "origin_path": "originPath",
        "probe_path": "probePath",
        "querystring_caching_behaviour": "querystringCachingBehaviour",
        "tags": "tags",
        "timeouts": "timeouts",
    },
)
class CdnEndpointConfig(cdktf.TerraformMetaArguments):
    def __init__(
        self,
        *,
        count: typing.Optional[jsii.Number] = None,
        depends_on: typing.Optional[typing.List[cdktf.TerraformResource]] = None,
        lifecycle: typing.Optional[cdktf.TerraformResourceLifecycle] = None,
        provider: typing.Optional[cdktf.TerraformProvider] = None,
        location: builtins.str,
        name: builtins.str,
        origin: typing.List["CdnEndpointOrigin"],
        profile_name: builtins.str,
        resource_group_name: builtins.str,
        content_types_to_compress: typing.Optional[typing.List[builtins.str]] = None,
        geo_filter: typing.Optional[typing.List["CdnEndpointGeoFilter"]] = None,
        is_compression_enabled: typing.Optional[builtins.bool] = None,
        is_http_allowed: typing.Optional[builtins.bool] = None,
        is_https_allowed: typing.Optional[builtins.bool] = None,
        optimization_type: typing.Optional[builtins.str] = None,
        origin_host_header: typing.Optional[builtins.str] = None,
        origin_path: typing.Optional[builtins.str] = None,
        probe_path: typing.Optional[builtins.str] = None,
        querystring_caching_behaviour: typing.Optional[builtins.str] = None,
        tags: typing.Optional[typing.Mapping[builtins.str, builtins.str]] = None,
        timeouts: typing.Optional["CdnEndpointTimeouts"] = None,
    ) -> None:
        """
        :param count: 
        :param depends_on: 
        :param lifecycle: 
        :param provider: 
        :param location: 
        :param name: 
        :param origin: origin block.
        :param profile_name: 
        :param resource_group_name: 
        :param content_types_to_compress: 
        :param geo_filter: geo_filter block.
        :param is_compression_enabled: 
        :param is_http_allowed: 
        :param is_https_allowed: 
        :param optimization_type: 
        :param origin_host_header: 
        :param origin_path: 
        :param probe_path: 
        :param querystring_caching_behaviour: 
        :param tags: 
        :param timeouts: timeouts block.
        """
        if isinstance(lifecycle, dict):
            lifecycle = cdktf.TerraformResourceLifecycle(**lifecycle)
        if isinstance(timeouts, dict):
            timeouts = CdnEndpointTimeouts(**timeouts)
        self._values: typing.Dict[str, typing.Any] = {
            "location": location,
            "name": name,
            "origin": origin,
            "profile_name": profile_name,
            "resource_group_name": resource_group_name,
        }
        if count is not None:
            self._values["count"] = count
        if depends_on is not None:
            self._values["depends_on"] = depends_on
        if lifecycle is not None:
            self._values["lifecycle"] = lifecycle
        if provider is not None:
            self._values["provider"] = provider
        if content_types_to_compress is not None:
            self._values["content_types_to_compress"] = content_types_to_compress
        if geo_filter is not None:
            self._values["geo_filter"] = geo_filter
        if is_compression_enabled is not None:
            self._values["is_compression_enabled"] = is_compression_enabled
        if is_http_allowed is not None:
            self._values["is_http_allowed"] = is_http_allowed
        if is_https_allowed is not None:
            self._values["is_https_allowed"] = is_https_allowed
        if optimization_type is not None:
            self._values["optimization_type"] = optimization_type
        if origin_host_header is not None:
            self._values["origin_host_header"] = origin_host_header
        if origin_path is not None:
            self._values["origin_path"] = origin_path
        if probe_path is not None:
            self._values["probe_path"] = probe_path
        if querystring_caching_behaviour is not None:
            self._values["querystring_caching_behaviour"] = querystring_caching_behaviour
        if tags is not None:
            self._values["tags"] = tags
        if timeouts is not None:
            self._values["timeouts"] = timeouts

    @builtins.property
    def count(self) -> typing.Optional[jsii.Number]:
        """
        :stability: experimental
        """
        result = self._values.get("count")
        return result

    @builtins.property
    def depends_on(self) -> typing.Optional[typing.List[cdktf.TerraformResource]]:
        """
        :stability: experimental
        """
        result = self._values.get("depends_on")
        return result

    @builtins.property
    def lifecycle(self) -> typing.Optional[cdktf.TerraformResourceLifecycle]:
        """
        :stability: experimental
        """
        result = self._values.get("lifecycle")
        return result

    @builtins.property
    def provider(self) -> typing.Optional[cdktf.TerraformProvider]:
        """
        :stability: experimental
        """
        result = self._values.get("provider")
        return result

    @builtins.property
    def location(self) -> builtins.str:
        result = self._values.get("location")
        assert result is not None, "Required property 'location' is missing"
        return result

    @builtins.property
    def name(self) -> builtins.str:
        result = self._values.get("name")
        assert result is not None, "Required property 'name' is missing"
        return result

    @builtins.property
    def origin(self) -> typing.List["CdnEndpointOrigin"]:
        """origin block."""
        result = self._values.get("origin")
        assert result is not None, "Required property 'origin' is missing"
        return result

    @builtins.property
    def profile_name(self) -> builtins.str:
        result = self._values.get("profile_name")
        assert result is not None, "Required property 'profile_name' is missing"
        return result

    @builtins.property
    def resource_group_name(self) -> builtins.str:
        result = self._values.get("resource_group_name")
        assert result is not None, "Required property 'resource_group_name' is missing"
        return result

    @builtins.property
    def content_types_to_compress(self) -> typing.Optional[typing.List[builtins.str]]:
        result = self._values.get("content_types_to_compress")
        return result

    @builtins.property
    def geo_filter(self) -> typing.Optional[typing.List["CdnEndpointGeoFilter"]]:
        """geo_filter block."""
        result = self._values.get("geo_filter")
        return result

    @builtins.property
    def is_compression_enabled(self) -> typing.Optional[builtins.bool]:
        result = self._values.get("is_compression_enabled")
        return result

    @builtins.property
    def is_http_allowed(self) -> typing.Optional[builtins.bool]:
        result = self._values.get("is_http_allowed")
        return result

    @builtins.property
    def is_https_allowed(self) -> typing.Optional[builtins.bool]:
        result = self._values.get("is_https_allowed")
        return result

    @builtins.property
    def optimization_type(self) -> typing.Optional[builtins.str]:
        result = self._values.get("optimization_type")
        return result

    @builtins.property
    def origin_host_header(self) -> typing.Optional[builtins.str]:
        result = self._values.get("origin_host_header")
        return result

    @builtins.property
    def origin_path(self) -> typing.Optional[builtins.str]:
        result = self._values.get("origin_path")
        return result

    @builtins.property
    def probe_path(self) -> typing.Optional[builtins.str]:
        result = self._values.get("probe_path")
        return result

    @builtins.property
    def querystring_caching_behaviour(self) -> typing.Optional[builtins.str]:
        result = self._values.get("querystring_caching_behaviour")
        return result

    @builtins.property
    def tags(self) -> typing.Optional[typing.Mapping[builtins.str, builtins.str]]:
        result = self._values.get("tags")
        return result

    @builtins.property
    def timeouts(self) -> typing.Optional["CdnEndpointTimeouts"]:
        """timeouts block."""
        result = self._values.get("timeouts")
        return result

    def __eq__(self, rhs: typing.Any) -> builtins.bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs: typing.Any) -> builtins.bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return "CdnEndpointConfig(%s)" % ", ".join(
            k + "=" + repr(v) for k, v in self._values.items()
        )


@jsii.data_type(
    jsii_type="@cdktf/provider-azurerm.CdnEndpointGeoFilter",
    jsii_struct_bases=[],
    name_mapping={
        "action": "action",
        "country_codes": "countryCodes",
        "relative_path": "relativePath",
    },
)
class CdnEndpointGeoFilter:
    def __init__(
        self,
        *,
        action: builtins.str,
        country_codes: typing.List[builtins.str],
        relative_path: builtins.str,
    ) -> None:
        """
        :param action: 
        :param country_codes: 
        :param relative_path: 
        """
        self._values: typing.Dict[str, typing.Any] = {
            "action": action,
            "country_codes": country_codes,
            "relative_path": relative_path,
        }

    @builtins.property
    def action(self) -> builtins.str:
        result = self._values.get("action")
        assert result is not None, "Required property 'action' is missing"
        return result

    @builtins.property
    def country_codes(self) -> typing.List[builtins.str]:
        result = self._values.get("country_codes")
        assert result is not None, "Required property 'country_codes' is missing"
        return result

    @builtins.property
    def relative_path(self) -> builtins.str:
        result = self._values.get("relative_path")
        assert result is not None, "Required property 'relative_path' is missing"
        return result

    def __eq__(self, rhs: typing.Any) -> builtins.bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs: typing.Any) -> builtins.bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return "CdnEndpointGeoFilter(%s)" % ", ".join(
            k + "=" + repr(v) for k, v in self._values.items()
        )


@jsii.data_type(
    jsii_type="@cdktf/provider-azurerm.CdnEndpointOrigin",
    jsii_struct_bases=[],
    name_mapping={
        "host_name": "hostName",
        "name": "name",
        "http_port": "httpPort",
        "https_port": "httpsPort",
    },
)
class CdnEndpointOrigin:
    def __init__(
        self,
        *,
        host_name: builtins.str,
        name: builtins.str,
        http_port: typing.Optional[jsii.Number] = None,
        https_port: typing.Optional[jsii.Number] = None,
    ) -> None:
        """
        :param host_name: 
        :param name: 
        :param http_port: 
        :param https_port: 
        """
        self._values: typing.Dict[str, typing.Any] = {
            "host_name": host_name,
            "name": name,
        }
        if http_port is not None:
            self._values["http_port"] = http_port
        if https_port is not None:
            self._values["https_port"] = https_port

    @builtins.property
    def host_name(self) -> builtins.str:
        result = self._values.get("host_name")
        assert result is not None, "Required property 'host_name' is missing"
        return result

    @builtins.property
    def name(self) -> builtins.str:
        result = self._values.get("name")
        assert result is not None, "Required property 'name' is missing"
        return result

    @builtins.property
    def http_port(self) -> typing.Optional[jsii.Number]:
        result = self._values.get("http_port")
        return result

    @builtins.property
    def https_port(self) -> typing.Optional[jsii.Number]:
        result = self._values.get("https_port")
        return result

    def __eq__(self, rhs: typing.Any) -> builtins.bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs: typing.Any) -> builtins.bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return "CdnEndpointOrigin(%s)" % ", ".join(
            k + "=" + repr(v) for k, v in self._values.items()
        )


@jsii.data_type(
    jsii_type="@cdktf/provider-azurerm.CdnEndpointTimeouts",
    jsii_struct_bases=[],
    name_mapping={
        "create": "create",
        "delete": "delete",
        "read": "read",
        "update": "update",
    },
)
class CdnEndpointTimeouts:
    def __init__(
        self,
        *,
        create: typing.Optional[builtins.str] = None,
        delete: typing.Optional[builtins.str] = None,
        read: typing.Optional[builtins.str] = None,
        update: typing.Optional[builtins.str] = None,
    ) -> None:
        """
        :param create: 
        :param delete: 
        :param read: 
        :param update: 
        """
        self._values: typing.Dict[str, typing.Any] = {}
        if create is not None:
            self._values["create"] = create
        if delete is not None:
            self._values["delete"] = delete
        if read is not None:
            self._values["read"] = read
        if update is not None:
            self._values["update"] = update

    @builtins.property
    def create(self) -> typing.Optional[builtins.str]:
        result = self._values.get("create")
        return result

    @builtins.property
    def delete(self) -> typing.Optional[builtins.str]:
        result = self._values.get("delete")
        return result

    @builtins.property
    def read(self) -> typing.Optional[builtins.str]:
        result = self._values.get("read")
        return result

    @builtins.property
    def update(self) -> typing.Optional[builtins.str]:
        result = self._values.get("update")
        return result

    def __eq__(self, rhs: typing.Any) -> builtins.bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs: typing.Any) -> builtins.bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return "CdnEndpointTimeouts(%s)" % ", ".join(
            k + "=" + repr(v) for k, v in self._values.items()
        )


class CdnProfile(
    cdktf.TerraformResource,
    metaclass=jsii.JSIIMeta,
    jsii_type="@cdktf/provider-azurerm.CdnProfile",
):
    def __init__(
        self,
        scope: constructs.Construct,
        id: builtins.str,
        *,
        location: builtins.str,
        name: builtins.str,
        resource_group_name: builtins.str,
        sku: builtins.str,
        tags: typing.Optional[typing.Mapping[builtins.str, builtins.str]] = None,
        timeouts: typing.Optional["CdnProfileTimeouts"] = None,
        count: typing.Optional[jsii.Number] = None,
        depends_on: typing.Optional[typing.List[cdktf.TerraformResource]] = None,
        lifecycle: typing.Optional[cdktf.TerraformResourceLifecycle] = None,
        provider: typing.Optional[cdktf.TerraformProvider] = None,
    ) -> None:
        """
        :param scope: -
        :param id: -
        :param location: 
        :param name: 
        :param resource_group_name: 
        :param sku: 
        :param tags: 
        :param timeouts: timeouts block.
        :param count: 
        :param depends_on: 
        :param lifecycle: 
        :param provider: 
        """
        config = CdnProfileConfig(
            location=location,
            name=name,
            resource_group_name=resource_group_name,
            sku=sku,
            tags=tags,
            timeouts=timeouts,
            count=count,
            depends_on=depends_on,
            lifecycle=lifecycle,
            provider=provider,
        )

        jsii.create(CdnProfile, self, [scope, id, config])

    @jsii.member(jsii_name="synthesizeAttributes")
    def _synthesize_attributes(self) -> typing.Mapping[builtins.str, typing.Any]:
        return jsii.invoke(self, "synthesizeAttributes", [])

    @builtins.property # type: ignore
    @jsii.member(jsii_name="location")
    def location(self) -> builtins.str:
        return jsii.get(self, "location")

    @location.setter # type: ignore
    def location(self, value: builtins.str) -> None:
        jsii.set(self, "location", value)

    @builtins.property # type: ignore
    @jsii.member(jsii_name="name")
    def name(self) -> builtins.str:
        return jsii.get(self, "name")

    @name.setter # type: ignore
    def name(self, value: builtins.str) -> None:
        jsii.set(self, "name", value)

    @builtins.property # type: ignore
    @jsii.member(jsii_name="resourceGroupName")
    def resource_group_name(self) -> builtins.str:
        return jsii.get(self, "resourceGroupName")

    @resource_group_name.setter # type: ignore
    def resource_group_name(self, value: builtins.str) -> None:
        jsii.set(self, "resourceGroupName", value)

    @builtins.property # type: ignore
    @jsii.member(jsii_name="sku")
    def sku(self) -> builtins.str:
        return jsii.get(self, "sku")

    @sku.setter # type: ignore
    def sku(self, value: builtins.str) -> None:
        jsii.set(self, "sku", value)

    @builtins.property # type: ignore
    @jsii.member(jsii_name="id")
    def id(self) -> typing.Optional[builtins.str]:
        return jsii.get(self, "id")

    @id.setter # type: ignore
    def id(self, value: typing.Optional[builtins.str]) -> None:
        jsii.set(self, "id", value)

    @builtins.property # type: ignore
    @jsii.member(jsii_name="tags")
    def tags(self) -> typing.Optional[typing.Mapping[builtins.str, builtins.str]]:
        return jsii.get(self, "tags")

    @tags.setter # type: ignore
    def tags(
        self,
        value: typing.Optional[typing.Mapping[builtins.str, builtins.str]],
    ) -> None:
        jsii.set(self, "tags", value)

    @builtins.property # type: ignore
    @jsii.member(jsii_name="timeouts")
    def timeouts(self) -> typing.Optional["CdnProfileTimeouts"]:
        return jsii.get(self, "timeouts")

    @timeouts.setter # type: ignore
    def timeouts(self, value: typing.Optional["CdnProfileTimeouts"]) -> None:
        jsii.set(self, "timeouts", value)


@jsii.data_type(
    jsii_type="@cdktf/provider-azurerm.CdnProfileConfig",
    jsii_struct_bases=[cdktf.TerraformMetaArguments],
    name_mapping={
        "count": "count",
        "depends_on": "dependsOn",
        "lifecycle": "lifecycle",
        "provider": "provider",
        "location": "location",
        "name": "name",
        "resource_group_name": "resourceGroupName",
        "sku": "sku",
        "tags": "tags",
        "timeouts": "timeouts",
    },
)
class CdnProfileConfig(cdktf.TerraformMetaArguments):
    def __init__(
        self,
        *,
        count: typing.Optional[jsii.Number] = None,
        depends_on: typing.Optional[typing.List[cdktf.TerraformResource]] = None,
        lifecycle: typing.Optional[cdktf.TerraformResourceLifecycle] = None,
        provider: typing.Optional[cdktf.TerraformProvider] = None,
        location: builtins.str,
        name: builtins.str,
        resource_group_name: builtins.str,
        sku: builtins.str,
        tags: typing.Optional[typing.Mapping[builtins.str, builtins.str]] = None,
        timeouts: typing.Optional["CdnProfileTimeouts"] = None,
    ) -> None:
        """
        :param count: 
        :param depends_on: 
        :param lifecycle: 
        :param provider: 
        :param location: 
        :param name: 
        :param resource_group_name: 
        :param sku: 
        :param tags: 
        :param timeouts: timeouts block.
        """
        if isinstance(lifecycle, dict):
            lifecycle = cdktf.TerraformResourceLifecycle(**lifecycle)
        if isinstance(timeouts, dict):
            timeouts = CdnProfileTimeouts(**timeouts)
        self._values: typing.Dict[str, typing.Any] = {
            "location": location,
            "name": name,
            "resource_group_name": resource_group_name,
            "sku": sku,
        }
        if count is not None:
            self._values["count"] = count
        if depends_on is not None:
            self._values["depends_on"] = depends_on
        if lifecycle is not None:
            self._values["lifecycle"] = lifecycle
        if provider is not None:
            self._values["provider"] = provider
        if tags is not None:
            self._values["tags"] = tags
        if timeouts is not None:
            self._values["timeouts"] = timeouts

    @builtins.property
    def count(self) -> typing.Optional[jsii.Number]:
        """
        :stability: experimental
        """
        result = self._values.get("count")
        return result

    @builtins.property
    def depends_on(self) -> typing.Optional[typing.List[cdktf.TerraformResource]]:
        """
        :stability: experimental
        """
        result = self._values.get("depends_on")
        return result

    @builtins.property
    def lifecycle(self) -> typing.Optional[cdktf.TerraformResourceLifecycle]:
        """
        :stability: experimental
        """
        result = self._values.get("lifecycle")
        return result

    @builtins.property
    def provider(self) -> typing.Optional[cdktf.TerraformProvider]:
        """
        :stability: experimental
        """
        result = self._values.get("provider")
        return result

    @builtins.property
    def location(self) -> builtins.str:
        result = self._values.get("location")
        assert result is not None, "Required property 'location' is missing"
        return result

    @builtins.property
    def name(self) -> builtins.str:
        result = self._values.get("name")
        assert result is not None, "Required property 'name' is missing"
        return result

    @builtins.property
    def resource_group_name(self) -> builtins.str:
        result = self._values.get("resource_group_name")
        assert result is not None, "Required property 'resource_group_name' is missing"
        return result

    @builtins.property
    def sku(self) -> builtins.str:
        result = self._values.get("sku")
        assert result is not None, "Required property 'sku' is missing"
        return result

    @builtins.property
    def tags(self) -> typing.Optional[typing.Mapping[builtins.str, builtins.str]]:
        result = self._values.get("tags")
        return result

    @builtins.property
    def timeouts(self) -> typing.Optional["CdnProfileTimeouts"]:
        """timeouts block."""
        result = self._values.get("timeouts")
        return result

    def __eq__(self, rhs: typing.Any) -> builtins.bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs: typing.Any) -> builtins.bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return "CdnProfileConfig(%s)" % ", ".join(
            k + "=" + repr(v) for k, v in self._values.items()
        )


@jsii.data_type(
    jsii_type="@cdktf/provider-azurerm.CdnProfileTimeouts",
    jsii_struct_bases=[],
    name_mapping={
        "create": "create",
        "delete": "delete",
        "read": "read",
        "update": "update",
    },
)
class CdnProfileTimeouts:
    def __init__(
        self,
        *,
        create: typing.Optional[builtins.str] = None,
        delete: typing.Optional[builtins.str] = None,
        read: typing.Optional[builtins.str] = None,
        update: typing.Optional[builtins.str] = None,
    ) -> None:
        """
        :param create: 
        :param delete: 
        :param read: 
        :param update: 
        """
        self._values: typing.Dict[str, typing.Any] = {}
        if create is not None:
            self._values["create"] = create
        if delete is not None:
            self._values["delete"] = delete
        if read is not None:
            self._values["read"] = read
        if update is not None:
            self._values["update"] = update

    @builtins.property
    def create(self) -> typing.Optional[builtins.str]:
        result = self._values.get("create")
        return result

    @builtins.property
    def delete(self) -> typing.Optional[builtins.str]:
        result = self._values.get("delete")
        return result

    @builtins.property
    def read(self) -> typing.Optional[builtins.str]:
        result = self._values.get("read")
        return result

    @builtins.property
    def update(self) -> typing.Optional[builtins.str]:
        result = self._values.get("update")
        return result

    def __eq__(self, rhs: typing.Any) -> builtins.bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs: typing.Any) -> builtins.bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return "CdnProfileTimeouts(%s)" % ", ".join(
            k + "=" + repr(v) for k, v in self._values.items()
        )


class CognitiveAccount(
    cdktf.TerraformResource,
    metaclass=jsii.JSIIMeta,
    jsii_type="@cdktf/provider-azurerm.CognitiveAccount",
):
    def __init__(
        self,
        scope: constructs.Construct,
        id: builtins.str,
        *,
        kind: builtins.str,
        location: builtins.str,
        name: builtins.str,
        resource_group_name: builtins.str,
        sku_name: builtins.str,
        tags: typing.Optional[typing.Mapping[builtins.str, builtins.str]] = None,
        timeouts: typing.Optional["CognitiveAccountTimeouts"] = None,
        count: typing.Optional[jsii.Number] = None,
        depends_on: typing.Optional[typing.List[cdktf.TerraformResource]] = None,
        lifecycle: typing.Optional[cdktf.TerraformResourceLifecycle] = None,
        provider: typing.Optional[cdktf.TerraformProvider] = None,
    ) -> None:
        """
        :param scope: -
        :param id: -
        :param kind: 
        :param location: 
        :param name: 
        :param resource_group_name: 
        :param sku_name: 
        :param tags: 
        :param timeouts: timeouts block.
        :param count: 
        :param depends_on: 
        :param lifecycle: 
        :param provider: 
        """
        config = CognitiveAccountConfig(
            kind=kind,
            location=location,
            name=name,
            resource_group_name=resource_group_name,
            sku_name=sku_name,
            tags=tags,
            timeouts=timeouts,
            count=count,
            depends_on=depends_on,
            lifecycle=lifecycle,
            provider=provider,
        )

        jsii.create(CognitiveAccount, self, [scope, id, config])

    @jsii.member(jsii_name="synthesizeAttributes")
    def _synthesize_attributes(self) -> typing.Mapping[builtins.str, typing.Any]:
        return jsii.invoke(self, "synthesizeAttributes", [])

    @builtins.property # type: ignore
    @jsii.member(jsii_name="endpoint")
    def endpoint(self) -> builtins.str:
        return jsii.get(self, "endpoint")

    @builtins.property # type: ignore
    @jsii.member(jsii_name="primaryAccessKey")
    def primary_access_key(self) -> builtins.str:
        return jsii.get(self, "primaryAccessKey")

    @builtins.property # type: ignore
    @jsii.member(jsii_name="secondaryAccessKey")
    def secondary_access_key(self) -> builtins.str:
        return jsii.get(self, "secondaryAccessKey")

    @builtins.property # type: ignore
    @jsii.member(jsii_name="kind")
    def kind(self) -> builtins.str:
        return jsii.get(self, "kind")

    @kind.setter # type: ignore
    def kind(self, value: builtins.str) -> None:
        jsii.set(self, "kind", value)

    @builtins.property # type: ignore
    @jsii.member(jsii_name="location")
    def location(self) -> builtins.str:
        return jsii.get(self, "location")

    @location.setter # type: ignore
    def location(self, value: builtins.str) -> None:
        jsii.set(self, "location", value)

    @builtins.property # type: ignore
    @jsii.member(jsii_name="name")
    def name(self) -> builtins.str:
        return jsii.get(self, "name")

    @name.setter # type: ignore
    def name(self, value: builtins.str) -> None:
        jsii.set(self, "name", value)

    @builtins.property # type: ignore
    @jsii.member(jsii_name="resourceGroupName")
    def resource_group_name(self) -> builtins.str:
        return jsii.get(self, "resourceGroupName")

    @resource_group_name.setter # type: ignore
    def resource_group_name(self, value: builtins.str) -> None:
        jsii.set(self, "resourceGroupName", value)

    @builtins.property # type: ignore
    @jsii.member(jsii_name="skuName")
    def sku_name(self) -> builtins.str:
        return jsii.get(self, "skuName")

    @sku_name.setter # type: ignore
    def sku_name(self, value: builtins.str) -> None:
        jsii.set(self, "skuName", value)

    @builtins.property # type: ignore
    @jsii.member(jsii_name="id")
    def id(self) -> typing.Optional[builtins.str]:
        return jsii.get(self, "id")

    @id.setter # type: ignore
    def id(self, value: typing.Optional[builtins.str]) -> None:
        jsii.set(self, "id", value)

    @builtins.property # type: ignore
    @jsii.member(jsii_name="tags")
    def tags(self) -> typing.Optional[typing.Mapping[builtins.str, builtins.str]]:
        return jsii.get(self, "tags")

    @tags.setter # type: ignore
    def tags(
        self,
        value: typing.Optional[typing.Mapping[builtins.str, builtins.str]],
    ) -> None:
        jsii.set(self, "tags", value)

    @builtins.property # type: ignore
    @jsii.member(jsii_name="timeouts")
    def timeouts(self) -> typing.Optional["CognitiveAccountTimeouts"]:
        return jsii.get(self, "timeouts")

    @timeouts.setter # type: ignore
    def timeouts(self, value: typing.Optional["CognitiveAccountTimeouts"]) -> None:
        jsii.set(self, "timeouts", value)


@jsii.data_type(
    jsii_type="@cdktf/provider-azurerm.CognitiveAccountConfig",
    jsii_struct_bases=[cdktf.TerraformMetaArguments],
    name_mapping={
        "count": "count",
        "depends_on": "dependsOn",
        "lifecycle": "lifecycle",
        "provider": "provider",
        "kind": "kind",
        "location": "location",
        "name": "name",
        "resource_group_name": "resourceGroupName",
        "sku_name": "skuName",
        "tags": "tags",
        "timeouts": "timeouts",
    },
)
class CognitiveAccountConfig(cdktf.TerraformMetaArguments):
    def __init__(
        self,
        *,
        count: typing.Optional[jsii.Number] = None,
        depends_on: typing.Optional[typing.List[cdktf.TerraformResource]] = None,
        lifecycle: typing.Optional[cdktf.TerraformResourceLifecycle] = None,
        provider: typing.Optional[cdktf.TerraformProvider] = None,
        kind: builtins.str,
        location: builtins.str,
        name: builtins.str,
        resource_group_name: builtins.str,
        sku_name: builtins.str,
        tags: typing.Optional[typing.Mapping[builtins.str, builtins.str]] = None,
        timeouts: typing.Optional["CognitiveAccountTimeouts"] = None,
    ) -> None:
        """
        :param count: 
        :param depends_on: 
        :param lifecycle: 
        :param provider: 
        :param kind: 
        :param location: 
        :param name: 
        :param resource_group_name: 
        :param sku_name: 
        :param tags: 
        :param timeouts: timeouts block.
        """
        if isinstance(lifecycle, dict):
            lifecycle = cdktf.TerraformResourceLifecycle(**lifecycle)
        if isinstance(timeouts, dict):
            timeouts = CognitiveAccountTimeouts(**timeouts)
        self._values: typing.Dict[str, typing.Any] = {
            "kind": kind,
            "location": location,
            "name": name,
            "resource_group_name": resource_group_name,
            "sku_name": sku_name,
        }
        if count is not None:
            self._values["count"] = count
        if depends_on is not None:
            self._values["depends_on"] = depends_on
        if lifecycle is not None:
            self._values["lifecycle"] = lifecycle
        if provider is not None:
            self._values["provider"] = provider
        if tags is not None:
            self._values["tags"] = tags
        if timeouts is not None:
            self._values["timeouts"] = timeouts

    @builtins.property
    def count(self) -> typing.Optional[jsii.Number]:
        """
        :stability: experimental
        """
        result = self._values.get("count")
        return result

    @builtins.property
    def depends_on(self) -> typing.Optional[typing.List[cdktf.TerraformResource]]:
        """
        :stability: experimental
        """
        result = self._values.get("depends_on")
        return result

    @builtins.property
    def lifecycle(self) -> typing.Optional[cdktf.TerraformResourceLifecycle]:
        """
        :stability: experimental
        """
        result = self._values.get("lifecycle")
        return result

    @builtins.property
    def provider(self) -> typing.Optional[cdktf.TerraformProvider]:
        """
        :stability: experimental
        """
        result = self._values.get("provider")
        return result

    @builtins.property
    def kind(self) -> builtins.str:
        result = self._values.get("kind")
        assert result is not None, "Required property 'kind' is missing"
        return result

    @builtins.property
    def location(self) -> builtins.str:
        result = self._values.get("location")
        assert result is not None, "Required property 'location' is missing"
        return result

    @builtins.property
    def name(self) -> builtins.str:
        result = self._values.get("name")
        assert result is not None, "Required property 'name' is missing"
        return result

    @builtins.property
    def resource_group_name(self) -> builtins.str:
        result = self._values.get("resource_group_name")
        assert result is not None, "Required property 'resource_group_name' is missing"
        return result

    @builtins.property
    def sku_name(self) -> builtins.str:
        result = self._values.get("sku_name")
        assert result is not None, "Required property 'sku_name' is missing"
        return result

    @builtins.property
    def tags(self) -> typing.Optional[typing.Mapping[builtins.str, builtins.str]]:
        result = self._values.get("tags")
        return result

    @builtins.property
    def timeouts(self) -> typing.Optional["CognitiveAccountTimeouts"]:
        """timeouts block."""
        result = self._values.get("timeouts")
        return result

    def __eq__(self, rhs: typing.Any) -> builtins.bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs: typing.Any) -> builtins.bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return "CognitiveAccountConfig(%s)" % ", ".join(
            k + "=" + repr(v) for k, v in self._values.items()
        )


@jsii.data_type(
    jsii_type="@cdktf/provider-azurerm.CognitiveAccountTimeouts",
    jsii_struct_bases=[],
    name_mapping={
        "create": "create",
        "delete": "delete",
        "read": "read",
        "update": "update",
    },
)
class CognitiveAccountTimeouts:
    def __init__(
        self,
        *,
        create: typing.Optional[builtins.str] = None,
        delete: typing.Optional[builtins.str] = None,
        read: typing.Optional[builtins.str] = None,
        update: typing.Optional[builtins.str] = None,
    ) -> None:
        """
        :param create: 
        :param delete: 
        :param read: 
        :param update: 
        """
        self._values: typing.Dict[str, typing.Any] = {}
        if create is not None:
            self._values["create"] = create
        if delete is not None:
            self._values["delete"] = delete
        if read is not None:
            self._values["read"] = read
        if update is not None:
            self._values["update"] = update

    @builtins.property
    def create(self) -> typing.Optional[builtins.str]:
        result = self._values.get("create")
        return result

    @builtins.property
    def delete(self) -> typing.Optional[builtins.str]:
        result = self._values.get("delete")
        return result

    @builtins.property
    def read(self) -> typing.Optional[builtins.str]:
        result = self._values.get("read")
        return result

    @builtins.property
    def update(self) -> typing.Optional[builtins.str]:
        result = self._values.get("update")
        return result

    def __eq__(self, rhs: typing.Any) -> builtins.bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs: typing.Any) -> builtins.bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return "CognitiveAccountTimeouts(%s)" % ", ".join(
            k + "=" + repr(v) for k, v in self._values.items()
        )


class ContainerGroup(
    cdktf.TerraformResource,
    metaclass=jsii.JSIIMeta,
    jsii_type="@cdktf/provider-azurerm.ContainerGroup",
):
    def __init__(
        self,
        scope: constructs.Construct,
        id: builtins.str,
        *,
        container: typing.List["ContainerGroupContainer"],
        location: builtins.str,
        name: builtins.str,
        os_type: builtins.str,
        resource_group_name: builtins.str,
        diagnostics: typing.Optional[typing.List["ContainerGroupDiagnostics"]] = None,
        dns_name_label: typing.Optional[builtins.str] = None,
        identity: typing.Optional[typing.List["ContainerGroupIdentity"]] = None,
        image_registry_credential: typing.Optional[typing.List["ContainerGroupImageRegistryCredential"]] = None,
        ip_address_type: typing.Optional[builtins.str] = None,
        network_profile_id: typing.Optional[builtins.str] = None,
        restart_policy: typing.Optional[builtins.str] = None,
        tags: typing.Optional[typing.Mapping[builtins.str, builtins.str]] = None,
        timeouts: typing.Optional["ContainerGroupTimeouts"] = None,
        count: typing.Optional[jsii.Number] = None,
        depends_on: typing.Optional[typing.List[cdktf.TerraformResource]] = None,
        lifecycle: typing.Optional[cdktf.TerraformResourceLifecycle] = None,
        provider: typing.Optional[cdktf.TerraformProvider] = None,
    ) -> None:
        """
        :param scope: -
        :param id: -
        :param container: container block.
        :param location: 
        :param name: 
        :param os_type: 
        :param resource_group_name: 
        :param diagnostics: diagnostics block.
        :param dns_name_label: 
        :param identity: identity block.
        :param image_registry_credential: image_registry_credential block.
        :param ip_address_type: 
        :param network_profile_id: 
        :param restart_policy: 
        :param tags: 
        :param timeouts: timeouts block.
        :param count: 
        :param depends_on: 
        :param lifecycle: 
        :param provider: 
        """
        config = ContainerGroupConfig(
            container=container,
            location=location,
            name=name,
            os_type=os_type,
            resource_group_name=resource_group_name,
            diagnostics=diagnostics,
            dns_name_label=dns_name_label,
            identity=identity,
            image_registry_credential=image_registry_credential,
            ip_address_type=ip_address_type,
            network_profile_id=network_profile_id,
            restart_policy=restart_policy,
            tags=tags,
            timeouts=timeouts,
            count=count,
            depends_on=depends_on,
            lifecycle=lifecycle,
            provider=provider,
        )

        jsii.create(ContainerGroup, self, [scope, id, config])

    @jsii.member(jsii_name="synthesizeAttributes")
    def _synthesize_attributes(self) -> typing.Mapping[builtins.str, typing.Any]:
        return jsii.invoke(self, "synthesizeAttributes", [])

    @builtins.property # type: ignore
    @jsii.member(jsii_name="fqdn")
    def fqdn(self) -> builtins.str:
        return jsii.get(self, "fqdn")

    @builtins.property # type: ignore
    @jsii.member(jsii_name="ipAddress")
    def ip_address(self) -> builtins.str:
        return jsii.get(self, "ipAddress")

    @builtins.property # type: ignore
    @jsii.member(jsii_name="container")
    def container(self) -> typing.List["ContainerGroupContainer"]:
        return jsii.get(self, "container")

    @container.setter # type: ignore
    def container(self, value: typing.List["ContainerGroupContainer"]) -> None:
        jsii.set(self, "container", value)

    @builtins.property # type: ignore
    @jsii.member(jsii_name="location")
    def location(self) -> builtins.str:
        return jsii.get(self, "location")

    @location.setter # type: ignore
    def location(self, value: builtins.str) -> None:
        jsii.set(self, "location", value)

    @builtins.property # type: ignore
    @jsii.member(jsii_name="name")
    def name(self) -> builtins.str:
        return jsii.get(self, "name")

    @name.setter # type: ignore
    def name(self, value: builtins.str) -> None:
        jsii.set(self, "name", value)

    @builtins.property # type: ignore
    @jsii.member(jsii_name="osType")
    def os_type(self) -> builtins.str:
        return jsii.get(self, "osType")

    @os_type.setter # type: ignore
    def os_type(self, value: builtins.str) -> None:
        jsii.set(self, "osType", value)

    @builtins.property # type: ignore
    @jsii.member(jsii_name="resourceGroupName")
    def resource_group_name(self) -> builtins.str:
        return jsii.get(self, "resourceGroupName")

    @resource_group_name.setter # type: ignore
    def resource_group_name(self, value: builtins.str) -> None:
        jsii.set(self, "resourceGroupName", value)

    @builtins.property # type: ignore
    @jsii.member(jsii_name="diagnostics")
    def diagnostics(self) -> typing.Optional[typing.List["ContainerGroupDiagnostics"]]:
        return jsii.get(self, "diagnostics")

    @diagnostics.setter # type: ignore
    def diagnostics(
        self,
        value: typing.Optional[typing.List["ContainerGroupDiagnostics"]],
    ) -> None:
        jsii.set(self, "diagnostics", value)

    @builtins.property # type: ignore
    @jsii.member(jsii_name="dnsNameLabel")
    def dns_name_label(self) -> typing.Optional[builtins.str]:
        return jsii.get(self, "dnsNameLabel")

    @dns_name_label.setter # type: ignore
    def dns_name_label(self, value: typing.Optional[builtins.str]) -> None:
        jsii.set(self, "dnsNameLabel", value)

    @builtins.property # type: ignore
    @jsii.member(jsii_name="id")
    def id(self) -> typing.Optional[builtins.str]:
        return jsii.get(self, "id")

    @id.setter # type: ignore
    def id(self, value: typing.Optional[builtins.str]) -> None:
        jsii.set(self, "id", value)

    @builtins.property # type: ignore
    @jsii.member(jsii_name="identity")
    def identity(self) -> typing.Optional[typing.List["ContainerGroupIdentity"]]:
        return jsii.get(self, "identity")

    @identity.setter # type: ignore
    def identity(
        self,
        value: typing.Optional[typing.List["ContainerGroupIdentity"]],
    ) -> None:
        jsii.set(self, "identity", value)

    @builtins.property # type: ignore
    @jsii.member(jsii_name="imageRegistryCredential")
    def image_registry_credential(
        self,
    ) -> typing.Optional[typing.List["ContainerGroupImageRegistryCredential"]]:
        return jsii.get(self, "imageRegistryCredential")

    @image_registry_credential.setter # type: ignore
    def image_registry_credential(
        self,
        value: typing.Optional[typing.List["ContainerGroupImageRegistryCredential"]],
    ) -> None:
        jsii.set(self, "imageRegistryCredential", value)

    @builtins.property # type: ignore
    @jsii.member(jsii_name="ipAddressType")
    def ip_address_type(self) -> typing.Optional[builtins.str]:
        return jsii.get(self, "ipAddressType")

    @ip_address_type.setter # type: ignore
    def ip_address_type(self, value: typing.Optional[builtins.str]) -> None:
        jsii.set(self, "ipAddressType", value)

    @builtins.property # type: ignore
    @jsii.member(jsii_name="networkProfileId")
    def network_profile_id(self) -> typing.Optional[builtins.str]:
        return jsii.get(self, "networkProfileId")

    @network_profile_id.setter # type: ignore
    def network_profile_id(self, value: typing.Optional[builtins.str]) -> None:
        jsii.set(self, "networkProfileId", value)

    @builtins.property # type: ignore
    @jsii.member(jsii_name="restartPolicy")
    def restart_policy(self) -> typing.Optional[builtins.str]:
        return jsii.get(self, "restartPolicy")

    @restart_policy.setter # type: ignore
    def restart_policy(self, value: typing.Optional[builtins.str]) -> None:
        jsii.set(self, "restartPolicy", value)

    @builtins.property # type: ignore
    @jsii.member(jsii_name="tags")
    def tags(self) -> typing.Optional[typing.Mapping[builtins.str, builtins.str]]:
        return jsii.get(self, "tags")

    @tags.setter # type: ignore
    def tags(
        self,
        value: typing.Optional[typing.Mapping[builtins.str, builtins.str]],
    ) -> None:
        jsii.set(self, "tags", value)

    @builtins.property # type: ignore
    @jsii.member(jsii_name="timeouts")
    def timeouts(self) -> typing.Optional["ContainerGroupTimeouts"]:
        return jsii.get(self, "timeouts")

    @timeouts.setter # type: ignore
    def timeouts(self, value: typing.Optional["ContainerGroupTimeouts"]) -> None:
        jsii.set(self, "timeouts", value)


@jsii.data_type(
    jsii_type="@cdktf/provider-azurerm.ContainerGroupConfig",
    jsii_struct_bases=[cdktf.TerraformMetaArguments],
    name_mapping={
        "count": "count",
        "depends_on": "dependsOn",
        "lifecycle": "lifecycle",
        "provider": "provider",
        "container": "container",
        "location": "location",
        "name": "name",
        "os_type": "osType",
        "resource_group_name": "resourceGroupName",
        "diagnostics": "diagnostics",
        "dns_name_label": "dnsNameLabel",
        "identity": "identity",
        "image_registry_credential": "imageRegistryCredential",
        "ip_address_type": "ipAddressType",
        "network_profile_id": "networkProfileId",
        "restart_policy": "restartPolicy",
        "tags": "tags",
        "timeouts": "timeouts",
    },
)
class ContainerGroupConfig(cdktf.TerraformMetaArguments):
    def __init__(
        self,
        *,
        count: typing.Optional[jsii.Number] = None,
        depends_on: typing.Optional[typing.List[cdktf.TerraformResource]] = None,
        lifecycle: typing.Optional[cdktf.TerraformResourceLifecycle] = None,
        provider: typing.Optional[cdktf.TerraformProvider] = None,
        container: typing.List["ContainerGroupContainer"],
        location: builtins.str,
        name: builtins.str,
        os_type: builtins.str,
        resource_group_name: builtins.str,
        diagnostics: typing.Optional[typing.List["ContainerGroupDiagnostics"]] = None,
        dns_name_label: typing.Optional[builtins.str] = None,
        identity: typing.Optional[typing.List["ContainerGroupIdentity"]] = None,
        image_registry_credential: typing.Optional[typing.List["ContainerGroupImageRegistryCredential"]] = None,
        ip_address_type: typing.Optional[builtins.str] = None,
        network_profile_id: typing.Optional[builtins.str] = None,
        restart_policy: typing.Optional[builtins.str] = None,
        tags: typing.Optional[typing.Mapping[builtins.str, builtins.str]] = None,
        timeouts: typing.Optional["ContainerGroupTimeouts"] = None,
    ) -> None:
        """
        :param count: 
        :param depends_on: 
        :param lifecycle: 
        :param provider: 
        :param container: container block.
        :param location: 
        :param name: 
        :param os_type: 
        :param resource_group_name: 
        :param diagnostics: diagnostics block.
        :param dns_name_label: 
        :param identity: identity block.
        :param image_registry_credential: image_registry_credential block.
        :param ip_address_type: 
        :param network_profile_id: 
        :param restart_policy: 
        :param tags: 
        :param timeouts: timeouts block.
        """
        if isinstance(lifecycle, dict):
            lifecycle = cdktf.TerraformResourceLifecycle(**lifecycle)
        if isinstance(timeouts, dict):
            timeouts = ContainerGroupTimeouts(**timeouts)
        self._values: typing.Dict[str, typing.Any] = {
            "container": container,
            "location": location,
            "name": name,
            "os_type": os_type,
            "resource_group_name": resource_group_name,
        }
        if count is not None:
            self._values["count"] = count
        if depends_on is not None:
            self._values["depends_on"] = depends_on
        if lifecycle is not None:
            self._values["lifecycle"] = lifecycle
        if provider is not None:
            self._values["provider"] = provider
        if diagnostics is not None:
            self._values["diagnostics"] = diagnostics
        if dns_name_label is not None:
            self._values["dns_name_label"] = dns_name_label
        if identity is not None:
            self._values["identity"] = identity
        if image_registry_credential is not None:
            self._values["image_registry_credential"] = image_registry_credential
        if ip_address_type is not None:
            self._values["ip_address_type"] = ip_address_type
        if network_profile_id is not None:
            self._values["network_profile_id"] = network_profile_id
        if restart_policy is not None:
            self._values["restart_policy"] = restart_policy
        if tags is not None:
            self._values["tags"] = tags
        if timeouts is not None:
            self._values["timeouts"] = timeouts

    @builtins.property
    def count(self) -> typing.Optional[jsii.Number]:
        """
        :stability: experimental
        """
        result = self._values.get("count")
        return result

    @builtins.property
    def depends_on(self) -> typing.Optional[typing.List[cdktf.TerraformResource]]:
        """
        :stability: experimental
        """
        result = self._values.get("depends_on")
        return result

    @builtins.property
    def lifecycle(self) -> typing.Optional[cdktf.TerraformResourceLifecycle]:
        """
        :stability: experimental
        """
        result = self._values.get("lifecycle")
        return result

    @builtins.property
    def provider(self) -> typing.Optional[cdktf.TerraformProvider]:
        """
        :stability: experimental
        """
        result = self._values.get("provider")
        return result

    @builtins.property
    def container(self) -> typing.List["ContainerGroupContainer"]:
        """container block."""
        result = self._values.get("container")
        assert result is not None, "Required property 'container' is missing"
        return result

    @builtins.property
    def location(self) -> builtins.str:
        result = self._values.get("location")
        assert result is not None, "Required property 'location' is missing"
        return result

    @builtins.property
    def name(self) -> builtins.str:
        result = self._values.get("name")
        assert result is not None, "Required property 'name' is missing"
        return result

    @builtins.property
    def os_type(self) -> builtins.str:
        result = self._values.get("os_type")
        assert result is not None, "Required property 'os_type' is missing"
        return result

    @builtins.property
    def resource_group_name(self) -> builtins.str:
        result = self._values.get("resource_group_name")
        assert result is not None, "Required property 'resource_group_name' is missing"
        return result

    @builtins.property
    def diagnostics(self) -> typing.Optional[typing.List["ContainerGroupDiagnostics"]]:
        """diagnostics block."""
        result = self._values.get("diagnostics")
        return result

    @builtins.property
    def dns_name_label(self) -> typing.Optional[builtins.str]:
        result = self._values.get("dns_name_label")
        return result

    @builtins.property
    def identity(self) -> typing.Optional[typing.List["ContainerGroupIdentity"]]:
        """identity block."""
        result = self._values.get("identity")
        return result

    @builtins.property
    def image_registry_credential(
        self,
    ) -> typing.Optional[typing.List["ContainerGroupImageRegistryCredential"]]:
        """image_registry_credential block."""
        result = self._values.get("image_registry_credential")
        return result

    @builtins.property
    def ip_address_type(self) -> typing.Optional[builtins.str]:
        result = self._values.get("ip_address_type")
        return result

    @builtins.property
    def network_profile_id(self) -> typing.Optional[builtins.str]:
        result = self._values.get("network_profile_id")
        return result

    @builtins.property
    def restart_policy(self) -> typing.Optional[builtins.str]:
        result = self._values.get("restart_policy")
        return result

    @builtins.property
    def tags(self) -> typing.Optional[typing.Mapping[builtins.str, builtins.str]]:
        result = self._values.get("tags")
        return result

    @builtins.property
    def timeouts(self) -> typing.Optional["ContainerGroupTimeouts"]:
        """timeouts block."""
        result = self._values.get("timeouts")
        return result

    def __eq__(self, rhs: typing.Any) -> builtins.bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs: typing.Any) -> builtins.bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return "ContainerGroupConfig(%s)" % ", ".join(
            k + "=" + repr(v) for k, v in self._values.items()
        )


@jsii.data_type(
    jsii_type="@cdktf/provider-azurerm.ContainerGroupContainer",
    jsii_struct_bases=[],
    name_mapping={
        "cpu": "cpu",
        "image": "image",
        "memory": "memory",
        "name": "name",
        "commands": "commands",
        "environment_variables": "environmentVariables",
        "gpu": "gpu",
        "liveness_probe": "livenessProbe",
        "ports": "ports",
        "readiness_probe": "readinessProbe",
        "secure_environment_variables": "secureEnvironmentVariables",
        "volume": "volume",
    },
)
class ContainerGroupContainer:
    def __init__(
        self,
        *,
        cpu: jsii.Number,
        image: builtins.str,
        memory: jsii.Number,
        name: builtins.str,
        commands: typing.Optional[typing.List[builtins.str]] = None,
        environment_variables: typing.Optional[typing.Mapping[builtins.str, builtins.str]] = None,
        gpu: typing.Optional[typing.List["ContainerGroupContainerGpu"]] = None,
        liveness_probe: typing.Optional[typing.List["ContainerGroupContainerLivenessProbe"]] = None,
        ports: typing.Optional[typing.List["ContainerGroupContainerPorts"]] = None,
        readiness_probe: typing.Optional[typing.List["ContainerGroupContainerReadinessProbe"]] = None,
        secure_environment_variables: typing.Optional[typing.Mapping[builtins.str, builtins.str]] = None,
        volume: typing.Optional[typing.List["ContainerGroupContainerVolume"]] = None,
    ) -> None:
        """
        :param cpu: 
        :param image: 
        :param memory: 
        :param name: 
        :param commands: 
        :param environment_variables: 
        :param gpu: gpu block.
        :param liveness_probe: liveness_probe block.
        :param ports: ports block.
        :param readiness_probe: readiness_probe block.
        :param secure_environment_variables: 
        :param volume: volume block.
        """
        self._values: typing.Dict[str, typing.Any] = {
            "cpu": cpu,
            "image": image,
            "memory": memory,
            "name": name,
        }
        if commands is not None:
            self._values["commands"] = commands
        if environment_variables is not None:
            self._values["environment_variables"] = environment_variables
        if gpu is not None:
            self._values["gpu"] = gpu
        if liveness_probe is not None:
            self._values["liveness_probe"] = liveness_probe
        if ports is not None:
            self._values["ports"] = ports
        if readiness_probe is not None:
            self._values["readiness_probe"] = readiness_probe
        if secure_environment_variables is not None:
            self._values["secure_environment_variables"] = secure_environment_variables
        if volume is not None:
            self._values["volume"] = volume

    @builtins.property
    def cpu(self) -> jsii.Number:
        result = self._values.get("cpu")
        assert result is not None, "Required property 'cpu' is missing"
        return result

    @builtins.property
    def image(self) -> builtins.str:
        result = self._values.get("image")
        assert result is not None, "Required property 'image' is missing"
        return result

    @builtins.property
    def memory(self) -> jsii.Number:
        result = self._values.get("memory")
        assert result is not None, "Required property 'memory' is missing"
        return result

    @builtins.property
    def name(self) -> builtins.str:
        result = self._values.get("name")
        assert result is not None, "Required property 'name' is missing"
        return result

    @builtins.property
    def commands(self) -> typing.Optional[typing.List[builtins.str]]:
        result = self._values.get("commands")
        return result

    @builtins.property
    def environment_variables(
        self,
    ) -> typing.Optional[typing.Mapping[builtins.str, builtins.str]]:
        result = self._values.get("environment_variables")
        return result

    @builtins.property
    def gpu(self) -> typing.Optional[typing.List["ContainerGroupContainerGpu"]]:
        """gpu block."""
        result = self._values.get("gpu")
        return result

    @builtins.property
    def liveness_probe(
        self,
    ) -> typing.Optional[typing.List["ContainerGroupContainerLivenessProbe"]]:
        """liveness_probe block."""
        result = self._values.get("liveness_probe")
        return result

    @builtins.property
    def ports(self) -> typing.Optional[typing.List["ContainerGroupContainerPorts"]]:
        """ports block."""
        result = self._values.get("ports")
        return result

    @builtins.property
    def readiness_probe(
        self,
    ) -> typing.Optional[typing.List["ContainerGroupContainerReadinessProbe"]]:
        """readiness_probe block."""
        result = self._values.get("readiness_probe")
        return result

    @builtins.property
    def secure_environment_variables(
        self,
    ) -> typing.Optional[typing.Mapping[builtins.str, builtins.str]]:
        result = self._values.get("secure_environment_variables")
        return result

    @builtins.property
    def volume(self) -> typing.Optional[typing.List["ContainerGroupContainerVolume"]]:
        """volume block."""
        result = self._values.get("volume")
        return result

    def __eq__(self, rhs: typing.Any) -> builtins.bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs: typing.Any) -> builtins.bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return "ContainerGroupContainer(%s)" % ", ".join(
            k + "=" + repr(v) for k, v in self._values.items()
        )


@jsii.data_type(
    jsii_type="@cdktf/provider-azurerm.ContainerGroupContainerGpu",
    jsii_struct_bases=[],
    name_mapping={"count": "count", "sku": "sku"},
)
class ContainerGroupContainerGpu:
    def __init__(
        self,
        *,
        count: typing.Optional[jsii.Number] = None,
        sku: typing.Optional[builtins.str] = None,
    ) -> None:
        """
        :param count: 
        :param sku: 
        """
        self._values: typing.Dict[str, typing.Any] = {}
        if count is not None:
            self._values["count"] = count
        if sku is not None:
            self._values["sku"] = sku

    @builtins.property
    def count(self) -> typing.Optional[jsii.Number]:
        result = self._values.get("count")
        return result

    @builtins.property
    def sku(self) -> typing.Optional[builtins.str]:
        result = self._values.get("sku")
        return result

    def __eq__(self, rhs: typing.Any) -> builtins.bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs: typing.Any) -> builtins.bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return "ContainerGroupContainerGpu(%s)" % ", ".join(
            k + "=" + repr(v) for k, v in self._values.items()
        )


@jsii.data_type(
    jsii_type="@cdktf/provider-azurerm.ContainerGroupContainerLivenessProbe",
    jsii_struct_bases=[],
    name_mapping={
        "exec": "exec",
        "failure_threshold": "failureThreshold",
        "http_get": "httpGet",
        "initial_delay_seconds": "initialDelaySeconds",
        "period_seconds": "periodSeconds",
        "success_threshold": "successThreshold",
        "timeout_seconds": "timeoutSeconds",
    },
)
class ContainerGroupContainerLivenessProbe:
    def __init__(
        self,
        *,
        exec: typing.Optional[typing.List[builtins.str]] = None,
        failure_threshold: typing.Optional[jsii.Number] = None,
        http_get: typing.Optional[typing.List["ContainerGroupContainerLivenessProbeHttpGet"]] = None,
        initial_delay_seconds: typing.Optional[jsii.Number] = None,
        period_seconds: typing.Optional[jsii.Number] = None,
        success_threshold: typing.Optional[jsii.Number] = None,
        timeout_seconds: typing.Optional[jsii.Number] = None,
    ) -> None:
        """
        :param exec: 
        :param failure_threshold: 
        :param http_get: http_get block.
        :param initial_delay_seconds: 
        :param period_seconds: 
        :param success_threshold: 
        :param timeout_seconds: 
        """
        self._values: typing.Dict[str, typing.Any] = {}
        if exec is not None:
            self._values["exec"] = exec
        if failure_threshold is not None:
            self._values["failure_threshold"] = failure_threshold
        if http_get is not None:
            self._values["http_get"] = http_get
        if initial_delay_seconds is not None:
            self._values["initial_delay_seconds"] = initial_delay_seconds
        if period_seconds is not None:
            self._values["period_seconds"] = period_seconds
        if success_threshold is not None:
            self._values["success_threshold"] = success_threshold
        if timeout_seconds is not None:
            self._values["timeout_seconds"] = timeout_seconds

    @builtins.property
    def exec(self) -> typing.Optional[typing.List[builtins.str]]:
        result = self._values.get("exec")
        return result

    @builtins.property
    def failure_threshold(self) -> typing.Optional[jsii.Number]:
        result = self._values.get("failure_threshold")
        return result

    @builtins.property
    def http_get(
        self,
    ) -> typing.Optional[typing.List["ContainerGroupContainerLivenessProbeHttpGet"]]:
        """http_get block."""
        result = self._values.get("http_get")
        return result

    @builtins.property
    def initial_delay_seconds(self) -> typing.Optional[jsii.Number]:
        result = self._values.get("initial_delay_seconds")
        return result

    @builtins.property
    def period_seconds(self) -> typing.Optional[jsii.Number]:
        result = self._values.get("period_seconds")
        return result

    @builtins.property
    def success_threshold(self) -> typing.Optional[jsii.Number]:
        result = self._values.get("success_threshold")
        return result

    @builtins.property
    def timeout_seconds(self) -> typing.Optional[jsii.Number]:
        result = self._values.get("timeout_seconds")
        return result

    def __eq__(self, rhs: typing.Any) -> builtins.bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs: typing.Any) -> builtins.bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return "ContainerGroupContainerLivenessProbe(%s)" % ", ".join(
            k + "=" + repr(v) for k, v in self._values.items()
        )


@jsii.data_type(
    jsii_type="@cdktf/provider-azurerm.ContainerGroupContainerLivenessProbeHttpGet",
    jsii_struct_bases=[],
    name_mapping={"path": "path", "port": "port", "scheme": "scheme"},
)
class ContainerGroupContainerLivenessProbeHttpGet:
    def __init__(
        self,
        *,
        path: typing.Optional[builtins.str] = None,
        port: typing.Optional[jsii.Number] = None,
        scheme: typing.Optional[builtins.str] = None,
    ) -> None:
        """
        :param path: 
        :param port: 
        :param scheme: 
        """
        self._values: typing.Dict[str, typing.Any] = {}
        if path is not None:
            self._values["path"] = path
        if port is not None:
            self._values["port"] = port
        if scheme is not None:
            self._values["scheme"] = scheme

    @builtins.property
    def path(self) -> typing.Optional[builtins.str]:
        result = self._values.get("path")
        return result

    @builtins.property
    def port(self) -> typing.Optional[jsii.Number]:
        result = self._values.get("port")
        return result

    @builtins.property
    def scheme(self) -> typing.Optional[builtins.str]:
        result = self._values.get("scheme")
        return result

    def __eq__(self, rhs: typing.Any) -> builtins.bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs: typing.Any) -> builtins.bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return "ContainerGroupContainerLivenessProbeHttpGet(%s)" % ", ".join(
            k + "=" + repr(v) for k, v in self._values.items()
        )


@jsii.data_type(
    jsii_type="@cdktf/provider-azurerm.ContainerGroupContainerPorts",
    jsii_struct_bases=[],
    name_mapping={"port": "port", "protocol": "protocol"},
)
class ContainerGroupContainerPorts:
    def __init__(
        self,
        *,
        port: typing.Optional[jsii.Number] = None,
        protocol: typing.Optional[builtins.str] = None,
    ) -> None:
        """
        :param port: 
        :param protocol: 
        """
        self._values: typing.Dict[str, typing.Any] = {}
        if port is not None:
            self._values["port"] = port
        if protocol is not None:
            self._values["protocol"] = protocol

    @builtins.property
    def port(self) -> typing.Optional[jsii.Number]:
        result = self._values.get("port")
        return result

    @builtins.property
    def protocol(self) -> typing.Optional[builtins.str]:
        result = self._values.get("protocol")
        return result

    def __eq__(self, rhs: typing.Any) -> builtins.bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs: typing.Any) -> builtins.bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return "ContainerGroupContainerPorts(%s)" % ", ".join(
            k + "=" + repr(v) for k, v in self._values.items()
        )


@jsii.data_type(
    jsii_type="@cdktf/provider-azurerm.ContainerGroupContainerReadinessProbe",
    jsii_struct_bases=[],
    name_mapping={
        "exec": "exec",
        "failure_threshold": "failureThreshold",
        "http_get": "httpGet",
        "initial_delay_seconds": "initialDelaySeconds",
        "period_seconds": "periodSeconds",
        "success_threshold": "successThreshold",
        "timeout_seconds": "timeoutSeconds",
    },
)
class ContainerGroupContainerReadinessProbe:
    def __init__(
        self,
        *,
        exec: typing.Optional[typing.List[builtins.str]] = None,
        failure_threshold: typing.Optional[jsii.Number] = None,
        http_get: typing.Optional[typing.List["ContainerGroupContainerReadinessProbeHttpGet"]] = None,
        initial_delay_seconds: typing.Optional[jsii.Number] = None,
        period_seconds: typing.Optional[jsii.Number] = None,
        success_threshold: typing.Optional[jsii.Number] = None,
        timeout_seconds: typing.Optional[jsii.Number] = None,
    ) -> None:
        """
        :param exec: 
        :param failure_threshold: 
        :param http_get: http_get block.
        :param initial_delay_seconds: 
        :param period_seconds: 
        :param success_threshold: 
        :param timeout_seconds: 
        """
        self._values: typing.Dict[str, typing.Any] = {}
        if exec is not None:
            self._values["exec"] = exec
        if failure_threshold is not None:
            self._values["failure_threshold"] = failure_threshold
        if http_get is not None:
            self._values["http_get"] = http_get
        if initial_delay_seconds is not None:
            self._values["initial_delay_seconds"] = initial_delay_seconds
        if period_seconds is not None:
            self._values["period_seconds"] = period_seconds
        if success_threshold is not None:
            self._values["success_threshold"] = success_threshold
        if timeout_seconds is not None:
            self._values["timeout_seconds"] = timeout_seconds

    @builtins.property
    def exec(self) -> typing.Optional[typing.List[builtins.str]]:
        result = self._values.get("exec")
        return result

    @builtins.property
    def failure_threshold(self) -> typing.Optional[jsii.Number]:
        result = self._values.get("failure_threshold")
        return result

    @builtins.property
    def http_get(
        self,
    ) -> typing.Optional[typing.List["ContainerGroupContainerReadinessProbeHttpGet"]]:
        """http_get block."""
        result = self._values.get("http_get")
        return result

    @builtins.property
    def initial_delay_seconds(self) -> typing.Optional[jsii.Number]:
        result = self._values.get("initial_delay_seconds")
        return result

    @builtins.property
    def period_seconds(self) -> typing.Optional[jsii.Number]:
        result = self._values.get("period_seconds")
        return result

    @builtins.property
    def success_threshold(self) -> typing.Optional[jsii.Number]:
        result = self._values.get("success_threshold")
        return result

    @builtins.property
    def timeout_seconds(self) -> typing.Optional[jsii.Number]:
        result = self._values.get("timeout_seconds")
        return result

    def __eq__(self, rhs: typing.Any) -> builtins.bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs: typing.Any) -> builtins.bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return "ContainerGroupContainerReadinessProbe(%s)" % ", ".join(
            k + "=" + repr(v) for k, v in self._values.items()
        )


@jsii.data_type(
    jsii_type="@cdktf/provider-azurerm.ContainerGroupContainerReadinessProbeHttpGet",
    jsii_struct_bases=[],
    name_mapping={"path": "path", "port": "port", "scheme": "scheme"},
)
class ContainerGroupContainerReadinessProbeHttpGet:
    def __init__(
        self,
        *,
        path: typing.Optional[builtins.str] = None,
        port: typing.Optional[jsii.Number] = None,
        scheme: typing.Optional[builtins.str] = None,
    ) -> None:
        """
        :param path: 
        :param port: 
        :param scheme: 
        """
        self._values: typing.Dict[str, typing.Any] = {}
        if path is not None:
            self._values["path"] = path
        if port is not None:
            self._values["port"] = port
        if scheme is not None:
            self._values["scheme"] = scheme

    @builtins.property
    def path(self) -> typing.Optional[builtins.str]:
        result = self._values.get("path")
        return result

    @builtins.property
    def port(self) -> typing.Optional[jsii.Number]:
        result = self._values.get("port")
        return result

    @builtins.property
    def scheme(self) -> typing.Optional[builtins.str]:
        result = self._values.get("scheme")
        return result

    def __eq__(self, rhs: typing.Any) -> builtins.bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs: typing.Any) -> builtins.bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return "ContainerGroupContainerReadinessProbeHttpGet(%s)" % ", ".join(
            k + "=" + repr(v) for k, v in self._values.items()
        )


@jsii.data_type(
    jsii_type="@cdktf/provider-azurerm.ContainerGroupContainerVolume",
    jsii_struct_bases=[],
    name_mapping={
        "mount_path": "mountPath",
        "name": "name",
        "share_name": "shareName",
        "storage_account_key": "storageAccountKey",
        "storage_account_name": "storageAccountName",
        "read_only": "readOnly",
    },
)
class ContainerGroupContainerVolume:
    def __init__(
        self,
        *,
        mount_path: builtins.str,
        name: builtins.str,
        share_name: builtins.str,
        storage_account_key: builtins.str,
        storage_account_name: builtins.str,
        read_only: typing.Optional[builtins.bool] = None,
    ) -> None:
        """
        :param mount_path: 
        :param name: 
        :param share_name: 
        :param storage_account_key: 
        :param storage_account_name: 
        :param read_only: 
        """
        self._values: typing.Dict[str, typing.Any] = {
            "mount_path": mount_path,
            "name": name,
            "share_name": share_name,
            "storage_account_key": storage_account_key,
            "storage_account_name": storage_account_name,
        }
        if read_only is not None:
            self._values["read_only"] = read_only

    @builtins.property
    def mount_path(self) -> builtins.str:
        result = self._values.get("mount_path")
        assert result is not None, "Required property 'mount_path' is missing"
        return result

    @builtins.property
    def name(self) -> builtins.str:
        result = self._values.get("name")
        assert result is not None, "Required property 'name' is missing"
        return result

    @builtins.property
    def share_name(self) -> builtins.str:
        result = self._values.get("share_name")
        assert result is not None, "Required property 'share_name' is missing"
        return result

    @builtins.property
    def storage_account_key(self) -> builtins.str:
        result = self._values.get("storage_account_key")
        assert result is not None, "Required property 'storage_account_key' is missing"
        return result

    @builtins.property
    def storage_account_name(self) -> builtins.str:
        result = self._values.get("storage_account_name")
        assert result is not None, "Required property 'storage_account_name' is missing"
        return result

    @builtins.property
    def read_only(self) -> typing.Optional[builtins.bool]:
        result = self._values.get("read_only")
        return result

    def __eq__(self, rhs: typing.Any) -> builtins.bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs: typing.Any) -> builtins.bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return "ContainerGroupContainerVolume(%s)" % ", ".join(
            k + "=" + repr(v) for k, v in self._values.items()
        )


@jsii.data_type(
    jsii_type="@cdktf/provider-azurerm.ContainerGroupDiagnostics",
    jsii_struct_bases=[],
    name_mapping={"log_analytics": "logAnalytics"},
)
class ContainerGroupDiagnostics:
    def __init__(
        self,
        *,
        log_analytics: typing.List["ContainerGroupDiagnosticsLogAnalytics"],
    ) -> None:
        """
        :param log_analytics: log_analytics block.
        """
        self._values: typing.Dict[str, typing.Any] = {
            "log_analytics": log_analytics,
        }

    @builtins.property
    def log_analytics(self) -> typing.List["ContainerGroupDiagnosticsLogAnalytics"]:
        """log_analytics block."""
        result = self._values.get("log_analytics")
        assert result is not None, "Required property 'log_analytics' is missing"
        return result

    def __eq__(self, rhs: typing.Any) -> builtins.bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs: typing.Any) -> builtins.bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return "ContainerGroupDiagnostics(%s)" % ", ".join(
            k + "=" + repr(v) for k, v in self._values.items()
        )


@jsii.data_type(
    jsii_type="@cdktf/provider-azurerm.ContainerGroupDiagnosticsLogAnalytics",
    jsii_struct_bases=[],
    name_mapping={
        "workspace_id": "workspaceId",
        "workspace_key": "workspaceKey",
        "log_type": "logType",
        "metadata": "metadata",
    },
)
class ContainerGroupDiagnosticsLogAnalytics:
    def __init__(
        self,
        *,
        workspace_id: builtins.str,
        workspace_key: builtins.str,
        log_type: typing.Optional[builtins.str] = None,
        metadata: typing.Optional[typing.Mapping[builtins.str, builtins.str]] = None,
    ) -> None:
        """
        :param workspace_id: 
        :param workspace_key: 
        :param log_type: 
        :param metadata: 
        """
        self._values: typing.Dict[str, typing.Any] = {
            "workspace_id": workspace_id,
            "workspace_key": workspace_key,
        }
        if log_type is not None:
            self._values["log_type"] = log_type
        if metadata is not None:
            self._values["metadata"] = metadata

    @builtins.property
    def workspace_id(self) -> builtins.str:
        result = self._values.get("workspace_id")
        assert result is not None, "Required property 'workspace_id' is missing"
        return result

    @builtins.property
    def workspace_key(self) -> builtins.str:
        result = self._values.get("workspace_key")
        assert result is not None, "Required property 'workspace_key' is missing"
        return result

    @builtins.property
    def log_type(self) -> typing.Optional[builtins.str]:
        result = self._values.get("log_type")
        return result

    @builtins.property
    def metadata(self) -> typing.Optional[typing.Mapping[builtins.str, builtins.str]]:
        result = self._values.get("metadata")
        return result

    def __eq__(self, rhs: typing.Any) -> builtins.bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs: typing.Any) -> builtins.bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return "ContainerGroupDiagnosticsLogAnalytics(%s)" % ", ".join(
            k + "=" + repr(v) for k, v in self._values.items()
        )


@jsii.data_type(
    jsii_type="@cdktf/provider-azurerm.ContainerGroupIdentity",
    jsii_struct_bases=[],
    name_mapping={"type": "type", "identity_ids": "identityIds"},
)
class ContainerGroupIdentity:
    def __init__(
        self,
        *,
        type: builtins.str,
        identity_ids: typing.Optional[typing.List[builtins.str]] = None,
    ) -> None:
        """
        :param type: 
        :param identity_ids: 
        """
        self._values: typing.Dict[str, typing.Any] = {
            "type": type,
        }
        if identity_ids is not None:
            self._values["identity_ids"] = identity_ids

    @builtins.property
    def type(self) -> builtins.str:
        result = self._values.get("type")
        assert result is not None, "Required property 'type' is missing"
        return result

    @builtins.property
    def identity_ids(self) -> typing.Optional[typing.List[builtins.str]]:
        result = self._values.get("identity_ids")
        return result

    def __eq__(self, rhs: typing.Any) -> builtins.bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs: typing.Any) -> builtins.bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return "ContainerGroupIdentity(%s)" % ", ".join(
            k + "=" + repr(v) for k, v in self._values.items()
        )


@jsii.data_type(
    jsii_type="@cdktf/provider-azurerm.ContainerGroupImageRegistryCredential",
    jsii_struct_bases=[],
    name_mapping={"password": "password", "server": "server", "username": "username"},
)
class ContainerGroupImageRegistryCredential:
    def __init__(
        self,
        *,
        password: builtins.str,
        server: builtins.str,
        username: builtins.str,
    ) -> None:
        """
        :param password: 
        :param server: 
        :param username: 
        """
        self._values: typing.Dict[str, typing.Any] = {
            "password": password,
            "server": server,
            "username": username,
        }

    @builtins.property
    def password(self) -> builtins.str:
        result = self._values.get("password")
        assert result is not None, "Required property 'password' is missing"
        return result

    @builtins.property
    def server(self) -> builtins.str:
        result = self._values.get("server")
        assert result is not None, "Required property 'server' is missing"
        return result

    @builtins.property
    def username(self) -> builtins.str:
        result = self._values.get("username")
        assert result is not None, "Required property 'username' is missing"
        return result

    def __eq__(self, rhs: typing.Any) -> builtins.bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs: typing.Any) -> builtins.bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return "ContainerGroupImageRegistryCredential(%s)" % ", ".join(
            k + "=" + repr(v) for k, v in self._values.items()
        )


@jsii.data_type(
    jsii_type="@cdktf/provider-azurerm.ContainerGroupTimeouts",
    jsii_struct_bases=[],
    name_mapping={
        "create": "create",
        "delete": "delete",
        "read": "read",
        "update": "update",
    },
)
class ContainerGroupTimeouts:
    def __init__(
        self,
        *,
        create: typing.Optional[builtins.str] = None,
        delete: typing.Optional[builtins.str] = None,
        read: typing.Optional[builtins.str] = None,
        update: typing.Optional[builtins.str] = None,
    ) -> None:
        """
        :param create: 
        :param delete: 
        :param read: 
        :param update: 
        """
        self._values: typing.Dict[str, typing.Any] = {}
        if create is not None:
            self._values["create"] = create
        if delete is not None:
            self._values["delete"] = delete
        if read is not None:
            self._values["read"] = read
        if update is not None:
            self._values["update"] = update

    @builtins.property
    def create(self) -> typing.Optional[builtins.str]:
        result = self._values.get("create")
        return result

    @builtins.property
    def delete(self) -> typing.Optional[builtins.str]:
        result = self._values.get("delete")
        return result

    @builtins.property
    def read(self) -> typing.Optional[builtins.str]:
        result = self._values.get("read")
        return result

    @builtins.property
    def update(self) -> typing.Optional[builtins.str]:
        result = self._values.get("update")
        return result

    def __eq__(self, rhs: typing.Any) -> builtins.bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs: typing.Any) -> builtins.bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return "ContainerGroupTimeouts(%s)" % ", ".join(
            k + "=" + repr(v) for k, v in self._values.items()
        )


class ContainerRegistry(
    cdktf.TerraformResource,
    metaclass=jsii.JSIIMeta,
    jsii_type="@cdktf/provider-azurerm.ContainerRegistry",
):
    def __init__(
        self,
        scope: constructs.Construct,
        id: builtins.str,
        *,
        location: builtins.str,
        name: builtins.str,
        resource_group_name: builtins.str,
        admin_enabled: typing.Optional[builtins.bool] = None,
        georeplication_locations: typing.Optional[typing.List[builtins.str]] = None,
        network_rule_set: typing.Optional[typing.List["ContainerRegistryNetworkRuleSet"]] = None,
        sku: typing.Optional[builtins.str] = None,
        storage_account_id: typing.Optional[builtins.str] = None,
        tags: typing.Optional[typing.Mapping[builtins.str, builtins.str]] = None,
        timeouts: typing.Optional["ContainerRegistryTimeouts"] = None,
        count: typing.Optional[jsii.Number] = None,
        depends_on: typing.Optional[typing.List[cdktf.TerraformResource]] = None,
        lifecycle: typing.Optional[cdktf.TerraformResourceLifecycle] = None,
        provider: typing.Optional[cdktf.TerraformProvider] = None,
    ) -> None:
        """
        :param scope: -
        :param id: -
        :param location: 
        :param name: 
        :param resource_group_name: 
        :param admin_enabled: 
        :param georeplication_locations: 
        :param network_rule_set: 
        :param sku: 
        :param storage_account_id: 
        :param tags: 
        :param timeouts: timeouts block.
        :param count: 
        :param depends_on: 
        :param lifecycle: 
        :param provider: 
        """
        config = ContainerRegistryConfig(
            location=location,
            name=name,
            resource_group_name=resource_group_name,
            admin_enabled=admin_enabled,
            georeplication_locations=georeplication_locations,
            network_rule_set=network_rule_set,
            sku=sku,
            storage_account_id=storage_account_id,
            tags=tags,
            timeouts=timeouts,
            count=count,
            depends_on=depends_on,
            lifecycle=lifecycle,
            provider=provider,
        )

        jsii.create(ContainerRegistry, self, [scope, id, config])

    @jsii.member(jsii_name="synthesizeAttributes")
    def _synthesize_attributes(self) -> typing.Mapping[builtins.str, typing.Any]:
        return jsii.invoke(self, "synthesizeAttributes", [])

    @builtins.property # type: ignore
    @jsii.member(jsii_name="adminPassword")
    def admin_password(self) -> builtins.str:
        return jsii.get(self, "adminPassword")

    @builtins.property # type: ignore
    @jsii.member(jsii_name="adminUsername")
    def admin_username(self) -> builtins.str:
        return jsii.get(self, "adminUsername")

    @builtins.property # type: ignore
    @jsii.member(jsii_name="loginServer")
    def login_server(self) -> builtins.str:
        return jsii.get(self, "loginServer")

    @builtins.property # type: ignore
    @jsii.member(jsii_name="location")
    def location(self) -> builtins.str:
        return jsii.get(self, "location")

    @location.setter # type: ignore
    def location(self, value: builtins.str) -> None:
        jsii.set(self, "location", value)

    @builtins.property # type: ignore
    @jsii.member(jsii_name="name")
    def name(self) -> builtins.str:
        return jsii.get(self, "name")

    @name.setter # type: ignore
    def name(self, value: builtins.str) -> None:
        jsii.set(self, "name", value)

    @builtins.property # type: ignore
    @jsii.member(jsii_name="resourceGroupName")
    def resource_group_name(self) -> builtins.str:
        return jsii.get(self, "resourceGroupName")

    @resource_group_name.setter # type: ignore
    def resource_group_name(self, value: builtins.str) -> None:
        jsii.set(self, "resourceGroupName", value)

    @builtins.property # type: ignore
    @jsii.member(jsii_name="adminEnabled")
    def admin_enabled(self) -> typing.Optional[builtins.bool]:
        return jsii.get(self, "adminEnabled")

    @admin_enabled.setter # type: ignore
    def admin_enabled(self, value: typing.Optional[builtins.bool]) -> None:
        jsii.set(self, "adminEnabled", value)

    @builtins.property # type: ignore
    @jsii.member(jsii_name="georeplicationLocations")
    def georeplication_locations(self) -> typing.Optional[typing.List[builtins.str]]:
        return jsii.get(self, "georeplicationLocations")

    @georeplication_locations.setter # type: ignore
    def georeplication_locations(
        self,
        value: typing.Optional[typing.List[builtins.str]],
    ) -> None:
        jsii.set(self, "georeplicationLocations", value)

    @builtins.property # type: ignore
    @jsii.member(jsii_name="id")
    def id(self) -> typing.Optional[builtins.str]:
        return jsii.get(self, "id")

    @id.setter # type: ignore
    def id(self, value: typing.Optional[builtins.str]) -> None:
        jsii.set(self, "id", value)

    @builtins.property # type: ignore
    @jsii.member(jsii_name="networkRuleSet")
    def network_rule_set(
        self,
    ) -> typing.Optional[typing.List["ContainerRegistryNetworkRuleSet"]]:
        return jsii.get(self, "networkRuleSet")

    @network_rule_set.setter # type: ignore
    def network_rule_set(
        self,
        value: typing.Optional[typing.List["ContainerRegistryNetworkRuleSet"]],
    ) -> None:
        jsii.set(self, "networkRuleSet", value)

    @builtins.property # type: ignore
    @jsii.member(jsii_name="sku")
    def sku(self) -> typing.Optional[builtins.str]:
        return jsii.get(self, "sku")

    @sku.setter # type: ignore
    def sku(self, value: typing.Optional[builtins.str]) -> None:
        jsii.set(self, "sku", value)

    @builtins.property # type: ignore
    @jsii.member(jsii_name="storageAccountId")
    def storage_account_id(self) -> typing.Optional[builtins.str]:
        return jsii.get(self, "storageAccountId")

    @storage_account_id.setter # type: ignore
    def storage_account_id(self, value: typing.Optional[builtins.str]) -> None:
        jsii.set(self, "storageAccountId", value)

    @builtins.property # type: ignore
    @jsii.member(jsii_name="tags")
    def tags(self) -> typing.Optional[typing.Mapping[builtins.str, builtins.str]]:
        return jsii.get(self, "tags")

    @tags.setter # type: ignore
    def tags(
        self,
        value: typing.Optional[typing.Mapping[builtins.str, builtins.str]],
    ) -> None:
        jsii.set(self, "tags", value)

    @builtins.property # type: ignore
    @jsii.member(jsii_name="timeouts")
    def timeouts(self) -> typing.Optional["ContainerRegistryTimeouts"]:
        return jsii.get(self, "timeouts")

    @timeouts.setter # type: ignore
    def timeouts(self, value: typing.Optional["ContainerRegistryTimeouts"]) -> None:
        jsii.set(self, "timeouts", value)


@jsii.data_type(
    jsii_type="@cdktf/provider-azurerm.ContainerRegistryConfig",
    jsii_struct_bases=[cdktf.TerraformMetaArguments],
    name_mapping={
        "count": "count",
        "depends_on": "dependsOn",
        "lifecycle": "lifecycle",
        "provider": "provider",
        "location": "location",
        "name": "name",
        "resource_group_name": "resourceGroupName",
        "admin_enabled": "adminEnabled",
        "georeplication_locations": "georeplicationLocations",
        "network_rule_set": "networkRuleSet",
        "sku": "sku",
        "storage_account_id": "storageAccountId",
        "tags": "tags",
        "timeouts": "timeouts",
    },
)
class ContainerRegistryConfig(cdktf.TerraformMetaArguments):
    def __init__(
        self,
        *,
        count: typing.Optional[jsii.Number] = None,
        depends_on: typing.Optional[typing.List[cdktf.TerraformResource]] = None,
        lifecycle: typing.Optional[cdktf.TerraformResourceLifecycle] = None,
        provider: typing.Optional[cdktf.TerraformProvider] = None,
        location: builtins.str,
        name: builtins.str,
        resource_group_name: builtins.str,
        admin_enabled: typing.Optional[builtins.bool] = None,
        georeplication_locations: typing.Optional[typing.List[builtins.str]] = None,
        network_rule_set: typing.Optional[typing.List["ContainerRegistryNetworkRuleSet"]] = None,
        sku: typing.Optional[builtins.str] = None,
        storage_account_id: typing.Optional[builtins.str] = None,
        tags: typing.Optional[typing.Mapping[builtins.str, builtins.str]] = None,
        timeouts: typing.Optional["ContainerRegistryTimeouts"] = None,
    ) -> None:
        """
        :param count: 
        :param depends_on: 
        :param lifecycle: 
        :param provider: 
        :param location: 
        :param name: 
        :param resource_group_name: 
        :param admin_enabled: 
        :param georeplication_locations: 
        :param network_rule_set: 
        :param sku: 
        :param storage_account_id: 
        :param tags: 
        :param timeouts: timeouts block.
        """
        if isinstance(lifecycle, dict):
            lifecycle = cdktf.TerraformResourceLifecycle(**lifecycle)
        if isinstance(timeouts, dict):
            timeouts = ContainerRegistryTimeouts(**timeouts)
        self._values: typing.Dict[str, typing.Any] = {
            "location": location,
            "name": name,
            "resource_group_name": resource_group_name,
        }
        if count is not None:
            self._values["count"] = count
        if depends_on is not None:
            self._values["depends_on"] = depends_on
        if lifecycle is not None:
            self._values["lifecycle"] = lifecycle
        if provider is not None:
            self._values["provider"] = provider
        if admin_enabled is not None:
            self._values["admin_enabled"] = admin_enabled
        if georeplication_locations is not None:
            self._values["georeplication_locations"] = georeplication_locations
        if network_rule_set is not None:
            self._values["network_rule_set"] = network_rule_set
        if sku is not None:
            self._values["sku"] = sku
        if storage_account_id is not None:
            self._values["storage_account_id"] = storage_account_id
        if tags is not None:
            self._values["tags"] = tags
        if timeouts is not None:
            self._values["timeouts"] = timeouts

    @builtins.property
    def count(self) -> typing.Optional[jsii.Number]:
        """
        :stability: experimental
        """
        result = self._values.get("count")
        return result

    @builtins.property
    def depends_on(self) -> typing.Optional[typing.List[cdktf.TerraformResource]]:
        """
        :stability: experimental
        """
        result = self._values.get("depends_on")
        return result

    @builtins.property
    def lifecycle(self) -> typing.Optional[cdktf.TerraformResourceLifecycle]:
        """
        :stability: experimental
        """
        result = self._values.get("lifecycle")
        return result

    @builtins.property
    def provider(self) -> typing.Optional[cdktf.TerraformProvider]:
        """
        :stability: experimental
        """
        result = self._values.get("provider")
        return result

    @builtins.property
    def location(self) -> builtins.str:
        result = self._values.get("location")
        assert result is not None, "Required property 'location' is missing"
        return result

    @builtins.property
    def name(self) -> builtins.str:
        result = self._values.get("name")
        assert result is not None, "Required property 'name' is missing"
        return result

    @builtins.property
    def resource_group_name(self) -> builtins.str:
        result = self._values.get("resource_group_name")
        assert result is not None, "Required property 'resource_group_name' is missing"
        return result

    @builtins.property
    def admin_enabled(self) -> typing.Optional[builtins.bool]:
        result = self._values.get("admin_enabled")
        return result

    @builtins.property
    def georeplication_locations(self) -> typing.Optional[typing.List[builtins.str]]:
        result = self._values.get("georeplication_locations")
        return result

    @builtins.property
    def network_rule_set(
        self,
    ) -> typing.Optional[typing.List["ContainerRegistryNetworkRuleSet"]]:
        result = self._values.get("network_rule_set")
        return result

    @builtins.property
    def sku(self) -> typing.Optional[builtins.str]:
        result = self._values.get("sku")
        return result

    @builtins.property
    def storage_account_id(self) -> typing.Optional[builtins.str]:
        result = self._values.get("storage_account_id")
        return result

    @builtins.property
    def tags(self) -> typing.Optional[typing.Mapping[builtins.str, builtins.str]]:
        result = self._values.get("tags")
        return result

    @builtins.property
    def timeouts(self) -> typing.Optional["ContainerRegistryTimeouts"]:
        """timeouts block."""
        result = self._values.get("timeouts")
        return result

    def __eq__(self, rhs: typing.Any) -> builtins.bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs: typing.Any) -> builtins.bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return "ContainerRegistryConfig(%s)" % ", ".join(
            k + "=" + repr(v) for k, v in self._values.items()
        )


@jsii.data_type(
    jsii_type="@cdktf/provider-azurerm.ContainerRegistryNetworkRuleSet",
    jsii_struct_bases=[],
    name_mapping={
        "default_action": "defaultAction",
        "ip_rule": "ipRule",
        "virtual_network": "virtualNetwork",
    },
)
class ContainerRegistryNetworkRuleSet:
    def __init__(
        self,
        *,
        default_action: typing.Optional[builtins.str] = None,
        ip_rule: typing.Optional[typing.List["ContainerRegistryNetworkRuleSetIpRule"]] = None,
        virtual_network: typing.Optional[typing.List["ContainerRegistryNetworkRuleSetVirtualNetwork"]] = None,
    ) -> None:
        """
        :param default_action: 
        :param ip_rule: 
        :param virtual_network: 
        """
        self._values: typing.Dict[str, typing.Any] = {}
        if default_action is not None:
            self._values["default_action"] = default_action
        if ip_rule is not None:
            self._values["ip_rule"] = ip_rule
        if virtual_network is not None:
            self._values["virtual_network"] = virtual_network

    @builtins.property
    def default_action(self) -> typing.Optional[builtins.str]:
        result = self._values.get("default_action")
        return result

    @builtins.property
    def ip_rule(
        self,
    ) -> typing.Optional[typing.List["ContainerRegistryNetworkRuleSetIpRule"]]:
        result = self._values.get("ip_rule")
        return result

    @builtins.property
    def virtual_network(
        self,
    ) -> typing.Optional[typing.List["ContainerRegistryNetworkRuleSetVirtualNetwork"]]:
        result = self._values.get("virtual_network")
        return result

    def __eq__(self, rhs: typing.Any) -> builtins.bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs: typing.Any) -> builtins.bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return "ContainerRegistryNetworkRuleSet(%s)" % ", ".join(
            k + "=" + repr(v) for k, v in self._values.items()
        )


@jsii.data_type(
    jsii_type="@cdktf/provider-azurerm.ContainerRegistryNetworkRuleSetIpRule",
    jsii_struct_bases=[],
    name_mapping={"action": "action", "ip_range": "ipRange"},
)
class ContainerRegistryNetworkRuleSetIpRule:
    def __init__(
        self,
        *,
        action: typing.Optional[builtins.str] = None,
        ip_range: typing.Optional[builtins.str] = None,
    ) -> None:
        """
        :param action: 
        :param ip_range: 
        """
        self._values: typing.Dict[str, typing.Any] = {}
        if action is not None:
            self._values["action"] = action
        if ip_range is not None:
            self._values["ip_range"] = ip_range

    @builtins.property
    def action(self) -> typing.Optional[builtins.str]:
        result = self._values.get("action")
        return result

    @builtins.property
    def ip_range(self) -> typing.Optional[builtins.str]:
        result = self._values.get("ip_range")
        return result

    def __eq__(self, rhs: typing.Any) -> builtins.bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs: typing.Any) -> builtins.bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return "ContainerRegistryNetworkRuleSetIpRule(%s)" % ", ".join(
            k + "=" + repr(v) for k, v in self._values.items()
        )


@jsii.data_type(
    jsii_type="@cdktf/provider-azurerm.ContainerRegistryNetworkRuleSetVirtualNetwork",
    jsii_struct_bases=[],
    name_mapping={"action": "action", "subnet_id": "subnetId"},
)
class ContainerRegistryNetworkRuleSetVirtualNetwork:
    def __init__(
        self,
        *,
        action: typing.Optional[builtins.str] = None,
        subnet_id: typing.Optional[builtins.str] = None,
    ) -> None:
        """
        :param action: 
        :param subnet_id: 
        """
        self._values: typing.Dict[str, typing.Any] = {}
        if action is not None:
            self._values["action"] = action
        if subnet_id is not None:
            self._values["subnet_id"] = subnet_id

    @builtins.property
    def action(self) -> typing.Optional[builtins.str]:
        result = self._values.get("action")
        return result

    @builtins.property
    def subnet_id(self) -> typing.Optional[builtins.str]:
        result = self._values.get("subnet_id")
        return result

    def __eq__(self, rhs: typing.Any) -> builtins.bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs: typing.Any) -> builtins.bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return "ContainerRegistryNetworkRuleSetVirtualNetwork(%s)" % ", ".join(
            k + "=" + repr(v) for k, v in self._values.items()
        )


@jsii.data_type(
    jsii_type="@cdktf/provider-azurerm.ContainerRegistryTimeouts",
    jsii_struct_bases=[],
    name_mapping={
        "create": "create",
        "delete": "delete",
        "read": "read",
        "update": "update",
    },
)
class ContainerRegistryTimeouts:
    def __init__(
        self,
        *,
        create: typing.Optional[builtins.str] = None,
        delete: typing.Optional[builtins.str] = None,
        read: typing.Optional[builtins.str] = None,
        update: typing.Optional[builtins.str] = None,
    ) -> None:
        """
        :param create: 
        :param delete: 
        :param read: 
        :param update: 
        """
        self._values: typing.Dict[str, typing.Any] = {}
        if create is not None:
            self._values["create"] = create
        if delete is not None:
            self._values["delete"] = delete
        if read is not None:
            self._values["read"] = read
        if update is not None:
            self._values["update"] = update

    @builtins.property
    def create(self) -> typing.Optional[builtins.str]:
        result = self._values.get("create")
        return result

    @builtins.property
    def delete(self) -> typing.Optional[builtins.str]:
        result = self._values.get("delete")
        return result

    @builtins.property
    def read(self) -> typing.Optional[builtins.str]:
        result = self._values.get("read")
        return result

    @builtins.property
    def update(self) -> typing.Optional[builtins.str]:
        result = self._values.get("update")
        return result

    def __eq__(self, rhs: typing.Any) -> builtins.bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs: typing.Any) -> builtins.bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return "ContainerRegistryTimeouts(%s)" % ", ".join(
            k + "=" + repr(v) for k, v in self._values.items()
        )


class ContainerRegistryWebhook(
    cdktf.TerraformResource,
    metaclass=jsii.JSIIMeta,
    jsii_type="@cdktf/provider-azurerm.ContainerRegistryWebhook",
):
    def __init__(
        self,
        scope_: constructs.Construct,
        id: builtins.str,
        *,
        actions: typing.List[builtins.str],
        location: builtins.str,
        name: builtins.str,
        registry_name: builtins.str,
        resource_group_name: builtins.str,
        service_uri: builtins.str,
        custom_headers: typing.Optional[typing.Mapping[builtins.str, builtins.str]] = None,
        scope: typing.Optional[builtins.str] = None,
        status: typing.Optional[builtins.str] = None,
        tags: typing.Optional[typing.Mapping[builtins.str, builtins.str]] = None,
        timeouts: typing.Optional["ContainerRegistryWebhookTimeouts"] = None,
        count: typing.Optional[jsii.Number] = None,
        depends_on: typing.Optional[typing.List[cdktf.TerraformResource]] = None,
        lifecycle: typing.Optional[cdktf.TerraformResourceLifecycle] = None,
        provider: typing.Optional[cdktf.TerraformProvider] = None,
    ) -> None:
        """
        :param scope_: -
        :param id: -
        :param actions: 
        :param location: 
        :param name: 
        :param registry_name: 
        :param resource_group_name: 
        :param service_uri: 
        :param custom_headers: 
        :param scope: 
        :param status: 
        :param tags: 
        :param timeouts: timeouts block.
        :param count: 
        :param depends_on: 
        :param lifecycle: 
        :param provider: 
        """
        config = ContainerRegistryWebhookConfig(
            actions=actions,
            location=location,
            name=name,
            registry_name=registry_name,
            resource_group_name=resource_group_name,
            service_uri=service_uri,
            custom_headers=custom_headers,
            scope=scope,
            status=status,
            tags=tags,
            timeouts=timeouts,
            count=count,
            depends_on=depends_on,
            lifecycle=lifecycle,
            provider=provider,
        )

        jsii.create(ContainerRegistryWebhook, self, [scope_, id, config])

    @jsii.member(jsii_name="synthesizeAttributes")
    def _synthesize_attributes(self) -> typing.Mapping[builtins.str, typing.Any]:
        return jsii.invoke(self, "synthesizeAttributes", [])

    @builtins.property # type: ignore
    @jsii.member(jsii_name="actions")
    def actions(self) -> typing.List[builtins.str]:
        return jsii.get(self, "actions")

    @actions.setter # type: ignore
    def actions(self, value: typing.List[builtins.str]) -> None:
        jsii.set(self, "actions", value)

    @builtins.property # type: ignore
    @jsii.member(jsii_name="location")
    def location(self) -> builtins.str:
        return jsii.get(self, "location")

    @location.setter # type: ignore
    def location(self, value: builtins.str) -> None:
        jsii.set(self, "location", value)

    @builtins.property # type: ignore
    @jsii.member(jsii_name="name")
    def name(self) -> builtins.str:
        return jsii.get(self, "name")

    @name.setter # type: ignore
    def name(self, value: builtins.str) -> None:
        jsii.set(self, "name", value)

    @builtins.property # type: ignore
    @jsii.member(jsii_name="registryName")
    def registry_name(self) -> builtins.str:
        return jsii.get(self, "registryName")

    @registry_name.setter # type: ignore
    def registry_name(self, value: builtins.str) -> None:
        jsii.set(self, "registryName", value)

    @builtins.property # type: ignore
    @jsii.member(jsii_name="resourceGroupName")
    def resource_group_name(self) -> builtins.str:
        return jsii.get(self, "resourceGroupName")

    @resource_group_name.setter # type: ignore
    def resource_group_name(self, value: builtins.str) -> None:
        jsii.set(self, "resourceGroupName", value)

    @builtins.property # type: ignore
    @jsii.member(jsii_name="serviceUri")
    def service_uri(self) -> builtins.str:
        return jsii.get(self, "serviceUri")

    @service_uri.setter # type: ignore
    def service_uri(self, value: builtins.str) -> None:
        jsii.set(self, "serviceUri", value)

    @builtins.property # type: ignore
    @jsii.member(jsii_name="customHeaders")
    def custom_headers(
        self,
    ) -> typing.Optional[typing.Mapping[builtins.str, builtins.str]]:
        return jsii.get(self, "customHeaders")

    @custom_headers.setter # type: ignore
    def custom_headers(
        self,
        value: typing.Optional[typing.Mapping[builtins.str, builtins.str]],
    ) -> None:
        jsii.set(self, "customHeaders", value)

    @builtins.property # type: ignore
    @jsii.member(jsii_name="id")
    def id(self) -> typing.Optional[builtins.str]:
        return jsii.get(self, "id")

    @id.setter # type: ignore
    def id(self, value: typing.Optional[builtins.str]) -> None:
        jsii.set(self, "id", value)

    @builtins.property # type: ignore
    @jsii.member(jsii_name="scope")
    def scope(self) -> typing.Optional[builtins.str]:
        return jsii.get(self, "scope")

    @scope.setter # type: ignore
    def scope(self, value: typing.Optional[builtins.str]) -> None:
        jsii.set(self, "scope", value)

    @builtins.property # type: ignore
    @jsii.member(jsii_name="status")
    def status(self) -> typing.Optional[builtins.str]:
        return jsii.get(self, "status")

    @status.setter # type: ignore
    def status(self, value: typing.Optional[builtins.str]) -> None:
        jsii.set(self, "status", value)

    @builtins.property # type: ignore
    @jsii.member(jsii_name="tags")
    def tags(self) -> typing.Optional[typing.Mapping[builtins.str, builtins.str]]:
        return jsii.get(self, "tags")

    @tags.setter # type: ignore
    def tags(
        self,
        value: typing.Optional[typing.Mapping[builtins.str, builtins.str]],
    ) -> None:
        jsii.set(self, "tags", value)

    @builtins.property # type: ignore
    @jsii.member(jsii_name="timeouts")
    def timeouts(self) -> typing.Optional["ContainerRegistryWebhookTimeouts"]:
        return jsii.get(self, "timeouts")

    @timeouts.setter # type: ignore
    def timeouts(
        self,
        value: typing.Optional["ContainerRegistryWebhookTimeouts"],
    ) -> None:
        jsii.set(self, "timeouts", value)


@jsii.data_type(
    jsii_type="@cdktf/provider-azurerm.ContainerRegistryWebhookConfig",
    jsii_struct_bases=[cdktf.TerraformMetaArguments],
    name_mapping={
        "count": "count",
        "depends_on": "dependsOn",
        "lifecycle": "lifecycle",
        "provider": "provider",
        "actions": "actions",
        "location": "location",
        "name": "name",
        "registry_name": "registryName",
        "resource_group_name": "resourceGroupName",
        "service_uri": "serviceUri",
        "custom_headers": "customHeaders",
        "scope": "scope",
        "status": "status",
        "tags": "tags",
        "timeouts": "timeouts",
    },
)
class ContainerRegistryWebhookConfig(cdktf.TerraformMetaArguments):
    def __init__(
        self,
        *,
        count: typing.Optional[jsii.Number] = None,
        depends_on: typing.Optional[typing.List[cdktf.TerraformResource]] = None,
        lifecycle: typing.Optional[cdktf.TerraformResourceLifecycle] = None,
        provider: typing.Optional[cdktf.TerraformProvider] = None,
        actions: typing.List[builtins.str],
        location: builtins.str,
        name: builtins.str,
        registry_name: builtins.str,
        resource_group_name: builtins.str,
        service_uri: builtins.str,
        custom_headers: typing.Optional[typing.Mapping[builtins.str, builtins.str]] = None,
        scope: typing.Optional[builtins.str] = None,
        status: typing.Optional[builtins.str] = None,
        tags: typing.Optional[typing.Mapping[builtins.str, builtins.str]] = None,
        timeouts: typing.Optional["ContainerRegistryWebhookTimeouts"] = None,
    ) -> None:
        """
        :param count: 
        :param depends_on: 
        :param lifecycle: 
        :param provider: 
        :param actions: 
        :param location: 
        :param name: 
        :param registry_name: 
        :param resource_group_name: 
        :param service_uri: 
        :param custom_headers: 
        :param scope: 
        :param status: 
        :param tags: 
        :param timeouts: timeouts block.
        """
        if isinstance(lifecycle, dict):
            lifecycle = cdktf.TerraformResourceLifecycle(**lifecycle)
        if isinstance(timeouts, dict):
            timeouts = ContainerRegistryWebhookTimeouts(**timeouts)
        self._values: typing.Dict[str, typing.Any] = {
            "actions": actions,
            "location": location,
            "name": name,
            "registry_name": registry_name,
            "resource_group_name": resource_group_name,
            "service_uri": service_uri,
        }
        if count is not None:
            self._values["count"] = count
        if depends_on is not None:
            self._values["depends_on"] = depends_on
        if lifecycle is not None:
            self._values["lifecycle"] = lifecycle
        if provider is not None:
            self._values["provider"] = provider
        if custom_headers is not None:
            self._values["custom_headers"] = custom_headers
        if scope is not None:
            self._values["scope"] = scope
        if status is not None:
            self._values["status"] = status
        if tags is not None:
            self._values["tags"] = tags
        if timeouts is not None:
            self._values["timeouts"] = timeouts

    @builtins.property
    def count(self) -> typing.Optional[jsii.Number]:
        """
        :stability: experimental
        """
        result = self._values.get("count")
        return result

    @builtins.property
    def depends_on(self) -> typing.Optional[typing.List[cdktf.TerraformResource]]:
        """
        :stability: experimental
        """
        result = self._values.get("depends_on")
        return result

    @builtins.property
    def lifecycle(self) -> typing.Optional[cdktf.TerraformResourceLifecycle]:
        """
        :stability: experimental
        """
        result = self._values.get("lifecycle")
        return result

    @builtins.property
    def provider(self) -> typing.Optional[cdktf.TerraformProvider]:
        """
        :stability: experimental
        """
        result = self._values.get("provider")
        return result

    @builtins.property
    def actions(self) -> typing.List[builtins.str]:
        result = self._values.get("actions")
        assert result is not None, "Required property 'actions' is missing"
        return result

    @builtins.property
    def location(self) -> builtins.str:
        result = self._values.get("location")
        assert result is not None, "Required property 'location' is missing"
        return result

    @builtins.property
    def name(self) -> builtins.str:
        result = self._values.get("name")
        assert result is not None, "Required property 'name' is missing"
        return result

    @builtins.property
    def registry_name(self) -> builtins.str:
        result = self._values.get("registry_name")
        assert result is not None, "Required property 'registry_name' is missing"
        return result

    @builtins.property
    def resource_group_name(self) -> builtins.str:
        result = self._values.get("resource_group_name")
        assert result is not None, "Required property 'resource_group_name' is missing"
        return result

    @builtins.property
    def service_uri(self) -> builtins.str:
        result = self._values.get("service_uri")
        assert result is not None, "Required property 'service_uri' is missing"
        return result

    @builtins.property
    def custom_headers(
        self,
    ) -> typing.Optional[typing.Mapping[builtins.str, builtins.str]]:
        result = self._values.get("custom_headers")
        return result

    @builtins.property
    def scope(self) -> typing.Optional[builtins.str]:
        result = self._values.get("scope")
        return result

    @builtins.property
    def status(self) -> typing.Optional[builtins.str]:
        result = self._values.get("status")
        return result

    @builtins.property
    def tags(self) -> typing.Optional[typing.Mapping[builtins.str, builtins.str]]:
        result = self._values.get("tags")
        return result

    @builtins.property
    def timeouts(self) -> typing.Optional["ContainerRegistryWebhookTimeouts"]:
        """timeouts block."""
        result = self._values.get("timeouts")
        return result

    def __eq__(self, rhs: typing.Any) -> builtins.bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs: typing.Any) -> builtins.bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return "ContainerRegistryWebhookConfig(%s)" % ", ".join(
            k + "=" + repr(v) for k, v in self._values.items()
        )


@jsii.data_type(
    jsii_type="@cdktf/provider-azurerm.ContainerRegistryWebhookTimeouts",
    jsii_struct_bases=[],
    name_mapping={
        "create": "create",
        "delete": "delete",
        "read": "read",
        "update": "update",
    },
)
class ContainerRegistryWebhookTimeouts:
    def __init__(
        self,
        *,
        create: typing.Optional[builtins.str] = None,
        delete: typing.Optional[builtins.str] = None,
        read: typing.Optional[builtins.str] = None,
        update: typing.Optional[builtins.str] = None,
    ) -> None:
        """
        :param create: 
        :param delete: 
        :param read: 
        :param update: 
        """
        self._values: typing.Dict[str, typing.Any] = {}
        if create is not None:
            self._values["create"] = create
        if delete is not None:
            self._values["delete"] = delete
        if read is not None:
            self._values["read"] = read
        if update is not None:
            self._values["update"] = update

    @builtins.property
    def create(self) -> typing.Optional[builtins.str]:
        result = self._values.get("create")
        return result

    @builtins.property
    def delete(self) -> typing.Optional[builtins.str]:
        result = self._values.get("delete")
        return result

    @builtins.property
    def read(self) -> typing.Optional[builtins.str]:
        result = self._values.get("read")
        return result

    @builtins.property
    def update(self) -> typing.Optional[builtins.str]:
        result = self._values.get("update")
        return result

    def __eq__(self, rhs: typing.Any) -> builtins.bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs: typing.Any) -> builtins.bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return "ContainerRegistryWebhookTimeouts(%s)" % ", ".join(
            k + "=" + repr(v) for k, v in self._values.items()
        )


class CosmosdbAccount(
    cdktf.TerraformResource,
    metaclass=jsii.JSIIMeta,
    jsii_type="@cdktf/provider-azurerm.CosmosdbAccount",
):
    def __init__(
        self,
        scope: constructs.Construct,
        id: builtins.str,
        *,
        consistency_policy: typing.List["CosmosdbAccountConsistencyPolicy"],
        geo_location: typing.List["CosmosdbAccountGeoLocation"],
        location: builtins.str,
        name: builtins.str,
        offer_type: builtins.str,
        resource_group_name: builtins.str,
        capabilities: typing.Optional[typing.List["CosmosdbAccountCapabilities"]] = None,
        enable_automatic_failover: typing.Optional[builtins.bool] = None,
        enable_multiple_write_locations: typing.Optional[builtins.bool] = None,
        ip_range_filter: typing.Optional[builtins.str] = None,
        is_virtual_network_filter_enabled: typing.Optional[builtins.bool] = None,
        kind: typing.Optional[builtins.str] = None,
        tags: typing.Optional[typing.Mapping[builtins.str, builtins.str]] = None,
        timeouts: typing.Optional["CosmosdbAccountTimeouts"] = None,
        virtual_network_rule: typing.Optional[typing.List["CosmosdbAccountVirtualNetworkRule"]] = None,
        count: typing.Optional[jsii.Number] = None,
        depends_on: typing.Optional[typing.List[cdktf.TerraformResource]] = None,
        lifecycle: typing.Optional[cdktf.TerraformResourceLifecycle] = None,
        provider: typing.Optional[cdktf.TerraformProvider] = None,
    ) -> None:
        """
        :param scope: -
        :param id: -
        :param consistency_policy: consistency_policy block.
        :param geo_location: geo_location block.
        :param location: 
        :param name: 
        :param offer_type: 
        :param resource_group_name: 
        :param capabilities: capabilities block.
        :param enable_automatic_failover: 
        :param enable_multiple_write_locations: 
        :param ip_range_filter: 
        :param is_virtual_network_filter_enabled: 
        :param kind: 
        :param tags: 
        :param timeouts: timeouts block.
        :param virtual_network_rule: virtual_network_rule block.
        :param count: 
        :param depends_on: 
        :param lifecycle: 
        :param provider: 
        """
        config = CosmosdbAccountConfig(
            consistency_policy=consistency_policy,
            geo_location=geo_location,
            location=location,
            name=name,
            offer_type=offer_type,
            resource_group_name=resource_group_name,
            capabilities=capabilities,
            enable_automatic_failover=enable_automatic_failover,
            enable_multiple_write_locations=enable_multiple_write_locations,
            ip_range_filter=ip_range_filter,
            is_virtual_network_filter_enabled=is_virtual_network_filter_enabled,
            kind=kind,
            tags=tags,
            timeouts=timeouts,
            virtual_network_rule=virtual_network_rule,
            count=count,
            depends_on=depends_on,
            lifecycle=lifecycle,
            provider=provider,
        )

        jsii.create(CosmosdbAccount, self, [scope, id, config])

    @jsii.member(jsii_name="synthesizeAttributes")
    def _synthesize_attributes(self) -> typing.Mapping[builtins.str, typing.Any]:
        return jsii.invoke(self, "synthesizeAttributes", [])

    @builtins.property # type: ignore
    @jsii.member(jsii_name="connectionStrings")
    def connection_strings(self) -> typing.List[builtins.str]:
        return jsii.get(self, "connectionStrings")

    @builtins.property # type: ignore
    @jsii.member(jsii_name="endpoint")
    def endpoint(self) -> builtins.str:
        return jsii.get(self, "endpoint")

    @builtins.property # type: ignore
    @jsii.member(jsii_name="primaryMasterKey")
    def primary_master_key(self) -> builtins.str:
        return jsii.get(self, "primaryMasterKey")

    @builtins.property # type: ignore
    @jsii.member(jsii_name="primaryReadonlyMasterKey")
    def primary_readonly_master_key(self) -> builtins.str:
        return jsii.get(self, "primaryReadonlyMasterKey")

    @builtins.property # type: ignore
    @jsii.member(jsii_name="readEndpoints")
    def read_endpoints(self) -> typing.List[builtins.str]:
        return jsii.get(self, "readEndpoints")

    @builtins.property # type: ignore
    @jsii.member(jsii_name="secondaryMasterKey")
    def secondary_master_key(self) -> builtins.str:
        return jsii.get(self, "secondaryMasterKey")

    @builtins.property # type: ignore
    @jsii.member(jsii_name="secondaryReadonlyMasterKey")
    def secondary_readonly_master_key(self) -> builtins.str:
        return jsii.get(self, "secondaryReadonlyMasterKey")

    @builtins.property # type: ignore
    @jsii.member(jsii_name="writeEndpoints")
    def write_endpoints(self) -> typing.List[builtins.str]:
        return jsii.get(self, "writeEndpoints")

    @builtins.property # type: ignore
    @jsii.member(jsii_name="consistencyPolicy")
    def consistency_policy(self) -> typing.List["CosmosdbAccountConsistencyPolicy"]:
        return jsii.get(self, "consistencyPolicy")

    @consistency_policy.setter # type: ignore
    def consistency_policy(
        self,
        value: typing.List["CosmosdbAccountConsistencyPolicy"],
    ) -> None:
        jsii.set(self, "consistencyPolicy", value)

    @builtins.property # type: ignore
    @jsii.member(jsii_name="geoLocation")
    def geo_location(self) -> typing.List["CosmosdbAccountGeoLocation"]:
        return jsii.get(self, "geoLocation")

    @geo_location.setter # type: ignore
    def geo_location(self, value: typing.List["CosmosdbAccountGeoLocation"]) -> None:
        jsii.set(self, "geoLocation", value)

    @builtins.property # type: ignore
    @jsii.member(jsii_name="location")
    def location(self) -> builtins.str:
        return jsii.get(self, "location")

    @location.setter # type: ignore
    def location(self, value: builtins.str) -> None:
        jsii.set(self, "location", value)

    @builtins.property # type: ignore
    @jsii.member(jsii_name="name")
    def name(self) -> builtins.str:
        return jsii.get(self, "name")

    @name.setter # type: ignore
    def name(self, value: builtins.str) -> None:
        jsii.set(self, "name", value)

    @builtins.property # type: ignore
    @jsii.member(jsii_name="offerType")
    def offer_type(self) -> builtins.str:
        return jsii.get(self, "offerType")

    @offer_type.setter # type: ignore
    def offer_type(self, value: builtins.str) -> None:
        jsii.set(self, "offerType", value)

    @builtins.property # type: ignore
    @jsii.member(jsii_name="resourceGroupName")
    def resource_group_name(self) -> builtins.str:
        return jsii.get(self, "resourceGroupName")

    @resource_group_name.setter # type: ignore
    def resource_group_name(self, value: builtins.str) -> None:
        jsii.set(self, "resourceGroupName", value)

    @builtins.property # type: ignore
    @jsii.member(jsii_name="capabilities")
    def capabilities(
        self,
    ) -> typing.Optional[typing.List["CosmosdbAccountCapabilities"]]:
        return jsii.get(self, "capabilities")

    @capabilities.setter # type: ignore
    def capabilities(
        self,
        value: typing.Optional[typing.List["CosmosdbAccountCapabilities"]],
    ) -> None:
        jsii.set(self, "capabilities", value)

    @builtins.property # type: ignore
    @jsii.member(jsii_name="enableAutomaticFailover")
    def enable_automatic_failover(self) -> typing.Optional[builtins.bool]:
        return jsii.get(self, "enableAutomaticFailover")

    @enable_automatic_failover.setter # type: ignore
    def enable_automatic_failover(self, value: typing.Optional[builtins.bool]) -> None:
        jsii.set(self, "enableAutomaticFailover", value)

    @builtins.property # type: ignore
    @jsii.member(jsii_name="enableMultipleWriteLocations")
    def enable_multiple_write_locations(self) -> typing.Optional[builtins.bool]:
        return jsii.get(self, "enableMultipleWriteLocations")

    @enable_multiple_write_locations.setter # type: ignore
    def enable_multiple_write_locations(
        self,
        value: typing.Optional[builtins.bool],
    ) -> None:
        jsii.set(self, "enableMultipleWriteLocations", value)

    @builtins.property # type: ignore
    @jsii.member(jsii_name="id")
    def id(self) -> typing.Optional[builtins.str]:
        return jsii.get(self, "id")

    @id.setter # type: ignore
    def id(self, value: typing.Optional[builtins.str]) -> None:
        jsii.set(self, "id", value)

    @builtins.property # type: ignore
    @jsii.member(jsii_name="ipRangeFilter")
    def ip_range_filter(self) -> typing.Optional[builtins.str]:
        return jsii.get(self, "ipRangeFilter")

    @ip_range_filter.setter # type: ignore
    def ip_range_filter(self, value: typing.Optional[builtins.str]) -> None:
        jsii.set(self, "ipRangeFilter", value)

    @builtins.property # type: ignore
    @jsii.member(jsii_name="isVirtualNetworkFilterEnabled")
    def is_virtual_network_filter_enabled(self) -> typing.Optional[builtins.bool]:
        return jsii.get(self, "isVirtualNetworkFilterEnabled")

    @is_virtual_network_filter_enabled.setter # type: ignore
    def is_virtual_network_filter_enabled(
        self,
        value: typing.Optional[builtins.bool],
    ) -> None:
        jsii.set(self, "isVirtualNetworkFilterEnabled", value)

    @builtins.property # type: ignore
    @jsii.member(jsii_name="kind")
    def kind(self) -> typing.Optional[builtins.str]:
        return jsii.get(self, "kind")

    @kind.setter # type: ignore
    def kind(self, value: typing.Optional[builtins.str]) -> None:
        jsii.set(self, "kind", value)

    @builtins.property # type: ignore
    @jsii.member(jsii_name="tags")
    def tags(self) -> typing.Optional[typing.Mapping[builtins.str, builtins.str]]:
        return jsii.get(self, "tags")

    @tags.setter # type: ignore
    def tags(
        self,
        value: typing.Optional[typing.Mapping[builtins.str, builtins.str]],
    ) -> None:
        jsii.set(self, "tags", value)

    @builtins.property # type: ignore
    @jsii.member(jsii_name="timeouts")
    def timeouts(self) -> typing.Optional["CosmosdbAccountTimeouts"]:
        return jsii.get(self, "timeouts")

    @timeouts.setter # type: ignore
    def timeouts(self, value: typing.Optional["CosmosdbAccountTimeouts"]) -> None:
        jsii.set(self, "timeouts", value)

    @builtins.property # type: ignore
    @jsii.member(jsii_name="virtualNetworkRule")
    def virtual_network_rule(
        self,
    ) -> typing.Optional[typing.List["CosmosdbAccountVirtualNetworkRule"]]:
        return jsii.get(self, "virtualNetworkRule")

    @virtual_network_rule.setter # type: ignore
    def virtual_network_rule(
        self,
        value: typing.Optional[typing.List["CosmosdbAccountVirtualNetworkRule"]],
    ) -> None:
        jsii.set(self, "virtualNetworkRule", value)


@jsii.data_type(
    jsii_type="@cdktf/provider-azurerm.CosmosdbAccountCapabilities",
    jsii_struct_bases=[],
    name_mapping={"name": "name"},
)
class CosmosdbAccountCapabilities:
    def __init__(self, *, name: builtins.str) -> None:
        """
        :param name: 
        """
        self._values: typing.Dict[str, typing.Any] = {
            "name": name,
        }

    @builtins.property
    def name(self) -> builtins.str:
        result = self._values.get("name")
        assert result is not None, "Required property 'name' is missing"
        return result

    def __eq__(self, rhs: typing.Any) -> builtins.bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs: typing.Any) -> builtins.bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return "CosmosdbAccountCapabilities(%s)" % ", ".join(
            k + "=" + repr(v) for k, v in self._values.items()
        )


@jsii.data_type(
    jsii_type="@cdktf/provider-azurerm.CosmosdbAccountConfig",
    jsii_struct_bases=[cdktf.TerraformMetaArguments],
    name_mapping={
        "count": "count",
        "depends_on": "dependsOn",
        "lifecycle": "lifecycle",
        "provider": "provider",
        "consistency_policy": "consistencyPolicy",
        "geo_location": "geoLocation",
        "location": "location",
        "name": "name",
        "offer_type": "offerType",
        "resource_group_name": "resourceGroupName",
        "capabilities": "capabilities",
        "enable_automatic_failover": "enableAutomaticFailover",
        "enable_multiple_write_locations": "enableMultipleWriteLocations",
        "ip_range_filter": "ipRangeFilter",
        "is_virtual_network_filter_enabled": "isVirtualNetworkFilterEnabled",
        "kind": "kind",
        "tags": "tags",
        "timeouts": "timeouts",
        "virtual_network_rule": "virtualNetworkRule",
    },
)
class CosmosdbAccountConfig(cdktf.TerraformMetaArguments):
    def __init__(
        self,
        *,
        count: typing.Optional[jsii.Number] = None,
        depends_on: typing.Optional[typing.List[cdktf.TerraformResource]] = None,
        lifecycle: typing.Optional[cdktf.TerraformResourceLifecycle] = None,
        provider: typing.Optional[cdktf.TerraformProvider] = None,
        consistency_policy: typing.List["CosmosdbAccountConsistencyPolicy"],
        geo_location: typing.List["CosmosdbAccountGeoLocation"],
        location: builtins.str,
        name: builtins.str,
        offer_type: builtins.str,
        resource_group_name: builtins.str,
        capabilities: typing.Optional[typing.List[CosmosdbAccountCapabilities]] = None,
        enable_automatic_failover: typing.Optional[builtins.bool] = None,
        enable_multiple_write_locations: typing.Optional[builtins.bool] = None,
        ip_range_filter: typing.Optional[builtins.str] = None,
        is_virtual_network_filter_enabled: typing.Optional[builtins.bool] = None,
        kind: typing.Optional[builtins.str] = None,
        tags: typing.Optional[typing.Mapping[builtins.str, builtins.str]] = None,
        timeouts: typing.Optional["CosmosdbAccountTimeouts"] = None,
        virtual_network_rule: typing.Optional[typing.List["CosmosdbAccountVirtualNetworkRule"]] = None,
    ) -> None:
        """
        :param count: 
        :param depends_on: 
        :param lifecycle: 
        :param provider: 
        :param consistency_policy: consistency_policy block.
        :param geo_location: geo_location block.
        :param location: 
        :param name: 
        :param offer_type: 
        :param resource_group_name: 
        :param capabilities: capabilities block.
        :param enable_automatic_failover: 
        :param enable_multiple_write_locations: 
        :param ip_range_filter: 
        :param is_virtual_network_filter_enabled: 
        :param kind: 
        :param tags: 
        :param timeouts: timeouts block.
        :param virtual_network_rule: virtual_network_rule block.
        """
        if isinstance(lifecycle, dict):
            lifecycle = cdktf.TerraformResourceLifecycle(**lifecycle)
        if isinstance(timeouts, dict):
            timeouts = CosmosdbAccountTimeouts(**timeouts)
        self._values: typing.Dict[str, typing.Any] = {
            "consistency_policy": consistency_policy,
            "geo_location": geo_location,
            "location": location,
            "name": name,
            "offer_type": offer_type,
            "resource_group_name": resource_group_name,
        }
        if count is not None:
            self._values["count"] = count
        if depends_on is not None:
            self._values["depends_on"] = depends_on
        if lifecycle is not None:
            self._values["lifecycle"] = lifecycle
        if provider is not None:
            self._values["provider"] = provider
        if capabilities is not None:
            self._values["capabilities"] = capabilities
        if enable_automatic_failover is not None:
            self._values["enable_automatic_failover"] = enable_automatic_failover
        if enable_multiple_write_locations is not None:
            self._values["enable_multiple_write_locations"] = enable_multiple_write_locations
        if ip_range_filter is not None:
            self._values["ip_range_filter"] = ip_range_filter
        if is_virtual_network_filter_enabled is not None:
            self._values["is_virtual_network_filter_enabled"] = is_virtual_network_filter_enabled
        if kind is not None:
            self._values["kind"] = kind
        if tags is not None:
            self._values["tags"] = tags
        if timeouts is not None:
            self._values["timeouts"] = timeouts
        if virtual_network_rule is not None:
            self._values["virtual_network_rule"] = virtual_network_rule

    @builtins.property
    def count(self) -> typing.Optional[jsii.Number]:
        """
        :stability: experimental
        """
        result = self._values.get("count")
        return result

    @builtins.property
    def depends_on(self) -> typing.Optional[typing.List[cdktf.TerraformResource]]:
        """
        :stability: experimental
        """
        result = self._values.get("depends_on")
        return result

    @builtins.property
    def lifecycle(self) -> typing.Optional[cdktf.TerraformResourceLifecycle]:
        """
        :stability: experimental
        """
        result = self._values.get("lifecycle")
        return result

    @builtins.property
    def provider(self) -> typing.Optional[cdktf.TerraformProvider]:
        """
        :stability: experimental
        """
        result = self._values.get("provider")
        return result

    @builtins.property
    def consistency_policy(self) -> typing.List["CosmosdbAccountConsistencyPolicy"]:
        """consistency_policy block."""
        result = self._values.get("consistency_policy")
        assert result is not None, "Required property 'consistency_policy' is missing"
        return result

    @builtins.property
    def geo_location(self) -> typing.List["CosmosdbAccountGeoLocation"]:
        """geo_location block."""
        result = self._values.get("geo_location")
        assert result is not None, "Required property 'geo_location' is missing"
        return result

    @builtins.property
    def location(self) -> builtins.str:
        result = self._values.get("location")
        assert result is not None, "Required property 'location' is missing"
        return result

    @builtins.property
    def name(self) -> builtins.str:
        result = self._values.get("name")
        assert result is not None, "Required property 'name' is missing"
        return result

    @builtins.property
    def offer_type(self) -> builtins.str:
        result = self._values.get("offer_type")
        assert result is not None, "Required property 'offer_type' is missing"
        return result

    @builtins.property
    def resource_group_name(self) -> builtins.str:
        result = self._values.get("resource_group_name")
        assert result is not None, "Required property 'resource_group_name' is missing"
        return result

    @builtins.property
    def capabilities(self) -> typing.Optional[typing.List[CosmosdbAccountCapabilities]]:
        """capabilities block."""
        result = self._values.get("capabilities")
        return result

    @builtins.property
    def enable_automatic_failover(self) -> typing.Optional[builtins.bool]:
        result = self._values.get("enable_automatic_failover")
        return result

    @builtins.property
    def enable_multiple_write_locations(self) -> typing.Optional[builtins.bool]:
        result = self._values.get("enable_multiple_write_locations")
        return result

    @builtins.property
    def ip_range_filter(self) -> typing.Optional[builtins.str]:
        result = self._values.get("ip_range_filter")
        return result

    @builtins.property
    def is_virtual_network_filter_enabled(self) -> typing.Optional[builtins.bool]:
        result = self._values.get("is_virtual_network_filter_enabled")
        return result

    @builtins.property
    def kind(self) -> typing.Optional[builtins.str]:
        result = self._values.get("kind")
        return result

    @builtins.property
    def tags(self) -> typing.Optional[typing.Mapping[builtins.str, builtins.str]]:
        result = self._values.get("tags")
        return result

    @builtins.property
    def timeouts(self) -> typing.Optional["CosmosdbAccountTimeouts"]:
        """timeouts block."""
        result = self._values.get("timeouts")
        return result

    @builtins.property
    def virtual_network_rule(
        self,
    ) -> typing.Optional[typing.List["CosmosdbAccountVirtualNetworkRule"]]:
        """virtual_network_rule block."""
        result = self._values.get("virtual_network_rule")
        return result

    def __eq__(self, rhs: typing.Any) -> builtins.bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs: typing.Any) -> builtins.bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return "CosmosdbAccountConfig(%s)" % ", ".join(
            k + "=" + repr(v) for k, v in self._values.items()
        )


@jsii.data_type(
    jsii_type="@cdktf/provider-azurerm.CosmosdbAccountConsistencyPolicy",
    jsii_struct_bases=[],
    name_mapping={
        "consistency_level": "consistencyLevel",
        "max_interval_in_seconds": "maxIntervalInSeconds",
        "max_staleness_prefix": "maxStalenessPrefix",
    },
)
class CosmosdbAccountConsistencyPolicy:
    def __init__(
        self,
        *,
        consistency_level: builtins.str,
        max_interval_in_seconds: typing.Optional[jsii.Number] = None,
        max_staleness_prefix: typing.Optional[jsii.Number] = None,
    ) -> None:
        """
        :param consistency_level: 
        :param max_interval_in_seconds: 
        :param max_staleness_prefix: 
        """
        self._values: typing.Dict[str, typing.Any] = {
            "consistency_level": consistency_level,
        }
        if max_interval_in_seconds is not None:
            self._values["max_interval_in_seconds"] = max_interval_in_seconds
        if max_staleness_prefix is not None:
            self._values["max_staleness_prefix"] = max_staleness_prefix

    @builtins.property
    def consistency_level(self) -> builtins.str:
        result = self._values.get("consistency_level")
        assert result is not None, "Required property 'consistency_level' is missing"
        return result

    @builtins.property
    def max_interval_in_seconds(self) -> typing.Optional[jsii.Number]:
        result = self._values.get("max_interval_in_seconds")
        return result

    @builtins.property
    def max_staleness_prefix(self) -> typing.Optional[jsii.Number]:
        result = self._values.get("max_staleness_prefix")
        return result

    def __eq__(self, rhs: typing.Any) -> builtins.bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs: typing.Any) -> builtins.bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return "CosmosdbAccountConsistencyPolicy(%s)" % ", ".join(
            k + "=" + repr(v) for k, v in self._values.items()
        )


@jsii.data_type(
    jsii_type="@cdktf/provider-azurerm.CosmosdbAccountGeoLocation",
    jsii_struct_bases=[],
    name_mapping={
        "failover_priority": "failoverPriority",
        "location": "location",
        "prefix": "prefix",
    },
)
class CosmosdbAccountGeoLocation:
    def __init__(
        self,
        *,
        failover_priority: jsii.Number,
        location: builtins.str,
        prefix: typing.Optional[builtins.str] = None,
    ) -> None:
        """
        :param failover_priority: 
        :param location: 
        :param prefix: 
        """
        self._values: typing.Dict[str, typing.Any] = {
            "failover_priority": failover_priority,
            "location": location,
        }
        if prefix is not None:
            self._values["prefix"] = prefix

    @builtins.property
    def failover_priority(self) -> jsii.Number:
        result = self._values.get("failover_priority")
        assert result is not None, "Required property 'failover_priority' is missing"
        return result

    @builtins.property
    def location(self) -> builtins.str:
        result = self._values.get("location")
        assert result is not None, "Required property 'location' is missing"
        return result

    @builtins.property
    def prefix(self) -> typing.Optional[builtins.str]:
        result = self._values.get("prefix")
        return result

    def __eq__(self, rhs: typing.Any) -> builtins.bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs: typing.Any) -> builtins.bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return "CosmosdbAccountGeoLocation(%s)" % ", ".join(
            k + "=" + repr(v) for k, v in self._values.items()
        )


@jsii.data_type(
    jsii_type="@cdktf/provider-azurerm.CosmosdbAccountTimeouts",
    jsii_struct_bases=[],
    name_mapping={
        "create": "create",
        "delete": "delete",
        "read": "read",
        "update": "update",
    },
)
class CosmosdbAccountTimeouts:
    def __init__(
        self,
        *,
        create: typing.Optional[builtins.str] = None,
        delete: typing.Optional[builtins.str] = None,
        read: typing.Optional[builtins.str] = None,
        update: typing.Optional[builtins.str] = None,
    ) -> None:
        """
        :param create: 
        :param delete: 
        :param read: 
        :param update: 
        """
        self._values: typing.Dict[str, typing.Any] = {}
        if create is not None:
            self._values["create"] = create
        if delete is not None:
            self._values["delete"] = delete
        if read is not None:
            self._values["read"] = read
        if update is not None:
            self._values["update"] = update

    @builtins.property
    def create(self) -> typing.Optional[builtins.str]:
        result = self._values.get("create")
        return result

    @builtins.property
    def delete(self) -> typing.Optional[builtins.str]:
        result = self._values.get("delete")
        return result

    @builtins.property
    def read(self) -> typing.Optional[builtins.str]:
        result = self._values.get("read")
        return result

    @builtins.property
    def update(self) -> typing.Optional[builtins.str]:
        result = self._values.get("update")
        return result

    def __eq__(self, rhs: typing.Any) -> builtins.bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs: typing.Any) -> builtins.bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return "CosmosdbAccountTimeouts(%s)" % ", ".join(
            k + "=" + repr(v) for k, v in self._values.items()
        )


@jsii.data_type(
    jsii_type="@cdktf/provider-azurerm.CosmosdbAccountVirtualNetworkRule",
    jsii_struct_bases=[],
    name_mapping={"id": "id"},
)
class CosmosdbAccountVirtualNetworkRule:
    def __init__(self, *, id: builtins.str) -> None:
        """
        :param id: 
        """
        self._values: typing.Dict[str, typing.Any] = {
            "id": id,
        }

    @builtins.property
    def id(self) -> builtins.str:
        result = self._values.get("id")
        assert result is not None, "Required property 'id' is missing"
        return result

    def __eq__(self, rhs: typing.Any) -> builtins.bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs: typing.Any) -> builtins.bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return "CosmosdbAccountVirtualNetworkRule(%s)" % ", ".join(
            k + "=" + repr(v) for k, v in self._values.items()
        )


class CosmosdbCassandraKeyspace(
    cdktf.TerraformResource,
    metaclass=jsii.JSIIMeta,
    jsii_type="@cdktf/provider-azurerm.CosmosdbCassandraKeyspace",
):
    def __init__(
        self,
        scope: constructs.Construct,
        id: builtins.str,
        *,
        account_name: builtins.str,
        name: builtins.str,
        resource_group_name: builtins.str,
        throughput: typing.Optional[jsii.Number] = None,
        timeouts: typing.Optional["CosmosdbCassandraKeyspaceTimeouts"] = None,
        count: typing.Optional[jsii.Number] = None,
        depends_on: typing.Optional[typing.List[cdktf.TerraformResource]] = None,
        lifecycle: typing.Optional[cdktf.TerraformResourceLifecycle] = None,
        provider: typing.Optional[cdktf.TerraformProvider] = None,
    ) -> None:
        """
        :param scope: -
        :param id: -
        :param account_name: 
        :param name: 
        :param resource_group_name: 
        :param throughput: 
        :param timeouts: timeouts block.
        :param count: 
        :param depends_on: 
        :param lifecycle: 
        :param provider: 
        """
        config = CosmosdbCassandraKeyspaceConfig(
            account_name=account_name,
            name=name,
            resource_group_name=resource_group_name,
            throughput=throughput,
            timeouts=timeouts,
            count=count,
            depends_on=depends_on,
            lifecycle=lifecycle,
            provider=provider,
        )

        jsii.create(CosmosdbCassandraKeyspace, self, [scope, id, config])

    @jsii.member(jsii_name="synthesizeAttributes")
    def _synthesize_attributes(self) -> typing.Mapping[builtins.str, typing.Any]:
        return jsii.invoke(self, "synthesizeAttributes", [])

    @builtins.property # type: ignore
    @jsii.member(jsii_name="accountName")
    def account_name(self) -> builtins.str:
        return jsii.get(self, "accountName")

    @account_name.setter # type: ignore
    def account_name(self, value: builtins.str) -> None:
        jsii.set(self, "accountName", value)

    @builtins.property # type: ignore
    @jsii.member(jsii_name="name")
    def name(self) -> builtins.str:
        return jsii.get(self, "name")

    @name.setter # type: ignore
    def name(self, value: builtins.str) -> None:
        jsii.set(self, "name", value)

    @builtins.property # type: ignore
    @jsii.member(jsii_name="resourceGroupName")
    def resource_group_name(self) -> builtins.str:
        return jsii.get(self, "resourceGroupName")

    @resource_group_name.setter # type: ignore
    def resource_group_name(self, value: builtins.str) -> None:
        jsii.set(self, "resourceGroupName", value)

    @builtins.property # type: ignore
    @jsii.member(jsii_name="id")
    def id(self) -> typing.Optional[builtins.str]:
        return jsii.get(self, "id")

    @id.setter # type: ignore
    def id(self, value: typing.Optional[builtins.str]) -> None:
        jsii.set(self, "id", value)

    @builtins.property # type: ignore
    @jsii.member(jsii_name="throughput")
    def throughput(self) -> typing.Optional[jsii.Number]:
        return jsii.get(self, "throughput")

    @throughput.setter # type: ignore
    def throughput(self, value: typing.Optional[jsii.Number]) -> None:
        jsii.set(self, "throughput", value)

    @builtins.property # type: ignore
    @jsii.member(jsii_name="timeouts")
    def timeouts(self) -> typing.Optional["CosmosdbCassandraKeyspaceTimeouts"]:
        return jsii.get(self, "timeouts")

    @timeouts.setter # type: ignore
    def timeouts(
        self,
        value: typing.Optional["CosmosdbCassandraKeyspaceTimeouts"],
    ) -> None:
        jsii.set(self, "timeouts", value)


@jsii.data_type(
    jsii_type="@cdktf/provider-azurerm.CosmosdbCassandraKeyspaceConfig",
    jsii_struct_bases=[cdktf.TerraformMetaArguments],
    name_mapping={
        "count": "count",
        "depends_on": "dependsOn",
        "lifecycle": "lifecycle",
        "provider": "provider",
        "account_name": "accountName",
        "name": "name",
        "resource_group_name": "resourceGroupName",
        "throughput": "throughput",
        "timeouts": "timeouts",
    },
)
class CosmosdbCassandraKeyspaceConfig(cdktf.TerraformMetaArguments):
    def __init__(
        self,
        *,
        count: typing.Optional[jsii.Number] = None,
        depends_on: typing.Optional[typing.List[cdktf.TerraformResource]] = None,
        lifecycle: typing.Optional[cdktf.TerraformResourceLifecycle] = None,
        provider: typing.Optional[cdktf.TerraformProvider] = None,
        account_name: builtins.str,
        name: builtins.str,
        resource_group_name: builtins.str,
        throughput: typing.Optional[jsii.Number] = None,
        timeouts: typing.Optional["CosmosdbCassandraKeyspaceTimeouts"] = None,
    ) -> None:
        """
        :param count: 
        :param depends_on: 
        :param lifecycle: 
        :param provider: 
        :param account_name: 
        :param name: 
        :param resource_group_name: 
        :param throughput: 
        :param timeouts: timeouts block.
        """
        if isinstance(lifecycle, dict):
            lifecycle = cdktf.TerraformResourceLifecycle(**lifecycle)
        if isinstance(timeouts, dict):
            timeouts = CosmosdbCassandraKeyspaceTimeouts(**timeouts)
        self._values: typing.Dict[str, typing.Any] = {
            "account_name": account_name,
            "name": name,
            "resource_group_name": resource_group_name,
        }
        if count is not None:
            self._values["count"] = count
        if depends_on is not None:
            self._values["depends_on"] = depends_on
        if lifecycle is not None:
            self._values["lifecycle"] = lifecycle
        if provider is not None:
            self._values["provider"] = provider
        if throughput is not None:
            self._values["throughput"] = throughput
        if timeouts is not None:
            self._values["timeouts"] = timeouts

    @builtins.property
    def count(self) -> typing.Optional[jsii.Number]:
        """
        :stability: experimental
        """
        result = self._values.get("count")
        return result

    @builtins.property
    def depends_on(self) -> typing.Optional[typing.List[cdktf.TerraformResource]]:
        """
        :stability: experimental
        """
        result = self._values.get("depends_on")
        return result

    @builtins.property
    def lifecycle(self) -> typing.Optional[cdktf.TerraformResourceLifecycle]:
        """
        :stability: experimental
        """
        result = self._values.get("lifecycle")
        return result

    @builtins.property
    def provider(self) -> typing.Optional[cdktf.TerraformProvider]:
        """
        :stability: experimental
        """
        result = self._values.get("provider")
        return result

    @builtins.property
    def account_name(self) -> builtins.str:
        result = self._values.get("account_name")
        assert result is not None, "Required property 'account_name' is missing"
        return result

    @builtins.property
    def name(self) -> builtins.str:
        result = self._values.get("name")
        assert result is not None, "Required property 'name' is missing"
        return result

    @builtins.property
    def resource_group_name(self) -> builtins.str:
        result = self._values.get("resource_group_name")
        assert result is not None, "Required property 'resource_group_name' is missing"
        return result

    @builtins.property
    def throughput(self) -> typing.Optional[jsii.Number]:
        result = self._values.get("throughput")
        return result

    @builtins.property
    def timeouts(self) -> typing.Optional["CosmosdbCassandraKeyspaceTimeouts"]:
        """timeouts block."""
        result = self._values.get("timeouts")
        return result

    def __eq__(self, rhs: typing.Any) -> builtins.bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs: typing.Any) -> builtins.bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return "CosmosdbCassandraKeyspaceConfig(%s)" % ", ".join(
            k + "=" + repr(v) for k, v in self._values.items()
        )


@jsii.data_type(
    jsii_type="@cdktf/provider-azurerm.CosmosdbCassandraKeyspaceTimeouts",
    jsii_struct_bases=[],
    name_mapping={
        "create": "create",
        "delete": "delete",
        "read": "read",
        "update": "update",
    },
)
class CosmosdbCassandraKeyspaceTimeouts:
    def __init__(
        self,
        *,
        create: typing.Optional[builtins.str] = None,
        delete: typing.Optional[builtins.str] = None,
        read: typing.Optional[builtins.str] = None,
        update: typing.Optional[builtins.str] = None,
    ) -> None:
        """
        :param create: 
        :param delete: 
        :param read: 
        :param update: 
        """
        self._values: typing.Dict[str, typing.Any] = {}
        if create is not None:
            self._values["create"] = create
        if delete is not None:
            self._values["delete"] = delete
        if read is not None:
            self._values["read"] = read
        if update is not None:
            self._values["update"] = update

    @builtins.property
    def create(self) -> typing.Optional[builtins.str]:
        result = self._values.get("create")
        return result

    @builtins.property
    def delete(self) -> typing.Optional[builtins.str]:
        result = self._values.get("delete")
        return result

    @builtins.property
    def read(self) -> typing.Optional[builtins.str]:
        result = self._values.get("read")
        return result

    @builtins.property
    def update(self) -> typing.Optional[builtins.str]:
        result = self._values.get("update")
        return result

    def __eq__(self, rhs: typing.Any) -> builtins.bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs: typing.Any) -> builtins.bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return "CosmosdbCassandraKeyspaceTimeouts(%s)" % ", ".join(
            k + "=" + repr(v) for k, v in self._values.items()
        )


class CosmosdbGremlinDatabase(
    cdktf.TerraformResource,
    metaclass=jsii.JSIIMeta,
    jsii_type="@cdktf/provider-azurerm.CosmosdbGremlinDatabase",
):
    def __init__(
        self,
        scope: constructs.Construct,
        id: builtins.str,
        *,
        account_name: builtins.str,
        name: builtins.str,
        resource_group_name: builtins.str,
        throughput: typing.Optional[jsii.Number] = None,
        timeouts: typing.Optional["CosmosdbGremlinDatabaseTimeouts"] = None,
        count: typing.Optional[jsii.Number] = None,
        depends_on: typing.Optional[typing.List[cdktf.TerraformResource]] = None,
        lifecycle: typing.Optional[cdktf.TerraformResourceLifecycle] = None,
        provider: typing.Optional[cdktf.TerraformProvider] = None,
    ) -> None:
        """
        :param scope: -
        :param id: -
        :param account_name: 
        :param name: 
        :param resource_group_name: 
        :param throughput: 
        :param timeouts: timeouts block.
        :param count: 
        :param depends_on: 
        :param lifecycle: 
        :param provider: 
        """
        config = CosmosdbGremlinDatabaseConfig(
            account_name=account_name,
            name=name,
            resource_group_name=resource_group_name,
            throughput=throughput,
            timeouts=timeouts,
            count=count,
            depends_on=depends_on,
            lifecycle=lifecycle,
            provider=provider,
        )

        jsii.create(CosmosdbGremlinDatabase, self, [scope, id, config])

    @jsii.member(jsii_name="synthesizeAttributes")
    def _synthesize_attributes(self) -> typing.Mapping[builtins.str, typing.Any]:
        return jsii.invoke(self, "synthesizeAttributes", [])

    @builtins.property # type: ignore
    @jsii.member(jsii_name="accountName")
    def account_name(self) -> builtins.str:
        return jsii.get(self, "accountName")

    @account_name.setter # type: ignore
    def account_name(self, value: builtins.str) -> None:
        jsii.set(self, "accountName", value)

    @builtins.property # type: ignore
    @jsii.member(jsii_name="name")
    def name(self) -> builtins.str:
        return jsii.get(self, "name")

    @name.setter # type: ignore
    def name(self, value: builtins.str) -> None:
        jsii.set(self, "name", value)

    @builtins.property # type: ignore
    @jsii.member(jsii_name="resourceGroupName")
    def resource_group_name(self) -> builtins.str:
        return jsii.get(self, "resourceGroupName")

    @resource_group_name.setter # type: ignore
    def resource_group_name(self, value: builtins.str) -> None:
        jsii.set(self, "resourceGroupName", value)

    @builtins.property # type: ignore
    @jsii.member(jsii_name="id")
    def id(self) -> typing.Optional[builtins.str]:
        return jsii.get(self, "id")

    @id.setter # type: ignore
    def id(self, value: typing.Optional[builtins.str]) -> None:
        jsii.set(self, "id", value)

    @builtins.property # type: ignore
    @jsii.member(jsii_name="throughput")
    def throughput(self) -> typing.Optional[jsii.Number]:
        return jsii.get(self, "throughput")

    @throughput.setter # type: ignore
    def throughput(self, value: typing.Optional[jsii.Number]) -> None:
        jsii.set(self, "throughput", value)

    @builtins.property # type: ignore
    @jsii.member(jsii_name="timeouts")
    def timeouts(self) -> typing.Optional["CosmosdbGremlinDatabaseTimeouts"]:
        return jsii.get(self, "timeouts")

    @timeouts.setter # type: ignore
    def timeouts(
        self,
        value: typing.Optional["CosmosdbGremlinDatabaseTimeouts"],
    ) -> None:
        jsii.set(self, "timeouts", value)


@jsii.data_type(
    jsii_type="@cdktf/provider-azurerm.CosmosdbGremlinDatabaseConfig",
    jsii_struct_bases=[cdktf.TerraformMetaArguments],
    name_mapping={
        "count": "count",
        "depends_on": "dependsOn",
        "lifecycle": "lifecycle",
        "provider": "provider",
        "account_name": "accountName",
        "name": "name",
        "resource_group_name": "resourceGroupName",
        "throughput": "throughput",
        "timeouts": "timeouts",
    },
)
class CosmosdbGremlinDatabaseConfig(cdktf.TerraformMetaArguments):
    def __init__(
        self,
        *,
        count: typing.Optional[jsii.Number] = None,
        depends_on: typing.Optional[typing.List[cdktf.TerraformResource]] = None,
        lifecycle: typing.Optional[cdktf.TerraformResourceLifecycle] = None,
        provider: typing.Optional[cdktf.TerraformProvider] = None,
        account_name: builtins.str,
        name: builtins.str,
        resource_group_name: builtins.str,
        throughput: typing.Optional[jsii.Number] = None,
        timeouts: typing.Optional["CosmosdbGremlinDatabaseTimeouts"] = None,
    ) -> None:
        """
        :param count: 
        :param depends_on: 
        :param lifecycle: 
        :param provider: 
        :param account_name: 
        :param name: 
        :param resource_group_name: 
        :param throughput: 
        :param timeouts: timeouts block.
        """
        if isinstance(lifecycle, dict):
            lifecycle = cdktf.TerraformResourceLifecycle(**lifecycle)
        if isinstance(timeouts, dict):
            timeouts = CosmosdbGremlinDatabaseTimeouts(**timeouts)
        self._values: typing.Dict[str, typing.Any] = {
            "account_name": account_name,
            "name": name,
            "resource_group_name": resource_group_name,
        }
        if count is not None:
            self._values["count"] = count
        if depends_on is not None:
            self._values["depends_on"] = depends_on
        if lifecycle is not None:
            self._values["lifecycle"] = lifecycle
        if provider is not None:
            self._values["provider"] = provider
        if throughput is not None:
            self._values["throughput"] = throughput
        if timeouts is not None:
            self._values["timeouts"] = timeouts

    @builtins.property
    def count(self) -> typing.Optional[jsii.Number]:
        """
        :stability: experimental
        """
        result = self._values.get("count")
        return result

    @builtins.property
    def depends_on(self) -> typing.Optional[typing.List[cdktf.TerraformResource]]:
        """
        :stability: experimental
        """
        result = self._values.get("depends_on")
        return result

    @builtins.property
    def lifecycle(self) -> typing.Optional[cdktf.TerraformResourceLifecycle]:
        """
        :stability: experimental
        """
        result = self._values.get("lifecycle")
        return result

    @builtins.property
    def provider(self) -> typing.Optional[cdktf.TerraformProvider]:
        """
        :stability: experimental
        """
        result = self._values.get("provider")
        return result

    @builtins.property
    def account_name(self) -> builtins.str:
        result = self._values.get("account_name")
        assert result is not None, "Required property 'account_name' is missing"
        return result

    @builtins.property
    def name(self) -> builtins.str:
        result = self._values.get("name")
        assert result is not None, "Required property 'name' is missing"
        return result

    @builtins.property
    def resource_group_name(self) -> builtins.str:
        result = self._values.get("resource_group_name")
        assert result is not None, "Required property 'resource_group_name' is missing"
        return result

    @builtins.property
    def throughput(self) -> typing.Optional[jsii.Number]:
        result = self._values.get("throughput")
        return result

    @builtins.property
    def timeouts(self) -> typing.Optional["CosmosdbGremlinDatabaseTimeouts"]:
        """timeouts block."""
        result = self._values.get("timeouts")
        return result

    def __eq__(self, rhs: typing.Any) -> builtins.bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs: typing.Any) -> builtins.bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return "CosmosdbGremlinDatabaseConfig(%s)" % ", ".join(
            k + "=" + repr(v) for k, v in self._values.items()
        )


@jsii.data_type(
    jsii_type="@cdktf/provider-azurerm.CosmosdbGremlinDatabaseTimeouts",
    jsii_struct_bases=[],
    name_mapping={
        "create": "create",
        "delete": "delete",
        "read": "read",
        "update": "update",
    },
)
class CosmosdbGremlinDatabaseTimeouts:
    def __init__(
        self,
        *,
        create: typing.Optional[builtins.str] = None,
        delete: typing.Optional[builtins.str] = None,
        read: typing.Optional[builtins.str] = None,
        update: typing.Optional[builtins.str] = None,
    ) -> None:
        """
        :param create: 
        :param delete: 
        :param read: 
        :param update: 
        """
        self._values: typing.Dict[str, typing.Any] = {}
        if create is not None:
            self._values["create"] = create
        if delete is not None:
            self._values["delete"] = delete
        if read is not None:
            self._values["read"] = read
        if update is not None:
            self._values["update"] = update

    @builtins.property
    def create(self) -> typing.Optional[builtins.str]:
        result = self._values.get("create")
        return result

    @builtins.property
    def delete(self) -> typing.Optional[builtins.str]:
        result = self._values.get("delete")
        return result

    @builtins.property
    def read(self) -> typing.Optional[builtins.str]:
        result = self._values.get("read")
        return result

    @builtins.property
    def update(self) -> typing.Optional[builtins.str]:
        result = self._values.get("update")
        return result

    def __eq__(self, rhs: typing.Any) -> builtins.bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs: typing.Any) -> builtins.bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return "CosmosdbGremlinDatabaseTimeouts(%s)" % ", ".join(
            k + "=" + repr(v) for k, v in self._values.items()
        )


class CosmosdbGremlinGraph(
    cdktf.TerraformResource,
    metaclass=jsii.JSIIMeta,
    jsii_type="@cdktf/provider-azurerm.CosmosdbGremlinGraph",
):
    def __init__(
        self,
        scope: constructs.Construct,
        id: builtins.str,
        *,
        account_name: builtins.str,
        conflict_resolution_policy: typing.List["CosmosdbGremlinGraphConflictResolutionPolicy"],
        database_name: builtins.str,
        index_policy: typing.List["CosmosdbGremlinGraphIndexPolicy"],
        name: builtins.str,
        resource_group_name: builtins.str,
        partition_key_path: typing.Optional[builtins.str] = None,
        throughput: typing.Optional[jsii.Number] = None,
        timeouts: typing.Optional["CosmosdbGremlinGraphTimeouts"] = None,
        unique_key: typing.Optional[typing.List["CosmosdbGremlinGraphUniqueKey"]] = None,
        count: typing.Optional[jsii.Number] = None,
        depends_on: typing.Optional[typing.List[cdktf.TerraformResource]] = None,
        lifecycle: typing.Optional[cdktf.TerraformResourceLifecycle] = None,
        provider: typing.Optional[cdktf.TerraformProvider] = None,
    ) -> None:
        """
        :param scope: -
        :param id: -
        :param account_name: 
        :param conflict_resolution_policy: conflict_resolution_policy block.
        :param database_name: 
        :param index_policy: index_policy block.
        :param name: 
        :param resource_group_name: 
        :param partition_key_path: 
        :param throughput: 
        :param timeouts: timeouts block.
        :param unique_key: unique_key block.
        :param count: 
        :param depends_on: 
        :param lifecycle: 
        :param provider: 
        """
        config = CosmosdbGremlinGraphConfig(
            account_name=account_name,
            conflict_resolution_policy=conflict_resolution_policy,
            database_name=database_name,
            index_policy=index_policy,
            name=name,
            resource_group_name=resource_group_name,
            partition_key_path=partition_key_path,
            throughput=throughput,
            timeouts=timeouts,
            unique_key=unique_key,
            count=count,
            depends_on=depends_on,
            lifecycle=lifecycle,
            provider=provider,
        )

        jsii.create(CosmosdbGremlinGraph, self, [scope, id, config])

    @jsii.member(jsii_name="synthesizeAttributes")
    def _synthesize_attributes(self) -> typing.Mapping[builtins.str, typing.Any]:
        return jsii.invoke(self, "synthesizeAttributes", [])

    @builtins.property # type: ignore
    @jsii.member(jsii_name="accountName")
    def account_name(self) -> builtins.str:
        return jsii.get(self, "accountName")

    @account_name.setter # type: ignore
    def account_name(self, value: builtins.str) -> None:
        jsii.set(self, "accountName", value)

    @builtins.property # type: ignore
    @jsii.member(jsii_name="conflictResolutionPolicy")
    def conflict_resolution_policy(
        self,
    ) -> typing.List["CosmosdbGremlinGraphConflictResolutionPolicy"]:
        return jsii.get(self, "conflictResolutionPolicy")

    @conflict_resolution_policy.setter # type: ignore
    def conflict_resolution_policy(
        self,
        value: typing.List["CosmosdbGremlinGraphConflictResolutionPolicy"],
    ) -> None:
        jsii.set(self, "conflictResolutionPolicy", value)

    @builtins.property # type: ignore
    @jsii.member(jsii_name="databaseName")
    def database_name(self) -> builtins.str:
        return jsii.get(self, "databaseName")

    @database_name.setter # type: ignore
    def database_name(self, value: builtins.str) -> None:
        jsii.set(self, "databaseName", value)

    @builtins.property # type: ignore
    @jsii.member(jsii_name="indexPolicy")
    def index_policy(self) -> typing.List["CosmosdbGremlinGraphIndexPolicy"]:
        return jsii.get(self, "indexPolicy")

    @index_policy.setter # type: ignore
    def index_policy(
        self,
        value: typing.List["CosmosdbGremlinGraphIndexPolicy"],
    ) -> None:
        jsii.set(self, "indexPolicy", value)

    @builtins.property # type: ignore
    @jsii.member(jsii_name="name")
    def name(self) -> builtins.str:
        return jsii.get(self, "name")

    @name.setter # type: ignore
    def name(self, value: builtins.str) -> None:
        jsii.set(self, "name", value)

    @builtins.property # type: ignore
    @jsii.member(jsii_name="resourceGroupName")
    def resource_group_name(self) -> builtins.str:
        return jsii.get(self, "resourceGroupName")

    @resource_group_name.setter # type: ignore
    def resource_group_name(self, value: builtins.str) -> None:
        jsii.set(self, "resourceGroupName", value)

    @builtins.property # type: ignore
    @jsii.member(jsii_name="id")
    def id(self) -> typing.Optional[builtins.str]:
        return jsii.get(self, "id")

    @id.setter # type: ignore
    def id(self, value: typing.Optional[builtins.str]) -> None:
        jsii.set(self, "id", value)

    @builtins.property # type: ignore
    @jsii.member(jsii_name="partitionKeyPath")
    def partition_key_path(self) -> typing.Optional[builtins.str]:
        return jsii.get(self, "partitionKeyPath")

    @partition_key_path.setter # type: ignore
    def partition_key_path(self, value: typing.Optional[builtins.str]) -> None:
        jsii.set(self, "partitionKeyPath", value)

    @builtins.property # type: ignore
    @jsii.member(jsii_name="throughput")
    def throughput(self) -> typing.Optional[jsii.Number]:
        return jsii.get(self, "throughput")

    @throughput.setter # type: ignore
    def throughput(self, value: typing.Optional[jsii.Number]) -> None:
        jsii.set(self, "throughput", value)

    @builtins.property # type: ignore
    @jsii.member(jsii_name="timeouts")
    def timeouts(self) -> typing.Optional["CosmosdbGremlinGraphTimeouts"]:
        return jsii.get(self, "timeouts")

    @timeouts.setter # type: ignore
    def timeouts(self, value: typing.Optional["CosmosdbGremlinGraphTimeouts"]) -> None:
        jsii.set(self, "timeouts", value)

    @builtins.property # type: ignore
    @jsii.member(jsii_name="uniqueKey")
    def unique_key(
        self,
    ) -> typing.Optional[typing.List["CosmosdbGremlinGraphUniqueKey"]]:
        return jsii.get(self, "uniqueKey")

    @unique_key.setter # type: ignore
    def unique_key(
        self,
        value: typing.Optional[typing.List["CosmosdbGremlinGraphUniqueKey"]],
    ) -> None:
        jsii.set(self, "uniqueKey", value)


@jsii.data_type(
    jsii_type="@cdktf/provider-azurerm.CosmosdbGremlinGraphConfig",
    jsii_struct_bases=[cdktf.TerraformMetaArguments],
    name_mapping={
        "count": "count",
        "depends_on": "dependsOn",
        "lifecycle": "lifecycle",
        "provider": "provider",
        "account_name": "accountName",
        "conflict_resolution_policy": "conflictResolutionPolicy",
        "database_name": "databaseName",
        "index_policy": "indexPolicy",
        "name": "name",
        "resource_group_name": "resourceGroupName",
        "partition_key_path": "partitionKeyPath",
        "throughput": "throughput",
        "timeouts": "timeouts",
        "unique_key": "uniqueKey",
    },
)
class CosmosdbGremlinGraphConfig(cdktf.TerraformMetaArguments):
    def __init__(
        self,
        *,
        count: typing.Optional[jsii.Number] = None,
        depends_on: typing.Optional[typing.List[cdktf.TerraformResource]] = None,
        lifecycle: typing.Optional[cdktf.TerraformResourceLifecycle] = None,
        provider: typing.Optional[cdktf.TerraformProvider] = None,
        account_name: builtins.str,
        conflict_resolution_policy: typing.List["CosmosdbGremlinGraphConflictResolutionPolicy"],
        database_name: builtins.str,
        index_policy: typing.List["CosmosdbGremlinGraphIndexPolicy"],
        name: builtins.str,
        resource_group_name: builtins.str,
        partition_key_path: typing.Optional[builtins.str] = None,
        throughput: typing.Optional[jsii.Number] = None,
        timeouts: typing.Optional["CosmosdbGremlinGraphTimeouts"] = None,
        unique_key: typing.Optional[typing.List["CosmosdbGremlinGraphUniqueKey"]] = None,
    ) -> None:
        """
        :param count: 
        :param depends_on: 
        :param lifecycle: 
        :param provider: 
        :param account_name: 
        :param conflict_resolution_policy: conflict_resolution_policy block.
        :param database_name: 
        :param index_policy: index_policy block.
        :param name: 
        :param resource_group_name: 
        :param partition_key_path: 
        :param throughput: 
        :param timeouts: timeouts block.
        :param unique_key: unique_key block.
        """
        if isinstance(lifecycle, dict):
            lifecycle = cdktf.TerraformResourceLifecycle(**lifecycle)
        if isinstance(timeouts, dict):
            timeouts = CosmosdbGremlinGraphTimeouts(**timeouts)
        self._values: typing.Dict[str, typing.Any] = {
            "account_name": account_name,
            "conflict_resolution_policy": conflict_resolution_policy,
            "database_name": database_name,
            "index_policy": index_policy,
            "name": name,
            "resource_group_name": resource_group_name,
        }
        if count is not None:
            self._values["count"] = count
        if depends_on is not None:
            self._values["depends_on"] = depends_on
        if lifecycle is not None:
            self._values["lifecycle"] = lifecycle
        if provider is not None:
            self._values["provider"] = provider
        if partition_key_path is not None:
            self._values["partition_key_path"] = partition_key_path
        if throughput is not None:
            self._values["throughput"] = throughput
        if timeouts is not None:
            self._values["timeouts"] = timeouts
        if unique_key is not None:
            self._values["unique_key"] = unique_key

    @builtins.property
    def count(self) -> typing.Optional[jsii.Number]:
        """
        :stability: experimental
        """
        result = self._values.get("count")
        return result

    @builtins.property
    def depends_on(self) -> typing.Optional[typing.List[cdktf.TerraformResource]]:
        """
        :stability: experimental
        """
        result = self._values.get("depends_on")
        return result

    @builtins.property
    def lifecycle(self) -> typing.Optional[cdktf.TerraformResourceLifecycle]:
        """
        :stability: experimental
        """
        result = self._values.get("lifecycle")
        return result

    @builtins.property
    def provider(self) -> typing.Optional[cdktf.TerraformProvider]:
        """
        :stability: experimental
        """
        result = self._values.get("provider")
        return result

    @builtins.property
    def account_name(self) -> builtins.str:
        result = self._values.get("account_name")
        assert result is not None, "Required property 'account_name' is missing"
        return result

    @builtins.property
    def conflict_resolution_policy(
        self,
    ) -> typing.List["CosmosdbGremlinGraphConflictResolutionPolicy"]:
        """conflict_resolution_policy block."""
        result = self._values.get("conflict_resolution_policy")
        assert result is not None, "Required property 'conflict_resolution_policy' is missing"
        return result

    @builtins.property
    def database_name(self) -> builtins.str:
        result = self._values.get("database_name")
        assert result is not None, "Required property 'database_name' is missing"
        return result

    @builtins.property
    def index_policy(self) -> typing.List["CosmosdbGremlinGraphIndexPolicy"]:
        """index_policy block."""
        result = self._values.get("index_policy")
        assert result is not None, "Required property 'index_policy' is missing"
        return result

    @builtins.property
    def name(self) -> builtins.str:
        result = self._values.get("name")
        assert result is not None, "Required property 'name' is missing"
        return result

    @builtins.property
    def resource_group_name(self) -> builtins.str:
        result = self._values.get("resource_group_name")
        assert result is not None, "Required property 'resource_group_name' is missing"
        return result

    @builtins.property
    def partition_key_path(self) -> typing.Optional[builtins.str]:
        result = self._values.get("partition_key_path")
        return result

    @builtins.property
    def throughput(self) -> typing.Optional[jsii.Number]:
        result = self._values.get("throughput")
        return result

    @builtins.property
    def timeouts(self) -> typing.Optional["CosmosdbGremlinGraphTimeouts"]:
        """timeouts block."""
        result = self._values.get("timeouts")
        return result

    @builtins.property
    def unique_key(
        self,
    ) -> typing.Optional[typing.List["CosmosdbGremlinGraphUniqueKey"]]:
        """unique_key block."""
        result = self._values.get("unique_key")
        return result

    def __eq__(self, rhs: typing.Any) -> builtins.bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs: typing.Any) -> builtins.bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return "CosmosdbGremlinGraphConfig(%s)" % ", ".join(
            k + "=" + repr(v) for k, v in self._values.items()
        )


@jsii.data_type(
    jsii_type="@cdktf/provider-azurerm.CosmosdbGremlinGraphConflictResolutionPolicy",
    jsii_struct_bases=[],
    name_mapping={
        "mode": "mode",
        "conflict_resolution_path": "conflictResolutionPath",
        "conflict_resolution_procedure": "conflictResolutionProcedure",
    },
)
class CosmosdbGremlinGraphConflictResolutionPolicy:
    def __init__(
        self,
        *,
        mode: builtins.str,
        conflict_resolution_path: typing.Optional[builtins.str] = None,
        conflict_resolution_procedure: typing.Optional[builtins.str] = None,
    ) -> None:
        """
        :param mode: 
        :param conflict_resolution_path: 
        :param conflict_resolution_procedure: 
        """
        self._values: typing.Dict[str, typing.Any] = {
            "mode": mode,
        }
        if conflict_resolution_path is not None:
            self._values["conflict_resolution_path"] = conflict_resolution_path
        if conflict_resolution_procedure is not None:
            self._values["conflict_resolution_procedure"] = conflict_resolution_procedure

    @builtins.property
    def mode(self) -> builtins.str:
        result = self._values.get("mode")
        assert result is not None, "Required property 'mode' is missing"
        return result

    @builtins.property
    def conflict_resolution_path(self) -> typing.Optional[builtins.str]:
        result = self._values.get("conflict_resolution_path")
        return result

    @builtins.property
    def conflict_resolution_procedure(self) -> typing.Optional[builtins.str]:
        result = self._values.get("conflict_resolution_procedure")
        return result

    def __eq__(self, rhs: typing.Any) -> builtins.bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs: typing.Any) -> builtins.bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return "CosmosdbGremlinGraphConflictResolutionPolicy(%s)" % ", ".join(
            k + "=" + repr(v) for k, v in self._values.items()
        )


@jsii.data_type(
    jsii_type="@cdktf/provider-azurerm.CosmosdbGremlinGraphIndexPolicy",
    jsii_struct_bases=[],
    name_mapping={
        "indexing_mode": "indexingMode",
        "automatic": "automatic",
        "excluded_paths": "excludedPaths",
        "included_paths": "includedPaths",
    },
)
class CosmosdbGremlinGraphIndexPolicy:
    def __init__(
        self,
        *,
        indexing_mode: builtins.str,
        automatic: typing.Optional[builtins.bool] = None,
        excluded_paths: typing.Optional[typing.List[builtins.str]] = None,
        included_paths: typing.Optional[typing.List[builtins.str]] = None,
    ) -> None:
        """
        :param indexing_mode: 
        :param automatic: 
        :param excluded_paths: 
        :param included_paths: 
        """
        self._values: typing.Dict[str, typing.Any] = {
            "indexing_mode": indexing_mode,
        }
        if automatic is not None:
            self._values["automatic"] = automatic
        if excluded_paths is not None:
            self._values["excluded_paths"] = excluded_paths
        if included_paths is not None:
            self._values["included_paths"] = included_paths

    @builtins.property
    def indexing_mode(self) -> builtins.str:
        result = self._values.get("indexing_mode")
        assert result is not None, "Required property 'indexing_mode' is missing"
        return result

    @builtins.property
    def automatic(self) -> typing.Optional[builtins.bool]:
        result = self._values.get("automatic")
        return result

    @builtins.property
    def excluded_paths(self) -> typing.Optional[typing.List[builtins.str]]:
        result = self._values.get("excluded_paths")
        return result

    @builtins.property
    def included_paths(self) -> typing.Optional[typing.List[builtins.str]]:
        result = self._values.get("included_paths")
        return result

    def __eq__(self, rhs: typing.Any) -> builtins.bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs: typing.Any) -> builtins.bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return "CosmosdbGremlinGraphIndexPolicy(%s)" % ", ".join(
            k + "=" + repr(v) for k, v in self._values.items()
        )


@jsii.data_type(
    jsii_type="@cdktf/provider-azurerm.CosmosdbGremlinGraphTimeouts",
    jsii_struct_bases=[],
    name_mapping={
        "create": "create",
        "delete": "delete",
        "read": "read",
        "update": "update",
    },
)
class CosmosdbGremlinGraphTimeouts:
    def __init__(
        self,
        *,
        create: typing.Optional[builtins.str] = None,
        delete: typing.Optional[builtins.str] = None,
        read: typing.Optional[builtins.str] = None,
        update: typing.Optional[builtins.str] = None,
    ) -> None:
        """
        :param create: 
        :param delete: 
        :param read: 
        :param update: 
        """
        self._values: typing.Dict[str, typing.Any] = {}
        if create is not None:
            self._values["create"] = create
        if delete is not None:
            self._values["delete"] = delete
        if read is not None:
            self._values["read"] = read
        if update is not None:
            self._values["update"] = update

    @builtins.property
    def create(self) -> typing.Optional[builtins.str]:
        result = self._values.get("create")
        return result

    @builtins.property
    def delete(self) -> typing.Optional[builtins.str]:
        result = self._values.get("delete")
        return result

    @builtins.property
    def read(self) -> typing.Optional[builtins.str]:
        result = self._values.get("read")
        return result

    @builtins.property
    def update(self) -> typing.Optional[builtins.str]:
        result = self._values.get("update")
        return result

    def __eq__(self, rhs: typing.Any) -> builtins.bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs: typing.Any) -> builtins.bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return "CosmosdbGremlinGraphTimeouts(%s)" % ", ".join(
            k + "=" + repr(v) for k, v in self._values.items()
        )


@jsii.data_type(
    jsii_type="@cdktf/provider-azurerm.CosmosdbGremlinGraphUniqueKey",
    jsii_struct_bases=[],
    name_mapping={"paths": "paths"},
)
class CosmosdbGremlinGraphUniqueKey:
    def __init__(self, *, paths: typing.List[builtins.str]) -> None:
        """
        :param paths: 
        """
        self._values: typing.Dict[str, typing.Any] = {
            "paths": paths,
        }

    @builtins.property
    def paths(self) -> typing.List[builtins.str]:
        result = self._values.get("paths")
        assert result is not None, "Required property 'paths' is missing"
        return result

    def __eq__(self, rhs: typing.Any) -> builtins.bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs: typing.Any) -> builtins.bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return "CosmosdbGremlinGraphUniqueKey(%s)" % ", ".join(
            k + "=" + repr(v) for k, v in self._values.items()
        )


class CosmosdbMongoCollection(
    cdktf.TerraformResource,
    metaclass=jsii.JSIIMeta,
    jsii_type="@cdktf/provider-azurerm.CosmosdbMongoCollection",
):
    def __init__(
        self,
        scope: constructs.Construct,
        id: builtins.str,
        *,
        account_name: builtins.str,
        database_name: builtins.str,
        name: builtins.str,
        resource_group_name: builtins.str,
        default_ttl_seconds: typing.Optional[jsii.Number] = None,
        shard_key: typing.Optional[builtins.str] = None,
        throughput: typing.Optional[jsii.Number] = None,
        timeouts: typing.Optional["CosmosdbMongoCollectionTimeouts"] = None,
        count: typing.Optional[jsii.Number] = None,
        depends_on: typing.Optional[typing.List[cdktf.TerraformResource]] = None,
        lifecycle: typing.Optional[cdktf.TerraformResourceLifecycle] = None,
        provider: typing.Optional[cdktf.TerraformProvider] = None,
    ) -> None:
        """
        :param scope: -
        :param id: -
        :param account_name: 
        :param database_name: 
        :param name: 
        :param resource_group_name: 
        :param default_ttl_seconds: 
        :param shard_key: 
        :param throughput: 
        :param timeouts: timeouts block.
        :param count: 
        :param depends_on: 
        :param lifecycle: 
        :param provider: 
        """
        config = CosmosdbMongoCollectionConfig(
            account_name=account_name,
            database_name=database_name,
            name=name,
            resource_group_name=resource_group_name,
            default_ttl_seconds=default_ttl_seconds,
            shard_key=shard_key,
            throughput=throughput,
            timeouts=timeouts,
            count=count,
            depends_on=depends_on,
            lifecycle=lifecycle,
            provider=provider,
        )

        jsii.create(CosmosdbMongoCollection, self, [scope, id, config])

    @jsii.member(jsii_name="synthesizeAttributes")
    def _synthesize_attributes(self) -> typing.Mapping[builtins.str, typing.Any]:
        return jsii.invoke(self, "synthesizeAttributes", [])

    @builtins.property # type: ignore
    @jsii.member(jsii_name="accountName")
    def account_name(self) -> builtins.str:
        return jsii.get(self, "accountName")

    @account_name.setter # type: ignore
    def account_name(self, value: builtins.str) -> None:
        jsii.set(self, "accountName", value)

    @builtins.property # type: ignore
    @jsii.member(jsii_name="databaseName")
    def database_name(self) -> builtins.str:
        return jsii.get(self, "databaseName")

    @database_name.setter # type: ignore
    def database_name(self, value: builtins.str) -> None:
        jsii.set(self, "databaseName", value)

    @builtins.property # type: ignore
    @jsii.member(jsii_name="name")
    def name(self) -> builtins.str:
        return jsii.get(self, "name")

    @name.setter # type: ignore
    def name(self, value: builtins.str) -> None:
        jsii.set(self, "name", value)

    @builtins.property # type: ignore
    @jsii.member(jsii_name="resourceGroupName")
    def resource_group_name(self) -> builtins.str:
        return jsii.get(self, "resourceGroupName")

    @resource_group_name.setter # type: ignore
    def resource_group_name(self, value: builtins.str) -> None:
        jsii.set(self, "resourceGroupName", value)

    @builtins.property # type: ignore
    @jsii.member(jsii_name="defaultTtlSeconds")
    def default_ttl_seconds(self) -> typing.Optional[jsii.Number]:
        return jsii.get(self, "defaultTtlSeconds")

    @default_ttl_seconds.setter # type: ignore
    def default_ttl_seconds(self, value: typing.Optional[jsii.Number]) -> None:
        jsii.set(self, "defaultTtlSeconds", value)

    @builtins.property # type: ignore
    @jsii.member(jsii_name="id")
    def id(self) -> typing.Optional[builtins.str]:
        return jsii.get(self, "id")

    @id.setter # type: ignore
    def id(self, value: typing.Optional[builtins.str]) -> None:
        jsii.set(self, "id", value)

    @builtins.property # type: ignore
    @jsii.member(jsii_name="shardKey")
    def shard_key(self) -> typing.Optional[builtins.str]:
        return jsii.get(self, "shardKey")

    @shard_key.setter # type: ignore
    def shard_key(self, value: typing.Optional[builtins.str]) -> None:
        jsii.set(self, "shardKey", value)

    @builtins.property # type: ignore
    @jsii.member(jsii_name="throughput")
    def throughput(self) -> typing.Optional[jsii.Number]:
        return jsii.get(self, "throughput")

    @throughput.setter # type: ignore
    def throughput(self, value: typing.Optional[jsii.Number]) -> None:
        jsii.set(self, "throughput", value)

    @builtins.property # type: ignore
    @jsii.member(jsii_name="timeouts")
    def timeouts(self) -> typing.Optional["CosmosdbMongoCollectionTimeouts"]:
        return jsii.get(self, "timeouts")

    @timeouts.setter # type: ignore
    def timeouts(
        self,
        value: typing.Optional["CosmosdbMongoCollectionTimeouts"],
    ) -> None:
        jsii.set(self, "timeouts", value)


@jsii.data_type(
    jsii_type="@cdktf/provider-azurerm.CosmosdbMongoCollectionConfig",
    jsii_struct_bases=[cdktf.TerraformMetaArguments],
    name_mapping={
        "count": "count",
        "depends_on": "dependsOn",
        "lifecycle": "lifecycle",
        "provider": "provider",
        "account_name": "accountName",
        "database_name": "databaseName",
        "name": "name",
        "resource_group_name": "resourceGroupName",
        "default_ttl_seconds": "defaultTtlSeconds",
        "shard_key": "shardKey",
        "throughput": "throughput",
        "timeouts": "timeouts",
    },
)
class CosmosdbMongoCollectionConfig(cdktf.TerraformMetaArguments):
    def __init__(
        self,
        *,
        count: typing.Optional[jsii.Number] = None,
        depends_on: typing.Optional[typing.List[cdktf.TerraformResource]] = None,
        lifecycle: typing.Optional[cdktf.TerraformResourceLifecycle] = None,
        provider: typing.Optional[cdktf.TerraformProvider] = None,
        account_name: builtins.str,
        database_name: builtins.str,
        name: builtins.str,
        resource_group_name: builtins.str,
        default_ttl_seconds: typing.Optional[jsii.Number] = None,
        shard_key: typing.Optional[builtins.str] = None,
        throughput: typing.Optional[jsii.Number] = None,
        timeouts: typing.Optional["CosmosdbMongoCollectionTimeouts"] = None,
    ) -> None:
        """
        :param count: 
        :param depends_on: 
        :param lifecycle: 
        :param provider: 
        :param account_name: 
        :param database_name: 
        :param name: 
        :param resource_group_name: 
        :param default_ttl_seconds: 
        :param shard_key: 
        :param throughput: 
        :param timeouts: timeouts block.
        """
        if isinstance(lifecycle, dict):
            lifecycle = cdktf.TerraformResourceLifecycle(**lifecycle)
        if isinstance(timeouts, dict):
            timeouts = CosmosdbMongoCollectionTimeouts(**timeouts)
        self._values: typing.Dict[str, typing.Any] = {
            "account_name": account_name,
            "database_name": database_name,
            "name": name,
            "resource_group_name": resource_group_name,
        }
        if count is not None:
            self._values["count"] = count
        if depends_on is not None:
            self._values["depends_on"] = depends_on
        if lifecycle is not None:
            self._values["lifecycle"] = lifecycle
        if provider is not None:
            self._values["provider"] = provider
        if default_ttl_seconds is not None:
            self._values["default_ttl_seconds"] = default_ttl_seconds
        if shard_key is not None:
            self._values["shard_key"] = shard_key
        if throughput is not None:
            self._values["throughput"] = throughput
        if timeouts is not None:
            self._values["timeouts"] = timeouts

    @builtins.property
    def count(self) -> typing.Optional[jsii.Number]:
        """
        :stability: experimental
        """
        result = self._values.get("count")
        return result

    @builtins.property
    def depends_on(self) -> typing.Optional[typing.List[cdktf.TerraformResource]]:
        """
        :stability: experimental
        """
        result = self._values.get("depends_on")
        return result

    @builtins.property
    def lifecycle(self) -> typing.Optional[cdktf.TerraformResourceLifecycle]:
        """
        :stability: experimental
        """
        result = self._values.get("lifecycle")
        return result

    @builtins.property
    def provider(self) -> typing.Optional[cdktf.TerraformProvider]:
        """
        :stability: experimental
        """
        result = self._values.get("provider")
        return result

    @builtins.property
    def account_name(self) -> builtins.str:
        result = self._values.get("account_name")
        assert result is not None, "Required property 'account_name' is missing"
        return result

    @builtins.property
    def database_name(self) -> builtins.str:
        result = self._values.get("database_name")
        assert result is not None, "Required property 'database_name' is missing"
        return result

    @builtins.property
    def name(self) -> builtins.str:
        result = self._values.get("name")
        assert result is not None, "Required property 'name' is missing"
        return result

    @builtins.property
    def resource_group_name(self) -> builtins.str:
        result = self._values.get("resource_group_name")
        assert result is not None, "Required property 'resource_group_name' is missing"
        return result

    @builtins.property
    def default_ttl_seconds(self) -> typing.Optional[jsii.Number]:
        result = self._values.get("default_ttl_seconds")
        return result

    @builtins.property
    def shard_key(self) -> typing.Optional[builtins.str]:
        result = self._values.get("shard_key")
        return result

    @builtins.property
    def throughput(self) -> typing.Optional[jsii.Number]:
        result = self._values.get("throughput")
        return result

    @builtins.property
    def timeouts(self) -> typing.Optional["CosmosdbMongoCollectionTimeouts"]:
        """timeouts block."""
        result = self._values.get("timeouts")
        return result

    def __eq__(self, rhs: typing.Any) -> builtins.bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs: typing.Any) -> builtins.bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return "CosmosdbMongoCollectionConfig(%s)" % ", ".join(
            k + "=" + repr(v) for k, v in self._values.items()
        )


@jsii.data_type(
    jsii_type="@cdktf/provider-azurerm.CosmosdbMongoCollectionTimeouts",
    jsii_struct_bases=[],
    name_mapping={
        "create": "create",
        "delete": "delete",
        "read": "read",
        "update": "update",
    },
)
class CosmosdbMongoCollectionTimeouts:
    def __init__(
        self,
        *,
        create: typing.Optional[builtins.str] = None,
        delete: typing.Optional[builtins.str] = None,
        read: typing.Optional[builtins.str] = None,
        update: typing.Optional[builtins.str] = None,
    ) -> None:
        """
        :param create: 
        :param delete: 
        :param read: 
        :param update: 
        """
        self._values: typing.Dict[str, typing.Any] = {}
        if create is not None:
            self._values["create"] = create
        if delete is not None:
            self._values["delete"] = delete
        if read is not None:
            self._values["read"] = read
        if update is not None:
            self._values["update"] = update

    @builtins.property
    def create(self) -> typing.Optional[builtins.str]:
        result = self._values.get("create")
        return result

    @builtins.property
    def delete(self) -> typing.Optional[builtins.str]:
        result = self._values.get("delete")
        return result

    @builtins.property
    def read(self) -> typing.Optional[builtins.str]:
        result = self._values.get("read")
        return result

    @builtins.property
    def update(self) -> typing.Optional[builtins.str]:
        result = self._values.get("update")
        return result

    def __eq__(self, rhs: typing.Any) -> builtins.bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs: typing.Any) -> builtins.bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return "CosmosdbMongoCollectionTimeouts(%s)" % ", ".join(
            k + "=" + repr(v) for k, v in self._values.items()
        )


class CosmosdbMongoDatabase(
    cdktf.TerraformResource,
    metaclass=jsii.JSIIMeta,
    jsii_type="@cdktf/provider-azurerm.CosmosdbMongoDatabase",
):
    def __init__(
        self,
        scope: constructs.Construct,
        id: builtins.str,
        *,
        account_name: builtins.str,
        name: builtins.str,
        resource_group_name: builtins.str,
        throughput: typing.Optional[jsii.Number] = None,
        timeouts: typing.Optional["CosmosdbMongoDatabaseTimeouts"] = None,
        count: typing.Optional[jsii.Number] = None,
        depends_on: typing.Optional[typing.List[cdktf.TerraformResource]] = None,
        lifecycle: typing.Optional[cdktf.TerraformResourceLifecycle] = None,
        provider: typing.Optional[cdktf.TerraformProvider] = None,
    ) -> None:
        """
        :param scope: -
        :param id: -
        :param account_name: 
        :param name: 
        :param resource_group_name: 
        :param throughput: 
        :param timeouts: timeouts block.
        :param count: 
        :param depends_on: 
        :param lifecycle: 
        :param provider: 
        """
        config = CosmosdbMongoDatabaseConfig(
            account_name=account_name,
            name=name,
            resource_group_name=resource_group_name,
            throughput=throughput,
            timeouts=timeouts,
            count=count,
            depends_on=depends_on,
            lifecycle=lifecycle,
            provider=provider,
        )

        jsii.create(CosmosdbMongoDatabase, self, [scope, id, config])

    @jsii.member(jsii_name="synthesizeAttributes")
    def _synthesize_attributes(self) -> typing.Mapping[builtins.str, typing.Any]:
        return jsii.invoke(self, "synthesizeAttributes", [])

    @builtins.property # type: ignore
    @jsii.member(jsii_name="accountName")
    def account_name(self) -> builtins.str:
        return jsii.get(self, "accountName")

    @account_name.setter # type: ignore
    def account_name(self, value: builtins.str) -> None:
        jsii.set(self, "accountName", value)

    @builtins.property # type: ignore
    @jsii.member(jsii_name="name")
    def name(self) -> builtins.str:
        return jsii.get(self, "name")

    @name.setter # type: ignore
    def name(self, value: builtins.str) -> None:
        jsii.set(self, "name", value)

    @builtins.property # type: ignore
    @jsii.member(jsii_name="resourceGroupName")
    def resource_group_name(self) -> builtins.str:
        return jsii.get(self, "resourceGroupName")

    @resource_group_name.setter # type: ignore
    def resource_group_name(self, value: builtins.str) -> None:
        jsii.set(self, "resourceGroupName", value)

    @builtins.property # type: ignore
    @jsii.member(jsii_name="id")
    def id(self) -> typing.Optional[builtins.str]:
        return jsii.get(self, "id")

    @id.setter # type: ignore
    def id(self, value: typing.Optional[builtins.str]) -> None:
        jsii.set(self, "id", value)

    @builtins.property # type: ignore
    @jsii.member(jsii_name="throughput")
    def throughput(self) -> typing.Optional[jsii.Number]:
        return jsii.get(self, "throughput")

    @throughput.setter # type: ignore
    def throughput(self, value: typing.Optional[jsii.Number]) -> None:
        jsii.set(self, "throughput", value)

    @builtins.property # type: ignore
    @jsii.member(jsii_name="timeouts")
    def timeouts(self) -> typing.Optional["CosmosdbMongoDatabaseTimeouts"]:
        return jsii.get(self, "timeouts")

    @timeouts.setter # type: ignore
    def timeouts(self, value: typing.Optional["CosmosdbMongoDatabaseTimeouts"]) -> None:
        jsii.set(self, "timeouts", value)


@jsii.data_type(
    jsii_type="@cdktf/provider-azurerm.CosmosdbMongoDatabaseConfig",
    jsii_struct_bases=[cdktf.TerraformMetaArguments],
    name_mapping={
        "count": "count",
        "depends_on": "dependsOn",
        "lifecycle": "lifecycle",
        "provider": "provider",
        "account_name": "accountName",
        "name": "name",
        "resource_group_name": "resourceGroupName",
        "throughput": "throughput",
        "timeouts": "timeouts",
    },
)
class CosmosdbMongoDatabaseConfig(cdktf.TerraformMetaArguments):
    def __init__(
        self,
        *,
        count: typing.Optional[jsii.Number] = None,
        depends_on: typing.Optional[typing.List[cdktf.TerraformResource]] = None,
        lifecycle: typing.Optional[cdktf.TerraformResourceLifecycle] = None,
        provider: typing.Optional[cdktf.TerraformProvider] = None,
        account_name: builtins.str,
        name: builtins.str,
        resource_group_name: builtins.str,
        throughput: typing.Optional[jsii.Number] = None,
        timeouts: typing.Optional["CosmosdbMongoDatabaseTimeouts"] = None,
    ) -> None:
        """
        :param count: 
        :param depends_on: 
        :param lifecycle: 
        :param provider: 
        :param account_name: 
        :param name: 
        :param resource_group_name: 
        :param throughput: 
        :param timeouts: timeouts block.
        """
        if isinstance(lifecycle, dict):
            lifecycle = cdktf.TerraformResourceLifecycle(**lifecycle)
        if isinstance(timeouts, dict):
            timeouts = CosmosdbMongoDatabaseTimeouts(**timeouts)
        self._values: typing.Dict[str, typing.Any] = {
            "account_name": account_name,
            "name": name,
            "resource_group_name": resource_group_name,
        }
        if count is not None:
            self._values["count"] = count
        if depends_on is not None:
            self._values["depends_on"] = depends_on
        if lifecycle is not None:
            self._values["lifecycle"] = lifecycle
        if provider is not None:
            self._values["provider"] = provider
        if throughput is not None:
            self._values["throughput"] = throughput
        if timeouts is not None:
            self._values["timeouts"] = timeouts

    @builtins.property
    def count(self) -> typing.Optional[jsii.Number]:
        """
        :stability: experimental
        """
        result = self._values.get("count")
        return result

    @builtins.property
    def depends_on(self) -> typing.Optional[typing.List[cdktf.TerraformResource]]:
        """
        :stability: experimental
        """
        result = self._values.get("depends_on")
        return result

    @builtins.property
    def lifecycle(self) -> typing.Optional[cdktf.TerraformResourceLifecycle]:
        """
        :stability: experimental
        """
        result = self._values.get("lifecycle")
        return result

    @builtins.property
    def provider(self) -> typing.Optional[cdktf.TerraformProvider]:
        """
        :stability: experimental
        """
        result = self._values.get("provider")
        return result

    @builtins.property
    def account_name(self) -> builtins.str:
        result = self._values.get("account_name")
        assert result is not None, "Required property 'account_name' is missing"
        return result

    @builtins.property
    def name(self) -> builtins.str:
        result = self._values.get("name")
        assert result is not None, "Required property 'name' is missing"
        return result

    @builtins.property
    def resource_group_name(self) -> builtins.str:
        result = self._values.get("resource_group_name")
        assert result is not None, "Required property 'resource_group_name' is missing"
        return result

    @builtins.property
    def throughput(self) -> typing.Optional[jsii.Number]:
        result = self._values.get("throughput")
        return result

    @builtins.property
    def timeouts(self) -> typing.Optional["CosmosdbMongoDatabaseTimeouts"]:
        """timeouts block."""
        result = self._values.get("timeouts")
        return result

    def __eq__(self, rhs: typing.Any) -> builtins.bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs: typing.Any) -> builtins.bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return "CosmosdbMongoDatabaseConfig(%s)" % ", ".join(
            k + "=" + repr(v) for k, v in self._values.items()
        )


@jsii.data_type(
    jsii_type="@cdktf/provider-azurerm.CosmosdbMongoDatabaseTimeouts",
    jsii_struct_bases=[],
    name_mapping={
        "create": "create",
        "delete": "delete",
        "read": "read",
        "update": "update",
    },
)
class CosmosdbMongoDatabaseTimeouts:
    def __init__(
        self,
        *,
        create: typing.Optional[builtins.str] = None,
        delete: typing.Optional[builtins.str] = None,
        read: typing.Optional[builtins.str] = None,
        update: typing.Optional[builtins.str] = None,
    ) -> None:
        """
        :param create: 
        :param delete: 
        :param read: 
        :param update: 
        """
        self._values: typing.Dict[str, typing.Any] = {}
        if create is not None:
            self._values["create"] = create
        if delete is not None:
            self._values["delete"] = delete
        if read is not None:
            self._values["read"] = read
        if update is not None:
            self._values["update"] = update

    @builtins.property
    def create(self) -> typing.Optional[builtins.str]:
        result = self._values.get("create")
        return result

    @builtins.property
    def delete(self) -> typing.Optional[builtins.str]:
        result = self._values.get("delete")
        return result

    @builtins.property
    def read(self) -> typing.Optional[builtins.str]:
        result = self._values.get("read")
        return result

    @builtins.property
    def update(self) -> typing.Optional[builtins.str]:
        result = self._values.get("update")
        return result

    def __eq__(self, rhs: typing.Any) -> builtins.bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs: typing.Any) -> builtins.bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return "CosmosdbMongoDatabaseTimeouts(%s)" % ", ".join(
            k + "=" + repr(v) for k, v in self._values.items()
        )


class CosmosdbSqlContainer(
    cdktf.TerraformResource,
    metaclass=jsii.JSIIMeta,
    jsii_type="@cdktf/provider-azurerm.CosmosdbSqlContainer",
):
    def __init__(
        self,
        scope: constructs.Construct,
        id: builtins.str,
        *,
        account_name: builtins.str,
        database_name: builtins.str,
        name: builtins.str,
        resource_group_name: builtins.str,
        default_ttl: typing.Optional[jsii.Number] = None,
        partition_key_path: typing.Optional[builtins.str] = None,
        throughput: typing.Optional[jsii.Number] = None,
        timeouts: typing.Optional["CosmosdbSqlContainerTimeouts"] = None,
        unique_key: typing.Optional[typing.List["CosmosdbSqlContainerUniqueKey"]] = None,
        count: typing.Optional[jsii.Number] = None,
        depends_on: typing.Optional[typing.List[cdktf.TerraformResource]] = None,
        lifecycle: typing.Optional[cdktf.TerraformResourceLifecycle] = None,
        provider: typing.Optional[cdktf.TerraformProvider] = None,
    ) -> None:
        """
        :param scope: -
        :param id: -
        :param account_name: 
        :param database_name: 
        :param name: 
        :param resource_group_name: 
        :param default_ttl: 
        :param partition_key_path: 
        :param throughput: 
        :param timeouts: timeouts block.
        :param unique_key: unique_key block.
        :param count: 
        :param depends_on: 
        :param lifecycle: 
        :param provider: 
        """
        config = CosmosdbSqlContainerConfig(
            account_name=account_name,
            database_name=database_name,
            name=name,
            resource_group_name=resource_group_name,
            default_ttl=default_ttl,
            partition_key_path=partition_key_path,
            throughput=throughput,
            timeouts=timeouts,
            unique_key=unique_key,
            count=count,
            depends_on=depends_on,
            lifecycle=lifecycle,
            provider=provider,
        )

        jsii.create(CosmosdbSqlContainer, self, [scope, id, config])

    @jsii.member(jsii_name="synthesizeAttributes")
    def _synthesize_attributes(self) -> typing.Mapping[builtins.str, typing.Any]:
        return jsii.invoke(self, "synthesizeAttributes", [])

    @builtins.property # type: ignore
    @jsii.member(jsii_name="accountName")
    def account_name(self) -> builtins.str:
        return jsii.get(self, "accountName")

    @account_name.setter # type: ignore
    def account_name(self, value: builtins.str) -> None:
        jsii.set(self, "accountName", value)

    @builtins.property # type: ignore
    @jsii.member(jsii_name="databaseName")
    def database_name(self) -> builtins.str:
        return jsii.get(self, "databaseName")

    @database_name.setter # type: ignore
    def database_name(self, value: builtins.str) -> None:
        jsii.set(self, "databaseName", value)

    @builtins.property # type: ignore
    @jsii.member(jsii_name="name")
    def name(self) -> builtins.str:
        return jsii.get(self, "name")

    @name.setter # type: ignore
    def name(self, value: builtins.str) -> None:
        jsii.set(self, "name", value)

    @builtins.property # type: ignore
    @jsii.member(jsii_name="resourceGroupName")
    def resource_group_name(self) -> builtins.str:
        return jsii.get(self, "resourceGroupName")

    @resource_group_name.setter # type: ignore
    def resource_group_name(self, value: builtins.str) -> None:
        jsii.set(self, "resourceGroupName", value)

    @builtins.property # type: ignore
    @jsii.member(jsii_name="defaultTtl")
    def default_ttl(self) -> typing.Optional[jsii.Number]:
        return jsii.get(self, "defaultTtl")

    @default_ttl.setter # type: ignore
    def default_ttl(self, value: typing.Optional[jsii.Number]) -> None:
        jsii.set(self, "defaultTtl", value)

    @builtins.property # type: ignore
    @jsii.member(jsii_name="id")
    def id(self) -> typing.Optional[builtins.str]:
        return jsii.get(self, "id")

    @id.setter # type: ignore
    def id(self, value: typing.Optional[builtins.str]) -> None:
        jsii.set(self, "id", value)

    @builtins.property # type: ignore
    @jsii.member(jsii_name="partitionKeyPath")
    def partition_key_path(self) -> typing.Optional[builtins.str]:
        return jsii.get(self, "partitionKeyPath")

    @partition_key_path.setter # type: ignore
    def partition_key_path(self, value: typing.Optional[builtins.str]) -> None:
        jsii.set(self, "partitionKeyPath", value)

    @builtins.property # type: ignore
    @jsii.member(jsii_name="throughput")
    def throughput(self) -> typing.Optional[jsii.Number]:
        return jsii.get(self, "throughput")

    @throughput.setter # type: ignore
    def throughput(self, value: typing.Optional[jsii.Number]) -> None:
        jsii.set(self, "throughput", value)

    @builtins.property # type: ignore
    @jsii.member(jsii_name="timeouts")
    def timeouts(self) -> typing.Optional["CosmosdbSqlContainerTimeouts"]:
        return jsii.get(self, "timeouts")

    @timeouts.setter # type: ignore
    def timeouts(self, value: typing.Optional["CosmosdbSqlContainerTimeouts"]) -> None:
        jsii.set(self, "timeouts", value)

    @builtins.property # type: ignore
    @jsii.member(jsii_name="uniqueKey")
    def unique_key(
        self,
    ) -> typing.Optional[typing.List["CosmosdbSqlContainerUniqueKey"]]:
        return jsii.get(self, "uniqueKey")

    @unique_key.setter # type: ignore
    def unique_key(
        self,
        value: typing.Optional[typing.List["CosmosdbSqlContainerUniqueKey"]],
    ) -> None:
        jsii.set(self, "uniqueKey", value)


@jsii.data_type(
    jsii_type="@cdktf/provider-azurerm.CosmosdbSqlContainerConfig",
    jsii_struct_bases=[cdktf.TerraformMetaArguments],
    name_mapping={
        "count": "count",
        "depends_on": "dependsOn",
        "lifecycle": "lifecycle",
        "provider": "provider",
        "account_name": "accountName",
        "database_name": "databaseName",
        "name": "name",
        "resource_group_name": "resourceGroupName",
        "default_ttl": "defaultTtl",
        "partition_key_path": "partitionKeyPath",
        "throughput": "throughput",
        "timeouts": "timeouts",
        "unique_key": "uniqueKey",
    },
)
class CosmosdbSqlContainerConfig(cdktf.TerraformMetaArguments):
    def __init__(
        self,
        *,
        count: typing.Optional[jsii.Number] = None,
        depends_on: typing.Optional[typing.List[cdktf.TerraformResource]] = None,
        lifecycle: typing.Optional[cdktf.TerraformResourceLifecycle] = None,
        provider: typing.Optional[cdktf.TerraformProvider] = None,
        account_name: builtins.str,
        database_name: builtins.str,
        name: builtins.str,
        resource_group_name: builtins.str,
        default_ttl: typing.Optional[jsii.Number] = None,
        partition_key_path: typing.Optional[builtins.str] = None,
        throughput: typing.Optional[jsii.Number] = None,
        timeouts: typing.Optional["CosmosdbSqlContainerTimeouts"] = None,
        unique_key: typing.Optional[typing.List["CosmosdbSqlContainerUniqueKey"]] = None,
    ) -> None:
        """
        :param count: 
        :param depends_on: 
        :param lifecycle: 
        :param provider: 
        :param account_name: 
        :param database_name: 
        :param name: 
        :param resource_group_name: 
        :param default_ttl: 
        :param partition_key_path: 
        :param throughput: 
        :param timeouts: timeouts block.
        :param unique_key: unique_key block.
        """
        if isinstance(lifecycle, dict):
            lifecycle = cdktf.TerraformResourceLifecycle(**lifecycle)
        if isinstance(timeouts, dict):
            timeouts = CosmosdbSqlContainerTimeouts(**timeouts)
        self._values: typing.Dict[str, typing.Any] = {
            "account_name": account_name,
            "database_name": database_name,
            "name": name,
            "resource_group_name": resource_group_name,
        }
        if count is not None:
            self._values["count"] = count
        if depends_on is not None:
            self._values["depends_on"] = depends_on
        if lifecycle is not None:
            self._values["lifecycle"] = lifecycle
        if provider is not None:
            self._values["provider"] = provider
        if default_ttl is not None:
            self._values["default_ttl"] = default_ttl
        if partition_key_path is not None:
            self._values["partition_key_path"] = partition_key_path
        if throughput is not None:
            self._values["throughput"] = throughput
        if timeouts is not None:
            self._values["timeouts"] = timeouts
        if unique_key is not None:
            self._values["unique_key"] = unique_key

    @builtins.property
    def count(self) -> typing.Optional[jsii.Number]:
        """
        :stability: experimental
        """
        result = self._values.get("count")
        return result

    @builtins.property
    def depends_on(self) -> typing.Optional[typing.List[cdktf.TerraformResource]]:
        """
        :stability: experimental
        """
        result = self._values.get("depends_on")
        return result

    @builtins.property
    def lifecycle(self) -> typing.Optional[cdktf.TerraformResourceLifecycle]:
        """
        :stability: experimental
        """
        result = self._values.get("lifecycle")
        return result

    @builtins.property
    def provider(self) -> typing.Optional[cdktf.TerraformProvider]:
        """
        :stability: experimental
        """
        result = self._values.get("provider")
        return result

    @builtins.property
    def account_name(self) -> builtins.str:
        result = self._values.get("account_name")
        assert result is not None, "Required property 'account_name' is missing"
        return result

    @builtins.property
    def database_name(self) -> builtins.str:
        result = self._values.get("database_name")
        assert result is not None, "Required property 'database_name' is missing"
        return result

    @builtins.property
    def name(self) -> builtins.str:
        result = self._values.get("name")
        assert result is not None, "Required property 'name' is missing"
        return result

    @builtins.property
    def resource_group_name(self) -> builtins.str:
        result = self._values.get("resource_group_name")
        assert result is not None, "Required property 'resource_group_name' is missing"
        return result

    @builtins.property
    def default_ttl(self) -> typing.Optional[jsii.Number]:
        result = self._values.get("default_ttl")
        return result

    @builtins.property
    def partition_key_path(self) -> typing.Optional[builtins.str]:
        result = self._values.get("partition_key_path")
        return result

    @builtins.property
    def throughput(self) -> typing.Optional[jsii.Number]:
        result = self._values.get("throughput")
        return result

    @builtins.property
    def timeouts(self) -> typing.Optional["CosmosdbSqlContainerTimeouts"]:
        """timeouts block."""
        result = self._values.get("timeouts")
        return result

    @builtins.property
    def unique_key(
        self,
    ) -> typing.Optional[typing.List["CosmosdbSqlContainerUniqueKey"]]:
        """unique_key block."""
        result = self._values.get("unique_key")
        return result

    def __eq__(self, rhs: typing.Any) -> builtins.bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs: typing.Any) -> builtins.bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return "CosmosdbSqlContainerConfig(%s)" % ", ".join(
            k + "=" + repr(v) for k, v in self._values.items()
        )


@jsii.data_type(
    jsii_type="@cdktf/provider-azurerm.CosmosdbSqlContainerTimeouts",
    jsii_struct_bases=[],
    name_mapping={
        "create": "create",
        "delete": "delete",
        "read": "read",
        "update": "update",
    },
)
class CosmosdbSqlContainerTimeouts:
    def __init__(
        self,
        *,
        create: typing.Optional[builtins.str] = None,
        delete: typing.Optional[builtins.str] = None,
        read: typing.Optional[builtins.str] = None,
        update: typing.Optional[builtins.str] = None,
    ) -> None:
        """
        :param create: 
        :param delete: 
        :param read: 
        :param update: 
        """
        self._values: typing.Dict[str, typing.Any] = {}
        if create is not None:
            self._values["create"] = create
        if delete is not None:
            self._values["delete"] = delete
        if read is not None:
            self._values["read"] = read
        if update is not None:
            self._values["update"] = update

    @builtins.property
    def create(self) -> typing.Optional[builtins.str]:
        result = self._values.get("create")
        return result

    @builtins.property
    def delete(self) -> typing.Optional[builtins.str]:
        result = self._values.get("delete")
        return result

    @builtins.property
    def read(self) -> typing.Optional[builtins.str]:
        result = self._values.get("read")
        return result

    @builtins.property
    def update(self) -> typing.Optional[builtins.str]:
        result = self._values.get("update")
        return result

    def __eq__(self, rhs: typing.Any) -> builtins.bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs: typing.Any) -> builtins.bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return "CosmosdbSqlContainerTimeouts(%s)" % ", ".join(
            k + "=" + repr(v) for k, v in self._values.items()
        )


@jsii.data_type(
    jsii_type="@cdktf/provider-azurerm.CosmosdbSqlContainerUniqueKey",
    jsii_struct_bases=[],
    name_mapping={"paths": "paths"},
)
class CosmosdbSqlContainerUniqueKey:
    def __init__(self, *, paths: typing.List[builtins.str]) -> None:
        """
        :param paths: 
        """
        self._values: typing.Dict[str, typing.Any] = {
            "paths": paths,
        }

    @builtins.property
    def paths(self) -> typing.List[builtins.str]:
        result = self._values.get("paths")
        assert result is not None, "Required property 'paths' is missing"
        return result

    def __eq__(self, rhs: typing.Any) -> builtins.bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs: typing.Any) -> builtins.bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return "CosmosdbSqlContainerUniqueKey(%s)" % ", ".join(
            k + "=" + repr(v) for k, v in self._values.items()
        )


class CosmosdbSqlDatabase(
    cdktf.TerraformResource,
    metaclass=jsii.JSIIMeta,
    jsii_type="@cdktf/provider-azurerm.CosmosdbSqlDatabase",
):
    def __init__(
        self,
        scope: constructs.Construct,
        id: builtins.str,
        *,
        account_name: builtins.str,
        name: builtins.str,
        resource_group_name: builtins.str,
        throughput: typing.Optional[jsii.Number] = None,
        timeouts: typing.Optional["CosmosdbSqlDatabaseTimeouts"] = None,
        count: typing.Optional[jsii.Number] = None,
        depends_on: typing.Optional[typing.List[cdktf.TerraformResource]] = None,
        lifecycle: typing.Optional[cdktf.TerraformResourceLifecycle] = None,
        provider: typing.Optional[cdktf.TerraformProvider] = None,
    ) -> None:
        """
        :param scope: -
        :param id: -
        :param account_name: 
        :param name: 
        :param resource_group_name: 
        :param throughput: 
        :param timeouts: timeouts block.
        :param count: 
        :param depends_on: 
        :param lifecycle: 
        :param provider: 
        """
        config = CosmosdbSqlDatabaseConfig(
            account_name=account_name,
            name=name,
            resource_group_name=resource_group_name,
            throughput=throughput,
            timeouts=timeouts,
            count=count,
            depends_on=depends_on,
            lifecycle=lifecycle,
            provider=provider,
        )

        jsii.create(CosmosdbSqlDatabase, self, [scope, id, config])

    @jsii.member(jsii_name="synthesizeAttributes")
    def _synthesize_attributes(self) -> typing.Mapping[builtins.str, typing.Any]:
        return jsii.invoke(self, "synthesizeAttributes", [])

    @builtins.property # type: ignore
    @jsii.member(jsii_name="accountName")
    def account_name(self) -> builtins.str:
        return jsii.get(self, "accountName")

    @account_name.setter # type: ignore
    def account_name(self, value: builtins.str) -> None:
        jsii.set(self, "accountName", value)

    @builtins.property # type: ignore
    @jsii.member(jsii_name="name")
    def name(self) -> builtins.str:
        return jsii.get(self, "name")

    @name.setter # type: ignore
    def name(self, value: builtins.str) -> None:
        jsii.set(self, "name", value)

    @builtins.property # type: ignore
    @jsii.member(jsii_name="resourceGroupName")
    def resource_group_name(self) -> builtins.str:
        return jsii.get(self, "resourceGroupName")

    @resource_group_name.setter # type: ignore
    def resource_group_name(self, value: builtins.str) -> None:
        jsii.set(self, "resourceGroupName", value)

    @builtins.property # type: ignore
    @jsii.member(jsii_name="id")
    def id(self) -> typing.Optional[builtins.str]:
        return jsii.get(self, "id")

    @id.setter # type: ignore
    def id(self, value: typing.Optional[builtins.str]) -> None:
        jsii.set(self, "id", value)

    @builtins.property # type: ignore
    @jsii.member(jsii_name="throughput")
    def throughput(self) -> typing.Optional[jsii.Number]:
        return jsii.get(self, "throughput")

    @throughput.setter # type: ignore
    def throughput(self, value: typing.Optional[jsii.Number]) -> None:
        jsii.set(self, "throughput", value)

    @builtins.property # type: ignore
    @jsii.member(jsii_name="timeouts")
    def timeouts(self) -> typing.Optional["CosmosdbSqlDatabaseTimeouts"]:
        return jsii.get(self, "timeouts")

    @timeouts.setter # type: ignore
    def timeouts(self, value: typing.Optional["CosmosdbSqlDatabaseTimeouts"]) -> None:
        jsii.set(self, "timeouts", value)


@jsii.data_type(
    jsii_type="@cdktf/provider-azurerm.CosmosdbSqlDatabaseConfig",
    jsii_struct_bases=[cdktf.TerraformMetaArguments],
    name_mapping={
        "count": "count",
        "depends_on": "dependsOn",
        "lifecycle": "lifecycle",
        "provider": "provider",
        "account_name": "accountName",
        "name": "name",
        "resource_group_name": "resourceGroupName",
        "throughput": "throughput",
        "timeouts": "timeouts",
    },
)
class CosmosdbSqlDatabaseConfig(cdktf.TerraformMetaArguments):
    def __init__(
        self,
        *,
        count: typing.Optional[jsii.Number] = None,
        depends_on: typing.Optional[typing.List[cdktf.TerraformResource]] = None,
        lifecycle: typing.Optional[cdktf.TerraformResourceLifecycle] = None,
        provider: typing.Optional[cdktf.TerraformProvider] = None,
        account_name: builtins.str,
        name: builtins.str,
        resource_group_name: builtins.str,
        throughput: typing.Optional[jsii.Number] = None,
        timeouts: typing.Optional["CosmosdbSqlDatabaseTimeouts"] = None,
    ) -> None:
        """
        :param count: 
        :param depends_on: 
        :param lifecycle: 
        :param provider: 
        :param account_name: 
        :param name: 
        :param resource_group_name: 
        :param throughput: 
        :param timeouts: timeouts block.
        """
        if isinstance(lifecycle, dict):
            lifecycle = cdktf.TerraformResourceLifecycle(**lifecycle)
        if isinstance(timeouts, dict):
            timeouts = CosmosdbSqlDatabaseTimeouts(**timeouts)
        self._values: typing.Dict[str, typing.Any] = {
            "account_name": account_name,
            "name": name,
            "resource_group_name": resource_group_name,
        }
        if count is not None:
            self._values["count"] = count
        if depends_on is not None:
            self._values["depends_on"] = depends_on
        if lifecycle is not None:
            self._values["lifecycle"] = lifecycle
        if provider is not None:
            self._values["provider"] = provider
        if throughput is not None:
            self._values["throughput"] = throughput
        if timeouts is not None:
            self._values["timeouts"] = timeouts

    @builtins.property
    def count(self) -> typing.Optional[jsii.Number]:
        """
        :stability: experimental
        """
        result = self._values.get("count")
        return result

    @builtins.property
    def depends_on(self) -> typing.Optional[typing.List[cdktf.TerraformResource]]:
        """
        :stability: experimental
        """
        result = self._values.get("depends_on")
        return result

    @builtins.property
    def lifecycle(self) -> typing.Optional[cdktf.TerraformResourceLifecycle]:
        """
        :stability: experimental
        """
        result = self._values.get("lifecycle")
        return result

    @builtins.property
    def provider(self) -> typing.Optional[cdktf.TerraformProvider]:
        """
        :stability: experimental
        """
        result = self._values.get("provider")
        return result

    @builtins.property
    def account_name(self) -> builtins.str:
        result = self._values.get("account_name")
        assert result is not None, "Required property 'account_name' is missing"
        return result

    @builtins.property
    def name(self) -> builtins.str:
        result = self._values.get("name")
        assert result is not None, "Required property 'name' is missing"
        return result

    @builtins.property
    def resource_group_name(self) -> builtins.str:
        result = self._values.get("resource_group_name")
        assert result is not None, "Required property 'resource_group_name' is missing"
        return result

    @builtins.property
    def throughput(self) -> typing.Optional[jsii.Number]:
        result = self._values.get("throughput")
        return result

    @builtins.property
    def timeouts(self) -> typing.Optional["CosmosdbSqlDatabaseTimeouts"]:
        """timeouts block."""
        result = self._values.get("timeouts")
        return result

    def __eq__(self, rhs: typing.Any) -> builtins.bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs: typing.Any) -> builtins.bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return "CosmosdbSqlDatabaseConfig(%s)" % ", ".join(
            k + "=" + repr(v) for k, v in self._values.items()
        )


@jsii.data_type(
    jsii_type="@cdktf/provider-azurerm.CosmosdbSqlDatabaseTimeouts",
    jsii_struct_bases=[],
    name_mapping={
        "create": "create",
        "delete": "delete",
        "read": "read",
        "update": "update",
    },
)
class CosmosdbSqlDatabaseTimeouts:
    def __init__(
        self,
        *,
        create: typing.Optional[builtins.str] = None,
        delete: typing.Optional[builtins.str] = None,
        read: typing.Optional[builtins.str] = None,
        update: typing.Optional[builtins.str] = None,
    ) -> None:
        """
        :param create: 
        :param delete: 
        :param read: 
        :param update: 
        """
        self._values: typing.Dict[str, typing.Any] = {}
        if create is not None:
            self._values["create"] = create
        if delete is not None:
            self._values["delete"] = delete
        if read is not None:
            self._values["read"] = read
        if update is not None:
            self._values["update"] = update

    @builtins.property
    def create(self) -> typing.Optional[builtins.str]:
        result = self._values.get("create")
        return result

    @builtins.property
    def delete(self) -> typing.Optional[builtins.str]:
        result = self._values.get("delete")
        return result

    @builtins.property
    def read(self) -> typing.Optional[builtins.str]:
        result = self._values.get("read")
        return result

    @builtins.property
    def update(self) -> typing.Optional[builtins.str]:
        result = self._values.get("update")
        return result

    def __eq__(self, rhs: typing.Any) -> builtins.bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs: typing.Any) -> builtins.bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return "CosmosdbSqlDatabaseTimeouts(%s)" % ", ".join(
            k + "=" + repr(v) for k, v in self._values.items()
        )


class CosmosdbTable(
    cdktf.TerraformResource,
    metaclass=jsii.JSIIMeta,
    jsii_type="@cdktf/provider-azurerm.CosmosdbTable",
):
    def __init__(
        self,
        scope: constructs.Construct,
        id: builtins.str,
        *,
        account_name: builtins.str,
        name: builtins.str,
        resource_group_name: builtins.str,
        throughput: typing.Optional[jsii.Number] = None,
        timeouts: typing.Optional["CosmosdbTableTimeouts"] = None,
        count: typing.Optional[jsii.Number] = None,
        depends_on: typing.Optional[typing.List[cdktf.TerraformResource]] = None,
        lifecycle: typing.Optional[cdktf.TerraformResourceLifecycle] = None,
        provider: typing.Optional[cdktf.TerraformProvider] = None,
    ) -> None:
        """
        :param scope: -
        :param id: -
        :param account_name: 
        :param name: 
        :param resource_group_name: 
        :param throughput: 
        :param timeouts: timeouts block.
        :param count: 
        :param depends_on: 
        :param lifecycle: 
        :param provider: 
        """
        config = CosmosdbTableConfig(
            account_name=account_name,
            name=name,
            resource_group_name=resource_group_name,
            throughput=throughput,
            timeouts=timeouts,
            count=count,
            depends_on=depends_on,
            lifecycle=lifecycle,
            provider=provider,
        )

        jsii.create(CosmosdbTable, self, [scope, id, config])

    @jsii.member(jsii_name="synthesizeAttributes")
    def _synthesize_attributes(self) -> typing.Mapping[builtins.str, typing.Any]:
        return jsii.invoke(self, "synthesizeAttributes", [])

    @builtins.property # type: ignore
    @jsii.member(jsii_name="accountName")
    def account_name(self) -> builtins.str:
        return jsii.get(self, "accountName")

    @account_name.setter # type: ignore
    def account_name(self, value: builtins.str) -> None:
        jsii.set(self, "accountName", value)

    @builtins.property # type: ignore
    @jsii.member(jsii_name="name")
    def name(self) -> builtins.str:
        return jsii.get(self, "name")

    @name.setter # type: ignore
    def name(self, value: builtins.str) -> None:
        jsii.set(self, "name", value)

    @builtins.property # type: ignore
    @jsii.member(jsii_name="resourceGroupName")
    def resource_group_name(self) -> builtins.str:
        return jsii.get(self, "resourceGroupName")

    @resource_group_name.setter # type: ignore
    def resource_group_name(self, value: builtins.str) -> None:
        jsii.set(self, "resourceGroupName", value)

    @builtins.property # type: ignore
    @jsii.member(jsii_name="id")
    def id(self) -> typing.Optional[builtins.str]:
        return jsii.get(self, "id")

    @id.setter # type: ignore
    def id(self, value: typing.Optional[builtins.str]) -> None:
        jsii.set(self, "id", value)

    @builtins.property # type: ignore
    @jsii.member(jsii_name="throughput")
    def throughput(self) -> typing.Optional[jsii.Number]:
        return jsii.get(self, "throughput")

    @throughput.setter # type: ignore
    def throughput(self, value: typing.Optional[jsii.Number]) -> None:
        jsii.set(self, "throughput", value)

    @builtins.property # type: ignore
    @jsii.member(jsii_name="timeouts")
    def timeouts(self) -> typing.Optional["CosmosdbTableTimeouts"]:
        return jsii.get(self, "timeouts")

    @timeouts.setter # type: ignore
    def timeouts(self, value: typing.Optional["CosmosdbTableTimeouts"]) -> None:
        jsii.set(self, "timeouts", value)


@jsii.data_type(
    jsii_type="@cdktf/provider-azurerm.CosmosdbTableConfig",
    jsii_struct_bases=[cdktf.TerraformMetaArguments],
    name_mapping={
        "count": "count",
        "depends_on": "dependsOn",
        "lifecycle": "lifecycle",
        "provider": "provider",
        "account_name": "accountName",
        "name": "name",
        "resource_group_name": "resourceGroupName",
        "throughput": "throughput",
        "timeouts": "timeouts",
    },
)
class CosmosdbTableConfig(cdktf.TerraformMetaArguments):
    def __init__(
        self,
        *,
        count: typing.Optional[jsii.Number] = None,
        depends_on: typing.Optional[typing.List[cdktf.TerraformResource]] = None,
        lifecycle: typing.Optional[cdktf.TerraformResourceLifecycle] = None,
        provider: typing.Optional[cdktf.TerraformProvider] = None,
        account_name: builtins.str,
        name: builtins.str,
        resource_group_name: builtins.str,
        throughput: typing.Optional[jsii.Number] = None,
        timeouts: typing.Optional["CosmosdbTableTimeouts"] = None,
    ) -> None:
        """
        :param count: 
        :param depends_on: 
        :param lifecycle: 
        :param provider: 
        :param account_name: 
        :param name: 
        :param resource_group_name: 
        :param throughput: 
        :param timeouts: timeouts block.
        """
        if isinstance(lifecycle, dict):
            lifecycle = cdktf.TerraformResourceLifecycle(**lifecycle)
        if isinstance(timeouts, dict):
            timeouts = CosmosdbTableTimeouts(**timeouts)
        self._values: typing.Dict[str, typing.Any] = {
            "account_name": account_name,
            "name": name,
            "resource_group_name": resource_group_name,
        }
        if count is not None:
            self._values["count"] = count
        if depends_on is not None:
            self._values["depends_on"] = depends_on
        if lifecycle is not None:
            self._values["lifecycle"] = lifecycle
        if provider is not None:
            self._values["provider"] = provider
        if throughput is not None:
            self._values["throughput"] = throughput
        if timeouts is not None:
            self._values["timeouts"] = timeouts

    @builtins.property
    def count(self) -> typing.Optional[jsii.Number]:
        """
        :stability: experimental
        """
        result = self._values.get("count")
        return result

    @builtins.property
    def depends_on(self) -> typing.Optional[typing.List[cdktf.TerraformResource]]:
        """
        :stability: experimental
        """
        result = self._values.get("depends_on")
        return result

    @builtins.property
    def lifecycle(self) -> typing.Optional[cdktf.TerraformResourceLifecycle]:
        """
        :stability: experimental
        """
        result = self._values.get("lifecycle")
        return result

    @builtins.property
    def provider(self) -> typing.Optional[cdktf.TerraformProvider]:
        """
        :stability: experimental
        """
        result = self._values.get("provider")
        return result

    @builtins.property
    def account_name(self) -> builtins.str:
        result = self._values.get("account_name")
        assert result is not None, "Required property 'account_name' is missing"
        return result

    @builtins.property
    def name(self) -> builtins.str:
        result = self._values.get("name")
        assert result is not None, "Required property 'name' is missing"
        return result

    @builtins.property
    def resource_group_name(self) -> builtins.str:
        result = self._values.get("resource_group_name")
        assert result is not None, "Required property 'resource_group_name' is missing"
        return result

    @builtins.property
    def throughput(self) -> typing.Optional[jsii.Number]:
        result = self._values.get("throughput")
        return result

    @builtins.property
    def timeouts(self) -> typing.Optional["CosmosdbTableTimeouts"]:
        """timeouts block."""
        result = self._values.get("timeouts")
        return result

    def __eq__(self, rhs: typing.Any) -> builtins.bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs: typing.Any) -> builtins.bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return "CosmosdbTableConfig(%s)" % ", ".join(
            k + "=" + repr(v) for k, v in self._values.items()
        )


@jsii.data_type(
    jsii_type="@cdktf/provider-azurerm.CosmosdbTableTimeouts",
    jsii_struct_bases=[],
    name_mapping={
        "create": "create",
        "delete": "delete",
        "read": "read",
        "update": "update",
    },
)
class CosmosdbTableTimeouts:
    def __init__(
        self,
        *,
        create: typing.Optional[builtins.str] = None,
        delete: typing.Optional[builtins.str] = None,
        read: typing.Optional[builtins.str] = None,
        update: typing.Optional[builtins.str] = None,
    ) -> None:
        """
        :param create: 
        :param delete: 
        :param read: 
        :param update: 
        """
        self._values: typing.Dict[str, typing.Any] = {}
        if create is not None:
            self._values["create"] = create
        if delete is not None:
            self._values["delete"] = delete
        if read is not None:
            self._values["read"] = read
        if update is not None:
            self._values["update"] = update

    @builtins.property
    def create(self) -> typing.Optional[builtins.str]:
        result = self._values.get("create")
        return result

    @builtins.property
    def delete(self) -> typing.Optional[builtins.str]:
        result = self._values.get("delete")
        return result

    @builtins.property
    def read(self) -> typing.Optional[builtins.str]:
        result = self._values.get("read")
        return result

    @builtins.property
    def update(self) -> typing.Optional[builtins.str]:
        result = self._values.get("update")
        return result

    def __eq__(self, rhs: typing.Any) -> builtins.bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs: typing.Any) -> builtins.bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return "CosmosdbTableTimeouts(%s)" % ", ".join(
            k + "=" + repr(v) for k, v in self._values.items()
        )


class Dashboard(
    cdktf.TerraformResource,
    metaclass=jsii.JSIIMeta,
    jsii_type="@cdktf/provider-azurerm.Dashboard",
):
    def __init__(
        self,
        scope: constructs.Construct,
        id: builtins.str,
        *,
        location: builtins.str,
        name: builtins.str,
        resource_group_name: builtins.str,
        dashboard_properties: typing.Optional[builtins.str] = None,
        tags: typing.Optional[typing.Mapping[builtins.str, builtins.str]] = None,
        timeouts: typing.Optional["DashboardTimeouts"] = None,
        count: typing.Optional[jsii.Number] = None,
        depends_on: typing.Optional[typing.List[cdktf.TerraformResource]] = None,
        lifecycle: typing.Optional[cdktf.TerraformResourceLifecycle] = None,
        provider: typing.Optional[cdktf.TerraformProvider] = None,
    ) -> None:
        """
        :param scope: -
        :param id: -
        :param location: 
        :param name: 
        :param resource_group_name: 
        :param dashboard_properties: 
        :param tags: 
        :param timeouts: timeouts block.
        :param count: 
        :param depends_on: 
        :param lifecycle: 
        :param provider: 
        """
        config = DashboardConfig(
            location=location,
            name=name,
            resource_group_name=resource_group_name,
            dashboard_properties=dashboard_properties,
            tags=tags,
            timeouts=timeouts,
            count=count,
            depends_on=depends_on,
            lifecycle=lifecycle,
            provider=provider,
        )

        jsii.create(Dashboard, self, [scope, id, config])

    @jsii.member(jsii_name="synthesizeAttributes")
    def _synthesize_attributes(self) -> typing.Mapping[builtins.str, typing.Any]:
        return jsii.invoke(self, "synthesizeAttributes", [])

    @builtins.property # type: ignore
    @jsii.member(jsii_name="location")
    def location(self) -> builtins.str:
        return jsii.get(self, "location")

    @location.setter # type: ignore
    def location(self, value: builtins.str) -> None:
        jsii.set(self, "location", value)

    @builtins.property # type: ignore
    @jsii.member(jsii_name="name")
    def name(self) -> builtins.str:
        return jsii.get(self, "name")

    @name.setter # type: ignore
    def name(self, value: builtins.str) -> None:
        jsii.set(self, "name", value)

    @builtins.property # type: ignore
    @jsii.member(jsii_name="resourceGroupName")
    def resource_group_name(self) -> builtins.str:
        return jsii.get(self, "resourceGroupName")

    @resource_group_name.setter # type: ignore
    def resource_group_name(self, value: builtins.str) -> None:
        jsii.set(self, "resourceGroupName", value)

    @builtins.property # type: ignore
    @jsii.member(jsii_name="dashboardProperties")
    def dashboard_properties(self) -> typing.Optional[builtins.str]:
        return jsii.get(self, "dashboardProperties")

    @dashboard_properties.setter # type: ignore
    def dashboard_properties(self, value: typing.Optional[builtins.str]) -> None:
        jsii.set(self, "dashboardProperties", value)

    @builtins.property # type: ignore
    @jsii.member(jsii_name="id")
    def id(self) -> typing.Optional[builtins.str]:
        return jsii.get(self, "id")

    @id.setter # type: ignore
    def id(self, value: typing.Optional[builtins.str]) -> None:
        jsii.set(self, "id", value)

    @builtins.property # type: ignore
    @jsii.member(jsii_name="tags")
    def tags(self) -> typing.Optional[typing.Mapping[builtins.str, builtins.str]]:
        return jsii.get(self, "tags")

    @tags.setter # type: ignore
    def tags(
        self,
        value: typing.Optional[typing.Mapping[builtins.str, builtins.str]],
    ) -> None:
        jsii.set(self, "tags", value)

    @builtins.property # type: ignore
    @jsii.member(jsii_name="timeouts")
    def timeouts(self) -> typing.Optional["DashboardTimeouts"]:
        return jsii.get(self, "timeouts")

    @timeouts.setter # type: ignore
    def timeouts(self, value: typing.Optional["DashboardTimeouts"]) -> None:
        jsii.set(self, "timeouts", value)


@jsii.data_type(
    jsii_type="@cdktf/provider-azurerm.DashboardConfig",
    jsii_struct_bases=[cdktf.TerraformMetaArguments],
    name_mapping={
        "count": "count",
        "depends_on": "dependsOn",
        "lifecycle": "lifecycle",
        "provider": "provider",
        "location": "location",
        "name": "name",
        "resource_group_name": "resourceGroupName",
        "dashboard_properties": "dashboardProperties",
        "tags": "tags",
        "timeouts": "timeouts",
    },
)
class DashboardConfig(cdktf.TerraformMetaArguments):
    def __init__(
        self,
        *,
        count: typing.Optional[jsii.Number] = None,
        depends_on: typing.Optional[typing.List[cdktf.TerraformResource]] = None,
        lifecycle: typing.Optional[cdktf.TerraformResourceLifecycle] = None,
        provider: typing.Optional[cdktf.TerraformProvider] = None,
        location: builtins.str,
        name: builtins.str,
        resource_group_name: builtins.str,
        dashboard_properties: typing.Optional[builtins.str] = None,
        tags: typing.Optional[typing.Mapping[builtins.str, builtins.str]] = None,
        timeouts: typing.Optional["DashboardTimeouts"] = None,
    ) -> None:
        """
        :param count: 
        :param depends_on: 
        :param lifecycle: 
        :param provider: 
        :param location: 
        :param name: 
        :param resource_group_name: 
        :param dashboard_properties: 
        :param tags: 
        :param timeouts: timeouts block.
        """
        if isinstance(lifecycle, dict):
            lifecycle = cdktf.TerraformResourceLifecycle(**lifecycle)
        if isinstance(timeouts, dict):
            timeouts = DashboardTimeouts(**timeouts)
        self._values: typing.Dict[str, typing.Any] = {
            "location": location,
            "name": name,
            "resource_group_name": resource_group_name,
        }
        if count is not None:
            self._values["count"] = count
        if depends_on is not None:
            self._values["depends_on"] = depends_on
        if lifecycle is not None:
            self._values["lifecycle"] = lifecycle
        if provider is not None:
            self._values["provider"] = provider
        if dashboard_properties is not None:
            self._values["dashboard_properties"] = dashboard_properties
        if tags is not None:
            self._values["tags"] = tags
        if timeouts is not None:
            self._values["timeouts"] = timeouts

    @builtins.property
    def count(self) -> typing.Optional[jsii.Number]:
        """
        :stability: experimental
        """
        result = self._values.get("count")
        return result

    @builtins.property
    def depends_on(self) -> typing.Optional[typing.List[cdktf.TerraformResource]]:
        """
        :stability: experimental
        """
        result = self._values.get("depends_on")
        return result

    @builtins.property
    def lifecycle(self) -> typing.Optional[cdktf.TerraformResourceLifecycle]:
        """
        :stability: experimental
        """
        result = self._values.get("lifecycle")
        return result

    @builtins.property
    def provider(self) -> typing.Optional[cdktf.TerraformProvider]:
        """
        :stability: experimental
        """
        result = self._values.get("provider")
        return result

    @builtins.property
    def location(self) -> builtins.str:
        result = self._values.get("location")
        assert result is not None, "Required property 'location' is missing"
        return result

    @builtins.property
    def name(self) -> builtins.str:
        result = self._values.get("name")
        assert result is not None, "Required property 'name' is missing"
        return result

    @builtins.property
    def resource_group_name(self) -> builtins.str:
        result = self._values.get("resource_group_name")
        assert result is not None, "Required property 'resource_group_name' is missing"
        return result

    @builtins.property
    def dashboard_properties(self) -> typing.Optional[builtins.str]:
        result = self._values.get("dashboard_properties")
        return result

    @builtins.property
    def tags(self) -> typing.Optional[typing.Mapping[builtins.str, builtins.str]]:
        result = self._values.get("tags")
        return result

    @builtins.property
    def timeouts(self) -> typing.Optional["DashboardTimeouts"]:
        """timeouts block."""
        result = self._values.get("timeouts")
        return result

    def __eq__(self, rhs: typing.Any) -> builtins.bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs: typing.Any) -> builtins.bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return "DashboardConfig(%s)" % ", ".join(
            k + "=" + repr(v) for k, v in self._values.items()
        )


@jsii.data_type(
    jsii_type="@cdktf/provider-azurerm.DashboardTimeouts",
    jsii_struct_bases=[],
    name_mapping={
        "create": "create",
        "delete": "delete",
        "read": "read",
        "update": "update",
    },
)
class DashboardTimeouts:
    def __init__(
        self,
        *,
        create: typing.Optional[builtins.str] = None,
        delete: typing.Optional[builtins.str] = None,
        read: typing.Optional[builtins.str] = None,
        update: typing.Optional[builtins.str] = None,
    ) -> None:
        """
        :param create: 
        :param delete: 
        :param read: 
        :param update: 
        """
        self._values: typing.Dict[str, typing.Any] = {}
        if create is not None:
            self._values["create"] = create
        if delete is not None:
            self._values["delete"] = delete
        if read is not None:
            self._values["read"] = read
        if update is not None:
            self._values["update"] = update

    @builtins.property
    def create(self) -> typing.Optional[builtins.str]:
        result = self._values.get("create")
        return result

    @builtins.property
    def delete(self) -> typing.Optional[builtins.str]:
        result = self._values.get("delete")
        return result

    @builtins.property
    def read(self) -> typing.Optional[builtins.str]:
        result = self._values.get("read")
        return result

    @builtins.property
    def update(self) -> typing.Optional[builtins.str]:
        result = self._values.get("update")
        return result

    def __eq__(self, rhs: typing.Any) -> builtins.bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs: typing.Any) -> builtins.bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return "DashboardTimeouts(%s)" % ", ".join(
            k + "=" + repr(v) for k, v in self._values.items()
        )


class DataAzurermApiManagement(
    cdktf.TerraformDataSource,
    metaclass=jsii.JSIIMeta,
    jsii_type="@cdktf/provider-azurerm.DataAzurermApiManagement",
):
    def __init__(
        self,
        scope: constructs.Construct,
        id: builtins.str,
        *,
        name: builtins.str,
        resource_group_name: builtins.str,
        timeouts: typing.Optional["DataAzurermApiManagementTimeouts"] = None,
        count: typing.Optional[jsii.Number] = None,
        depends_on: typing.Optional[typing.List[cdktf.TerraformResource]] = None,
        lifecycle: typing.Optional[cdktf.TerraformResourceLifecycle] = None,
        provider: typing.Optional[cdktf.TerraformProvider] = None,
    ) -> None:
        """
        :param scope: -
        :param id: -
        :param name: 
        :param resource_group_name: 
        :param timeouts: timeouts block.
        :param count: 
        :param depends_on: 
        :param lifecycle: 
        :param provider: 
        """
        config = DataAzurermApiManagementConfig(
            name=name,
            resource_group_name=resource_group_name,
            timeouts=timeouts,
            count=count,
            depends_on=depends_on,
            lifecycle=lifecycle,
            provider=provider,
        )

        jsii.create(DataAzurermApiManagement, self, [scope, id, config])

    @jsii.member(jsii_name="additionalLocation")
    def additional_location(
        self,
        index: builtins.str,
    ) -> "DataAzurermApiManagementAdditionalLocation":
        """
        :param index: -
        """
        return jsii.invoke(self, "additionalLocation", [index])

    @jsii.member(jsii_name="hostnameConfiguration")
    def hostname_configuration(
        self,
        index: builtins.str,
    ) -> "DataAzurermApiManagementHostnameConfiguration":
        """
        :param index: -
        """
        return jsii.invoke(self, "hostnameConfiguration", [index])

    @jsii.member(jsii_name="synthesizeAttributes")
    def _synthesize_attributes(self) -> typing.Mapping[builtins.str, typing.Any]:
        return jsii.invoke(self, "synthesizeAttributes", [])

    @jsii.member(jsii_name="tags")
    def tags(self, key: builtins.str) -> builtins.str:
        """
        :param key: -
        """
        return jsii.invoke(self, "tags", [key])

    @builtins.property # type: ignore
    @jsii.member(jsii_name="gatewayRegionalUrl")
    def gateway_regional_url(self) -> builtins.str:
        return jsii.get(self, "gatewayRegionalUrl")

    @builtins.property # type: ignore
    @jsii.member(jsii_name="gatewayUrl")
    def gateway_url(self) -> builtins.str:
        return jsii.get(self, "gatewayUrl")

    @builtins.property # type: ignore
    @jsii.member(jsii_name="location")
    def location(self) -> builtins.str:
        return jsii.get(self, "location")

    @builtins.property # type: ignore
    @jsii.member(jsii_name="managementApiUrl")
    def management_api_url(self) -> builtins.str:
        return jsii.get(self, "managementApiUrl")

    @builtins.property # type: ignore
    @jsii.member(jsii_name="notificationSenderEmail")
    def notification_sender_email(self) -> builtins.str:
        return jsii.get(self, "notificationSenderEmail")

    @builtins.property # type: ignore
    @jsii.member(jsii_name="portalUrl")
    def portal_url(self) -> builtins.str:
        return jsii.get(self, "portalUrl")

    @builtins.property # type: ignore
    @jsii.member(jsii_name="publicIpAddresses")
    def public_ip_addresses(self) -> typing.List[builtins.str]:
        return jsii.get(self, "publicIpAddresses")

    @builtins.property # type: ignore
    @jsii.member(jsii_name="publisherEmail")
    def publisher_email(self) -> builtins.str:
        return jsii.get(self, "publisherEmail")

    @builtins.property # type: ignore
    @jsii.member(jsii_name="publisherName")
    def publisher_name(self) -> builtins.str:
        return jsii.get(self, "publisherName")

    @builtins.property # type: ignore
    @jsii.member(jsii_name="scmUrl")
    def scm_url(self) -> builtins.str:
        return jsii.get(self, "scmUrl")

    @builtins.property # type: ignore
    @jsii.member(jsii_name="skuName")
    def sku_name(self) -> builtins.str:
        return jsii.get(self, "skuName")

    @builtins.property # type: ignore
    @jsii.member(jsii_name="name")
    def name(self) -> builtins.str:
        return jsii.get(self, "name")

    @name.setter # type: ignore
    def name(self, value: builtins.str) -> None:
        jsii.set(self, "name", value)

    @builtins.property # type: ignore
    @jsii.member(jsii_name="resourceGroupName")
    def resource_group_name(self) -> builtins.str:
        return jsii.get(self, "resourceGroupName")

    @resource_group_name.setter # type: ignore
    def resource_group_name(self, value: builtins.str) -> None:
        jsii.set(self, "resourceGroupName", value)

    @builtins.property # type: ignore
    @jsii.member(jsii_name="id")
    def id(self) -> typing.Optional[builtins.str]:
        return jsii.get(self, "id")

    @id.setter # type: ignore
    def id(self, value: typing.Optional[builtins.str]) -> None:
        jsii.set(self, "id", value)

    @builtins.property # type: ignore
    @jsii.member(jsii_name="timeouts")
    def timeouts(self) -> typing.Optional["DataAzurermApiManagementTimeouts"]:
        return jsii.get(self, "timeouts")

    @timeouts.setter # type: ignore
    def timeouts(
        self,
        value: typing.Optional["DataAzurermApiManagementTimeouts"],
    ) -> None:
        jsii.set(self, "timeouts", value)


class DataAzurermApiManagementAdditionalLocation(
    cdktf.ComplexComputedList,
    metaclass=jsii.JSIIMeta,
    jsii_type="@cdktf/provider-azurerm.DataAzurermApiManagementAdditionalLocation",
):
    def __init__(
        self,
        terraform_resource: cdktf.ITerraformResource,
        terraform_attribute: builtins.str,
        index: builtins.str,
    ) -> None:
        """
        :param terraform_resource: -
        :param terraform_attribute: -
        :param index: -

        :stability: experimental
        """
        jsii.create(DataAzurermApiManagementAdditionalLocation, self, [terraform_resource, terraform_attribute, index])

    @builtins.property # type: ignore
    @jsii.member(jsii_name="gatewayRegionalUrl")
    def gateway_regional_url(self) -> builtins.str:
        return jsii.get(self, "gatewayRegionalUrl")

    @builtins.property # type: ignore
    @jsii.member(jsii_name="location")
    def location(self) -> builtins.str:
        return jsii.get(self, "location")

    @builtins.property # type: ignore
    @jsii.member(jsii_name="publicIpAddresses")
    def public_ip_addresses(self) -> typing.List[builtins.str]:
        return jsii.get(self, "publicIpAddresses")


class DataAzurermApiManagementApi(
    cdktf.TerraformDataSource,
    metaclass=jsii.JSIIMeta,
    jsii_type="@cdktf/provider-azurerm.DataAzurermApiManagementApi",
):
    def __init__(
        self,
        scope: constructs.Construct,
        id: builtins.str,
        *,
        api_management_name: builtins.str,
        name: builtins.str,
        resource_group_name: builtins.str,
        revision: builtins.str,
        timeouts: typing.Optional["DataAzurermApiManagementApiTimeouts"] = None,
        count: typing.Optional[jsii.Number] = None,
        depends_on: typing.Optional[typing.List[cdktf.TerraformResource]] = None,
        lifecycle: typing.Optional[cdktf.TerraformResourceLifecycle] = None,
        provider: typing.Optional[cdktf.TerraformProvider] = None,
    ) -> None:
        """
        :param scope: -
        :param id: -
        :param api_management_name: 
        :param name: 
        :param resource_group_name: 
        :param revision: 
        :param timeouts: timeouts block.
        :param count: 
        :param depends_on: 
        :param lifecycle: 
        :param provider: 
        """
        config = DataAzurermApiManagementApiConfig(
            api_management_name=api_management_name,
            name=name,
            resource_group_name=resource_group_name,
            revision=revision,
            timeouts=timeouts,
            count=count,
            depends_on=depends_on,
            lifecycle=lifecycle,
            provider=provider,
        )

        jsii.create(DataAzurermApiManagementApi, self, [scope, id, config])

    @jsii.member(jsii_name="subscriptionKeyParameterNames")
    def subscription_key_parameter_names(
        self,
        index: builtins.str,
    ) -> "DataAzurermApiManagementApiSubscriptionKeyParameterNames":
        """
        :param index: -
        """
        return jsii.invoke(self, "subscriptionKeyParameterNames", [index])

    @jsii.member(jsii_name="synthesizeAttributes")
    def _synthesize_attributes(self) -> typing.Mapping[builtins.str, typing.Any]:
        return jsii.invoke(self, "synthesizeAttributes", [])

    @builtins.property # type: ignore
    @jsii.member(jsii_name="description")
    def description(self) -> builtins.str:
        return jsii.get(self, "description")

    @builtins.property # type: ignore
    @jsii.member(jsii_name="displayName")
    def display_name(self) -> builtins.str:
        return jsii.get(self, "displayName")

    @builtins.property # type: ignore
    @jsii.member(jsii_name="isCurrent")
    def is_current(self) -> builtins.bool:
        return jsii.get(self, "isCurrent")

    @builtins.property # type: ignore
    @jsii.member(jsii_name="isOnline")
    def is_online(self) -> builtins.bool:
        return jsii.get(self, "isOnline")

    @builtins.property # type: ignore
    @jsii.member(jsii_name="path")
    def path(self) -> builtins.str:
        return jsii.get(self, "path")

    @builtins.property # type: ignore
    @jsii.member(jsii_name="protocols")
    def protocols(self) -> typing.List[builtins.str]:
        return jsii.get(self, "protocols")

    @builtins.property # type: ignore
    @jsii.member(jsii_name="serviceUrl")
    def service_url(self) -> builtins.str:
        return jsii.get(self, "serviceUrl")

    @builtins.property # type: ignore
    @jsii.member(jsii_name="soapPassThrough")
    def soap_pass_through(self) -> builtins.bool:
        return jsii.get(self, "soapPassThrough")

    @builtins.property # type: ignore
    @jsii.member(jsii_name="version")
    def version(self) -> builtins.str:
        return jsii.get(self, "version")

    @builtins.property # type: ignore
    @jsii.member(jsii_name="versionSetId")
    def version_set_id(self) -> builtins.str:
        return jsii.get(self, "versionSetId")

    @builtins.property # type: ignore
    @jsii.member(jsii_name="apiManagementName")
    def api_management_name(self) -> builtins.str:
        return jsii.get(self, "apiManagementName")

    @api_management_name.setter # type: ignore
    def api_management_name(self, value: builtins.str) -> None:
        jsii.set(self, "apiManagementName", value)

    @builtins.property # type: ignore
    @jsii.member(jsii_name="name")
    def name(self) -> builtins.str:
        return jsii.get(self, "name")

    @name.setter # type: ignore
    def name(self, value: builtins.str) -> None:
        jsii.set(self, "name", value)

    @builtins.property # type: ignore
    @jsii.member(jsii_name="resourceGroupName")
    def resource_group_name(self) -> builtins.str:
        return jsii.get(self, "resourceGroupName")

    @resource_group_name.setter # type: ignore
    def resource_group_name(self, value: builtins.str) -> None:
        jsii.set(self, "resourceGroupName", value)

    @builtins.property # type: ignore
    @jsii.member(jsii_name="revision")
    def revision(self) -> builtins.str:
        return jsii.get(self, "revision")

    @revision.setter # type: ignore
    def revision(self, value: builtins.str) -> None:
        jsii.set(self, "revision", value)

    @builtins.property # type: ignore
    @jsii.member(jsii_name="id")
    def id(self) -> typing.Optional[builtins.str]:
        return jsii.get(self, "id")

    @id.setter # type: ignore
    def id(self, value: typing.Optional[builtins.str]) -> None:
        jsii.set(self, "id", value)

    @builtins.property # type: ignore
    @jsii.member(jsii_name="timeouts")
    def timeouts(self) -> typing.Optional["DataAzurermApiManagementApiTimeouts"]:
        return jsii.get(self, "timeouts")

    @timeouts.setter # type: ignore
    def timeouts(
        self,
        value: typing.Optional["DataAzurermApiManagementApiTimeouts"],
    ) -> None:
        jsii.set(self, "timeouts", value)


@jsii.data_type(
    jsii_type="@cdktf/provider-azurerm.DataAzurermApiManagementApiConfig",
    jsii_struct_bases=[cdktf.TerraformMetaArguments],
    name_mapping={
        "count": "count",
        "depends_on": "dependsOn",
        "lifecycle": "lifecycle",
        "provider": "provider",
        "api_management_name": "apiManagementName",
        "name": "name",
        "resource_group_name": "resourceGroupName",
        "revision": "revision",
        "timeouts": "timeouts",
    },
)
class DataAzurermApiManagementApiConfig(cdktf.TerraformMetaArguments):
    def __init__(
        self,
        *,
        count: typing.Optional[jsii.Number] = None,
        depends_on: typing.Optional[typing.List[cdktf.TerraformResource]] = None,
        lifecycle: typing.Optional[cdktf.TerraformResourceLifecycle] = None,
        provider: typing.Optional[cdktf.TerraformProvider] = None,
        api_management_name: builtins.str,
        name: builtins.str,
        resource_group_name: builtins.str,
        revision: builtins.str,
        timeouts: typing.Optional["DataAzurermApiManagementApiTimeouts"] = None,
    ) -> None:
        """
        :param count: 
        :param depends_on: 
        :param lifecycle: 
        :param provider: 
        :param api_management_name: 
        :param name: 
        :param resource_group_name: 
        :param revision: 
        :param timeouts: timeouts block.
        """
        if isinstance(lifecycle, dict):
            lifecycle = cdktf.TerraformResourceLifecycle(**lifecycle)
        if isinstance(timeouts, dict):
            timeouts = DataAzurermApiManagementApiTimeouts(**timeouts)
        self._values: typing.Dict[str, typing.Any] = {
            "api_management_name": api_management_name,
            "name": name,
            "resource_group_name": resource_group_name,
            "revision": revision,
        }
        if count is not None:
            self._values["count"] = count
        if depends_on is not None:
            self._values["depends_on"] = depends_on
        if lifecycle is not None:
            self._values["lifecycle"] = lifecycle
        if provider is not None:
            self._values["provider"] = provider
        if timeouts is not None:
            self._values["timeouts"] = timeouts

    @builtins.property
    def count(self) -> typing.Optional[jsii.Number]:
        """
        :stability: experimental
        """
        result = self._values.get("count")
        return result

    @builtins.property
    def depends_on(self) -> typing.Optional[typing.List[cdktf.TerraformResource]]:
        """
        :stability: experimental
        """
        result = self._values.get("depends_on")
        return result

    @builtins.property
    def lifecycle(self) -> typing.Optional[cdktf.TerraformResourceLifecycle]:
        """
        :stability: experimental
        """
        result = self._values.get("lifecycle")
        return result

    @builtins.property
    def provider(self) -> typing.Optional[cdktf.TerraformProvider]:
        """
        :stability: experimental
        """
        result = self._values.get("provider")
        return result

    @builtins.property
    def api_management_name(self) -> builtins.str:
        result = self._values.get("api_management_name")
        assert result is not None, "Required property 'api_management_name' is missing"
        return result

    @builtins.property
    def name(self) -> builtins.str:
        result = self._values.get("name")
        assert result is not None, "Required property 'name' is missing"
        return result

    @builtins.property
    def resource_group_name(self) -> builtins.str:
        result = self._values.get("resource_group_name")
        assert result is not None, "Required property 'resource_group_name' is missing"
        return result

    @builtins.property
    def revision(self) -> builtins.str:
        result = self._values.get("revision")
        assert result is not None, "Required property 'revision' is missing"
        return result

    @builtins.property
    def timeouts(self) -> typing.Optional["DataAzurermApiManagementApiTimeouts"]:
        """timeouts block."""
        result = self._values.get("timeouts")
        return result

    def __eq__(self, rhs: typing.Any) -> builtins.bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs: typing.Any) -> builtins.bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return "DataAzurermApiManagementApiConfig(%s)" % ", ".join(
            k + "=" + repr(v) for k, v in self._values.items()
        )


class DataAzurermApiManagementApiSubscriptionKeyParameterNames(
    cdktf.ComplexComputedList,
    metaclass=jsii.JSIIMeta,
    jsii_type="@cdktf/provider-azurerm.DataAzurermApiManagementApiSubscriptionKeyParameterNames",
):
    def __init__(
        self,
        terraform_resource: cdktf.ITerraformResource,
        terraform_attribute: builtins.str,
        index: builtins.str,
    ) -> None:
        """
        :param terraform_resource: -
        :param terraform_attribute: -
        :param index: -

        :stability: experimental
        """
        jsii.create(DataAzurermApiManagementApiSubscriptionKeyParameterNames, self, [terraform_resource, terraform_attribute, index])

    @builtins.property # type: ignore
    @jsii.member(jsii_name="header")
    def header(self) -> builtins.str:
        return jsii.get(self, "header")

    @builtins.property # type: ignore
    @jsii.member(jsii_name="query")
    def query(self) -> builtins.str:
        return jsii.get(self, "query")


@jsii.data_type(
    jsii_type="@cdktf/provider-azurerm.DataAzurermApiManagementApiTimeouts",
    jsii_struct_bases=[],
    name_mapping={"read": "read"},
)
class DataAzurermApiManagementApiTimeouts:
    def __init__(self, *, read: typing.Optional[builtins.str] = None) -> None:
        """
        :param read: 
        """
        self._values: typing.Dict[str, typing.Any] = {}
        if read is not None:
            self._values["read"] = read

    @builtins.property
    def read(self) -> typing.Optional[builtins.str]:
        result = self._values.get("read")
        return result

    def __eq__(self, rhs: typing.Any) -> builtins.bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs: typing.Any) -> builtins.bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return "DataAzurermApiManagementApiTimeouts(%s)" % ", ".join(
            k + "=" + repr(v) for k, v in self._values.items()
        )


class DataAzurermApiManagementApiVersionSet(
    cdktf.TerraformDataSource,
    metaclass=jsii.JSIIMeta,
    jsii_type="@cdktf/provider-azurerm.DataAzurermApiManagementApiVersionSet",
):
    def __init__(
        self,
        scope: constructs.Construct,
        id: builtins.str,
        *,
        api_management_name: builtins.str,
        name: builtins.str,
        resource_group_name: builtins.str,
        timeouts: typing.Optional["DataAzurermApiManagementApiVersionSetTimeouts"] = None,
        count: typing.Optional[jsii.Number] = None,
        depends_on: typing.Optional[typing.List[cdktf.TerraformResource]] = None,
        lifecycle: typing.Optional[cdktf.TerraformResourceLifecycle] = None,
        provider: typing.Optional[cdktf.TerraformProvider] = None,
    ) -> None:
        """
        :param scope: -
        :param id: -
        :param api_management_name: 
        :param name: 
        :param resource_group_name: 
        :param timeouts: timeouts block.
        :param count: 
        :param depends_on: 
        :param lifecycle: 
        :param provider: 
        """
        config = DataAzurermApiManagementApiVersionSetConfig(
            api_management_name=api_management_name,
            name=name,
            resource_group_name=resource_group_name,
            timeouts=timeouts,
            count=count,
            depends_on=depends_on,
            lifecycle=lifecycle,
            provider=provider,
        )

        jsii.create(DataAzurermApiManagementApiVersionSet, self, [scope, id, config])

    @jsii.member(jsii_name="synthesizeAttributes")
    def _synthesize_attributes(self) -> typing.Mapping[builtins.str, typing.Any]:
        return jsii.invoke(self, "synthesizeAttributes", [])

    @builtins.property # type: ignore
    @jsii.member(jsii_name="description")
    def description(self) -> builtins.str:
        return jsii.get(self, "description")

    @builtins.property # type: ignore
    @jsii.member(jsii_name="displayName")
    def display_name(self) -> builtins.str:
        return jsii.get(self, "displayName")

    @builtins.property # type: ignore
    @jsii.member(jsii_name="versionHeaderName")
    def version_header_name(self) -> builtins.str:
        return jsii.get(self, "versionHeaderName")

    @builtins.property # type: ignore
    @jsii.member(jsii_name="versioningScheme")
    def versioning_scheme(self) -> builtins.str:
        return jsii.get(self, "versioningScheme")

    @builtins.property # type: ignore
    @jsii.member(jsii_name="versionQueryName")
    def version_query_name(self) -> builtins.str:
        return jsii.get(self, "versionQueryName")

    @builtins.property # type: ignore
    @jsii.member(jsii_name="apiManagementName")
    def api_management_name(self) -> builtins.str:
        return jsii.get(self, "apiManagementName")

    @api_management_name.setter # type: ignore
    def api_management_name(self, value: builtins.str) -> None:
        jsii.set(self, "apiManagementName", value)

    @builtins.property # type: ignore
    @jsii.member(jsii_name="name")
    def name(self) -> builtins.str:
        return jsii.get(self, "name")

    @name.setter # type: ignore
    def name(self, value: builtins.str) -> None:
        jsii.set(self, "name", value)

    @builtins.property # type: ignore
    @jsii.member(jsii_name="resourceGroupName")
    def resource_group_name(self) -> builtins.str:
        return jsii.get(self, "resourceGroupName")

    @resource_group_name.setter # type: ignore
    def resource_group_name(self, value: builtins.str) -> None:
        jsii.set(self, "resourceGroupName", value)

    @builtins.property # type: ignore
    @jsii.member(jsii_name="id")
    def id(self) -> typing.Optional[builtins.str]:
        return jsii.get(self, "id")

    @id.setter # type: ignore
    def id(self, value: typing.Optional[builtins.str]) -> None:
        jsii.set(self, "id", value)

    @builtins.property # type: ignore
    @jsii.member(jsii_name="timeouts")
    def timeouts(
        self,
    ) -> typing.Optional["DataAzurermApiManagementApiVersionSetTimeouts"]:
        return jsii.get(self, "timeouts")

    @timeouts.setter # type: ignore
    def timeouts(
        self,
        value: typing.Optional["DataAzurermApiManagementApiVersionSetTimeouts"],
    ) -> None:
        jsii.set(self, "timeouts", value)


@jsii.data_type(
    jsii_type="@cdktf/provider-azurerm.DataAzurermApiManagementApiVersionSetConfig",
    jsii_struct_bases=[cdktf.TerraformMetaArguments],
    name_mapping={
        "count": "count",
        "depends_on": "dependsOn",
        "lifecycle": "lifecycle",
        "provider": "provider",
        "api_management_name": "apiManagementName",
        "name": "name",
        "resource_group_name": "resourceGroupName",
        "timeouts": "timeouts",
    },
)
class DataAzurermApiManagementApiVersionSetConfig(cdktf.TerraformMetaArguments):
    def __init__(
        self,
        *,
        count: typing.Optional[jsii.Number] = None,
        depends_on: typing.Optional[typing.List[cdktf.TerraformResource]] = None,
        lifecycle: typing.Optional[cdktf.TerraformResourceLifecycle] = None,
        provider: typing.Optional[cdktf.TerraformProvider] = None,
        api_management_name: builtins.str,
        name: builtins.str,
        resource_group_name: builtins.str,
        timeouts: typing.Optional["DataAzurermApiManagementApiVersionSetTimeouts"] = None,
    ) -> None:
        """
        :param count: 
        :param depends_on: 
        :param lifecycle: 
        :param provider: 
        :param api_management_name: 
        :param name: 
        :param resource_group_name: 
        :param timeouts: timeouts block.
        """
        if isinstance(lifecycle, dict):
            lifecycle = cdktf.TerraformResourceLifecycle(**lifecycle)
        if isinstance(timeouts, dict):
            timeouts = DataAzurermApiManagementApiVersionSetTimeouts(**timeouts)
        self._values: typing.Dict[str, typing.Any] = {
            "api_management_name": api_management_name,
            "name": name,
            "resource_group_name": resource_group_name,
        }
        if count is not None:
            self._values["count"] = count
        if depends_on is not None:
            self._values["depends_on"] = depends_on
        if lifecycle is not None:
            self._values["lifecycle"] = lifecycle
        if provider is not None:
            self._values["provider"] = provider
        if timeouts is not None:
            self._values["timeouts"] = timeouts

    @builtins.property
    def count(self) -> typing.Optional[jsii.Number]:
        """
        :stability: experimental
        """
        result = self._values.get("count")
        return result

    @builtins.property
    def depends_on(self) -> typing.Optional[typing.List[cdktf.TerraformResource]]:
        """
        :stability: experimental
        """
        result = self._values.get("depends_on")
        return result

    @builtins.property
    def lifecycle(self) -> typing.Optional[cdktf.TerraformResourceLifecycle]:
        """
        :stability: experimental
        """
        result = self._values.get("lifecycle")
        return result

    @builtins.property
    def provider(self) -> typing.Optional[cdktf.TerraformProvider]:
        """
        :stability: experimental
        """
        result = self._values.get("provider")
        return result

    @builtins.property
    def api_management_name(self) -> builtins.str:
        result = self._values.get("api_management_name")
        assert result is not None, "Required property 'api_management_name' is missing"
        return result

    @builtins.property
    def name(self) -> builtins.str:
        result = self._values.get("name")
        assert result is not None, "Required property 'name' is missing"
        return result

    @builtins.property
    def resource_group_name(self) -> builtins.str:
        result = self._values.get("resource_group_name")
        assert result is not None, "Required property 'resource_group_name' is missing"
        return result

    @builtins.property
    def timeouts(
        self,
    ) -> typing.Optional["DataAzurermApiManagementApiVersionSetTimeouts"]:
        """timeouts block."""
        result = self._values.get("timeouts")
        return result

    def __eq__(self, rhs: typing.Any) -> builtins.bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs: typing.Any) -> builtins.bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return "DataAzurermApiManagementApiVersionSetConfig(%s)" % ", ".join(
            k + "=" + repr(v) for k, v in self._values.items()
        )


@jsii.data_type(
    jsii_type="@cdktf/provider-azurerm.DataAzurermApiManagementApiVersionSetTimeouts",
    jsii_struct_bases=[],
    name_mapping={"read": "read"},
)
class DataAzurermApiManagementApiVersionSetTimeouts:
    def __init__(self, *, read: typing.Optional[builtins.str] = None) -> None:
        """
        :param read: 
        """
        self._values: typing.Dict[str, typing.Any] = {}
        if read is not None:
            self._values["read"] = read

    @builtins.property
    def read(self) -> typing.Optional[builtins.str]:
        result = self._values.get("read")
        return result

    def __eq__(self, rhs: typing.Any) -> builtins.bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs: typing.Any) -> builtins.bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return "DataAzurermApiManagementApiVersionSetTimeouts(%s)" % ", ".join(
            k + "=" + repr(v) for k, v in self._values.items()
        )


@jsii.data_type(
    jsii_type="@cdktf/provider-azurerm.DataAzurermApiManagementConfig",
    jsii_struct_bases=[cdktf.TerraformMetaArguments],
    name_mapping={
        "count": "count",
        "depends_on": "dependsOn",
        "lifecycle": "lifecycle",
        "provider": "provider",
        "name": "name",
        "resource_group_name": "resourceGroupName",
        "timeouts": "timeouts",
    },
)
class DataAzurermApiManagementConfig(cdktf.TerraformMetaArguments):
    def __init__(
        self,
        *,
        count: typing.Optional[jsii.Number] = None,
        depends_on: typing.Optional[typing.List[cdktf.TerraformResource]] = None,
        lifecycle: typing.Optional[cdktf.TerraformResourceLifecycle] = None,
        provider: typing.Optional[cdktf.TerraformProvider] = None,
        name: builtins.str,
        resource_group_name: builtins.str,
        timeouts: typing.Optional["DataAzurermApiManagementTimeouts"] = None,
    ) -> None:
        """
        :param count: 
        :param depends_on: 
        :param lifecycle: 
        :param provider: 
        :param name: 
        :param resource_group_name: 
        :param timeouts: timeouts block.
        """
        if isinstance(lifecycle, dict):
            lifecycle = cdktf.TerraformResourceLifecycle(**lifecycle)
        if isinstance(timeouts, dict):
            timeouts = DataAzurermApiManagementTimeouts(**timeouts)
        self._values: typing.Dict[str, typing.Any] = {
            "name": name,
            "resource_group_name": resource_group_name,
        }
        if count is not None:
            self._values["count"] = count
        if depends_on is not None:
            self._values["depends_on"] = depends_on
        if lifecycle is not None:
            self._values["lifecycle"] = lifecycle
        if provider is not None:
            self._values["provider"] = provider
        if timeouts is not None:
            self._values["timeouts"] = timeouts

    @builtins.property
    def count(self) -> typing.Optional[jsii.Number]:
        """
        :stability: experimental
        """
        result = self._values.get("count")
        return result

    @builtins.property
    def depends_on(self) -> typing.Optional[typing.List[cdktf.TerraformResource]]:
        """
        :stability: experimental
        """
        result = self._values.get("depends_on")
        return result

    @builtins.property
    def lifecycle(self) -> typing.Optional[cdktf.TerraformResourceLifecycle]:
        """
        :stability: experimental
        """
        result = self._values.get("lifecycle")
        return result

    @builtins.property
    def provider(self) -> typing.Optional[cdktf.TerraformProvider]:
        """
        :stability: experimental
        """
        result = self._values.get("provider")
        return result

    @builtins.property
    def name(self) -> builtins.str:
        result = self._values.get("name")
        assert result is not None, "Required property 'name' is missing"
        return result

    @builtins.property
    def resource_group_name(self) -> builtins.str:
        result = self._values.get("resource_group_name")
        assert result is not None, "Required property 'resource_group_name' is missing"
        return result

    @builtins.property
    def timeouts(self) -> typing.Optional["DataAzurermApiManagementTimeouts"]:
        """timeouts block."""
        result = self._values.get("timeouts")
        return result

    def __eq__(self, rhs: typing.Any) -> builtins.bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs: typing.Any) -> builtins.bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return "DataAzurermApiManagementConfig(%s)" % ", ".join(
            k + "=" + repr(v) for k, v in self._values.items()
        )


class DataAzurermApiManagementGroup(
    cdktf.TerraformDataSource,
    metaclass=jsii.JSIIMeta,
    jsii_type="@cdktf/provider-azurerm.DataAzurermApiManagementGroup",
):
    def __init__(
        self,
        scope: constructs.Construct,
        id: builtins.str,
        *,
        api_management_name: builtins.str,
        name: builtins.str,
        resource_group_name: builtins.str,
        timeouts: typing.Optional["DataAzurermApiManagementGroupTimeouts"] = None,
        count: typing.Optional[jsii.Number] = None,
        depends_on: typing.Optional[typing.List[cdktf.TerraformResource]] = None,
        lifecycle: typing.Optional[cdktf.TerraformResourceLifecycle] = None,
        provider: typing.Optional[cdktf.TerraformProvider] = None,
    ) -> None:
        """
        :param scope: -
        :param id: -
        :param api_management_name: 
        :param name: 
        :param resource_group_name: 
        :param timeouts: timeouts block.
        :param count: 
        :param depends_on: 
        :param lifecycle: 
        :param provider: 
        """
        config = DataAzurermApiManagementGroupConfig(
            api_management_name=api_management_name,
            name=name,
            resource_group_name=resource_group_name,
            timeouts=timeouts,
            count=count,
            depends_on=depends_on,
            lifecycle=lifecycle,
            provider=provider,
        )

        jsii.create(DataAzurermApiManagementGroup, self, [scope, id, config])

    @jsii.member(jsii_name="synthesizeAttributes")
    def _synthesize_attributes(self) -> typing.Mapping[builtins.str, typing.Any]:
        return jsii.invoke(self, "synthesizeAttributes", [])

    @builtins.property # type: ignore
    @jsii.member(jsii_name="description")
    def description(self) -> builtins.str:
        return jsii.get(self, "description")

    @builtins.property # type: ignore
    @jsii.member(jsii_name="displayName")
    def display_name(self) -> builtins.str:
        return jsii.get(self, "displayName")

    @builtins.property # type: ignore
    @jsii.member(jsii_name="externalId")
    def external_id(self) -> builtins.str:
        return jsii.get(self, "externalId")

    @builtins.property # type: ignore
    @jsii.member(jsii_name="type")
    def type(self) -> builtins.str:
        return jsii.get(self, "type")

    @builtins.property # type: ignore
    @jsii.member(jsii_name="apiManagementName")
    def api_management_name(self) -> builtins.str:
        return jsii.get(self, "apiManagementName")

    @api_management_name.setter # type: ignore
    def api_management_name(self, value: builtins.str) -> None:
        jsii.set(self, "apiManagementName", value)

    @builtins.property # type: ignore
    @jsii.member(jsii_name="name")
    def name(self) -> builtins.str:
        return jsii.get(self, "name")

    @name.setter # type: ignore
    def name(self, value: builtins.str) -> None:
        jsii.set(self, "name", value)

    @builtins.property # type: ignore
    @jsii.member(jsii_name="resourceGroupName")
    def resource_group_name(self) -> builtins.str:
        return jsii.get(self, "resourceGroupName")

    @resource_group_name.setter # type: ignore
    def resource_group_name(self, value: builtins.str) -> None:
        jsii.set(self, "resourceGroupName", value)

    @builtins.property # type: ignore
    @jsii.member(jsii_name="id")
    def id(self) -> typing.Optional[builtins.str]:
        return jsii.get(self, "id")

    @id.setter # type: ignore
    def id(self, value: typing.Optional[builtins.str]) -> None:
        jsii.set(self, "id", value)

    @builtins.property # type: ignore
    @jsii.member(jsii_name="timeouts")
    def timeouts(self) -> typing.Optional["DataAzurermApiManagementGroupTimeouts"]:
        return jsii.get(self, "timeouts")

    @timeouts.setter # type: ignore
    def timeouts(
        self,
        value: typing.Optional["DataAzurermApiManagementGroupTimeouts"],
    ) -> None:
        jsii.set(self, "timeouts", value)


@jsii.data_type(
    jsii_type="@cdktf/provider-azurerm.DataAzurermApiManagementGroupConfig",
    jsii_struct_bases=[cdktf.TerraformMetaArguments],
    name_mapping={
        "count": "count",
        "depends_on": "dependsOn",
        "lifecycle": "lifecycle",
        "provider": "provider",
        "api_management_name": "apiManagementName",
        "name": "name",
        "resource_group_name": "resourceGroupName",
        "timeouts": "timeouts",
    },
)
class DataAzurermApiManagementGroupConfig(cdktf.TerraformMetaArguments):
    def __init__(
        self,
        *,
        count: typing.Optional[jsii.Number] = None,
        depends_on: typing.Optional[typing.List[cdktf.TerraformResource]] = None,
        lifecycle: typing.Optional[cdktf.TerraformResourceLifecycle] = None,
        provider: typing.Optional[cdktf.TerraformProvider] = None,
        api_management_name: builtins.str,
        name: builtins.str,
        resource_group_name: builtins.str,
        timeouts: typing.Optional["DataAzurermApiManagementGroupTimeouts"] = None,
    ) -> None:
        """
        :param count: 
        :param depends_on: 
        :param lifecycle: 
        :param provider: 
        :param api_management_name: 
        :param name: 
        :param resource_group_name: 
        :param timeouts: timeouts block.
        """
        if isinstance(lifecycle, dict):
            lifecycle = cdktf.TerraformResourceLifecycle(**lifecycle)
        if isinstance(timeouts, dict):
            timeouts = DataAzurermApiManagementGroupTimeouts(**timeouts)
        self._values: typing.Dict[str, typing.Any] = {
            "api_management_name": api_management_name,
            "name": name,
            "resource_group_name": resource_group_name,
        }
        if count is not None:
            self._values["count"] = count
        if depends_on is not None:
            self._values["depends_on"] = depends_on
        if lifecycle is not None:
            self._values["lifecycle"] = lifecycle
        if provider is not None:
            self._values["provider"] = provider
        if timeouts is not None:
            self._values["timeouts"] = timeouts

    @builtins.property
    def count(self) -> typing.Optional[jsii.Number]:
        """
        :stability: experimental
        """
        result = self._values.get("count")
        return result

    @builtins.property
    def depends_on(self) -> typing.Optional[typing.List[cdktf.TerraformResource]]:
        """
        :stability: experimental
        """
        result = self._values.get("depends_on")
        return result

    @builtins.property
    def lifecycle(self) -> typing.Optional[cdktf.TerraformResourceLifecycle]:
        """
        :stability: experimental
        """
        result = self._values.get("lifecycle")
        return result

    @builtins.property
    def provider(self) -> typing.Optional[cdktf.TerraformProvider]:
        """
        :stability: experimental
        """
        result = self._values.get("provider")
        return result

    @builtins.property
    def api_management_name(self) -> builtins.str:
        result = self._values.get("api_management_name")
        assert result is not None, "Required property 'api_management_name' is missing"
        return result

    @builtins.property
    def name(self) -> builtins.str:
        result = self._values.get("name")
        assert result is not None, "Required property 'name' is missing"
        return result

    @builtins.property
    def resource_group_name(self) -> builtins.str:
        result = self._values.get("resource_group_name")
        assert result is not None, "Required property 'resource_group_name' is missing"
        return result

    @builtins.property
    def timeouts(self) -> typing.Optional["DataAzurermApiManagementGroupTimeouts"]:
        """timeouts block."""
        result = self._values.get("timeouts")
        return result

    def __eq__(self, rhs: typing.Any) -> builtins.bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs: typing.Any) -> builtins.bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return "DataAzurermApiManagementGroupConfig(%s)" % ", ".join(
            k + "=" + repr(v) for k, v in self._values.items()
        )


@jsii.data_type(
    jsii_type="@cdktf/provider-azurerm.DataAzurermApiManagementGroupTimeouts",
    jsii_struct_bases=[],
    name_mapping={"read": "read"},
)
class DataAzurermApiManagementGroupTimeouts:
    def __init__(self, *, read: typing.Optional[builtins.str] = None) -> None:
        """
        :param read: 
        """
        self._values: typing.Dict[str, typing.Any] = {}
        if read is not None:
            self._values["read"] = read

    @builtins.property
    def read(self) -> typing.Optional[builtins.str]:
        result = self._values.get("read")
        return result

    def __eq__(self, rhs: typing.Any) -> builtins.bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs: typing.Any) -> builtins.bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return "DataAzurermApiManagementGroupTimeouts(%s)" % ", ".join(
            k + "=" + repr(v) for k, v in self._values.items()
        )


class DataAzurermApiManagementHostnameConfiguration(
    cdktf.ComplexComputedList,
    metaclass=jsii.JSIIMeta,
    jsii_type="@cdktf/provider-azurerm.DataAzurermApiManagementHostnameConfiguration",
):
    def __init__(
        self,
        terraform_resource: cdktf.ITerraformResource,
        terraform_attribute: builtins.str,
        index: builtins.str,
    ) -> None:
        """
        :param terraform_resource: -
        :param terraform_attribute: -
        :param index: -

        :stability: experimental
        """
        jsii.create(DataAzurermApiManagementHostnameConfiguration, self, [terraform_resource, terraform_attribute, index])

    @builtins.property # type: ignore
    @jsii.member(jsii_name="management")
    def management(self) -> typing.Any:
        return jsii.get(self, "management")

    @builtins.property # type: ignore
    @jsii.member(jsii_name="portal")
    def portal(self) -> typing.Any:
        return jsii.get(self, "portal")

    @builtins.property # type: ignore
    @jsii.member(jsii_name="proxy")
    def proxy(self) -> typing.Any:
        return jsii.get(self, "proxy")

    @builtins.property # type: ignore
    @jsii.member(jsii_name="scm")
    def scm(self) -> typing.Any:
        return jsii.get(self, "scm")


class DataAzurermApiManagementHostnameConfigurationManagement(
    cdktf.ComplexComputedList,
    metaclass=jsii.JSIIMeta,
    jsii_type="@cdktf/provider-azurerm.DataAzurermApiManagementHostnameConfigurationManagement",
):
    def __init__(
        self,
        terraform_resource: cdktf.ITerraformResource,
        terraform_attribute: builtins.str,
        index: builtins.str,
    ) -> None:
        """
        :param terraform_resource: -
        :param terraform_attribute: -
        :param index: -

        :stability: experimental
        """
        jsii.create(DataAzurermApiManagementHostnameConfigurationManagement, self, [terraform_resource, terraform_attribute, index])

    @builtins.property # type: ignore
    @jsii.member(jsii_name="hostName")
    def host_name(self) -> builtins.str:
        return jsii.get(self, "hostName")

    @builtins.property # type: ignore
    @jsii.member(jsii_name="keyVaultId")
    def key_vault_id(self) -> builtins.str:
        return jsii.get(self, "keyVaultId")

    @builtins.property # type: ignore
    @jsii.member(jsii_name="negotiateClientCertificate")
    def negotiate_client_certificate(self) -> builtins.bool:
        return jsii.get(self, "negotiateClientCertificate")


class DataAzurermApiManagementHostnameConfigurationPortal(
    cdktf.ComplexComputedList,
    metaclass=jsii.JSIIMeta,
    jsii_type="@cdktf/provider-azurerm.DataAzurermApiManagementHostnameConfigurationPortal",
):
    def __init__(
        self,
        terraform_resource: cdktf.ITerraformResource,
        terraform_attribute: builtins.str,
        index: builtins.str,
    ) -> None:
        """
        :param terraform_resource: -
        :param terraform_attribute: -
        :param index: -

        :stability: experimental
        """
        jsii.create(DataAzurermApiManagementHostnameConfigurationPortal, self, [terraform_resource, terraform_attribute, index])

    @builtins.property # type: ignore
    @jsii.member(jsii_name="hostName")
    def host_name(self) -> builtins.str:
        return jsii.get(self, "hostName")

    @builtins.property # type: ignore
    @jsii.member(jsii_name="keyVaultId")
    def key_vault_id(self) -> builtins.str:
        return jsii.get(self, "keyVaultId")

    @builtins.property # type: ignore
    @jsii.member(jsii_name="negotiateClientCertificate")
    def negotiate_client_certificate(self) -> builtins.bool:
        return jsii.get(self, "negotiateClientCertificate")


class DataAzurermApiManagementHostnameConfigurationProxy(
    cdktf.ComplexComputedList,
    metaclass=jsii.JSIIMeta,
    jsii_type="@cdktf/provider-azurerm.DataAzurermApiManagementHostnameConfigurationProxy",
):
    def __init__(
        self,
        terraform_resource: cdktf.ITerraformResource,
        terraform_attribute: builtins.str,
        index: builtins.str,
    ) -> None:
        """
        :param terraform_resource: -
        :param terraform_attribute: -
        :param index: -

        :stability: experimental
        """
        jsii.create(DataAzurermApiManagementHostnameConfigurationProxy, self, [terraform_resource, terraform_attribute, index])

    @builtins.property # type: ignore
    @jsii.member(jsii_name="defaultSslBinding")
    def default_ssl_binding(self) -> builtins.bool:
        return jsii.get(self, "defaultSslBinding")

    @builtins.property # type: ignore
    @jsii.member(jsii_name="hostName")
    def host_name(self) -> builtins.str:
        return jsii.get(self, "hostName")

    @builtins.property # type: ignore
    @jsii.member(jsii_name="keyVaultId")
    def key_vault_id(self) -> builtins.str:
        return jsii.get(self, "keyVaultId")

    @builtins.property # type: ignore
    @jsii.member(jsii_name="negotiateClientCertificate")
    def negotiate_client_certificate(self) -> builtins.bool:
        return jsii.get(self, "negotiateClientCertificate")


class DataAzurermApiManagementHostnameConfigurationScm(
    cdktf.ComplexComputedList,
    metaclass=jsii.JSIIMeta,
    jsii_type="@cdktf/provider-azurerm.DataAzurermApiManagementHostnameConfigurationScm",
):
    def __init__(
        self,
        terraform_resource: cdktf.ITerraformResource,
        terraform_attribute: builtins.str,
        index: builtins.str,
    ) -> None:
        """
        :param terraform_resource: -
        :param terraform_attribute: -
        :param index: -

        :stability: experimental
        """
        jsii.create(DataAzurermApiManagementHostnameConfigurationScm, self, [terraform_resource, terraform_attribute, index])

    @builtins.property # type: ignore
    @jsii.member(jsii_name="hostName")
    def host_name(self) -> builtins.str:
        return jsii.get(self, "hostName")

    @builtins.property # type: ignore
    @jsii.member(jsii_name="keyVaultId")
    def key_vault_id(self) -> builtins.str:
        return jsii.get(self, "keyVaultId")

    @builtins.property # type: ignore
    @jsii.member(jsii_name="negotiateClientCertificate")
    def negotiate_client_certificate(self) -> builtins.bool:
        return jsii.get(self, "negotiateClientCertificate")


class DataAzurermApiManagementProduct(
    cdktf.TerraformDataSource,
    metaclass=jsii.JSIIMeta,
    jsii_type="@cdktf/provider-azurerm.DataAzurermApiManagementProduct",
):
    def __init__(
        self,
        scope: constructs.Construct,
        id: builtins.str,
        *,
        api_management_name: builtins.str,
        product_id: builtins.str,
        resource_group_name: builtins.str,
        timeouts: typing.Optional["DataAzurermApiManagementProductTimeouts"] = None,
        count: typing.Optional[jsii.Number] = None,
        depends_on: typing.Optional[typing.List[cdktf.TerraformResource]] = None,
        lifecycle: typing.Optional[cdktf.TerraformResourceLifecycle] = None,
        provider: typing.Optional[cdktf.TerraformProvider] = None,
    ) -> None:
        """
        :param scope: -
        :param id: -
        :param api_management_name: 
        :param product_id: 
        :param resource_group_name: 
        :param timeouts: timeouts block.
        :param count: 
        :param depends_on: 
        :param lifecycle: 
        :param provider: 
        """
        config = DataAzurermApiManagementProductConfig(
            api_management_name=api_management_name,
            product_id=product_id,
            resource_group_name=resource_group_name,
            timeouts=timeouts,
            count=count,
            depends_on=depends_on,
            lifecycle=lifecycle,
            provider=provider,
        )

        jsii.create(DataAzurermApiManagementProduct, self, [scope, id, config])

    @jsii.member(jsii_name="synthesizeAttributes")
    def _synthesize_attributes(self) -> typing.Mapping[builtins.str, typing.Any]:
        return jsii.invoke(self, "synthesizeAttributes", [])

    @builtins.property # type: ignore
    @jsii.member(jsii_name="approvalRequired")
    def approval_required(self) -> builtins.bool:
        return jsii.get(self, "approvalRequired")

    @builtins.property # type: ignore
    @jsii.member(jsii_name="description")
    def description(self) -> builtins.str:
        return jsii.get(self, "description")

    @builtins.property # type: ignore
    @jsii.member(jsii_name="displayName")
    def display_name(self) -> builtins.str:
        return jsii.get(self, "displayName")

    @builtins.property # type: ignore
    @jsii.member(jsii_name="published")
    def published(self) -> builtins.bool:
        return jsii.get(self, "published")

    @builtins.property # type: ignore
    @jsii.member(jsii_name="subscriptionRequired")
    def subscription_required(self) -> builtins.bool:
        return jsii.get(self, "subscriptionRequired")

    @builtins.property # type: ignore
    @jsii.member(jsii_name="subscriptionsLimit")
    def subscriptions_limit(self) -> jsii.Number:
        return jsii.get(self, "subscriptionsLimit")

    @builtins.property # type: ignore
    @jsii.member(jsii_name="terms")
    def terms(self) -> builtins.str:
        return jsii.get(self, "terms")

    @builtins.property # type: ignore
    @jsii.member(jsii_name="apiManagementName")
    def api_management_name(self) -> builtins.str:
        return jsii.get(self, "apiManagementName")

    @api_management_name.setter # type: ignore
    def api_management_name(self, value: builtins.str) -> None:
        jsii.set(self, "apiManagementName", value)

    @builtins.property # type: ignore
    @jsii.member(jsii_name="productId")
    def product_id(self) -> builtins.str:
        return jsii.get(self, "productId")

    @product_id.setter # type: ignore
    def product_id(self, value: builtins.str) -> None:
        jsii.set(self, "productId", value)

    @builtins.property # type: ignore
    @jsii.member(jsii_name="resourceGroupName")
    def resource_group_name(self) -> builtins.str:
        return jsii.get(self, "resourceGroupName")

    @resource_group_name.setter # type: ignore
    def resource_group_name(self, value: builtins.str) -> None:
        jsii.set(self, "resourceGroupName", value)

    @builtins.property # type: ignore
    @jsii.member(jsii_name="id")
    def id(self) -> typing.Optional[builtins.str]:
        return jsii.get(self, "id")

    @id.setter # type: ignore
    def id(self, value: typing.Optional[builtins.str]) -> None:
        jsii.set(self, "id", value)

    @builtins.property # type: ignore
    @jsii.member(jsii_name="timeouts")
    def timeouts(self) -> typing.Optional["DataAzurermApiManagementProductTimeouts"]:
        return jsii.get(self, "timeouts")

    @timeouts.setter # type: ignore
    def timeouts(
        self,
        value: typing.Optional["DataAzurermApiManagementProductTimeouts"],
    ) -> None:
        jsii.set(self, "timeouts", value)


@jsii.data_type(
    jsii_type="@cdktf/provider-azurerm.DataAzurermApiManagementProductConfig",
    jsii_struct_bases=[cdktf.TerraformMetaArguments],
    name_mapping={
        "count": "count",
        "depends_on": "dependsOn",
        "lifecycle": "lifecycle",
        "provider": "provider",
        "api_management_name": "apiManagementName",
        "product_id": "productId",
        "resource_group_name": "resourceGroupName",
        "timeouts": "timeouts",
    },
)
class DataAzurermApiManagementProductConfig(cdktf.TerraformMetaArguments):
    def __init__(
        self,
        *,
        count: typing.Optional[jsii.Number] = None,
        depends_on: typing.Optional[typing.List[cdktf.TerraformResource]] = None,
        lifecycle: typing.Optional[cdktf.TerraformResourceLifecycle] = None,
        provider: typing.Optional[cdktf.TerraformProvider] = None,
        api_management_name: builtins.str,
        product_id: builtins.str,
        resource_group_name: builtins.str,
        timeouts: typing.Optional["DataAzurermApiManagementProductTimeouts"] = None,
    ) -> None:
        """
        :param count: 
        :param depends_on: 
        :param lifecycle: 
        :param provider: 
        :param api_management_name: 
        :param product_id: 
        :param resource_group_name: 
        :param timeouts: timeouts block.
        """
        if isinstance(lifecycle, dict):
            lifecycle = cdktf.TerraformResourceLifecycle(**lifecycle)
        if isinstance(timeouts, dict):
            timeouts = DataAzurermApiManagementProductTimeouts(**timeouts)
        self._values: typing.Dict[str, typing.Any] = {
            "api_management_name": api_management_name,
            "product_id": product_id,
            "resource_group_name": resource_group_name,
        }
        if count is not None:
            self._values["count"] = count
        if depends_on is not None:
            self._values["depends_on"] = depends_on
        if lifecycle is not None:
            self._values["lifecycle"] = lifecycle
        if provider is not None:
            self._values["provider"] = provider
        if timeouts is not None:
            self._values["timeouts"] = timeouts

    @builtins.property
    def count(self) -> typing.Optional[jsii.Number]:
        """
        :stability: experimental
        """
        result = self._values.get("count")
        return result

    @builtins.property
    def depends_on(self) -> typing.Optional[typing.List[cdktf.TerraformResource]]:
        """
        :stability: experimental
        """
        result = self._values.get("depends_on")
        return result

    @builtins.property
    def lifecycle(self) -> typing.Optional[cdktf.TerraformResourceLifecycle]:
        """
        :stability: experimental
        """
        result = self._values.get("lifecycle")
        return result

    @builtins.property
    def provider(self) -> typing.Optional[cdktf.TerraformProvider]:
        """
        :stability: experimental
        """
        result = self._values.get("provider")
        return result

    @builtins.property
    def api_management_name(self) -> builtins.str:
        result = self._values.get("api_management_name")
        assert result is not None, "Required property 'api_management_name' is missing"
        return result

    @builtins.property
    def product_id(self) -> builtins.str:
        result = self._values.get("product_id")
        assert result is not None, "Required property 'product_id' is missing"
        return result

    @builtins.property
    def resource_group_name(self) -> builtins.str:
        result = self._values.get("resource_group_name")
        assert result is not None, "Required property 'resource_group_name' is missing"
        return result

    @builtins.property
    def timeouts(self) -> typing.Optional["DataAzurermApiManagementProductTimeouts"]:
        """timeouts block."""
        result = self._values.get("timeouts")
        return result

    def __eq__(self, rhs: typing.Any) -> builtins.bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs: typing.Any) -> builtins.bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return "DataAzurermApiManagementProductConfig(%s)" % ", ".join(
            k + "=" + repr(v) for k, v in self._values.items()
        )


@jsii.data_type(
    jsii_type="@cdktf/provider-azurerm.DataAzurermApiManagementProductTimeouts",
    jsii_struct_bases=[],
    name_mapping={"read": "read"},
)
class DataAzurermApiManagementProductTimeouts:
    def __init__(self, *, read: typing.Optional[builtins.str] = None) -> None:
        """
        :param read: 
        """
        self._values: typing.Dict[str, typing.Any] = {}
        if read is not None:
            self._values["read"] = read

    @builtins.property
    def read(self) -> typing.Optional[builtins.str]:
        result = self._values.get("read")
        return result

    def __eq__(self, rhs: typing.Any) -> builtins.bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs: typing.Any) -> builtins.bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return "DataAzurermApiManagementProductTimeouts(%s)" % ", ".join(
            k + "=" + repr(v) for k, v in self._values.items()
        )


@jsii.data_type(
    jsii_type="@cdktf/provider-azurerm.DataAzurermApiManagementTimeouts",
    jsii_struct_bases=[],
    name_mapping={"read": "read"},
)
class DataAzurermApiManagementTimeouts:
    def __init__(self, *, read: typing.Optional[builtins.str] = None) -> None:
        """
        :param read: 
        """
        self._values: typing.Dict[str, typing.Any] = {}
        if read is not None:
            self._values["read"] = read

    @builtins.property
    def read(self) -> typing.Optional[builtins.str]:
        result = self._values.get("read")
        return result

    def __eq__(self, rhs: typing.Any) -> builtins.bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs: typing.Any) -> builtins.bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return "DataAzurermApiManagementTimeouts(%s)" % ", ".join(
            k + "=" + repr(v) for k, v in self._values.items()
        )


class DataAzurermApiManagementUser(
    cdktf.TerraformDataSource,
    metaclass=jsii.JSIIMeta,
    jsii_type="@cdktf/provider-azurerm.DataAzurermApiManagementUser",
):
    def __init__(
        self,
        scope: constructs.Construct,
        id: builtins.str,
        *,
        api_management_name: builtins.str,
        resource_group_name: builtins.str,
        user_id: builtins.str,
        timeouts: typing.Optional["DataAzurermApiManagementUserTimeouts"] = None,
        count: typing.Optional[jsii.Number] = None,
        depends_on: typing.Optional[typing.List[cdktf.TerraformResource]] = None,
        lifecycle: typing.Optional[cdktf.TerraformResourceLifecycle] = None,
        provider: typing.Optional[cdktf.TerraformProvider] = None,
    ) -> None:
        """
        :param scope: -
        :param id: -
        :param api_management_name: 
        :param resource_group_name: 
        :param user_id: 
        :param timeouts: timeouts block.
        :param count: 
        :param depends_on: 
        :param lifecycle: 
        :param provider: 
        """
        config = DataAzurermApiManagementUserConfig(
            api_management_name=api_management_name,
            resource_group_name=resource_group_name,
            user_id=user_id,
            timeouts=timeouts,
            count=count,
            depends_on=depends_on,
            lifecycle=lifecycle,
            provider=provider,
        )

        jsii.create(DataAzurermApiManagementUser, self, [scope, id, config])

    @jsii.member(jsii_name="synthesizeAttributes")
    def _synthesize_attributes(self) -> typing.Mapping[builtins.str, typing.Any]:
        return jsii.invoke(self, "synthesizeAttributes", [])

    @builtins.property # type: ignore
    @jsii.member(jsii_name="email")
    def email(self) -> builtins.str:
        return jsii.get(self, "email")

    @builtins.property # type: ignore
    @jsii.member(jsii_name="firstName")
    def first_name(self) -> builtins.str:
        return jsii.get(self, "firstName")

    @builtins.property # type: ignore
    @jsii.member(jsii_name="lastName")
    def last_name(self) -> builtins.str:
        return jsii.get(self, "lastName")

    @builtins.property # type: ignore
    @jsii.member(jsii_name="note")
    def note(self) -> builtins.str:
        return jsii.get(self, "note")

    @builtins.property # type: ignore
    @jsii.member(jsii_name="state")
    def state(self) -> builtins.str:
        return jsii.get(self, "state")

    @builtins.property # type: ignore
    @jsii.member(jsii_name="apiManagementName")
    def api_management_name(self) -> builtins.str:
        return jsii.get(self, "apiManagementName")

    @api_management_name.setter # type: ignore
    def api_management_name(self, value: builtins.str) -> None:
        jsii.set(self, "apiManagementName", value)

    @builtins.property # type: ignore
    @jsii.member(jsii_name="resourceGroupName")
    def resource_group_name(self) -> builtins.str:
        return jsii.get(self, "resourceGroupName")

    @resource_group_name.setter # type: ignore
    def resource_group_name(self, value: builtins.str) -> None:
        jsii.set(self, "resourceGroupName", value)

    @builtins.property # type: ignore
    @jsii.member(jsii_name="userId")
    def user_id(self) -> builtins.str:
        return jsii.get(self, "userId")

    @user_id.setter # type: ignore
    def user_id(self, value: builtins.str) -> None:
        jsii.set(self, "userId", value)

    @builtins.property # type: ignore
    @jsii.member(jsii_name="id")
    def id(self) -> typing.Optional[builtins.str]:
        return jsii.get(self, "id")

    @id.setter # type: ignore
    def id(self, value: typing.Optional[builtins.str]) -> None:
        jsii.set(self, "id", value)

    @builtins.property # type: ignore
    @jsii.member(jsii_name="timeouts")
    def timeouts(self) -> typing.Optional["DataAzurermApiManagementUserTimeouts"]:
        return jsii.get(self, "timeouts")

    @timeouts.setter # type: ignore
    def timeouts(
        self,
        value: typing.Optional["DataAzurermApiManagementUserTimeouts"],
    ) -> None:
        jsii.set(self, "timeouts", value)


@jsii.data_type(
    jsii_type="@cdktf/provider-azurerm.DataAzurermApiManagementUserConfig",
    jsii_struct_bases=[cdktf.TerraformMetaArguments],
    name_mapping={
        "count": "count",
        "depends_on": "dependsOn",
        "lifecycle": "lifecycle",
        "provider": "provider",
        "api_management_name": "apiManagementName",
        "resource_group_name": "resourceGroupName",
        "user_id": "userId",
        "timeouts": "timeouts",
    },
)
class DataAzurermApiManagementUserConfig(cdktf.TerraformMetaArguments):
    def __init__(
        self,
        *,
        count: typing.Optional[jsii.Number] = None,
        depends_on: typing.Optional[typing.List[cdktf.TerraformResource]] = None,
        lifecycle: typing.Optional[cdktf.TerraformResourceLifecycle] = None,
        provider: typing.Optional[cdktf.TerraformProvider] = None,
        api_management_name: builtins.str,
        resource_group_name: builtins.str,
        user_id: builtins.str,
        timeouts: typing.Optional["DataAzurermApiManagementUserTimeouts"] = None,
    ) -> None:
        """
        :param count: 
        :param depends_on: 
        :param lifecycle: 
        :param provider: 
        :param api_management_name: 
        :param resource_group_name: 
        :param user_id: 
        :param timeouts: timeouts block.
        """
        if isinstance(lifecycle, dict):
            lifecycle = cdktf.TerraformResourceLifecycle(**lifecycle)
        if isinstance(timeouts, dict):
            timeouts = DataAzurermApiManagementUserTimeouts(**timeouts)
        self._values: typing.Dict[str, typing.Any] = {
            "api_management_name": api_management_name,
            "resource_group_name": resource_group_name,
            "user_id": user_id,
        }
        if count is not None:
            self._values["count"] = count
        if depends_on is not None:
            self._values["depends_on"] = depends_on
        if lifecycle is not None:
            self._values["lifecycle"] = lifecycle
        if provider is not None:
            self._values["provider"] = provider
        if timeouts is not None:
            self._values["timeouts"] = timeouts

    @builtins.property
    def count(self) -> typing.Optional[jsii.Number]:
        """
        :stability: experimental
        """
        result = self._values.get("count")
        return result

    @builtins.property
    def depends_on(self) -> typing.Optional[typing.List[cdktf.TerraformResource]]:
        """
        :stability: experimental
        """
        result = self._values.get("depends_on")
        return result

    @builtins.property
    def lifecycle(self) -> typing.Optional[cdktf.TerraformResourceLifecycle]:
        """
        :stability: experimental
        """
        result = self._values.get("lifecycle")
        return result

    @builtins.property
    def provider(self) -> typing.Optional[cdktf.TerraformProvider]:
        """
        :stability: experimental
        """
        result = self._values.get("provider")
        return result

    @builtins.property
    def api_management_name(self) -> builtins.str:
        result = self._values.get("api_management_name")
        assert result is not None, "Required property 'api_management_name' is missing"
        return result

    @builtins.property
    def resource_group_name(self) -> builtins.str:
        result = self._values.get("resource_group_name")
        assert result is not None, "Required property 'resource_group_name' is missing"
        return result

    @builtins.property
    def user_id(self) -> builtins.str:
        result = self._values.get("user_id")
        assert result is not None, "Required property 'user_id' is missing"
        return result

    @builtins.property
    def timeouts(self) -> typing.Optional["DataAzurermApiManagementUserTimeouts"]:
        """timeouts block."""
        result = self._values.get("timeouts")
        return result

    def __eq__(self, rhs: typing.Any) -> builtins.bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs: typing.Any) -> builtins.bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return "DataAzurermApiManagementUserConfig(%s)" % ", ".join(
            k + "=" + repr(v) for k, v in self._values.items()
        )


@jsii.data_type(
    jsii_type="@cdktf/provider-azurerm.DataAzurermApiManagementUserTimeouts",
    jsii_struct_bases=[],
    name_mapping={"read": "read"},
)
class DataAzurermApiManagementUserTimeouts:
    def __init__(self, *, read: typing.Optional[builtins.str] = None) -> None:
        """
        :param read: 
        """
        self._values: typing.Dict[str, typing.Any] = {}
        if read is not None:
            self._values["read"] = read

    @builtins.property
    def read(self) -> typing.Optional[builtins.str]:
        result = self._values.get("read")
        return result

    def __eq__(self, rhs: typing.Any) -> builtins.bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs: typing.Any) -> builtins.bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return "DataAzurermApiManagementUserTimeouts(%s)" % ", ".join(
            k + "=" + repr(v) for k, v in self._values.items()
        )


class DataAzurermAppService(
    cdktf.TerraformDataSource,
    metaclass=jsii.JSIIMeta,
    jsii_type="@cdktf/provider-azurerm.DataAzurermAppService",
):
    def __init__(
        self,
        scope: constructs.Construct,
        id: builtins.str,
        *,
        name: builtins.str,
        resource_group_name: builtins.str,
        timeouts: typing.Optional["DataAzurermAppServiceTimeouts"] = None,
        count: typing.Optional[jsii.Number] = None,
        depends_on: typing.Optional[typing.List[cdktf.TerraformResource]] = None,
        lifecycle: typing.Optional[cdktf.TerraformResourceLifecycle] = None,
        provider: typing.Optional[cdktf.TerraformProvider] = None,
    ) -> None:
        """
        :param scope: -
        :param id: -
        :param name: 
        :param resource_group_name: 
        :param timeouts: timeouts block.
        :param count: 
        :param depends_on: 
        :param lifecycle: 
        :param provider: 
        """
        config = DataAzurermAppServiceConfig(
            name=name,
            resource_group_name=resource_group_name,
            timeouts=timeouts,
            count=count,
            depends_on=depends_on,
            lifecycle=lifecycle,
            provider=provider,
        )

        jsii.create(DataAzurermAppService, self, [scope, id, config])

    @jsii.member(jsii_name="appSettings")
    def app_settings(self, key: builtins.str) -> builtins.str:
        """
        :param key: -
        """
        return jsii.invoke(self, "appSettings", [key])

    @jsii.member(jsii_name="connectionString")
    def connection_string(
        self,
        index: builtins.str,
    ) -> "DataAzurermAppServiceConnectionString":
        """
        :param index: -
        """
        return jsii.invoke(self, "connectionString", [index])

    @jsii.member(jsii_name="siteConfig")
    def site_config(self, index: builtins.str) -> "DataAzurermAppServiceSiteConfig":
        """
        :param index: -
        """
        return jsii.invoke(self, "siteConfig", [index])

    @jsii.member(jsii_name="siteCredential")
    def site_credential(
        self,
        index: builtins.str,
    ) -> "DataAzurermAppServiceSiteCredential":
        """
        :param index: -
        """
        return jsii.invoke(self, "siteCredential", [index])

    @jsii.member(jsii_name="sourceControl")
    def source_control(
        self,
        index: builtins.str,
    ) -> "DataAzurermAppServiceSourceControl":
        """
        :param index: -
        """
        return jsii.invoke(self, "sourceControl", [index])

    @jsii.member(jsii_name="synthesizeAttributes")
    def _synthesize_attributes(self) -> typing.Mapping[builtins.str, typing.Any]:
        return jsii.invoke(self, "synthesizeAttributes", [])

    @jsii.member(jsii_name="tags")
    def tags(self, key: builtins.str) -> builtins.str:
        """
        :param key: -
        """
        return jsii.invoke(self, "tags", [key])

    @builtins.property # type: ignore
    @jsii.member(jsii_name="appServicePlanId")
    def app_service_plan_id(self) -> builtins.str:
        return jsii.get(self, "appServicePlanId")

    @builtins.property # type: ignore
    @jsii.member(jsii_name="clientAffinityEnabled")
    def client_affinity_enabled(self) -> builtins.bool:
        return jsii.get(self, "clientAffinityEnabled")

    @builtins.property # type: ignore
    @jsii.member(jsii_name="clientCertEnabled")
    def client_cert_enabled(self) -> builtins.bool:
        return jsii.get(self, "clientCertEnabled")

    @builtins.property # type: ignore
    @jsii.member(jsii_name="defaultSiteHostname")
    def default_site_hostname(self) -> builtins.str:
        return jsii.get(self, "defaultSiteHostname")

    @builtins.property # type: ignore
    @jsii.member(jsii_name="enabled")
    def enabled(self) -> builtins.bool:
        return jsii.get(self, "enabled")

    @builtins.property # type: ignore
    @jsii.member(jsii_name="httpsOnly")
    def https_only(self) -> builtins.bool:
        return jsii.get(self, "httpsOnly")

    @builtins.property # type: ignore
    @jsii.member(jsii_name="location")
    def location(self) -> builtins.str:
        return jsii.get(self, "location")

    @builtins.property # type: ignore
    @jsii.member(jsii_name="outboundIpAddresses")
    def outbound_ip_addresses(self) -> builtins.str:
        return jsii.get(self, "outboundIpAddresses")

    @builtins.property # type: ignore
    @jsii.member(jsii_name="possibleOutboundIpAddresses")
    def possible_outbound_ip_addresses(self) -> builtins.str:
        return jsii.get(self, "possibleOutboundIpAddresses")

    @builtins.property # type: ignore
    @jsii.member(jsii_name="name")
    def name(self) -> builtins.str:
        return jsii.get(self, "name")

    @name.setter # type: ignore
    def name(self, value: builtins.str) -> None:
        jsii.set(self, "name", value)

    @builtins.property # type: ignore
    @jsii.member(jsii_name="resourceGroupName")
    def resource_group_name(self) -> builtins.str:
        return jsii.get(self, "resourceGroupName")

    @resource_group_name.setter # type: ignore
    def resource_group_name(self, value: builtins.str) -> None:
        jsii.set(self, "resourceGroupName", value)

    @builtins.property # type: ignore
    @jsii.member(jsii_name="id")
    def id(self) -> typing.Optional[builtins.str]:
        return jsii.get(self, "id")

    @id.setter # type: ignore
    def id(self, value: typing.Optional[builtins.str]) -> None:
        jsii.set(self, "id", value)

    @builtins.property # type: ignore
    @jsii.member(jsii_name="timeouts")
    def timeouts(self) -> typing.Optional["DataAzurermAppServiceTimeouts"]:
        return jsii.get(self, "timeouts")

    @timeouts.setter # type: ignore
    def timeouts(self, value: typing.Optional["DataAzurermAppServiceTimeouts"]) -> None:
        jsii.set(self, "timeouts", value)


class DataAzurermAppServiceCertificate(
    cdktf.TerraformDataSource,
    metaclass=jsii.JSIIMeta,
    jsii_type="@cdktf/provider-azurerm.DataAzurermAppServiceCertificate",
):
    def __init__(
        self,
        scope: constructs.Construct,
        id: builtins.str,
        *,
        name: builtins.str,
        resource_group_name: builtins.str,
        tags: typing.Optional[typing.Mapping[builtins.str, builtins.str]] = None,
        timeouts: typing.Optional["DataAzurermAppServiceCertificateTimeouts"] = None,
        count: typing.Optional[jsii.Number] = None,
        depends_on: typing.Optional[typing.List[cdktf.TerraformResource]] = None,
        lifecycle: typing.Optional[cdktf.TerraformResourceLifecycle] = None,
        provider: typing.Optional[cdktf.TerraformProvider] = None,
    ) -> None:
        """
        :param scope: -
        :param id: -
        :param name: 
        :param resource_group_name: 
        :param tags: 
        :param timeouts: timeouts block.
        :param count: 
        :param depends_on: 
        :param lifecycle: 
        :param provider: 
        """
        config = DataAzurermAppServiceCertificateConfig(
            name=name,
            resource_group_name=resource_group_name,
            tags=tags,
            timeouts=timeouts,
            count=count,
            depends_on=depends_on,
            lifecycle=lifecycle,
            provider=provider,
        )

        jsii.create(DataAzurermAppServiceCertificate, self, [scope, id, config])

    @jsii.member(jsii_name="synthesizeAttributes")
    def _synthesize_attributes(self) -> typing.Mapping[builtins.str, typing.Any]:
        return jsii.invoke(self, "synthesizeAttributes", [])

    @builtins.property # type: ignore
    @jsii.member(jsii_name="expirationDate")
    def expiration_date(self) -> builtins.str:
        return jsii.get(self, "expirationDate")

    @builtins.property # type: ignore
    @jsii.member(jsii_name="friendlyName")
    def friendly_name(self) -> builtins.str:
        return jsii.get(self, "friendlyName")

    @builtins.property # type: ignore
    @jsii.member(jsii_name="hostNames")
    def host_names(self) -> typing.List[builtins.str]:
        return jsii.get(self, "hostNames")

    @builtins.property # type: ignore
    @jsii.member(jsii_name="issueDate")
    def issue_date(self) -> builtins.str:
        return jsii.get(self, "issueDate")

    @builtins.property # type: ignore
    @jsii.member(jsii_name="issuer")
    def issuer(self) -> builtins.str:
        return jsii.get(self, "issuer")

    @builtins.property # type: ignore
    @jsii.member(jsii_name="location")
    def location(self) -> builtins.str:
        return jsii.get(self, "location")

    @builtins.property # type: ignore
    @jsii.member(jsii_name="subjectName")
    def subject_name(self) -> builtins.str:
        return jsii.get(self, "subjectName")

    @builtins.property # type: ignore
    @jsii.member(jsii_name="thumbprint")
    def thumbprint(self) -> builtins.str:
        return jsii.get(self, "thumbprint")

    @builtins.property # type: ignore
    @jsii.member(jsii_name="name")
    def name(self) -> builtins.str:
        return jsii.get(self, "name")

    @name.setter # type: ignore
    def name(self, value: builtins.str) -> None:
        jsii.set(self, "name", value)

    @builtins.property # type: ignore
    @jsii.member(jsii_name="resourceGroupName")
    def resource_group_name(self) -> builtins.str:
        return jsii.get(self, "resourceGroupName")

    @resource_group_name.setter # type: ignore
    def resource_group_name(self, value: builtins.str) -> None:
        jsii.set(self, "resourceGroupName", value)

    @builtins.property # type: ignore
    @jsii.member(jsii_name="id")
    def id(self) -> typing.Optional[builtins.str]:
        return jsii.get(self, "id")

    @id.setter # type: ignore
    def id(self, value: typing.Optional[builtins.str]) -> None:
        jsii.set(self, "id", value)

    @builtins.property # type: ignore
    @jsii.member(jsii_name="tags")
    def tags(self) -> typing.Optional[typing.Mapping[builtins.str, builtins.str]]:
        return jsii.get(self, "tags")

    @tags.setter # type: ignore
    def tags(
        self,
        value: typing.Optional[typing.Mapping[builtins.str, builtins.str]],
    ) -> None:
        jsii.set(self, "tags", value)

    @builtins.property # type: ignore
    @jsii.member(jsii_name="timeouts")
    def timeouts(self) -> typing.Optional["DataAzurermAppServiceCertificateTimeouts"]:
        return jsii.get(self, "timeouts")

    @timeouts.setter # type: ignore
    def timeouts(
        self,
        value: typing.Optional["DataAzurermAppServiceCertificateTimeouts"],
    ) -> None:
        jsii.set(self, "timeouts", value)


@jsii.data_type(
    jsii_type="@cdktf/provider-azurerm.DataAzurermAppServiceCertificateConfig",
    jsii_struct_bases=[cdktf.TerraformMetaArguments],
    name_mapping={
        "count": "count",
        "depends_on": "dependsOn",
        "lifecycle": "lifecycle",
        "provider": "provider",
        "name": "name",
        "resource_group_name": "resourceGroupName",
        "tags": "tags",
        "timeouts": "timeouts",
    },
)
class DataAzurermAppServiceCertificateConfig(cdktf.TerraformMetaArguments):
    def __init__(
        self,
        *,
        count: typing.Optional[jsii.Number] = None,
        depends_on: typing.Optional[typing.List[cdktf.TerraformResource]] = None,
        lifecycle: typing.Optional[cdktf.TerraformResourceLifecycle] = None,
        provider: typing.Optional[cdktf.TerraformProvider] = None,
        name: builtins.str,
        resource_group_name: builtins.str,
        tags: typing.Optional[typing.Mapping[builtins.str, builtins.str]] = None,
        timeouts: typing.Optional["DataAzurermAppServiceCertificateTimeouts"] = None,
    ) -> None:
        """
        :param count: 
        :param depends_on: 
        :param lifecycle: 
        :param provider: 
        :param name: 
        :param resource_group_name: 
        :param tags: 
        :param timeouts: timeouts block.
        """
        if isinstance(lifecycle, dict):
            lifecycle = cdktf.TerraformResourceLifecycle(**lifecycle)
        if isinstance(timeouts, dict):
            timeouts = DataAzurermAppServiceCertificateTimeouts(**timeouts)
        self._values: typing.Dict[str, typing.Any] = {
            "name": name,
            "resource_group_name": resource_group_name,
        }
        if count is not None:
            self._values["count"] = count
        if depends_on is not None:
            self._values["depends_on"] = depends_on
        if lifecycle is not None:
            self._values["lifecycle"] = lifecycle
        if provider is not None:
            self._values["provider"] = provider
        if tags is not None:
            self._values["tags"] = tags
        if timeouts is not None:
            self._values["timeouts"] = timeouts

    @builtins.property
    def count(self) -> typing.Optional[jsii.Number]:
        """
        :stability: experimental
        """
        result = self._values.get("count")
        return result

    @builtins.property
    def depends_on(self) -> typing.Optional[typing.List[cdktf.TerraformResource]]:
        """
        :stability: experimental
        """
        result = self._values.get("depends_on")
        return result

    @builtins.property
    def lifecycle(self) -> typing.Optional[cdktf.TerraformResourceLifecycle]:
        """
        :stability: experimental
        """
        result = self._values.get("lifecycle")
        return result

    @builtins.property
    def provider(self) -> typing.Optional[cdktf.TerraformProvider]:
        """
        :stability: experimental
        """
        result = self._values.get("provider")
        return result

    @builtins.property
    def name(self) -> builtins.str:
        result = self._values.get("name")
        assert result is not None, "Required property 'name' is missing"
        return result

    @builtins.property
    def resource_group_name(self) -> builtins.str:
        result = self._values.get("resource_group_name")
        assert result is not None, "Required property 'resource_group_name' is missing"
        return result

    @builtins.property
    def tags(self) -> typing.Optional[typing.Mapping[builtins.str, builtins.str]]:
        result = self._values.get("tags")
        return result

    @builtins.property
    def timeouts(self) -> typing.Optional["DataAzurermAppServiceCertificateTimeouts"]:
        """timeouts block."""
        result = self._values.get("timeouts")
        return result

    def __eq__(self, rhs: typing.Any) -> builtins.bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs: typing.Any) -> builtins.bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return "DataAzurermAppServiceCertificateConfig(%s)" % ", ".join(
            k + "=" + repr(v) for k, v in self._values.items()
        )


class DataAzurermAppServiceCertificateOrder(
    cdktf.TerraformDataSource,
    metaclass=jsii.JSIIMeta,
    jsii_type="@cdktf/provider-azurerm.DataAzurermAppServiceCertificateOrder",
):
    def __init__(
        self,
        scope: constructs.Construct,
        id: builtins.str,
        *,
        name: builtins.str,
        resource_group_name: builtins.str,
        timeouts: typing.Optional["DataAzurermAppServiceCertificateOrderTimeouts"] = None,
        count: typing.Optional[jsii.Number] = None,
        depends_on: typing.Optional[typing.List[cdktf.TerraformResource]] = None,
        lifecycle: typing.Optional[cdktf.TerraformResourceLifecycle] = None,
        provider: typing.Optional[cdktf.TerraformProvider] = None,
    ) -> None:
        """
        :param scope: -
        :param id: -
        :param name: 
        :param resource_group_name: 
        :param timeouts: timeouts block.
        :param count: 
        :param depends_on: 
        :param lifecycle: 
        :param provider: 
        """
        config = DataAzurermAppServiceCertificateOrderConfig(
            name=name,
            resource_group_name=resource_group_name,
            timeouts=timeouts,
            count=count,
            depends_on=depends_on,
            lifecycle=lifecycle,
            provider=provider,
        )

        jsii.create(DataAzurermAppServiceCertificateOrder, self, [scope, id, config])

    @jsii.member(jsii_name="certificates")
    def certificates(
        self,
        index: builtins.str,
    ) -> "DataAzurermAppServiceCertificateOrderCertificates":
        """
        :param index: -
        """
        return jsii.invoke(self, "certificates", [index])

    @jsii.member(jsii_name="synthesizeAttributes")
    def _synthesize_attributes(self) -> typing.Mapping[builtins.str, typing.Any]:
        return jsii.invoke(self, "synthesizeAttributes", [])

    @jsii.member(jsii_name="tags")
    def tags(self, key: builtins.str) -> builtins.str:
        """
        :param key: -
        """
        return jsii.invoke(self, "tags", [key])

    @builtins.property # type: ignore
    @jsii.member(jsii_name="appServiceCertificateNotRenewableReasons")
    def app_service_certificate_not_renewable_reasons(
        self,
    ) -> typing.List[builtins.str]:
        return jsii.get(self, "appServiceCertificateNotRenewableReasons")

    @builtins.property # type: ignore
    @jsii.member(jsii_name="autoRenew")
    def auto_renew(self) -> builtins.bool:
        return jsii.get(self, "autoRenew")

    @builtins.property # type: ignore
    @jsii.member(jsii_name="csr")
    def csr(self) -> builtins.str:
        return jsii.get(self, "csr")

    @builtins.property # type: ignore
    @jsii.member(jsii_name="distinguishedName")
    def distinguished_name(self) -> builtins.str:
        return jsii.get(self, "distinguishedName")

    @builtins.property # type: ignore
    @jsii.member(jsii_name="domainVerificationToken")
    def domain_verification_token(self) -> builtins.str:
        return jsii.get(self, "domainVerificationToken")

    @builtins.property # type: ignore
    @jsii.member(jsii_name="expirationTime")
    def expiration_time(self) -> builtins.str:
        return jsii.get(self, "expirationTime")

    @builtins.property # type: ignore
    @jsii.member(jsii_name="intermediateThumbprint")
    def intermediate_thumbprint(self) -> builtins.str:
        return jsii.get(self, "intermediateThumbprint")

    @builtins.property # type: ignore
    @jsii.member(jsii_name="isPrivateKeyExternal")
    def is_private_key_external(self) -> builtins.bool:
        return jsii.get(self, "isPrivateKeyExternal")

    @builtins.property # type: ignore
    @jsii.member(jsii_name="keySize")
    def key_size(self) -> jsii.Number:
        return jsii.get(self, "keySize")

    @builtins.property # type: ignore
    @jsii.member(jsii_name="location")
    def location(self) -> builtins.str:
        return jsii.get(self, "location")

    @builtins.property # type: ignore
    @jsii.member(jsii_name="productType")
    def product_type(self) -> builtins.str:
        return jsii.get(self, "productType")

    @builtins.property # type: ignore
    @jsii.member(jsii_name="rootThumbprint")
    def root_thumbprint(self) -> builtins.str:
        return jsii.get(self, "rootThumbprint")

    @builtins.property # type: ignore
    @jsii.member(jsii_name="signedCertificateThumbprint")
    def signed_certificate_thumbprint(self) -> builtins.str:
        return jsii.get(self, "signedCertificateThumbprint")

    @builtins.property # type: ignore
    @jsii.member(jsii_name="status")
    def status(self) -> builtins.str:
        return jsii.get(self, "status")

    @builtins.property # type: ignore
    @jsii.member(jsii_name="validityInYears")
    def validity_in_years(self) -> jsii.Number:
        return jsii.get(self, "validityInYears")

    @builtins.property # type: ignore
    @jsii.member(jsii_name="name")
    def name(self) -> builtins.str:
        return jsii.get(self, "name")

    @name.setter # type: ignore
    def name(self, value: builtins.str) -> None:
        jsii.set(self, "name", value)

    @builtins.property # type: ignore
    @jsii.member(jsii_name="resourceGroupName")
    def resource_group_name(self) -> builtins.str:
        return jsii.get(self, "resourceGroupName")

    @resource_group_name.setter # type: ignore
    def resource_group_name(self, value: builtins.str) -> None:
        jsii.set(self, "resourceGroupName", value)

    @builtins.property # type: ignore
    @jsii.member(jsii_name="id")
    def id(self) -> typing.Optional[builtins.str]:
        return jsii.get(self, "id")

    @id.setter # type: ignore
    def id(self, value: typing.Optional[builtins.str]) -> None:
        jsii.set(self, "id", value)

    @builtins.property # type: ignore
    @jsii.member(jsii_name="timeouts")
    def timeouts(
        self,
    ) -> typing.Optional["DataAzurermAppServiceCertificateOrderTimeouts"]:
        return jsii.get(self, "timeouts")

    @timeouts.setter # type: ignore
    def timeouts(
        self,
        value: typing.Optional["DataAzurermAppServiceCertificateOrderTimeouts"],
    ) -> None:
        jsii.set(self, "timeouts", value)


class DataAzurermAppServiceCertificateOrderCertificates(
    cdktf.ComplexComputedList,
    metaclass=jsii.JSIIMeta,
    jsii_type="@cdktf/provider-azurerm.DataAzurermAppServiceCertificateOrderCertificates",
):
    def __init__(
        self,
        terraform_resource: cdktf.ITerraformResource,
        terraform_attribute: builtins.str,
        index: builtins.str,
    ) -> None:
        """
        :param terraform_resource: -
        :param terraform_attribute: -
        :param index: -

        :stability: experimental
        """
        jsii.create(DataAzurermAppServiceCertificateOrderCertificates, self, [terraform_resource, terraform_attribute, index])

    @builtins.property # type: ignore
    @jsii.member(jsii_name="certificateName")
    def certificate_name(self) -> builtins.str:
        return jsii.get(self, "certificateName")

    @builtins.property # type: ignore
    @jsii.member(jsii_name="keyVaultId")
    def key_vault_id(self) -> builtins.str:
        return jsii.get(self, "keyVaultId")

    @builtins.property # type: ignore
    @jsii.member(jsii_name="keyVaultSecretName")
    def key_vault_secret_name(self) -> builtins.str:
        return jsii.get(self, "keyVaultSecretName")

    @builtins.property # type: ignore
    @jsii.member(jsii_name="provisioningState")
    def provisioning_state(self) -> builtins.str:
        return jsii.get(self, "provisioningState")


@jsii.data_type(
    jsii_type="@cdktf/provider-azurerm.DataAzurermAppServiceCertificateOrderConfig",
    jsii_struct_bases=[cdktf.TerraformMetaArguments],
    name_mapping={
        "count": "count",
        "depends_on": "dependsOn",
        "lifecycle": "lifecycle",
        "provider": "provider",
        "name": "name",
        "resource_group_name": "resourceGroupName",
        "timeouts": "timeouts",
    },
)
class DataAzurermAppServiceCertificateOrderConfig(cdktf.TerraformMetaArguments):
    def __init__(
        self,
        *,
        count: typing.Optional[jsii.Number] = None,
        depends_on: typing.Optional[typing.List[cdktf.TerraformResource]] = None,
        lifecycle: typing.Optional[cdktf.TerraformResourceLifecycle] = None,
        provider: typing.Optional[cdktf.TerraformProvider] = None,
        name: builtins.str,
        resource_group_name: builtins.str,
        timeouts: typing.Optional["DataAzurermAppServiceCertificateOrderTimeouts"] = None,
    ) -> None:
        """
        :param count: 
        :param depends_on: 
        :param lifecycle: 
        :param provider: 
        :param name: 
        :param resource_group_name: 
        :param timeouts: timeouts block.
        """
        if isinstance(lifecycle, dict):
            lifecycle = cdktf.TerraformResourceLifecycle(**lifecycle)
        if isinstance(timeouts, dict):
            timeouts = DataAzurermAppServiceCertificateOrderTimeouts(**timeouts)
        self._values: typing.Dict[str, typing.Any] = {
            "name": name,
            "resource_group_name": resource_group_name,
        }
        if count is not None:
            self._values["count"] = count
        if depends_on is not None:
            self._values["depends_on"] = depends_on
        if lifecycle is not None:
            self._values["lifecycle"] = lifecycle
        if provider is not None:
            self._values["provider"] = provider
        if timeouts is not None:
            self._values["timeouts"] = timeouts

    @builtins.property
    def count(self) -> typing.Optional[jsii.Number]:
        """
        :stability: experimental
        """
        result = self._values.get("count")
        return result

    @builtins.property
    def depends_on(self) -> typing.Optional[typing.List[cdktf.TerraformResource]]:
        """
        :stability: experimental
        """
        result = self._values.get("depends_on")
        return result

    @builtins.property
    def lifecycle(self) -> typing.Optional[cdktf.TerraformResourceLifecycle]:
        """
        :stability: experimental
        """
        result = self._values.get("lifecycle")
        return result

    @builtins.property
    def provider(self) -> typing.Optional[cdktf.TerraformProvider]:
        """
        :stability: experimental
        """
        result = self._values.get("provider")
        return result

    @builtins.property
    def name(self) -> builtins.str:
        result = self._values.get("name")
        assert result is not None, "Required property 'name' is missing"
        return result

    @builtins.property
    def resource_group_name(self) -> builtins.str:
        result = self._values.get("resource_group_name")
        assert result is not None, "Required property 'resource_group_name' is missing"
        return result

    @builtins.property
    def timeouts(
        self,
    ) -> typing.Optional["DataAzurermAppServiceCertificateOrderTimeouts"]:
        """timeouts block."""
        result = self._values.get("timeouts")
        return result

    def __eq__(self, rhs: typing.Any) -> builtins.bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs: typing.Any) -> builtins.bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return "DataAzurermAppServiceCertificateOrderConfig(%s)" % ", ".join(
            k + "=" + repr(v) for k, v in self._values.items()
        )


@jsii.data_type(
    jsii_type="@cdktf/provider-azurerm.DataAzurermAppServiceCertificateOrderTimeouts",
    jsii_struct_bases=[],
    name_mapping={"read": "read"},
)
class DataAzurermAppServiceCertificateOrderTimeouts:
    def __init__(self, *, read: typing.Optional[builtins.str] = None) -> None:
        """
        :param read: 
        """
        self._values: typing.Dict[str, typing.Any] = {}
        if read is not None:
            self._values["read"] = read

    @builtins.property
    def read(self) -> typing.Optional[builtins.str]:
        result = self._values.get("read")
        return result

    def __eq__(self, rhs: typing.Any) -> builtins.bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs: typing.Any) -> builtins.bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return "DataAzurermAppServiceCertificateOrderTimeouts(%s)" % ", ".join(
            k + "=" + repr(v) for k, v in self._values.items()
        )


@jsii.data_type(
    jsii_type="@cdktf/provider-azurerm.DataAzurermAppServiceCertificateTimeouts",
    jsii_struct_bases=[],
    name_mapping={"read": "read"},
)
class DataAzurermAppServiceCertificateTimeouts:
    def __init__(self, *, read: typing.Optional[builtins.str] = None) -> None:
        """
        :param read: 
        """
        self._values: typing.Dict[str, typing.Any] = {}
        if read is not None:
            self._values["read"] = read

    @builtins.property
    def read(self) -> typing.Optional[builtins.str]:
        result = self._values.get("read")
        return result

    def __eq__(self, rhs: typing.Any) -> builtins.bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs: typing.Any) -> builtins.bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return "DataAzurermAppServiceCertificateTimeouts(%s)" % ", ".join(
            k + "=" + repr(v) for k, v in self._values.items()
        )


@jsii.data_type(
    jsii_type="@cdktf/provider-azurerm.DataAzurermAppServiceConfig",
    jsii_struct_bases=[cdktf.TerraformMetaArguments],
    name_mapping={
        "count": "count",
        "depends_on": "dependsOn",
        "lifecycle": "lifecycle",
        "provider": "provider",
        "name": "name",
        "resource_group_name": "resourceGroupName",
        "timeouts": "timeouts",
    },
)
class DataAzurermAppServiceConfig(cdktf.TerraformMetaArguments):
    def __init__(
        self,
        *,
        count: typing.Optional[jsii.Number] = None,
        depends_on: typing.Optional[typing.List[cdktf.TerraformResource]] = None,
        lifecycle: typing.Optional[cdktf.TerraformResourceLifecycle] = None,
        provider: typing.Optional[cdktf.TerraformProvider] = None,
        name: builtins.str,
        resource_group_name: builtins.str,
        timeouts: typing.Optional["DataAzurermAppServiceTimeouts"] = None,
    ) -> None:
        """
        :param count: 
        :param depends_on: 
        :param lifecycle: 
        :param provider: 
        :param name: 
        :param resource_group_name: 
        :param timeouts: timeouts block.
        """
        if isinstance(lifecycle, dict):
            lifecycle = cdktf.TerraformResourceLifecycle(**lifecycle)
        if isinstance(timeouts, dict):
            timeouts = DataAzurermAppServiceTimeouts(**timeouts)
        self._values: typing.Dict[str, typing.Any] = {
            "name": name,
            "resource_group_name": resource_group_name,
        }
        if count is not None:
            self._values["count"] = count
        if depends_on is not None:
            self._values["depends_on"] = depends_on
        if lifecycle is not None:
            self._values["lifecycle"] = lifecycle
        if provider is not None:
            self._values["provider"] = provider
        if timeouts is not None:
            self._values["timeouts"] = timeouts

    @builtins.property
    def count(self) -> typing.Optional[jsii.Number]:
        """
        :stability: experimental
        """
        result = self._values.get("count")
        return result

    @builtins.property
    def depends_on(self) -> typing.Optional[typing.List[cdktf.TerraformResource]]:
        """
        :stability: experimental
        """
        result = self._values.get("depends_on")
        return result

    @builtins.property
    def lifecycle(self) -> typing.Optional[cdktf.TerraformResourceLifecycle]:
        """
        :stability: experimental
        """
        result = self._values.get("lifecycle")
        return result

    @builtins.property
    def provider(self) -> typing.Optional[cdktf.TerraformProvider]:
        """
        :stability: experimental
        """
        result = self._values.get("provider")
        return result

    @builtins.property
    def name(self) -> builtins.str:
        result = self._values.get("name")
        assert result is not None, "Required property 'name' is missing"
        return result

    @builtins.property
    def resource_group_name(self) -> builtins.str:
        result = self._values.get("resource_group_name")
        assert result is not None, "Required property 'resource_group_name' is missing"
        return result

    @builtins.property
    def timeouts(self) -> typing.Optional["DataAzurermAppServiceTimeouts"]:
        """timeouts block."""
        result = self._values.get("timeouts")
        return result

    def __eq__(self, rhs: typing.Any) -> builtins.bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs: typing.Any) -> builtins.bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return "DataAzurermAppServiceConfig(%s)" % ", ".join(
            k + "=" + repr(v) for k, v in self._values.items()
        )


class DataAzurermAppServiceConnectionString(
    cdktf.ComplexComputedList,
    metaclass=jsii.JSIIMeta,
    jsii_type="@cdktf/provider-azurerm.DataAzurermAppServiceConnectionString",
):
    def __init__(
        self,
        terraform_resource: cdktf.ITerraformResource,
        terraform_attribute: builtins.str,
        index: builtins.str,
    ) -> None:
        """
        :param terraform_resource: -
        :param terraform_attribute: -
        :param index: -

        :stability: experimental
        """
        jsii.create(DataAzurermAppServiceConnectionString, self, [terraform_resource, terraform_attribute, index])

    @builtins.property # type: ignore
    @jsii.member(jsii_name="name")
    def name(self) -> builtins.str:
        return jsii.get(self, "name")

    @builtins.property # type: ignore
    @jsii.member(jsii_name="type")
    def type(self) -> builtins.str:
        return jsii.get(self, "type")

    @builtins.property # type: ignore
    @jsii.member(jsii_name="value")
    def value(self) -> builtins.str:
        return jsii.get(self, "value")


class DataAzurermAppServiceEnvironment(
    cdktf.TerraformDataSource,
    metaclass=jsii.JSIIMeta,
    jsii_type="@cdktf/provider-azurerm.DataAzurermAppServiceEnvironment",
):
    def __init__(
        self,
        scope: constructs.Construct,
        id: builtins.str,
        *,
        name: builtins.str,
        resource_group_name: builtins.str,
        timeouts: typing.Optional["DataAzurermAppServiceEnvironmentTimeouts"] = None,
        count: typing.Optional[jsii.Number] = None,
        depends_on: typing.Optional[typing.List[cdktf.TerraformResource]] = None,
        lifecycle: typing.Optional[cdktf.TerraformResourceLifecycle] = None,
        provider: typing.Optional[cdktf.TerraformProvider] = None,
    ) -> None:
        """
        :param scope: -
        :param id: -
        :param name: 
        :param resource_group_name: 
        :param timeouts: timeouts block.
        :param count: 
        :param depends_on: 
        :param lifecycle: 
        :param provider: 
        """
        config = DataAzurermAppServiceEnvironmentConfig(
            name=name,
            resource_group_name=resource_group_name,
            timeouts=timeouts,
            count=count,
            depends_on=depends_on,
            lifecycle=lifecycle,
            provider=provider,
        )

        jsii.create(DataAzurermAppServiceEnvironment, self, [scope, id, config])

    @jsii.member(jsii_name="synthesizeAttributes")
    def _synthesize_attributes(self) -> typing.Mapping[builtins.str, typing.Any]:
        return jsii.invoke(self, "synthesizeAttributes", [])

    @jsii.member(jsii_name="tags")
    def tags(self, key: builtins.str) -> builtins.str:
        """
        :param key: -
        """
        return jsii.invoke(self, "tags", [key])

    @builtins.property # type: ignore
    @jsii.member(jsii_name="frontEndScaleFactor")
    def front_end_scale_factor(self) -> jsii.Number:
        return jsii.get(self, "frontEndScaleFactor")

    @builtins.property # type: ignore
    @jsii.member(jsii_name="pricingTier")
    def pricing_tier(self) -> builtins.str:
        return jsii.get(self, "pricingTier")

    @builtins.property # type: ignore
    @jsii.member(jsii_name="name")
    def name(self) -> builtins.str:
        return jsii.get(self, "name")

    @name.setter # type: ignore
    def name(self, value: builtins.str) -> None:
        jsii.set(self, "name", value)

    @builtins.property # type: ignore
    @jsii.member(jsii_name="resourceGroupName")
    def resource_group_name(self) -> builtins.str:
        return jsii.get(self, "resourceGroupName")

    @resource_group_name.setter # type: ignore
    def resource_group_name(self, value: builtins.str) -> None:
        jsii.set(self, "resourceGroupName", value)

    @builtins.property # type: ignore
    @jsii.member(jsii_name="id")
    def id(self) -> typing.Optional[builtins.str]:
        return jsii.get(self, "id")

    @id.setter # type: ignore
    def id(self, value: typing.Optional[builtins.str]) -> None:
        jsii.set(self, "id", value)

    @builtins.property # type: ignore
    @jsii.member(jsii_name="timeouts")
    def timeouts(self) -> typing.Optional["DataAzurermAppServiceEnvironmentTimeouts"]:
        return jsii.get(self, "timeouts")

    @timeouts.setter # type: ignore
    def timeouts(
        self,
        value: typing.Optional["DataAzurermAppServiceEnvironmentTimeouts"],
    ) -> None:
        jsii.set(self, "timeouts", value)


@jsii.data_type(
    jsii_type="@cdktf/provider-azurerm.DataAzurermAppServiceEnvironmentConfig",
    jsii_struct_bases=[cdktf.TerraformMetaArguments],
    name_mapping={
        "count": "count",
        "depends_on": "dependsOn",
        "lifecycle": "lifecycle",
        "provider": "provider",
        "name": "name",
        "resource_group_name": "resourceGroupName",
        "timeouts": "timeouts",
    },
)
class DataAzurermAppServiceEnvironmentConfig(cdktf.TerraformMetaArguments):
    def __init__(
        self,
        *,
        count: typing.Optional[jsii.Number] = None,
        depends_on: typing.Optional[typing.List[cdktf.TerraformResource]] = None,
        lifecycle: typing.Optional[cdktf.TerraformResourceLifecycle] = None,
        provider: typing.Optional[cdktf.TerraformProvider] = None,
        name: builtins.str,
        resource_group_name: builtins.str,
        timeouts: typing.Optional["DataAzurermAppServiceEnvironmentTimeouts"] = None,
    ) -> None:
        """
        :param count: 
        :param depends_on: 
        :param lifecycle: 
        :param provider: 
        :param name: 
        :param resource_group_name: 
        :param timeouts: timeouts block.
        """
        if isinstance(lifecycle, dict):
            lifecycle = cdktf.TerraformResourceLifecycle(**lifecycle)
        if isinstance(timeouts, dict):
            timeouts = DataAzurermAppServiceEnvironmentTimeouts(**timeouts)
        self._values: typing.Dict[str, typing.Any] = {
            "name": name,
            "resource_group_name": resource_group_name,
        }
        if count is not None:
            self._values["count"] = count
        if depends_on is not None:
            self._values["depends_on"] = depends_on
        if lifecycle is not None:
            self._values["lifecycle"] = lifecycle
        if provider is not None:
            self._values["provider"] = provider
        if timeouts is not None:
            self._values["timeouts"] = timeouts

    @builtins.property
    def count(self) -> typing.Optional[jsii.Number]:
        """
        :stability: experimental
        """
        result = self._values.get("count")
        return result

    @builtins.property
    def depends_on(self) -> typing.Optional[typing.List[cdktf.TerraformResource]]:
        """
        :stability: experimental
        """
        result = self._values.get("depends_on")
        return result

    @builtins.property
    def lifecycle(self) -> typing.Optional[cdktf.TerraformResourceLifecycle]:
        """
        :stability: experimental
        """
        result = self._values.get("lifecycle")
        return result

    @builtins.property
    def provider(self) -> typing.Optional[cdktf.TerraformProvider]:
        """
        :stability: experimental
        """
        result = self._values.get("provider")
        return result

    @builtins.property
    def name(self) -> builtins.str:
        result = self._values.get("name")
        assert result is not None, "Required property 'name' is missing"
        return result

    @builtins.property
    def resource_group_name(self) -> builtins.str:
        result = self._values.get("resource_group_name")
        assert result is not None, "Required property 'resource_group_name' is missing"
        return result

    @builtins.property
    def timeouts(self) -> typing.Optional["DataAzurermAppServiceEnvironmentTimeouts"]:
        """timeouts block."""
        result = self._values.get("timeouts")
        return result

    def __eq__(self, rhs: typing.Any) -> builtins.bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs: typing.Any) -> builtins.bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return "DataAzurermAppServiceEnvironmentConfig(%s)" % ", ".join(
            k + "=" + repr(v) for k, v in self._values.items()
        )


@jsii.data_type(
    jsii_type="@cdktf/provider-azurerm.DataAzurermAppServiceEnvironmentTimeouts",
    jsii_struct_bases=[],
    name_mapping={"read": "read"},
)
class DataAzurermAppServiceEnvironmentTimeouts:
    def __init__(self, *, read: typing.Optional[builtins.str] = None) -> None:
        """
        :param read: 
        """
        self._values: typing.Dict[str, typing.Any] = {}
        if read is not None:
            self._values["read"] = read

    @builtins.property
    def read(self) -> typing.Optional[builtins.str]:
        result = self._values.get("read")
        return result

    def __eq__(self, rhs: typing.Any) -> builtins.bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs: typing.Any) -> builtins.bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return "DataAzurermAppServiceEnvironmentTimeouts(%s)" % ", ".join(
            k + "=" + repr(v) for k, v in self._values.items()
        )


class DataAzurermAppServicePlan(
    cdktf.TerraformDataSource,
    metaclass=jsii.JSIIMeta,
    jsii_type="@cdktf/provider-azurerm.DataAzurermAppServicePlan",
):
    def __init__(
        self,
        scope: constructs.Construct,
        id: builtins.str,
        *,
        name: builtins.str,
        resource_group_name: builtins.str,
        timeouts: typing.Optional["DataAzurermAppServicePlanTimeouts"] = None,
        count: typing.Optional[jsii.Number] = None,
        depends_on: typing.Optional[typing.List[cdktf.TerraformResource]] = None,
        lifecycle: typing.Optional[cdktf.TerraformResourceLifecycle] = None,
        provider: typing.Optional[cdktf.TerraformProvider] = None,
    ) -> None:
        """
        :param scope: -
        :param id: -
        :param name: 
        :param resource_group_name: 
        :param timeouts: timeouts block.
        :param count: 
        :param depends_on: 
        :param lifecycle: 
        :param provider: 
        """
        config = DataAzurermAppServicePlanConfig(
            name=name,
            resource_group_name=resource_group_name,
            timeouts=timeouts,
            count=count,
            depends_on=depends_on,
            lifecycle=lifecycle,
            provider=provider,
        )

        jsii.create(DataAzurermAppServicePlan, self, [scope, id, config])

    @jsii.member(jsii_name="sku")
    def sku(self, index: builtins.str) -> "DataAzurermAppServicePlanSku":
        """
        :param index: -
        """
        return jsii.invoke(self, "sku", [index])

    @jsii.member(jsii_name="synthesizeAttributes")
    def _synthesize_attributes(self) -> typing.Mapping[builtins.str, typing.Any]:
        return jsii.invoke(self, "synthesizeAttributes", [])

    @jsii.member(jsii_name="tags")
    def tags(self, key: builtins.str) -> builtins.str:
        """
        :param key: -
        """
        return jsii.invoke(self, "tags", [key])

    @builtins.property # type: ignore
    @jsii.member(jsii_name="appServiceEnvironmentId")
    def app_service_environment_id(self) -> builtins.str:
        return jsii.get(self, "appServiceEnvironmentId")

    @builtins.property # type: ignore
    @jsii.member(jsii_name="isXenon")
    def is_xenon(self) -> builtins.bool:
        return jsii.get(self, "isXenon")

    @builtins.property # type: ignore
    @jsii.member(jsii_name="kind")
    def kind(self) -> builtins.str:
        return jsii.get(self, "kind")

    @builtins.property # type: ignore
    @jsii.member(jsii_name="location")
    def location(self) -> builtins.str:
        return jsii.get(self, "location")

    @builtins.property # type: ignore
    @jsii.member(jsii_name="maximumElasticWorkerCount")
    def maximum_elastic_worker_count(self) -> jsii.Number:
        return jsii.get(self, "maximumElasticWorkerCount")

    @builtins.property # type: ignore
    @jsii.member(jsii_name="maximumNumberOfWorkers")
    def maximum_number_of_workers(self) -> jsii.Number:
        return jsii.get(self, "maximumNumberOfWorkers")

    @builtins.property # type: ignore
    @jsii.member(jsii_name="perSiteScaling")
    def per_site_scaling(self) -> builtins.bool:
        return jsii.get(self, "perSiteScaling")

    @builtins.property # type: ignore
    @jsii.member(jsii_name="reserved")
    def reserved(self) -> builtins.bool:
        return jsii.get(self, "reserved")

    @builtins.property # type: ignore
    @jsii.member(jsii_name="name")
    def name(self) -> builtins.str:
        return jsii.get(self, "name")

    @name.setter # type: ignore
    def name(self, value: builtins.str) -> None:
        jsii.set(self, "name", value)

    @builtins.property # type: ignore
    @jsii.member(jsii_name="resourceGroupName")
    def resource_group_name(self) -> builtins.str:
        return jsii.get(self, "resourceGroupName")

    @resource_group_name.setter # type: ignore
    def resource_group_name(self, value: builtins.str) -> None:
        jsii.set(self, "resourceGroupName", value)

    @builtins.property # type: ignore
    @jsii.member(jsii_name="id")
    def id(self) -> typing.Optional[builtins.str]:
        return jsii.get(self, "id")

    @id.setter # type: ignore
    def id(self, value: typing.Optional[builtins.str]) -> None:
        jsii.set(self, "id", value)

    @builtins.property # type: ignore
    @jsii.member(jsii_name="timeouts")
    def timeouts(self) -> typing.Optional["DataAzurermAppServicePlanTimeouts"]:
        return jsii.get(self, "timeouts")

    @timeouts.setter # type: ignore
    def timeouts(
        self,
        value: typing.Optional["DataAzurermAppServicePlanTimeouts"],
    ) -> None:
        jsii.set(self, "timeouts", value)


@jsii.data_type(
    jsii_type="@cdktf/provider-azurerm.DataAzurermAppServicePlanConfig",
    jsii_struct_bases=[cdktf.TerraformMetaArguments],
    name_mapping={
        "count": "count",
        "depends_on": "dependsOn",
        "lifecycle": "lifecycle",
        "provider": "provider",
        "name": "name",
        "resource_group_name": "resourceGroupName",
        "timeouts": "timeouts",
    },
)
class DataAzurermAppServicePlanConfig(cdktf.TerraformMetaArguments):
    def __init__(
        self,
        *,
        count: typing.Optional[jsii.Number] = None,
        depends_on: typing.Optional[typing.List[cdktf.TerraformResource]] = None,
        lifecycle: typing.Optional[cdktf.TerraformResourceLifecycle] = None,
        provider: typing.Optional[cdktf.TerraformProvider] = None,
        name: builtins.str,
        resource_group_name: builtins.str,
        timeouts: typing.Optional["DataAzurermAppServicePlanTimeouts"] = None,
    ) -> None:
        """
        :param count: 
        :param depends_on: 
        :param lifecycle: 
        :param provider: 
        :param name: 
        :param resource_group_name: 
        :param timeouts: timeouts block.
        """
        if isinstance(lifecycle, dict):
            lifecycle = cdktf.TerraformResourceLifecycle(**lifecycle)
        if isinstance(timeouts, dict):
            timeouts = DataAzurermAppServicePlanTimeouts(**timeouts)
        self._values: typing.Dict[str, typing.Any] = {
            "name": name,
            "resource_group_name": resource_group_name,
        }
        if count is not None:
            self._values["count"] = count
        if depends_on is not None:
            self._values["depends_on"] = depends_on
        if lifecycle is not None:
            self._values["lifecycle"] = lifecycle
        if provider is not None:
            self._values["provider"] = provider
        if timeouts is not None:
            self._values["timeouts"] = timeouts

    @builtins.property
    def count(self) -> typing.Optional[jsii.Number]:
        """
        :stability: experimental
        """
        result = self._values.get("count")
        return result

    @builtins.property
    def depends_on(self) -> typing.Optional[typing.List[cdktf.TerraformResource]]:
        """
        :stability: experimental
        """
        result = self._values.get("depends_on")
        return result

    @builtins.property
    def lifecycle(self) -> typing.Optional[cdktf.TerraformResourceLifecycle]:
        """
        :stability: experimental
        """
        result = self._values.get("lifecycle")
        return result

    @builtins.property
    def provider(self) -> typing.Optional[cdktf.TerraformProvider]:
        """
        :stability: experimental
        """
        result = self._values.get("provider")
        return result

    @builtins.property
    def name(self) -> builtins.str:
        result = self._values.get("name")
        assert result is not None, "Required property 'name' is missing"
        return result

    @builtins.property
    def resource_group_name(self) -> builtins.str:
        result = self._values.get("resource_group_name")
        assert result is not None, "Required property 'resource_group_name' is missing"
        return result

    @builtins.property
    def timeouts(self) -> typing.Optional["DataAzurermAppServicePlanTimeouts"]:
        """timeouts block."""
        result = self._values.get("timeouts")
        return result

    def __eq__(self, rhs: typing.Any) -> builtins.bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs: typing.Any) -> builtins.bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return "DataAzurermAppServicePlanConfig(%s)" % ", ".join(
            k + "=" + repr(v) for k, v in self._values.items()
        )


class DataAzurermAppServicePlanSku(
    cdktf.ComplexComputedList,
    metaclass=jsii.JSIIMeta,
    jsii_type="@cdktf/provider-azurerm.DataAzurermAppServicePlanSku",
):
    def __init__(
        self,
        terraform_resource: cdktf.ITerraformResource,
        terraform_attribute: builtins.str,
        index: builtins.str,
    ) -> None:
        """
        :param terraform_resource: -
        :param terraform_attribute: -
        :param index: -

        :stability: experimental
        """
        jsii.create(DataAzurermAppServicePlanSku, self, [terraform_resource, terraform_attribute, index])

    @builtins.property # type: ignore
    @jsii.member(jsii_name="capacity")
    def capacity(self) -> jsii.Number:
        return jsii.get(self, "capacity")

    @builtins.property # type: ignore
    @jsii.member(jsii_name="size")
    def size(self) -> builtins.str:
        return jsii.get(self, "size")

    @builtins.property # type: ignore
    @jsii.member(jsii_name="tier")
    def tier(self) -> builtins.str:
        return jsii.get(self, "tier")


@jsii.data_type(
    jsii_type="@cdktf/provider-azurerm.DataAzurermAppServicePlanTimeouts",
    jsii_struct_bases=[],
    name_mapping={"read": "read"},
)
class DataAzurermAppServicePlanTimeouts:
    def __init__(self, *, read: typing.Optional[builtins.str] = None) -> None:
        """
        :param read: 
        """
        self._values: typing.Dict[str, typing.Any] = {}
        if read is not None:
            self._values["read"] = read

    @builtins.property
    def read(self) -> typing.Optional[builtins.str]:
        result = self._values.get("read")
        return result

    def __eq__(self, rhs: typing.Any) -> builtins.bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs: typing.Any) -> builtins.bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return "DataAzurermAppServicePlanTimeouts(%s)" % ", ".join(
            k + "=" + repr(v) for k, v in self._values.items()
        )


class DataAzurermAppServiceSiteConfig(
    cdktf.ComplexComputedList,
    metaclass=jsii.JSIIMeta,
    jsii_type="@cdktf/provider-azurerm.DataAzurermAppServiceSiteConfig",
):
    def __init__(
        self,
        terraform_resource: cdktf.ITerraformResource,
        terraform_attribute: builtins.str,
        index: builtins.str,
    ) -> None:
        """
        :param terraform_resource: -
        :param terraform_attribute: -
        :param index: -

        :stability: experimental
        """
        jsii.create(DataAzurermAppServiceSiteConfig, self, [terraform_resource, terraform_attribute, index])

    @builtins.property # type: ignore
    @jsii.member(jsii_name="alwaysOn")
    def always_on(self) -> builtins.bool:
        return jsii.get(self, "alwaysOn")

    @builtins.property # type: ignore
    @jsii.member(jsii_name="appCommandLine")
    def app_command_line(self) -> builtins.str:
        return jsii.get(self, "appCommandLine")

    @builtins.property # type: ignore
    @jsii.member(jsii_name="cors")
    def cors(self) -> typing.Any:
        return jsii.get(self, "cors")

    @builtins.property # type: ignore
    @jsii.member(jsii_name="defaultDocuments")
    def default_documents(self) -> typing.List[builtins.str]:
        return jsii.get(self, "defaultDocuments")

    @builtins.property # type: ignore
    @jsii.member(jsii_name="dotnetFrameworkVersion")
    def dotnet_framework_version(self) -> builtins.str:
        return jsii.get(self, "dotnetFrameworkVersion")

    @builtins.property # type: ignore
    @jsii.member(jsii_name="ftpsState")
    def ftps_state(self) -> builtins.str:
        return jsii.get(self, "ftpsState")

    @builtins.property # type: ignore
    @jsii.member(jsii_name="http2Enabled")
    def http2_enabled(self) -> builtins.bool:
        return jsii.get(self, "http2Enabled")

    @builtins.property # type: ignore
    @jsii.member(jsii_name="ipRestriction")
    def ip_restriction(self) -> typing.Any:
        return jsii.get(self, "ipRestriction")

    @builtins.property # type: ignore
    @jsii.member(jsii_name="javaContainer")
    def java_container(self) -> builtins.str:
        return jsii.get(self, "javaContainer")

    @builtins.property # type: ignore
    @jsii.member(jsii_name="javaContainerVersion")
    def java_container_version(self) -> builtins.str:
        return jsii.get(self, "javaContainerVersion")

    @builtins.property # type: ignore
    @jsii.member(jsii_name="javaVersion")
    def java_version(self) -> builtins.str:
        return jsii.get(self, "javaVersion")

    @builtins.property # type: ignore
    @jsii.member(jsii_name="linuxFxVersion")
    def linux_fx_version(self) -> builtins.str:
        return jsii.get(self, "linuxFxVersion")

    @builtins.property # type: ignore
    @jsii.member(jsii_name="localMysqlEnabled")
    def local_mysql_enabled(self) -> builtins.bool:
        return jsii.get(self, "localMysqlEnabled")

    @builtins.property # type: ignore
    @jsii.member(jsii_name="managedPipelineMode")
    def managed_pipeline_mode(self) -> builtins.str:
        return jsii.get(self, "managedPipelineMode")

    @builtins.property # type: ignore
    @jsii.member(jsii_name="minTlsVersion")
    def min_tls_version(self) -> builtins.str:
        return jsii.get(self, "minTlsVersion")

    @builtins.property # type: ignore
    @jsii.member(jsii_name="phpVersion")
    def php_version(self) -> builtins.str:
        return jsii.get(self, "phpVersion")

    @builtins.property # type: ignore
    @jsii.member(jsii_name="pythonVersion")
    def python_version(self) -> builtins.str:
        return jsii.get(self, "pythonVersion")

    @builtins.property # type: ignore
    @jsii.member(jsii_name="remoteDebuggingEnabled")
    def remote_debugging_enabled(self) -> builtins.bool:
        return jsii.get(self, "remoteDebuggingEnabled")

    @builtins.property # type: ignore
    @jsii.member(jsii_name="remoteDebuggingVersion")
    def remote_debugging_version(self) -> builtins.str:
        return jsii.get(self, "remoteDebuggingVersion")

    @builtins.property # type: ignore
    @jsii.member(jsii_name="scmType")
    def scm_type(self) -> builtins.str:
        return jsii.get(self, "scmType")

    @builtins.property # type: ignore
    @jsii.member(jsii_name="use32BitWorkerProcess")
    def use32_bit_worker_process(self) -> builtins.bool:
        return jsii.get(self, "use32BitWorkerProcess")

    @builtins.property # type: ignore
    @jsii.member(jsii_name="websocketsEnabled")
    def websockets_enabled(self) -> builtins.bool:
        return jsii.get(self, "websocketsEnabled")

    @builtins.property # type: ignore
    @jsii.member(jsii_name="windowsFxVersion")
    def windows_fx_version(self) -> builtins.str:
        return jsii.get(self, "windowsFxVersion")


class DataAzurermAppServiceSiteConfigCors(
    cdktf.ComplexComputedList,
    metaclass=jsii.JSIIMeta,
    jsii_type="@cdktf/provider-azurerm.DataAzurermAppServiceSiteConfigCors",
):
    def __init__(
        self,
        terraform_resource: cdktf.ITerraformResource,
        terraform_attribute: builtins.str,
        index: builtins.str,
    ) -> None:
        """
        :param terraform_resource: -
        :param terraform_attribute: -
        :param index: -

        :stability: experimental
        """
        jsii.create(DataAzurermAppServiceSiteConfigCors, self, [terraform_resource, terraform_attribute, index])

    @builtins.property # type: ignore
    @jsii.member(jsii_name="allowedOrigins")
    def allowed_origins(self) -> typing.List[builtins.str]:
        return jsii.get(self, "allowedOrigins")

    @builtins.property # type: ignore
    @jsii.member(jsii_name="supportCredentials")
    def support_credentials(self) -> builtins.bool:
        return jsii.get(self, "supportCredentials")


class DataAzurermAppServiceSiteConfigIpRestriction(
    cdktf.ComplexComputedList,
    metaclass=jsii.JSIIMeta,
    jsii_type="@cdktf/provider-azurerm.DataAzurermAppServiceSiteConfigIpRestriction",
):
    def __init__(
        self,
        terraform_resource: cdktf.ITerraformResource,
        terraform_attribute: builtins.str,
        index: builtins.str,
    ) -> None:
        """
        :param terraform_resource: -
        :param terraform_attribute: -
        :param index: -

        :stability: experimental
        """
        jsii.create(DataAzurermAppServiceSiteConfigIpRestriction, self, [terraform_resource, terraform_attribute, index])

    @builtins.property # type: ignore
    @jsii.member(jsii_name="ipAddress")
    def ip_address(self) -> builtins.str:
        return jsii.get(self, "ipAddress")

    @builtins.property # type: ignore
    @jsii.member(jsii_name="virtualNetworkSubnetId")
    def virtual_network_subnet_id(self) -> builtins.str:
        return jsii.get(self, "virtualNetworkSubnetId")


class DataAzurermAppServiceSiteCredential(
    cdktf.ComplexComputedList,
    metaclass=jsii.JSIIMeta,
    jsii_type="@cdktf/provider-azurerm.DataAzurermAppServiceSiteCredential",
):
    def __init__(
        self,
        terraform_resource: cdktf.ITerraformResource,
        terraform_attribute: builtins.str,
        index: builtins.str,
    ) -> None:
        """
        :param terraform_resource: -
        :param terraform_attribute: -
        :param index: -

        :stability: experimental
        """
        jsii.create(DataAzurermAppServiceSiteCredential, self, [terraform_resource, terraform_attribute, index])

    @builtins.property # type: ignore
    @jsii.member(jsii_name="password")
    def password(self) -> builtins.str:
        return jsii.get(self, "password")

    @builtins.property # type: ignore
    @jsii.member(jsii_name="username")
    def username(self) -> builtins.str:
        return jsii.get(self, "username")


class DataAzurermAppServiceSourceControl(
    cdktf.ComplexComputedList,
    metaclass=jsii.JSIIMeta,
    jsii_type="@cdktf/provider-azurerm.DataAzurermAppServiceSourceControl",
):
    def __init__(
        self,
        terraform_resource: cdktf.ITerraformResource,
        terraform_attribute: builtins.str,
        index: builtins.str,
    ) -> None:
        """
        :param terraform_resource: -
        :param terraform_attribute: -
        :param index: -

        :stability: experimental
        """
        jsii.create(DataAzurermAppServiceSourceControl, self, [terraform_resource, terraform_attribute, index])

    @builtins.property # type: ignore
    @jsii.member(jsii_name="branch")
    def branch(self) -> builtins.str:
        return jsii.get(self, "branch")

    @builtins.property # type: ignore
    @jsii.member(jsii_name="repoUrl")
    def repo_url(self) -> builtins.str:
        return jsii.get(self, "repoUrl")


@jsii.data_type(
    jsii_type="@cdktf/provider-azurerm.DataAzurermAppServiceTimeouts",
    jsii_struct_bases=[],
    name_mapping={"read": "read"},
)
class DataAzurermAppServiceTimeouts:
    def __init__(self, *, read: typing.Optional[builtins.str] = None) -> None:
        """
        :param read: 
        """
        self._values: typing.Dict[str, typing.Any] = {}
        if read is not None:
            self._values["read"] = read

    @builtins.property
    def read(self) -> typing.Optional[builtins.str]:
        result = self._values.get("read")
        return result

    def __eq__(self, rhs: typing.Any) -> builtins.bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs: typing.Any) -> builtins.bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return "DataAzurermAppServiceTimeouts(%s)" % ", ".join(
            k + "=" + repr(v) for k, v in self._values.items()
        )


class DataAzurermApplicationInsights(
    cdktf.TerraformDataSource,
    metaclass=jsii.JSIIMeta,
    jsii_type="@cdktf/provider-azurerm.DataAzurermApplicationInsights",
):
    def __init__(
        self,
        scope: constructs.Construct,
        id: builtins.str,
        *,
        name: builtins.str,
        resource_group_name: builtins.str,
        timeouts: typing.Optional["DataAzurermApplicationInsightsTimeouts"] = None,
        count: typing.Optional[jsii.Number] = None,
        depends_on: typing.Optional[typing.List[cdktf.TerraformResource]] = None,
        lifecycle: typing.Optional[cdktf.TerraformResourceLifecycle] = None,
        provider: typing.Optional[cdktf.TerraformProvider] = None,
    ) -> None:
        """
        :param scope: -
        :param id: -
        :param name: 
        :param resource_group_name: 
        :param timeouts: timeouts block.
        :param count: 
        :param depends_on: 
        :param lifecycle: 
        :param provider: 
        """
        config = DataAzurermApplicationInsightsConfig(
            name=name,
            resource_group_name=resource_group_name,
            timeouts=timeouts,
            count=count,
            depends_on=depends_on,
            lifecycle=lifecycle,
            provider=provider,
        )

        jsii.create(DataAzurermApplicationInsights, self, [scope, id, config])

    @jsii.member(jsii_name="synthesizeAttributes")
    def _synthesize_attributes(self) -> typing.Mapping[builtins.str, typing.Any]:
        return jsii.invoke(self, "synthesizeAttributes", [])

    @jsii.member(jsii_name="tags")
    def tags(self, key: builtins.str) -> builtins.str:
        """
        :param key: -
        """
        return jsii.invoke(self, "tags", [key])

    @builtins.property # type: ignore
    @jsii.member(jsii_name="appId")
    def app_id(self) -> builtins.str:
        return jsii.get(self, "appId")

    @builtins.property # type: ignore
    @jsii.member(jsii_name="applicationType")
    def application_type(self) -> builtins.str:
        return jsii.get(self, "applicationType")

    @builtins.property # type: ignore
    @jsii.member(jsii_name="instrumentationKey")
    def instrumentation_key(self) -> builtins.str:
        return jsii.get(self, "instrumentationKey")

    @builtins.property # type: ignore
    @jsii.member(jsii_name="location")
    def location(self) -> builtins.str:
        return jsii.get(self, "location")

    @builtins.property # type: ignore
    @jsii.member(jsii_name="retentionInDays")
    def retention_in_days(self) -> jsii.Number:
        return jsii.get(self, "retentionInDays")

    @builtins.property # type: ignore
    @jsii.member(jsii_name="name")
    def name(self) -> builtins.str:
        return jsii.get(self, "name")

    @name.setter # type: ignore
    def name(self, value: builtins.str) -> None:
        jsii.set(self, "name", value)

    @builtins.property # type: ignore
    @jsii.member(jsii_name="resourceGroupName")
    def resource_group_name(self) -> builtins.str:
        return jsii.get(self, "resourceGroupName")

    @resource_group_name.setter # type: ignore
    def resource_group_name(self, value: builtins.str) -> None:
        jsii.set(self, "resourceGroupName", value)

    @builtins.property # type: ignore
    @jsii.member(jsii_name="id")
    def id(self) -> typing.Optional[builtins.str]:
        return jsii.get(self, "id")

    @id.setter # type: ignore
    def id(self, value: typing.Optional[builtins.str]) -> None:
        jsii.set(self, "id", value)

    @builtins.property # type: ignore
    @jsii.member(jsii_name="timeouts")
    def timeouts(self) -> typing.Optional["DataAzurermApplicationInsightsTimeouts"]:
        return jsii.get(self, "timeouts")

    @timeouts.setter # type: ignore
    def timeouts(
        self,
        value: typing.Optional["DataAzurermApplicationInsightsTimeouts"],
    ) -> None:
        jsii.set(self, "timeouts", value)


@jsii.data_type(
    jsii_type="@cdktf/provider-azurerm.DataAzurermApplicationInsightsConfig",
    jsii_struct_bases=[cdktf.TerraformMetaArguments],
    name_mapping={
        "count": "count",
        "depends_on": "dependsOn",
        "lifecycle": "lifecycle",
        "provider": "provider",
        "name": "name",
        "resource_group_name": "resourceGroupName",
        "timeouts": "timeouts",
    },
)
class DataAzurermApplicationInsightsConfig(cdktf.TerraformMetaArguments):
    def __init__(
        self,
        *,
        count: typing.Optional[jsii.Number] = None,
        depends_on: typing.Optional[typing.List[cdktf.TerraformResource]] = None,
        lifecycle: typing.Optional[cdktf.TerraformResourceLifecycle] = None,
        provider: typing.Optional[cdktf.TerraformProvider] = None,
        name: builtins.str,
        resource_group_name: builtins.str,
        timeouts: typing.Optional["DataAzurermApplicationInsightsTimeouts"] = None,
    ) -> None:
        """
        :param count: 
        :param depends_on: 
        :param lifecycle: 
        :param provider: 
        :param name: 
        :param resource_group_name: 
        :param timeouts: timeouts block.
        """
        if isinstance(lifecycle, dict):
            lifecycle = cdktf.TerraformResourceLifecycle(**lifecycle)
        if isinstance(timeouts, dict):
            timeouts = DataAzurermApplicationInsightsTimeouts(**timeouts)
        self._values: typing.Dict[str, typing.Any] = {
            "name": name,
            "resource_group_name": resource_group_name,
        }
        if count is not None:
            self._values["count"] = count
        if depends_on is not None:
            self._values["depends_on"] = depends_on
        if lifecycle is not None:
            self._values["lifecycle"] = lifecycle
        if provider is not None:
            self._values["provider"] = provider
        if timeouts is not None:
            self._values["timeouts"] = timeouts

    @builtins.property
    def count(self) -> typing.Optional[jsii.Number]:
        """
        :stability: experimental
        """
        result = self._values.get("count")
        return result

    @builtins.property
    def depends_on(self) -> typing.Optional[typing.List[cdktf.TerraformResource]]:
        """
        :stability: experimental
        """
        result = self._values.get("depends_on")
        return result

    @builtins.property
    def lifecycle(self) -> typing.Optional[cdktf.TerraformResourceLifecycle]:
        """
        :stability: experimental
        """
        result = self._values.get("lifecycle")
        return result

    @builtins.property
    def provider(self) -> typing.Optional[cdktf.TerraformProvider]:
        """
        :stability: experimental
        """
        result = self._values.get("provider")
        return result

    @builtins.property
    def name(self) -> builtins.str:
        result = self._values.get("name")
        assert result is not None, "Required property 'name' is missing"
        return result

    @builtins.property
    def resource_group_name(self) -> builtins.str:
        result = self._values.get("resource_group_name")
        assert result is not None, "Required property 'resource_group_name' is missing"
        return result

    @builtins.property
    def timeouts(self) -> typing.Optional["DataAzurermApplicationInsightsTimeouts"]:
        """timeouts block."""
        result = self._values.get("timeouts")
        return result

    def __eq__(self, rhs: typing.Any) -> builtins.bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs: typing.Any) -> builtins.bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return "DataAzurermApplicationInsightsConfig(%s)" % ", ".join(
            k + "=" + repr(v) for k, v in self._values.items()
        )


@jsii.data_type(
    jsii_type="@cdktf/provider-azurerm.DataAzurermApplicationInsightsTimeouts",
    jsii_struct_bases=[],
    name_mapping={"read": "read"},
)
class DataAzurermApplicationInsightsTimeouts:
    def __init__(self, *, read: typing.Optional[builtins.str] = None) -> None:
        """
        :param read: 
        """
        self._values: typing.Dict[str, typing.Any] = {}
        if read is not None:
            self._values["read"] = read

    @builtins.property
    def read(self) -> typing.Optional[builtins.str]:
        result = self._values.get("read")
        return result

    def __eq__(self, rhs: typing.Any) -> builtins.bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs: typing.Any) -> builtins.bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return "DataAzurermApplicationInsightsTimeouts(%s)" % ", ".join(
            k + "=" + repr(v) for k, v in self._values.items()
        )


class DataAzurermApplicationSecurityGroup(
    cdktf.TerraformDataSource,
    metaclass=jsii.JSIIMeta,
    jsii_type="@cdktf/provider-azurerm.DataAzurermApplicationSecurityGroup",
):
    def __init__(
        self,
        scope: constructs.Construct,
        id: builtins.str,
        *,
        name: builtins.str,
        resource_group_name: builtins.str,
        timeouts: typing.Optional["DataAzurermApplicationSecurityGroupTimeouts"] = None,
        count: typing.Optional[jsii.Number] = None,
        depends_on: typing.Optional[typing.List[cdktf.TerraformResource]] = None,
        lifecycle: typing.Optional[cdktf.TerraformResourceLifecycle] = None,
        provider: typing.Optional[cdktf.TerraformProvider] = None,
    ) -> None:
        """
        :param scope: -
        :param id: -
        :param name: 
        :param resource_group_name: 
        :param timeouts: timeouts block.
        :param count: 
        :param depends_on: 
        :param lifecycle: 
        :param provider: 
        """
        config = DataAzurermApplicationSecurityGroupConfig(
            name=name,
            resource_group_name=resource_group_name,
            timeouts=timeouts,
            count=count,
            depends_on=depends_on,
            lifecycle=lifecycle,
            provider=provider,
        )

        jsii.create(DataAzurermApplicationSecurityGroup, self, [scope, id, config])

    @jsii.member(jsii_name="synthesizeAttributes")
    def _synthesize_attributes(self) -> typing.Mapping[builtins.str, typing.Any]:
        return jsii.invoke(self, "synthesizeAttributes", [])

    @jsii.member(jsii_name="tags")
    def tags(self, key: builtins.str) -> builtins.str:
        """
        :param key: -
        """
        return jsii.invoke(self, "tags", [key])

    @builtins.property # type: ignore
    @jsii.member(jsii_name="location")
    def location(self) -> builtins.str:
        return jsii.get(self, "location")

    @builtins.property # type: ignore
    @jsii.member(jsii_name="name")
    def name(self) -> builtins.str:
        return jsii.get(self, "name")

    @name.setter # type: ignore
    def name(self, value: builtins.str) -> None:
        jsii.set(self, "name", value)

    @builtins.property # type: ignore
    @jsii.member(jsii_name="resourceGroupName")
    def resource_group_name(self) -> builtins.str:
        return jsii.get(self, "resourceGroupName")

    @resource_group_name.setter # type: ignore
    def resource_group_name(self, value: builtins.str) -> None:
        jsii.set(self, "resourceGroupName", value)

    @builtins.property # type: ignore
    @jsii.member(jsii_name="id")
    def id(self) -> typing.Optional[builtins.str]:
        return jsii.get(self, "id")

    @id.setter # type: ignore
    def id(self, value: typing.Optional[builtins.str]) -> None:
        jsii.set(self, "id", value)

    @builtins.property # type: ignore
    @jsii.member(jsii_name="timeouts")
    def timeouts(
        self,
    ) -> typing.Optional["DataAzurermApplicationSecurityGroupTimeouts"]:
        return jsii.get(self, "timeouts")

    @timeouts.setter # type: ignore
    def timeouts(
        self,
        value: typing.Optional["DataAzurermApplicationSecurityGroupTimeouts"],
    ) -> None:
        jsii.set(self, "timeouts", value)


@jsii.data_type(
    jsii_type="@cdktf/provider-azurerm.DataAzurermApplicationSecurityGroupConfig",
    jsii_struct_bases=[cdktf.TerraformMetaArguments],
    name_mapping={
        "count": "count",
        "depends_on": "dependsOn",
        "lifecycle": "lifecycle",
        "provider": "provider",
        "name": "name",
        "resource_group_name": "resourceGroupName",
        "timeouts": "timeouts",
    },
)
class DataAzurermApplicationSecurityGroupConfig(cdktf.TerraformMetaArguments):
    def __init__(
        self,
        *,
        count: typing.Optional[jsii.Number] = None,
        depends_on: typing.Optional[typing.List[cdktf.TerraformResource]] = None,
        lifecycle: typing.Optional[cdktf.TerraformResourceLifecycle] = None,
        provider: typing.Optional[cdktf.TerraformProvider] = None,
        name: builtins.str,
        resource_group_name: builtins.str,
        timeouts: typing.Optional["DataAzurermApplicationSecurityGroupTimeouts"] = None,
    ) -> None:
        """
        :param count: 
        :param depends_on: 
        :param lifecycle: 
        :param provider: 
        :param name: 
        :param resource_group_name: 
        :param timeouts: timeouts block.
        """
        if isinstance(lifecycle, dict):
            lifecycle = cdktf.TerraformResourceLifecycle(**lifecycle)
        if isinstance(timeouts, dict):
            timeouts = DataAzurermApplicationSecurityGroupTimeouts(**timeouts)
        self._values: typing.Dict[str, typing.Any] = {
            "name": name,
            "resource_group_name": resource_group_name,
        }
        if count is not None:
            self._values["count"] = count
        if depends_on is not None:
            self._values["depends_on"] = depends_on
        if lifecycle is not None:
            self._values["lifecycle"] = lifecycle
        if provider is not None:
            self._values["provider"] = provider
        if timeouts is not None:
            self._values["timeouts"] = timeouts

    @builtins.property
    def count(self) -> typing.Optional[jsii.Number]:
        """
        :stability: experimental
        """
        result = self._values.get("count")
        return result

    @builtins.property
    def depends_on(self) -> typing.Optional[typing.List[cdktf.TerraformResource]]:
        """
        :stability: experimental
        """
        result = self._values.get("depends_on")
        return result

    @builtins.property
    def lifecycle(self) -> typing.Optional[cdktf.TerraformResourceLifecycle]:
        """
        :stability: experimental
        """
        result = self._values.get("lifecycle")
        return result

    @builtins.property
    def provider(self) -> typing.Optional[cdktf.TerraformProvider]:
        """
        :stability: experimental
        """
        result = self._values.get("provider")
        return result

    @builtins.property
    def name(self) -> builtins.str:
        result = self._values.get("name")
        assert result is not None, "Required property 'name' is missing"
        return result

    @builtins.property
    def resource_group_name(self) -> builtins.str:
        result = self._values.get("resource_group_name")
        assert result is not None, "Required property 'resource_group_name' is missing"
        return result

    @builtins.property
    def timeouts(
        self,
    ) -> typing.Optional["DataAzurermApplicationSecurityGroupTimeouts"]:
        """timeouts block."""
        result = self._values.get("timeouts")
        return result

    def __eq__(self, rhs: typing.Any) -> builtins.bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs: typing.Any) -> builtins.bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return "DataAzurermApplicationSecurityGroupConfig(%s)" % ", ".join(
            k + "=" + repr(v) for k, v in self._values.items()
        )


@jsii.data_type(
    jsii_type="@cdktf/provider-azurerm.DataAzurermApplicationSecurityGroupTimeouts",
    jsii_struct_bases=[],
    name_mapping={"read": "read"},
)
class DataAzurermApplicationSecurityGroupTimeouts:
    def __init__(self, *, read: typing.Optional[builtins.str] = None) -> None:
        """
        :param read: 
        """
        self._values: typing.Dict[str, typing.Any] = {}
        if read is not None:
            self._values["read"] = read

    @builtins.property
    def read(self) -> typing.Optional[builtins.str]:
        result = self._values.get("read")
        return result

    def __eq__(self, rhs: typing.Any) -> builtins.bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs: typing.Any) -> builtins.bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return "DataAzurermApplicationSecurityGroupTimeouts(%s)" % ", ".join(
            k + "=" + repr(v) for k, v in self._values.items()
        )


class DataAzurermAutomationAccount(
    cdktf.TerraformDataSource,
    metaclass=jsii.JSIIMeta,
    jsii_type="@cdktf/provider-azurerm.DataAzurermAutomationAccount",
):
    def __init__(
        self,
        scope: constructs.Construct,
        id: builtins.str,
        *,
        name: builtins.str,
        resource_group_name: builtins.str,
        timeouts: typing.Optional["DataAzurermAutomationAccountTimeouts"] = None,
        count: typing.Optional[jsii.Number] = None,
        depends_on: typing.Optional[typing.List[cdktf.TerraformResource]] = None,
        lifecycle: typing.Optional[cdktf.TerraformResourceLifecycle] = None,
        provider: typing.Optional[cdktf.TerraformProvider] = None,
    ) -> None:
        """
        :param scope: -
        :param id: -
        :param name: 
        :param resource_group_name: 
        :param timeouts: timeouts block.
        :param count: 
        :param depends_on: 
        :param lifecycle: 
        :param provider: 
        """
        config = DataAzurermAutomationAccountConfig(
            name=name,
            resource_group_name=resource_group_name,
            timeouts=timeouts,
            count=count,
            depends_on=depends_on,
            lifecycle=lifecycle,
            provider=provider,
        )

        jsii.create(DataAzurermAutomationAccount, self, [scope, id, config])

    @jsii.member(jsii_name="synthesizeAttributes")
    def _synthesize_attributes(self) -> typing.Mapping[builtins.str, typing.Any]:
        return jsii.invoke(self, "synthesizeAttributes", [])

    @builtins.property # type: ignore
    @jsii.member(jsii_name="endpoint")
    def endpoint(self) -> builtins.str:
        return jsii.get(self, "endpoint")

    @builtins.property # type: ignore
    @jsii.member(jsii_name="primaryKey")
    def primary_key(self) -> builtins.str:
        return jsii.get(self, "primaryKey")

    @builtins.property # type: ignore
    @jsii.member(jsii_name="secondaryKey")
    def secondary_key(self) -> builtins.str:
        return jsii.get(self, "secondaryKey")

    @builtins.property # type: ignore
    @jsii.member(jsii_name="name")
    def name(self) -> builtins.str:
        return jsii.get(self, "name")

    @name.setter # type: ignore
    def name(self, value: builtins.str) -> None:
        jsii.set(self, "name", value)

    @builtins.property # type: ignore
    @jsii.member(jsii_name="resourceGroupName")
    def resource_group_name(self) -> builtins.str:
        return jsii.get(self, "resourceGroupName")

    @resource_group_name.setter # type: ignore
    def resource_group_name(self, value: builtins.str) -> None:
        jsii.set(self, "resourceGroupName", value)

    @builtins.property # type: ignore
    @jsii.member(jsii_name="id")
    def id(self) -> typing.Optional[builtins.str]:
        return jsii.get(self, "id")

    @id.setter # type: ignore
    def id(self, value: typing.Optional[builtins.str]) -> None:
        jsii.set(self, "id", value)

    @builtins.property # type: ignore
    @jsii.member(jsii_name="timeouts")
    def timeouts(self) -> typing.Optional["DataAzurermAutomationAccountTimeouts"]:
        return jsii.get(self, "timeouts")

    @timeouts.setter # type: ignore
    def timeouts(
        self,
        value: typing.Optional["DataAzurermAutomationAccountTimeouts"],
    ) -> None:
        jsii.set(self, "timeouts", value)


@jsii.data_type(
    jsii_type="@cdktf/provider-azurerm.DataAzurermAutomationAccountConfig",
    jsii_struct_bases=[cdktf.TerraformMetaArguments],
    name_mapping={
        "count": "count",
        "depends_on": "dependsOn",
        "lifecycle": "lifecycle",
        "provider": "provider",
        "name": "name",
        "resource_group_name": "resourceGroupName",
        "timeouts": "timeouts",
    },
)
class DataAzurermAutomationAccountConfig(cdktf.TerraformMetaArguments):
    def __init__(
        self,
        *,
        count: typing.Optional[jsii.Number] = None,
        depends_on: typing.Optional[typing.List[cdktf.TerraformResource]] = None,
        lifecycle: typing.Optional[cdktf.TerraformResourceLifecycle] = None,
        provider: typing.Optional[cdktf.TerraformProvider] = None,
        name: builtins.str,
        resource_group_name: builtins.str,
        timeouts: typing.Optional["DataAzurermAutomationAccountTimeouts"] = None,
    ) -> None:
        """
        :param count: 
        :param depends_on: 
        :param lifecycle: 
        :param provider: 
        :param name: 
        :param resource_group_name: 
        :param timeouts: timeouts block.
        """
        if isinstance(lifecycle, dict):
            lifecycle = cdktf.TerraformResourceLifecycle(**lifecycle)
        if isinstance(timeouts, dict):
            timeouts = DataAzurermAutomationAccountTimeouts(**timeouts)
        self._values: typing.Dict[str, typing.Any] = {
            "name": name,
            "resource_group_name": resource_group_name,
        }
        if count is not None:
            self._values["count"] = count
        if depends_on is not None:
            self._values["depends_on"] = depends_on
        if lifecycle is not None:
            self._values["lifecycle"] = lifecycle
        if provider is not None:
            self._values["provider"] = provider
        if timeouts is not None:
            self._values["timeouts"] = timeouts

    @builtins.property
    def count(self) -> typing.Optional[jsii.Number]:
        """
        :stability: experimental
        """
        result = self._values.get("count")
        return result

    @builtins.property
    def depends_on(self) -> typing.Optional[typing.List[cdktf.TerraformResource]]:
        """
        :stability: experimental
        """
        result = self._values.get("depends_on")
        return result

    @builtins.property
    def lifecycle(self) -> typing.Optional[cdktf.TerraformResourceLifecycle]:
        """
        :stability: experimental
        """
        result = self._values.get("lifecycle")
        return result

    @builtins.property
    def provider(self) -> typing.Optional[cdktf.TerraformProvider]:
        """
        :stability: experimental
        """
        result = self._values.get("provider")
        return result

    @builtins.property
    def name(self) -> builtins.str:
        result = self._values.get("name")
        assert result is not None, "Required property 'name' is missing"
        return result

    @builtins.property
    def resource_group_name(self) -> builtins.str:
        result = self._values.get("resource_group_name")
        assert result is not None, "Required property 'resource_group_name' is missing"
        return result

    @builtins.property
    def timeouts(self) -> typing.Optional["DataAzurermAutomationAccountTimeouts"]:
        """timeouts block."""
        result = self._values.get("timeouts")
        return result

    def __eq__(self, rhs: typing.Any) -> builtins.bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs: typing.Any) -> builtins.bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return "DataAzurermAutomationAccountConfig(%s)" % ", ".join(
            k + "=" + repr(v) for k, v in self._values.items()
        )


@jsii.data_type(
    jsii_type="@cdktf/provider-azurerm.DataAzurermAutomationAccountTimeouts",
    jsii_struct_bases=[],
    name_mapping={"read": "read"},
)
class DataAzurermAutomationAccountTimeouts:
    def __init__(self, *, read: typing.Optional[builtins.str] = None) -> None:
        """
        :param read: 
        """
        self._values: typing.Dict[str, typing.Any] = {}
        if read is not None:
            self._values["read"] = read

    @builtins.property
    def read(self) -> typing.Optional[builtins.str]:
        result = self._values.get("read")
        return result

    def __eq__(self, rhs: typing.Any) -> builtins.bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs: typing.Any) -> builtins.bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return "DataAzurermAutomationAccountTimeouts(%s)" % ", ".join(
            k + "=" + repr(v) for k, v in self._values.items()
        )


class DataAzurermAutomationVariableBool(
    cdktf.TerraformDataSource,
    metaclass=jsii.JSIIMeta,
    jsii_type="@cdktf/provider-azurerm.DataAzurermAutomationVariableBool",
):
    def __init__(
        self,
        scope: constructs.Construct,
        id: builtins.str,
        *,
        automation_account_name: builtins.str,
        name: builtins.str,
        resource_group_name: builtins.str,
        timeouts: typing.Optional["DataAzurermAutomationVariableBoolTimeouts"] = None,
        count: typing.Optional[jsii.Number] = None,
        depends_on: typing.Optional[typing.List[cdktf.TerraformResource]] = None,
        lifecycle: typing.Optional[cdktf.TerraformResourceLifecycle] = None,
        provider: typing.Optional[cdktf.TerraformProvider] = None,
    ) -> None:
        """
        :param scope: -
        :param id: -
        :param automation_account_name: 
        :param name: 
        :param resource_group_name: 
        :param timeouts: timeouts block.
        :param count: 
        :param depends_on: 
        :param lifecycle: 
        :param provider: 
        """
        config = DataAzurermAutomationVariableBoolConfig(
            automation_account_name=automation_account_name,
            name=name,
            resource_group_name=resource_group_name,
            timeouts=timeouts,
            count=count,
            depends_on=depends_on,
            lifecycle=lifecycle,
            provider=provider,
        )

        jsii.create(DataAzurermAutomationVariableBool, self, [scope, id, config])

    @jsii.member(jsii_name="synthesizeAttributes")
    def _synthesize_attributes(self) -> typing.Mapping[builtins.str, typing.Any]:
        return jsii.invoke(self, "synthesizeAttributes", [])

    @builtins.property # type: ignore
    @jsii.member(jsii_name="description")
    def description(self) -> builtins.str:
        return jsii.get(self, "description")

    @builtins.property # type: ignore
    @jsii.member(jsii_name="encrypted")
    def encrypted(self) -> builtins.bool:
        return jsii.get(self, "encrypted")

    @builtins.property # type: ignore
    @jsii.member(jsii_name="value")
    def value(self) -> builtins.bool:
        return jsii.get(self, "value")

    @builtins.property # type: ignore
    @jsii.member(jsii_name="automationAccountName")
    def automation_account_name(self) -> builtins.str:
        return jsii.get(self, "automationAccountName")

    @automation_account_name.setter # type: ignore
    def automation_account_name(self, value: builtins.str) -> None:
        jsii.set(self, "automationAccountName", value)

    @builtins.property # type: ignore
    @jsii.member(jsii_name="name")
    def name(self) -> builtins.str:
        return jsii.get(self, "name")

    @name.setter # type: ignore
    def name(self, value: builtins.str) -> None:
        jsii.set(self, "name", value)

    @builtins.property # type: ignore
    @jsii.member(jsii_name="resourceGroupName")
    def resource_group_name(self) -> builtins.str:
        return jsii.get(self, "resourceGroupName")

    @resource_group_name.setter # type: ignore
    def resource_group_name(self, value: builtins.str) -> None:
        jsii.set(self, "resourceGroupName", value)

    @builtins.property # type: ignore
    @jsii.member(jsii_name="id")
    def id(self) -> typing.Optional[builtins.str]:
        return jsii.get(self, "id")

    @id.setter # type: ignore
    def id(self, value: typing.Optional[builtins.str]) -> None:
        jsii.set(self, "id", value)

    @builtins.property # type: ignore
    @jsii.member(jsii_name="timeouts")
    def timeouts(self) -> typing.Optional["DataAzurermAutomationVariableBoolTimeouts"]:
        return jsii.get(self, "timeouts")

    @timeouts.setter # type: ignore
    def timeouts(
        self,
        value: typing.Optional["DataAzurermAutomationVariableBoolTimeouts"],
    ) -> None:
        jsii.set(self, "timeouts", value)


@jsii.data_type(
    jsii_type="@cdktf/provider-azurerm.DataAzurermAutomationVariableBoolConfig",
    jsii_struct_bases=[cdktf.TerraformMetaArguments],
    name_mapping={
        "count": "count",
        "depends_on": "dependsOn",
        "lifecycle": "lifecycle",
        "provider": "provider",
        "automation_account_name": "automationAccountName",
        "name": "name",
        "resource_group_name": "resourceGroupName",
        "timeouts": "timeouts",
    },
)
class DataAzurermAutomationVariableBoolConfig(cdktf.TerraformMetaArguments):
    def __init__(
        self,
        *,
        count: typing.Optional[jsii.Number] = None,
        depends_on: typing.Optional[typing.List[cdktf.TerraformResource]] = None,
        lifecycle: typing.Optional[cdktf.TerraformResourceLifecycle] = None,
        provider: typing.Optional[cdktf.TerraformProvider] = None,
        automation_account_name: builtins.str,
        name: builtins.str,
        resource_group_name: builtins.str,
        timeouts: typing.Optional["DataAzurermAutomationVariableBoolTimeouts"] = None,
    ) -> None:
        """
        :param count: 
        :param depends_on: 
        :param lifecycle: 
        :param provider: 
        :param automation_account_name: 
        :param name: 
        :param resource_group_name: 
        :param timeouts: timeouts block.
        """
        if isinstance(lifecycle, dict):
            lifecycle = cdktf.TerraformResourceLifecycle(**lifecycle)
        if isinstance(timeouts, dict):
            timeouts = DataAzurermAutomationVariableBoolTimeouts(**timeouts)
        self._values: typing.Dict[str, typing.Any] = {
            "automation_account_name": automation_account_name,
            "name": name,
            "resource_group_name": resource_group_name,
        }
        if count is not None:
            self._values["count"] = count
        if depends_on is not None:
            self._values["depends_on"] = depends_on
        if lifecycle is not None:
            self._values["lifecycle"] = lifecycle
        if provider is not None:
            self._values["provider"] = provider
        if timeouts is not None:
            self._values["timeouts"] = timeouts

    @builtins.property
    def count(self) -> typing.Optional[jsii.Number]:
        """
        :stability: experimental
        """
        result = self._values.get("count")
        return result

    @builtins.property
    def depends_on(self) -> typing.Optional[typing.List[cdktf.TerraformResource]]:
        """
        :stability: experimental
        """
        result = self._values.get("depends_on")
        return result

    @builtins.property
    def lifecycle(self) -> typing.Optional[cdktf.TerraformResourceLifecycle]:
        """
        :stability: experimental
        """
        result = self._values.get("lifecycle")
        return result

    @builtins.property
    def provider(self) -> typing.Optional[cdktf.TerraformProvider]:
        """
        :stability: experimental
        """
        result = self._values.get("provider")
        return result

    @builtins.property
    def automation_account_name(self) -> builtins.str:
        result = self._values.get("automation_account_name")
        assert result is not None, "Required property 'automation_account_name' is missing"
        return result

    @builtins.property
    def name(self) -> builtins.str:
        result = self._values.get("name")
        assert result is not None, "Required property 'name' is missing"
        return result

    @builtins.property
    def resource_group_name(self) -> builtins.str:
        result = self._values.get("resource_group_name")
        assert result is not None, "Required property 'resource_group_name' is missing"
        return result

    @builtins.property
    def timeouts(self) -> typing.Optional["DataAzurermAutomationVariableBoolTimeouts"]:
        """timeouts block."""
        result = self._values.get("timeouts")
        return result

    def __eq__(self, rhs: typing.Any) -> builtins.bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs: typing.Any) -> builtins.bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return "DataAzurermAutomationVariableBoolConfig(%s)" % ", ".join(
            k + "=" + repr(v) for k, v in self._values.items()
        )


@jsii.data_type(
    jsii_type="@cdktf/provider-azurerm.DataAzurermAutomationVariableBoolTimeouts",
    jsii_struct_bases=[],
    name_mapping={"read": "read"},
)
class DataAzurermAutomationVariableBoolTimeouts:
    def __init__(self, *, read: typing.Optional[builtins.str] = None) -> None:
        """
        :param read: 
        """
        self._values: typing.Dict[str, typing.Any] = {}
        if read is not None:
            self._values["read"] = read

    @builtins.property
    def read(self) -> typing.Optional[builtins.str]:
        result = self._values.get("read")
        return result

    def __eq__(self, rhs: typing.Any) -> builtins.bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs: typing.Any) -> builtins.bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return "DataAzurermAutomationVariableBoolTimeouts(%s)" % ", ".join(
            k + "=" + repr(v) for k, v in self._values.items()
        )


class DataAzurermAutomationVariableDatetime(
    cdktf.TerraformDataSource,
    metaclass=jsii.JSIIMeta,
    jsii_type="@cdktf/provider-azurerm.DataAzurermAutomationVariableDatetime",
):
    def __init__(
        self,
        scope: constructs.Construct,
        id: builtins.str,
        *,
        automation_account_name: builtins.str,
        name: builtins.str,
        resource_group_name: builtins.str,
        timeouts: typing.Optional["DataAzurermAutomationVariableDatetimeTimeouts"] = None,
        count: typing.Optional[jsii.Number] = None,
        depends_on: typing.Optional[typing.List[cdktf.TerraformResource]] = None,
        lifecycle: typing.Optional[cdktf.TerraformResourceLifecycle] = None,
        provider: typing.Optional[cdktf.TerraformProvider] = None,
    ) -> None:
        """
        :param scope: -
        :param id: -
        :param automation_account_name: 
        :param name: 
        :param resource_group_name: 
        :param timeouts: timeouts block.
        :param count: 
        :param depends_on: 
        :param lifecycle: 
        :param provider: 
        """
        config = DataAzurermAutomationVariableDatetimeConfig(
            automation_account_name=automation_account_name,
            name=name,
            resource_group_name=resource_group_name,
            timeouts=timeouts,
            count=count,
            depends_on=depends_on,
            lifecycle=lifecycle,
            provider=provider,
        )

        jsii.create(DataAzurermAutomationVariableDatetime, self, [scope, id, config])

    @jsii.member(jsii_name="synthesizeAttributes")
    def _synthesize_attributes(self) -> typing.Mapping[builtins.str, typing.Any]:
        return jsii.invoke(self, "synthesizeAttributes", [])

    @builtins.property # type: ignore
    @jsii.member(jsii_name="description")
    def description(self) -> builtins.str:
        return jsii.get(self, "description")

    @builtins.property # type: ignore
    @jsii.member(jsii_name="encrypted")
    def encrypted(self) -> builtins.bool:
        return jsii.get(self, "encrypted")

    @builtins.property # type: ignore
    @jsii.member(jsii_name="value")
    def value(self) -> builtins.str:
        return jsii.get(self, "value")

    @builtins.property # type: ignore
    @jsii.member(jsii_name="automationAccountName")
    def automation_account_name(self) -> builtins.str:
        return jsii.get(self, "automationAccountName")

    @automation_account_name.setter # type: ignore
    def automation_account_name(self, value: builtins.str) -> None:
        jsii.set(self, "automationAccountName", value)

    @builtins.property # type: ignore
    @jsii.member(jsii_name="name")
    def name(self) -> builtins.str:
        return jsii.get(self, "name")

    @name.setter # type: ignore
    def name(self, value: builtins.str) -> None:
        jsii.set(self, "name", value)

    @builtins.property # type: ignore
    @jsii.member(jsii_name="resourceGroupName")
    def resource_group_name(self) -> builtins.str:
        return jsii.get(self, "resourceGroupName")

    @resource_group_name.setter # type: ignore
    def resource_group_name(self, value: builtins.str) -> None:
        jsii.set(self, "resourceGroupName", value)

    @builtins.property # type: ignore
    @jsii.member(jsii_name="id")
    def id(self) -> typing.Optional[builtins.str]:
        return jsii.get(self, "id")

    @id.setter # type: ignore
    def id(self, value: typing.Optional[builtins.str]) -> None:
        jsii.set(self, "id", value)

    @builtins.property # type: ignore
    @jsii.member(jsii_name="timeouts")
    def timeouts(
        self,
    ) -> typing.Optional["DataAzurermAutomationVariableDatetimeTimeouts"]:
        return jsii.get(self, "timeouts")

    @timeouts.setter # type: ignore
    def timeouts(
        self,
        value: typing.Optional["DataAzurermAutomationVariableDatetimeTimeouts"],
    ) -> None:
        jsii.set(self, "timeouts", value)


@jsii.data_type(
    jsii_type="@cdktf/provider-azurerm.DataAzurermAutomationVariableDatetimeConfig",
    jsii_struct_bases=[cdktf.TerraformMetaArguments],
    name_mapping={
        "count": "count",
        "depends_on": "dependsOn",
        "lifecycle": "lifecycle",
        "provider": "provider",
        "automation_account_name": "automationAccountName",
        "name": "name",
        "resource_group_name": "resourceGroupName",
        "timeouts": "timeouts",
    },
)
class DataAzurermAutomationVariableDatetimeConfig(cdktf.TerraformMetaArguments):
    def __init__(
        self,
        *,
        count: typing.Optional[jsii.Number] = None,
        depends_on: typing.Optional[typing.List[cdktf.TerraformResource]] = None,
        lifecycle: typing.Optional[cdktf.TerraformResourceLifecycle] = None,
        provider: typing.Optional[cdktf.TerraformProvider] = None,
        automation_account_name: builtins.str,
        name: builtins.str,
        resource_group_name: builtins.str,
        timeouts: typing.Optional["DataAzurermAutomationVariableDatetimeTimeouts"] = None,
    ) -> None:
        """
        :param count: 
        :param depends_on: 
        :param lifecycle: 
        :param provider: 
        :param automation_account_name: 
        :param name: 
        :param resource_group_name: 
        :param timeouts: timeouts block.
        """
        if isinstance(lifecycle, dict):
            lifecycle = cdktf.TerraformResourceLifecycle(**lifecycle)
        if isinstance(timeouts, dict):
            timeouts = DataAzurermAutomationVariableDatetimeTimeouts(**timeouts)
        self._values: typing.Dict[str, typing.Any] = {
            "automation_account_name": automation_account_name,
            "name": name,
            "resource_group_name": resource_group_name,
        }
        if count is not None:
            self._values["count"] = count
        if depends_on is not None:
            self._values["depends_on"] = depends_on
        if lifecycle is not None:
            self._values["lifecycle"] = lifecycle
        if provider is not None:
            self._values["provider"] = provider
        if timeouts is not None:
            self._values["timeouts"] = timeouts

    @builtins.property
    def count(self) -> typing.Optional[jsii.Number]:
        """
        :stability: experimental
        """
        result = self._values.get("count")
        return result

    @builtins.property
    def depends_on(self) -> typing.Optional[typing.List[cdktf.TerraformResource]]:
        """
        :stability: experimental
        """
        result = self._values.get("depends_on")
        return result

    @builtins.property
    def lifecycle(self) -> typing.Optional[cdktf.TerraformResourceLifecycle]:
        """
        :stability: experimental
        """
        result = self._values.get("lifecycle")
        return result

    @builtins.property
    def provider(self) -> typing.Optional[cdktf.TerraformProvider]:
        """
        :stability: experimental
        """
        result = self._values.get("provider")
        return result

    @builtins.property
    def automation_account_name(self) -> builtins.str:
        result = self._values.get("automation_account_name")
        assert result is not None, "Required property 'automation_account_name' is missing"
        return result

    @builtins.property
    def name(self) -> builtins.str:
        result = self._values.get("name")
        assert result is not None, "Required property 'name' is missing"
        return result

    @builtins.property
    def resource_group_name(self) -> builtins.str:
        result = self._values.get("resource_group_name")
        assert result is not None, "Required property 'resource_group_name' is missing"
        return result

    @builtins.property
    def timeouts(
        self,
    ) -> typing.Optional["DataAzurermAutomationVariableDatetimeTimeouts"]:
        """timeouts block."""
        result = self._values.get("timeouts")
        return result

    def __eq__(self, rhs: typing.Any) -> builtins.bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs: typing.Any) -> builtins.bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return "DataAzurermAutomationVariableDatetimeConfig(%s)" % ", ".join(
            k + "=" + repr(v) for k, v in self._values.items()
        )


@jsii.data_type(
    jsii_type="@cdktf/provider-azurerm.DataAzurermAutomationVariableDatetimeTimeouts",
    jsii_struct_bases=[],
    name_mapping={"read": "read"},
)
class DataAzurermAutomationVariableDatetimeTimeouts:
    def __init__(self, *, read: typing.Optional[builtins.str] = None) -> None:
        """
        :param read: 
        """
        self._values: typing.Dict[str, typing.Any] = {}
        if read is not None:
            self._values["read"] = read

    @builtins.property
    def read(self) -> typing.Optional[builtins.str]:
        result = self._values.get("read")
        return result

    def __eq__(self, rhs: typing.Any) -> builtins.bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs: typing.Any) -> builtins.bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return "DataAzurermAutomationVariableDatetimeTimeouts(%s)" % ", ".join(
            k + "=" + repr(v) for k, v in self._values.items()
        )


class DataAzurermAutomationVariableInt(
    cdktf.TerraformDataSource,
    metaclass=jsii.JSIIMeta,
    jsii_type="@cdktf/provider-azurerm.DataAzurermAutomationVariableInt",
):
    def __init__(
        self,
        scope: constructs.Construct,
        id: builtins.str,
        *,
        automation_account_name: builtins.str,
        name: builtins.str,
        resource_group_name: builtins.str,
        timeouts: typing.Optional["DataAzurermAutomationVariableIntTimeouts"] = None,
        count: typing.Optional[jsii.Number] = None,
        depends_on: typing.Optional[typing.List[cdktf.TerraformResource]] = None,
        lifecycle: typing.Optional[cdktf.TerraformResourceLifecycle] = None,
        provider: typing.Optional[cdktf.TerraformProvider] = None,
    ) -> None:
        """
        :param scope: -
        :param id: -
        :param automation_account_name: 
        :param name: 
        :param resource_group_name: 
        :param timeouts: timeouts block.
        :param count: 
        :param depends_on: 
        :param lifecycle: 
        :param provider: 
        """
        config = DataAzurermAutomationVariableIntConfig(
            automation_account_name=automation_account_name,
            name=name,
            resource_group_name=resource_group_name,
            timeouts=timeouts,
            count=count,
            depends_on=depends_on,
            lifecycle=lifecycle,
            provider=provider,
        )

        jsii.create(DataAzurermAutomationVariableInt, self, [scope, id, config])

    @jsii.member(jsii_name="synthesizeAttributes")
    def _synthesize_attributes(self) -> typing.Mapping[builtins.str, typing.Any]:
        return jsii.invoke(self, "synthesizeAttributes", [])

    @builtins.property # type: ignore
    @jsii.member(jsii_name="description")
    def description(self) -> builtins.str:
        return jsii.get(self, "description")

    @builtins.property # type: ignore
    @jsii.member(jsii_name="encrypted")
    def encrypted(self) -> builtins.bool:
        return jsii.get(self, "encrypted")

    @builtins.property # type: ignore
    @jsii.member(jsii_name="value")
    def value(self) -> jsii.Number:
        return jsii.get(self, "value")

    @builtins.property # type: ignore
    @jsii.member(jsii_name="automationAccountName")
    def automation_account_name(self) -> builtins.str:
        return jsii.get(self, "automationAccountName")

    @automation_account_name.setter # type: ignore
    def automation_account_name(self, value: builtins.str) -> None:
        jsii.set(self, "automationAccountName", value)

    @builtins.property # type: ignore
    @jsii.member(jsii_name="name")
    def name(self) -> builtins.str:
        return jsii.get(self, "name")

    @name.setter # type: ignore
    def name(self, value: builtins.str) -> None:
        jsii.set(self, "name", value)

    @builtins.property # type: ignore
    @jsii.member(jsii_name="resourceGroupName")
    def resource_group_name(self) -> builtins.str:
        return jsii.get(self, "resourceGroupName")

    @resource_group_name.setter # type: ignore
    def resource_group_name(self, value: builtins.str) -> None:
        jsii.set(self, "resourceGroupName", value)

    @builtins.property # type: ignore
    @jsii.member(jsii_name="id")
    def id(self) -> typing.Optional[builtins.str]:
        return jsii.get(self, "id")

    @id.setter # type: ignore
    def id(self, value: typing.Optional[builtins.str]) -> None:
        jsii.set(self, "id", value)

    @builtins.property # type: ignore
    @jsii.member(jsii_name="timeouts")
    def timeouts(self) -> typing.Optional["DataAzurermAutomationVariableIntTimeouts"]:
        return jsii.get(self, "timeouts")

    @timeouts.setter # type: ignore
    def timeouts(
        self,
        value: typing.Optional["DataAzurermAutomationVariableIntTimeouts"],
    ) -> None:
        jsii.set(self, "timeouts", value)


@jsii.data_type(
    jsii_type="@cdktf/provider-azurerm.DataAzurermAutomationVariableIntConfig",
    jsii_struct_bases=[cdktf.TerraformMetaArguments],
    name_mapping={
        "count": "count",
        "depends_on": "dependsOn",
        "lifecycle": "lifecycle",
        "provider": "provider",
        "automation_account_name": "automationAccountName",
        "name": "name",
        "resource_group_name": "resourceGroupName",
        "timeouts": "timeouts",
    },
)
class DataAzurermAutomationVariableIntConfig(cdktf.TerraformMetaArguments):
    def __init__(
        self,
        *,
        count: typing.Optional[jsii.Number] = None,
        depends_on: typing.Optional[typing.List[cdktf.TerraformResource]] = None,
        lifecycle: typing.Optional[cdktf.TerraformResourceLifecycle] = None,
        provider: typing.Optional[cdktf.TerraformProvider] = None,
        automation_account_name: builtins.str,
        name: builtins.str,
        resource_group_name: builtins.str,
        timeouts: typing.Optional["DataAzurermAutomationVariableIntTimeouts"] = None,
    ) -> None:
        """
        :param count: 
        :param depends_on: 
        :param lifecycle: 
        :param provider: 
        :param automation_account_name: 
        :param name: 
        :param resource_group_name: 
        :param timeouts: timeouts block.
        """
        if isinstance(lifecycle, dict):
            lifecycle = cdktf.TerraformResourceLifecycle(**lifecycle)
        if isinstance(timeouts, dict):
            timeouts = DataAzurermAutomationVariableIntTimeouts(**timeouts)
        self._values: typing.Dict[str, typing.Any] = {
            "automation_account_name": automation_account_name,
            "name": name,
            "resource_group_name": resource_group_name,
        }
        if count is not None:
            self._values["count"] = count
        if depends_on is not None:
            self._values["depends_on"] = depends_on
        if lifecycle is not None:
            self._values["lifecycle"] = lifecycle
        if provider is not None:
            self._values["provider"] = provider
        if timeouts is not None:
            self._values["timeouts"] = timeouts

    @builtins.property
    def count(self) -> typing.Optional[jsii.Number]:
        """
        :stability: experimental
        """
        result = self._values.get("count")
        return result

    @builtins.property
    def depends_on(self) -> typing.Optional[typing.List[cdktf.TerraformResource]]:
        """
        :stability: experimental
        """
        result = self._values.get("depends_on")
        return result

    @builtins.property
    def lifecycle(self) -> typing.Optional[cdktf.TerraformResourceLifecycle]:
        """
        :stability: experimental
        """
        result = self._values.get("lifecycle")
        return result

    @builtins.property
    def provider(self) -> typing.Optional[cdktf.TerraformProvider]:
        """
        :stability: experimental
        """
        result = self._values.get("provider")
        return result

    @builtins.property
    def automation_account_name(self) -> builtins.str:
        result = self._values.get("automation_account_name")
        assert result is not None, "Required property 'automation_account_name' is missing"
        return result

    @builtins.property
    def name(self) -> builtins.str:
        result = self._values.get("name")
        assert result is not None, "Required property 'name' is missing"
        return result

    @builtins.property
    def resource_group_name(self) -> builtins.str:
        result = self._values.get("resource_group_name")
        assert result is not None, "Required property 'resource_group_name' is missing"
        return result

    @builtins.property
    def timeouts(self) -> typing.Optional["DataAzurermAutomationVariableIntTimeouts"]:
        """timeouts block."""
        result = self._values.get("timeouts")
        return result

    def __eq__(self, rhs: typing.Any) -> builtins.bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs: typing.Any) -> builtins.bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return "DataAzurermAutomationVariableIntConfig(%s)" % ", ".join(
            k + "=" + repr(v) for k, v in self._values.items()
        )


@jsii.data_type(
    jsii_type="@cdktf/provider-azurerm.DataAzurermAutomationVariableIntTimeouts",
    jsii_struct_bases=[],
    name_mapping={"read": "read"},
)
class DataAzurermAutomationVariableIntTimeouts:
    def __init__(self, *, read: typing.Optional[builtins.str] = None) -> None:
        """
        :param read: 
        """
        self._values: typing.Dict[str, typing.Any] = {}
        if read is not None:
            self._values["read"] = read

    @builtins.property
    def read(self) -> typing.Optional[builtins.str]:
        result = self._values.get("read")
        return result

    def __eq__(self, rhs: typing.Any) -> builtins.bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs: typing.Any) -> builtins.bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return "DataAzurermAutomationVariableIntTimeouts(%s)" % ", ".join(
            k + "=" + repr(v) for k, v in self._values.items()
        )


class DataAzurermAutomationVariableString(
    cdktf.TerraformDataSource,
    metaclass=jsii.JSIIMeta,
    jsii_type="@cdktf/provider-azurerm.DataAzurermAutomationVariableString",
):
    def __init__(
        self,
        scope: constructs.Construct,
        id: builtins.str,
        *,
        automation_account_name: builtins.str,
        name: builtins.str,
        resource_group_name: builtins.str,
        timeouts: typing.Optional["DataAzurermAutomationVariableStringTimeouts"] = None,
        count: typing.Optional[jsii.Number] = None,
        depends_on: typing.Optional[typing.List[cdktf.TerraformResource]] = None,
        lifecycle: typing.Optional[cdktf.TerraformResourceLifecycle] = None,
        provider: typing.Optional[cdktf.TerraformProvider] = None,
    ) -> None:
        """
        :param scope: -
        :param id: -
        :param automation_account_name: 
        :param name: 
        :param resource_group_name: 
        :param timeouts: timeouts block.
        :param count: 
        :param depends_on: 
        :param lifecycle: 
        :param provider: 
        """
        config = DataAzurermAutomationVariableStringConfig(
            automation_account_name=automation_account_name,
            name=name,
            resource_group_name=resource_group_name,
            timeouts=timeouts,
            count=count,
            depends_on=depends_on,
            lifecycle=lifecycle,
            provider=provider,
        )

        jsii.create(DataAzurermAutomationVariableString, self, [scope, id, config])

    @jsii.member(jsii_name="synthesizeAttributes")
    def _synthesize_attributes(self) -> typing.Mapping[builtins.str, typing.Any]:
        return jsii.invoke(self, "synthesizeAttributes", [])

    @builtins.property # type: ignore
    @jsii.member(jsii_name="description")
    def description(self) -> builtins.str:
        return jsii.get(self, "description")

    @builtins.property # type: ignore
    @jsii.member(jsii_name="encrypted")
    def encrypted(self) -> builtins.bool:
        return jsii.get(self, "encrypted")

    @builtins.property # type: ignore
    @jsii.member(jsii_name="value")
    def value(self) -> builtins.str:
        return jsii.get(self, "value")

    @builtins.property # type: ignore
    @jsii.member(jsii_name="automationAccountName")
    def automation_account_name(self) -> builtins.str:
        return jsii.get(self, "automationAccountName")

    @automation_account_name.setter # type: ignore
    def automation_account_name(self, value: builtins.str) -> None:
        jsii.set(self, "automationAccountName", value)

    @builtins.property # type: ignore
    @jsii.member(jsii_name="name")
    def name(self) -> builtins.str:
        return jsii.get(self, "name")

    @name.setter # type: ignore
    def name(self, value: builtins.str) -> None:
        jsii.set(self, "name", value)

    @builtins.property # type: ignore
    @jsii.member(jsii_name="resourceGroupName")
    def resource_group_name(self) -> builtins.str:
        return jsii.get(self, "resourceGroupName")

    @resource_group_name.setter # type: ignore
    def resource_group_name(self, value: builtins.str) -> None:
        jsii.set(self, "resourceGroupName", value)

    @builtins.property # type: ignore
    @jsii.member(jsii_name="id")
    def id(self) -> typing.Optional[builtins.str]:
        return jsii.get(self, "id")

    @id.setter # type: ignore
    def id(self, value: typing.Optional[builtins.str]) -> None:
        jsii.set(self, "id", value)

    @builtins.property # type: ignore
    @jsii.member(jsii_name="timeouts")
    def timeouts(
        self,
    ) -> typing.Optional["DataAzurermAutomationVariableStringTimeouts"]:
        return jsii.get(self, "timeouts")

    @timeouts.setter # type: ignore
    def timeouts(
        self,
        value: typing.Optional["DataAzurermAutomationVariableStringTimeouts"],
    ) -> None:
        jsii.set(self, "timeouts", value)


@jsii.data_type(
    jsii_type="@cdktf/provider-azurerm.DataAzurermAutomationVariableStringConfig",
    jsii_struct_bases=[cdktf.TerraformMetaArguments],
    name_mapping={
        "count": "count",
        "depends_on": "dependsOn",
        "lifecycle": "lifecycle",
        "provider": "provider",
        "automation_account_name": "automationAccountName",
        "name": "name",
        "resource_group_name": "resourceGroupName",
        "timeouts": "timeouts",
    },
)
class DataAzurermAutomationVariableStringConfig(cdktf.TerraformMetaArguments):
    def __init__(
        self,
        *,
        count: typing.Optional[jsii.Number] = None,
        depends_on: typing.Optional[typing.List[cdktf.TerraformResource]] = None,
        lifecycle: typing.Optional[cdktf.TerraformResourceLifecycle] = None,
        provider: typing.Optional[cdktf.TerraformProvider] = None,
        automation_account_name: builtins.str,
        name: builtins.str,
        resource_group_name: builtins.str,
        timeouts: typing.Optional["DataAzurermAutomationVariableStringTimeouts"] = None,
    ) -> None:
        """
        :param count: 
        :param depends_on: 
        :param lifecycle: 
        :param provider: 
        :param automation_account_name: 
        :param name: 
        :param resource_group_name: 
        :param timeouts: timeouts block.
        """
        if isinstance(lifecycle, dict):
            lifecycle = cdktf.TerraformResourceLifecycle(**lifecycle)
        if isinstance(timeouts, dict):
            timeouts = DataAzurermAutomationVariableStringTimeouts(**timeouts)
        self._values: typing.Dict[str, typing.Any] = {
            "automation_account_name": automation_account_name,
            "name": name,
            "resource_group_name": resource_group_name,
        }
        if count is not None:
            self._values["count"] = count
        if depends_on is not None:
            self._values["depends_on"] = depends_on
        if lifecycle is not None:
            self._values["lifecycle"] = lifecycle
        if provider is not None:
            self._values["provider"] = provider
        if timeouts is not None:
            self._values["timeouts"] = timeouts

    @builtins.property
    def count(self) -> typing.Optional[jsii.Number]:
        """
        :stability: experimental
        """
        result = self._values.get("count")
        return result

    @builtins.property
    def depends_on(self) -> typing.Optional[typing.List[cdktf.TerraformResource]]:
        """
        :stability: experimental
        """
        result = self._values.get("depends_on")
        return result

    @builtins.property
    def lifecycle(self) -> typing.Optional[cdktf.TerraformResourceLifecycle]:
        """
        :stability: experimental
        """
        result = self._values.get("lifecycle")
        return result

    @builtins.property
    def provider(self) -> typing.Optional[cdktf.TerraformProvider]:
        """
        :stability: experimental
        """
        result = self._values.get("provider")
        return result

    @builtins.property
    def automation_account_name(self) -> builtins.str:
        result = self._values.get("automation_account_name")
        assert result is not None, "Required property 'automation_account_name' is missing"
        return result

    @builtins.property
    def name(self) -> builtins.str:
        result = self._values.get("name")
        assert result is not None, "Required property 'name' is missing"
        return result

    @builtins.property
    def resource_group_name(self) -> builtins.str:
        result = self._values.get("resource_group_name")
        assert result is not None, "Required property 'resource_group_name' is missing"
        return result

    @builtins.property
    def timeouts(
        self,
    ) -> typing.Optional["DataAzurermAutomationVariableStringTimeouts"]:
        """timeouts block."""
        result = self._values.get("timeouts")
        return result

    def __eq__(self, rhs: typing.Any) -> builtins.bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs: typing.Any) -> builtins.bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return "DataAzurermAutomationVariableStringConfig(%s)" % ", ".join(
            k + "=" + repr(v) for k, v in self._values.items()
        )


@jsii.data_type(
    jsii_type="@cdktf/provider-azurerm.DataAzurermAutomationVariableStringTimeouts",
    jsii_struct_bases=[],
    name_mapping={"read": "read"},
)
class DataAzurermAutomationVariableStringTimeouts:
    def __init__(self, *, read: typing.Optional[builtins.str] = None) -> None:
        """
        :param read: 
        """
        self._values: typing.Dict[str, typing.Any] = {}
        if read is not None:
            self._values["read"] = read

    @builtins.property
    def read(self) -> typing.Optional[builtins.str]:
        result = self._values.get("read")
        return result

    def __eq__(self, rhs: typing.Any) -> builtins.bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs: typing.Any) -> builtins.bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return "DataAzurermAutomationVariableStringTimeouts(%s)" % ", ".join(
            k + "=" + repr(v) for k, v in self._values.items()
        )


class DataAzurermAvailabilitySet(
    cdktf.TerraformDataSource,
    metaclass=jsii.JSIIMeta,
    jsii_type="@cdktf/provider-azurerm.DataAzurermAvailabilitySet",
):
    def __init__(
        self,
        scope: constructs.Construct,
        id: builtins.str,
        *,
        name: builtins.str,
        resource_group_name: builtins.str,
        timeouts: typing.Optional["DataAzurermAvailabilitySetTimeouts"] = None,
        count: typing.Optional[jsii.Number] = None,
        depends_on: typing.Optional[typing.List[cdktf.TerraformResource]] = None,
        lifecycle: typing.Optional[cdktf.TerraformResourceLifecycle] = None,
        provider: typing.Optional[cdktf.TerraformProvider] = None,
    ) -> None:
        """
        :param scope: -
        :param id: -
        :param name: 
        :param resource_group_name: 
        :param timeouts: timeouts block.
        :param count: 
        :param depends_on: 
        :param lifecycle: 
        :param provider: 
        """
        config = DataAzurermAvailabilitySetConfig(
            name=name,
            resource_group_name=resource_group_name,
            timeouts=timeouts,
            count=count,
            depends_on=depends_on,
            lifecycle=lifecycle,
            provider=provider,
        )

        jsii.create(DataAzurermAvailabilitySet, self, [scope, id, config])

    @jsii.member(jsii_name="synthesizeAttributes")
    def _synthesize_attributes(self) -> typing.Mapping[builtins.str, typing.Any]:
        return jsii.invoke(self, "synthesizeAttributes", [])

    @jsii.member(jsii_name="tags")
    def tags(self, key: builtins.str) -> builtins.str:
        """
        :param key: -
        """
        return jsii.invoke(self, "tags", [key])

    @builtins.property # type: ignore
    @jsii.member(jsii_name="location")
    def location(self) -> builtins.str:
        return jsii.get(self, "location")

    @builtins.property # type: ignore
    @jsii.member(jsii_name="managed")
    def managed(self) -> builtins.bool:
        return jsii.get(self, "managed")

    @builtins.property # type: ignore
    @jsii.member(jsii_name="platformFaultDomainCount")
    def platform_fault_domain_count(self) -> builtins.str:
        return jsii.get(self, "platformFaultDomainCount")

    @builtins.property # type: ignore
    @jsii.member(jsii_name="platformUpdateDomainCount")
    def platform_update_domain_count(self) -> builtins.str:
        return jsii.get(self, "platformUpdateDomainCount")

    @builtins.property # type: ignore
    @jsii.member(jsii_name="name")
    def name(self) -> builtins.str:
        return jsii.get(self, "name")

    @name.setter # type: ignore
    def name(self, value: builtins.str) -> None:
        jsii.set(self, "name", value)

    @builtins.property # type: ignore
    @jsii.member(jsii_name="resourceGroupName")
    def resource_group_name(self) -> builtins.str:
        return jsii.get(self, "resourceGroupName")

    @resource_group_name.setter # type: ignore
    def resource_group_name(self, value: builtins.str) -> None:
        jsii.set(self, "resourceGroupName", value)

    @builtins.property # type: ignore
    @jsii.member(jsii_name="id")
    def id(self) -> typing.Optional[builtins.str]:
        return jsii.get(self, "id")

    @id.setter # type: ignore
    def id(self, value: typing.Optional[builtins.str]) -> None:
        jsii.set(self, "id", value)

    @builtins.property # type: ignore
    @jsii.member(jsii_name="timeouts")
    def timeouts(self) -> typing.Optional["DataAzurermAvailabilitySetTimeouts"]:
        return jsii.get(self, "timeouts")

    @timeouts.setter # type: ignore
    def timeouts(
        self,
        value: typing.Optional["DataAzurermAvailabilitySetTimeouts"],
    ) -> None:
        jsii.set(self, "timeouts", value)


@jsii.data_type(
    jsii_type="@cdktf/provider-azurerm.DataAzurermAvailabilitySetConfig",
    jsii_struct_bases=[cdktf.TerraformMetaArguments],
    name_mapping={
        "count": "count",
        "depends_on": "dependsOn",
        "lifecycle": "lifecycle",
        "provider": "provider",
        "name": "name",
        "resource_group_name": "resourceGroupName",
        "timeouts": "timeouts",
    },
)
class DataAzurermAvailabilitySetConfig(cdktf.TerraformMetaArguments):
    def __init__(
        self,
        *,
        count: typing.Optional[jsii.Number] = None,
        depends_on: typing.Optional[typing.List[cdktf.TerraformResource]] = None,
        lifecycle: typing.Optional[cdktf.TerraformResourceLifecycle] = None,
        provider: typing.Optional[cdktf.TerraformProvider] = None,
        name: builtins.str,
        resource_group_name: builtins.str,
        timeouts: typing.Optional["DataAzurermAvailabilitySetTimeouts"] = None,
    ) -> None:
        """
        :param count: 
        :param depends_on: 
        :param lifecycle: 
        :param provider: 
        :param name: 
        :param resource_group_name: 
        :param timeouts: timeouts block.
        """
        if isinstance(lifecycle, dict):
            lifecycle = cdktf.TerraformResourceLifecycle(**lifecycle)
        if isinstance(timeouts, dict):
            timeouts = DataAzurermAvailabilitySetTimeouts(**timeouts)
        self._values: typing.Dict[str, typing.Any] = {
            "name": name,
            "resource_group_name": resource_group_name,
        }
        if count is not None:
            self._values["count"] = count
        if depends_on is not None:
            self._values["depends_on"] = depends_on
        if lifecycle is not None:
            self._values["lifecycle"] = lifecycle
        if provider is not None:
            self._values["provider"] = provider
        if timeouts is not None:
            self._values["timeouts"] = timeouts

    @builtins.property
    def count(self) -> typing.Optional[jsii.Number]:
        """
        :stability: experimental
        """
        result = self._values.get("count")
        return result

    @builtins.property
    def depends_on(self) -> typing.Optional[typing.List[cdktf.TerraformResource]]:
        """
        :stability: experimental
        """
        result = self._values.get("depends_on")
        return result

    @builtins.property
    def lifecycle(self) -> typing.Optional[cdktf.TerraformResourceLifecycle]:
        """
        :stability: experimental
        """
        result = self._values.get("lifecycle")
        return result

    @builtins.property
    def provider(self) -> typing.Optional[cdktf.TerraformProvider]:
        """
        :stability: experimental
        """
        result = self._values.get("provider")
        return result

    @builtins.property
    def name(self) -> builtins.str:
        result = self._values.get("name")
        assert result is not None, "Required property 'name' is missing"
        return result

    @builtins.property
    def resource_group_name(self) -> builtins.str:
        result = self._values.get("resource_group_name")
        assert result is not None, "Required property 'resource_group_name' is missing"
        return result

    @builtins.property
    def timeouts(self) -> typing.Optional["DataAzurermAvailabilitySetTimeouts"]:
        """timeouts block."""
        result = self._values.get("timeouts")
        return result

    def __eq__(self, rhs: typing.Any) -> builtins.bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs: typing.Any) -> builtins.bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return "DataAzurermAvailabilitySetConfig(%s)" % ", ".join(
            k + "=" + repr(v) for k, v in self._values.items()
        )


@jsii.data_type(
    jsii_type="@cdktf/provider-azurerm.DataAzurermAvailabilitySetTimeouts",
    jsii_struct_bases=[],
    name_mapping={"read": "read"},
)
class DataAzurermAvailabilitySetTimeouts:
    def __init__(self, *, read: typing.Optional[builtins.str] = None) -> None:
        """
        :param read: 
        """
        self._values: typing.Dict[str, typing.Any] = {}
        if read is not None:
            self._values["read"] = read

    @builtins.property
    def read(self) -> typing.Optional[builtins.str]:
        result = self._values.get("read")
        return result

    def __eq__(self, rhs: typing.Any) -> builtins.bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs: typing.Any) -> builtins.bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return "DataAzurermAvailabilitySetTimeouts(%s)" % ", ".join(
            k + "=" + repr(v) for k, v in self._values.items()
        )


class DataAzurermBackupPolicyVm(
    cdktf.TerraformDataSource,
    metaclass=jsii.JSIIMeta,
    jsii_type="@cdktf/provider-azurerm.DataAzurermBackupPolicyVm",
):
    def __init__(
        self,
        scope: constructs.Construct,
        id: builtins.str,
        *,
        name: builtins.str,
        recovery_vault_name: builtins.str,
        resource_group_name: builtins.str,
        timeouts: typing.Optional["DataAzurermBackupPolicyVmTimeouts"] = None,
        count: typing.Optional[jsii.Number] = None,
        depends_on: typing.Optional[typing.List[cdktf.TerraformResource]] = None,
        lifecycle: typing.Optional[cdktf.TerraformResourceLifecycle] = None,
        provider: typing.Optional[cdktf.TerraformProvider] = None,
    ) -> None:
        """
        :param scope: -
        :param id: -
        :param name: 
        :param recovery_vault_name: 
        :param resource_group_name: 
        :param timeouts: timeouts block.
        :param count: 
        :param depends_on: 
        :param lifecycle: 
        :param provider: 
        """
        config = DataAzurermBackupPolicyVmConfig(
            name=name,
            recovery_vault_name=recovery_vault_name,
            resource_group_name=resource_group_name,
            timeouts=timeouts,
            count=count,
            depends_on=depends_on,
            lifecycle=lifecycle,
            provider=provider,
        )

        jsii.create(DataAzurermBackupPolicyVm, self, [scope, id, config])

    @jsii.member(jsii_name="synthesizeAttributes")
    def _synthesize_attributes(self) -> typing.Mapping[builtins.str, typing.Any]:
        return jsii.invoke(self, "synthesizeAttributes", [])

    @jsii.member(jsii_name="tags")
    def tags(self, key: builtins.str) -> builtins.str:
        """
        :param key: -
        """
        return jsii.invoke(self, "tags", [key])

    @builtins.property # type: ignore
    @jsii.member(jsii_name="name")
    def name(self) -> builtins.str:
        return jsii.get(self, "name")

    @name.setter # type: ignore
    def name(self, value: builtins.str) -> None:
        jsii.set(self, "name", value)

    @builtins.property # type: ignore
    @jsii.member(jsii_name="recoveryVaultName")
    def recovery_vault_name(self) -> builtins.str:
        return jsii.get(self, "recoveryVaultName")

    @recovery_vault_name.setter # type: ignore
    def recovery_vault_name(self, value: builtins.str) -> None:
        jsii.set(self, "recoveryVaultName", value)

    @builtins.property # type: ignore
    @jsii.member(jsii_name="resourceGroupName")
    def resource_group_name(self) -> builtins.str:
        return jsii.get(self, "resourceGroupName")

    @resource_group_name.setter # type: ignore
    def resource_group_name(self, value: builtins.str) -> None:
        jsii.set(self, "resourceGroupName", value)

    @builtins.property # type: ignore
    @jsii.member(jsii_name="id")
    def id(self) -> typing.Optional[builtins.str]:
        return jsii.get(self, "id")

    @id.setter # type: ignore
    def id(self, value: typing.Optional[builtins.str]) -> None:
        jsii.set(self, "id", value)

    @builtins.property # type: ignore
    @jsii.member(jsii_name="timeouts")
    def timeouts(self) -> typing.Optional["DataAzurermBackupPolicyVmTimeouts"]:
        return jsii.get(self, "timeouts")

    @timeouts.setter # type: ignore
    def timeouts(
        self,
        value: typing.Optional["DataAzurermBackupPolicyVmTimeouts"],
    ) -> None:
        jsii.set(self, "timeouts", value)


@jsii.data_type(
    jsii_type="@cdktf/provider-azurerm.DataAzurermBackupPolicyVmConfig",
    jsii_struct_bases=[cdktf.TerraformMetaArguments],
    name_mapping={
        "count": "count",
        "depends_on": "dependsOn",
        "lifecycle": "lifecycle",
        "provider": "provider",
        "name": "name",
        "recovery_vault_name": "recoveryVaultName",
        "resource_group_name": "resourceGroupName",
        "timeouts": "timeouts",
    },
)
class DataAzurermBackupPolicyVmConfig(cdktf.TerraformMetaArguments):
    def __init__(
        self,
        *,
        count: typing.Optional[jsii.Number] = None,
        depends_on: typing.Optional[typing.List[cdktf.TerraformResource]] = None,
        lifecycle: typing.Optional[cdktf.TerraformResourceLifecycle] = None,
        provider: typing.Optional[cdktf.TerraformProvider] = None,
        name: builtins.str,
        recovery_vault_name: builtins.str,
        resource_group_name: builtins.str,
        timeouts: typing.Optional["DataAzurermBackupPolicyVmTimeouts"] = None,
    ) -> None:
        """
        :param count: 
        :param depends_on: 
        :param lifecycle: 
        :param provider: 
        :param name: 
        :param recovery_vault_name: 
        :param resource_group_name: 
        :param timeouts: timeouts block.
        """
        if isinstance(lifecycle, dict):
            lifecycle = cdktf.TerraformResourceLifecycle(**lifecycle)
        if isinstance(timeouts, dict):
            timeouts = DataAzurermBackupPolicyVmTimeouts(**timeouts)
        self._values: typing.Dict[str, typing.Any] = {
            "name": name,
            "recovery_vault_name": recovery_vault_name,
            "resource_group_name": resource_group_name,
        }
        if count is not None:
            self._values["count"] = count
        if depends_on is not None:
            self._values["depends_on"] = depends_on
        if lifecycle is not None:
            self._values["lifecycle"] = lifecycle
        if provider is not None:
            self._values["provider"] = provider
        if timeouts is not None:
            self._values["timeouts"] = timeouts

    @builtins.property
    def count(self) -> typing.Optional[jsii.Number]:
        """
        :stability: experimental
        """
        result = self._values.get("count")
        return result

    @builtins.property
    def depends_on(self) -> typing.Optional[typing.List[cdktf.TerraformResource]]:
        """
        :stability: experimental
        """
        result = self._values.get("depends_on")
        return result

    @builtins.property
    def lifecycle(self) -> typing.Optional[cdktf.TerraformResourceLifecycle]:
        """
        :stability: experimental
        """
        result = self._values.get("lifecycle")
        return result

    @builtins.property
    def provider(self) -> typing.Optional[cdktf.TerraformProvider]:
        """
        :stability: experimental
        """
        result = self._values.get("provider")
        return result

    @builtins.property
    def name(self) -> builtins.str:
        result = self._values.get("name")
        assert result is not None, "Required property 'name' is missing"
        return result

    @builtins.property
    def recovery_vault_name(self) -> builtins.str:
        result = self._values.get("recovery_vault_name")
        assert result is not None, "Required property 'recovery_vault_name' is missing"
        return result

    @builtins.property
    def resource_group_name(self) -> builtins.str:
        result = self._values.get("resource_group_name")
        assert result is not None, "Required property 'resource_group_name' is missing"
        return result

    @builtins.property
    def timeouts(self) -> typing.Optional["DataAzurermBackupPolicyVmTimeouts"]:
        """timeouts block."""
        result = self._values.get("timeouts")
        return result

    def __eq__(self, rhs: typing.Any) -> builtins.bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs: typing.Any) -> builtins.bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return "DataAzurermBackupPolicyVmConfig(%s)" % ", ".join(
            k + "=" + repr(v) for k, v in self._values.items()
        )


@jsii.data_type(
    jsii_type="@cdktf/provider-azurerm.DataAzurermBackupPolicyVmTimeouts",
    jsii_struct_bases=[],
    name_mapping={"read": "read"},
)
class DataAzurermBackupPolicyVmTimeouts:
    def __init__(self, *, read: typing.Optional[builtins.str] = None) -> None:
        """
        :param read: 
        """
        self._values: typing.Dict[str, typing.Any] = {}
        if read is not None:
            self._values["read"] = read

    @builtins.property
    def read(self) -> typing.Optional[builtins.str]:
        result = self._values.get("read")
        return result

    def __eq__(self, rhs: typing.Any) -> builtins.bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs: typing.Any) -> builtins.bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return "DataAzurermBackupPolicyVmTimeouts(%s)" % ", ".join(
            k + "=" + repr(v) for k, v in self._values.items()
        )


class DataAzurermBatchAccount(
    cdktf.TerraformDataSource,
    metaclass=jsii.JSIIMeta,
    jsii_type="@cdktf/provider-azurerm.DataAzurermBatchAccount",
):
    def __init__(
        self,
        scope: constructs.Construct,
        id: builtins.str,
        *,
        name: builtins.str,
        resource_group_name: builtins.str,
        timeouts: typing.Optional["DataAzurermBatchAccountTimeouts"] = None,
        count: typing.Optional[jsii.Number] = None,
        depends_on: typing.Optional[typing.List[cdktf.TerraformResource]] = None,
        lifecycle: typing.Optional[cdktf.TerraformResourceLifecycle] = None,
        provider: typing.Optional[cdktf.TerraformProvider] = None,
    ) -> None:
        """
        :param scope: -
        :param id: -
        :param name: 
        :param resource_group_name: 
        :param timeouts: timeouts block.
        :param count: 
        :param depends_on: 
        :param lifecycle: 
        :param provider: 
        """
        config = DataAzurermBatchAccountConfig(
            name=name,
            resource_group_name=resource_group_name,
            timeouts=timeouts,
            count=count,
            depends_on=depends_on,
            lifecycle=lifecycle,
            provider=provider,
        )

        jsii.create(DataAzurermBatchAccount, self, [scope, id, config])

    @jsii.member(jsii_name="keyVaultReference")
    def key_vault_reference(
        self,
        index: builtins.str,
    ) -> "DataAzurermBatchAccountKeyVaultReference":
        """
        :param index: -
        """
        return jsii.invoke(self, "keyVaultReference", [index])

    @jsii.member(jsii_name="synthesizeAttributes")
    def _synthesize_attributes(self) -> typing.Mapping[builtins.str, typing.Any]:
        return jsii.invoke(self, "synthesizeAttributes", [])

    @jsii.member(jsii_name="tags")
    def tags(self, key: builtins.str) -> builtins.str:
        """
        :param key: -
        """
        return jsii.invoke(self, "tags", [key])

    @builtins.property # type: ignore
    @jsii.member(jsii_name="accountEndpoint")
    def account_endpoint(self) -> builtins.str:
        return jsii.get(self, "accountEndpoint")

    @builtins.property # type: ignore
    @jsii.member(jsii_name="location")
    def location(self) -> builtins.str:
        return jsii.get(self, "location")

    @builtins.property # type: ignore
    @jsii.member(jsii_name="poolAllocationMode")
    def pool_allocation_mode(self) -> builtins.str:
        return jsii.get(self, "poolAllocationMode")

    @builtins.property # type: ignore
    @jsii.member(jsii_name="primaryAccessKey")
    def primary_access_key(self) -> builtins.str:
        return jsii.get(self, "primaryAccessKey")

    @builtins.property # type: ignore
    @jsii.member(jsii_name="secondaryAccessKey")
    def secondary_access_key(self) -> builtins.str:
        return jsii.get(self, "secondaryAccessKey")

    @builtins.property # type: ignore
    @jsii.member(jsii_name="storageAccountId")
    def storage_account_id(self) -> builtins.str:
        return jsii.get(self, "storageAccountId")

    @builtins.property # type: ignore
    @jsii.member(jsii_name="name")
    def name(self) -> builtins.str:
        return jsii.get(self, "name")

    @name.setter # type: ignore
    def name(self, value: builtins.str) -> None:
        jsii.set(self, "name", value)

    @builtins.property # type: ignore
    @jsii.member(jsii_name="resourceGroupName")
    def resource_group_name(self) -> builtins.str:
        return jsii.get(self, "resourceGroupName")

    @resource_group_name.setter # type: ignore
    def resource_group_name(self, value: builtins.str) -> None:
        jsii.set(self, "resourceGroupName", value)

    @builtins.property # type: ignore
    @jsii.member(jsii_name="id")
    def id(self) -> typing.Optional[builtins.str]:
        return jsii.get(self, "id")

    @id.setter # type: ignore
    def id(self, value: typing.Optional[builtins.str]) -> None:
        jsii.set(self, "id", value)

    @builtins.property # type: ignore
    @jsii.member(jsii_name="timeouts")
    def timeouts(self) -> typing.Optional["DataAzurermBatchAccountTimeouts"]:
        return jsii.get(self, "timeouts")

    @timeouts.setter # type: ignore
    def timeouts(
        self,
        value: typing.Optional["DataAzurermBatchAccountTimeouts"],
    ) -> None:
        jsii.set(self, "timeouts", value)


@jsii.data_type(
    jsii_type="@cdktf/provider-azurerm.DataAzurermBatchAccountConfig",
    jsii_struct_bases=[cdktf.TerraformMetaArguments],
    name_mapping={
        "count": "count",
        "depends_on": "dependsOn",
        "lifecycle": "lifecycle",
        "provider": "provider",
        "name": "name",
        "resource_group_name": "resourceGroupName",
        "timeouts": "timeouts",
    },
)
class DataAzurermBatchAccountConfig(cdktf.TerraformMetaArguments):
    def __init__(
        self,
        *,
        count: typing.Optional[jsii.Number] = None,
        depends_on: typing.Optional[typing.List[cdktf.TerraformResource]] = None,
        lifecycle: typing.Optional[cdktf.TerraformResourceLifecycle] = None,
        provider: typing.Optional[cdktf.TerraformProvider] = None,
        name: builtins.str,
        resource_group_name: builtins.str,
        timeouts: typing.Optional["DataAzurermBatchAccountTimeouts"] = None,
    ) -> None:
        """
        :param count: 
        :param depends_on: 
        :param lifecycle: 
        :param provider: 
        :param name: 
        :param resource_group_name: 
        :param timeouts: timeouts block.
        """
        if isinstance(lifecycle, dict):
            lifecycle = cdktf.TerraformResourceLifecycle(**lifecycle)
        if isinstance(timeouts, dict):
            timeouts = DataAzurermBatchAccountTimeouts(**timeouts)
        self._values: typing.Dict[str, typing.Any] = {
            "name": name,
            "resource_group_name": resource_group_name,
        }
        if count is not None:
            self._values["count"] = count
        if depends_on is not None:
            self._values["depends_on"] = depends_on
        if lifecycle is not None:
            self._values["lifecycle"] = lifecycle
        if provider is not None:
            self._values["provider"] = provider
        if timeouts is not None:
            self._values["timeouts"] = timeouts

    @builtins.property
    def count(self) -> typing.Optional[jsii.Number]:
        """
        :stability: experimental
        """
        result = self._values.get("count")
        return result

    @builtins.property
    def depends_on(self) -> typing.Optional[typing.List[cdktf.TerraformResource]]:
        """
        :stability: experimental
        """
        result = self._values.get("depends_on")
        return result

    @builtins.property
    def lifecycle(self) -> typing.Optional[cdktf.TerraformResourceLifecycle]:
        """
        :stability: experimental
        """
        result = self._values.get("lifecycle")
        return result

    @builtins.property
    def provider(self) -> typing.Optional[cdktf.TerraformProvider]:
        """
        :stability: experimental
        """
        result = self._values.get("provider")
        return result

    @builtins.property
    def name(self) -> builtins.str:
        result = self._values.get("name")
        assert result is not None, "Required property 'name' is missing"
        return result

    @builtins.property
    def resource_group_name(self) -> builtins.str:
        result = self._values.get("resource_group_name")
        assert result is not None, "Required property 'resource_group_name' is missing"
        return result

    @builtins.property
    def timeouts(self) -> typing.Optional["DataAzurermBatchAccountTimeouts"]:
        """timeouts block."""
        result = self._values.get("timeouts")
        return result

    def __eq__(self, rhs: typing.Any) -> builtins.bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs: typing.Any) -> builtins.bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return "DataAzurermBatchAccountConfig(%s)" % ", ".join(
            k + "=" + repr(v) for k, v in self._values.items()
        )


class DataAzurermBatchAccountKeyVaultReference(
    cdktf.ComplexComputedList,
    metaclass=jsii.JSIIMeta,
    jsii_type="@cdktf/provider-azurerm.DataAzurermBatchAccountKeyVaultReference",
):
    def __init__(
        self,
        terraform_resource: cdktf.ITerraformResource,
        terraform_attribute: builtins.str,
        index: builtins.str,
    ) -> None:
        """
        :param terraform_resource: -
        :param terraform_attribute: -
        :param index: -

        :stability: experimental
        """
        jsii.create(DataAzurermBatchAccountKeyVaultReference, self, [terraform_resource, terraform_attribute, index])

    @builtins.property # type: ignore
    @jsii.member(jsii_name="id")
    def id(self) -> builtins.str:
        return jsii.get(self, "id")

    @builtins.property # type: ignore
    @jsii.member(jsii_name="url")
    def url(self) -> builtins.str:
        return jsii.get(self, "url")


@jsii.data_type(
    jsii_type="@cdktf/provider-azurerm.DataAzurermBatchAccountTimeouts",
    jsii_struct_bases=[],
    name_mapping={"read": "read"},
)
class DataAzurermBatchAccountTimeouts:
    def __init__(self, *, read: typing.Optional[builtins.str] = None) -> None:
        """
        :param read: 
        """
        self._values: typing.Dict[str, typing.Any] = {}
        if read is not None:
            self._values["read"] = read

    @builtins.property
    def read(self) -> typing.Optional[builtins.str]:
        result = self._values.get("read")
        return result

    def __eq__(self, rhs: typing.Any) -> builtins.bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs: typing.Any) -> builtins.bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return "DataAzurermBatchAccountTimeouts(%s)" % ", ".join(
            k + "=" + repr(v) for k, v in self._values.items()
        )


class DataAzurermBatchCertificate(
    cdktf.TerraformDataSource,
    metaclass=jsii.JSIIMeta,
    jsii_type="@cdktf/provider-azurerm.DataAzurermBatchCertificate",
):
    def __init__(
        self,
        scope: constructs.Construct,
        id: builtins.str,
        *,
        account_name: builtins.str,
        name: builtins.str,
        resource_group_name: builtins.str,
        timeouts: typing.Optional["DataAzurermBatchCertificateTimeouts"] = None,
        count: typing.Optional[jsii.Number] = None,
        depends_on: typing.Optional[typing.List[cdktf.TerraformResource]] = None,
        lifecycle: typing.Optional[cdktf.TerraformResourceLifecycle] = None,
        provider: typing.Optional[cdktf.TerraformProvider] = None,
    ) -> None:
        """
        :param scope: -
        :param id: -
        :param account_name: 
        :param name: 
        :param resource_group_name: 
        :param timeouts: timeouts block.
        :param count: 
        :param depends_on: 
        :param lifecycle: 
        :param provider: 
        """
        config = DataAzurermBatchCertificateConfig(
            account_name=account_name,
            name=name,
            resource_group_name=resource_group_name,
            timeouts=timeouts,
            count=count,
            depends_on=depends_on,
            lifecycle=lifecycle,
            provider=provider,
        )

        jsii.create(DataAzurermBatchCertificate, self, [scope, id, config])

    @jsii.member(jsii_name="synthesizeAttributes")
    def _synthesize_attributes(self) -> typing.Mapping[builtins.str, typing.Any]:
        return jsii.invoke(self, "synthesizeAttributes", [])

    @builtins.property # type: ignore
    @jsii.member(jsii_name="format")
    def format(self) -> builtins.str:
        return jsii.get(self, "format")

    @builtins.property # type: ignore
    @jsii.member(jsii_name="publicData")
    def public_data(self) -> builtins.str:
        return jsii.get(self, "publicData")

    @builtins.property # type: ignore
    @jsii.member(jsii_name="thumbprint")
    def thumbprint(self) -> builtins.str:
        return jsii.get(self, "thumbprint")

    @builtins.property # type: ignore
    @jsii.member(jsii_name="thumbprintAlgorithm")
    def thumbprint_algorithm(self) -> builtins.str:
        return jsii.get(self, "thumbprintAlgorithm")

    @builtins.property # type: ignore
    @jsii.member(jsii_name="accountName")
    def account_name(self) -> builtins.str:
        return jsii.get(self, "accountName")

    @account_name.setter # type: ignore
    def account_name(self, value: builtins.str) -> None:
        jsii.set(self, "accountName", value)

    @builtins.property # type: ignore
    @jsii.member(jsii_name="name")
    def name(self) -> builtins.str:
        return jsii.get(self, "name")

    @name.setter # type: ignore
    def name(self, value: builtins.str) -> None:
        jsii.set(self, "name", value)

    @builtins.property # type: ignore
    @jsii.member(jsii_name="resourceGroupName")
    def resource_group_name(self) -> builtins.str:
        return jsii.get(self, "resourceGroupName")

    @resource_group_name.setter # type: ignore
    def resource_group_name(self, value: builtins.str) -> None:
        jsii.set(self, "resourceGroupName", value)

    @builtins.property # type: ignore
    @jsii.member(jsii_name="id")
    def id(self) -> typing.Optional[builtins.str]:
        return jsii.get(self, "id")

    @id.setter # type: ignore
    def id(self, value: typing.Optional[builtins.str]) -> None:
        jsii.set(self, "id", value)

    @builtins.property # type: ignore
    @jsii.member(jsii_name="timeouts")
    def timeouts(self) -> typing.Optional["DataAzurermBatchCertificateTimeouts"]:
        return jsii.get(self, "timeouts")

    @timeouts.setter # type: ignore
    def timeouts(
        self,
        value: typing.Optional["DataAzurermBatchCertificateTimeouts"],
    ) -> None:
        jsii.set(self, "timeouts", value)


@jsii.data_type(
    jsii_type="@cdktf/provider-azurerm.DataAzurermBatchCertificateConfig",
    jsii_struct_bases=[cdktf.TerraformMetaArguments],
    name_mapping={
        "count": "count",
        "depends_on": "dependsOn",
        "lifecycle": "lifecycle",
        "provider": "provider",
        "account_name": "accountName",
        "name": "name",
        "resource_group_name": "resourceGroupName",
        "timeouts": "timeouts",
    },
)
class DataAzurermBatchCertificateConfig(cdktf.TerraformMetaArguments):
    def __init__(
        self,
        *,
        count: typing.Optional[jsii.Number] = None,
        depends_on: typing.Optional[typing.List[cdktf.TerraformResource]] = None,
        lifecycle: typing.Optional[cdktf.TerraformResourceLifecycle] = None,
        provider: typing.Optional[cdktf.TerraformProvider] = None,
        account_name: builtins.str,
        name: builtins.str,
        resource_group_name: builtins.str,
        timeouts: typing.Optional["DataAzurermBatchCertificateTimeouts"] = None,
    ) -> None:
        """
        :param count: 
        :param depends_on: 
        :param lifecycle: 
        :param provider: 
        :param account_name: 
        :param name: 
        :param resource_group_name: 
        :param timeouts: timeouts block.
        """
        if isinstance(lifecycle, dict):
            lifecycle = cdktf.TerraformResourceLifecycle(**lifecycle)
        if isinstance(timeouts, dict):
            timeouts = DataAzurermBatchCertificateTimeouts(**timeouts)
        self._values: typing.Dict[str, typing.Any] = {
            "account_name": account_name,
            "name": name,
            "resource_group_name": resource_group_name,
        }
        if count is not None:
            self._values["count"] = count
        if depends_on is not None:
            self._values["depends_on"] = depends_on
        if lifecycle is not None:
            self._values["lifecycle"] = lifecycle
        if provider is not None:
            self._values["provider"] = provider
        if timeouts is not None:
            self._values["timeouts"] = timeouts

    @builtins.property
    def count(self) -> typing.Optional[jsii.Number]:
        """
        :stability: experimental
        """
        result = self._values.get("count")
        return result

    @builtins.property
    def depends_on(self) -> typing.Optional[typing.List[cdktf.TerraformResource]]:
        """
        :stability: experimental
        """
        result = self._values.get("depends_on")
        return result

    @builtins.property
    def lifecycle(self) -> typing.Optional[cdktf.TerraformResourceLifecycle]:
        """
        :stability: experimental
        """
        result = self._values.get("lifecycle")
        return result

    @builtins.property
    def provider(self) -> typing.Optional[cdktf.TerraformProvider]:
        """
        :stability: experimental
        """
        result = self._values.get("provider")
        return result

    @builtins.property
    def account_name(self) -> builtins.str:
        result = self._values.get("account_name")
        assert result is not None, "Required property 'account_name' is missing"
        return result

    @builtins.property
    def name(self) -> builtins.str:
        result = self._values.get("name")
        assert result is not None, "Required property 'name' is missing"
        return result

    @builtins.property
    def resource_group_name(self) -> builtins.str:
        result = self._values.get("resource_group_name")
        assert result is not None, "Required property 'resource_group_name' is missing"
        return result

    @builtins.property
    def timeouts(self) -> typing.Optional["DataAzurermBatchCertificateTimeouts"]:
        """timeouts block."""
        result = self._values.get("timeouts")
        return result

    def __eq__(self, rhs: typing.Any) -> builtins.bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs: typing.Any) -> builtins.bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return "DataAzurermBatchCertificateConfig(%s)" % ", ".join(
            k + "=" + repr(v) for k, v in self._values.items()
        )


@jsii.data_type(
    jsii_type="@cdktf/provider-azurerm.DataAzurermBatchCertificateTimeouts",
    jsii_struct_bases=[],
    name_mapping={"read": "read"},
)
class DataAzurermBatchCertificateTimeouts:
    def __init__(self, *, read: typing.Optional[builtins.str] = None) -> None:
        """
        :param read: 
        """
        self._values: typing.Dict[str, typing.Any] = {}
        if read is not None:
            self._values["read"] = read

    @builtins.property
    def read(self) -> typing.Optional[builtins.str]:
        result = self._values.get("read")
        return result

    def __eq__(self, rhs: typing.Any) -> builtins.bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs: typing.Any) -> builtins.bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return "DataAzurermBatchCertificateTimeouts(%s)" % ", ".join(
            k + "=" + repr(v) for k, v in self._values.items()
        )


class DataAzurermBatchPool(
    cdktf.TerraformDataSource,
    metaclass=jsii.JSIIMeta,
    jsii_type="@cdktf/provider-azurerm.DataAzurermBatchPool",
):
    def __init__(
        self,
        scope: constructs.Construct,
        id: builtins.str,
        *,
        account_name: builtins.str,
        name: builtins.str,
        resource_group_name: builtins.str,
        certificate: typing.Optional[typing.List["DataAzurermBatchPoolCertificate"]] = None,
        network_configuration: typing.Optional[typing.List["DataAzurermBatchPoolNetworkConfiguration"]] = None,
        start_task: typing.Optional[typing.List["DataAzurermBatchPoolStartTask"]] = None,
        timeouts: typing.Optional["DataAzurermBatchPoolTimeouts"] = None,
        count: typing.Optional[jsii.Number] = None,
        depends_on: typing.Optional[typing.List[cdktf.TerraformResource]] = None,
        lifecycle: typing.Optional[cdktf.TerraformResourceLifecycle] = None,
        provider: typing.Optional[cdktf.TerraformProvider] = None,
    ) -> None:
        """
        :param scope: -
        :param id: -
        :param account_name: 
        :param name: 
        :param resource_group_name: 
        :param certificate: certificate block.
        :param network_configuration: network_configuration block.
        :param start_task: start_task block.
        :param timeouts: timeouts block.
        :param count: 
        :param depends_on: 
        :param lifecycle: 
        :param provider: 
        """
        config = DataAzurermBatchPoolConfig(
            account_name=account_name,
            name=name,
            resource_group_name=resource_group_name,
            certificate=certificate,
            network_configuration=network_configuration,
            start_task=start_task,
            timeouts=timeouts,
            count=count,
            depends_on=depends_on,
            lifecycle=lifecycle,
            provider=provider,
        )

        jsii.create(DataAzurermBatchPool, self, [scope, id, config])

    @jsii.member(jsii_name="autoScale")
    def auto_scale(self, index: builtins.str) -> "DataAzurermBatchPoolAutoScale":
        """
        :param index: -
        """
        return jsii.invoke(self, "autoScale", [index])

    @jsii.member(jsii_name="containerConfiguration")
    def container_configuration(
        self,
        index: builtins.str,
    ) -> "DataAzurermBatchPoolContainerConfiguration":
        """
        :param index: -
        """
        return jsii.invoke(self, "containerConfiguration", [index])

    @jsii.member(jsii_name="fixedScale")
    def fixed_scale(self, index: builtins.str) -> "DataAzurermBatchPoolFixedScale":
        """
        :param index: -
        """
        return jsii.invoke(self, "fixedScale", [index])

    @jsii.member(jsii_name="metadata")
    def metadata(self, key: builtins.str) -> builtins.str:
        """
        :param key: -
        """
        return jsii.invoke(self, "metadata", [key])

    @jsii.member(jsii_name="storageImageReference")
    def storage_image_reference(
        self,
        index: builtins.str,
    ) -> "DataAzurermBatchPoolStorageImageReference":
        """
        :param index: -
        """
        return jsii.invoke(self, "storageImageReference", [index])

    @jsii.member(jsii_name="synthesizeAttributes")
    def _synthesize_attributes(self) -> typing.Mapping[builtins.str, typing.Any]:
        return jsii.invoke(self, "synthesizeAttributes", [])

    @builtins.property # type: ignore
    @jsii.member(jsii_name="displayName")
    def display_name(self) -> builtins.str:
        return jsii.get(self, "displayName")

    @builtins.property # type: ignore
    @jsii.member(jsii_name="maxTasksPerNode")
    def max_tasks_per_node(self) -> jsii.Number:
        return jsii.get(self, "maxTasksPerNode")

    @builtins.property # type: ignore
    @jsii.member(jsii_name="nodeAgentSkuId")
    def node_agent_sku_id(self) -> builtins.str:
        return jsii.get(self, "nodeAgentSkuId")

    @builtins.property # type: ignore
    @jsii.member(jsii_name="vmSize")
    def vm_size(self) -> builtins.str:
        return jsii.get(self, "vmSize")

    @builtins.property # type: ignore
    @jsii.member(jsii_name="accountName")
    def account_name(self) -> builtins.str:
        return jsii.get(self, "accountName")

    @account_name.setter # type: ignore
    def account_name(self, value: builtins.str) -> None:
        jsii.set(self, "accountName", value)

    @builtins.property # type: ignore
    @jsii.member(jsii_name="name")
    def name(self) -> builtins.str:
        return jsii.get(self, "name")

    @name.setter # type: ignore
    def name(self, value: builtins.str) -> None:
        jsii.set(self, "name", value)

    @builtins.property # type: ignore
    @jsii.member(jsii_name="resourceGroupName")
    def resource_group_name(self) -> builtins.str:
        return jsii.get(self, "resourceGroupName")

    @resource_group_name.setter # type: ignore
    def resource_group_name(self, value: builtins.str) -> None:
        jsii.set(self, "resourceGroupName", value)

    @builtins.property # type: ignore
    @jsii.member(jsii_name="certificate")
    def certificate(
        self,
    ) -> typing.Optional[typing.List["DataAzurermBatchPoolCertificate"]]:
        return jsii.get(self, "certificate")

    @certificate.setter # type: ignore
    def certificate(
        self,
        value: typing.Optional[typing.List["DataAzurermBatchPoolCertificate"]],
    ) -> None:
        jsii.set(self, "certificate", value)

    @builtins.property # type: ignore
    @jsii.member(jsii_name="id")
    def id(self) -> typing.Optional[builtins.str]:
        return jsii.get(self, "id")

    @id.setter # type: ignore
    def id(self, value: typing.Optional[builtins.str]) -> None:
        jsii.set(self, "id", value)

    @builtins.property # type: ignore
    @jsii.member(jsii_name="networkConfiguration")
    def network_configuration(
        self,
    ) -> typing.Optional[typing.List["DataAzurermBatchPoolNetworkConfiguration"]]:
        return jsii.get(self, "networkConfiguration")

    @network_configuration.setter # type: ignore
    def network_configuration(
        self,
        value: typing.Optional[typing.List["DataAzurermBatchPoolNetworkConfiguration"]],
    ) -> None:
        jsii.set(self, "networkConfiguration", value)

    @builtins.property # type: ignore
    @jsii.member(jsii_name="startTask")
    def start_task(
        self,
    ) -> typing.Optional[typing.List["DataAzurermBatchPoolStartTask"]]:
        return jsii.get(self, "startTask")

    @start_task.setter # type: ignore
    def start_task(
        self,
        value: typing.Optional[typing.List["DataAzurermBatchPoolStartTask"]],
    ) -> None:
        jsii.set(self, "startTask", value)

    @builtins.property # type: ignore
    @jsii.member(jsii_name="timeouts")
    def timeouts(self) -> typing.Optional["DataAzurermBatchPoolTimeouts"]:
        return jsii.get(self, "timeouts")

    @timeouts.setter # type: ignore
    def timeouts(self, value: typing.Optional["DataAzurermBatchPoolTimeouts"]) -> None:
        jsii.set(self, "timeouts", value)


class DataAzurermBatchPoolAutoScale(
    cdktf.ComplexComputedList,
    metaclass=jsii.JSIIMeta,
    jsii_type="@cdktf/provider-azurerm.DataAzurermBatchPoolAutoScale",
):
    def __init__(
        self,
        terraform_resource: cdktf.ITerraformResource,
        terraform_attribute: builtins.str,
        index: builtins.str,
    ) -> None:
        """
        :param terraform_resource: -
        :param terraform_attribute: -
        :param index: -

        :stability: experimental
        """
        jsii.create(DataAzurermBatchPoolAutoScale, self, [terraform_resource, terraform_attribute, index])

    @builtins.property # type: ignore
    @jsii.member(jsii_name="evaluationInterval")
    def evaluation_interval(self) -> builtins.str:
        return jsii.get(self, "evaluationInterval")

    @builtins.property # type: ignore
    @jsii.member(jsii_name="formula")
    def formula(self) -> builtins.str:
        return jsii.get(self, "formula")


@jsii.data_type(
    jsii_type="@cdktf/provider-azurerm.DataAzurermBatchPoolCertificate",
    jsii_struct_bases=[],
    name_mapping={
        "id": "id",
        "store_location": "storeLocation",
        "store_name": "storeName",
        "visibility": "visibility",
    },
)
class DataAzurermBatchPoolCertificate:
    def __init__(
        self,
        *,
        id: builtins.str,
        store_location: builtins.str,
        store_name: typing.Optional[builtins.str] = None,
        visibility: typing.Optional[typing.List[builtins.str]] = None,
    ) -> None:
        """
        :param id: 
        :param store_location: 
        :param store_name: 
        :param visibility: 
        """
        self._values: typing.Dict[str, typing.Any] = {
            "id": id,
            "store_location": store_location,
        }
        if store_name is not None:
            self._values["store_name"] = store_name
        if visibility is not None:
            self._values["visibility"] = visibility

    @builtins.property
    def id(self) -> builtins.str:
        result = self._values.get("id")
        assert result is not None, "Required property 'id' is missing"
        return result

    @builtins.property
    def store_location(self) -> builtins.str:
        result = self._values.get("store_location")
        assert result is not None, "Required property 'store_location' is missing"
        return result

    @builtins.property
    def store_name(self) -> typing.Optional[builtins.str]:
        result = self._values.get("store_name")
        return result

    @builtins.property
    def visibility(self) -> typing.Optional[typing.List[builtins.str]]:
        result = self._values.get("visibility")
        return result

    def __eq__(self, rhs: typing.Any) -> builtins.bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs: typing.Any) -> builtins.bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return "DataAzurermBatchPoolCertificate(%s)" % ", ".join(
            k + "=" + repr(v) for k, v in self._values.items()
        )


@jsii.data_type(
    jsii_type="@cdktf/provider-azurerm.DataAzurermBatchPoolConfig",
    jsii_struct_bases=[cdktf.TerraformMetaArguments],
    name_mapping={
        "count": "count",
        "depends_on": "dependsOn",
        "lifecycle": "lifecycle",
        "provider": "provider",
        "account_name": "accountName",
        "name": "name",
        "resource_group_name": "resourceGroupName",
        "certificate": "certificate",
        "network_configuration": "networkConfiguration",
        "start_task": "startTask",
        "timeouts": "timeouts",
    },
)
class DataAzurermBatchPoolConfig(cdktf.TerraformMetaArguments):
    def __init__(
        self,
        *,
        count: typing.Optional[jsii.Number] = None,
        depends_on: typing.Optional[typing.List[cdktf.TerraformResource]] = None,
        lifecycle: typing.Optional[cdktf.TerraformResourceLifecycle] = None,
        provider: typing.Optional[cdktf.TerraformProvider] = None,
        account_name: builtins.str,
        name: builtins.str,
        resource_group_name: builtins.str,
        certificate: typing.Optional[typing.List[DataAzurermBatchPoolCertificate]] = None,
        network_configuration: typing.Optional[typing.List["DataAzurermBatchPoolNetworkConfiguration"]] = None,
        start_task: typing.Optional[typing.List["DataAzurermBatchPoolStartTask"]] = None,
        timeouts: typing.Optional["DataAzurermBatchPoolTimeouts"] = None,
    ) -> None:
        """
        :param count: 
        :param depends_on: 
        :param lifecycle: 
        :param provider: 
        :param account_name: 
        :param name: 
        :param resource_group_name: 
        :param certificate: certificate block.
        :param network_configuration: network_configuration block.
        :param start_task: start_task block.
        :param timeouts: timeouts block.
        """
        if isinstance(lifecycle, dict):
            lifecycle = cdktf.TerraformResourceLifecycle(**lifecycle)
        if isinstance(timeouts, dict):
            timeouts = DataAzurermBatchPoolTimeouts(**timeouts)
        self._values: typing.Dict[str, typing.Any] = {
            "account_name": account_name,
            "name": name,
            "resource_group_name": resource_group_name,
        }
        if count is not None:
            self._values["count"] = count
        if depends_on is not None:
            self._values["depends_on"] = depends_on
        if lifecycle is not None:
            self._values["lifecycle"] = lifecycle
        if provider is not None:
            self._values["provider"] = provider
        if certificate is not None:
            self._values["certificate"] = certificate
        if network_configuration is not None:
            self._values["network_configuration"] = network_configuration
        if start_task is not None:
            self._values["start_task"] = start_task
        if timeouts is not None:
            self._values["timeouts"] = timeouts

    @builtins.property
    def count(self) -> typing.Optional[jsii.Number]:
        """
        :stability: experimental
        """
        result = self._values.get("count")
        return result

    @builtins.property
    def depends_on(self) -> typing.Optional[typing.List[cdktf.TerraformResource]]:
        """
        :stability: experimental
        """
        result = self._values.get("depends_on")
        return result

    @builtins.property
    def lifecycle(self) -> typing.Optional[cdktf.TerraformResourceLifecycle]:
        """
        :stability: experimental
        """
        result = self._values.get("lifecycle")
        return result

    @builtins.property
    def provider(self) -> typing.Optional[cdktf.TerraformProvider]:
        """
        :stability: experimental
        """
        result = self._values.get("provider")
        return result

    @builtins.property
    def account_name(self) -> builtins.str:
        result = self._values.get("account_name")
        assert result is not None, "Required property 'account_name' is missing"
        return result

    @builtins.property
    def name(self) -> builtins.str:
        result = self._values.get("name")
        assert result is not None, "Required property 'name' is missing"
        return result

    @builtins.property
    def resource_group_name(self) -> builtins.str:
        result = self._values.get("resource_group_name")
        assert result is not None, "Required property 'resource_group_name' is missing"
        return result

    @builtins.property
    def certificate(
        self,
    ) -> typing.Optional[typing.List[DataAzurermBatchPoolCertificate]]:
        """certificate block."""
        result = self._values.get("certificate")
        return result

    @builtins.property
    def network_configuration(
        self,
    ) -> typing.Optional[typing.List["DataAzurermBatchPoolNetworkConfiguration"]]:
        """network_configuration block."""
        result = self._values.get("network_configuration")
        return result

    @builtins.property
    def start_task(
        self,
    ) -> typing.Optional[typing.List["DataAzurermBatchPoolStartTask"]]:
        """start_task block."""
        result = self._values.get("start_task")
        return result

    @builtins.property
    def timeouts(self) -> typing.Optional["DataAzurermBatchPoolTimeouts"]:
        """timeouts block."""
        result = self._values.get("timeouts")
        return result

    def __eq__(self, rhs: typing.Any) -> builtins.bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs: typing.Any) -> builtins.bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return "DataAzurermBatchPoolConfig(%s)" % ", ".join(
            k + "=" + repr(v) for k, v in self._values.items()
        )


class DataAzurermBatchPoolContainerConfiguration(
    cdktf.ComplexComputedList,
    metaclass=jsii.JSIIMeta,
    jsii_type="@cdktf/provider-azurerm.DataAzurermBatchPoolContainerConfiguration",
):
    def __init__(
        self,
        terraform_resource: cdktf.ITerraformResource,
        terraform_attribute: builtins.str,
        index: builtins.str,
    ) -> None:
        """
        :param terraform_resource: -
        :param terraform_attribute: -
        :param index: -

        :stability: experimental
        """
        jsii.create(DataAzurermBatchPoolContainerConfiguration, self, [terraform_resource, terraform_attribute, index])

    @builtins.property # type: ignore
    @jsii.member(jsii_name="containerRegistries")
    def container_registries(self) -> typing.Any:
        return jsii.get(self, "containerRegistries")

    @builtins.property # type: ignore
    @jsii.member(jsii_name="type")
    def type(self) -> builtins.str:
        return jsii.get(self, "type")


class DataAzurermBatchPoolContainerConfigurationContainerRegistries(
    cdktf.ComplexComputedList,
    metaclass=jsii.JSIIMeta,
    jsii_type="@cdktf/provider-azurerm.DataAzurermBatchPoolContainerConfigurationContainerRegistries",
):
    def __init__(
        self,
        terraform_resource: cdktf.ITerraformResource,
        terraform_attribute: builtins.str,
        index: builtins.str,
    ) -> None:
        """
        :param terraform_resource: -
        :param terraform_attribute: -
        :param index: -

        :stability: experimental
        """
        jsii.create(DataAzurermBatchPoolContainerConfigurationContainerRegistries, self, [terraform_resource, terraform_attribute, index])

    @builtins.property # type: ignore
    @jsii.member(jsii_name="password")
    def password(self) -> builtins.str:
        return jsii.get(self, "password")

    @builtins.property # type: ignore
    @jsii.member(jsii_name="registryServer")
    def registry_server(self) -> builtins.str:
        return jsii.get(self, "registryServer")

    @builtins.property # type: ignore
    @jsii.member(jsii_name="userName")
    def user_name(self) -> builtins.str:
        return jsii.get(self, "userName")


class DataAzurermBatchPoolFixedScale(
    cdktf.ComplexComputedList,
    metaclass=jsii.JSIIMeta,
    jsii_type="@cdktf/provider-azurerm.DataAzurermBatchPoolFixedScale",
):
    def __init__(
        self,
        terraform_resource: cdktf.ITerraformResource,
        terraform_attribute: builtins.str,
        index: builtins.str,
    ) -> None:
        """
        :param terraform_resource: -
        :param terraform_attribute: -
        :param index: -

        :stability: experimental
        """
        jsii.create(DataAzurermBatchPoolFixedScale, self, [terraform_resource, terraform_attribute, index])

    @builtins.property # type: ignore
    @jsii.member(jsii_name="resizeTimeout")
    def resize_timeout(self) -> builtins.str:
        return jsii.get(self, "resizeTimeout")

    @builtins.property # type: ignore
    @jsii.member(jsii_name="targetDedicatedNodes")
    def target_dedicated_nodes(self) -> jsii.Number:
        return jsii.get(self, "targetDedicatedNodes")

    @builtins.property # type: ignore
    @jsii.member(jsii_name="targetLowPriorityNodes")
    def target_low_priority_nodes(self) -> jsii.Number:
        return jsii.get(self, "targetLowPriorityNodes")


@jsii.data_type(
    jsii_type="@cdktf/provider-azurerm.DataAzurermBatchPoolNetworkConfiguration",
    jsii_struct_bases=[],
    name_mapping={
        "endpoint_configuration": "endpointConfiguration",
        "subnet_id": "subnetId",
    },
)
class DataAzurermBatchPoolNetworkConfiguration:
    def __init__(
        self,
        *,
        endpoint_configuration: typing.Optional[typing.List["DataAzurermBatchPoolNetworkConfigurationEndpointConfiguration"]] = None,
        subnet_id: typing.Optional[builtins.str] = None,
    ) -> None:
        """
        :param endpoint_configuration: endpoint_configuration block.
        :param subnet_id: 
        """
        self._values: typing.Dict[str, typing.Any] = {}
        if endpoint_configuration is not None:
            self._values["endpoint_configuration"] = endpoint_configuration
        if subnet_id is not None:
            self._values["subnet_id"] = subnet_id

    @builtins.property
    def endpoint_configuration(
        self,
    ) -> typing.Optional[typing.List["DataAzurermBatchPoolNetworkConfigurationEndpointConfiguration"]]:
        """endpoint_configuration block."""
        result = self._values.get("endpoint_configuration")
        return result

    @builtins.property
    def subnet_id(self) -> typing.Optional[builtins.str]:
        result = self._values.get("subnet_id")
        return result

    def __eq__(self, rhs: typing.Any) -> builtins.bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs: typing.Any) -> builtins.bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return "DataAzurermBatchPoolNetworkConfiguration(%s)" % ", ".join(
            k + "=" + repr(v) for k, v in self._values.items()
        )


@jsii.data_type(
    jsii_type="@cdktf/provider-azurerm.DataAzurermBatchPoolNetworkConfigurationEndpointConfiguration",
    jsii_struct_bases=[],
    name_mapping={"network_security_group_rules": "networkSecurityGroupRules"},
)
class DataAzurermBatchPoolNetworkConfigurationEndpointConfiguration:
    def __init__(
        self,
        *,
        network_security_group_rules: typing.Optional[typing.List["DataAzurermBatchPoolNetworkConfigurationEndpointConfigurationNetworkSecurityGroupRules"]] = None,
    ) -> None:
        """
        :param network_security_group_rules: network_security_group_rules block.
        """
        self._values: typing.Dict[str, typing.Any] = {}
        if network_security_group_rules is not None:
            self._values["network_security_group_rules"] = network_security_group_rules

    @builtins.property
    def network_security_group_rules(
        self,
    ) -> typing.Optional[typing.List["DataAzurermBatchPoolNetworkConfigurationEndpointConfigurationNetworkSecurityGroupRules"]]:
        """network_security_group_rules block."""
        result = self._values.get("network_security_group_rules")
        return result

    def __eq__(self, rhs: typing.Any) -> builtins.bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs: typing.Any) -> builtins.bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return "DataAzurermBatchPoolNetworkConfigurationEndpointConfiguration(%s)" % ", ".join(
            k + "=" + repr(v) for k, v in self._values.items()
        )


@jsii.data_type(
    jsii_type="@cdktf/provider-azurerm.DataAzurermBatchPoolNetworkConfigurationEndpointConfigurationNetworkSecurityGroupRules",
    jsii_struct_bases=[],
    name_mapping={},
)
class DataAzurermBatchPoolNetworkConfigurationEndpointConfigurationNetworkSecurityGroupRules:
    def __init__(self) -> None:
        self._values: typing.Dict[str, typing.Any] = {}

    def __eq__(self, rhs: typing.Any) -> builtins.bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs: typing.Any) -> builtins.bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return "DataAzurermBatchPoolNetworkConfigurationEndpointConfigurationNetworkSecurityGroupRules(%s)" % ", ".join(
            k + "=" + repr(v) for k, v in self._values.items()
        )


@jsii.data_type(
    jsii_type="@cdktf/provider-azurerm.DataAzurermBatchPoolStartTask",
    jsii_struct_bases=[],
    name_mapping={
        "command_line": "commandLine",
        "environment": "environment",
        "max_task_retry_count": "maxTaskRetryCount",
        "wait_for_success": "waitForSuccess",
    },
)
class DataAzurermBatchPoolStartTask:
    def __init__(
        self,
        *,
        command_line: builtins.str,
        environment: typing.Optional[typing.Mapping[builtins.str, builtins.str]] = None,
        max_task_retry_count: typing.Optional[jsii.Number] = None,
        wait_for_success: typing.Optional[builtins.bool] = None,
    ) -> None:
        """
        :param command_line: 
        :param environment: 
        :param max_task_retry_count: 
        :param wait_for_success: 
        """
        self._values: typing.Dict[str, typing.Any] = {
            "command_line": command_line,
        }
        if environment is not None:
            self._values["environment"] = environment
        if max_task_retry_count is not None:
            self._values["max_task_retry_count"] = max_task_retry_count
        if wait_for_success is not None:
            self._values["wait_for_success"] = wait_for_success

    @builtins.property
    def command_line(self) -> builtins.str:
        result = self._values.get("command_line")
        assert result is not None, "Required property 'command_line' is missing"
        return result

    @builtins.property
    def environment(
        self,
    ) -> typing.Optional[typing.Mapping[builtins.str, builtins.str]]:
        result = self._values.get("environment")
        return result

    @builtins.property
    def max_task_retry_count(self) -> typing.Optional[jsii.Number]:
        result = self._values.get("max_task_retry_count")
        return result

    @builtins.property
    def wait_for_success(self) -> typing.Optional[builtins.bool]:
        result = self._values.get("wait_for_success")
        return result

    def __eq__(self, rhs: typing.Any) -> builtins.bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs: typing.Any) -> builtins.bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return "DataAzurermBatchPoolStartTask(%s)" % ", ".join(
            k + "=" + repr(v) for k, v in self._values.items()
        )


class DataAzurermBatchPoolStorageImageReference(
    cdktf.ComplexComputedList,
    metaclass=jsii.JSIIMeta,
    jsii_type="@cdktf/provider-azurerm.DataAzurermBatchPoolStorageImageReference",
):
    def __init__(
        self,
        terraform_resource: cdktf.ITerraformResource,
        terraform_attribute: builtins.str,
        index: builtins.str,
    ) -> None:
        """
        :param terraform_resource: -
        :param terraform_attribute: -
        :param index: -

        :stability: experimental
        """
        jsii.create(DataAzurermBatchPoolStorageImageReference, self, [terraform_resource, terraform_attribute, index])

    @builtins.property # type: ignore
    @jsii.member(jsii_name="id")
    def id(self) -> builtins.str:
        return jsii.get(self, "id")

    @builtins.property # type: ignore
    @jsii.member(jsii_name="offer")
    def offer(self) -> builtins.str:
        return jsii.get(self, "offer")

    @builtins.property # type: ignore
    @jsii.member(jsii_name="publisher")
    def publisher(self) -> builtins.str:
        return jsii.get(self, "publisher")

    @builtins.property # type: ignore
    @jsii.member(jsii_name="sku")
    def sku(self) -> builtins.str:
        return jsii.get(self, "sku")

    @builtins.property # type: ignore
    @jsii.member(jsii_name="version")
    def version(self) -> builtins.str:
        return jsii.get(self, "version")


@jsii.data_type(
    jsii_type="@cdktf/provider-azurerm.DataAzurermBatchPoolTimeouts",
    jsii_struct_bases=[],
    name_mapping={"read": "read"},
)
class DataAzurermBatchPoolTimeouts:
    def __init__(self, *, read: typing.Optional[builtins.str] = None) -> None:
        """
        :param read: 
        """
        self._values: typing.Dict[str, typing.Any] = {}
        if read is not None:
            self._values["read"] = read

    @builtins.property
    def read(self) -> typing.Optional[builtins.str]:
        result = self._values.get("read")
        return result

    def __eq__(self, rhs: typing.Any) -> builtins.bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs: typing.Any) -> builtins.bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return "DataAzurermBatchPoolTimeouts(%s)" % ", ".join(
            k + "=" + repr(v) for k, v in self._values.items()
        )


class DataAzurermCdnProfile(
    cdktf.TerraformDataSource,
    metaclass=jsii.JSIIMeta,
    jsii_type="@cdktf/provider-azurerm.DataAzurermCdnProfile",
):
    def __init__(
        self,
        scope: constructs.Construct,
        id: builtins.str,
        *,
        name: builtins.str,
        resource_group_name: builtins.str,
        timeouts: typing.Optional["DataAzurermCdnProfileTimeouts"] = None,
        count: typing.Optional[jsii.Number] = None,
        depends_on: typing.Optional[typing.List[cdktf.TerraformResource]] = None,
        lifecycle: typing.Optional[cdktf.TerraformResourceLifecycle] = None,
        provider: typing.Optional[cdktf.TerraformProvider] = None,
    ) -> None:
        """
        :param scope: -
        :param id: -
        :param name: 
        :param resource_group_name: 
        :param timeouts: timeouts block.
        :param count: 
        :param depends_on: 
        :param lifecycle: 
        :param provider: 
        """
        config = DataAzurermCdnProfileConfig(
            name=name,
            resource_group_name=resource_group_name,
            timeouts=timeouts,
            count=count,
            depends_on=depends_on,
            lifecycle=lifecycle,
            provider=provider,
        )

        jsii.create(DataAzurermCdnProfile, self, [scope, id, config])

    @jsii.member(jsii_name="synthesizeAttributes")
    def _synthesize_attributes(self) -> typing.Mapping[builtins.str, typing.Any]:
        return jsii.invoke(self, "synthesizeAttributes", [])

    @jsii.member(jsii_name="tags")
    def tags(self, key: builtins.str) -> builtins.str:
        """
        :param key: -
        """
        return jsii.invoke(self, "tags", [key])

    @builtins.property # type: ignore
    @jsii.member(jsii_name="location")
    def location(self) -> builtins.str:
        return jsii.get(self, "location")

    @builtins.property # type: ignore
    @jsii.member(jsii_name="sku")
    def sku(self) -> builtins.str:
        return jsii.get(self, "sku")

    @builtins.property # type: ignore
    @jsii.member(jsii_name="name")
    def name(self) -> builtins.str:
        return jsii.get(self, "name")

    @name.setter # type: ignore
    def name(self, value: builtins.str) -> None:
        jsii.set(self, "name", value)

    @builtins.property # type: ignore
    @jsii.member(jsii_name="resourceGroupName")
    def resource_group_name(self) -> builtins.str:
        return jsii.get(self, "resourceGroupName")

    @resource_group_name.setter # type: ignore
    def resource_group_name(self, value: builtins.str) -> None:
        jsii.set(self, "resourceGroupName", value)

    @builtins.property # type: ignore
    @jsii.member(jsii_name="id")
    def id(self) -> typing.Optional[builtins.str]:
        return jsii.get(self, "id")

    @id.setter # type: ignore
    def id(self, value: typing.Optional[builtins.str]) -> None:
        jsii.set(self, "id", value)

    @builtins.property # type: ignore
    @jsii.member(jsii_name="timeouts")
    def timeouts(self) -> typing.Optional["DataAzurermCdnProfileTimeouts"]:
        return jsii.get(self, "timeouts")

    @timeouts.setter # type: ignore
    def timeouts(self, value: typing.Optional["DataAzurermCdnProfileTimeouts"]) -> None:
        jsii.set(self, "timeouts", value)


@jsii.data_type(
    jsii_type="@cdktf/provider-azurerm.DataAzurermCdnProfileConfig",
    jsii_struct_bases=[cdktf.TerraformMetaArguments],
    name_mapping={
        "count": "count",
        "depends_on": "dependsOn",
        "lifecycle": "lifecycle",
        "provider": "provider",
        "name": "name",
        "resource_group_name": "resourceGroupName",
        "timeouts": "timeouts",
    },
)
class DataAzurermCdnProfileConfig(cdktf.TerraformMetaArguments):
    def __init__(
        self,
        *,
        count: typing.Optional[jsii.Number] = None,
        depends_on: typing.Optional[typing.List[cdktf.TerraformResource]] = None,
        lifecycle: typing.Optional[cdktf.TerraformResourceLifecycle] = None,
        provider: typing.Optional[cdktf.TerraformProvider] = None,
        name: builtins.str,
        resource_group_name: builtins.str,
        timeouts: typing.Optional["DataAzurermCdnProfileTimeouts"] = None,
    ) -> None:
        """
        :param count: 
        :param depends_on: 
        :param lifecycle: 
        :param provider: 
        :param name: 
        :param resource_group_name: 
        :param timeouts: timeouts block.
        """
        if isinstance(lifecycle, dict):
            lifecycle = cdktf.TerraformResourceLifecycle(**lifecycle)
        if isinstance(timeouts, dict):
            timeouts = DataAzurermCdnProfileTimeouts(**timeouts)
        self._values: typing.Dict[str, typing.Any] = {
            "name": name,
            "resource_group_name": resource_group_name,
        }
        if count is not None:
            self._values["count"] = count
        if depends_on is not None:
            self._values["depends_on"] = depends_on
        if lifecycle is not None:
            self._values["lifecycle"] = lifecycle
        if provider is not None:
            self._values["provider"] = provider
        if timeouts is not None:
            self._values["timeouts"] = timeouts

    @builtins.property
    def count(self) -> typing.Optional[jsii.Number]:
        """
        :stability: experimental
        """
        result = self._values.get("count")
        return result

    @builtins.property
    def depends_on(self) -> typing.Optional[typing.List[cdktf.TerraformResource]]:
        """
        :stability: experimental
        """
        result = self._values.get("depends_on")
        return result

    @builtins.property
    def lifecycle(self) -> typing.Optional[cdktf.TerraformResourceLifecycle]:
        """
        :stability: experimental
        """
        result = self._values.get("lifecycle")
        return result

    @builtins.property
    def provider(self) -> typing.Optional[cdktf.TerraformProvider]:
        """
        :stability: experimental
        """
        result = self._values.get("provider")
        return result

    @builtins.property
    def name(self) -> builtins.str:
        result = self._values.get("name")
        assert result is not None, "Required property 'name' is missing"
        return result

    @builtins.property
    def resource_group_name(self) -> builtins.str:
        result = self._values.get("resource_group_name")
        assert result is not None, "Required property 'resource_group_name' is missing"
        return result

    @builtins.property
    def timeouts(self) -> typing.Optional["DataAzurermCdnProfileTimeouts"]:
        """timeouts block."""
        result = self._values.get("timeouts")
        return result

    def __eq__(self, rhs: typing.Any) -> builtins.bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs: typing.Any) -> builtins.bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return "DataAzurermCdnProfileConfig(%s)" % ", ".join(
            k + "=" + repr(v) for k, v in self._values.items()
        )


@jsii.data_type(
    jsii_type="@cdktf/provider-azurerm.DataAzurermCdnProfileTimeouts",
    jsii_struct_bases=[],
    name_mapping={"read": "read"},
)
class DataAzurermCdnProfileTimeouts:
    def __init__(self, *, read: typing.Optional[builtins.str] = None) -> None:
        """
        :param read: 
        """
        self._values: typing.Dict[str, typing.Any] = {}
        if read is not None:
            self._values["read"] = read

    @builtins.property
    def read(self) -> typing.Optional[builtins.str]:
        result = self._values.get("read")
        return result

    def __eq__(self, rhs: typing.Any) -> builtins.bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs: typing.Any) -> builtins.bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return "DataAzurermCdnProfileTimeouts(%s)" % ", ".join(
            k + "=" + repr(v) for k, v in self._values.items()
        )


class DataAzurermClientConfig(
    cdktf.TerraformDataSource,
    metaclass=jsii.JSIIMeta,
    jsii_type="@cdktf/provider-azurerm.DataAzurermClientConfig",
):
    def __init__(
        self,
        scope: constructs.Construct,
        id: builtins.str,
        *,
        timeouts: typing.Optional["DataAzurermClientConfigTimeouts"] = None,
        count: typing.Optional[jsii.Number] = None,
        depends_on: typing.Optional[typing.List[cdktf.TerraformResource]] = None,
        lifecycle: typing.Optional[cdktf.TerraformResourceLifecycle] = None,
        provider: typing.Optional[cdktf.TerraformProvider] = None,
    ) -> None:
        """
        :param scope: -
        :param id: -
        :param timeouts: timeouts block.
        :param count: 
        :param depends_on: 
        :param lifecycle: 
        :param provider: 
        """
        config = DataAzurermClientConfigConfig(
            timeouts=timeouts,
            count=count,
            depends_on=depends_on,
            lifecycle=lifecycle,
            provider=provider,
        )

        jsii.create(DataAzurermClientConfig, self, [scope, id, config])

    @jsii.member(jsii_name="synthesizeAttributes")
    def _synthesize_attributes(self) -> typing.Mapping[builtins.str, typing.Any]:
        return jsii.invoke(self, "synthesizeAttributes", [])

    @builtins.property # type: ignore
    @jsii.member(jsii_name="clientId")
    def client_id(self) -> builtins.str:
        return jsii.get(self, "clientId")

    @builtins.property # type: ignore
    @jsii.member(jsii_name="objectId")
    def object_id(self) -> builtins.str:
        return jsii.get(self, "objectId")

    @builtins.property # type: ignore
    @jsii.member(jsii_name="subscriptionId")
    def subscription_id(self) -> builtins.str:
        return jsii.get(self, "subscriptionId")

    @builtins.property # type: ignore
    @jsii.member(jsii_name="tenantId")
    def tenant_id(self) -> builtins.str:
        return jsii.get(self, "tenantId")

    @builtins.property # type: ignore
    @jsii.member(jsii_name="id")
    def id(self) -> typing.Optional[builtins.str]:
        return jsii.get(self, "id")

    @id.setter # type: ignore
    def id(self, value: typing.Optional[builtins.str]) -> None:
        jsii.set(self, "id", value)

    @builtins.property # type: ignore
    @jsii.member(jsii_name="timeouts")
    def timeouts(self) -> typing.Optional["DataAzurermClientConfigTimeouts"]:
        return jsii.get(self, "timeouts")

    @timeouts.setter # type: ignore
    def timeouts(
        self,
        value: typing.Optional["DataAzurermClientConfigTimeouts"],
    ) -> None:
        jsii.set(self, "timeouts", value)


@jsii.data_type(
    jsii_type="@cdktf/provider-azurerm.DataAzurermClientConfigConfig",
    jsii_struct_bases=[cdktf.TerraformMetaArguments],
    name_mapping={
        "count": "count",
        "depends_on": "dependsOn",
        "lifecycle": "lifecycle",
        "provider": "provider",
        "timeouts": "timeouts",
    },
)
class DataAzurermClientConfigConfig(cdktf.TerraformMetaArguments):
    def __init__(
        self,
        *,
        count: typing.Optional[jsii.Number] = None,
        depends_on: typing.Optional[typing.List[cdktf.TerraformResource]] = None,
        lifecycle: typing.Optional[cdktf.TerraformResourceLifecycle] = None,
        provider: typing.Optional[cdktf.TerraformProvider] = None,
        timeouts: typing.Optional["DataAzurermClientConfigTimeouts"] = None,
    ) -> None:
        """
        :param count: 
        :param depends_on: 
        :param lifecycle: 
        :param provider: 
        :param timeouts: timeouts block.
        """
        if isinstance(lifecycle, dict):
            lifecycle = cdktf.TerraformResourceLifecycle(**lifecycle)
        if isinstance(timeouts, dict):
            timeouts = DataAzurermClientConfigTimeouts(**timeouts)
        self._values: typing.Dict[str, typing.Any] = {}
        if count is not None:
            self._values["count"] = count
        if depends_on is not None:
            self._values["depends_on"] = depends_on
        if lifecycle is not None:
            self._values["lifecycle"] = lifecycle
        if provider is not None:
            self._values["provider"] = provider
        if timeouts is not None:
            self._values["timeouts"] = timeouts

    @builtins.property
    def count(self) -> typing.Optional[jsii.Number]:
        """
        :stability: experimental
        """
        result = self._values.get("count")
        return result

    @builtins.property
    def depends_on(self) -> typing.Optional[typing.List[cdktf.TerraformResource]]:
        """
        :stability: experimental
        """
        result = self._values.get("depends_on")
        return result

    @builtins.property
    def lifecycle(self) -> typing.Optional[cdktf.TerraformResourceLifecycle]:
        """
        :stability: experimental
        """
        result = self._values.get("lifecycle")
        return result

    @builtins.property
    def provider(self) -> typing.Optional[cdktf.TerraformProvider]:
        """
        :stability: experimental
        """
        result = self._values.get("provider")
        return result

    @builtins.property
    def timeouts(self) -> typing.Optional["DataAzurermClientConfigTimeouts"]:
        """timeouts block."""
        result = self._values.get("timeouts")
        return result

    def __eq__(self, rhs: typing.Any) -> builtins.bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs: typing.Any) -> builtins.bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return "DataAzurermClientConfigConfig(%s)" % ", ".join(
            k + "=" + repr(v) for k, v in self._values.items()
        )


@jsii.data_type(
    jsii_type="@cdktf/provider-azurerm.DataAzurermClientConfigTimeouts",
    jsii_struct_bases=[],
    name_mapping={"read": "read"},
)
class DataAzurermClientConfigTimeouts:
    def __init__(self, *, read: typing.Optional[builtins.str] = None) -> None:
        """
        :param read: 
        """
        self._values: typing.Dict[str, typing.Any] = {}
        if read is not None:
            self._values["read"] = read

    @builtins.property
    def read(self) -> typing.Optional[builtins.str]:
        result = self._values.get("read")
        return result

    def __eq__(self, rhs: typing.Any) -> builtins.bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs: typing.Any) -> builtins.bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return "DataAzurermClientConfigTimeouts(%s)" % ", ".join(
            k + "=" + repr(v) for k, v in self._values.items()
        )


class DataAzurermContainerRegistry(
    cdktf.TerraformDataSource,
    metaclass=jsii.JSIIMeta,
    jsii_type="@cdktf/provider-azurerm.DataAzurermContainerRegistry",
):
    def __init__(
        self,
        scope: constructs.Construct,
        id: builtins.str,
        *,
        name: builtins.str,
        resource_group_name: builtins.str,
        timeouts: typing.Optional["DataAzurermContainerRegistryTimeouts"] = None,
        count: typing.Optional[jsii.Number] = None,
        depends_on: typing.Optional[typing.List[cdktf.TerraformResource]] = None,
        lifecycle: typing.Optional[cdktf.TerraformResourceLifecycle] = None,
        provider: typing.Optional[cdktf.TerraformProvider] = None,
    ) -> None:
        """
        :param scope: -
        :param id: -
        :param name: 
        :param resource_group_name: 
        :param timeouts: timeouts block.
        :param count: 
        :param depends_on: 
        :param lifecycle: 
        :param provider: 
        """
        config = DataAzurermContainerRegistryConfig(
            name=name,
            resource_group_name=resource_group_name,
            timeouts=timeouts,
            count=count,
            depends_on=depends_on,
            lifecycle=lifecycle,
            provider=provider,
        )

        jsii.create(DataAzurermContainerRegistry, self, [scope, id, config])

    @jsii.member(jsii_name="synthesizeAttributes")
    def _synthesize_attributes(self) -> typing.Mapping[builtins.str, typing.Any]:
        return jsii.invoke(self, "synthesizeAttributes", [])

    @jsii.member(jsii_name="tags")
    def tags(self, key: builtins.str) -> builtins.str:
        """
        :param key: -
        """
        return jsii.invoke(self, "tags", [key])

    @builtins.property # type: ignore
    @jsii.member(jsii_name="adminEnabled")
    def admin_enabled(self) -> builtins.bool:
        return jsii.get(self, "adminEnabled")

    @builtins.property # type: ignore
    @jsii.member(jsii_name="adminPassword")
    def admin_password(self) -> builtins.str:
        return jsii.get(self, "adminPassword")

    @builtins.property # type: ignore
    @jsii.member(jsii_name="adminUsername")
    def admin_username(self) -> builtins.str:
        return jsii.get(self, "adminUsername")

    @builtins.property # type: ignore
    @jsii.member(jsii_name="location")
    def location(self) -> builtins.str:
        return jsii.get(self, "location")

    @builtins.property # type: ignore
    @jsii.member(jsii_name="loginServer")
    def login_server(self) -> builtins.str:
        return jsii.get(self, "loginServer")

    @builtins.property # type: ignore
    @jsii.member(jsii_name="sku")
    def sku(self) -> builtins.str:
        return jsii.get(self, "sku")

    @builtins.property # type: ignore
    @jsii.member(jsii_name="storageAccountId")
    def storage_account_id(self) -> builtins.str:
        return jsii.get(self, "storageAccountId")

    @builtins.property # type: ignore
    @jsii.member(jsii_name="name")
    def name(self) -> builtins.str:
        return jsii.get(self, "name")

    @name.setter # type: ignore
    def name(self, value: builtins.str) -> None:
        jsii.set(self, "name", value)

    @builtins.property # type: ignore
    @jsii.member(jsii_name="resourceGroupName")
    def resource_group_name(self) -> builtins.str:
        return jsii.get(self, "resourceGroupName")

    @resource_group_name.setter # type: ignore
    def resource_group_name(self, value: builtins.str) -> None:
        jsii.set(self, "resourceGroupName", value)

    @builtins.property # type: ignore
    @jsii.member(jsii_name="id")
    def id(self) -> typing.Optional[builtins.str]:
        return jsii.get(self, "id")

    @id.setter # type: ignore
    def id(self, value: typing.Optional[builtins.str]) -> None:
        jsii.set(self, "id", value)

    @builtins.property # type: ignore
    @jsii.member(jsii_name="timeouts")
    def timeouts(self) -> typing.Optional["DataAzurermContainerRegistryTimeouts"]:
        return jsii.get(self, "timeouts")

    @timeouts.setter # type: ignore
    def timeouts(
        self,
        value: typing.Optional["DataAzurermContainerRegistryTimeouts"],
    ) -> None:
        jsii.set(self, "timeouts", value)


@jsii.data_type(
    jsii_type="@cdktf/provider-azurerm.DataAzurermContainerRegistryConfig",
    jsii_struct_bases=[cdktf.TerraformMetaArguments],
    name_mapping={
        "count": "count",
        "depends_on": "dependsOn",
        "lifecycle": "lifecycle",
        "provider": "provider",
        "name": "name",
        "resource_group_name": "resourceGroupName",
        "timeouts": "timeouts",
    },
)
class DataAzurermContainerRegistryConfig(cdktf.TerraformMetaArguments):
    def __init__(
        self,
        *,
        count: typing.Optional[jsii.Number] = None,
        depends_on: typing.Optional[typing.List[cdktf.TerraformResource]] = None,
        lifecycle: typing.Optional[cdktf.TerraformResourceLifecycle] = None,
        provider: typing.Optional[cdktf.TerraformProvider] = None,
        name: builtins.str,
        resource_group_name: builtins.str,
        timeouts: typing.Optional["DataAzurermContainerRegistryTimeouts"] = None,
    ) -> None:
        """
        :param count: 
        :param depends_on: 
        :param lifecycle: 
        :param provider: 
        :param name: 
        :param resource_group_name: 
        :param timeouts: timeouts block.
        """
        if isinstance(lifecycle, dict):
            lifecycle = cdktf.TerraformResourceLifecycle(**lifecycle)
        if isinstance(timeouts, dict):
            timeouts = DataAzurermContainerRegistryTimeouts(**timeouts)
        self._values: typing.Dict[str, typing.Any] = {
            "name": name,
            "resource_group_name": resource_group_name,
        }
        if count is not None:
            self._values["count"] = count
        if depends_on is not None:
            self._values["depends_on"] = depends_on
        if lifecycle is not None:
            self._values["lifecycle"] = lifecycle
        if provider is not None:
            self._values["provider"] = provider
        if timeouts is not None:
            self._values["timeouts"] = timeouts

    @builtins.property
    def count(self) -> typing.Optional[jsii.Number]:
        """
        :stability: experimental
        """
        result = self._values.get("count")
        return result

    @builtins.property
    def depends_on(self) -> typing.Optional[typing.List[cdktf.TerraformResource]]:
        """
        :stability: experimental
        """
        result = self._values.get("depends_on")
        return result

    @builtins.property
    def lifecycle(self) -> typing.Optional[cdktf.TerraformResourceLifecycle]:
        """
        :stability: experimental
        """
        result = self._values.get("lifecycle")
        return result

    @builtins.property
    def provider(self) -> typing.Optional[cdktf.TerraformProvider]:
        """
        :stability: experimental
        """
        result = self._values.get("provider")
        return result

    @builtins.property
    def name(self) -> builtins.str:
        result = self._values.get("name")
        assert result is not None, "Required property 'name' is missing"
        return result

    @builtins.property
    def resource_group_name(self) -> builtins.str:
        result = self._values.get("resource_group_name")
        assert result is not None, "Required property 'resource_group_name' is missing"
        return result

    @builtins.property
    def timeouts(self) -> typing.Optional["DataAzurermContainerRegistryTimeouts"]:
        """timeouts block."""
        result = self._values.get("timeouts")
        return result

    def __eq__(self, rhs: typing.Any) -> builtins.bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs: typing.Any) -> builtins.bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return "DataAzurermContainerRegistryConfig(%s)" % ", ".join(
            k + "=" + repr(v) for k, v in self._values.items()
        )


@jsii.data_type(
    jsii_type="@cdktf/provider-azurerm.DataAzurermContainerRegistryTimeouts",
    jsii_struct_bases=[],
    name_mapping={"read": "read"},
)
class DataAzurermContainerRegistryTimeouts:
    def __init__(self, *, read: typing.Optional[builtins.str] = None) -> None:
        """
        :param read: 
        """
        self._values: typing.Dict[str, typing.Any] = {}
        if read is not None:
            self._values["read"] = read

    @builtins.property
    def read(self) -> typing.Optional[builtins.str]:
        result = self._values.get("read")
        return result

    def __eq__(self, rhs: typing.Any) -> builtins.bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs: typing.Any) -> builtins.bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return "DataAzurermContainerRegistryTimeouts(%s)" % ", ".join(
            k + "=" + repr(v) for k, v in self._values.items()
        )


class DataAzurermCosmosdbAccount(
    cdktf.TerraformDataSource,
    metaclass=jsii.JSIIMeta,
    jsii_type="@cdktf/provider-azurerm.DataAzurermCosmosdbAccount",
):
    def __init__(
        self,
        scope: constructs.Construct,
        id: builtins.str,
        *,
        name: builtins.str,
        resource_group_name: builtins.str,
        timeouts: typing.Optional["DataAzurermCosmosdbAccountTimeouts"] = None,
        count: typing.Optional[jsii.Number] = None,
        depends_on: typing.Optional[typing.List[cdktf.TerraformResource]] = None,
        lifecycle: typing.Optional[cdktf.TerraformResourceLifecycle] = None,
        provider: typing.Optional[cdktf.TerraformProvider] = None,
    ) -> None:
        """
        :param scope: -
        :param id: -
        :param name: 
        :param resource_group_name: 
        :param timeouts: timeouts block.
        :param count: 
        :param depends_on: 
        :param lifecycle: 
        :param provider: 
        """
        config = DataAzurermCosmosdbAccountConfig(
            name=name,
            resource_group_name=resource_group_name,
            timeouts=timeouts,
            count=count,
            depends_on=depends_on,
            lifecycle=lifecycle,
            provider=provider,
        )

        jsii.create(DataAzurermCosmosdbAccount, self, [scope, id, config])

    @jsii.member(jsii_name="capabilities")
    def capabilities(
        self,
        index: builtins.str,
    ) -> "DataAzurermCosmosdbAccountCapabilities":
        """
        :param index: -
        """
        return jsii.invoke(self, "capabilities", [index])

    @jsii.member(jsii_name="consistencyPolicy")
    def consistency_policy(
        self,
        index: builtins.str,
    ) -> "DataAzurermCosmosdbAccountConsistencyPolicy":
        """
        :param index: -
        """
        return jsii.invoke(self, "consistencyPolicy", [index])

    @jsii.member(jsii_name="geoLocation")
    def geo_location(
        self,
        index: builtins.str,
    ) -> "DataAzurermCosmosdbAccountGeoLocation":
        """
        :param index: -
        """
        return jsii.invoke(self, "geoLocation", [index])

    @jsii.member(jsii_name="synthesizeAttributes")
    def _synthesize_attributes(self) -> typing.Mapping[builtins.str, typing.Any]:
        return jsii.invoke(self, "synthesizeAttributes", [])

    @jsii.member(jsii_name="tags")
    def tags(self, key: builtins.str) -> builtins.str:
        """
        :param key: -
        """
        return jsii.invoke(self, "tags", [key])

    @jsii.member(jsii_name="virtualNetworkRule")
    def virtual_network_rule(
        self,
        index: builtins.str,
    ) -> "DataAzurermCosmosdbAccountVirtualNetworkRule":
        """
        :param index: -
        """
        return jsii.invoke(self, "virtualNetworkRule", [index])

    @builtins.property # type: ignore
    @jsii.member(jsii_name="enableAutomaticFailover")
    def enable_automatic_failover(self) -> builtins.bool:
        return jsii.get(self, "enableAutomaticFailover")

    @builtins.property # type: ignore
    @jsii.member(jsii_name="enableMultipleWriteLocations")
    def enable_multiple_write_locations(self) -> builtins.bool:
        return jsii.get(self, "enableMultipleWriteLocations")

    @builtins.property # type: ignore
    @jsii.member(jsii_name="endpoint")
    def endpoint(self) -> builtins.str:
        return jsii.get(self, "endpoint")

    @builtins.property # type: ignore
    @jsii.member(jsii_name="ipRangeFilter")
    def ip_range_filter(self) -> builtins.str:
        return jsii.get(self, "ipRangeFilter")

    @builtins.property # type: ignore
    @jsii.member(jsii_name="isVirtualNetworkFilterEnabled")
    def is_virtual_network_filter_enabled(self) -> builtins.bool:
        return jsii.get(self, "isVirtualNetworkFilterEnabled")

    @builtins.property # type: ignore
    @jsii.member(jsii_name="kind")
    def kind(self) -> builtins.str:
        return jsii.get(self, "kind")

    @builtins.property # type: ignore
    @jsii.member(jsii_name="location")
    def location(self) -> builtins.str:
        return jsii.get(self, "location")

    @builtins.property # type: ignore
    @jsii.member(jsii_name="offerType")
    def offer_type(self) -> builtins.str:
        return jsii.get(self, "offerType")

    @builtins.property # type: ignore
    @jsii.member(jsii_name="primaryMasterKey")
    def primary_master_key(self) -> builtins.str:
        return jsii.get(self, "primaryMasterKey")

    @builtins.property # type: ignore
    @jsii.member(jsii_name="primaryReadonlyMasterKey")
    def primary_readonly_master_key(self) -> builtins.str:
        return jsii.get(self, "primaryReadonlyMasterKey")

    @builtins.property # type: ignore
    @jsii.member(jsii_name="readEndpoints")
    def read_endpoints(self) -> typing.List[builtins.str]:
        return jsii.get(self, "readEndpoints")

    @builtins.property # type: ignore
    @jsii.member(jsii_name="secondaryMasterKey")
    def secondary_master_key(self) -> builtins.str:
        return jsii.get(self, "secondaryMasterKey")

    @builtins.property # type: ignore
    @jsii.member(jsii_name="secondaryReadonlyMasterKey")
    def secondary_readonly_master_key(self) -> builtins.str:
        return jsii.get(self, "secondaryReadonlyMasterKey")

    @builtins.property # type: ignore
    @jsii.member(jsii_name="writeEndpoints")
    def write_endpoints(self) -> typing.List[builtins.str]:
        return jsii.get(self, "writeEndpoints")

    @builtins.property # type: ignore
    @jsii.member(jsii_name="name")
    def name(self) -> builtins.str:
        return jsii.get(self, "name")

    @name.setter # type: ignore
    def name(self, value: builtins.str) -> None:
        jsii.set(self, "name", value)

    @builtins.property # type: ignore
    @jsii.member(jsii_name="resourceGroupName")
    def resource_group_name(self) -> builtins.str:
        return jsii.get(self, "resourceGroupName")

    @resource_group_name.setter # type: ignore
    def resource_group_name(self, value: builtins.str) -> None:
        jsii.set(self, "resourceGroupName", value)

    @builtins.property # type: ignore
    @jsii.member(jsii_name="id")
    def id(self) -> typing.Optional[builtins.str]:
        return jsii.get(self, "id")

    @id.setter # type: ignore
    def id(self, value: typing.Optional[builtins.str]) -> None:
        jsii.set(self, "id", value)

    @builtins.property # type: ignore
    @jsii.member(jsii_name="timeouts")
    def timeouts(self) -> typing.Optional["DataAzurermCosmosdbAccountTimeouts"]:
        return jsii.get(self, "timeouts")

    @timeouts.setter # type: ignore
    def timeouts(
        self,
        value: typing.Optional["DataAzurermCosmosdbAccountTimeouts"],
    ) -> None:
        jsii.set(self, "timeouts", value)


class DataAzurermCosmosdbAccountCapabilities(
    cdktf.ComplexComputedList,
    metaclass=jsii.JSIIMeta,
    jsii_type="@cdktf/provider-azurerm.DataAzurermCosmosdbAccountCapabilities",
):
    def __init__(
        self,
        terraform_resource: cdktf.ITerraformResource,
        terraform_attribute: builtins.str,
        index: builtins.str,
    ) -> None:
        """
        :param terraform_resource: -
        :param terraform_attribute: -
        :param index: -

        :stability: experimental
        """
        jsii.create(DataAzurermCosmosdbAccountCapabilities, self, [terraform_resource, terraform_attribute, index])

    @builtins.property # type: ignore
    @jsii.member(jsii_name="name")
    def name(self) -> builtins.str:
        return jsii.get(self, "name")


@jsii.data_type(
    jsii_type="@cdktf/provider-azurerm.DataAzurermCosmosdbAccountConfig",
    jsii_struct_bases=[cdktf.TerraformMetaArguments],
    name_mapping={
        "count": "count",
        "depends_on": "dependsOn",
        "lifecycle": "lifecycle",
        "provider": "provider",
        "name": "name",
        "resource_group_name": "resourceGroupName",
        "timeouts": "timeouts",
    },
)
class DataAzurermCosmosdbAccountConfig(cdktf.TerraformMetaArguments):
    def __init__(
        self,
        *,
        count: typing.Optional[jsii.Number] = None,
        depends_on: typing.Optional[typing.List[cdktf.TerraformResource]] = None,
        lifecycle: typing.Optional[cdktf.TerraformResourceLifecycle] = None,
        provider: typing.Optional[cdktf.TerraformProvider] = None,
        name: builtins.str,
        resource_group_name: builtins.str,
        timeouts: typing.Optional["DataAzurermCosmosdbAccountTimeouts"] = None,
    ) -> None:
        """
        :param count: 
        :param depends_on: 
        :param lifecycle: 
        :param provider: 
        :param name: 
        :param resource_group_name: 
        :param timeouts: timeouts block.
        """
        if isinstance(lifecycle, dict):
            lifecycle = cdktf.TerraformResourceLifecycle(**lifecycle)
        if isinstance(timeouts, dict):
            timeouts = DataAzurermCosmosdbAccountTimeouts(**timeouts)
        self._values: typing.Dict[str, typing.Any] = {
            "name": name,
            "resource_group_name": resource_group_name,
        }
        if count is not None:
            self._values["count"] = count
        if depends_on is not None:
            self._values["depends_on"] = depends_on
        if lifecycle is not None:
            self._values["lifecycle"] = lifecycle
        if provider is not None:
            self._values["provider"] = provider
        if timeouts is not None:
            self._values["timeouts"] = timeouts

    @builtins.property
    def count(self) -> typing.Optional[jsii.Number]:
        """
        :stability: experimental
        """
        result = self._values.get("count")
        return result

    @builtins.property
    def depends_on(self) -> typing.Optional[typing.List[cdktf.TerraformResource]]:
        """
        :stability: experimental
        """
        result = self._values.get("depends_on")
        return result

    @builtins.property
    def lifecycle(self) -> typing.Optional[cdktf.TerraformResourceLifecycle]:
        """
        :stability: experimental
        """
        result = self._values.get("lifecycle")
        return result

    @builtins.property
    def provider(self) -> typing.Optional[cdktf.TerraformProvider]:
        """
        :stability: experimental
        """
        result = self._values.get("provider")
        return result

    @builtins.property
    def name(self) -> builtins.str:
        result = self._values.get("name")
        assert result is not None, "Required property 'name' is missing"
        return result

    @builtins.property
    def resource_group_name(self) -> builtins.str:
        result = self._values.get("resource_group_name")
        assert result is not None, "Required property 'resource_group_name' is missing"
        return result

    @builtins.property
    def timeouts(self) -> typing.Optional["DataAzurermCosmosdbAccountTimeouts"]:
        """timeouts block."""
        result = self._values.get("timeouts")
        return result

    def __eq__(self, rhs: typing.Any) -> builtins.bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs: typing.Any) -> builtins.bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return "DataAzurermCosmosdbAccountConfig(%s)" % ", ".join(
            k + "=" + repr(v) for k, v in self._values.items()
        )


class DataAzurermCosmosdbAccountConsistencyPolicy(
    cdktf.ComplexComputedList,
    metaclass=jsii.JSIIMeta,
    jsii_type="@cdktf/provider-azurerm.DataAzurermCosmosdbAccountConsistencyPolicy",
):
    def __init__(
        self,
        terraform_resource: cdktf.ITerraformResource,
        terraform_attribute: builtins.str,
        index: builtins.str,
    ) -> None:
        """
        :param terraform_resource: -
        :param terraform_attribute: -
        :param index: -

        :stability: experimental
        """
        jsii.create(DataAzurermCosmosdbAccountConsistencyPolicy, self, [terraform_resource, terraform_attribute, index])

    @builtins.property # type: ignore
    @jsii.member(jsii_name="consistencyLevel")
    def consistency_level(self) -> builtins.str:
        return jsii.get(self, "consistencyLevel")

    @builtins.property # type: ignore
    @jsii.member(jsii_name="maxIntervalInSeconds")
    def max_interval_in_seconds(self) -> jsii.Number:
        return jsii.get(self, "maxIntervalInSeconds")

    @builtins.property # type: ignore
    @jsii.member(jsii_name="maxStalenessPrefix")
    def max_staleness_prefix(self) -> jsii.Number:
        return jsii.get(self, "maxStalenessPrefix")


class DataAzurermCosmosdbAccountGeoLocation(
    cdktf.ComplexComputedList,
    metaclass=jsii.JSIIMeta,
    jsii_type="@cdktf/provider-azurerm.DataAzurermCosmosdbAccountGeoLocation",
):
    def __init__(
        self,
        terraform_resource: cdktf.ITerraformResource,
        terraform_attribute: builtins.str,
        index: builtins.str,
    ) -> None:
        """
        :param terraform_resource: -
        :param terraform_attribute: -
        :param index: -

        :stability: experimental
        """
        jsii.create(DataAzurermCosmosdbAccountGeoLocation, self, [terraform_resource, terraform_attribute, index])

    @builtins.property # type: ignore
    @jsii.member(jsii_name="failoverPriority")
    def failover_priority(self) -> jsii.Number:
        return jsii.get(self, "failoverPriority")

    @builtins.property # type: ignore
    @jsii.member(jsii_name="id")
    def id(self) -> builtins.str:
        return jsii.get(self, "id")

    @builtins.property # type: ignore
    @jsii.member(jsii_name="location")
    def location(self) -> builtins.str:
        return jsii.get(self, "location")


@jsii.data_type(
    jsii_type="@cdktf/provider-azurerm.DataAzurermCosmosdbAccountTimeouts",
    jsii_struct_bases=[],
    name_mapping={"read": "read"},
)
class DataAzurermCosmosdbAccountTimeouts:
    def __init__(self, *, read: typing.Optional[builtins.str] = None) -> None:
        """
        :param read: 
        """
        self._values: typing.Dict[str, typing.Any] = {}
        if read is not None:
            self._values["read"] = read

    @builtins.property
    def read(self) -> typing.Optional[builtins.str]:
        result = self._values.get("read")
        return result

    def __eq__(self, rhs: typing.Any) -> builtins.bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs: typing.Any) -> builtins.bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return "DataAzurermCosmosdbAccountTimeouts(%s)" % ", ".join(
            k + "=" + repr(v) for k, v in self._values.items()
        )


class DataAzurermCosmosdbAccountVirtualNetworkRule(
    cdktf.ComplexComputedList,
    metaclass=jsii.JSIIMeta,
    jsii_type="@cdktf/provider-azurerm.DataAzurermCosmosdbAccountVirtualNetworkRule",
):
    def __init__(
        self,
        terraform_resource: cdktf.ITerraformResource,
        terraform_attribute: builtins.str,
        index: builtins.str,
    ) -> None:
        """
        :param terraform_resource: -
        :param terraform_attribute: -
        :param index: -

        :stability: experimental
        """
        jsii.create(DataAzurermCosmosdbAccountVirtualNetworkRule, self, [terraform_resource, terraform_attribute, index])

    @builtins.property # type: ignore
    @jsii.member(jsii_name="id")
    def id(self) -> builtins.str:
        return jsii.get(self, "id")


class DataAzurermDataFactory(
    cdktf.TerraformDataSource,
    metaclass=jsii.JSIIMeta,
    jsii_type="@cdktf/provider-azurerm.DataAzurermDataFactory",
):
    def __init__(
        self,
        scope: constructs.Construct,
        id: builtins.str,
        *,
        name: builtins.str,
        resource_group_name: builtins.str,
        timeouts: typing.Optional["DataAzurermDataFactoryTimeouts"] = None,
        count: typing.Optional[jsii.Number] = None,
        depends_on: typing.Optional[typing.List[cdktf.TerraformResource]] = None,
        lifecycle: typing.Optional[cdktf.TerraformResourceLifecycle] = None,
        provider: typing.Optional[cdktf.TerraformProvider] = None,
    ) -> None:
        """
        :param scope: -
        :param id: -
        :param name: 
        :param resource_group_name: 
        :param timeouts: timeouts block.
        :param count: 
        :param depends_on: 
        :param lifecycle: 
        :param provider: 
        """
        config = DataAzurermDataFactoryConfig(
            name=name,
            resource_group_name=resource_group_name,
            timeouts=timeouts,
            count=count,
            depends_on=depends_on,
            lifecycle=lifecycle,
            provider=provider,
        )

        jsii.create(DataAzurermDataFactory, self, [scope, id, config])

    @jsii.member(jsii_name="githubConfiguration")
    def github_configuration(
        self,
        index: builtins.str,
    ) -> "DataAzurermDataFactoryGithubConfiguration":
        """
        :param index: -
        """
        return jsii.invoke(self, "githubConfiguration", [index])

    @jsii.member(jsii_name="identity")
    def identity(self, index: builtins.str) -> "DataAzurermDataFactoryIdentity":
        """
        :param index: -
        """
        return jsii.invoke(self, "identity", [index])

    @jsii.member(jsii_name="synthesizeAttributes")
    def _synthesize_attributes(self) -> typing.Mapping[builtins.str, typing.Any]:
        return jsii.invoke(self, "synthesizeAttributes", [])

    @jsii.member(jsii_name="tags")
    def tags(self, key: builtins.str) -> builtins.str:
        """
        :param key: -
        """
        return jsii.invoke(self, "tags", [key])

    @jsii.member(jsii_name="vstsConfiguration")
    def vsts_configuration(
        self,
        index: builtins.str,
    ) -> "DataAzurermDataFactoryVstsConfiguration":
        """
        :param index: -
        """
        return jsii.invoke(self, "vstsConfiguration", [index])

    @builtins.property # type: ignore
    @jsii.member(jsii_name="location")
    def location(self) -> builtins.str:
        return jsii.get(self, "location")

    @builtins.property # type: ignore
    @jsii.member(jsii_name="name")
    def name(self) -> builtins.str:
        return jsii.get(self, "name")

    @name.setter # type: ignore
    def name(self, value: builtins.str) -> None:
        jsii.set(self, "name", value)

    @builtins.property # type: ignore
    @jsii.member(jsii_name="resourceGroupName")
    def resource_group_name(self) -> builtins.str:
        return jsii.get(self, "resourceGroupName")

    @resource_group_name.setter # type: ignore
    def resource_group_name(self, value: builtins.str) -> None:
        jsii.set(self, "resourceGroupName", value)

    @builtins.property # type: ignore
    @jsii.member(jsii_name="id")
    def id(self) -> typing.Optional[builtins.str]:
        return jsii.get(self, "id")

    @id.setter # type: ignore
    def id(self, value: typing.Optional[builtins.str]) -> None:
        jsii.set(self, "id", value)

    @builtins.property # type: ignore
    @jsii.member(jsii_name="timeouts")
    def timeouts(self) -> typing.Optional["DataAzurermDataFactoryTimeouts"]:
        return jsii.get(self, "timeouts")

    @timeouts.setter # type: ignore
    def timeouts(
        self,
        value: typing.Optional["DataAzurermDataFactoryTimeouts"],
    ) -> None:
        jsii.set(self, "timeouts", value)


@jsii.data_type(
    jsii_type="@cdktf/provider-azurerm.DataAzurermDataFactoryConfig",
    jsii_struct_bases=[cdktf.TerraformMetaArguments],
    name_mapping={
        "count": "count",
        "depends_on": "dependsOn",
        "lifecycle": "lifecycle",
        "provider": "provider",
        "name": "name",
        "resource_group_name": "resourceGroupName",
        "timeouts": "timeouts",
    },
)
class DataAzurermDataFactoryConfig(cdktf.TerraformMetaArguments):
    def __init__(
        self,
        *,
        count: typing.Optional[jsii.Number] = None,
        depends_on: typing.Optional[typing.List[cdktf.TerraformResource]] = None,
        lifecycle: typing.Optional[cdktf.TerraformResourceLifecycle] = None,
        provider: typing.Optional[cdktf.TerraformProvider] = None,
        name: builtins.str,
        resource_group_name: builtins.str,
        timeouts: typing.Optional["DataAzurermDataFactoryTimeouts"] = None,
    ) -> None:
        """
        :param count: 
        :param depends_on: 
        :param lifecycle: 
        :param provider: 
        :param name: 
        :param resource_group_name: 
        :param timeouts: timeouts block.
        """
        if isinstance(lifecycle, dict):
            lifecycle = cdktf.TerraformResourceLifecycle(**lifecycle)
        if isinstance(timeouts, dict):
            timeouts = DataAzurermDataFactoryTimeouts(**timeouts)
        self._values: typing.Dict[str, typing.Any] = {
            "name": name,
            "resource_group_name": resource_group_name,
        }
        if count is not None:
            self._values["count"] = count
        if depends_on is not None:
            self._values["depends_on"] = depends_on
        if lifecycle is not None:
            self._values["lifecycle"] = lifecycle
        if provider is not None:
            self._values["provider"] = provider
        if timeouts is not None:
            self._values["timeouts"] = timeouts

    @builtins.property
    def count(self) -> typing.Optional[jsii.Number]:
        """
        :stability: experimental
        """
        result = self._values.get("count")
        return result

    @builtins.property
    def depends_on(self) -> typing.Optional[typing.List[cdktf.TerraformResource]]:
        """
        :stability: experimental
        """
        result = self._values.get("depends_on")
        return result

    @builtins.property
    def lifecycle(self) -> typing.Optional[cdktf.TerraformResourceLifecycle]:
        """
        :stability: experimental
        """
        result = self._values.get("lifecycle")
        return result

    @builtins.property
    def provider(self) -> typing.Optional[cdktf.TerraformProvider]:
        """
        :stability: experimental
        """
        result = self._values.get("provider")
        return result

    @builtins.property
    def name(self) -> builtins.str:
        result = self._values.get("name")
        assert result is not None, "Required property 'name' is missing"
        return result

    @builtins.property
    def resource_group_name(self) -> builtins.str:
        result = self._values.get("resource_group_name")
        assert result is not None, "Required property 'resource_group_name' is missing"
        return result

    @builtins.property
    def timeouts(self) -> typing.Optional["DataAzurermDataFactoryTimeouts"]:
        """timeouts block."""
        result = self._values.get("timeouts")
        return result

    def __eq__(self, rhs: typing.Any) -> builtins.bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs: typing.Any) -> builtins.bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return "DataAzurermDataFactoryConfig(%s)" % ", ".join(
            k + "=" + repr(v) for k, v in self._values.items()
        )


class DataAzurermDataFactoryGithubConfiguration(
    cdktf.ComplexComputedList,
    metaclass=jsii.JSIIMeta,
    jsii_type="@cdktf/provider-azurerm.DataAzurermDataFactoryGithubConfiguration",
):
    def __init__(
        self,
        terraform_resource: cdktf.ITerraformResource,
        terraform_attribute: builtins.str,
        index: builtins.str,
    ) -> None:
        """
        :param terraform_resource: -
        :param terraform_attribute: -
        :param index: -

        :stability: experimental
        """
        jsii.create(DataAzurermDataFactoryGithubConfiguration, self, [terraform_resource, terraform_attribute, index])

    @builtins.property # type: ignore
    @jsii.member(jsii_name="accountName")
    def account_name(self) -> builtins.str:
        return jsii.get(self, "accountName")

    @builtins.property # type: ignore
    @jsii.member(jsii_name="branchName")
    def branch_name(self) -> builtins.str:
        return jsii.get(self, "branchName")

    @builtins.property # type: ignore
    @jsii.member(jsii_name="gitUrl")
    def git_url(self) -> builtins.str:
        return jsii.get(self, "gitUrl")

    @builtins.property # type: ignore
    @jsii.member(jsii_name="repositoryName")
    def repository_name(self) -> builtins.str:
        return jsii.get(self, "repositoryName")

    @builtins.property # type: ignore
    @jsii.member(jsii_name="rootFolder")
    def root_folder(self) -> builtins.str:
        return jsii.get(self, "rootFolder")


class DataAzurermDataFactoryIdentity(
    cdktf.ComplexComputedList,
    metaclass=jsii.JSIIMeta,
    jsii_type="@cdktf/provider-azurerm.DataAzurermDataFactoryIdentity",
):
    def __init__(
        self,
        terraform_resource: cdktf.ITerraformResource,
        terraform_attribute: builtins.str,
        index: builtins.str,
    ) -> None:
        """
        :param terraform_resource: -
        :param terraform_attribute: -
        :param index: -

        :stability: experimental
        """
        jsii.create(DataAzurermDataFactoryIdentity, self, [terraform_resource, terraform_attribute, index])

    @builtins.property # type: ignore
    @jsii.member(jsii_name="principalId")
    def principal_id(self) -> builtins.str:
        return jsii.get(self, "principalId")

    @builtins.property # type: ignore
    @jsii.member(jsii_name="tenantId")
    def tenant_id(self) -> builtins.str:
        return jsii.get(self, "tenantId")

    @builtins.property # type: ignore
    @jsii.member(jsii_name="type")
    def type(self) -> builtins.str:
        return jsii.get(self, "type")


@jsii.data_type(
    jsii_type="@cdktf/provider-azurerm.DataAzurermDataFactoryTimeouts",
    jsii_struct_bases=[],
    name_mapping={"read": "read"},
)
class DataAzurermDataFactoryTimeouts:
    def __init__(self, *, read: typing.Optional[builtins.str] = None) -> None:
        """
        :param read: 
        """
        self._values: typing.Dict[str, typing.Any] = {}
        if read is not None:
            self._values["read"] = read

    @builtins.property
    def read(self) -> typing.Optional[builtins.str]:
        result = self._values.get("read")
        return result

    def __eq__(self, rhs: typing.Any) -> builtins.bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs: typing.Any) -> builtins.bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return "DataAzurermDataFactoryTimeouts(%s)" % ", ".join(
            k + "=" + repr(v) for k, v in self._values.items()
        )


class DataAzurermDataFactoryVstsConfiguration(
    cdktf.ComplexComputedList,
    metaclass=jsii.JSIIMeta,
    jsii_type="@cdktf/provider-azurerm.DataAzurermDataFactoryVstsConfiguration",
):
    def __init__(
        self,
        terraform_resource: cdktf.ITerraformResource,
        terraform_attribute: builtins.str,
        index: builtins.str,
    ) -> None:
        """
        :param terraform_resource: -
        :param terraform_attribute: -
        :param index: -

        :stability: experimental
        """
        jsii.create(DataAzurermDataFactoryVstsConfiguration, self, [terraform_resource, terraform_attribute, index])

    @builtins.property # type: ignore
    @jsii.member(jsii_name="accountName")
    def account_name(self) -> builtins.str:
        return jsii.get(self, "accountName")

    @builtins.property # type: ignore
    @jsii.member(jsii_name="branchName")
    def branch_name(self) -> builtins.str:
        return jsii.get(self, "branchName")

    @builtins.property # type: ignore
    @jsii.member(jsii_name="projectName")
    def project_name(self) -> builtins.str:
        return jsii.get(self, "projectName")

    @builtins.property # type: ignore
    @jsii.member(jsii_name="repositoryName")
    def repository_name(self) -> builtins.str:
        return jsii.get(self, "repositoryName")

    @builtins.property # type: ignore
    @jsii.member(jsii_name="rootFolder")
    def root_folder(self) -> builtins.str:
        return jsii.get(self, "rootFolder")

    @builtins.property # type: ignore
    @jsii.member(jsii_name="tenantId")
    def tenant_id(self) -> builtins.str:
        return jsii.get(self, "tenantId")


class DataAzurermDataLakeStore(
    cdktf.TerraformDataSource,
    metaclass=jsii.JSIIMeta,
    jsii_type="@cdktf/provider-azurerm.DataAzurermDataLakeStore",
):
    def __init__(
        self,
        scope: constructs.Construct,
        id: builtins.str,
        *,
        name: builtins.str,
        resource_group_name: builtins.str,
        timeouts: typing.Optional["DataAzurermDataLakeStoreTimeouts"] = None,
        count: typing.Optional[jsii.Number] = None,
        depends_on: typing.Optional[typing.List[cdktf.TerraformResource]] = None,
        lifecycle: typing.Optional[cdktf.TerraformResourceLifecycle] = None,
        provider: typing.Optional[cdktf.TerraformProvider] = None,
    ) -> None:
        """
        :param scope: -
        :param id: -
        :param name: 
        :param resource_group_name: 
        :param timeouts: timeouts block.
        :param count: 
        :param depends_on: 
        :param lifecycle: 
        :param provider: 
        """
        config = DataAzurermDataLakeStoreConfig(
            name=name,
            resource_group_name=resource_group_name,
            timeouts=timeouts,
            count=count,
            depends_on=depends_on,
            lifecycle=lifecycle,
            provider=provider,
        )

        jsii.create(DataAzurermDataLakeStore, self, [scope, id, config])

    @jsii.member(jsii_name="synthesizeAttributes")
    def _synthesize_attributes(self) -> typing.Mapping[builtins.str, typing.Any]:
        return jsii.invoke(self, "synthesizeAttributes", [])

    @jsii.member(jsii_name="tags")
    def tags(self, key: builtins.str) -> builtins.str:
        """
        :param key: -
        """
        return jsii.invoke(self, "tags", [key])

    @builtins.property # type: ignore
    @jsii.member(jsii_name="encryptionState")
    def encryption_state(self) -> builtins.str:
        return jsii.get(self, "encryptionState")

    @builtins.property # type: ignore
    @jsii.member(jsii_name="encryptionType")
    def encryption_type(self) -> builtins.str:
        return jsii.get(self, "encryptionType")

    @builtins.property # type: ignore
    @jsii.member(jsii_name="firewallAllowAzureIps")
    def firewall_allow_azure_ips(self) -> builtins.str:
        return jsii.get(self, "firewallAllowAzureIps")

    @builtins.property # type: ignore
    @jsii.member(jsii_name="firewallState")
    def firewall_state(self) -> builtins.str:
        return jsii.get(self, "firewallState")

    @builtins.property # type: ignore
    @jsii.member(jsii_name="location")
    def location(self) -> builtins.str:
        return jsii.get(self, "location")

    @builtins.property # type: ignore
    @jsii.member(jsii_name="tier")
    def tier(self) -> builtins.str:
        return jsii.get(self, "tier")

    @builtins.property # type: ignore
    @jsii.member(jsii_name="name")
    def name(self) -> builtins.str:
        return jsii.get(self, "name")

    @name.setter # type: ignore
    def name(self, value: builtins.str) -> None:
        jsii.set(self, "name", value)

    @builtins.property # type: ignore
    @jsii.member(jsii_name="resourceGroupName")
    def resource_group_name(self) -> builtins.str:
        return jsii.get(self, "resourceGroupName")

    @resource_group_name.setter # type: ignore
    def resource_group_name(self, value: builtins.str) -> None:
        jsii.set(self, "resourceGroupName", value)

    @builtins.property # type: ignore
    @jsii.member(jsii_name="id")
    def id(self) -> typing.Optional[builtins.str]:
        return jsii.get(self, "id")

    @id.setter # type: ignore
    def id(self, value: typing.Optional[builtins.str]) -> None:
        jsii.set(self, "id", value)

    @builtins.property # type: ignore
    @jsii.member(jsii_name="timeouts")
    def timeouts(self) -> typing.Optional["DataAzurermDataLakeStoreTimeouts"]:
        return jsii.get(self, "timeouts")

    @timeouts.setter # type: ignore
    def timeouts(
        self,
        value: typing.Optional["DataAzurermDataLakeStoreTimeouts"],
    ) -> None:
        jsii.set(self, "timeouts", value)


@jsii.data_type(
    jsii_type="@cdktf/provider-azurerm.DataAzurermDataLakeStoreConfig",
    jsii_struct_bases=[cdktf.TerraformMetaArguments],
    name_mapping={
        "count": "count",
        "depends_on": "dependsOn",
        "lifecycle": "lifecycle",
        "provider": "provider",
        "name": "name",
        "resource_group_name": "resourceGroupName",
        "timeouts": "timeouts",
    },
)
class DataAzurermDataLakeStoreConfig(cdktf.TerraformMetaArguments):
    def __init__(
        self,
        *,
        count: typing.Optional[jsii.Number] = None,
        depends_on: typing.Optional[typing.List[cdktf.TerraformResource]] = None,
        lifecycle: typing.Optional[cdktf.TerraformResourceLifecycle] = None,
        provider: typing.Optional[cdktf.TerraformProvider] = None,
        name: builtins.str,
        resource_group_name: builtins.str,
        timeouts: typing.Optional["DataAzurermDataLakeStoreTimeouts"] = None,
    ) -> None:
        """
        :param count: 
        :param depends_on: 
        :param lifecycle: 
        :param provider: 
        :param name: 
        :param resource_group_name: 
        :param timeouts: timeouts block.
        """
        if isinstance(lifecycle, dict):
            lifecycle = cdktf.TerraformResourceLifecycle(**lifecycle)
        if isinstance(timeouts, dict):
            timeouts = DataAzurermDataLakeStoreTimeouts(**timeouts)
        self._values: typing.Dict[str, typing.Any] = {
            "name": name,
            "resource_group_name": resource_group_name,
        }
        if count is not None:
            self._values["count"] = count
        if depends_on is not None:
            self._values["depends_on"] = depends_on
        if lifecycle is not None:
            self._values["lifecycle"] = lifecycle
        if provider is not None:
            self._values["provider"] = provider
        if timeouts is not None:
            self._values["timeouts"] = timeouts

    @builtins.property
    def count(self) -> typing.Optional[jsii.Number]:
        """
        :stability: experimental
        """
        result = self._values.get("count")
        return result

    @builtins.property
    def depends_on(self) -> typing.Optional[typing.List[cdktf.TerraformResource]]:
        """
        :stability: experimental
        """
        result = self._values.get("depends_on")
        return result

    @builtins.property
    def lifecycle(self) -> typing.Optional[cdktf.TerraformResourceLifecycle]:
        """
        :stability: experimental
        """
        result = self._values.get("lifecycle")
        return result

    @builtins.property
    def provider(self) -> typing.Optional[cdktf.TerraformProvider]:
        """
        :stability: experimental
        """
        result = self._values.get("provider")
        return result

    @builtins.property
    def name(self) -> builtins.str:
        result = self._values.get("name")
        assert result is not None, "Required property 'name' is missing"
        return result

    @builtins.property
    def resource_group_name(self) -> builtins.str:
        result = self._values.get("resource_group_name")
        assert result is not None, "Required property 'resource_group_name' is missing"
        return result

    @builtins.property
    def timeouts(self) -> typing.Optional["DataAzurermDataLakeStoreTimeouts"]:
        """timeouts block."""
        result = self._values.get("timeouts")
        return result

    def __eq__(self, rhs: typing.Any) -> builtins.bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs: typing.Any) -> builtins.bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return "DataAzurermDataLakeStoreConfig(%s)" % ", ".join(
            k + "=" + repr(v) for k, v in self._values.items()
        )


@jsii.data_type(
    jsii_type="@cdktf/provider-azurerm.DataAzurermDataLakeStoreTimeouts",
    jsii_struct_bases=[],
    name_mapping={"read": "read"},
)
class DataAzurermDataLakeStoreTimeouts:
    def __init__(self, *, read: typing.Optional[builtins.str] = None) -> None:
        """
        :param read: 
        """
        self._values: typing.Dict[str, typing.Any] = {}
        if read is not None:
            self._values["read"] = read

    @builtins.property
    def read(self) -> typing.Optional[builtins.str]:
        result = self._values.get("read")
        return result

    def __eq__(self, rhs: typing.Any) -> builtins.bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs: typing.Any) -> builtins.bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return "DataAzurermDataLakeStoreTimeouts(%s)" % ", ".join(
            k + "=" + repr(v) for k, v in self._values.items()
        )


class DataAzurermDedicatedHost(
    cdktf.TerraformDataSource,
    metaclass=jsii.JSIIMeta,
    jsii_type="@cdktf/provider-azurerm.DataAzurermDedicatedHost",
):
    def __init__(
        self,
        scope: constructs.Construct,
        id: builtins.str,
        *,
        dedicated_host_group_name: builtins.str,
        name: builtins.str,
        resource_group_name: builtins.str,
        timeouts: typing.Optional["DataAzurermDedicatedHostTimeouts"] = None,
        count: typing.Optional[jsii.Number] = None,
        depends_on: typing.Optional[typing.List[cdktf.TerraformResource]] = None,
        lifecycle: typing.Optional[cdktf.TerraformResourceLifecycle] = None,
        provider: typing.Optional[cdktf.TerraformProvider] = None,
    ) -> None:
        """
        :param scope: -
        :param id: -
        :param dedicated_host_group_name: 
        :param name: 
        :param resource_group_name: 
        :param timeouts: timeouts block.
        :param count: 
        :param depends_on: 
        :param lifecycle: 
        :param provider: 
        """
        config = DataAzurermDedicatedHostConfig(
            dedicated_host_group_name=dedicated_host_group_name,
            name=name,
            resource_group_name=resource_group_name,
            timeouts=timeouts,
            count=count,
            depends_on=depends_on,
            lifecycle=lifecycle,
            provider=provider,
        )

        jsii.create(DataAzurermDedicatedHost, self, [scope, id, config])

    @jsii.member(jsii_name="synthesizeAttributes")
    def _synthesize_attributes(self) -> typing.Mapping[builtins.str, typing.Any]:
        return jsii.invoke(self, "synthesizeAttributes", [])

    @jsii.member(jsii_name="tags")
    def tags(self, key: builtins.str) -> builtins.str:
        """
        :param key: -
        """
        return jsii.invoke(self, "tags", [key])

    @builtins.property # type: ignore
    @jsii.member(jsii_name="location")
    def location(self) -> builtins.str:
        return jsii.get(self, "location")

    @builtins.property # type: ignore
    @jsii.member(jsii_name="dedicatedHostGroupName")
    def dedicated_host_group_name(self) -> builtins.str:
        return jsii.get(self, "dedicatedHostGroupName")

    @dedicated_host_group_name.setter # type: ignore
    def dedicated_host_group_name(self, value: builtins.str) -> None:
        jsii.set(self, "dedicatedHostGroupName", value)

    @builtins.property # type: ignore
    @jsii.member(jsii_name="name")
    def name(self) -> builtins.str:
        return jsii.get(self, "name")

    @name.setter # type: ignore
    def name(self, value: builtins.str) -> None:
        jsii.set(self, "name", value)

    @builtins.property # type: ignore
    @jsii.member(jsii_name="resourceGroupName")
    def resource_group_name(self) -> builtins.str:
        return jsii.get(self, "resourceGroupName")

    @resource_group_name.setter # type: ignore
    def resource_group_name(self, value: builtins.str) -> None:
        jsii.set(self, "resourceGroupName", value)

    @builtins.property # type: ignore
    @jsii.member(jsii_name="id")
    def id(self) -> typing.Optional[builtins.str]:
        return jsii.get(self, "id")

    @id.setter # type: ignore
    def id(self, value: typing.Optional[builtins.str]) -> None:
        jsii.set(self, "id", value)

    @builtins.property # type: ignore
    @jsii.member(jsii_name="timeouts")
    def timeouts(self) -> typing.Optional["DataAzurermDedicatedHostTimeouts"]:
        return jsii.get(self, "timeouts")

    @timeouts.setter # type: ignore
    def timeouts(
        self,
        value: typing.Optional["DataAzurermDedicatedHostTimeouts"],
    ) -> None:
        jsii.set(self, "timeouts", value)


@jsii.data_type(
    jsii_type="@cdktf/provider-azurerm.DataAzurermDedicatedHostConfig",
    jsii_struct_bases=[cdktf.TerraformMetaArguments],
    name_mapping={
        "count": "count",
        "depends_on": "dependsOn",
        "lifecycle": "lifecycle",
        "provider": "provider",
        "dedicated_host_group_name": "dedicatedHostGroupName",
        "name": "name",
        "resource_group_name": "resourceGroupName",
        "timeouts": "timeouts",
    },
)
class DataAzurermDedicatedHostConfig(cdktf.TerraformMetaArguments):
    def __init__(
        self,
        *,
        count: typing.Optional[jsii.Number] = None,
        depends_on: typing.Optional[typing.List[cdktf.TerraformResource]] = None,
        lifecycle: typing.Optional[cdktf.TerraformResourceLifecycle] = None,
        provider: typing.Optional[cdktf.TerraformProvider] = None,
        dedicated_host_group_name: builtins.str,
        name: builtins.str,
        resource_group_name: builtins.str,
        timeouts: typing.Optional["DataAzurermDedicatedHostTimeouts"] = None,
    ) -> None:
        """
        :param count: 
        :param depends_on: 
        :param lifecycle: 
        :param provider: 
        :param dedicated_host_group_name: 
        :param name: 
        :param resource_group_name: 
        :param timeouts: timeouts block.
        """
        if isinstance(lifecycle, dict):
            lifecycle = cdktf.TerraformResourceLifecycle(**lifecycle)
        if isinstance(timeouts, dict):
            timeouts = DataAzurermDedicatedHostTimeouts(**timeouts)
        self._values: typing.Dict[str, typing.Any] = {
            "dedicated_host_group_name": dedicated_host_group_name,
            "name": name,
            "resource_group_name": resource_group_name,
        }
        if count is not None:
            self._values["count"] = count
        if depends_on is not None:
            self._values["depends_on"] = depends_on
        if lifecycle is not None:
            self._values["lifecycle"] = lifecycle
        if provider is not None:
            self._values["provider"] = provider
        if timeouts is not None:
            self._values["timeouts"] = timeouts

    @builtins.property
    def count(self) -> typing.Optional[jsii.Number]:
        """
        :stability: experimental
        """
        result = self._values.get("count")
        return result

    @builtins.property
    def depends_on(self) -> typing.Optional[typing.List[cdktf.TerraformResource]]:
        """
        :stability: experimental
        """
        result = self._values.get("depends_on")
        return result

    @builtins.property
    def lifecycle(self) -> typing.Optional[cdktf.TerraformResourceLifecycle]:
        """
        :stability: experimental
        """
        result = self._values.get("lifecycle")
        return result

    @builtins.property
    def provider(self) -> typing.Optional[cdktf.TerraformProvider]:
        """
        :stability: experimental
        """
        result = self._values.get("provider")
        return result

    @builtins.property
    def dedicated_host_group_name(self) -> builtins.str:
        result = self._values.get("dedicated_host_group_name")
        assert result is not None, "Required property 'dedicated_host_group_name' is missing"
        return result

    @builtins.property
    def name(self) -> builtins.str:
        result = self._values.get("name")
        assert result is not None, "Required property 'name' is missing"
        return result

    @builtins.property
    def resource_group_name(self) -> builtins.str:
        result = self._values.get("resource_group_name")
        assert result is not None, "Required property 'resource_group_name' is missing"
        return result

    @builtins.property
    def timeouts(self) -> typing.Optional["DataAzurermDedicatedHostTimeouts"]:
        """timeouts block."""
        result = self._values.get("timeouts")
        return result

    def __eq__(self, rhs: typing.Any) -> builtins.bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs: typing.Any) -> builtins.bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return "DataAzurermDedicatedHostConfig(%s)" % ", ".join(
            k + "=" + repr(v) for k, v in self._values.items()
        )


class DataAzurermDedicatedHostGroup(
    cdktf.TerraformDataSource,
    metaclass=jsii.JSIIMeta,
    jsii_type="@cdktf/provider-azurerm.DataAzurermDedicatedHostGroup",
):
    def __init__(
        self,
        scope: constructs.Construct,
        id: builtins.str,
        *,
        name: builtins.str,
        resource_group_name: builtins.str,
        timeouts: typing.Optional["DataAzurermDedicatedHostGroupTimeouts"] = None,
        count: typing.Optional[jsii.Number] = None,
        depends_on: typing.Optional[typing.List[cdktf.TerraformResource]] = None,
        lifecycle: typing.Optional[cdktf.TerraformResourceLifecycle] = None,
        provider: typing.Optional[cdktf.TerraformProvider] = None,
    ) -> None:
        """
        :param scope: -
        :param id: -
        :param name: 
        :param resource_group_name: 
        :param timeouts: timeouts block.
        :param count: 
        :param depends_on: 
        :param lifecycle: 
        :param provider: 
        """
        config = DataAzurermDedicatedHostGroupConfig(
            name=name,
            resource_group_name=resource_group_name,
            timeouts=timeouts,
            count=count,
            depends_on=depends_on,
            lifecycle=lifecycle,
            provider=provider,
        )

        jsii.create(DataAzurermDedicatedHostGroup, self, [scope, id, config])

    @jsii.member(jsii_name="synthesizeAttributes")
    def _synthesize_attributes(self) -> typing.Mapping[builtins.str, typing.Any]:
        return jsii.invoke(self, "synthesizeAttributes", [])

    @jsii.member(jsii_name="tags")
    def tags(self, key: builtins.str) -> builtins.str:
        """
        :param key: -
        """
        return jsii.invoke(self, "tags", [key])

    @builtins.property # type: ignore
    @jsii.member(jsii_name="location")
    def location(self) -> builtins.str:
        return jsii.get(self, "location")

    @builtins.property # type: ignore
    @jsii.member(jsii_name="platformFaultDomainCount")
    def platform_fault_domain_count(self) -> jsii.Number:
        return jsii.get(self, "platformFaultDomainCount")

    @builtins.property # type: ignore
    @jsii.member(jsii_name="zones")
    def zones(self) -> typing.List[builtins.str]:
        return jsii.get(self, "zones")

    @builtins.property # type: ignore
    @jsii.member(jsii_name="name")
    def name(self) -> builtins.str:
        return jsii.get(self, "name")

    @name.setter # type: ignore
    def name(self, value: builtins.str) -> None:
        jsii.set(self, "name", value)

    @builtins.property # type: ignore
    @jsii.member(jsii_name="resourceGroupName")
    def resource_group_name(self) -> builtins.str:
        return jsii.get(self, "resourceGroupName")

    @resource_group_name.setter # type: ignore
    def resource_group_name(self, value: builtins.str) -> None:
        jsii.set(self, "resourceGroupName", value)

    @builtins.property # type: ignore
    @jsii.member(jsii_name="id")
    def id(self) -> typing.Optional[builtins.str]:
        return jsii.get(self, "id")

    @id.setter # type: ignore
    def id(self, value: typing.Optional[builtins.str]) -> None:
        jsii.set(self, "id", value)

    @builtins.property # type: ignore
    @jsii.member(jsii_name="timeouts")
    def timeouts(self) -> typing.Optional["DataAzurermDedicatedHostGroupTimeouts"]:
        return jsii.get(self, "timeouts")

    @timeouts.setter # type: ignore
    def timeouts(
        self,
        value: typing.Optional["DataAzurermDedicatedHostGroupTimeouts"],
    ) -> None:
        jsii.set(self, "timeouts", value)


@jsii.data_type(
    jsii_type="@cdktf/provider-azurerm.DataAzurermDedicatedHostGroupConfig",
    jsii_struct_bases=[cdktf.TerraformMetaArguments],
    name_mapping={
        "count": "count",
        "depends_on": "dependsOn",
        "lifecycle": "lifecycle",
        "provider": "provider",
        "name": "name",
        "resource_group_name": "resourceGroupName",
        "timeouts": "timeouts",
    },
)
class DataAzurermDedicatedHostGroupConfig(cdktf.TerraformMetaArguments):
    def __init__(
        self,
        *,
        count: typing.Optional[jsii.Number] = None,
        depends_on: typing.Optional[typing.List[cdktf.TerraformResource]] = None,
        lifecycle: typing.Optional[cdktf.TerraformResourceLifecycle] = None,
        provider: typing.Optional[cdktf.TerraformProvider] = None,
        name: builtins.str,
        resource_group_name: builtins.str,
        timeouts: typing.Optional["DataAzurermDedicatedHostGroupTimeouts"] = None,
    ) -> None:
        """
        :param count: 
        :param depends_on: 
        :param lifecycle: 
        :param provider: 
        :param name: 
        :param resource_group_name: 
        :param timeouts: timeouts block.
        """
        if isinstance(lifecycle, dict):
            lifecycle = cdktf.TerraformResourceLifecycle(**lifecycle)
        if isinstance(timeouts, dict):
            timeouts = DataAzurermDedicatedHostGroupTimeouts(**timeouts)
        self._values: typing.Dict[str, typing.Any] = {
            "name": name,
            "resource_group_name": resource_group_name,
        }
        if count is not None:
            self._values["count"] = count
        if depends_on is not None:
            self._values["depends_on"] = depends_on
        if lifecycle is not None:
            self._values["lifecycle"] = lifecycle
        if provider is not None:
            self._values["provider"] = provider
        if timeouts is not None:
            self._values["timeouts"] = timeouts

    @builtins.property
    def count(self) -> typing.Optional[jsii.Number]:
        """
        :stability: experimental
        """
        result = self._values.get("count")
        return result

    @builtins.property
    def depends_on(self) -> typing.Optional[typing.List[cdktf.TerraformResource]]:
        """
        :stability: experimental
        """
        result = self._values.get("depends_on")
        return result

    @builtins.property
    def lifecycle(self) -> typing.Optional[cdktf.TerraformResourceLifecycle]:
        """
        :stability: experimental
        """
        result = self._values.get("lifecycle")
        return result

    @builtins.property
    def provider(self) -> typing.Optional[cdktf.TerraformProvider]:
        """
        :stability: experimental
        """
        result = self._values.get("provider")
        return result

    @builtins.property
    def name(self) -> builtins.str:
        result = self._values.get("name")
        assert result is not None, "Required property 'name' is missing"
        return result

    @builtins.property
    def resource_group_name(self) -> builtins.str:
        result = self._values.get("resource_group_name")
        assert result is not None, "Required property 'resource_group_name' is missing"
        return result

    @builtins.property
    def timeouts(self) -> typing.Optional["DataAzurermDedicatedHostGroupTimeouts"]:
        """timeouts block."""
        result = self._values.get("timeouts")
        return result

    def __eq__(self, rhs: typing.Any) -> builtins.bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs: typing.Any) -> builtins.bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return "DataAzurermDedicatedHostGroupConfig(%s)" % ", ".join(
            k + "=" + repr(v) for k, v in self._values.items()
        )


@jsii.data_type(
    jsii_type="@cdktf/provider-azurerm.DataAzurermDedicatedHostGroupTimeouts",
    jsii_struct_bases=[],
    name_mapping={"read": "read"},
)
class DataAzurermDedicatedHostGroupTimeouts:
    def __init__(self, *, read: typing.Optional[builtins.str] = None) -> None:
        """
        :param read: 
        """
        self._values: typing.Dict[str, typing.Any] = {}
        if read is not None:
            self._values["read"] = read

    @builtins.property
    def read(self) -> typing.Optional[builtins.str]:
        result = self._values.get("read")
        return result

    def __eq__(self, rhs: typing.Any) -> builtins.bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs: typing.Any) -> builtins.bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return "DataAzurermDedicatedHostGroupTimeouts(%s)" % ", ".join(
            k + "=" + repr(v) for k, v in self._values.items()
        )


@jsii.data_type(
    jsii_type="@cdktf/provider-azurerm.DataAzurermDedicatedHostTimeouts",
    jsii_struct_bases=[],
    name_mapping={"read": "read"},
)
class DataAzurermDedicatedHostTimeouts:
    def __init__(self, *, read: typing.Optional[builtins.str] = None) -> None:
        """
        :param read: 
        """
        self._values: typing.Dict[str, typing.Any] = {}
        if read is not None:
            self._values["read"] = read

    @builtins.property
    def read(self) -> typing.Optional[builtins.str]:
        result = self._values.get("read")
        return result

    def __eq__(self, rhs: typing.Any) -> builtins.bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs: typing.Any) -> builtins.bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return "DataAzurermDedicatedHostTimeouts(%s)" % ", ".join(
            k + "=" + repr(v) for k, v in self._values.items()
        )


class DataAzurermDevTestLab(
    cdktf.TerraformDataSource,
    metaclass=jsii.JSIIMeta,
    jsii_type="@cdktf/provider-azurerm.DataAzurermDevTestLab",
):
    def __init__(
        self,
        scope: constructs.Construct,
        id: builtins.str,
        *,
        name: builtins.str,
        resource_group_name: builtins.str,
        timeouts: typing.Optional["DataAzurermDevTestLabTimeouts"] = None,
        count: typing.Optional[jsii.Number] = None,
        depends_on: typing.Optional[typing.List[cdktf.TerraformResource]] = None,
        lifecycle: typing.Optional[cdktf.TerraformResourceLifecycle] = None,
        provider: typing.Optional[cdktf.TerraformProvider] = None,
    ) -> None:
        """
        :param scope: -
        :param id: -
        :param name: 
        :param resource_group_name: 
        :param timeouts: timeouts block.
        :param count: 
        :param depends_on: 
        :param lifecycle: 
        :param provider: 
        """
        config = DataAzurermDevTestLabConfig(
            name=name,
            resource_group_name=resource_group_name,
            timeouts=timeouts,
            count=count,
            depends_on=depends_on,
            lifecycle=lifecycle,
            provider=provider,
        )

        jsii.create(DataAzurermDevTestLab, self, [scope, id, config])

    @jsii.member(jsii_name="synthesizeAttributes")
    def _synthesize_attributes(self) -> typing.Mapping[builtins.str, typing.Any]:
        return jsii.invoke(self, "synthesizeAttributes", [])

    @jsii.member(jsii_name="tags")
    def tags(self, key: builtins.str) -> builtins.str:
        """
        :param key: -
        """
        return jsii.invoke(self, "tags", [key])

    @builtins.property # type: ignore
    @jsii.member(jsii_name="artifactsStorageAccountId")
    def artifacts_storage_account_id(self) -> builtins.str:
        return jsii.get(self, "artifactsStorageAccountId")

    @builtins.property # type: ignore
    @jsii.member(jsii_name="defaultPremiumStorageAccountId")
    def default_premium_storage_account_id(self) -> builtins.str:
        return jsii.get(self, "defaultPremiumStorageAccountId")

    @builtins.property # type: ignore
    @jsii.member(jsii_name="defaultStorageAccountId")
    def default_storage_account_id(self) -> builtins.str:
        return jsii.get(self, "defaultStorageAccountId")

    @builtins.property # type: ignore
    @jsii.member(jsii_name="keyVaultId")
    def key_vault_id(self) -> builtins.str:
        return jsii.get(self, "keyVaultId")

    @builtins.property # type: ignore
    @jsii.member(jsii_name="location")
    def location(self) -> builtins.str:
        return jsii.get(self, "location")

    @builtins.property # type: ignore
    @jsii.member(jsii_name="premiumDataDiskStorageAccountId")
    def premium_data_disk_storage_account_id(self) -> builtins.str:
        return jsii.get(self, "premiumDataDiskStorageAccountId")

    @builtins.property # type: ignore
    @jsii.member(jsii_name="storageType")
    def storage_type(self) -> builtins.str:
        return jsii.get(self, "storageType")

    @builtins.property # type: ignore
    @jsii.member(jsii_name="uniqueIdentifier")
    def unique_identifier(self) -> builtins.str:
        return jsii.get(self, "uniqueIdentifier")

    @builtins.property # type: ignore
    @jsii.member(jsii_name="name")
    def name(self) -> builtins.str:
        return jsii.get(self, "name")

    @name.setter # type: ignore
    def name(self, value: builtins.str) -> None:
        jsii.set(self, "name", value)

    @builtins.property # type: ignore
    @jsii.member(jsii_name="resourceGroupName")
    def resource_group_name(self) -> builtins.str:
        return jsii.get(self, "resourceGroupName")

    @resource_group_name.setter # type: ignore
    def resource_group_name(self, value: builtins.str) -> None:
        jsii.set(self, "resourceGroupName", value)

    @builtins.property # type: ignore
    @jsii.member(jsii_name="id")
    def id(self) -> typing.Optional[builtins.str]:
        return jsii.get(self, "id")

    @id.setter # type: ignore
    def id(self, value: typing.Optional[builtins.str]) -> None:
        jsii.set(self, "id", value)

    @builtins.property # type: ignore
    @jsii.member(jsii_name="timeouts")
    def timeouts(self) -> typing.Optional["DataAzurermDevTestLabTimeouts"]:
        return jsii.get(self, "timeouts")

    @timeouts.setter # type: ignore
    def timeouts(self, value: typing.Optional["DataAzurermDevTestLabTimeouts"]) -> None:
        jsii.set(self, "timeouts", value)


@jsii.data_type(
    jsii_type="@cdktf/provider-azurerm.DataAzurermDevTestLabConfig",
    jsii_struct_bases=[cdktf.TerraformMetaArguments],
    name_mapping={
        "count": "count",
        "depends_on": "dependsOn",
        "lifecycle": "lifecycle",
        "provider": "provider",
        "name": "name",
        "resource_group_name": "resourceGroupName",
        "timeouts": "timeouts",
    },
)
class DataAzurermDevTestLabConfig(cdktf.TerraformMetaArguments):
    def __init__(
        self,
        *,
        count: typing.Optional[jsii.Number] = None,
        depends_on: typing.Optional[typing.List[cdktf.TerraformResource]] = None,
        lifecycle: typing.Optional[cdktf.TerraformResourceLifecycle] = None,
        provider: typing.Optional[cdktf.TerraformProvider] = None,
        name: builtins.str,
        resource_group_name: builtins.str,
        timeouts: typing.Optional["DataAzurermDevTestLabTimeouts"] = None,
    ) -> None:
        """
        :param count: 
        :param depends_on: 
        :param lifecycle: 
        :param provider: 
        :param name: 
        :param resource_group_name: 
        :param timeouts: timeouts block.
        """
        if isinstance(lifecycle, dict):
            lifecycle = cdktf.TerraformResourceLifecycle(**lifecycle)
        if isinstance(timeouts, dict):
            timeouts = DataAzurermDevTestLabTimeouts(**timeouts)
        self._values: typing.Dict[str, typing.Any] = {
            "name": name,
            "resource_group_name": resource_group_name,
        }
        if count is not None:
            self._values["count"] = count
        if depends_on is not None:
            self._values["depends_on"] = depends_on
        if lifecycle is not None:
            self._values["lifecycle"] = lifecycle
        if provider is not None:
            self._values["provider"] = provider
        if timeouts is not None:
            self._values["timeouts"] = timeouts

    @builtins.property
    def count(self) -> typing.Optional[jsii.Number]:
        """
        :stability: experimental
        """
        result = self._values.get("count")
        return result

    @builtins.property
    def depends_on(self) -> typing.Optional[typing.List[cdktf.TerraformResource]]:
        """
        :stability: experimental
        """
        result = self._values.get("depends_on")
        return result

    @builtins.property
    def lifecycle(self) -> typing.Optional[cdktf.TerraformResourceLifecycle]:
        """
        :stability: experimental
        """
        result = self._values.get("lifecycle")
        return result

    @builtins.property
    def provider(self) -> typing.Optional[cdktf.TerraformProvider]:
        """
        :stability: experimental
        """
        result = self._values.get("provider")
        return result

    @builtins.property
    def name(self) -> builtins.str:
        result = self._values.get("name")
        assert result is not None, "Required property 'name' is missing"
        return result

    @builtins.property
    def resource_group_name(self) -> builtins.str:
        result = self._values.get("resource_group_name")
        assert result is not None, "Required property 'resource_group_name' is missing"
        return result

    @builtins.property
    def timeouts(self) -> typing.Optional["DataAzurermDevTestLabTimeouts"]:
        """timeouts block."""
        result = self._values.get("timeouts")
        return result

    def __eq__(self, rhs: typing.Any) -> builtins.bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs: typing.Any) -> builtins.bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return "DataAzurermDevTestLabConfig(%s)" % ", ".join(
            k + "=" + repr(v) for k, v in self._values.items()
        )


@jsii.data_type(
    jsii_type="@cdktf/provider-azurerm.DataAzurermDevTestLabTimeouts",
    jsii_struct_bases=[],
    name_mapping={"read": "read"},
)
class DataAzurermDevTestLabTimeouts:
    def __init__(self, *, read: typing.Optional[builtins.str] = None) -> None:
        """
        :param read: 
        """
        self._values: typing.Dict[str, typing.Any] = {}
        if read is not None:
            self._values["read"] = read

    @builtins.property
    def read(self) -> typing.Optional[builtins.str]:
        result = self._values.get("read")
        return result

    def __eq__(self, rhs: typing.Any) -> builtins.bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs: typing.Any) -> builtins.bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return "DataAzurermDevTestLabTimeouts(%s)" % ", ".join(
            k + "=" + repr(v) for k, v in self._values.items()
        )


class DataAzurermDevTestVirtualNetwork(
    cdktf.TerraformDataSource,
    metaclass=jsii.JSIIMeta,
    jsii_type="@cdktf/provider-azurerm.DataAzurermDevTestVirtualNetwork",
):
    def __init__(
        self,
        scope: constructs.Construct,
        id: builtins.str,
        *,
        lab_name: builtins.str,
        name: builtins.str,
        resource_group_name: builtins.str,
        timeouts: typing.Optional["DataAzurermDevTestVirtualNetworkTimeouts"] = None,
        count: typing.Optional[jsii.Number] = None,
        depends_on: typing.Optional[typing.List[cdktf.TerraformResource]] = None,
        lifecycle: typing.Optional[cdktf.TerraformResourceLifecycle] = None,
        provider: typing.Optional[cdktf.TerraformProvider] = None,
    ) -> None:
        """
        :param scope: -
        :param id: -
        :param lab_name: 
        :param name: 
        :param resource_group_name: 
        :param timeouts: timeouts block.
        :param count: 
        :param depends_on: 
        :param lifecycle: 
        :param provider: 
        """
        config = DataAzurermDevTestVirtualNetworkConfig(
            lab_name=lab_name,
            name=name,
            resource_group_name=resource_group_name,
            timeouts=timeouts,
            count=count,
            depends_on=depends_on,
            lifecycle=lifecycle,
            provider=provider,
        )

        jsii.create(DataAzurermDevTestVirtualNetwork, self, [scope, id, config])

    @jsii.member(jsii_name="allowedSubnets")
    def allowed_subnets(
        self,
        index: builtins.str,
    ) -> "DataAzurermDevTestVirtualNetworkAllowedSubnets":
        """
        :param index: -
        """
        return jsii.invoke(self, "allowedSubnets", [index])

    @jsii.member(jsii_name="subnetOverrides")
    def subnet_overrides(
        self,
        index: builtins.str,
    ) -> "DataAzurermDevTestVirtualNetworkSubnetOverrides":
        """
        :param index: -
        """
        return jsii.invoke(self, "subnetOverrides", [index])

    @jsii.member(jsii_name="synthesizeAttributes")
    def _synthesize_attributes(self) -> typing.Mapping[builtins.str, typing.Any]:
        return jsii.invoke(self, "synthesizeAttributes", [])

    @builtins.property # type: ignore
    @jsii.member(jsii_name="uniqueIdentifier")
    def unique_identifier(self) -> builtins.str:
        return jsii.get(self, "uniqueIdentifier")

    @builtins.property # type: ignore
    @jsii.member(jsii_name="labName")
    def lab_name(self) -> builtins.str:
        return jsii.get(self, "labName")

    @lab_name.setter # type: ignore
    def lab_name(self, value: builtins.str) -> None:
        jsii.set(self, "labName", value)

    @builtins.property # type: ignore
    @jsii.member(jsii_name="name")
    def name(self) -> builtins.str:
        return jsii.get(self, "name")

    @name.setter # type: ignore
    def name(self, value: builtins.str) -> None:
        jsii.set(self, "name", value)

    @builtins.property # type: ignore
    @jsii.member(jsii_name="resourceGroupName")
    def resource_group_name(self) -> builtins.str:
        return jsii.get(self, "resourceGroupName")

    @resource_group_name.setter # type: ignore
    def resource_group_name(self, value: builtins.str) -> None:
        jsii.set(self, "resourceGroupName", value)

    @builtins.property # type: ignore
    @jsii.member(jsii_name="id")
    def id(self) -> typing.Optional[builtins.str]:
        return jsii.get(self, "id")

    @id.setter # type: ignore
    def id(self, value: typing.Optional[builtins.str]) -> None:
        jsii.set(self, "id", value)

    @builtins.property # type: ignore
    @jsii.member(jsii_name="timeouts")
    def timeouts(self) -> typing.Optional["DataAzurermDevTestVirtualNetworkTimeouts"]:
        return jsii.get(self, "timeouts")

    @timeouts.setter # type: ignore
    def timeouts(
        self,
        value: typing.Optional["DataAzurermDevTestVirtualNetworkTimeouts"],
    ) -> None:
        jsii.set(self, "timeouts", value)


class DataAzurermDevTestVirtualNetworkAllowedSubnets(
    cdktf.ComplexComputedList,
    metaclass=jsii.JSIIMeta,
    jsii_type="@cdktf/provider-azurerm.DataAzurermDevTestVirtualNetworkAllowedSubnets",
):
    def __init__(
        self,
        terraform_resource: cdktf.ITerraformResource,
        terraform_attribute: builtins.str,
        index: builtins.str,
    ) -> None:
        """
        :param terraform_resource: -
        :param terraform_attribute: -
        :param index: -

        :stability: experimental
        """
        jsii.create(DataAzurermDevTestVirtualNetworkAllowedSubnets, self, [terraform_resource, terraform_attribute, index])

    @builtins.property # type: ignore
    @jsii.member(jsii_name="allowPublicIp")
    def allow_public_ip(self) -> builtins.str:
        return jsii.get(self, "allowPublicIp")

    @builtins.property # type: ignore
    @jsii.member(jsii_name="labSubnetName")
    def lab_subnet_name(self) -> builtins.str:
        return jsii.get(self, "labSubnetName")

    @builtins.property # type: ignore
    @jsii.member(jsii_name="resourceId")
    def resource_id(self) -> builtins.str:
        return jsii.get(self, "resourceId")


@jsii.data_type(
    jsii_type="@cdktf/provider-azurerm.DataAzurermDevTestVirtualNetworkConfig",
    jsii_struct_bases=[cdktf.TerraformMetaArguments],
    name_mapping={
        "count": "count",
        "depends_on": "dependsOn",
        "lifecycle": "lifecycle",
        "provider": "provider",
        "lab_name": "labName",
        "name": "name",
        "resource_group_name": "resourceGroupName",
        "timeouts": "timeouts",
    },
)
class DataAzurermDevTestVirtualNetworkConfig(cdktf.TerraformMetaArguments):
    def __init__(
        self,
        *,
        count: typing.Optional[jsii.Number] = None,
        depends_on: typing.Optional[typing.List[cdktf.TerraformResource]] = None,
        lifecycle: typing.Optional[cdktf.TerraformResourceLifecycle] = None,
        provider: typing.Optional[cdktf.TerraformProvider] = None,
        lab_name: builtins.str,
        name: builtins.str,
        resource_group_name: builtins.str,
        timeouts: typing.Optional["DataAzurermDevTestVirtualNetworkTimeouts"] = None,
    ) -> None:
        """
        :param count: 
        :param depends_on: 
        :param lifecycle: 
        :param provider: 
        :param lab_name: 
        :param name: 
        :param resource_group_name: 
        :param timeouts: timeouts block.
        """
        if isinstance(lifecycle, dict):
            lifecycle = cdktf.TerraformResourceLifecycle(**lifecycle)
        if isinstance(timeouts, dict):
            timeouts = DataAzurermDevTestVirtualNetworkTimeouts(**timeouts)
        self._values: typing.Dict[str, typing.Any] = {
            "lab_name": lab_name,
            "name": name,
            "resource_group_name": resource_group_name,
        }
        if count is not None:
            self._values["count"] = count
        if depends_on is not None:
            self._values["depends_on"] = depends_on
        if lifecycle is not None:
            self._values["lifecycle"] = lifecycle
        if provider is not None:
            self._values["provider"] = provider
        if timeouts is not None:
            self._values["timeouts"] = timeouts

    @builtins.property
    def count(self) -> typing.Optional[jsii.Number]:
        """
        :stability: experimental
        """
        result = self._values.get("count")
        return result

    @builtins.property
    def depends_on(self) -> typing.Optional[typing.List[cdktf.TerraformResource]]:
        """
        :stability: experimental
        """
        result = self._values.get("depends_on")
        return result

    @builtins.property
    def lifecycle(self) -> typing.Optional[cdktf.TerraformResourceLifecycle]:
        """
        :stability: experimental
        """
        result = self._values.get("lifecycle")
        return result

    @builtins.property
    def provider(self) -> typing.Optional[cdktf.TerraformProvider]:
        """
        :stability: experimental
        """
        result = self._values.get("provider")
        return result

    @builtins.property
    def lab_name(self) -> builtins.str:
        result = self._values.get("lab_name")
        assert result is not None, "Required property 'lab_name' is missing"
        return result

    @builtins.property
    def name(self) -> builtins.str:
        result = self._values.get("name")
        assert result is not None, "Required property 'name' is missing"
        return result

    @builtins.property
    def resource_group_name(self) -> builtins.str:
        result = self._values.get("resource_group_name")
        assert result is not None, "Required property 'resource_group_name' is missing"
        return result

    @builtins.property
    def timeouts(self) -> typing.Optional["DataAzurermDevTestVirtualNetworkTimeouts"]:
        """timeouts block."""
        result = self._values.get("timeouts")
        return result

    def __eq__(self, rhs: typing.Any) -> builtins.bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs: typing.Any) -> builtins.bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return "DataAzurermDevTestVirtualNetworkConfig(%s)" % ", ".join(
            k + "=" + repr(v) for k, v in self._values.items()
        )


class DataAzurermDevTestVirtualNetworkSubnetOverrides(
    cdktf.ComplexComputedList,
    metaclass=jsii.JSIIMeta,
    jsii_type="@cdktf/provider-azurerm.DataAzurermDevTestVirtualNetworkSubnetOverrides",
):
    def __init__(
        self,
        terraform_resource: cdktf.ITerraformResource,
        terraform_attribute: builtins.str,
        index: builtins.str,
    ) -> None:
        """
        :param terraform_resource: -
        :param terraform_attribute: -
        :param index: -

        :stability: experimental
        """
        jsii.create(DataAzurermDevTestVirtualNetworkSubnetOverrides, self, [terraform_resource, terraform_attribute, index])

    @builtins.property # type: ignore
    @jsii.member(jsii_name="labSubnetName")
    def lab_subnet_name(self) -> builtins.str:
        return jsii.get(self, "labSubnetName")

    @builtins.property # type: ignore
    @jsii.member(jsii_name="resourceId")
    def resource_id(self) -> builtins.str:
        return jsii.get(self, "resourceId")

    @builtins.property # type: ignore
    @jsii.member(jsii_name="useInVmCreationPermission")
    def use_in_vm_creation_permission(self) -> builtins.str:
        return jsii.get(self, "useInVmCreationPermission")

    @builtins.property # type: ignore
    @jsii.member(jsii_name="usePublicIpAddressPermission")
    def use_public_ip_address_permission(self) -> builtins.str:
        return jsii.get(self, "usePublicIpAddressPermission")

    @builtins.property # type: ignore
    @jsii.member(jsii_name="virtualNetworkPoolName")
    def virtual_network_pool_name(self) -> builtins.str:
        return jsii.get(self, "virtualNetworkPoolName")


@jsii.data_type(
    jsii_type="@cdktf/provider-azurerm.DataAzurermDevTestVirtualNetworkTimeouts",
    jsii_struct_bases=[],
    name_mapping={"read": "read"},
)
class DataAzurermDevTestVirtualNetworkTimeouts:
    def __init__(self, *, read: typing.Optional[builtins.str] = None) -> None:
        """
        :param read: 
        """
        self._values: typing.Dict[str, typing.Any] = {}
        if read is not None:
            self._values["read"] = read

    @builtins.property
    def read(self) -> typing.Optional[builtins.str]:
        result = self._values.get("read")
        return result

    def __eq__(self, rhs: typing.Any) -> builtins.bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs: typing.Any) -> builtins.bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return "DataAzurermDevTestVirtualNetworkTimeouts(%s)" % ", ".join(
            k + "=" + repr(v) for k, v in self._values.items()
        )


class DataAzurermDiskEncryptionSet(
    cdktf.TerraformDataSource,
    metaclass=jsii.JSIIMeta,
    jsii_type="@cdktf/provider-azurerm.DataAzurermDiskEncryptionSet",
):
    def __init__(
        self,
        scope: constructs.Construct,
        id: builtins.str,
        *,
        name: builtins.str,
        resource_group_name: builtins.str,
        timeouts: typing.Optional["DataAzurermDiskEncryptionSetTimeouts"] = None,
        count: typing.Optional[jsii.Number] = None,
        depends_on: typing.Optional[typing.List[cdktf.TerraformResource]] = None,
        lifecycle: typing.Optional[cdktf.TerraformResourceLifecycle] = None,
        provider: typing.Optional[cdktf.TerraformProvider] = None,
    ) -> None:
        """
        :param scope: -
        :param id: -
        :param name: 
        :param resource_group_name: 
        :param timeouts: timeouts block.
        :param count: 
        :param depends_on: 
        :param lifecycle: 
        :param provider: 
        """
        config = DataAzurermDiskEncryptionSetConfig(
            name=name,
            resource_group_name=resource_group_name,
            timeouts=timeouts,
            count=count,
            depends_on=depends_on,
            lifecycle=lifecycle,
            provider=provider,
        )

        jsii.create(DataAzurermDiskEncryptionSet, self, [scope, id, config])

    @jsii.member(jsii_name="synthesizeAttributes")
    def _synthesize_attributes(self) -> typing.Mapping[builtins.str, typing.Any]:
        return jsii.invoke(self, "synthesizeAttributes", [])

    @jsii.member(jsii_name="tags")
    def tags(self, key: builtins.str) -> builtins.str:
        """
        :param key: -
        """
        return jsii.invoke(self, "tags", [key])

    @builtins.property # type: ignore
    @jsii.member(jsii_name="location")
    def location(self) -> builtins.str:
        return jsii.get(self, "location")

    @builtins.property # type: ignore
    @jsii.member(jsii_name="name")
    def name(self) -> builtins.str:
        return jsii.get(self, "name")

    @name.setter # type: ignore
    def name(self, value: builtins.str) -> None:
        jsii.set(self, "name", value)

    @builtins.property # type: ignore
    @jsii.member(jsii_name="resourceGroupName")
    def resource_group_name(self) -> builtins.str:
        return jsii.get(self, "resourceGroupName")

    @resource_group_name.setter # type: ignore
    def resource_group_name(self, value: builtins.str) -> None:
        jsii.set(self, "resourceGroupName", value)

    @builtins.property # type: ignore
    @jsii.member(jsii_name="id")
    def id(self) -> typing.Optional[builtins.str]:
        return jsii.get(self, "id")

    @id.setter # type: ignore
    def id(self, value: typing.Optional[builtins.str]) -> None:
        jsii.set(self, "id", value)

    @builtins.property # type: ignore
    @jsii.member(jsii_name="timeouts")
    def timeouts(self) -> typing.Optional["DataAzurermDiskEncryptionSetTimeouts"]:
        return jsii.get(self, "timeouts")

    @timeouts.setter # type: ignore
    def timeouts(
        self,
        value: typing.Optional["DataAzurermDiskEncryptionSetTimeouts"],
    ) -> None:
        jsii.set(self, "timeouts", value)


@jsii.data_type(
    jsii_type="@cdktf/provider-azurerm.DataAzurermDiskEncryptionSetConfig",
    jsii_struct_bases=[cdktf.TerraformMetaArguments],
    name_mapping={
        "count": "count",
        "depends_on": "dependsOn",
        "lifecycle": "lifecycle",
        "provider": "provider",
        "name": "name",
        "resource_group_name": "resourceGroupName",
        "timeouts": "timeouts",
    },
)
class DataAzurermDiskEncryptionSetConfig(cdktf.TerraformMetaArguments):
    def __init__(
        self,
        *,
        count: typing.Optional[jsii.Number] = None,
        depends_on: typing.Optional[typing.List[cdktf.TerraformResource]] = None,
        lifecycle: typing.Optional[cdktf.TerraformResourceLifecycle] = None,
        provider: typing.Optional[cdktf.TerraformProvider] = None,
        name: builtins.str,
        resource_group_name: builtins.str,
        timeouts: typing.Optional["DataAzurermDiskEncryptionSetTimeouts"] = None,
    ) -> None:
        """
        :param count: 
        :param depends_on: 
        :param lifecycle: 
        :param provider: 
        :param name: 
        :param resource_group_name: 
        :param timeouts: timeouts block.
        """
        if isinstance(lifecycle, dict):
            lifecycle = cdktf.TerraformResourceLifecycle(**lifecycle)
        if isinstance(timeouts, dict):
            timeouts = DataAzurermDiskEncryptionSetTimeouts(**timeouts)
        self._values: typing.Dict[str, typing.Any] = {
            "name": name,
            "resource_group_name": resource_group_name,
        }
        if count is not None:
            self._values["count"] = count
        if depends_on is not None:
            self._values["depends_on"] = depends_on
        if lifecycle is not None:
            self._values["lifecycle"] = lifecycle
        if provider is not None:
            self._values["provider"] = provider
        if timeouts is not None:
            self._values["timeouts"] = timeouts

    @builtins.property
    def count(self) -> typing.Optional[jsii.Number]:
        """
        :stability: experimental
        """
        result = self._values.get("count")
        return result

    @builtins.property
    def depends_on(self) -> typing.Optional[typing.List[cdktf.TerraformResource]]:
        """
        :stability: experimental
        """
        result = self._values.get("depends_on")
        return result

    @builtins.property
    def lifecycle(self) -> typing.Optional[cdktf.TerraformResourceLifecycle]:
        """
        :stability: experimental
        """
        result = self._values.get("lifecycle")
        return result

    @builtins.property
    def provider(self) -> typing.Optional[cdktf.TerraformProvider]:
        """
        :stability: experimental
        """
        result = self._values.get("provider")
        return result

    @builtins.property
    def name(self) -> builtins.str:
        result = self._values.get("name")
        assert result is not None, "Required property 'name' is missing"
        return result

    @builtins.property
    def resource_group_name(self) -> builtins.str:
        result = self._values.get("resource_group_name")
        assert result is not None, "Required property 'resource_group_name' is missing"
        return result

    @builtins.property
    def timeouts(self) -> typing.Optional["DataAzurermDiskEncryptionSetTimeouts"]:
        """timeouts block."""
        result = self._values.get("timeouts")
        return result

    def __eq__(self, rhs: typing.Any) -> builtins.bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs: typing.Any) -> builtins.bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return "DataAzurermDiskEncryptionSetConfig(%s)" % ", ".join(
            k + "=" + repr(v) for k, v in self._values.items()
        )


@jsii.data_type(
    jsii_type="@cdktf/provider-azurerm.DataAzurermDiskEncryptionSetTimeouts",
    jsii_struct_bases=[],
    name_mapping={"read": "read"},
)
class DataAzurermDiskEncryptionSetTimeouts:
    def __init__(self, *, read: typing.Optional[builtins.str] = None) -> None:
        """
        :param read: 
        """
        self._values: typing.Dict[str, typing.Any] = {}
        if read is not None:
            self._values["read"] = read

    @builtins.property
    def read(self) -> typing.Optional[builtins.str]:
        result = self._values.get("read")
        return result

    def __eq__(self, rhs: typing.Any) -> builtins.bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs: typing.Any) -> builtins.bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return "DataAzurermDiskEncryptionSetTimeouts(%s)" % ", ".join(
            k + "=" + repr(v) for k, v in self._values.items()
        )


class DataAzurermDnsZone(
    cdktf.TerraformDataSource,
    metaclass=jsii.JSIIMeta,
    jsii_type="@cdktf/provider-azurerm.DataAzurermDnsZone",
):
    def __init__(
        self,
        scope: constructs.Construct,
        id: builtins.str,
        *,
        name: builtins.str,
        resource_group_name: typing.Optional[builtins.str] = None,
        timeouts: typing.Optional["DataAzurermDnsZoneTimeouts"] = None,
        count: typing.Optional[jsii.Number] = None,
        depends_on: typing.Optional[typing.List[cdktf.TerraformResource]] = None,
        lifecycle: typing.Optional[cdktf.TerraformResourceLifecycle] = None,
        provider: typing.Optional[cdktf.TerraformProvider] = None,
    ) -> None:
        """
        :param scope: -
        :param id: -
        :param name: 
        :param resource_group_name: 
        :param timeouts: timeouts block.
        :param count: 
        :param depends_on: 
        :param lifecycle: 
        :param provider: 
        """
        config = DataAzurermDnsZoneConfig(
            name=name,
            resource_group_name=resource_group_name,
            timeouts=timeouts,
            count=count,
            depends_on=depends_on,
            lifecycle=lifecycle,
            provider=provider,
        )

        jsii.create(DataAzurermDnsZone, self, [scope, id, config])

    @jsii.member(jsii_name="synthesizeAttributes")
    def _synthesize_attributes(self) -> typing.Mapping[builtins.str, typing.Any]:
        return jsii.invoke(self, "synthesizeAttributes", [])

    @jsii.member(jsii_name="tags")
    def tags(self, key: builtins.str) -> builtins.str:
        """
        :param key: -
        """
        return jsii.invoke(self, "tags", [key])

    @builtins.property # type: ignore
    @jsii.member(jsii_name="maxNumberOfRecordSets")
    def max_number_of_record_sets(self) -> jsii.Number:
        return jsii.get(self, "maxNumberOfRecordSets")

    @builtins.property # type: ignore
    @jsii.member(jsii_name="nameServers")
    def name_servers(self) -> typing.List[builtins.str]:
        return jsii.get(self, "nameServers")

    @builtins.property # type: ignore
    @jsii.member(jsii_name="numberOfRecordSets")
    def number_of_record_sets(self) -> jsii.Number:
        return jsii.get(self, "numberOfRecordSets")

    @builtins.property # type: ignore
    @jsii.member(jsii_name="name")
    def name(self) -> builtins.str:
        return jsii.get(self, "name")

    @name.setter # type: ignore
    def name(self, value: builtins.str) -> None:
        jsii.set(self, "name", value)

    @builtins.property # type: ignore
    @jsii.member(jsii_name="id")
    def id(self) -> typing.Optional[builtins.str]:
        return jsii.get(self, "id")

    @id.setter # type: ignore
    def id(self, value: typing.Optional[builtins.str]) -> None:
        jsii.set(self, "id", value)

    @builtins.property # type: ignore
    @jsii.member(jsii_name="resourceGroupName")
    def resource_group_name(self) -> typing.Optional[builtins.str]:
        return jsii.get(self, "resourceGroupName")

    @resource_group_name.setter # type: ignore
    def resource_group_name(self, value: typing.Optional[builtins.str]) -> None:
        jsii.set(self, "resourceGroupName", value)

    @builtins.property # type: ignore
    @jsii.member(jsii_name="timeouts")
    def timeouts(self) -> typing.Optional["DataAzurermDnsZoneTimeouts"]:
        return jsii.get(self, "timeouts")

    @timeouts.setter # type: ignore
    def timeouts(self, value: typing.Optional["DataAzurermDnsZoneTimeouts"]) -> None:
        jsii.set(self, "timeouts", value)


@jsii.data_type(
    jsii_type="@cdktf/provider-azurerm.DataAzurermDnsZoneConfig",
    jsii_struct_bases=[cdktf.TerraformMetaArguments],
    name_mapping={
        "count": "count",
        "depends_on": "dependsOn",
        "lifecycle": "lifecycle",
        "provider": "provider",
        "name": "name",
        "resource_group_name": "resourceGroupName",
        "timeouts": "timeouts",
    },
)
class DataAzurermDnsZoneConfig(cdktf.TerraformMetaArguments):
    def __init__(
        self,
        *,
        count: typing.Optional[jsii.Number] = None,
        depends_on: typing.Optional[typing.List[cdktf.TerraformResource]] = None,
        lifecycle: typing.Optional[cdktf.TerraformResourceLifecycle] = None,
        provider: typing.Optional[cdktf.TerraformProvider] = None,
        name: builtins.str,
        resource_group_name: typing.Optional[builtins.str] = None,
        timeouts: typing.Optional["DataAzurermDnsZoneTimeouts"] = None,
    ) -> None:
        """
        :param count: 
        :param depends_on: 
        :param lifecycle: 
        :param provider: 
        :param name: 
        :param resource_group_name: 
        :param timeouts: timeouts block.
        """
        if isinstance(lifecycle, dict):
            lifecycle = cdktf.TerraformResourceLifecycle(**lifecycle)
        if isinstance(timeouts, dict):
            timeouts = DataAzurermDnsZoneTimeouts(**timeouts)
        self._values: typing.Dict[str, typing.Any] = {
            "name": name,
        }
        if count is not None:
            self._values["count"] = count
        if depends_on is not None:
            self._values["depends_on"] = depends_on
        if lifecycle is not None:
            self._values["lifecycle"] = lifecycle
        if provider is not None:
            self._values["provider"] = provider
        if resource_group_name is not None:
            self._values["resource_group_name"] = resource_group_name
        if timeouts is not None:
            self._values["timeouts"] = timeouts

    @builtins.property
    def count(self) -> typing.Optional[jsii.Number]:
        """
        :stability: experimental
        """
        result = self._values.get("count")
        return result

    @builtins.property
    def depends_on(self) -> typing.Optional[typing.List[cdktf.TerraformResource]]:
        """
        :stability: experimental
        """
        result = self._values.get("depends_on")
        return result

    @builtins.property
    def lifecycle(self) -> typing.Optional[cdktf.TerraformResourceLifecycle]:
        """
        :stability: experimental
        """
        result = self._values.get("lifecycle")
        return result

    @builtins.property
    def provider(self) -> typing.Optional[cdktf.TerraformProvider]:
        """
        :stability: experimental
        """
        result = self._values.get("provider")
        return result

    @builtins.property
    def name(self) -> builtins.str:
        result = self._values.get("name")
        assert result is not None, "Required property 'name' is missing"
        return result

    @builtins.property
    def resource_group_name(self) -> typing.Optional[builtins.str]:
        result = self._values.get("resource_group_name")
        return result

    @builtins.property
    def timeouts(self) -> typing.Optional["DataAzurermDnsZoneTimeouts"]:
        """timeouts block."""
        result = self._values.get("timeouts")
        return result

    def __eq__(self, rhs: typing.Any) -> builtins.bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs: typing.Any) -> builtins.bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return "DataAzurermDnsZoneConfig(%s)" % ", ".join(
            k + "=" + repr(v) for k, v in self._values.items()
        )


@jsii.data_type(
    jsii_type="@cdktf/provider-azurerm.DataAzurermDnsZoneTimeouts",
    jsii_struct_bases=[],
    name_mapping={"read": "read"},
)
class DataAzurermDnsZoneTimeouts:
    def __init__(self, *, read: typing.Optional[builtins.str] = None) -> None:
        """
        :param read: 
        """
        self._values: typing.Dict[str, typing.Any] = {}
        if read is not None:
            self._values["read"] = read

    @builtins.property
    def read(self) -> typing.Optional[builtins.str]:
        result = self._values.get("read")
        return result

    def __eq__(self, rhs: typing.Any) -> builtins.bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs: typing.Any) -> builtins.bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return "DataAzurermDnsZoneTimeouts(%s)" % ", ".join(
            k + "=" + repr(v) for k, v in self._values.items()
        )


class DataAzurermEventgridTopic(
    cdktf.TerraformDataSource,
    metaclass=jsii.JSIIMeta,
    jsii_type="@cdktf/provider-azurerm.DataAzurermEventgridTopic",
):
    def __init__(
        self,
        scope: constructs.Construct,
        id: builtins.str,
        *,
        name: builtins.str,
        resource_group_name: builtins.str,
        tags: typing.Optional[typing.Mapping[builtins.str, builtins.str]] = None,
        timeouts: typing.Optional["DataAzurermEventgridTopicTimeouts"] = None,
        count: typing.Optional[jsii.Number] = None,
        depends_on: typing.Optional[typing.List[cdktf.TerraformResource]] = None,
        lifecycle: typing.Optional[cdktf.TerraformResourceLifecycle] = None,
        provider: typing.Optional[cdktf.TerraformProvider] = None,
    ) -> None:
        """
        :param scope: -
        :param id: -
        :param name: 
        :param resource_group_name: 
        :param tags: 
        :param timeouts: timeouts block.
        :param count: 
        :param depends_on: 
        :param lifecycle: 
        :param provider: 
        """
        config = DataAzurermEventgridTopicConfig(
            name=name,
            resource_group_name=resource_group_name,
            tags=tags,
            timeouts=timeouts,
            count=count,
            depends_on=depends_on,
            lifecycle=lifecycle,
            provider=provider,
        )

        jsii.create(DataAzurermEventgridTopic, self, [scope, id, config])

    @jsii.member(jsii_name="synthesizeAttributes")
    def _synthesize_attributes(self) -> typing.Mapping[builtins.str, typing.Any]:
        return jsii.invoke(self, "synthesizeAttributes", [])

    @builtins.property # type: ignore
    @jsii.member(jsii_name="endpoint")
    def endpoint(self) -> builtins.str:
        return jsii.get(self, "endpoint")

    @builtins.property # type: ignore
    @jsii.member(jsii_name="location")
    def location(self) -> builtins.str:
        return jsii.get(self, "location")

    @builtins.property # type: ignore
    @jsii.member(jsii_name="primaryAccessKey")
    def primary_access_key(self) -> builtins.str:
        return jsii.get(self, "primaryAccessKey")

    @builtins.property # type: ignore
    @jsii.member(jsii_name="secondaryAccessKey")
    def secondary_access_key(self) -> builtins.str:
        return jsii.get(self, "secondaryAccessKey")

    @builtins.property # type: ignore
    @jsii.member(jsii_name="name")
    def name(self) -> builtins.str:
        return jsii.get(self, "name")

    @name.setter # type: ignore
    def name(self, value: builtins.str) -> None:
        jsii.set(self, "name", value)

    @builtins.property # type: ignore
    @jsii.member(jsii_name="resourceGroupName")
    def resource_group_name(self) -> builtins.str:
        return jsii.get(self, "resourceGroupName")

    @resource_group_name.setter # type: ignore
    def resource_group_name(self, value: builtins.str) -> None:
        jsii.set(self, "resourceGroupName", value)

    @builtins.property # type: ignore
    @jsii.member(jsii_name="id")
    def id(self) -> typing.Optional[builtins.str]:
        return jsii.get(self, "id")

    @id.setter # type: ignore
    def id(self, value: typing.Optional[builtins.str]) -> None:
        jsii.set(self, "id", value)

    @builtins.property # type: ignore
    @jsii.member(jsii_name="tags")
    def tags(self) -> typing.Optional[typing.Mapping[builtins.str, builtins.str]]:
        return jsii.get(self, "tags")

    @tags.setter # type: ignore
    def tags(
        self,
        value: typing.Optional[typing.Mapping[builtins.str, builtins.str]],
    ) -> None:
        jsii.set(self, "tags", value)

    @builtins.property # type: ignore
    @jsii.member(jsii_name="timeouts")
    def timeouts(self) -> typing.Optional["DataAzurermEventgridTopicTimeouts"]:
        return jsii.get(self, "timeouts")

    @timeouts.setter # type: ignore
    def timeouts(
        self,
        value: typing.Optional["DataAzurermEventgridTopicTimeouts"],
    ) -> None:
        jsii.set(self, "timeouts", value)


@jsii.data_type(
    jsii_type="@cdktf/provider-azurerm.DataAzurermEventgridTopicConfig",
    jsii_struct_bases=[cdktf.TerraformMetaArguments],
    name_mapping={
        "count": "count",
        "depends_on": "dependsOn",
        "lifecycle": "lifecycle",
        "provider": "provider",
        "name": "name",
        "resource_group_name": "resourceGroupName",
        "tags": "tags",
        "timeouts": "timeouts",
    },
)
class DataAzurermEventgridTopicConfig(cdktf.TerraformMetaArguments):
    def __init__(
        self,
        *,
        count: typing.Optional[jsii.Number] = None,
        depends_on: typing.Optional[typing.List[cdktf.TerraformResource]] = None,
        lifecycle: typing.Optional[cdktf.TerraformResourceLifecycle] = None,
        provider: typing.Optional[cdktf.TerraformProvider] = None,
        name: builtins.str,
        resource_group_name: builtins.str,
        tags: typing.Optional[typing.Mapping[builtins.str, builtins.str]] = None,
        timeouts: typing.Optional["DataAzurermEventgridTopicTimeouts"] = None,
    ) -> None:
        """
        :param count: 
        :param depends_on: 
        :param lifecycle: 
        :param provider: 
        :param name: 
        :param resource_group_name: 
        :param tags: 
        :param timeouts: timeouts block.
        """
        if isinstance(lifecycle, dict):
            lifecycle = cdktf.TerraformResourceLifecycle(**lifecycle)
        if isinstance(timeouts, dict):
            timeouts = DataAzurermEventgridTopicTimeouts(**timeouts)
        self._values: typing.Dict[str, typing.Any] = {
            "name": name,
            "resource_group_name": resource_group_name,
        }
        if count is not None:
            self._values["count"] = count
        if depends_on is not None:
            self._values["depends_on"] = depends_on
        if lifecycle is not None:
            self._values["lifecycle"] = lifecycle
        if provider is not None:
            self._values["provider"] = provider
        if tags is not None:
            self._values["tags"] = tags
        if timeouts is not None:
            self._values["timeouts"] = timeouts

    @builtins.property
    def count(self) -> typing.Optional[jsii.Number]:
        """
        :stability: experimental
        """
        result = self._values.get("count")
        return result

    @builtins.property
    def depends_on(self) -> typing.Optional[typing.List[cdktf.TerraformResource]]:
        """
        :stability: experimental
        """
        result = self._values.get("depends_on")
        return result

    @builtins.property
    def lifecycle(self) -> typing.Optional[cdktf.TerraformResourceLifecycle]:
        """
        :stability: experimental
        """
        result = self._values.get("lifecycle")
        return result

    @builtins.property
    def provider(self) -> typing.Optional[cdktf.TerraformProvider]:
        """
        :stability: experimental
        """
        result = self._values.get("provider")
        return result

    @builtins.property
    def name(self) -> builtins.str:
        result = self._values.get("name")
        assert result is not None, "Required property 'name' is missing"
        return result

    @builtins.property
    def resource_group_name(self) -> builtins.str:
        result = self._values.get("resource_group_name")
        assert result is not None, "Required property 'resource_group_name' is missing"
        return result

    @builtins.property
    def tags(self) -> typing.Optional[typing.Mapping[builtins.str, builtins.str]]:
        result = self._values.get("tags")
        return result

    @builtins.property
    def timeouts(self) -> typing.Optional["DataAzurermEventgridTopicTimeouts"]:
        """timeouts block."""
        result = self._values.get("timeouts")
        return result

    def __eq__(self, rhs: typing.Any) -> builtins.bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs: typing.Any) -> builtins.bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return "DataAzurermEventgridTopicConfig(%s)" % ", ".join(
            k + "=" + repr(v) for k, v in self._values.items()
        )


@jsii.data_type(
    jsii_type="@cdktf/provider-azurerm.DataAzurermEventgridTopicTimeouts",
    jsii_struct_bases=[],
    name_mapping={"read": "read"},
)
class DataAzurermEventgridTopicTimeouts:
    def __init__(self, *, read: typing.Optional[builtins.str] = None) -> None:
        """
        :param read: 
        """
        self._values: typing.Dict[str, typing.Any] = {}
        if read is not None:
            self._values["read"] = read

    @builtins.property
    def read(self) -> typing.Optional[builtins.str]:
        result = self._values.get("read")
        return result

    def __eq__(self, rhs: typing.Any) -> builtins.bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs: typing.Any) -> builtins.bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return "DataAzurermEventgridTopicTimeouts(%s)" % ", ".join(
            k + "=" + repr(v) for k, v in self._values.items()
        )


class DataAzurermEventhubAuthorizationRule(
    cdktf.TerraformDataSource,
    metaclass=jsii.JSIIMeta,
    jsii_type="@cdktf/provider-azurerm.DataAzurermEventhubAuthorizationRule",
):
    def __init__(
        self,
        scope: constructs.Construct,
        id: builtins.str,
        *,
        eventhub_name: builtins.str,
        name: builtins.str,
        namespace_name: builtins.str,
        resource_group_name: builtins.str,
        listen: typing.Optional[builtins.bool] = None,
        manage: typing.Optional[builtins.bool] = None,
        send: typing.Optional[builtins.bool] = None,
        timeouts: typing.Optional["DataAzurermEventhubAuthorizationRuleTimeouts"] = None,
        count: typing.Optional[jsii.Number] = None,
        depends_on: typing.Optional[typing.List[cdktf.TerraformResource]] = None,
        lifecycle: typing.Optional[cdktf.TerraformResourceLifecycle] = None,
        provider: typing.Optional[cdktf.TerraformProvider] = None,
    ) -> None:
        """
        :param scope: -
        :param id: -
        :param eventhub_name: 
        :param name: 
        :param namespace_name: 
        :param resource_group_name: 
        :param listen: 
        :param manage: 
        :param send: 
        :param timeouts: timeouts block.
        :param count: 
        :param depends_on: 
        :param lifecycle: 
        :param provider: 
        """
        config = DataAzurermEventhubAuthorizationRuleConfig(
            eventhub_name=eventhub_name,
            name=name,
            namespace_name=namespace_name,
            resource_group_name=resource_group_name,
            listen=listen,
            manage=manage,
            send=send,
            timeouts=timeouts,
            count=count,
            depends_on=depends_on,
            lifecycle=lifecycle,
            provider=provider,
        )

        jsii.create(DataAzurermEventhubAuthorizationRule, self, [scope, id, config])

    @jsii.member(jsii_name="synthesizeAttributes")
    def _synthesize_attributes(self) -> typing.Mapping[builtins.str, typing.Any]:
        return jsii.invoke(self, "synthesizeAttributes", [])

    @builtins.property # type: ignore
    @jsii.member(jsii_name="location")
    def location(self) -> builtins.str:
        return jsii.get(self, "location")

    @builtins.property # type: ignore
    @jsii.member(jsii_name="primaryConnectionString")
    def primary_connection_string(self) -> builtins.str:
        return jsii.get(self, "primaryConnectionString")

    @builtins.property # type: ignore
    @jsii.member(jsii_name="primaryKey")
    def primary_key(self) -> builtins.str:
        return jsii.get(self, "primaryKey")

    @builtins.property # type: ignore
    @jsii.member(jsii_name="secondaryConnectionString")
    def secondary_connection_string(self) -> builtins.str:
        return jsii.get(self, "secondaryConnectionString")

    @builtins.property # type: ignore
    @jsii.member(jsii_name="secondaryKey")
    def secondary_key(self) -> builtins.str:
        return jsii.get(self, "secondaryKey")

    @builtins.property # type: ignore
    @jsii.member(jsii_name="eventhubName")
    def eventhub_name(self) -> builtins.str:
        return jsii.get(self, "eventhubName")

    @eventhub_name.setter # type: ignore
    def eventhub_name(self, value: builtins.str) -> None:
        jsii.set(self, "eventhubName", value)

    @builtins.property # type: ignore
    @jsii.member(jsii_name="name")
    def name(self) -> builtins.str:
        return jsii.get(self, "name")

    @name.setter # type: ignore
    def name(self, value: builtins.str) -> None:
        jsii.set(self, "name", value)

    @builtins.property # type: ignore
    @jsii.member(jsii_name="namespaceName")
    def namespace_name(self) -> builtins.str:
        return jsii.get(self, "namespaceName")

    @namespace_name.setter # type: ignore
    def namespace_name(self, value: builtins.str) -> None:
        jsii.set(self, "namespaceName", value)

    @builtins.property # type: ignore
    @jsii.member(jsii_name="resourceGroupName")
    def resource_group_name(self) -> builtins.str:
        return jsii.get(self, "resourceGroupName")

    @resource_group_name.setter # type: ignore
    def resource_group_name(self, value: builtins.str) -> None:
        jsii.set(self, "resourceGroupName", value)

    @builtins.property # type: ignore
    @jsii.member(jsii_name="id")
    def id(self) -> typing.Optional[builtins.str]:
        return jsii.get(self, "id")

    @id.setter # type: ignore
    def id(self, value: typing.Optional[builtins.str]) -> None:
        jsii.set(self, "id", value)

    @builtins.property # type: ignore
    @jsii.member(jsii_name="listen")
    def listen(self) -> typing.Optional[builtins.bool]:
        return jsii.get(self, "listen")

    @listen.setter # type: ignore
    def listen(self, value: typing.Optional[builtins.bool]) -> None:
        jsii.set(self, "listen", value)

    @builtins.property # type: ignore
    @jsii.member(jsii_name="manage")
    def manage(self) -> typing.Optional[builtins.bool]:
        return jsii.get(self, "manage")

    @manage.setter # type: ignore
    def manage(self, value: typing.Optional[builtins.bool]) -> None:
        jsii.set(self, "manage", value)

    @builtins.property # type: ignore
    @jsii.member(jsii_name="send")
    def send(self) -> typing.Optional[builtins.bool]:
        return jsii.get(self, "send")

    @send.setter # type: ignore
    def send(self, value: typing.Optional[builtins.bool]) -> None:
        jsii.set(self, "send", value)

    @builtins.property # type: ignore
    @jsii.member(jsii_name="timeouts")
    def timeouts(
        self,
    ) -> typing.Optional["DataAzurermEventhubAuthorizationRuleTimeouts"]:
        return jsii.get(self, "timeouts")

    @timeouts.setter # type: ignore
    def timeouts(
        self,
        value: typing.Optional["DataAzurermEventhubAuthorizationRuleTimeouts"],
    ) -> None:
        jsii.set(self, "timeouts", value)


@jsii.data_type(
    jsii_type="@cdktf/provider-azurerm.DataAzurermEventhubAuthorizationRuleConfig",
    jsii_struct_bases=[cdktf.TerraformMetaArguments],
    name_mapping={
        "count": "count",
        "depends_on": "dependsOn",
        "lifecycle": "lifecycle",
        "provider": "provider",
        "eventhub_name": "eventhubName",
        "name": "name",
        "namespace_name": "namespaceName",
        "resource_group_name": "resourceGroupName",
        "listen": "listen",
        "manage": "manage",
        "send": "send",
        "timeouts": "timeouts",
    },
)
class DataAzurermEventhubAuthorizationRuleConfig(cdktf.TerraformMetaArguments):
    def __init__(
        self,
        *,
        count: typing.Optional[jsii.Number] = None,
        depends_on: typing.Optional[typing.List[cdktf.TerraformResource]] = None,
        lifecycle: typing.Optional[cdktf.TerraformResourceLifecycle] = None,
        provider: typing.Optional[cdktf.TerraformProvider] = None,
        eventhub_name: builtins.str,
        name: builtins.str,
        namespace_name: builtins.str,
        resource_group_name: builtins.str,
        listen: typing.Optional[builtins.bool] = None,
        manage: typing.Optional[builtins.bool] = None,
        send: typing.Optional[builtins.bool] = None,
        timeouts: typing.Optional["DataAzurermEventhubAuthorizationRuleTimeouts"] = None,
    ) -> None:
        """
        :param count: 
        :param depends_on: 
        :param lifecycle: 
        :param provider: 
        :param eventhub_name: 
        :param name: 
        :param namespace_name: 
        :param resource_group_name: 
        :param listen: 
        :param manage: 
        :param send: 
        :param timeouts: timeouts block.
        """
        if isinstance(lifecycle, dict):
            lifecycle = cdktf.TerraformResourceLifecycle(**lifecycle)
        if isinstance(timeouts, dict):
            timeouts = DataAzurermEventhubAuthorizationRuleTimeouts(**timeouts)
        self._values: typing.Dict[str, typing.Any] = {
            "eventhub_name": eventhub_name,
            "name": name,
            "namespace_name": namespace_name,
            "resource_group_name": resource_group_name,
        }
        if count is not None:
            self._values["count"] = count
        if depends_on is not None:
            self._values["depends_on"] = depends_on
        if lifecycle is not None:
            self._values["lifecycle"] = lifecycle
        if provider is not None:
            self._values["provider"] = provider
        if listen is not None:
            self._values["listen"] = listen
        if manage is not None:
            self._values["manage"] = manage
        if send is not None:
            self._values["send"] = send
        if timeouts is not None:
            self._values["timeouts"] = timeouts

    @builtins.property
    def count(self) -> typing.Optional[jsii.Number]:
        """
        :stability: experimental
        """
        result = self._values.get("count")
        return result

    @builtins.property
    def depends_on(self) -> typing.Optional[typing.List[cdktf.TerraformResource]]:
        """
        :stability: experimental
        """
        result = self._values.get("depends_on")
        return result

    @builtins.property
    def lifecycle(self) -> typing.Optional[cdktf.TerraformResourceLifecycle]:
        """
        :stability: experimental
        """
        result = self._values.get("lifecycle")
        return result

    @builtins.property
    def provider(self) -> typing.Optional[cdktf.TerraformProvider]:
        """
        :stability: experimental
        """
        result = self._values.get("provider")
        return result

    @builtins.property
    def eventhub_name(self) -> builtins.str:
        result = self._values.get("eventhub_name")
        assert result is not None, "Required property 'eventhub_name' is missing"
        return result

    @builtins.property
    def name(self) -> builtins.str:
        result = self._values.get("name")
        assert result is not None, "Required property 'name' is missing"
        return result

    @builtins.property
    def namespace_name(self) -> builtins.str:
        result = self._values.get("namespace_name")
        assert result is not None, "Required property 'namespace_name' is missing"
        return result

    @builtins.property
    def resource_group_name(self) -> builtins.str:
        result = self._values.get("resource_group_name")
        assert result is not None, "Required property 'resource_group_name' is missing"
        return result

    @builtins.property
    def listen(self) -> typing.Optional[builtins.bool]:
        result = self._values.get("listen")
        return result

    @builtins.property
    def manage(self) -> typing.Optional[builtins.bool]:
        result = self._values.get("manage")
        return result

    @builtins.property
    def send(self) -> typing.Optional[builtins.bool]:
        result = self._values.get("send")
        return result

    @builtins.property
    def timeouts(
        self,
    ) -> typing.Optional["DataAzurermEventhubAuthorizationRuleTimeouts"]:
        """timeouts block."""
        result = self._values.get("timeouts")
        return result

    def __eq__(self, rhs: typing.Any) -> builtins.bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs: typing.Any) -> builtins.bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return "DataAzurermEventhubAuthorizationRuleConfig(%s)" % ", ".join(
            k + "=" + repr(v) for k, v in self._values.items()
        )


@jsii.data_type(
    jsii_type="@cdktf/provider-azurerm.DataAzurermEventhubAuthorizationRuleTimeouts",
    jsii_struct_bases=[],
    name_mapping={"read": "read"},
)
class DataAzurermEventhubAuthorizationRuleTimeouts:
    def __init__(self, *, read: typing.Optional[builtins.str] = None) -> None:
        """
        :param read: 
        """
        self._values: typing.Dict[str, typing.Any] = {}
        if read is not None:
            self._values["read"] = read

    @builtins.property
    def read(self) -> typing.Optional[builtins.str]:
        result = self._values.get("read")
        return result

    def __eq__(self, rhs: typing.Any) -> builtins.bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs: typing.Any) -> builtins.bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return "DataAzurermEventhubAuthorizationRuleTimeouts(%s)" % ", ".join(
            k + "=" + repr(v) for k, v in self._values.items()
        )


class DataAzurermEventhubConsumerGroup(
    cdktf.TerraformDataSource,
    metaclass=jsii.JSIIMeta,
    jsii_type="@cdktf/provider-azurerm.DataAzurermEventhubConsumerGroup",
):
    def __init__(
        self,
        scope: constructs.Construct,
        id: builtins.str,
        *,
        eventhub_name: builtins.str,
        name: builtins.str,
        namespace_name: builtins.str,
        resource_group_name: builtins.str,
        timeouts: typing.Optional["DataAzurermEventhubConsumerGroupTimeouts"] = None,
        count: typing.Optional[jsii.Number] = None,
        depends_on: typing.Optional[typing.List[cdktf.TerraformResource]] = None,
        lifecycle: typing.Optional[cdktf.TerraformResourceLifecycle] = None,
        provider: typing.Optional[cdktf.TerraformProvider] = None,
    ) -> None:
        """
        :param scope: -
        :param id: -
        :param eventhub_name: 
        :param name: 
        :param namespace_name: 
        :param resource_group_name: 
        :param timeouts: timeouts block.
        :param count: 
        :param depends_on: 
        :param lifecycle: 
        :param provider: 
        """
        config = DataAzurermEventhubConsumerGroupConfig(
            eventhub_name=eventhub_name,
            name=name,
            namespace_name=namespace_name,
            resource_group_name=resource_group_name,
            timeouts=timeouts,
            count=count,
            depends_on=depends_on,
            lifecycle=lifecycle,
            provider=provider,
        )

        jsii.create(DataAzurermEventhubConsumerGroup, self, [scope, id, config])

    @jsii.member(jsii_name="synthesizeAttributes")
    def _synthesize_attributes(self) -> typing.Mapping[builtins.str, typing.Any]:
        return jsii.invoke(self, "synthesizeAttributes", [])

    @builtins.property # type: ignore
    @jsii.member(jsii_name="location")
    def location(self) -> builtins.str:
        return jsii.get(self, "location")

    @builtins.property # type: ignore
    @jsii.member(jsii_name="userMetadata")
    def user_metadata(self) -> builtins.str:
        return jsii.get(self, "userMetadata")

    @builtins.property # type: ignore
    @jsii.member(jsii_name="eventhubName")
    def eventhub_name(self) -> builtins.str:
        return jsii.get(self, "eventhubName")

    @eventhub_name.setter # type: ignore
    def eventhub_name(self, value: builtins.str) -> None:
        jsii.set(self, "eventhubName", value)

    @builtins.property # type: ignore
    @jsii.member(jsii_name="name")
    def name(self) -> builtins.str:
        return jsii.get(self, "name")

    @name.setter # type: ignore
    def name(self, value: builtins.str) -> None:
        jsii.set(self, "name", value)

    @builtins.property # type: ignore
    @jsii.member(jsii_name="namespaceName")
    def namespace_name(self) -> builtins.str:
        return jsii.get(self, "namespaceName")

    @namespace_name.setter # type: ignore
    def namespace_name(self, value: builtins.str) -> None:
        jsii.set(self, "namespaceName", value)

    @builtins.property # type: ignore
    @jsii.member(jsii_name="resourceGroupName")
    def resource_group_name(self) -> builtins.str:
        return jsii.get(self, "resourceGroupName")

    @resource_group_name.setter # type: ignore
    def resource_group_name(self, value: builtins.str) -> None:
        jsii.set(self, "resourceGroupName", value)

    @builtins.property # type: ignore
    @jsii.member(jsii_name="id")
    def id(self) -> typing.Optional[builtins.str]:
        return jsii.get(self, "id")

    @id.setter # type: ignore
    def id(self, value: typing.Optional[builtins.str]) -> None:
        jsii.set(self, "id", value)

    @builtins.property # type: ignore
    @jsii.member(jsii_name="timeouts")
    def timeouts(self) -> typing.Optional["DataAzurermEventhubConsumerGroupTimeouts"]:
        return jsii.get(self, "timeouts")

    @timeouts.setter # type: ignore
    def timeouts(
        self,
        value: typing.Optional["DataAzurermEventhubConsumerGroupTimeouts"],
    ) -> None:
        jsii.set(self, "timeouts", value)


@jsii.data_type(
    jsii_type="@cdktf/provider-azurerm.DataAzurermEventhubConsumerGroupConfig",
    jsii_struct_bases=[cdktf.TerraformMetaArguments],
    name_mapping={
        "count": "count",
        "depends_on": "dependsOn",
        "lifecycle": "lifecycle",
        "provider": "provider",
        "eventhub_name": "eventhubName",
        "name": "name",
        "namespace_name": "namespaceName",
        "resource_group_name": "resourceGroupName",
        "timeouts": "timeouts",
    },
)
class DataAzurermEventhubConsumerGroupConfig(cdktf.TerraformMetaArguments):
    def __init__(
        self,
        *,
        count: typing.Optional[jsii.Number] = None,
        depends_on: typing.Optional[typing.List[cdktf.TerraformResource]] = None,
        lifecycle: typing.Optional[cdktf.TerraformResourceLifecycle] = None,
        provider: typing.Optional[cdktf.TerraformProvider] = None,
        eventhub_name: builtins.str,
        name: builtins.str,
        namespace_name: builtins.str,
        resource_group_name: builtins.str,
        timeouts: typing.Optional["DataAzurermEventhubConsumerGroupTimeouts"] = None,
    ) -> None:
        """
        :param count: 
        :param depends_on: 
        :param lifecycle: 
        :param provider: 
        :param eventhub_name: 
        :param name: 
        :param namespace_name: 
        :param resource_group_name: 
        :param timeouts: timeouts block.
        """
        if isinstance(lifecycle, dict):
            lifecycle = cdktf.TerraformResourceLifecycle(**lifecycle)
        if isinstance(timeouts, dict):
            timeouts = DataAzurermEventhubConsumerGroupTimeouts(**timeouts)
        self._values: typing.Dict[str, typing.Any] = {
            "eventhub_name": eventhub_name,
            "name": name,
            "namespace_name": namespace_name,
            "resource_group_name": resource_group_name,
        }
        if count is not None:
            self._values["count"] = count
        if depends_on is not None:
            self._values["depends_on"] = depends_on
        if lifecycle is not None:
            self._values["lifecycle"] = lifecycle
        if provider is not None:
            self._values["provider"] = provider
        if timeouts is not None:
            self._values["timeouts"] = timeouts

    @builtins.property
    def count(self) -> typing.Optional[jsii.Number]:
        """
        :stability: experimental
        """
        result = self._values.get("count")
        return result

    @builtins.property
    def depends_on(self) -> typing.Optional[typing.List[cdktf.TerraformResource]]:
        """
        :stability: experimental
        """
        result = self._values.get("depends_on")
        return result

    @builtins.property
    def lifecycle(self) -> typing.Optional[cdktf.TerraformResourceLifecycle]:
        """
        :stability: experimental
        """
        result = self._values.get("lifecycle")
        return result

    @builtins.property
    def provider(self) -> typing.Optional[cdktf.TerraformProvider]:
        """
        :stability: experimental
        """
        result = self._values.get("provider")
        return result

    @builtins.property
    def eventhub_name(self) -> builtins.str:
        result = self._values.get("eventhub_name")
        assert result is not None, "Required property 'eventhub_name' is missing"
        return result

    @builtins.property
    def name(self) -> builtins.str:
        result = self._values.get("name")
        assert result is not None, "Required property 'name' is missing"
        return result

    @builtins.property
    def namespace_name(self) -> builtins.str:
        result = self._values.get("namespace_name")
        assert result is not None, "Required property 'namespace_name' is missing"
        return result

    @builtins.property
    def resource_group_name(self) -> builtins.str:
        result = self._values.get("resource_group_name")
        assert result is not None, "Required property 'resource_group_name' is missing"
        return result

    @builtins.property
    def timeouts(self) -> typing.Optional["DataAzurermEventhubConsumerGroupTimeouts"]:
        """timeouts block."""
        result = self._values.get("timeouts")
        return result

    def __eq__(self, rhs: typing.Any) -> builtins.bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs: typing.Any) -> builtins.bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return "DataAzurermEventhubConsumerGroupConfig(%s)" % ", ".join(
            k + "=" + repr(v) for k, v in self._values.items()
        )


@jsii.data_type(
    jsii_type="@cdktf/provider-azurerm.DataAzurermEventhubConsumerGroupTimeouts",
    jsii_struct_bases=[],
    name_mapping={"read": "read"},
)
class DataAzurermEventhubConsumerGroupTimeouts:
    def __init__(self, *, read: typing.Optional[builtins.str] = None) -> None:
        """
        :param read: 
        """
        self._values: typing.Dict[str, typing.Any] = {}
        if read is not None:
            self._values["read"] = read

    @builtins.property
    def read(self) -> typing.Optional[builtins.str]:
        result = self._values.get("read")
        return result

    def __eq__(self, rhs: typing.Any) -> builtins.bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs: typing.Any) -> builtins.bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return "DataAzurermEventhubConsumerGroupTimeouts(%s)" % ", ".join(
            k + "=" + repr(v) for k, v in self._values.items()
        )


class DataAzurermEventhubNamespace(
    cdktf.TerraformDataSource,
    metaclass=jsii.JSIIMeta,
    jsii_type="@cdktf/provider-azurerm.DataAzurermEventhubNamespace",
):
    def __init__(
        self,
        scope: constructs.Construct,
        id: builtins.str,
        *,
        name: builtins.str,
        resource_group_name: builtins.str,
        timeouts: typing.Optional["DataAzurermEventhubNamespaceTimeouts"] = None,
        count: typing.Optional[jsii.Number] = None,
        depends_on: typing.Optional[typing.List[cdktf.TerraformResource]] = None,
        lifecycle: typing.Optional[cdktf.TerraformResourceLifecycle] = None,
        provider: typing.Optional[cdktf.TerraformProvider] = None,
    ) -> None:
        """
        :param scope: -
        :param id: -
        :param name: 
        :param resource_group_name: 
        :param timeouts: timeouts block.
        :param count: 
        :param depends_on: 
        :param lifecycle: 
        :param provider: 
        """
        config = DataAzurermEventhubNamespaceConfig(
            name=name,
            resource_group_name=resource_group_name,
            timeouts=timeouts,
            count=count,
            depends_on=depends_on,
            lifecycle=lifecycle,
            provider=provider,
        )

        jsii.create(DataAzurermEventhubNamespace, self, [scope, id, config])

    @jsii.member(jsii_name="synthesizeAttributes")
    def _synthesize_attributes(self) -> typing.Mapping[builtins.str, typing.Any]:
        return jsii.invoke(self, "synthesizeAttributes", [])

    @jsii.member(jsii_name="tags")
    def tags(self, key: builtins.str) -> builtins.str:
        """
        :param key: -
        """
        return jsii.invoke(self, "tags", [key])

    @builtins.property # type: ignore
    @jsii.member(jsii_name="autoInflateEnabled")
    def auto_inflate_enabled(self) -> builtins.bool:
        return jsii.get(self, "autoInflateEnabled")

    @builtins.property # type: ignore
    @jsii.member(jsii_name="capacity")
    def capacity(self) -> jsii.Number:
        return jsii.get(self, "capacity")

    @builtins.property # type: ignore
    @jsii.member(jsii_name="defaultPrimaryConnectionString")
    def default_primary_connection_string(self) -> builtins.str:
        return jsii.get(self, "defaultPrimaryConnectionString")

    @builtins.property # type: ignore
    @jsii.member(jsii_name="defaultPrimaryKey")
    def default_primary_key(self) -> builtins.str:
        return jsii.get(self, "defaultPrimaryKey")

    @builtins.property # type: ignore
    @jsii.member(jsii_name="defaultSecondaryConnectionString")
    def default_secondary_connection_string(self) -> builtins.str:
        return jsii.get(self, "defaultSecondaryConnectionString")

    @builtins.property # type: ignore
    @jsii.member(jsii_name="defaultSecondaryKey")
    def default_secondary_key(self) -> builtins.str:
        return jsii.get(self, "defaultSecondaryKey")

    @builtins.property # type: ignore
    @jsii.member(jsii_name="kafkaEnabled")
    def kafka_enabled(self) -> builtins.bool:
        return jsii.get(self, "kafkaEnabled")

    @builtins.property # type: ignore
    @jsii.member(jsii_name="location")
    def location(self) -> builtins.str:
        return jsii.get(self, "location")

    @builtins.property # type: ignore
    @jsii.member(jsii_name="maximumThroughputUnits")
    def maximum_throughput_units(self) -> jsii.Number:
        return jsii.get(self, "maximumThroughputUnits")

    @builtins.property # type: ignore
    @jsii.member(jsii_name="sku")
    def sku(self) -> builtins.str:
        return jsii.get(self, "sku")

    @builtins.property # type: ignore
    @jsii.member(jsii_name="name")
    def name(self) -> builtins.str:
        return jsii.get(self, "name")

    @name.setter # type: ignore
    def name(self, value: builtins.str) -> None:
        jsii.set(self, "name", value)

    @builtins.property # type: ignore
    @jsii.member(jsii_name="resourceGroupName")
    def resource_group_name(self) -> builtins.str:
        return jsii.get(self, "resourceGroupName")

    @resource_group_name.setter # type: ignore
    def resource_group_name(self, value: builtins.str) -> None:
        jsii.set(self, "resourceGroupName", value)

    @builtins.property # type: ignore
    @jsii.member(jsii_name="id")
    def id(self) -> typing.Optional[builtins.str]:
        return jsii.get(self, "id")

    @id.setter # type: ignore
    def id(self, value: typing.Optional[builtins.str]) -> None:
        jsii.set(self, "id", value)

    @builtins.property # type: ignore
    @jsii.member(jsii_name="timeouts")
    def timeouts(self) -> typing.Optional["DataAzurermEventhubNamespaceTimeouts"]:
        return jsii.get(self, "timeouts")

    @timeouts.setter # type: ignore
    def timeouts(
        self,
        value: typing.Optional["DataAzurermEventhubNamespaceTimeouts"],
    ) -> None:
        jsii.set(self, "timeouts", value)


class DataAzurermEventhubNamespaceAuthorizationRule(
    cdktf.TerraformDataSource,
    metaclass=jsii.JSIIMeta,
    jsii_type="@cdktf/provider-azurerm.DataAzurermEventhubNamespaceAuthorizationRule",
):
    def __init__(
        self,
        scope: constructs.Construct,
        id: builtins.str,
        *,
        name: builtins.str,
        namespace_name: builtins.str,
        resource_group_name: builtins.str,
        timeouts: typing.Optional["DataAzurermEventhubNamespaceAuthorizationRuleTimeouts"] = None,
        count: typing.Optional[jsii.Number] = None,
        depends_on: typing.Optional[typing.List[cdktf.TerraformResource]] = None,
        lifecycle: typing.Optional[cdktf.TerraformResourceLifecycle] = None,
        provider: typing.Optional[cdktf.TerraformProvider] = None,
    ) -> None:
        """
        :param scope: -
        :param id: -
        :param name: 
        :param namespace_name: 
        :param resource_group_name: 
        :param timeouts: timeouts block.
        :param count: 
        :param depends_on: 
        :param lifecycle: 
        :param provider: 
        """
        config = DataAzurermEventhubNamespaceAuthorizationRuleConfig(
            name=name,
            namespace_name=namespace_name,
            resource_group_name=resource_group_name,
            timeouts=timeouts,
            count=count,
            depends_on=depends_on,
            lifecycle=lifecycle,
            provider=provider,
        )

        jsii.create(DataAzurermEventhubNamespaceAuthorizationRule, self, [scope, id, config])

    @jsii.member(jsii_name="synthesizeAttributes")
    def _synthesize_attributes(self) -> typing.Mapping[builtins.str, typing.Any]:
        return jsii.invoke(self, "synthesizeAttributes", [])

    @builtins.property # type: ignore
    @jsii.member(jsii_name="listen")
    def listen(self) -> builtins.bool:
        return jsii.get(self, "listen")

    @builtins.property # type: ignore
    @jsii.member(jsii_name="manage")
    def manage(self) -> builtins.bool:
        return jsii.get(self, "manage")

    @builtins.property # type: ignore
    @jsii.member(jsii_name="primaryConnectionString")
    def primary_connection_string(self) -> builtins.str:
        return jsii.get(self, "primaryConnectionString")

    @builtins.property # type: ignore
    @jsii.member(jsii_name="primaryKey")
    def primary_key(self) -> builtins.str:
        return jsii.get(self, "primaryKey")

    @builtins.property # type: ignore
    @jsii.member(jsii_name="secondaryConnectionString")
    def secondary_connection_string(self) -> builtins.str:
        return jsii.get(self, "secondaryConnectionString")

    @builtins.property # type: ignore
    @jsii.member(jsii_name="secondaryKey")
    def secondary_key(self) -> builtins.str:
        return jsii.get(self, "secondaryKey")

    @builtins.property # type: ignore
    @jsii.member(jsii_name="send")
    def send(self) -> builtins.bool:
        return jsii.get(self, "send")

    @builtins.property # type: ignore
    @jsii.member(jsii_name="name")
    def name(self) -> builtins.str:
        return jsii.get(self, "name")

    @name.setter # type: ignore
    def name(self, value: builtins.str) -> None:
        jsii.set(self, "name", value)

    @builtins.property # type: ignore
    @jsii.member(jsii_name="namespaceName")
    def namespace_name(self) -> builtins.str:
        return jsii.get(self, "namespaceName")

    @namespace_name.setter # type: ignore
    def namespace_name(self, value: builtins.str) -> None:
        jsii.set(self, "namespaceName", value)

    @builtins.property # type: ignore
    @jsii.member(jsii_name="resourceGroupName")
    def resource_group_name(self) -> builtins.str:
        return jsii.get(self, "resourceGroupName")

    @resource_group_name.setter # type: ignore
    def resource_group_name(self, value: builtins.str) -> None:
        jsii.set(self, "resourceGroupName", value)

    @builtins.property # type: ignore
    @jsii.member(jsii_name="id")
    def id(self) -> typing.Optional[builtins.str]:
        return jsii.get(self, "id")

    @id.setter # type: ignore
    def id(self, value: typing.Optional[builtins.str]) -> None:
        jsii.set(self, "id", value)

    @builtins.property # type: ignore
    @jsii.member(jsii_name="timeouts")
    def timeouts(
        self,
    ) -> typing.Optional["DataAzurermEventhubNamespaceAuthorizationRuleTimeouts"]:
        return jsii.get(self, "timeouts")

    @timeouts.setter # type: ignore
    def timeouts(
        self,
        value: typing.Optional["DataAzurermEventhubNamespaceAuthorizationRuleTimeouts"],
    ) -> None:
        jsii.set(self, "timeouts", value)


@jsii.data_type(
    jsii_type="@cdktf/provider-azurerm.DataAzurermEventhubNamespaceAuthorizationRuleConfig",
    jsii_struct_bases=[cdktf.TerraformMetaArguments],
    name_mapping={
        "count": "count",
        "depends_on": "dependsOn",
        "lifecycle": "lifecycle",
        "provider": "provider",
        "name": "name",
        "namespace_name": "namespaceName",
        "resource_group_name": "resourceGroupName",
        "timeouts": "timeouts",
    },
)
class DataAzurermEventhubNamespaceAuthorizationRuleConfig(cdktf.TerraformMetaArguments):
    def __init__(
        self,
        *,
        count: typing.Optional[jsii.Number] = None,
        depends_on: typing.Optional[typing.List[cdktf.TerraformResource]] = None,
        lifecycle: typing.Optional[cdktf.TerraformResourceLifecycle] = None,
        provider: typing.Optional[cdktf.TerraformProvider] = None,
        name: builtins.str,
        namespace_name: builtins.str,
        resource_group_name: builtins.str,
        timeouts: typing.Optional["DataAzurermEventhubNamespaceAuthorizationRuleTimeouts"] = None,
    ) -> None:
        """
        :param count: 
        :param depends_on: 
        :param lifecycle: 
        :param provider: 
        :param name: 
        :param namespace_name: 
        :param resource_group_name: 
        :param timeouts: timeouts block.
        """
        if isinstance(lifecycle, dict):
            lifecycle = cdktf.TerraformResourceLifecycle(**lifecycle)
        if isinstance(timeouts, dict):
            timeouts = DataAzurermEventhubNamespaceAuthorizationRuleTimeouts(**timeouts)
        self._values: typing.Dict[str, typing.Any] = {
            "name": name,
            "namespace_name": namespace_name,
            "resource_group_name": resource_group_name,
        }
        if count is not None:
            self._values["count"] = count
        if depends_on is not None:
            self._values["depends_on"] = depends_on
        if lifecycle is not None:
            self._values["lifecycle"] = lifecycle
        if provider is not None:
            self._values["provider"] = provider
        if timeouts is not None:
            self._values["timeouts"] = timeouts

    @builtins.property
    def count(self) -> typing.Optional[jsii.Number]:
        """
        :stability: experimental
        """
        result = self._values.get("count")
        return result

    @builtins.property
    def depends_on(self) -> typing.Optional[typing.List[cdktf.TerraformResource]]:
        """
        :stability: experimental
        """
        result = self._values.get("depends_on")
        return result

    @builtins.property
    def lifecycle(self) -> typing.Optional[cdktf.TerraformResourceLifecycle]:
        """
        :stability: experimental
        """
        result = self._values.get("lifecycle")
        return result

    @builtins.property
    def provider(self) -> typing.Optional[cdktf.TerraformProvider]:
        """
        :stability: experimental
        """
        result = self._values.get("provider")
        return result

    @builtins.property
    def name(self) -> builtins.str:
        result = self._values.get("name")
        assert result is not None, "Required property 'name' is missing"
        return result

    @builtins.property
    def namespace_name(self) -> builtins.str:
        result = self._values.get("namespace_name")
        assert result is not None, "Required property 'namespace_name' is missing"
        return result

    @builtins.property
    def resource_group_name(self) -> builtins.str:
        result = self._values.get("resource_group_name")
        assert result is not None, "Required property 'resource_group_name' is missing"
        return result

    @builtins.property
    def timeouts(
        self,
    ) -> typing.Optional["DataAzurermEventhubNamespaceAuthorizationRuleTimeouts"]:
        """timeouts block."""
        result = self._values.get("timeouts")
        return result

    def __eq__(self, rhs: typing.Any) -> builtins.bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs: typing.Any) -> builtins.bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return "DataAzurermEventhubNamespaceAuthorizationRuleConfig(%s)" % ", ".join(
            k + "=" + repr(v) for k, v in self._values.items()
        )


@jsii.data_type(
    jsii_type="@cdktf/provider-azurerm.DataAzurermEventhubNamespaceAuthorizationRuleTimeouts",
    jsii_struct_bases=[],
    name_mapping={"read": "read"},
)
class DataAzurermEventhubNamespaceAuthorizationRuleTimeouts:
    def __init__(self, *, read: typing.Optional[builtins.str] = None) -> None:
        """
        :param read: 
        """
        self._values: typing.Dict[str, typing.Any] = {}
        if read is not None:
            self._values["read"] = read

    @builtins.property
    def read(self) -> typing.Optional[builtins.str]:
        result = self._values.get("read")
        return result

    def __eq__(self, rhs: typing.Any) -> builtins.bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs: typing.Any) -> builtins.bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return "DataAzurermEventhubNamespaceAuthorizationRuleTimeouts(%s)" % ", ".join(
            k + "=" + repr(v) for k, v in self._values.items()
        )


@jsii.data_type(
    jsii_type="@cdktf/provider-azurerm.DataAzurermEventhubNamespaceConfig",
    jsii_struct_bases=[cdktf.TerraformMetaArguments],
    name_mapping={
        "count": "count",
        "depends_on": "dependsOn",
        "lifecycle": "lifecycle",
        "provider": "provider",
        "name": "name",
        "resource_group_name": "resourceGroupName",
        "timeouts": "timeouts",
    },
)
class DataAzurermEventhubNamespaceConfig(cdktf.TerraformMetaArguments):
    def __init__(
        self,
        *,
        count: typing.Optional[jsii.Number] = None,
        depends_on: typing.Optional[typing.List[cdktf.TerraformResource]] = None,
        lifecycle: typing.Optional[cdktf.TerraformResourceLifecycle] = None,
        provider: typing.Optional[cdktf.TerraformProvider] = None,
        name: builtins.str,
        resource_group_name: builtins.str,
        timeouts: typing.Optional["DataAzurermEventhubNamespaceTimeouts"] = None,
    ) -> None:
        """
        :param count: 
        :param depends_on: 
        :param lifecycle: 
        :param provider: 
        :param name: 
        :param resource_group_name: 
        :param timeouts: timeouts block.
        """
        if isinstance(lifecycle, dict):
            lifecycle = cdktf.TerraformResourceLifecycle(**lifecycle)
        if isinstance(timeouts, dict):
            timeouts = DataAzurermEventhubNamespaceTimeouts(**timeouts)
        self._values: typing.Dict[str, typing.Any] = {
            "name": name,
            "resource_group_name": resource_group_name,
        }
        if count is not None:
            self._values["count"] = count
        if depends_on is not None:
            self._values["depends_on"] = depends_on
        if lifecycle is not None:
            self._values["lifecycle"] = lifecycle
        if provider is not None:
            self._values["provider"] = provider
        if timeouts is not None:
            self._values["timeouts"] = timeouts

    @builtins.property
    def count(self) -> typing.Optional[jsii.Number]:
        """
        :stability: experimental
        """
        result = self._values.get("count")
        return result

    @builtins.property
    def depends_on(self) -> typing.Optional[typing.List[cdktf.TerraformResource]]:
        """
        :stability: experimental
        """
        result = self._values.get("depends_on")
        return result

    @builtins.property
    def lifecycle(self) -> typing.Optional[cdktf.TerraformResourceLifecycle]:
        """
        :stability: experimental
        """
        result = self._values.get("lifecycle")
        return result

    @builtins.property
    def provider(self) -> typing.Optional[cdktf.TerraformProvider]:
        """
        :stability: experimental
        """
        result = self._values.get("provider")
        return result

    @builtins.property
    def name(self) -> builtins.str:
        result = self._values.get("name")
        assert result is not None, "Required property 'name' is missing"
        return result

    @builtins.property
    def resource_group_name(self) -> builtins.str:
        result = self._values.get("resource_group_name")
        assert result is not None, "Required property 'resource_group_name' is missing"
        return result

    @builtins.property
    def timeouts(self) -> typing.Optional["DataAzurermEventhubNamespaceTimeouts"]:
        """timeouts block."""
        result = self._values.get("timeouts")
        return result

    def __eq__(self, rhs: typing.Any) -> builtins.bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs: typing.Any) -> builtins.bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return "DataAzurermEventhubNamespaceConfig(%s)" % ", ".join(
            k + "=" + repr(v) for k, v in self._values.items()
        )


@jsii.data_type(
    jsii_type="@cdktf/provider-azurerm.DataAzurermEventhubNamespaceTimeouts",
    jsii_struct_bases=[],
    name_mapping={"read": "read"},
)
class DataAzurermEventhubNamespaceTimeouts:
    def __init__(self, *, read: typing.Optional[builtins.str] = None) -> None:
        """
        :param read: 
        """
        self._values: typing.Dict[str, typing.Any] = {}
        if read is not None:
            self._values["read"] = read

    @builtins.property
    def read(self) -> typing.Optional[builtins.str]:
        result = self._values.get("read")
        return result

    def __eq__(self, rhs: typing.Any) -> builtins.bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs: typing.Any) -> builtins.bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return "DataAzurermEventhubNamespaceTimeouts(%s)" % ", ".join(
            k + "=" + repr(v) for k, v in self._values.items()
        )


class DataAzurermExpressRouteCircuit(
    cdktf.TerraformDataSource,
    metaclass=jsii.JSIIMeta,
    jsii_type="@cdktf/provider-azurerm.DataAzurermExpressRouteCircuit",
):
    def __init__(
        self,
        scope: constructs.Construct,
        id: builtins.str,
        *,
        name: builtins.str,
        resource_group_name: builtins.str,
        timeouts: typing.Optional["DataAzurermExpressRouteCircuitTimeouts"] = None,
        count: typing.Optional[jsii.Number] = None,
        depends_on: typing.Optional[typing.List[cdktf.TerraformResource]] = None,
        lifecycle: typing.Optional[cdktf.TerraformResourceLifecycle] = None,
        provider: typing.Optional[cdktf.TerraformProvider] = None,
    ) -> None:
        """
        :param scope: -
        :param id: -
        :param name: 
        :param resource_group_name: 
        :param timeouts: timeouts block.
        :param count: 
        :param depends_on: 
        :param lifecycle: 
        :param provider: 
        """
        config = DataAzurermExpressRouteCircuitConfig(
            name=name,
            resource_group_name=resource_group_name,
            timeouts=timeouts,
            count=count,
            depends_on=depends_on,
            lifecycle=lifecycle,
            provider=provider,
        )

        jsii.create(DataAzurermExpressRouteCircuit, self, [scope, id, config])

    @jsii.member(jsii_name="peerings")
    def peerings(self, index: builtins.str) -> "DataAzurermExpressRouteCircuitPeerings":
        """
        :param index: -
        """
        return jsii.invoke(self, "peerings", [index])

    @jsii.member(jsii_name="serviceProviderProperties")
    def service_provider_properties(
        self,
        index: builtins.str,
    ) -> "DataAzurermExpressRouteCircuitServiceProviderProperties":
        """
        :param index: -
        """
        return jsii.invoke(self, "serviceProviderProperties", [index])

    @jsii.member(jsii_name="sku")
    def sku(self, index: builtins.str) -> "DataAzurermExpressRouteCircuitSku":
        """
        :param index: -
        """
        return jsii.invoke(self, "sku", [index])

    @jsii.member(jsii_name="synthesizeAttributes")
    def _synthesize_attributes(self) -> typing.Mapping[builtins.str, typing.Any]:
        return jsii.invoke(self, "synthesizeAttributes", [])

    @builtins.property # type: ignore
    @jsii.member(jsii_name="location")
    def location(self) -> builtins.str:
        return jsii.get(self, "location")

    @builtins.property # type: ignore
    @jsii.member(jsii_name="serviceKey")
    def service_key(self) -> builtins.str:
        return jsii.get(self, "serviceKey")

    @builtins.property # type: ignore
    @jsii.member(jsii_name="serviceProviderProvisioningState")
    def service_provider_provisioning_state(self) -> builtins.str:
        return jsii.get(self, "serviceProviderProvisioningState")

    @builtins.property # type: ignore
    @jsii.member(jsii_name="name")
    def name(self) -> builtins.str:
        return jsii.get(self, "name")

    @name.setter # type: ignore
    def name(self, value: builtins.str) -> None:
        jsii.set(self, "name", value)

    @builtins.property # type: ignore
    @jsii.member(jsii_name="resourceGroupName")
    def resource_group_name(self) -> builtins.str:
        return jsii.get(self, "resourceGroupName")

    @resource_group_name.setter # type: ignore
    def resource_group_name(self, value: builtins.str) -> None:
        jsii.set(self, "resourceGroupName", value)

    @builtins.property # type: ignore
    @jsii.member(jsii_name="id")
    def id(self) -> typing.Optional[builtins.str]:
        return jsii.get(self, "id")

    @id.setter # type: ignore
    def id(self, value: typing.Optional[builtins.str]) -> None:
        jsii.set(self, "id", value)

    @builtins.property # type: ignore
    @jsii.member(jsii_name="timeouts")
    def timeouts(self) -> typing.Optional["DataAzurermExpressRouteCircuitTimeouts"]:
        return jsii.get(self, "timeouts")

    @timeouts.setter # type: ignore
    def timeouts(
        self,
        value: typing.Optional["DataAzurermExpressRouteCircuitTimeouts"],
    ) -> None:
        jsii.set(self, "timeouts", value)


@jsii.data_type(
    jsii_type="@cdktf/provider-azurerm.DataAzurermExpressRouteCircuitConfig",
    jsii_struct_bases=[cdktf.TerraformMetaArguments],
    name_mapping={
        "count": "count",
        "depends_on": "dependsOn",
        "lifecycle": "lifecycle",
        "provider": "provider",
        "name": "name",
        "resource_group_name": "resourceGroupName",
        "timeouts": "timeouts",
    },
)
class DataAzurermExpressRouteCircuitConfig(cdktf.TerraformMetaArguments):
    def __init__(
        self,
        *,
        count: typing.Optional[jsii.Number] = None,
        depends_on: typing.Optional[typing.List[cdktf.TerraformResource]] = None,
        lifecycle: typing.Optional[cdktf.TerraformResourceLifecycle] = None,
        provider: typing.Optional[cdktf.TerraformProvider] = None,
        name: builtins.str,
        resource_group_name: builtins.str,
        timeouts: typing.Optional["DataAzurermExpressRouteCircuitTimeouts"] = None,
    ) -> None:
        """
        :param count: 
        :param depends_on: 
        :param lifecycle: 
        :param provider: 
        :param name: 
        :param resource_group_name: 
        :param timeouts: timeouts block.
        """
        if isinstance(lifecycle, dict):
            lifecycle = cdktf.TerraformResourceLifecycle(**lifecycle)
        if isinstance(timeouts, dict):
            timeouts = DataAzurermExpressRouteCircuitTimeouts(**timeouts)
        self._values: typing.Dict[str, typing.Any] = {
            "name": name,
            "resource_group_name": resource_group_name,
        }
        if count is not None:
            self._values["count"] = count
        if depends_on is not None:
            self._values["depends_on"] = depends_on
        if lifecycle is not None:
            self._values["lifecycle"] = lifecycle
        if provider is not None:
            self._values["provider"] = provider
        if timeouts is not None:
            self._values["timeouts"] = timeouts

    @builtins.property
    def count(self) -> typing.Optional[jsii.Number]:
        """
        :stability: experimental
        """
        result = self._values.get("count")
        return result

    @builtins.property
    def depends_on(self) -> typing.Optional[typing.List[cdktf.TerraformResource]]:
        """
        :stability: experimental
        """
        result = self._values.get("depends_on")
        return result

    @builtins.property
    def lifecycle(self) -> typing.Optional[cdktf.TerraformResourceLifecycle]:
        """
        :stability: experimental
        """
        result = self._values.get("lifecycle")
        return result

    @builtins.property
    def provider(self) -> typing.Optional[cdktf.TerraformProvider]:
        """
        :stability: experimental
        """
        result = self._values.get("provider")
        return result

    @builtins.property
    def name(self) -> builtins.str:
        result = self._values.get("name")
        assert result is not None, "Required property 'name' is missing"
        return result

    @builtins.property
    def resource_group_name(self) -> builtins.str:
        result = self._values.get("resource_group_name")
        assert result is not None, "Required property 'resource_group_name' is missing"
        return result

    @builtins.property
    def timeouts(self) -> typing.Optional["DataAzurermExpressRouteCircuitTimeouts"]:
        """timeouts block."""
        result = self._values.get("timeouts")
        return result

    def __eq__(self, rhs: typing.Any) -> builtins.bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs: typing.Any) -> builtins.bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return "DataAzurermExpressRouteCircuitConfig(%s)" % ", ".join(
            k + "=" + repr(v) for k, v in self._values.items()
        )


class DataAzurermExpressRouteCircuitPeerings(
    cdktf.ComplexComputedList,
    metaclass=jsii.JSIIMeta,
    jsii_type="@cdktf/provider-azurerm.DataAzurermExpressRouteCircuitPeerings",
):
    def __init__(
        self,
        terraform_resource: cdktf.ITerraformResource,
        terraform_attribute: builtins.str,
        index: builtins.str,
    ) -> None:
        """
        :param terraform_resource: -
        :param terraform_attribute: -
        :param index: -

        :stability: experimental
        """
        jsii.create(DataAzurermExpressRouteCircuitPeerings, self, [terraform_resource, terraform_attribute, index])

    @builtins.property # type: ignore
    @jsii.member(jsii_name="azureAsn")
    def azure_asn(self) -> jsii.Number:
        return jsii.get(self, "azureAsn")

    @builtins.property # type: ignore
    @jsii.member(jsii_name="peerAsn")
    def peer_asn(self) -> jsii.Number:
        return jsii.get(self, "peerAsn")

    @builtins.property # type: ignore
    @jsii.member(jsii_name="peeringType")
    def peering_type(self) -> builtins.str:
        return jsii.get(self, "peeringType")

    @builtins.property # type: ignore
    @jsii.member(jsii_name="primaryPeerAddressPrefix")
    def primary_peer_address_prefix(self) -> builtins.str:
        return jsii.get(self, "primaryPeerAddressPrefix")

    @builtins.property # type: ignore
    @jsii.member(jsii_name="secondaryPeerAddressPrefix")
    def secondary_peer_address_prefix(self) -> builtins.str:
        return jsii.get(self, "secondaryPeerAddressPrefix")

    @builtins.property # type: ignore
    @jsii.member(jsii_name="sharedKey")
    def shared_key(self) -> builtins.str:
        return jsii.get(self, "sharedKey")

    @builtins.property # type: ignore
    @jsii.member(jsii_name="vlanId")
    def vlan_id(self) -> jsii.Number:
        return jsii.get(self, "vlanId")


class DataAzurermExpressRouteCircuitServiceProviderProperties(
    cdktf.ComplexComputedList,
    metaclass=jsii.JSIIMeta,
    jsii_type="@cdktf/provider-azurerm.DataAzurermExpressRouteCircuitServiceProviderProperties",
):
    def __init__(
        self,
        terraform_resource: cdktf.ITerraformResource,
        terraform_attribute: builtins.str,
        index: builtins.str,
    ) -> None:
        """
        :param terraform_resource: -
        :param terraform_attribute: -
        :param index: -

        :stability: experimental
        """
        jsii.create(DataAzurermExpressRouteCircuitServiceProviderProperties, self, [terraform_resource, terraform_attribute, index])

    @builtins.property # type: ignore
    @jsii.member(jsii_name="bandwidthInMbps")
    def bandwidth_in_mbps(self) -> jsii.Number:
        return jsii.get(self, "bandwidthInMbps")

    @builtins.property # type: ignore
    @jsii.member(jsii_name="peeringLocation")
    def peering_location(self) -> builtins.str:
        return jsii.get(self, "peeringLocation")

    @builtins.property # type: ignore
    @jsii.member(jsii_name="serviceProviderName")
    def service_provider_name(self) -> builtins.str:
        return jsii.get(self, "serviceProviderName")


class DataAzurermExpressRouteCircuitSku(
    cdktf.ComplexComputedList,
    metaclass=jsii.JSIIMeta,
    jsii_type="@cdktf/provider-azurerm.DataAzurermExpressRouteCircuitSku",
):
    def __init__(
        self,
        terraform_resource: cdktf.ITerraformResource,
        terraform_attribute: builtins.str,
        index: builtins.str,
    ) -> None:
        """
        :param terraform_resource: -
        :param terraform_attribute: -
        :param index: -

        :stability: experimental
        """
        jsii.create(DataAzurermExpressRouteCircuitSku, self, [terraform_resource, terraform_attribute, index])

    @builtins.property # type: ignore
    @jsii.member(jsii_name="family")
    def family(self) -> builtins.str:
        return jsii.get(self, "family")

    @builtins.property # type: ignore
    @jsii.member(jsii_name="tier")
    def tier(self) -> builtins.str:
        return jsii.get(self, "tier")


@jsii.data_type(
    jsii_type="@cdktf/provider-azurerm.DataAzurermExpressRouteCircuitTimeouts",
    jsii_struct_bases=[],
    name_mapping={"read": "read"},
)
class DataAzurermExpressRouteCircuitTimeouts:
    def __init__(self, *, read: typing.Optional[builtins.str] = None) -> None:
        """
        :param read: 
        """
        self._values: typing.Dict[str, typing.Any] = {}
        if read is not None:
            self._values["read"] = read

    @builtins.property
    def read(self) -> typing.Optional[builtins.str]:
        result = self._values.get("read")
        return result

    def __eq__(self, rhs: typing.Any) -> builtins.bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs: typing.Any) -> builtins.bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return "DataAzurermExpressRouteCircuitTimeouts(%s)" % ", ".join(
            k + "=" + repr(v) for k, v in self._values.items()
        )


class DataAzurermFirewall(
    cdktf.TerraformDataSource,
    metaclass=jsii.JSIIMeta,
    jsii_type="@cdktf/provider-azurerm.DataAzurermFirewall",
):
    def __init__(
        self,
        scope: constructs.Construct,
        id: builtins.str,
        *,
        name: builtins.str,
        resource_group_name: builtins.str,
        timeouts: typing.Optional["DataAzurermFirewallTimeouts"] = None,
        count: typing.Optional[jsii.Number] = None,
        depends_on: typing.Optional[typing.List[cdktf.TerraformResource]] = None,
        lifecycle: typing.Optional[cdktf.TerraformResourceLifecycle] = None,
        provider: typing.Optional[cdktf.TerraformProvider] = None,
    ) -> None:
        """
        :param scope: -
        :param id: -
        :param name: 
        :param resource_group_name: 
        :param timeouts: timeouts block.
        :param count: 
        :param depends_on: 
        :param lifecycle: 
        :param provider: 
        """
        config = DataAzurermFirewallConfig(
            name=name,
            resource_group_name=resource_group_name,
            timeouts=timeouts,
            count=count,
            depends_on=depends_on,
            lifecycle=lifecycle,
            provider=provider,
        )

        jsii.create(DataAzurermFirewall, self, [scope, id, config])

    @jsii.member(jsii_name="ipConfiguration")
    def ip_configuration(
        self,
        index: builtins.str,
    ) -> "DataAzurermFirewallIpConfiguration":
        """
        :param index: -
        """
        return jsii.invoke(self, "ipConfiguration", [index])

    @jsii.member(jsii_name="synthesizeAttributes")
    def _synthesize_attributes(self) -> typing.Mapping[builtins.str, typing.Any]:
        return jsii.invoke(self, "synthesizeAttributes", [])

    @jsii.member(jsii_name="tags")
    def tags(self, key: builtins.str) -> builtins.str:
        """
        :param key: -
        """
        return jsii.invoke(self, "tags", [key])

    @builtins.property # type: ignore
    @jsii.member(jsii_name="location")
    def location(self) -> builtins.str:
        return jsii.get(self, "location")

    @builtins.property # type: ignore
    @jsii.member(jsii_name="name")
    def name(self) -> builtins.str:
        return jsii.get(self, "name")

    @name.setter # type: ignore
    def name(self, value: builtins.str) -> None:
        jsii.set(self, "name", value)

    @builtins.property # type: ignore
    @jsii.member(jsii_name="resourceGroupName")
    def resource_group_name(self) -> builtins.str:
        return jsii.get(self, "resourceGroupName")

    @resource_group_name.setter # type: ignore
    def resource_group_name(self, value: builtins.str) -> None:
        jsii.set(self, "resourceGroupName", value)

    @builtins.property # type: ignore
    @jsii.member(jsii_name="id")
    def id(self) -> typing.Optional[builtins.str]:
        return jsii.get(self, "id")

    @id.setter # type: ignore
    def id(self, value: typing.Optional[builtins.str]) -> None:
        jsii.set(self, "id", value)

    @builtins.property # type: ignore
    @jsii.member(jsii_name="timeouts")
    def timeouts(self) -> typing.Optional["DataAzurermFirewallTimeouts"]:
        return jsii.get(self, "timeouts")

    @timeouts.setter # type: ignore
    def timeouts(self, value: typing.Optional["DataAzurermFirewallTimeouts"]) -> None:
        jsii.set(self, "timeouts", value)


@jsii.data_type(
    jsii_type="@cdktf/provider-azurerm.DataAzurermFirewallConfig",
    jsii_struct_bases=[cdktf.TerraformMetaArguments],
    name_mapping={
        "count": "count",
        "depends_on": "dependsOn",
        "lifecycle": "lifecycle",
        "provider": "provider",
        "name": "name",
        "resource_group_name": "resourceGroupName",
        "timeouts": "timeouts",
    },
)
class DataAzurermFirewallConfig(cdktf.TerraformMetaArguments):
    def __init__(
        self,
        *,
        count: typing.Optional[jsii.Number] = None,
        depends_on: typing.Optional[typing.List[cdktf.TerraformResource]] = None,
        lifecycle: typing.Optional[cdktf.TerraformResourceLifecycle] = None,
        provider: typing.Optional[cdktf.TerraformProvider] = None,
        name: builtins.str,
        resource_group_name: builtins.str,
        timeouts: typing.Optional["DataAzurermFirewallTimeouts"] = None,
    ) -> None:
        """
        :param count: 
        :param depends_on: 
        :param lifecycle: 
        :param provider: 
        :param name: 
        :param resource_group_name: 
        :param timeouts: timeouts block.
        """
        if isinstance(lifecycle, dict):
            lifecycle = cdktf.TerraformResourceLifecycle(**lifecycle)
        if isinstance(timeouts, dict):
            timeouts = DataAzurermFirewallTimeouts(**timeouts)
        self._values: typing.Dict[str, typing.Any] = {
            "name": name,
            "resource_group_name": resource_group_name,
        }
        if count is not None:
            self._values["count"] = count
        if depends_on is not None:
            self._values["depends_on"] = depends_on
        if lifecycle is not None:
            self._values["lifecycle"] = lifecycle
        if provider is not None:
            self._values["provider"] = provider
        if timeouts is not None:
            self._values["timeouts"] = timeouts

    @builtins.property
    def count(self) -> typing.Optional[jsii.Number]:
        """
        :stability: experimental
        """
        result = self._values.get("count")
        return result

    @builtins.property
    def depends_on(self) -> typing.Optional[typing.List[cdktf.TerraformResource]]:
        """
        :stability: experimental
        """
        result = self._values.get("depends_on")
        return result

    @builtins.property
    def lifecycle(self) -> typing.Optional[cdktf.TerraformResourceLifecycle]:
        """
        :stability: experimental
        """
        result = self._values.get("lifecycle")
        return result

    @builtins.property
    def provider(self) -> typing.Optional[cdktf.TerraformProvider]:
        """
        :stability: experimental
        """
        result = self._values.get("provider")
        return result

    @builtins.property
    def name(self) -> builtins.str:
        result = self._values.get("name")
        assert result is not None, "Required property 'name' is missing"
        return result

    @builtins.property
    def resource_group_name(self) -> builtins.str:
        result = self._values.get("resource_group_name")
        assert result is not None, "Required property 'resource_group_name' is missing"
        return result

    @builtins.property
    def timeouts(self) -> typing.Optional["DataAzurermFirewallTimeouts"]:
        """timeouts block."""
        result = self._values.get("timeouts")
        return result

    def __eq__(self, rhs: typing.Any) -> builtins.bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs: typing.Any) -> builtins.bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return "DataAzurermFirewallConfig(%s)" % ", ".join(
            k + "=" + repr(v) for k, v in self._values.items()
        )


class DataAzurermFirewallIpConfiguration(
    cdktf.ComplexComputedList,
    metaclass=jsii.JSIIMeta,
    jsii_type="@cdktf/provider-azurerm.DataAzurermFirewallIpConfiguration",
):
    def __init__(
        self,
        terraform_resource: cdktf.ITerraformResource,
        terraform_attribute: builtins.str,
        index: builtins.str,
    ) -> None:
        """
        :param terraform_resource: -
        :param terraform_attribute: -
        :param index: -

        :stability: experimental
        """
        jsii.create(DataAzurermFirewallIpConfiguration, self, [terraform_resource, terraform_attribute, index])

    @builtins.property # type: ignore
    @jsii.member(jsii_name="internalPublicIpAddressId")
    def internal_public_ip_address_id(self) -> builtins.str:
        return jsii.get(self, "internalPublicIpAddressId")

    @builtins.property # type: ignore
    @jsii.member(jsii_name="name")
    def name(self) -> builtins.str:
        return jsii.get(self, "name")

    @builtins.property # type: ignore
    @jsii.member(jsii_name="privateIpAddress")
    def private_ip_address(self) -> builtins.str:
        return jsii.get(self, "privateIpAddress")

    @builtins.property # type: ignore
    @jsii.member(jsii_name="publicIpAddressId")
    def public_ip_address_id(self) -> builtins.str:
        return jsii.get(self, "publicIpAddressId")

    @builtins.property # type: ignore
    @jsii.member(jsii_name="subnetId")
    def subnet_id(self) -> builtins.str:
        return jsii.get(self, "subnetId")


@jsii.data_type(
    jsii_type="@cdktf/provider-azurerm.DataAzurermFirewallTimeouts",
    jsii_struct_bases=[],
    name_mapping={"read": "read"},
)
class DataAzurermFirewallTimeouts:
    def __init__(self, *, read: typing.Optional[builtins.str] = None) -> None:
        """
        :param read: 
        """
        self._values: typing.Dict[str, typing.Any] = {}
        if read is not None:
            self._values["read"] = read

    @builtins.property
    def read(self) -> typing.Optional[builtins.str]:
        result = self._values.get("read")
        return result

    def __eq__(self, rhs: typing.Any) -> builtins.bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs: typing.Any) -> builtins.bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return "DataAzurermFirewallTimeouts(%s)" % ", ".join(
            k + "=" + repr(v) for k, v in self._values.items()
        )


class DataAzurermFunctionApp(
    cdktf.TerraformDataSource,
    metaclass=jsii.JSIIMeta,
    jsii_type="@cdktf/provider-azurerm.DataAzurermFunctionApp",
):
    def __init__(
        self,
        scope: constructs.Construct,
        id: builtins.str,
        *,
        name: builtins.str,
        resource_group_name: builtins.str,
        tags: typing.Optional[typing.Mapping[builtins.str, builtins.str]] = None,
        timeouts: typing.Optional["DataAzurermFunctionAppTimeouts"] = None,
        count: typing.Optional[jsii.Number] = None,
        depends_on: typing.Optional[typing.List[cdktf.TerraformResource]] = None,
        lifecycle: typing.Optional[cdktf.TerraformResourceLifecycle] = None,
        provider: typing.Optional[cdktf.TerraformProvider] = None,
    ) -> None:
        """
        :param scope: -
        :param id: -
        :param name: 
        :param resource_group_name: 
        :param tags: 
        :param timeouts: timeouts block.
        :param count: 
        :param depends_on: 
        :param lifecycle: 
        :param provider: 
        """
        config = DataAzurermFunctionAppConfig(
            name=name,
            resource_group_name=resource_group_name,
            tags=tags,
            timeouts=timeouts,
            count=count,
            depends_on=depends_on,
            lifecycle=lifecycle,
            provider=provider,
        )

        jsii.create(DataAzurermFunctionApp, self, [scope, id, config])

    @jsii.member(jsii_name="appSettings")
    def app_settings(self, key: builtins.str) -> builtins.str:
        """
        :param key: -
        """
        return jsii.invoke(self, "appSettings", [key])

    @jsii.member(jsii_name="connectionString")
    def connection_string(
        self,
        index: builtins.str,
    ) -> "DataAzurermFunctionAppConnectionString":
        """
        :param index: -
        """
        return jsii.invoke(self, "connectionString", [index])

    @jsii.member(jsii_name="siteCredential")
    def site_credential(
        self,
        index: builtins.str,
    ) -> "DataAzurermFunctionAppSiteCredential":
        """
        :param index: -
        """
        return jsii.invoke(self, "siteCredential", [index])

    @jsii.member(jsii_name="synthesizeAttributes")
    def _synthesize_attributes(self) -> typing.Mapping[builtins.str, typing.Any]:
        return jsii.invoke(self, "synthesizeAttributes", [])

    @builtins.property # type: ignore
    @jsii.member(jsii_name="appServicePlanId")
    def app_service_plan_id(self) -> builtins.str:
        return jsii.get(self, "appServicePlanId")

    @builtins.property # type: ignore
    @jsii.member(jsii_name="defaultHostname")
    def default_hostname(self) -> builtins.str:
        return jsii.get(self, "defaultHostname")

    @builtins.property # type: ignore
    @jsii.member(jsii_name="enabled")
    def enabled(self) -> builtins.bool:
        return jsii.get(self, "enabled")

    @builtins.property # type: ignore
    @jsii.member(jsii_name="location")
    def location(self) -> builtins.str:
        return jsii.get(self, "location")

    @builtins.property # type: ignore
    @jsii.member(jsii_name="outboundIpAddresses")
    def outbound_ip_addresses(self) -> builtins.str:
        return jsii.get(self, "outboundIpAddresses")

    @builtins.property # type: ignore
    @jsii.member(jsii_name="possibleOutboundIpAddresses")
    def possible_outbound_ip_addresses(self) -> builtins.str:
        return jsii.get(self, "possibleOutboundIpAddresses")

    @builtins.property # type: ignore
    @jsii.member(jsii_name="name")
    def name(self) -> builtins.str:
        return jsii.get(self, "name")

    @name.setter # type: ignore
    def name(self, value: builtins.str) -> None:
        jsii.set(self, "name", value)

    @builtins.property # type: ignore
    @jsii.member(jsii_name="resourceGroupName")
    def resource_group_name(self) -> builtins.str:
        return jsii.get(self, "resourceGroupName")

    @resource_group_name.setter # type: ignore
    def resource_group_name(self, value: builtins.str) -> None:
        jsii.set(self, "resourceGroupName", value)

    @builtins.property # type: ignore
    @jsii.member(jsii_name="id")
    def id(self) -> typing.Optional[builtins.str]:
        return jsii.get(self, "id")

    @id.setter # type: ignore
    def id(self, value: typing.Optional[builtins.str]) -> None:
        jsii.set(self, "id", value)

    @builtins.property # type: ignore
    @jsii.member(jsii_name="tags")
    def tags(self) -> typing.Optional[typing.Mapping[builtins.str, builtins.str]]:
        return jsii.get(self, "tags")

    @tags.setter # type: ignore
    def tags(
        self,
        value: typing.Optional[typing.Mapping[builtins.str, builtins.str]],
    ) -> None:
        jsii.set(self, "tags", value)

    @builtins.property # type: ignore
    @jsii.member(jsii_name="timeouts")
    def timeouts(self) -> typing.Optional["DataAzurermFunctionAppTimeouts"]:
        return jsii.get(self, "timeouts")

    @timeouts.setter # type: ignore
    def timeouts(
        self,
        value: typing.Optional["DataAzurermFunctionAppTimeouts"],
    ) -> None:
        jsii.set(self, "timeouts", value)


@jsii.data_type(
    jsii_type="@cdktf/provider-azurerm.DataAzurermFunctionAppConfig",
    jsii_struct_bases=[cdktf.TerraformMetaArguments],
    name_mapping={
        "count": "count",
        "depends_on": "dependsOn",
        "lifecycle": "lifecycle",
        "provider": "provider",
        "name": "name",
        "resource_group_name": "resourceGroupName",
        "tags": "tags",
        "timeouts": "timeouts",
    },
)
class DataAzurermFunctionAppConfig(cdktf.TerraformMetaArguments):
    def __init__(
        self,
        *,
        count: typing.Optional[jsii.Number] = None,
        depends_on: typing.Optional[typing.List[cdktf.TerraformResource]] = None,
        lifecycle: typing.Optional[cdktf.TerraformResourceLifecycle] = None,
        provider: typing.Optional[cdktf.TerraformProvider] = None,
        name: builtins.str,
        resource_group_name: builtins.str,
        tags: typing.Optional[typing.Mapping[builtins.str, builtins.str]] = None,
        timeouts: typing.Optional["DataAzurermFunctionAppTimeouts"] = None,
    ) -> None:
        """
        :param count: 
        :param depends_on: 
        :param lifecycle: 
        :param provider: 
        :param name: 
        :param resource_group_name: 
        :param tags: 
        :param timeouts: timeouts block.
        """
        if isinstance(lifecycle, dict):
            lifecycle = cdktf.TerraformResourceLifecycle(**lifecycle)
        if isinstance(timeouts, dict):
            timeouts = DataAzurermFunctionAppTimeouts(**timeouts)
        self._values: typing.Dict[str, typing.Any] = {
            "name": name,
            "resource_group_name": resource_group_name,
        }
        if count is not None:
            self._values["count"] = count
        if depends_on is not None:
            self._values["depends_on"] = depends_on
        if lifecycle is not None:
            self._values["lifecycle"] = lifecycle
        if provider is not None:
            self._values["provider"] = provider
        if tags is not None:
            self._values["tags"] = tags
        if timeouts is not None:
            self._values["timeouts"] = timeouts

    @builtins.property
    def count(self) -> typing.Optional[jsii.Number]:
        """
        :stability: experimental
        """
        result = self._values.get("count")
        return result

    @builtins.property
    def depends_on(self) -> typing.Optional[typing.List[cdktf.TerraformResource]]:
        """
        :stability: experimental
        """
        result = self._values.get("depends_on")
        return result

    @builtins.property
    def lifecycle(self) -> typing.Optional[cdktf.TerraformResourceLifecycle]:
        """
        :stability: experimental
        """
        result = self._values.get("lifecycle")
        return result

    @builtins.property
    def provider(self) -> typing.Optional[cdktf.TerraformProvider]:
        """
        :stability: experimental
        """
        result = self._values.get("provider")
        return result

    @builtins.property
    def name(self) -> builtins.str:
        result = self._values.get("name")
        assert result is not None, "Required property 'name' is missing"
        return result

    @builtins.property
    def resource_group_name(self) -> builtins.str:
        result = self._values.get("resource_group_name")
        assert result is not None, "Required property 'resource_group_name' is missing"
        return result

    @builtins.property
    def tags(self) -> typing.Optional[typing.Mapping[builtins.str, builtins.str]]:
        result = self._values.get("tags")
        return result

    @builtins.property
    def timeouts(self) -> typing.Optional["DataAzurermFunctionAppTimeouts"]:
        """timeouts block."""
        result = self._values.get("timeouts")
        return result

    def __eq__(self, rhs: typing.Any) -> builtins.bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs: typing.Any) -> builtins.bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return "DataAzurermFunctionAppConfig(%s)" % ", ".join(
            k + "=" + repr(v) for k, v in self._values.items()
        )


class DataAzurermFunctionAppConnectionString(
    cdktf.ComplexComputedList,
    metaclass=jsii.JSIIMeta,
    jsii_type="@cdktf/provider-azurerm.DataAzurermFunctionAppConnectionString",
):
    def __init__(
        self,
        terraform_resource: cdktf.ITerraformResource,
        terraform_attribute: builtins.str,
        index: builtins.str,
    ) -> None:
        """
        :param terraform_resource: -
        :param terraform_attribute: -
        :param index: -

        :stability: experimental
        """
        jsii.create(DataAzurermFunctionAppConnectionString, self, [terraform_resource, terraform_attribute, index])

    @builtins.property # type: ignore
    @jsii.member(jsii_name="name")
    def name(self) -> builtins.str:
        return jsii.get(self, "name")

    @builtins.property # type: ignore
    @jsii.member(jsii_name="type")
    def type(self) -> builtins.str:
        return jsii.get(self, "type")

    @builtins.property # type: ignore
    @jsii.member(jsii_name="value")
    def value(self) -> builtins.str:
        return jsii.get(self, "value")


class DataAzurermFunctionAppSiteCredential(
    cdktf.ComplexComputedList,
    metaclass=jsii.JSIIMeta,
    jsii_type="@cdktf/provider-azurerm.DataAzurermFunctionAppSiteCredential",
):
    def __init__(
        self,
        terraform_resource: cdktf.ITerraformResource,
        terraform_attribute: builtins.str,
        index: builtins.str,
    ) -> None:
        """
        :param terraform_resource: -
        :param terraform_attribute: -
        :param index: -

        :stability: experimental
        """
        jsii.create(DataAzurermFunctionAppSiteCredential, self, [terraform_resource, terraform_attribute, index])

    @builtins.property # type: ignore
    @jsii.member(jsii_name="password")
    def password(self) -> builtins.str:
        return jsii.get(self, "password")

    @builtins.property # type: ignore
    @jsii.member(jsii_name="username")
    def username(self) -> builtins.str:
        return jsii.get(self, "username")


@jsii.data_type(
    jsii_type="@cdktf/provider-azurerm.DataAzurermFunctionAppTimeouts",
    jsii_struct_bases=[],
    name_mapping={"read": "read"},
)
class DataAzurermFunctionAppTimeouts:
    def __init__(self, *, read: typing.Optional[builtins.str] = None) -> None:
        """
        :param read: 
        """
        self._values: typing.Dict[str, typing.Any] = {}
        if read is not None:
            self._values["read"] = read

    @builtins.property
    def read(self) -> typing.Optional[builtins.str]:
        result = self._values.get("read")
        return result

    def __eq__(self, rhs: typing.Any) -> builtins.bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs: typing.Any) -> builtins.bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return "DataAzurermFunctionAppTimeouts(%s)" % ", ".join(
            k + "=" + repr(v) for k, v in self._values.items()
        )


class DataAzurermHdinsightCluster(
    cdktf.TerraformDataSource,
    metaclass=jsii.JSIIMeta,
    jsii_type="@cdktf/provider-azurerm.DataAzurermHdinsightCluster",
):
    def __init__(
        self,
        scope: constructs.Construct,
        id: builtins.str,
        *,
        name: builtins.str,
        resource_group_name: builtins.str,
        timeouts: typing.Optional["DataAzurermHdinsightClusterTimeouts"] = None,
        count: typing.Optional[jsii.Number] = None,
        depends_on: typing.Optional[typing.List[cdktf.TerraformResource]] = None,
        lifecycle: typing.Optional[cdktf.TerraformResourceLifecycle] = None,
        provider: typing.Optional[cdktf.TerraformProvider] = None,
    ) -> None:
        """
        :param scope: -
        :param id: -
        :param name: 
        :param resource_group_name: 
        :param timeouts: timeouts block.
        :param count: 
        :param depends_on: 
        :param lifecycle: 
        :param provider: 
        """
        config = DataAzurermHdinsightClusterConfig(
            name=name,
            resource_group_name=resource_group_name,
            timeouts=timeouts,
            count=count,
            depends_on=depends_on,
            lifecycle=lifecycle,
            provider=provider,
        )

        jsii.create(DataAzurermHdinsightCluster, self, [scope, id, config])

    @jsii.member(jsii_name="componentVersions")
    def component_versions(self, key: builtins.str) -> builtins.str:
        """
        :param key: -
        """
        return jsii.invoke(self, "componentVersions", [key])

    @jsii.member(jsii_name="gateway")
    def gateway(self, index: builtins.str) -> "DataAzurermHdinsightClusterGateway":
        """
        :param index: -
        """
        return jsii.invoke(self, "gateway", [index])

    @jsii.member(jsii_name="synthesizeAttributes")
    def _synthesize_attributes(self) -> typing.Mapping[builtins.str, typing.Any]:
        return jsii.invoke(self, "synthesizeAttributes", [])

    @jsii.member(jsii_name="tags")
    def tags(self, key: builtins.str) -> builtins.str:
        """
        :param key: -
        """
        return jsii.invoke(self, "tags", [key])

    @builtins.property # type: ignore
    @jsii.member(jsii_name="clusterVersion")
    def cluster_version(self) -> builtins.str:
        return jsii.get(self, "clusterVersion")

    @builtins.property # type: ignore
    @jsii.member(jsii_name="edgeSshEndpoint")
    def edge_ssh_endpoint(self) -> builtins.str:
        return jsii.get(self, "edgeSshEndpoint")

    @builtins.property # type: ignore
    @jsii.member(jsii_name="httpsEndpoint")
    def https_endpoint(self) -> builtins.str:
        return jsii.get(self, "httpsEndpoint")

    @builtins.property # type: ignore
    @jsii.member(jsii_name="kind")
    def kind(self) -> builtins.str:
        return jsii.get(self, "kind")

    @builtins.property # type: ignore
    @jsii.member(jsii_name="location")
    def location(self) -> builtins.str:
        return jsii.get(self, "location")

    @builtins.property # type: ignore
    @jsii.member(jsii_name="sshEndpoint")
    def ssh_endpoint(self) -> builtins.str:
        return jsii.get(self, "sshEndpoint")

    @builtins.property # type: ignore
    @jsii.member(jsii_name="tier")
    def tier(self) -> builtins.str:
        return jsii.get(self, "tier")

    @builtins.property # type: ignore
    @jsii.member(jsii_name="name")
    def name(self) -> builtins.str:
        return jsii.get(self, "name")

    @name.setter # type: ignore
    def name(self, value: builtins.str) -> None:
        jsii.set(self, "name", value)

    @builtins.property # type: ignore
    @jsii.member(jsii_name="resourceGroupName")
    def resource_group_name(self) -> builtins.str:
        return jsii.get(self, "resourceGroupName")

    @resource_group_name.setter # type: ignore
    def resource_group_name(self, value: builtins.str) -> None:
        jsii.set(self, "resourceGroupName", value)

    @builtins.property # type: ignore
    @jsii.member(jsii_name="id")
    def id(self) -> typing.Optional[builtins.str]:
        return jsii.get(self, "id")

    @id.setter # type: ignore
    def id(self, value: typing.Optional[builtins.str]) -> None:
        jsii.set(self, "id", value)

    @builtins.property # type: ignore
    @jsii.member(jsii_name="timeouts")
    def timeouts(self) -> typing.Optional["DataAzurermHdinsightClusterTimeouts"]:
        return jsii.get(self, "timeouts")

    @timeouts.setter # type: ignore
    def timeouts(
        self,
        value: typing.Optional["DataAzurermHdinsightClusterTimeouts"],
    ) -> None:
        jsii.set(self, "timeouts", value)


@jsii.data_type(
    jsii_type="@cdktf/provider-azurerm.DataAzurermHdinsightClusterConfig",
    jsii_struct_bases=[cdktf.TerraformMetaArguments],
    name_mapping={
        "count": "count",
        "depends_on": "dependsOn",
        "lifecycle": "lifecycle",
        "provider": "provider",
        "name": "name",
        "resource_group_name": "resourceGroupName",
        "timeouts": "timeouts",
    },
)
class DataAzurermHdinsightClusterConfig(cdktf.TerraformMetaArguments):
    def __init__(
        self,
        *,
        count: typing.Optional[jsii.Number] = None,
        depends_on: typing.Optional[typing.List[cdktf.TerraformResource]] = None,
        lifecycle: typing.Optional[cdktf.TerraformResourceLifecycle] = None,
        provider: typing.Optional[cdktf.TerraformProvider] = None,
        name: builtins.str,
        resource_group_name: builtins.str,
        timeouts: typing.Optional["DataAzurermHdinsightClusterTimeouts"] = None,
    ) -> None:
        """
        :param count: 
        :param depends_on: 
        :param lifecycle: 
        :param provider: 
        :param name: 
        :param resource_group_name: 
        :param timeouts: timeouts block.
        """
        if isinstance(lifecycle, dict):
            lifecycle = cdktf.TerraformResourceLifecycle(**lifecycle)
        if isinstance(timeouts, dict):
            timeouts = DataAzurermHdinsightClusterTimeouts(**timeouts)
        self._values: typing.Dict[str, typing.Any] = {
            "name": name,
            "resource_group_name": resource_group_name,
        }
        if count is not None:
            self._values["count"] = count
        if depends_on is not None:
            self._values["depends_on"] = depends_on
        if lifecycle is not None:
            self._values["lifecycle"] = lifecycle
        if provider is not None:
            self._values["provider"] = provider
        if timeouts is not None:
            self._values["timeouts"] = timeouts

    @builtins.property
    def count(self) -> typing.Optional[jsii.Number]:
        """
        :stability: experimental
        """
        result = self._values.get("count")
        return result

    @builtins.property
    def depends_on(self) -> typing.Optional[typing.List[cdktf.TerraformResource]]:
        """
        :stability: experimental
        """
        result = self._values.get("depends_on")
        return result

    @builtins.property
    def lifecycle(self) -> typing.Optional[cdktf.TerraformResourceLifecycle]:
        """
        :stability: experimental
        """
        result = self._values.get("lifecycle")
        return result

    @builtins.property
    def provider(self) -> typing.Optional[cdktf.TerraformProvider]:
        """
        :stability: experimental
        """
        result = self._values.get("provider")
        return result

    @builtins.property
    def name(self) -> builtins.str:
        result = self._values.get("name")
        assert result is not None, "Required property 'name' is missing"
        return result

    @builtins.property
    def resource_group_name(self) -> builtins.str:
        result = self._values.get("resource_group_name")
        assert result is not None, "Required property 'resource_group_name' is missing"
        return result

    @builtins.property
    def timeouts(self) -> typing.Optional["DataAzurermHdinsightClusterTimeouts"]:
        """timeouts block."""
        result = self._values.get("timeouts")
        return result

    def __eq__(self, rhs: typing.Any) -> builtins.bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs: typing.Any) -> builtins.bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return "DataAzurermHdinsightClusterConfig(%s)" % ", ".join(
            k + "=" + repr(v) for k, v in self._values.items()
        )


class DataAzurermHdinsightClusterGateway(
    cdktf.ComplexComputedList,
    metaclass=jsii.JSIIMeta,
    jsii_type="@cdktf/provider-azurerm.DataAzurermHdinsightClusterGateway",
):
    def __init__(
        self,
        terraform_resource: cdktf.ITerraformResource,
        terraform_attribute: builtins.str,
        index: builtins.str,
    ) -> None:
        """
        :param terraform_resource: -
        :param terraform_attribute: -
        :param index: -

        :stability: experimental
        """
        jsii.create(DataAzurermHdinsightClusterGateway, self, [terraform_resource, terraform_attribute, index])

    @builtins.property # type: ignore
    @jsii.member(jsii_name="enabled")
    def enabled(self) -> builtins.bool:
        return jsii.get(self, "enabled")

    @builtins.property # type: ignore
    @jsii.member(jsii_name="password")
    def password(self) -> builtins.str:
        return jsii.get(self, "password")

    @builtins.property # type: ignore
    @jsii.member(jsii_name="username")
    def username(self) -> builtins.str:
        return jsii.get(self, "username")


@jsii.data_type(
    jsii_type="@cdktf/provider-azurerm.DataAzurermHdinsightClusterTimeouts",
    jsii_struct_bases=[],
    name_mapping={"read": "read"},
)
class DataAzurermHdinsightClusterTimeouts:
    def __init__(self, *, read: typing.Optional[builtins.str] = None) -> None:
        """
        :param read: 
        """
        self._values: typing.Dict[str, typing.Any] = {}
        if read is not None:
            self._values["read"] = read

    @builtins.property
    def read(self) -> typing.Optional[builtins.str]:
        result = self._values.get("read")
        return result

    def __eq__(self, rhs: typing.Any) -> builtins.bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs: typing.Any) -> builtins.bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return "DataAzurermHdinsightClusterTimeouts(%s)" % ", ".join(
            k + "=" + repr(v) for k, v in self._values.items()
        )


class DataAzurermHealthcareService(
    cdktf.TerraformDataSource,
    metaclass=jsii.JSIIMeta,
    jsii_type="@cdktf/provider-azurerm.DataAzurermHealthcareService",
):
    def __init__(
        self,
        scope: constructs.Construct,
        id: builtins.str,
        *,
        location: builtins.str,
        name: builtins.str,
        resource_group_name: builtins.str,
        timeouts: typing.Optional["DataAzurermHealthcareServiceTimeouts"] = None,
        count: typing.Optional[jsii.Number] = None,
        depends_on: typing.Optional[typing.List[cdktf.TerraformResource]] = None,
        lifecycle: typing.Optional[cdktf.TerraformResourceLifecycle] = None,
        provider: typing.Optional[cdktf.TerraformProvider] = None,
    ) -> None:
        """
        :param scope: -
        :param id: -
        :param location: 
        :param name: 
        :param resource_group_name: 
        :param timeouts: timeouts block.
        :param count: 
        :param depends_on: 
        :param lifecycle: 
        :param provider: 
        """
        config = DataAzurermHealthcareServiceConfig(
            location=location,
            name=name,
            resource_group_name=resource_group_name,
            timeouts=timeouts,
            count=count,
            depends_on=depends_on,
            lifecycle=lifecycle,
            provider=provider,
        )

        jsii.create(DataAzurermHealthcareService, self, [scope, id, config])

    @jsii.member(jsii_name="authenticationConfiguration")
    def authentication_configuration(
        self,
        index: builtins.str,
    ) -> "DataAzurermHealthcareServiceAuthenticationConfiguration":
        """
        :param index: -
        """
        return jsii.invoke(self, "authenticationConfiguration", [index])

    @jsii.member(jsii_name="corsConfiguration")
    def cors_configuration(
        self,
        index: builtins.str,
    ) -> "DataAzurermHealthcareServiceCorsConfiguration":
        """
        :param index: -
        """
        return jsii.invoke(self, "corsConfiguration", [index])

    @jsii.member(jsii_name="synthesizeAttributes")
    def _synthesize_attributes(self) -> typing.Mapping[builtins.str, typing.Any]:
        return jsii.invoke(self, "synthesizeAttributes", [])

    @jsii.member(jsii_name="tags")
    def tags(self, key: builtins.str) -> builtins.str:
        """
        :param key: -
        """
        return jsii.invoke(self, "tags", [key])

    @builtins.property # type: ignore
    @jsii.member(jsii_name="accessPolicyObjectIds")
    def access_policy_object_ids(self) -> typing.List[builtins.str]:
        return jsii.get(self, "accessPolicyObjectIds")

    @builtins.property # type: ignore
    @jsii.member(jsii_name="cosmosdbThroughput")
    def cosmosdb_throughput(self) -> jsii.Number:
        return jsii.get(self, "cosmosdbThroughput")

    @builtins.property # type: ignore
    @jsii.member(jsii_name="kind")
    def kind(self) -> builtins.str:
        return jsii.get(self, "kind")

    @builtins.property # type: ignore
    @jsii.member(jsii_name="location")
    def location(self) -> builtins.str:
        return jsii.get(self, "location")

    @location.setter # type: ignore
    def location(self, value: builtins.str) -> None:
        jsii.set(self, "location", value)

    @builtins.property # type: ignore
    @jsii.member(jsii_name="name")
    def name(self) -> builtins.str:
        return jsii.get(self, "name")

    @name.setter # type: ignore
    def name(self, value: builtins.str) -> None:
        jsii.set(self, "name", value)

    @builtins.property # type: ignore
    @jsii.member(jsii_name="resourceGroupName")
    def resource_group_name(self) -> builtins.str:
        return jsii.get(self, "resourceGroupName")

    @resource_group_name.setter # type: ignore
    def resource_group_name(self, value: builtins.str) -> None:
        jsii.set(self, "resourceGroupName", value)

    @builtins.property # type: ignore
    @jsii.member(jsii_name="id")
    def id(self) -> typing.Optional[builtins.str]:
        return jsii.get(self, "id")

    @id.setter # type: ignore
    def id(self, value: typing.Optional[builtins.str]) -> None:
        jsii.set(self, "id", value)

    @builtins.property # type: ignore
    @jsii.member(jsii_name="timeouts")
    def timeouts(self) -> typing.Optional["DataAzurermHealthcareServiceTimeouts"]:
        return jsii.get(self, "timeouts")

    @timeouts.setter # type: ignore
    def timeouts(
        self,
        value: typing.Optional["DataAzurermHealthcareServiceTimeouts"],
    ) -> None:
        jsii.set(self, "timeouts", value)


class DataAzurermHealthcareServiceAuthenticationConfiguration(
    cdktf.ComplexComputedList,
    metaclass=jsii.JSIIMeta,
    jsii_type="@cdktf/provider-azurerm.DataAzurermHealthcareServiceAuthenticationConfiguration",
):
    def __init__(
        self,
        terraform_resource: cdktf.ITerraformResource,
        terraform_attribute: builtins.str,
        index: builtins.str,
    ) -> None:
        """
        :param terraform_resource: -
        :param terraform_attribute: -
        :param index: -

        :stability: experimental
        """
        jsii.create(DataAzurermHealthcareServiceAuthenticationConfiguration, self, [terraform_resource, terraform_attribute, index])

    @builtins.property # type: ignore
    @jsii.member(jsii_name="audience")
    def audience(self) -> builtins.str:
        return jsii.get(self, "audience")

    @builtins.property # type: ignore
    @jsii.member(jsii_name="authority")
    def authority(self) -> builtins.str:
        return jsii.get(self, "authority")

    @builtins.property # type: ignore
    @jsii.member(jsii_name="smartProxyEnabled")
    def smart_proxy_enabled(self) -> builtins.bool:
        return jsii.get(self, "smartProxyEnabled")


@jsii.data_type(
    jsii_type="@cdktf/provider-azurerm.DataAzurermHealthcareServiceConfig",
    jsii_struct_bases=[cdktf.TerraformMetaArguments],
    name_mapping={
        "count": "count",
        "depends_on": "dependsOn",
        "lifecycle": "lifecycle",
        "provider": "provider",
        "location": "location",
        "name": "name",
        "resource_group_name": "resourceGroupName",
        "timeouts": "timeouts",
    },
)
class DataAzurermHealthcareServiceConfig(cdktf.TerraformMetaArguments):
    def __init__(
        self,
        *,
        count: typing.Optional[jsii.Number] = None,
        depends_on: typing.Optional[typing.List[cdktf.TerraformResource]] = None,
        lifecycle: typing.Optional[cdktf.TerraformResourceLifecycle] = None,
        provider: typing.Optional[cdktf.TerraformProvider] = None,
        location: builtins.str,
        name: builtins.str,
        resource_group_name: builtins.str,
        timeouts: typing.Optional["DataAzurermHealthcareServiceTimeouts"] = None,
    ) -> None:
        """
        :param count: 
        :param depends_on: 
        :param lifecycle: 
        :param provider: 
        :param location: 
        :param name: 
        :param resource_group_name: 
        :param timeouts: timeouts block.
        """
        if isinstance(lifecycle, dict):
            lifecycle = cdktf.TerraformResourceLifecycle(**lifecycle)
        if isinstance(timeouts, dict):
            timeouts = DataAzurermHealthcareServiceTimeouts(**timeouts)
        self._values: typing.Dict[str, typing.Any] = {
            "location": location,
            "name": name,
            "resource_group_name": resource_group_name,
        }
        if count is not None:
            self._values["count"] = count
        if depends_on is not None:
            self._values["depends_on"] = depends_on
        if lifecycle is not None:
            self._values["lifecycle"] = lifecycle
        if provider is not None:
            self._values["provider"] = provider
        if timeouts is not None:
            self._values["timeouts"] = timeouts

    @builtins.property
    def count(self) -> typing.Optional[jsii.Number]:
        """
        :stability: experimental
        """
        result = self._values.get("count")
        return result

    @builtins.property
    def depends_on(self) -> typing.Optional[typing.List[cdktf.TerraformResource]]:
        """
        :stability: experimental
        """
        result = self._values.get("depends_on")
        return result

    @builtins.property
    def lifecycle(self) -> typing.Optional[cdktf.TerraformResourceLifecycle]:
        """
        :stability: experimental
        """
        result = self._values.get("lifecycle")
        return result

    @builtins.property
    def provider(self) -> typing.Optional[cdktf.TerraformProvider]:
        """
        :stability: experimental
        """
        result = self._values.get("provider")
        return result

    @builtins.property
    def location(self) -> builtins.str:
        result = self._values.get("location")
        assert result is not None, "Required property 'location' is missing"
        return result

    @builtins.property
    def name(self) -> builtins.str:
        result = self._values.get("name")
        assert result is not None, "Required property 'name' is missing"
        return result

    @builtins.property
    def resource_group_name(self) -> builtins.str:
        result = self._values.get("resource_group_name")
        assert result is not None, "Required property 'resource_group_name' is missing"
        return result

    @builtins.property
    def timeouts(self) -> typing.Optional["DataAzurermHealthcareServiceTimeouts"]:
        """timeouts block."""
        result = self._values.get("timeouts")
        return result

    def __eq__(self, rhs: typing.Any) -> builtins.bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs: typing.Any) -> builtins.bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return "DataAzurermHealthcareServiceConfig(%s)" % ", ".join(
            k + "=" + repr(v) for k, v in self._values.items()
        )


class DataAzurermHealthcareServiceCorsConfiguration(
    cdktf.ComplexComputedList,
    metaclass=jsii.JSIIMeta,
    jsii_type="@cdktf/provider-azurerm.DataAzurermHealthcareServiceCorsConfiguration",
):
    def __init__(
        self,
        terraform_resource: cdktf.ITerraformResource,
        terraform_attribute: builtins.str,
        index: builtins.str,
    ) -> None:
        """
        :param terraform_resource: -
        :param terraform_attribute: -
        :param index: -

        :stability: experimental
        """
        jsii.create(DataAzurermHealthcareServiceCorsConfiguration, self, [terraform_resource, terraform_attribute, index])

    @builtins.property # type: ignore
    @jsii.member(jsii_name="allowCredentials")
    def allow_credentials(self) -> builtins.bool:
        return jsii.get(self, "allowCredentials")

    @builtins.property # type: ignore
    @jsii.member(jsii_name="allowedHeaders")
    def allowed_headers(self) -> typing.List[builtins.str]:
        return jsii.get(self, "allowedHeaders")

    @builtins.property # type: ignore
    @jsii.member(jsii_name="allowedMethods")
    def allowed_methods(self) -> typing.List[builtins.str]:
        return jsii.get(self, "allowedMethods")

    @builtins.property # type: ignore
    @jsii.member(jsii_name="allowedOrigins")
    def allowed_origins(self) -> typing.List[builtins.str]:
        return jsii.get(self, "allowedOrigins")

    @builtins.property # type: ignore
    @jsii.member(jsii_name="maxAgeInSeconds")
    def max_age_in_seconds(self) -> jsii.Number:
        return jsii.get(self, "maxAgeInSeconds")


@jsii.data_type(
    jsii_type="@cdktf/provider-azurerm.DataAzurermHealthcareServiceTimeouts",
    jsii_struct_bases=[],
    name_mapping={"read": "read"},
)
class DataAzurermHealthcareServiceTimeouts:
    def __init__(self, *, read: typing.Optional[builtins.str] = None) -> None:
        """
        :param read: 
        """
        self._values: typing.Dict[str, typing.Any] = {}
        if read is not None:
            self._values["read"] = read

    @builtins.property
    def read(self) -> typing.Optional[builtins.str]:
        result = self._values.get("read")
        return result

    def __eq__(self, rhs: typing.Any) -> builtins.bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs: typing.Any) -> builtins.bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return "DataAzurermHealthcareServiceTimeouts(%s)" % ", ".join(
            k + "=" + repr(v) for k, v in self._values.items()
        )


class DataAzurermImage(
    cdktf.TerraformDataSource,
    metaclass=jsii.JSIIMeta,
    jsii_type="@cdktf/provider-azurerm.DataAzurermImage",
):
    def __init__(
        self,
        scope: constructs.Construct,
        id: builtins.str,
        *,
        resource_group_name: builtins.str,
        name: typing.Optional[builtins.str] = None,
        name_regex: typing.Optional[builtins.str] = None,
        sort_descending: typing.Optional[builtins.bool] = None,
        timeouts: typing.Optional["DataAzurermImageTimeouts"] = None,
        count: typing.Optional[jsii.Number] = None,
        depends_on: typing.Optional[typing.List[cdktf.TerraformResource]] = None,
        lifecycle: typing.Optional[cdktf.TerraformResourceLifecycle] = None,
        provider: typing.Optional[cdktf.TerraformProvider] = None,
    ) -> None:
        """
        :param scope: -
        :param id: -
        :param resource_group_name: 
        :param name: 
        :param name_regex: 
        :param sort_descending: 
        :param timeouts: timeouts block.
        :param count: 
        :param depends_on: 
        :param lifecycle: 
        :param provider: 
        """
        config = DataAzurermImageConfig(
            resource_group_name=resource_group_name,
            name=name,
            name_regex=name_regex,
            sort_descending=sort_descending,
            timeouts=timeouts,
            count=count,
            depends_on=depends_on,
            lifecycle=lifecycle,
            provider=provider,
        )

        jsii.create(DataAzurermImage, self, [scope, id, config])

    @jsii.member(jsii_name="dataDisk")
    def data_disk(self, index: builtins.str) -> "DataAzurermImageDataDisk":
        """
        :param index: -
        """
        return jsii.invoke(self, "dataDisk", [index])

    @jsii.member(jsii_name="osDisk")
    def os_disk(self, index: builtins.str) -> "DataAzurermImageOsDisk":
        """
        :param index: -
        """
        return jsii.invoke(self, "osDisk", [index])

    @jsii.member(jsii_name="synthesizeAttributes")
    def _synthesize_attributes(self) -> typing.Mapping[builtins.str, typing.Any]:
        return jsii.invoke(self, "synthesizeAttributes", [])

    @jsii.member(jsii_name="tags")
    def tags(self, key: builtins.str) -> builtins.str:
        """
        :param key: -
        """
        return jsii.invoke(self, "tags", [key])

    @builtins.property # type: ignore
    @jsii.member(jsii_name="location")
    def location(self) -> builtins.str:
        return jsii.get(self, "location")

    @builtins.property # type: ignore
    @jsii.member(jsii_name="zoneResilient")
    def zone_resilient(self) -> builtins.bool:
        return jsii.get(self, "zoneResilient")

    @builtins.property # type: ignore
    @jsii.member(jsii_name="resourceGroupName")
    def resource_group_name(self) -> builtins.str:
        return jsii.get(self, "resourceGroupName")

    @resource_group_name.setter # type: ignore
    def resource_group_name(self, value: builtins.str) -> None:
        jsii.set(self, "resourceGroupName", value)

    @builtins.property # type: ignore
    @jsii.member(jsii_name="id")
    def id(self) -> typing.Optional[builtins.str]:
        return jsii.get(self, "id")

    @id.setter # type: ignore
    def id(self, value: typing.Optional[builtins.str]) -> None:
        jsii.set(self, "id", value)

    @builtins.property # type: ignore
    @jsii.member(jsii_name="name")
    def name(self) -> typing.Optional[builtins.str]:
        return jsii.get(self, "name")

    @name.setter # type: ignore
    def name(self, value: typing.Optional[builtins.str]) -> None:
        jsii.set(self, "name", value)

    @builtins.property # type: ignore
    @jsii.member(jsii_name="nameRegex")
    def name_regex(self) -> typing.Optional[builtins.str]:
        return jsii.get(self, "nameRegex")

    @name_regex.setter # type: ignore
    def name_regex(self, value: typing.Optional[builtins.str]) -> None:
        jsii.set(self, "nameRegex", value)

    @builtins.property # type: ignore
    @jsii.member(jsii_name="sortDescending")
    def sort_descending(self) -> typing.Optional[builtins.bool]:
        return jsii.get(self, "sortDescending")

    @sort_descending.setter # type: ignore
    def sort_descending(self, value: typing.Optional[builtins.bool]) -> None:
        jsii.set(self, "sortDescending", value)

    @builtins.property # type: ignore
    @jsii.member(jsii_name="timeouts")
    def timeouts(self) -> typing.Optional["DataAzurermImageTimeouts"]:
        return jsii.get(self, "timeouts")

    @timeouts.setter # type: ignore
    def timeouts(self, value: typing.Optional["DataAzurermImageTimeouts"]) -> None:
        jsii.set(self, "timeouts", value)


@jsii.data_type(
    jsii_type="@cdktf/provider-azurerm.DataAzurermImageConfig",
    jsii_struct_bases=[cdktf.TerraformMetaArguments],
    name_mapping={
        "count": "count",
        "depends_on": "dependsOn",
        "lifecycle": "lifecycle",
        "provider": "provider",
        "resource_group_name": "resourceGroupName",
        "name": "name",
        "name_regex": "nameRegex",
        "sort_descending": "sortDescending",
        "timeouts": "timeouts",
    },
)
class DataAzurermImageConfig(cdktf.TerraformMetaArguments):
    def __init__(
        self,
        *,
        count: typing.Optional[jsii.Number] = None,
        depends_on: typing.Optional[typing.List[cdktf.TerraformResource]] = None,
        lifecycle: typing.Optional[cdktf.TerraformResourceLifecycle] = None,
        provider: typing.Optional[cdktf.TerraformProvider] = None,
        resource_group_name: builtins.str,
        name: typing.Optional[builtins.str] = None,
        name_regex: typing.Optional[builtins.str] = None,
        sort_descending: typing.Optional[builtins.bool] = None,
        timeouts: typing.Optional["DataAzurermImageTimeouts"] = None,
    ) -> None:
        """
        :param count: 
        :param depends_on: 
        :param lifecycle: 
        :param provider: 
        :param resource_group_name: 
        :param name: 
        :param name_regex: 
        :param sort_descending: 
        :param timeouts: timeouts block.
        """
        if isinstance(lifecycle, dict):
            lifecycle = cdktf.TerraformResourceLifecycle(**lifecycle)
        if isinstance(timeouts, dict):
            timeouts = DataAzurermImageTimeouts(**timeouts)
        self._values: typing.Dict[str, typing.Any] = {
            "resource_group_name": resource_group_name,
        }
        if count is not None:
            self._values["count"] = count
        if depends_on is not None:
            self._values["depends_on"] = depends_on
        if lifecycle is not None:
            self._values["lifecycle"] = lifecycle
        if provider is not None:
            self._values["provider"] = provider
        if name is not None:
            self._values["name"] = name
        if name_regex is not None:
            self._values["name_regex"] = name_regex
        if sort_descending is not None:
            self._values["sort_descending"] = sort_descending
        if timeouts is not None:
            self._values["timeouts"] = timeouts

    @builtins.property
    def count(self) -> typing.Optional[jsii.Number]:
        """
        :stability: experimental
        """
        result = self._values.get("count")
        return result

    @builtins.property
    def depends_on(self) -> typing.Optional[typing.List[cdktf.TerraformResource]]:
        """
        :stability: experimental
        """
        result = self._values.get("depends_on")
        return result

    @builtins.property
    def lifecycle(self) -> typing.Optional[cdktf.TerraformResourceLifecycle]:
        """
        :stability: experimental
        """
        result = self._values.get("lifecycle")
        return result

    @builtins.property
    def provider(self) -> typing.Optional[cdktf.TerraformProvider]:
        """
        :stability: experimental
        """
        result = self._values.get("provider")
        return result

    @builtins.property
    def resource_group_name(self) -> builtins.str:
        result = self._values.get("resource_group_name")
        assert result is not None, "Required property 'resource_group_name' is missing"
        return result

    @builtins.property
    def name(self) -> typing.Optional[builtins.str]:
        result = self._values.get("name")
        return result

    @builtins.property
    def name_regex(self) -> typing.Optional[builtins.str]:
        result = self._values.get("name_regex")
        return result

    @builtins.property
    def sort_descending(self) -> typing.Optional[builtins.bool]:
        result = self._values.get("sort_descending")
        return result

    @builtins.property
    def timeouts(self) -> typing.Optional["DataAzurermImageTimeouts"]:
        """timeouts block."""
        result = self._values.get("timeouts")
        return result

    def __eq__(self, rhs: typing.Any) -> builtins.bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs: typing.Any) -> builtins.bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return "DataAzurermImageConfig(%s)" % ", ".join(
            k + "=" + repr(v) for k, v in self._values.items()
        )


class DataAzurermImageDataDisk(
    cdktf.ComplexComputedList,
    metaclass=jsii.JSIIMeta,
    jsii_type="@cdktf/provider-azurerm.DataAzurermImageDataDisk",
):
    def __init__(
        self,
        terraform_resource: cdktf.ITerraformResource,
        terraform_attribute: builtins.str,
        index: builtins.str,
    ) -> None:
        """
        :param terraform_resource: -
        :param terraform_attribute: -
        :param index: -

        :stability: experimental
        """
        jsii.create(DataAzurermImageDataDisk, self, [terraform_resource, terraform_attribute, index])

    @builtins.property # type: ignore
    @jsii.member(jsii_name="blobUri")
    def blob_uri(self) -> builtins.str:
        return jsii.get(self, "blobUri")

    @builtins.property # type: ignore
    @jsii.member(jsii_name="caching")
    def caching(self) -> builtins.str:
        return jsii.get(self, "caching")

    @builtins.property # type: ignore
    @jsii.member(jsii_name="lun")
    def lun(self) -> jsii.Number:
        return jsii.get(self, "lun")

    @builtins.property # type: ignore
    @jsii.member(jsii_name="managedDiskId")
    def managed_disk_id(self) -> builtins.str:
        return jsii.get(self, "managedDiskId")

    @builtins.property # type: ignore
    @jsii.member(jsii_name="sizeGb")
    def size_gb(self) -> jsii.Number:
        return jsii.get(self, "sizeGb")


class DataAzurermImageOsDisk(
    cdktf.ComplexComputedList,
    metaclass=jsii.JSIIMeta,
    jsii_type="@cdktf/provider-azurerm.DataAzurermImageOsDisk",
):
    def __init__(
        self,
        terraform_resource: cdktf.ITerraformResource,
        terraform_attribute: builtins.str,
        index: builtins.str,
    ) -> None:
        """
        :param terraform_resource: -
        :param terraform_attribute: -
        :param index: -

        :stability: experimental
        """
        jsii.create(DataAzurermImageOsDisk, self, [terraform_resource, terraform_attribute, index])

    @builtins.property # type: ignore
    @jsii.member(jsii_name="blobUri")
    def blob_uri(self) -> builtins.str:
        return jsii.get(self, "blobUri")

    @builtins.property # type: ignore
    @jsii.member(jsii_name="caching")
    def caching(self) -> builtins.str:
        return jsii.get(self, "caching")

    @builtins.property # type: ignore
    @jsii.member(jsii_name="managedDiskId")
    def managed_disk_id(self) -> builtins.str:
        return jsii.get(self, "managedDiskId")

    @builtins.property # type: ignore
    @jsii.member(jsii_name="osState")
    def os_state(self) -> builtins.str:
        return jsii.get(self, "osState")

    @builtins.property # type: ignore
    @jsii.member(jsii_name="osType")
    def os_type(self) -> builtins.str:
        return jsii.get(self, "osType")

    @builtins.property # type: ignore
    @jsii.member(jsii_name="sizeGb")
    def size_gb(self) -> jsii.Number:
        return jsii.get(self, "sizeGb")


@jsii.data_type(
    jsii_type="@cdktf/provider-azurerm.DataAzurermImageTimeouts",
    jsii_struct_bases=[],
    name_mapping={"read": "read"},
)
class DataAzurermImageTimeouts:
    def __init__(self, *, read: typing.Optional[builtins.str] = None) -> None:
        """
        :param read: 
        """
        self._values: typing.Dict[str, typing.Any] = {}
        if read is not None:
            self._values["read"] = read

    @builtins.property
    def read(self) -> typing.Optional[builtins.str]:
        result = self._values.get("read")
        return result

    def __eq__(self, rhs: typing.Any) -> builtins.bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs: typing.Any) -> builtins.bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return "DataAzurermImageTimeouts(%s)" % ", ".join(
            k + "=" + repr(v) for k, v in self._values.items()
        )


class DataAzurermIothubDps(
    cdktf.TerraformDataSource,
    metaclass=jsii.JSIIMeta,
    jsii_type="@cdktf/provider-azurerm.DataAzurermIothubDps",
):
    def __init__(
        self,
        scope: constructs.Construct,
        id: builtins.str,
        *,
        name: builtins.str,
        resource_group_name: builtins.str,
        tags: typing.Optional[typing.Mapping[builtins.str, builtins.str]] = None,
        timeouts: typing.Optional["DataAzurermIothubDpsTimeouts"] = None,
        count: typing.Optional[jsii.Number] = None,
        depends_on: typing.Optional[typing.List[cdktf.TerraformResource]] = None,
        lifecycle: typing.Optional[cdktf.TerraformResourceLifecycle] = None,
        provider: typing.Optional[cdktf.TerraformProvider] = None,
    ) -> None:
        """
        :param scope: -
        :param id: -
        :param name: 
        :param resource_group_name: 
        :param tags: 
        :param timeouts: timeouts block.
        :param count: 
        :param depends_on: 
        :param lifecycle: 
        :param provider: 
        """
        config = DataAzurermIothubDpsConfig(
            name=name,
            resource_group_name=resource_group_name,
            tags=tags,
            timeouts=timeouts,
            count=count,
            depends_on=depends_on,
            lifecycle=lifecycle,
            provider=provider,
        )

        jsii.create(DataAzurermIothubDps, self, [scope, id, config])

    @jsii.member(jsii_name="synthesizeAttributes")
    def _synthesize_attributes(self) -> typing.Mapping[builtins.str, typing.Any]:
        return jsii.invoke(self, "synthesizeAttributes", [])

    @builtins.property # type: ignore
    @jsii.member(jsii_name="allocationPolicy")
    def allocation_policy(self) -> builtins.str:
        return jsii.get(self, "allocationPolicy")

    @builtins.property # type: ignore
    @jsii.member(jsii_name="deviceProvisioningHostName")
    def device_provisioning_host_name(self) -> builtins.str:
        return jsii.get(self, "deviceProvisioningHostName")

    @builtins.property # type: ignore
    @jsii.member(jsii_name="idScope")
    def id_scope(self) -> builtins.str:
        return jsii.get(self, "idScope")

    @builtins.property # type: ignore
    @jsii.member(jsii_name="location")
    def location(self) -> builtins.str:
        return jsii.get(self, "location")

    @builtins.property # type: ignore
    @jsii.member(jsii_name="serviceOperationsHostName")
    def service_operations_host_name(self) -> builtins.str:
        return jsii.get(self, "serviceOperationsHostName")

    @builtins.property # type: ignore
    @jsii.member(jsii_name="name")
    def name(self) -> builtins.str:
        return jsii.get(self, "name")

    @name.setter # type: ignore
    def name(self, value: builtins.str) -> None:
        jsii.set(self, "name", value)

    @builtins.property # type: ignore
    @jsii.member(jsii_name="resourceGroupName")
    def resource_group_name(self) -> builtins.str:
        return jsii.get(self, "resourceGroupName")

    @resource_group_name.setter # type: ignore
    def resource_group_name(self, value: builtins.str) -> None:
        jsii.set(self, "resourceGroupName", value)

    @builtins.property # type: ignore
    @jsii.member(jsii_name="id")
    def id(self) -> typing.Optional[builtins.str]:
        return jsii.get(self, "id")

    @id.setter # type: ignore
    def id(self, value: typing.Optional[builtins.str]) -> None:
        jsii.set(self, "id", value)

    @builtins.property # type: ignore
    @jsii.member(jsii_name="tags")
    def tags(self) -> typing.Optional[typing.Mapping[builtins.str, builtins.str]]:
        return jsii.get(self, "tags")

    @tags.setter # type: ignore
    def tags(
        self,
        value: typing.Optional[typing.Mapping[builtins.str, builtins.str]],
    ) -> None:
        jsii.set(self, "tags", value)

    @builtins.property # type: ignore
    @jsii.member(jsii_name="timeouts")
    def timeouts(self) -> typing.Optional["DataAzurermIothubDpsTimeouts"]:
        return jsii.get(self, "timeouts")

    @timeouts.setter # type: ignore
    def timeouts(self, value: typing.Optional["DataAzurermIothubDpsTimeouts"]) -> None:
        jsii.set(self, "timeouts", value)


@jsii.data_type(
    jsii_type="@cdktf/provider-azurerm.DataAzurermIothubDpsConfig",
    jsii_struct_bases=[cdktf.TerraformMetaArguments],
    name_mapping={
        "count": "count",
        "depends_on": "dependsOn",
        "lifecycle": "lifecycle",
        "provider": "provider",
        "name": "name",
        "resource_group_name": "resourceGroupName",
        "tags": "tags",
        "timeouts": "timeouts",
    },
)
class DataAzurermIothubDpsConfig(cdktf.TerraformMetaArguments):
    def __init__(
        self,
        *,
        count: typing.Optional[jsii.Number] = None,
        depends_on: typing.Optional[typing.List[cdktf.TerraformResource]] = None,
        lifecycle: typing.Optional[cdktf.TerraformResourceLifecycle] = None,
        provider: typing.Optional[cdktf.TerraformProvider] = None,
        name: builtins.str,
        resource_group_name: builtins.str,
        tags: typing.Optional[typing.Mapping[builtins.str, builtins.str]] = None,
        timeouts: typing.Optional["DataAzurermIothubDpsTimeouts"] = None,
    ) -> None:
        """
        :param count: 
        :param depends_on: 
        :param lifecycle: 
        :param provider: 
        :param name: 
        :param resource_group_name: 
        :param tags: 
        :param timeouts: timeouts block.
        """
        if isinstance(lifecycle, dict):
            lifecycle = cdktf.TerraformResourceLifecycle(**lifecycle)
        if isinstance(timeouts, dict):
            timeouts = DataAzurermIothubDpsTimeouts(**timeouts)
        self._values: typing.Dict[str, typing.Any] = {
            "name": name,
            "resource_group_name": resource_group_name,
        }
        if count is not None:
            self._values["count"] = count
        if depends_on is not None:
            self._values["depends_on"] = depends_on
        if lifecycle is not None:
            self._values["lifecycle"] = lifecycle
        if provider is not None:
            self._values["provider"] = provider
        if tags is not None:
            self._values["tags"] = tags
        if timeouts is not None:
            self._values["timeouts"] = timeouts

    @builtins.property
    def count(self) -> typing.Optional[jsii.Number]:
        """
        :stability: experimental
        """
        result = self._values.get("count")
        return result

    @builtins.property
    def depends_on(self) -> typing.Optional[typing.List[cdktf.TerraformResource]]:
        """
        :stability: experimental
        """
        result = self._values.get("depends_on")
        return result

    @builtins.property
    def lifecycle(self) -> typing.Optional[cdktf.TerraformResourceLifecycle]:
        """
        :stability: experimental
        """
        result = self._values.get("lifecycle")
        return result

    @builtins.property
    def provider(self) -> typing.Optional[cdktf.TerraformProvider]:
        """
        :stability: experimental
        """
        result = self._values.get("provider")
        return result

    @builtins.property
    def name(self) -> builtins.str:
        result = self._values.get("name")
        assert result is not None, "Required property 'name' is missing"
        return result

    @builtins.property
    def resource_group_name(self) -> builtins.str:
        result = self._values.get("resource_group_name")
        assert result is not None, "Required property 'resource_group_name' is missing"
        return result

    @builtins.property
    def tags(self) -> typing.Optional[typing.Mapping[builtins.str, builtins.str]]:
        result = self._values.get("tags")
        return result

    @builtins.property
    def timeouts(self) -> typing.Optional["DataAzurermIothubDpsTimeouts"]:
        """timeouts block."""
        result = self._values.get("timeouts")
        return result

    def __eq__(self, rhs: typing.Any) -> builtins.bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs: typing.Any) -> builtins.bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return "DataAzurermIothubDpsConfig(%s)" % ", ".join(
            k + "=" + repr(v) for k, v in self._values.items()
        )


class DataAzurermIothubDpsSharedAccessPolicy(
    cdktf.TerraformDataSource,
    metaclass=jsii.JSIIMeta,
    jsii_type="@cdktf/provider-azurerm.DataAzurermIothubDpsSharedAccessPolicy",
):
    def __init__(
        self,
        scope: constructs.Construct,
        id: builtins.str,
        *,
        iothub_dps_name: builtins.str,
        name: builtins.str,
        resource_group_name: builtins.str,
        timeouts: typing.Optional["DataAzurermIothubDpsSharedAccessPolicyTimeouts"] = None,
        count: typing.Optional[jsii.Number] = None,
        depends_on: typing.Optional[typing.List[cdktf.TerraformResource]] = None,
        lifecycle: typing.Optional[cdktf.TerraformResourceLifecycle] = None,
        provider: typing.Optional[cdktf.TerraformProvider] = None,
    ) -> None:
        """
        :param scope: -
        :param id: -
        :param iothub_dps_name: 
        :param name: 
        :param resource_group_name: 
        :param timeouts: timeouts block.
        :param count: 
        :param depends_on: 
        :param lifecycle: 
        :param provider: 
        """
        config = DataAzurermIothubDpsSharedAccessPolicyConfig(
            iothub_dps_name=iothub_dps_name,
            name=name,
            resource_group_name=resource_group_name,
            timeouts=timeouts,
            count=count,
            depends_on=depends_on,
            lifecycle=lifecycle,
            provider=provider,
        )

        jsii.create(DataAzurermIothubDpsSharedAccessPolicy, self, [scope, id, config])

    @jsii.member(jsii_name="synthesizeAttributes")
    def _synthesize_attributes(self) -> typing.Mapping[builtins.str, typing.Any]:
        return jsii.invoke(self, "synthesizeAttributes", [])

    @builtins.property # type: ignore
    @jsii.member(jsii_name="primaryConnectionString")
    def primary_connection_string(self) -> builtins.str:
        return jsii.get(self, "primaryConnectionString")

    @builtins.property # type: ignore
    @jsii.member(jsii_name="primaryKey")
    def primary_key(self) -> builtins.str:
        return jsii.get(self, "primaryKey")

    @builtins.property # type: ignore
    @jsii.member(jsii_name="secondaryConnectionString")
    def secondary_connection_string(self) -> builtins.str:
        return jsii.get(self, "secondaryConnectionString")

    @builtins.property # type: ignore
    @jsii.member(jsii_name="secondaryKey")
    def secondary_key(self) -> builtins.str:
        return jsii.get(self, "secondaryKey")

    @builtins.property # type: ignore
    @jsii.member(jsii_name="iothubDpsName")
    def iothub_dps_name(self) -> builtins.str:
        return jsii.get(self, "iothubDpsName")

    @iothub_dps_name.setter # type: ignore
    def iothub_dps_name(self, value: builtins.str) -> None:
        jsii.set(self, "iothubDpsName", value)

    @builtins.property # type: ignore
    @jsii.member(jsii_name="name")
    def name(self) -> builtins.str:
        return jsii.get(self, "name")

    @name.setter # type: ignore
    def name(self, value: builtins.str) -> None:
        jsii.set(self, "name", value)

    @builtins.property # type: ignore
    @jsii.member(jsii_name="resourceGroupName")
    def resource_group_name(self) -> builtins.str:
        return jsii.get(self, "resourceGroupName")

    @resource_group_name.setter # type: ignore
    def resource_group_name(self, value: builtins.str) -> None:
        jsii.set(self, "resourceGroupName", value)

    @builtins.property # type: ignore
    @jsii.member(jsii_name="id")
    def id(self) -> typing.Optional[builtins.str]:
        return jsii.get(self, "id")

    @id.setter # type: ignore
    def id(self, value: typing.Optional[builtins.str]) -> None:
        jsii.set(self, "id", value)

    @builtins.property # type: ignore
    @jsii.member(jsii_name="timeouts")
    def timeouts(
        self,
    ) -> typing.Optional["DataAzurermIothubDpsSharedAccessPolicyTimeouts"]:
        return jsii.get(self, "timeouts")

    @timeouts.setter # type: ignore
    def timeouts(
        self,
        value: typing.Optional["DataAzurermIothubDpsSharedAccessPolicyTimeouts"],
    ) -> None:
        jsii.set(self, "timeouts", value)


@jsii.data_type(
    jsii_type="@cdktf/provider-azurerm.DataAzurermIothubDpsSharedAccessPolicyConfig",
    jsii_struct_bases=[cdktf.TerraformMetaArguments],
    name_mapping={
        "count": "count",
        "depends_on": "dependsOn",
        "lifecycle": "lifecycle",
        "provider": "provider",
        "iothub_dps_name": "iothubDpsName",
        "name": "name",
        "resource_group_name": "resourceGroupName",
        "timeouts": "timeouts",
    },
)
class DataAzurermIothubDpsSharedAccessPolicyConfig(cdktf.TerraformMetaArguments):
    def __init__(
        self,
        *,
        count: typing.Optional[jsii.Number] = None,
        depends_on: typing.Optional[typing.List[cdktf.TerraformResource]] = None,
        lifecycle: typing.Optional[cdktf.TerraformResourceLifecycle] = None,
        provider: typing.Optional[cdktf.TerraformProvider] = None,
        iothub_dps_name: builtins.str,
        name: builtins.str,
        resource_group_name: builtins.str,
        timeouts: typing.Optional["DataAzurermIothubDpsSharedAccessPolicyTimeouts"] = None,
    ) -> None:
        """
        :param count: 
        :param depends_on: 
        :param lifecycle: 
        :param provider: 
        :param iothub_dps_name: 
        :param name: 
        :param resource_group_name: 
        :param timeouts: timeouts block.
        """
        if isinstance(lifecycle, dict):
            lifecycle = cdktf.TerraformResourceLifecycle(**lifecycle)
        if isinstance(timeouts, dict):
            timeouts = DataAzurermIothubDpsSharedAccessPolicyTimeouts(**timeouts)
        self._values: typing.Dict[str, typing.Any] = {
            "iothub_dps_name": iothub_dps_name,
            "name": name,
            "resource_group_name": resource_group_name,
        }
        if count is not None:
            self._values["count"] = count
        if depends_on is not None:
            self._values["depends_on"] = depends_on
        if lifecycle is not None:
            self._values["lifecycle"] = lifecycle
        if provider is not None:
            self._values["provider"] = provider
        if timeouts is not None:
            self._values["timeouts"] = timeouts

    @builtins.property
    def count(self) -> typing.Optional[jsii.Number]:
        """
        :stability: experimental
        """
        result = self._values.get("count")
        return result

    @builtins.property
    def depends_on(self) -> typing.Optional[typing.List[cdktf.TerraformResource]]:
        """
        :stability: experimental
        """
        result = self._values.get("depends_on")
        return result

    @builtins.property
    def lifecycle(self) -> typing.Optional[cdktf.TerraformResourceLifecycle]:
        """
        :stability: experimental
        """
        result = self._values.get("lifecycle")
        return result

    @builtins.property
    def provider(self) -> typing.Optional[cdktf.TerraformProvider]:
        """
        :stability: experimental
        """
        result = self._values.get("provider")
        return result

    @builtins.property
    def iothub_dps_name(self) -> builtins.str:
        result = self._values.get("iothub_dps_name")
        assert result is not None, "Required property 'iothub_dps_name' is missing"
        return result

    @builtins.property
    def name(self) -> builtins.str:
        result = self._values.get("name")
        assert result is not None, "Required property 'name' is missing"
        return result

    @builtins.property
    def resource_group_name(self) -> builtins.str:
        result = self._values.get("resource_group_name")
        assert result is not None, "Required property 'resource_group_name' is missing"
        return result

    @builtins.property
    def timeouts(
        self,
    ) -> typing.Optional["DataAzurermIothubDpsSharedAccessPolicyTimeouts"]:
        """timeouts block."""
        result = self._values.get("timeouts")
        return result

    def __eq__(self, rhs: typing.Any) -> builtins.bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs: typing.Any) -> builtins.bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return "DataAzurermIothubDpsSharedAccessPolicyConfig(%s)" % ", ".join(
            k + "=" + repr(v) for k, v in self._values.items()
        )


@jsii.data_type(
    jsii_type="@cdktf/provider-azurerm.DataAzurermIothubDpsSharedAccessPolicyTimeouts",
    jsii_struct_bases=[],
    name_mapping={"read": "read"},
)
class DataAzurermIothubDpsSharedAccessPolicyTimeouts:
    def __init__(self, *, read: typing.Optional[builtins.str] = None) -> None:
        """
        :param read: 
        """
        self._values: typing.Dict[str, typing.Any] = {}
        if read is not None:
            self._values["read"] = read

    @builtins.property
    def read(self) -> typing.Optional[builtins.str]:
        result = self._values.get("read")
        return result

    def __eq__(self, rhs: typing.Any) -> builtins.bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs: typing.Any) -> builtins.bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return "DataAzurermIothubDpsSharedAccessPolicyTimeouts(%s)" % ", ".join(
            k + "=" + repr(v) for k, v in self._values.items()
        )


@jsii.data_type(
    jsii_type="@cdktf/provider-azurerm.DataAzurermIothubDpsTimeouts",
    jsii_struct_bases=[],
    name_mapping={"read": "read"},
)
class DataAzurermIothubDpsTimeouts:
    def __init__(self, *, read: typing.Optional[builtins.str] = None) -> None:
        """
        :param read: 
        """
        self._values: typing.Dict[str, typing.Any] = {}
        if read is not None:
            self._values["read"] = read

    @builtins.property
    def read(self) -> typing.Optional[builtins.str]:
        result = self._values.get("read")
        return result

    def __eq__(self, rhs: typing.Any) -> builtins.bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs: typing.Any) -> builtins.bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return "DataAzurermIothubDpsTimeouts(%s)" % ", ".join(
            k + "=" + repr(v) for k, v in self._values.items()
        )


class DataAzurermIothubSharedAccessPolicy(
    cdktf.TerraformDataSource,
    metaclass=jsii.JSIIMeta,
    jsii_type="@cdktf/provider-azurerm.DataAzurermIothubSharedAccessPolicy",
):
    def __init__(
        self,
        scope: constructs.Construct,
        id: builtins.str,
        *,
        iothub_name: builtins.str,
        name: builtins.str,
        resource_group_name: builtins.str,
        timeouts: typing.Optional["DataAzurermIothubSharedAccessPolicyTimeouts"] = None,
        count: typing.Optional[jsii.Number] = None,
        depends_on: typing.Optional[typing.List[cdktf.TerraformResource]] = None,
        lifecycle: typing.Optional[cdktf.TerraformResourceLifecycle] = None,
        provider: typing.Optional[cdktf.TerraformProvider] = None,
    ) -> None:
        """
        :param scope: -
        :param id: -
        :param iothub_name: 
        :param name: 
        :param resource_group_name: 
        :param timeouts: timeouts block.
        :param count: 
        :param depends_on: 
        :param lifecycle: 
        :param provider: 
        """
        config = DataAzurermIothubSharedAccessPolicyConfig(
            iothub_name=iothub_name,
            name=name,
            resource_group_name=resource_group_name,
            timeouts=timeouts,
            count=count,
            depends_on=depends_on,
            lifecycle=lifecycle,
            provider=provider,
        )

        jsii.create(DataAzurermIothubSharedAccessPolicy, self, [scope, id, config])

    @jsii.member(jsii_name="synthesizeAttributes")
    def _synthesize_attributes(self) -> typing.Mapping[builtins.str, typing.Any]:
        return jsii.invoke(self, "synthesizeAttributes", [])

    @builtins.property # type: ignore
    @jsii.member(jsii_name="primaryConnectionString")
    def primary_connection_string(self) -> builtins.str:
        return jsii.get(self, "primaryConnectionString")

    @builtins.property # type: ignore
    @jsii.member(jsii_name="primaryKey")
    def primary_key(self) -> builtins.str:
        return jsii.get(self, "primaryKey")

    @builtins.property # type: ignore
    @jsii.member(jsii_name="secondaryConnectionString")
    def secondary_connection_string(self) -> builtins.str:
        return jsii.get(self, "secondaryConnectionString")

    @builtins.property # type: ignore
    @jsii.member(jsii_name="secondaryKey")
    def secondary_key(self) -> builtins.str:
        return jsii.get(self, "secondaryKey")

    @builtins.property # type: ignore
    @jsii.member(jsii_name="iothubName")
    def iothub_name(self) -> builtins.str:
        return jsii.get(self, "iothubName")

    @iothub_name.setter # type: ignore
    def iothub_name(self, value: builtins.str) -> None:
        jsii.set(self, "iothubName", value)

    @builtins.property # type: ignore
    @jsii.member(jsii_name="name")
    def name(self) -> builtins.str:
        return jsii.get(self, "name")

    @name.setter # type: ignore
    def name(self, value: builtins.str) -> None:
        jsii.set(self, "name", value)

    @builtins.property # type: ignore
    @jsii.member(jsii_name="resourceGroupName")
    def resource_group_name(self) -> builtins.str:
        return jsii.get(self, "resourceGroupName")

    @resource_group_name.setter # type: ignore
    def resource_group_name(self, value: builtins.str) -> None:
        jsii.set(self, "resourceGroupName", value)

    @builtins.property # type: ignore
    @jsii.member(jsii_name="id")
    def id(self) -> typing.Optional[builtins.str]:
        return jsii.get(self, "id")

    @id.setter # type: ignore
    def id(self, value: typing.Optional[builtins.str]) -> None:
        jsii.set(self, "id", value)

    @builtins.property # type: ignore
    @jsii.member(jsii_name="timeouts")
    def timeouts(
        self,
    ) -> typing.Optional["DataAzurermIothubSharedAccessPolicyTimeouts"]:
        return jsii.get(self, "timeouts")

    @timeouts.setter # type: ignore
    def timeouts(
        self,
        value: typing.Optional["DataAzurermIothubSharedAccessPolicyTimeouts"],
    ) -> None:
        jsii.set(self, "timeouts", value)


@jsii.data_type(
    jsii_type="@cdktf/provider-azurerm.DataAzurermIothubSharedAccessPolicyConfig",
    jsii_struct_bases=[cdktf.TerraformMetaArguments],
    name_mapping={
        "count": "count",
        "depends_on": "dependsOn",
        "lifecycle": "lifecycle",
        "provider": "provider",
        "iothub_name": "iothubName",
        "name": "name",
        "resource_group_name": "resourceGroupName",
        "timeouts": "timeouts",
    },
)
class DataAzurermIothubSharedAccessPolicyConfig(cdktf.TerraformMetaArguments):
    def __init__(
        self,
        *,
        count: typing.Optional[jsii.Number] = None,
        depends_on: typing.Optional[typing.List[cdktf.TerraformResource]] = None,
        lifecycle: typing.Optional[cdktf.TerraformResourceLifecycle] = None,
        provider: typing.Optional[cdktf.TerraformProvider] = None,
        iothub_name: builtins.str,
        name: builtins.str,
        resource_group_name: builtins.str,
        timeouts: typing.Optional["DataAzurermIothubSharedAccessPolicyTimeouts"] = None,
    ) -> None:
        """
        :param count: 
        :param depends_on: 
        :param lifecycle: 
        :param provider: 
        :param iothub_name: 
        :param name: 
        :param resource_group_name: 
        :param timeouts: timeouts block.
        """
        if isinstance(lifecycle, dict):
            lifecycle = cdktf.TerraformResourceLifecycle(**lifecycle)
        if isinstance(timeouts, dict):
            timeouts = DataAzurermIothubSharedAccessPolicyTimeouts(**timeouts)
        self._values: typing.Dict[str, typing.Any] = {
            "iothub_name": iothub_name,
            "name": name,
            "resource_group_name": resource_group_name,
        }
        if count is not None:
            self._values["count"] = count
        if depends_on is not None:
            self._values["depends_on"] = depends_on
        if lifecycle is not None:
            self._values["lifecycle"] = lifecycle
        if provider is not None:
            self._values["provider"] = provider
        if timeouts is not None:
            self._values["timeouts"] = timeouts

    @builtins.property
    def count(self) -> typing.Optional[jsii.Number]:
        """
        :stability: experimental
        """
        result = self._values.get("count")
        return result

    @builtins.property
    def depends_on(self) -> typing.Optional[typing.List[cdktf.TerraformResource]]:
        """
        :stability: experimental
        """
        result = self._values.get("depends_on")
        return result

    @builtins.property
    def lifecycle(self) -> typing.Optional[cdktf.TerraformResourceLifecycle]:
        """
        :stability: experimental
        """
        result = self._values.get("lifecycle")
        return result

    @builtins.property
    def provider(self) -> typing.Optional[cdktf.TerraformProvider]:
        """
        :stability: experimental
        """
        result = self._values.get("provider")
        return result

    @builtins.property
    def iothub_name(self) -> builtins.str:
        result = self._values.get("iothub_name")
        assert result is not None, "Required property 'iothub_name' is missing"
        return result

    @builtins.property
    def name(self) -> builtins.str:
        result = self._values.get("name")
        assert result is not None, "Required property 'name' is missing"
        return result

    @builtins.property
    def resource_group_name(self) -> builtins.str:
        result = self._values.get("resource_group_name")
        assert result is not None, "Required property 'resource_group_name' is missing"
        return result

    @builtins.property
    def timeouts(
        self,
    ) -> typing.Optional["DataAzurermIothubSharedAccessPolicyTimeouts"]:
        """timeouts block."""
        result = self._values.get("timeouts")
        return result

    def __eq__(self, rhs: typing.Any) -> builtins.bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs: typing.Any) -> builtins.bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return "DataAzurermIothubSharedAccessPolicyConfig(%s)" % ", ".join(
            k + "=" + repr(v) for k, v in self._values.items()
        )


@jsii.data_type(
    jsii_type="@cdktf/provider-azurerm.DataAzurermIothubSharedAccessPolicyTimeouts",
    jsii_struct_bases=[],
    name_mapping={"read": "read"},
)
class DataAzurermIothubSharedAccessPolicyTimeouts:
    def __init__(self, *, read: typing.Optional[builtins.str] = None) -> None:
        """
        :param read: 
        """
        self._values: typing.Dict[str, typing.Any] = {}
        if read is not None:
            self._values["read"] = read

    @builtins.property
    def read(self) -> typing.Optional[builtins.str]:
        result = self._values.get("read")
        return result

    def __eq__(self, rhs: typing.Any) -> builtins.bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs: typing.Any) -> builtins.bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return "DataAzurermIothubSharedAccessPolicyTimeouts(%s)" % ", ".join(
            k + "=" + repr(v) for k, v in self._values.items()
        )


class DataAzurermKeyVault(
    cdktf.TerraformDataSource,
    metaclass=jsii.JSIIMeta,
    jsii_type="@cdktf/provider-azurerm.DataAzurermKeyVault",
):
    def __init__(
        self,
        scope: constructs.Construct,
        id: builtins.str,
        *,
        name: builtins.str,
        resource_group_name: builtins.str,
        timeouts: typing.Optional["DataAzurermKeyVaultTimeouts"] = None,
        count: typing.Optional[jsii.Number] = None,
        depends_on: typing.Optional[typing.List[cdktf.TerraformResource]] = None,
        lifecycle: typing.Optional[cdktf.TerraformResourceLifecycle] = None,
        provider: typing.Optional[cdktf.TerraformProvider] = None,
    ) -> None:
        """
        :param scope: -
        :param id: -
        :param name: 
        :param resource_group_name: 
        :param timeouts: timeouts block.
        :param count: 
        :param depends_on: 
        :param lifecycle: 
        :param provider: 
        """
        config = DataAzurermKeyVaultConfig(
            name=name,
            resource_group_name=resource_group_name,
            timeouts=timeouts,
            count=count,
            depends_on=depends_on,
            lifecycle=lifecycle,
            provider=provider,
        )

        jsii.create(DataAzurermKeyVault, self, [scope, id, config])

    @jsii.member(jsii_name="accessPolicy")
    def access_policy(self, index: builtins.str) -> "DataAzurermKeyVaultAccessPolicy":
        """
        :param index: -
        """
        return jsii.invoke(self, "accessPolicy", [index])

    @jsii.member(jsii_name="networkAcls")
    def network_acls(self, index: builtins.str) -> "DataAzurermKeyVaultNetworkAcls":
        """
        :param index: -
        """
        return jsii.invoke(self, "networkAcls", [index])

    @jsii.member(jsii_name="synthesizeAttributes")
    def _synthesize_attributes(self) -> typing.Mapping[builtins.str, typing.Any]:
        return jsii.invoke(self, "synthesizeAttributes", [])

    @jsii.member(jsii_name="tags")
    def tags(self, key: builtins.str) -> builtins.str:
        """
        :param key: -
        """
        return jsii.invoke(self, "tags", [key])

    @builtins.property # type: ignore
    @jsii.member(jsii_name="enabledForDeployment")
    def enabled_for_deployment(self) -> builtins.bool:
        return jsii.get(self, "enabledForDeployment")

    @builtins.property # type: ignore
    @jsii.member(jsii_name="enabledForDiskEncryption")
    def enabled_for_disk_encryption(self) -> builtins.bool:
        return jsii.get(self, "enabledForDiskEncryption")

    @builtins.property # type: ignore
    @jsii.member(jsii_name="enabledForTemplateDeployment")
    def enabled_for_template_deployment(self) -> builtins.bool:
        return jsii.get(self, "enabledForTemplateDeployment")

    @builtins.property # type: ignore
    @jsii.member(jsii_name="location")
    def location(self) -> builtins.str:
        return jsii.get(self, "location")

    @builtins.property # type: ignore
    @jsii.member(jsii_name="purgeProtectionEnabled")
    def purge_protection_enabled(self) -> builtins.bool:
        return jsii.get(self, "purgeProtectionEnabled")

    @builtins.property # type: ignore
    @jsii.member(jsii_name="skuName")
    def sku_name(self) -> builtins.str:
        return jsii.get(self, "skuName")

    @builtins.property # type: ignore
    @jsii.member(jsii_name="softDeleteEnabled")
    def soft_delete_enabled(self) -> builtins.bool:
        return jsii.get(self, "softDeleteEnabled")

    @builtins.property # type: ignore
    @jsii.member(jsii_name="tenantId")
    def tenant_id(self) -> builtins.str:
        return jsii.get(self, "tenantId")

    @builtins.property # type: ignore
    @jsii.member(jsii_name="vaultUri")
    def vault_uri(self) -> builtins.str:
        return jsii.get(self, "vaultUri")

    @builtins.property # type: ignore
    @jsii.member(jsii_name="name")
    def name(self) -> builtins.str:
        return jsii.get(self, "name")

    @name.setter # type: ignore
    def name(self, value: builtins.str) -> None:
        jsii.set(self, "name", value)

    @builtins.property # type: ignore
    @jsii.member(jsii_name="resourceGroupName")
    def resource_group_name(self) -> builtins.str:
        return jsii.get(self, "resourceGroupName")

    @resource_group_name.setter # type: ignore
    def resource_group_name(self, value: builtins.str) -> None:
        jsii.set(self, "resourceGroupName", value)

    @builtins.property # type: ignore
    @jsii.member(jsii_name="id")
    def id(self) -> typing.Optional[builtins.str]:
        return jsii.get(self, "id")

    @id.setter # type: ignore
    def id(self, value: typing.Optional[builtins.str]) -> None:
        jsii.set(self, "id", value)

    @builtins.property # type: ignore
    @jsii.member(jsii_name="timeouts")
    def timeouts(self) -> typing.Optional["DataAzurermKeyVaultTimeouts"]:
        return jsii.get(self, "timeouts")

    @timeouts.setter # type: ignore
    def timeouts(self, value: typing.Optional["DataAzurermKeyVaultTimeouts"]) -> None:
        jsii.set(self, "timeouts", value)


class DataAzurermKeyVaultAccessPolicy(
    cdktf.ComplexComputedList,
    metaclass=jsii.JSIIMeta,
    jsii_type="@cdktf/provider-azurerm.DataAzurermKeyVaultAccessPolicy",
):
    def __init__(
        self,
        terraform_resource: cdktf.ITerraformResource,
        terraform_attribute: builtins.str,
        index: builtins.str,
    ) -> None:
        """
        :param terraform_resource: -
        :param terraform_attribute: -
        :param index: -

        :stability: experimental
        """
        jsii.create(DataAzurermKeyVaultAccessPolicy, self, [terraform_resource, terraform_attribute, index])

    @builtins.property # type: ignore
    @jsii.member(jsii_name="applicationId")
    def application_id(self) -> builtins.str:
        return jsii.get(self, "applicationId")

    @builtins.property # type: ignore
    @jsii.member(jsii_name="certificatePermissions")
    def certificate_permissions(self) -> typing.List[builtins.str]:
        return jsii.get(self, "certificatePermissions")

    @builtins.property # type: ignore
    @jsii.member(jsii_name="keyPermissions")
    def key_permissions(self) -> typing.List[builtins.str]:
        return jsii.get(self, "keyPermissions")

    @builtins.property # type: ignore
    @jsii.member(jsii_name="objectId")
    def object_id(self) -> builtins.str:
        return jsii.get(self, "objectId")

    @builtins.property # type: ignore
    @jsii.member(jsii_name="secretPermissions")
    def secret_permissions(self) -> typing.List[builtins.str]:
        return jsii.get(self, "secretPermissions")

    @builtins.property # type: ignore
    @jsii.member(jsii_name="storagePermissions")
    def storage_permissions(self) -> typing.List[builtins.str]:
        return jsii.get(self, "storagePermissions")

    @builtins.property # type: ignore
    @jsii.member(jsii_name="tenantId")
    def tenant_id(self) -> builtins.str:
        return jsii.get(self, "tenantId")


class DataAzurermKeyVaultAccessPolicyA(
    cdktf.TerraformDataSource,
    metaclass=jsii.JSIIMeta,
    jsii_type="@cdktf/provider-azurerm.DataAzurermKeyVaultAccessPolicyA",
):
    def __init__(
        self,
        scope: constructs.Construct,
        id: builtins.str,
        *,
        name: builtins.str,
        timeouts: typing.Optional["DataAzurermKeyVaultAccessPolicyTimeouts"] = None,
        count: typing.Optional[jsii.Number] = None,
        depends_on: typing.Optional[typing.List[cdktf.TerraformResource]] = None,
        lifecycle: typing.Optional[cdktf.TerraformResourceLifecycle] = None,
        provider: typing.Optional[cdktf.TerraformProvider] = None,
    ) -> None:
        """
        :param scope: -
        :param id: -
        :param name: 
        :param timeouts: timeouts block.
        :param count: 
        :param depends_on: 
        :param lifecycle: 
        :param provider: 
        """
        config = DataAzurermKeyVaultAccessPolicyAConfig(
            name=name,
            timeouts=timeouts,
            count=count,
            depends_on=depends_on,
            lifecycle=lifecycle,
            provider=provider,
        )

        jsii.create(DataAzurermKeyVaultAccessPolicyA, self, [scope, id, config])

    @jsii.member(jsii_name="synthesizeAttributes")
    def _synthesize_attributes(self) -> typing.Mapping[builtins.str, typing.Any]:
        return jsii.invoke(self, "synthesizeAttributes", [])

    @builtins.property # type: ignore
    @jsii.member(jsii_name="certificatePermissions")
    def certificate_permissions(self) -> typing.List[builtins.str]:
        return jsii.get(self, "certificatePermissions")

    @builtins.property # type: ignore
    @jsii.member(jsii_name="keyPermissions")
    def key_permissions(self) -> typing.List[builtins.str]:
        return jsii.get(self, "keyPermissions")

    @builtins.property # type: ignore
    @jsii.member(jsii_name="secretPermissions")
    def secret_permissions(self) -> typing.List[builtins.str]:
        return jsii.get(self, "secretPermissions")

    @builtins.property # type: ignore
    @jsii.member(jsii_name="name")
    def name(self) -> builtins.str:
        return jsii.get(self, "name")

    @name.setter # type: ignore
    def name(self, value: builtins.str) -> None:
        jsii.set(self, "name", value)

    @builtins.property # type: ignore
    @jsii.member(jsii_name="id")
    def id(self) -> typing.Optional[builtins.str]:
        return jsii.get(self, "id")

    @id.setter # type: ignore
    def id(self, value: typing.Optional[builtins.str]) -> None:
        jsii.set(self, "id", value)

    @builtins.property # type: ignore
    @jsii.member(jsii_name="timeouts")
    def timeouts(self) -> typing.Optional["DataAzurermKeyVaultAccessPolicyTimeouts"]:
        return jsii.get(self, "timeouts")

    @timeouts.setter # type: ignore
    def timeouts(
        self,
        value: typing.Optional["DataAzurermKeyVaultAccessPolicyTimeouts"],
    ) -> None:
        jsii.set(self, "timeouts", value)


@jsii.data_type(
    jsii_type="@cdktf/provider-azurerm.DataAzurermKeyVaultAccessPolicyAConfig",
    jsii_struct_bases=[cdktf.TerraformMetaArguments],
    name_mapping={
        "count": "count",
        "depends_on": "dependsOn",
        "lifecycle": "lifecycle",
        "provider": "provider",
        "name": "name",
        "timeouts": "timeouts",
    },
)
class DataAzurermKeyVaultAccessPolicyAConfig(cdktf.TerraformMetaArguments):
    def __init__(
        self,
        *,
        count: typing.Optional[jsii.Number] = None,
        depends_on: typing.Optional[typing.List[cdktf.TerraformResource]] = None,
        lifecycle: typing.Optional[cdktf.TerraformResourceLifecycle] = None,
        provider: typing.Optional[cdktf.TerraformProvider] = None,
        name: builtins.str,
        timeouts: typing.Optional["DataAzurermKeyVaultAccessPolicyTimeouts"] = None,
    ) -> None:
        """
        :param count: 
        :param depends_on: 
        :param lifecycle: 
        :param provider: 
        :param name: 
        :param timeouts: timeouts block.
        """
        if isinstance(lifecycle, dict):
            lifecycle = cdktf.TerraformResourceLifecycle(**lifecycle)
        if isinstance(timeouts, dict):
            timeouts = DataAzurermKeyVaultAccessPolicyTimeouts(**timeouts)
        self._values: typing.Dict[str, typing.Any] = {
            "name": name,
        }
        if count is not None:
            self._values["count"] = count
        if depends_on is not None:
            self._values["depends_on"] = depends_on
        if lifecycle is not None:
            self._values["lifecycle"] = lifecycle
        if provider is not None:
            self._values["provider"] = provider
        if timeouts is not None:
            self._values["timeouts"] = timeouts

    @builtins.property
    def count(self) -> typing.Optional[jsii.Number]:
        """
        :stability: experimental
        """
        result = self._values.get("count")
        return result

    @builtins.property
    def depends_on(self) -> typing.Optional[typing.List[cdktf.TerraformResource]]:
        """
        :stability: experimental
        """
        result = self._values.get("depends_on")
        return result

    @builtins.property
    def lifecycle(self) -> typing.Optional[cdktf.TerraformResourceLifecycle]:
        """
        :stability: experimental
        """
        result = self._values.get("lifecycle")
        return result

    @builtins.property
    def provider(self) -> typing.Optional[cdktf.TerraformProvider]:
        """
        :stability: experimental
        """
        result = self._values.get("provider")
        return result

    @builtins.property
    def name(self) -> builtins.str:
        result = self._values.get("name")
        assert result is not None, "Required property 'name' is missing"
        return result

    @builtins.property
    def timeouts(self) -> typing.Optional["DataAzurermKeyVaultAccessPolicyTimeouts"]:
        """timeouts block."""
        result = self._values.get("timeouts")
        return result

    def __eq__(self, rhs: typing.Any) -> builtins.bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs: typing.Any) -> builtins.bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return "DataAzurermKeyVaultAccessPolicyAConfig(%s)" % ", ".join(
            k + "=" + repr(v) for k, v in self._values.items()
        )


@jsii.data_type(
    jsii_type="@cdktf/provider-azurerm.DataAzurermKeyVaultAccessPolicyTimeouts",
    jsii_struct_bases=[],
    name_mapping={"read": "read"},
)
class DataAzurermKeyVaultAccessPolicyTimeouts:
    def __init__(self, *, read: typing.Optional[builtins.str] = None) -> None:
        """
        :param read: 
        """
        self._values: typing.Dict[str, typing.Any] = {}
        if read is not None:
            self._values["read"] = read

    @builtins.property
    def read(self) -> typing.Optional[builtins.str]:
        result = self._values.get("read")
        return result

    def __eq__(self, rhs: typing.Any) -> builtins.bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs: typing.Any) -> builtins.bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return "DataAzurermKeyVaultAccessPolicyTimeouts(%s)" % ", ".join(
            k + "=" + repr(v) for k, v in self._values.items()
        )


@jsii.data_type(
    jsii_type="@cdktf/provider-azurerm.DataAzurermKeyVaultConfig",
    jsii_struct_bases=[cdktf.TerraformMetaArguments],
    name_mapping={
        "count": "count",
        "depends_on": "dependsOn",
        "lifecycle": "lifecycle",
        "provider": "provider",
        "name": "name",
        "resource_group_name": "resourceGroupName",
        "timeouts": "timeouts",
    },
)
class DataAzurermKeyVaultConfig(cdktf.TerraformMetaArguments):
    def __init__(
        self,
        *,
        count: typing.Optional[jsii.Number] = None,
        depends_on: typing.Optional[typing.List[cdktf.TerraformResource]] = None,
        lifecycle: typing.Optional[cdktf.TerraformResourceLifecycle] = None,
        provider: typing.Optional[cdktf.TerraformProvider] = None,
        name: builtins.str,
        resource_group_name: builtins.str,
        timeouts: typing.Optional["DataAzurermKeyVaultTimeouts"] = None,
    ) -> None:
        """
        :param count: 
        :param depends_on: 
        :param lifecycle: 
        :param provider: 
        :param name: 
        :param resource_group_name: 
        :param timeouts: timeouts block.
        """
        if isinstance(lifecycle, dict):
            lifecycle = cdktf.TerraformResourceLifecycle(**lifecycle)
        if isinstance(timeouts, dict):
            timeouts = DataAzurermKeyVaultTimeouts(**timeouts)
        self._values: typing.Dict[str, typing.Any] = {
            "name": name,
            "resource_group_name": resource_group_name,
        }
        if count is not None:
            self._values["count"] = count
        if depends_on is not None:
            self._values["depends_on"] = depends_on
        if lifecycle is not None:
            self._values["lifecycle"] = lifecycle
        if provider is not None:
            self._values["provider"] = provider
        if timeouts is not None:
            self._values["timeouts"] = timeouts

    @builtins.property
    def count(self) -> typing.Optional[jsii.Number]:
        """
        :stability: experimental
        """
        result = self._values.get("count")
        return result

    @builtins.property
    def depends_on(self) -> typing.Optional[typing.List[cdktf.TerraformResource]]:
        """
        :stability: experimental
        """
        result = self._values.get("depends_on")
        return result

    @builtins.property
    def lifecycle(self) -> typing.Optional[cdktf.TerraformResourceLifecycle]:
        """
        :stability: experimental
        """
        result = self._values.get("lifecycle")
        return result

    @builtins.property
    def provider(self) -> typing.Optional[cdktf.TerraformProvider]:
        """
        :stability: experimental
        """
        result = self._values.get("provider")
        return result

    @builtins.property
    def name(self) -> builtins.str:
        result = self._values.get("name")
        assert result is not None, "Required property 'name' is missing"
        return result

    @builtins.property
    def resource_group_name(self) -> builtins.str:
        result = self._values.get("resource_group_name")
        assert result is not None, "Required property 'resource_group_name' is missing"
        return result

    @builtins.property
    def timeouts(self) -> typing.Optional["DataAzurermKeyVaultTimeouts"]:
        """timeouts block."""
        result = self._values.get("timeouts")
        return result

    def __eq__(self, rhs: typing.Any) -> builtins.bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs: typing.Any) -> builtins.bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return "DataAzurermKeyVaultConfig(%s)" % ", ".join(
            k + "=" + repr(v) for k, v in self._values.items()
        )


class DataAzurermKeyVaultKey(
    cdktf.TerraformDataSource,
    metaclass=jsii.JSIIMeta,
    jsii_type="@cdktf/provider-azurerm.DataAzurermKeyVaultKey",
):
    def __init__(
        self,
        scope: constructs.Construct,
        id: builtins.str,
        *,
        key_vault_id: builtins.str,
        name: builtins.str,
        timeouts: typing.Optional["DataAzurermKeyVaultKeyTimeouts"] = None,
        count: typing.Optional[jsii.Number] = None,
        depends_on: typing.Optional[typing.List[cdktf.TerraformResource]] = None,
        lifecycle: typing.Optional[cdktf.TerraformResourceLifecycle] = None,
        provider: typing.Optional[cdktf.TerraformProvider] = None,
    ) -> None:
        """
        :param scope: -
        :param id: -
        :param key_vault_id: 
        :param name: 
        :param timeouts: timeouts block.
        :param count: 
        :param depends_on: 
        :param lifecycle: 
        :param provider: 
        """
        config = DataAzurermKeyVaultKeyConfig(
            key_vault_id=key_vault_id,
            name=name,
            timeouts=timeouts,
            count=count,
            depends_on=depends_on,
            lifecycle=lifecycle,
            provider=provider,
        )

        jsii.create(DataAzurermKeyVaultKey, self, [scope, id, config])

    @jsii.member(jsii_name="synthesizeAttributes")
    def _synthesize_attributes(self) -> typing.Mapping[builtins.str, typing.Any]:
        return jsii.invoke(self, "synthesizeAttributes", [])

    @jsii.member(jsii_name="tags")
    def tags(self, key: builtins.str) -> builtins.str:
        """
        :param key: -
        """
        return jsii.invoke(self, "tags", [key])

    @builtins.property # type: ignore
    @jsii.member(jsii_name="e")
    def e(self) -> builtins.str:
        return jsii.get(self, "e")

    @builtins.property # type: ignore
    @jsii.member(jsii_name="keyOpts")
    def key_opts(self) -> typing.List[builtins.str]:
        return jsii.get(self, "keyOpts")

    @builtins.property # type: ignore
    @jsii.member(jsii_name="keySize")
    def key_size(self) -> jsii.Number:
        return jsii.get(self, "keySize")

    @builtins.property # type: ignore
    @jsii.member(jsii_name="keyType")
    def key_type(self) -> builtins.str:
        return jsii.get(self, "keyType")

    @builtins.property # type: ignore
    @jsii.member(jsii_name="n")
    def n(self) -> builtins.str:
        return jsii.get(self, "n")

    @builtins.property # type: ignore
    @jsii.member(jsii_name="version")
    def version(self) -> builtins.str:
        return jsii.get(self, "version")

    @builtins.property # type: ignore
    @jsii.member(jsii_name="keyVaultId")
    def key_vault_id(self) -> builtins.str:
        return jsii.get(self, "keyVaultId")

    @key_vault_id.setter # type: ignore
    def key_vault_id(self, value: builtins.str) -> None:
        jsii.set(self, "keyVaultId", value)

    @builtins.property # type: ignore
    @jsii.member(jsii_name="name")
    def name(self) -> builtins.str:
        return jsii.get(self, "name")

    @name.setter # type: ignore
    def name(self, value: builtins.str) -> None:
        jsii.set(self, "name", value)

    @builtins.property # type: ignore
    @jsii.member(jsii_name="id")
    def id(self) -> typing.Optional[builtins.str]:
        return jsii.get(self, "id")

    @id.setter # type: ignore
    def id(self, value: typing.Optional[builtins.str]) -> None:
        jsii.set(self, "id", value)

    @builtins.property # type: ignore
    @jsii.member(jsii_name="timeouts")
    def timeouts(self) -> typing.Optional["DataAzurermKeyVaultKeyTimeouts"]:
        return jsii.get(self, "timeouts")

    @timeouts.setter # type: ignore
    def timeouts(
        self,
        value: typing.Optional["DataAzurermKeyVaultKeyTimeouts"],
    ) -> None:
        jsii.set(self, "timeouts", value)


@jsii.data_type(
    jsii_type="@cdktf/provider-azurerm.DataAzurermKeyVaultKeyConfig",
    jsii_struct_bases=[cdktf.TerraformMetaArguments],
    name_mapping={
        "count": "count",
        "depends_on": "dependsOn",
        "lifecycle": "lifecycle",
        "provider": "provider",
        "key_vault_id": "keyVaultId",
        "name": "name",
        "timeouts": "timeouts",
    },
)
class DataAzurermKeyVaultKeyConfig(cdktf.TerraformMetaArguments):
    def __init__(
        self,
        *,
        count: typing.Optional[jsii.Number] = None,
        depends_on: typing.Optional[typing.List[cdktf.TerraformResource]] = None,
        lifecycle: typing.Optional[cdktf.TerraformResourceLifecycle] = None,
        provider: typing.Optional[cdktf.TerraformProvider] = None,
        key_vault_id: builtins.str,
        name: builtins.str,
        timeouts: typing.Optional["DataAzurermKeyVaultKeyTimeouts"] = None,
    ) -> None:
        """
        :param count: 
        :param depends_on: 
        :param lifecycle: 
        :param provider: 
        :param key_vault_id: 
        :param name: 
        :param timeouts: timeouts block.
        """
        if isinstance(lifecycle, dict):
            lifecycle = cdktf.TerraformResourceLifecycle(**lifecycle)
        if isinstance(timeouts, dict):
            timeouts = DataAzurermKeyVaultKeyTimeouts(**timeouts)
        self._values: typing.Dict[str, typing.Any] = {
            "key_vault_id": key_vault_id,
            "name": name,
        }
        if count is not None:
            self._values["count"] = count
        if depends_on is not None:
            self._values["depends_on"] = depends_on
        if lifecycle is not None:
            self._values["lifecycle"] = lifecycle
        if provider is not None:
            self._values["provider"] = provider
        if timeouts is not None:
            self._values["timeouts"] = timeouts

    @builtins.property
    def count(self) -> typing.Optional[jsii.Number]:
        """
        :stability: experimental
        """
        result = self._values.get("count")
        return result

    @builtins.property
    def depends_on(self) -> typing.Optional[typing.List[cdktf.TerraformResource]]:
        """
        :stability: experimental
        """
        result = self._values.get("depends_on")
        return result

    @builtins.property
    def lifecycle(self) -> typing.Optional[cdktf.TerraformResourceLifecycle]:
        """
        :stability: experimental
        """
        result = self._values.get("lifecycle")
        return result

    @builtins.property
    def provider(self) -> typing.Optional[cdktf.TerraformProvider]:
        """
        :stability: experimental
        """
        result = self._values.get("provider")
        return result

    @builtins.property
    def key_vault_id(self) -> builtins.str:
        result = self._values.get("key_vault_id")
        assert result is not None, "Required property 'key_vault_id' is missing"
        return result

    @builtins.property
    def name(self) -> builtins.str:
        result = self._values.get("name")
        assert result is not None, "Required property 'name' is missing"
        return result

    @builtins.property
    def timeouts(self) -> typing.Optional["DataAzurermKeyVaultKeyTimeouts"]:
        """timeouts block."""
        result = self._values.get("timeouts")
        return result

    def __eq__(self, rhs: typing.Any) -> builtins.bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs: typing.Any) -> builtins.bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return "DataAzurermKeyVaultKeyConfig(%s)" % ", ".join(
            k + "=" + repr(v) for k, v in self._values.items()
        )


@jsii.data_type(
    jsii_type="@cdktf/provider-azurerm.DataAzurermKeyVaultKeyTimeouts",
    jsii_struct_bases=[],
    name_mapping={"read": "read"},
)
class DataAzurermKeyVaultKeyTimeouts:
    def __init__(self, *, read: typing.Optional[builtins.str] = None) -> None:
        """
        :param read: 
        """
        self._values: typing.Dict[str, typing.Any] = {}
        if read is not None:
            self._values["read"] = read

    @builtins.property
    def read(self) -> typing.Optional[builtins.str]:
        result = self._values.get("read")
        return result

    def __eq__(self, rhs: typing.Any) -> builtins.bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs: typing.Any) -> builtins.bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return "DataAzurermKeyVaultKeyTimeouts(%s)" % ", ".join(
            k + "=" + repr(v) for k, v in self._values.items()
        )


class DataAzurermKeyVaultNetworkAcls(
    cdktf.ComplexComputedList,
    metaclass=jsii.JSIIMeta,
    jsii_type="@cdktf/provider-azurerm.DataAzurermKeyVaultNetworkAcls",
):
    def __init__(
        self,
        terraform_resource: cdktf.ITerraformResource,
        terraform_attribute: builtins.str,
        index: builtins.str,
    ) -> None:
        """
        :param terraform_resource: -
        :param terraform_attribute: -
        :param index: -

        :stability: experimental
        """
        jsii.create(DataAzurermKeyVaultNetworkAcls, self, [terraform_resource, terraform_attribute, index])

    @builtins.property # type: ignore
    @jsii.member(jsii_name="bypass")
    def bypass(self) -> builtins.str:
        return jsii.get(self, "bypass")

    @builtins.property # type: ignore
    @jsii.member(jsii_name="defaultAction")
    def default_action(self) -> builtins.str:
        return jsii.get(self, "defaultAction")

    @builtins.property # type: ignore
    @jsii.member(jsii_name="ipRules")
    def ip_rules(self) -> typing.List[builtins.str]:
        return jsii.get(self, "ipRules")

    @builtins.property # type: ignore
    @jsii.member(jsii_name="virtualNetworkSubnetIds")
    def virtual_network_subnet_ids(self) -> typing.List[builtins.str]:
        return jsii.get(self, "virtualNetworkSubnetIds")


class DataAzurermKeyVaultSecret(
    cdktf.TerraformDataSource,
    metaclass=jsii.JSIIMeta,
    jsii_type="@cdktf/provider-azurerm.DataAzurermKeyVaultSecret",
):
    def __init__(
        self,
        scope: constructs.Construct,
        id: builtins.str,
        *,
        key_vault_id: builtins.str,
        name: builtins.str,
        timeouts: typing.Optional["DataAzurermKeyVaultSecretTimeouts"] = None,
        count: typing.Optional[jsii.Number] = None,
        depends_on: typing.Optional[typing.List[cdktf.TerraformResource]] = None,
        lifecycle: typing.Optional[cdktf.TerraformResourceLifecycle] = None,
        provider: typing.Optional[cdktf.TerraformProvider] = None,
    ) -> None:
        """
        :param scope: -
        :param id: -
        :param key_vault_id: 
        :param name: 
        :param timeouts: timeouts block.
        :param count: 
        :param depends_on: 
        :param lifecycle: 
        :param provider: 
        """
        config = DataAzurermKeyVaultSecretConfig(
            key_vault_id=key_vault_id,
            name=name,
            timeouts=timeouts,
            count=count,
            depends_on=depends_on,
            lifecycle=lifecycle,
            provider=provider,
        )

        jsii.create(DataAzurermKeyVaultSecret, self, [scope, id, config])

    @jsii.member(jsii_name="synthesizeAttributes")
    def _synthesize_attributes(self) -> typing.Mapping[builtins.str, typing.Any]:
        return jsii.invoke(self, "synthesizeAttributes", [])

    @jsii.member(jsii_name="tags")
    def tags(self, key: builtins.str) -> builtins.str:
        """
        :param key: -
        """
        return jsii.invoke(self, "tags", [key])

    @builtins.property # type: ignore
    @jsii.member(jsii_name="contentType")
    def content_type(self) -> builtins.str:
        return jsii.get(self, "contentType")

    @builtins.property # type: ignore
    @jsii.member(jsii_name="value")
    def value(self) -> builtins.str:
        return jsii.get(self, "value")

    @builtins.property # type: ignore
    @jsii.member(jsii_name="version")
    def version(self) -> builtins.str:
        return jsii.get(self, "version")

    @builtins.property # type: ignore
    @jsii.member(jsii_name="keyVaultId")
    def key_vault_id(self) -> builtins.str:
        return jsii.get(self, "keyVaultId")

    @key_vault_id.setter # type: ignore
    def key_vault_id(self, value: builtins.str) -> None:
        jsii.set(self, "keyVaultId", value)

    @builtins.property # type: ignore
    @jsii.member(jsii_name="name")
    def name(self) -> builtins.str:
        return jsii.get(self, "name")

    @name.setter # type: ignore
    def name(self, value: builtins.str) -> None:
        jsii.set(self, "name", value)

    @builtins.property # type: ignore
    @jsii.member(jsii_name="id")
    def id(self) -> typing.Optional[builtins.str]:
        return jsii.get(self, "id")

    @id.setter # type: ignore
    def id(self, value: typing.Optional[builtins.str]) -> None:
        jsii.set(self, "id", value)

    @builtins.property # type: ignore
    @jsii.member(jsii_name="timeouts")
    def timeouts(self) -> typing.Optional["DataAzurermKeyVaultSecretTimeouts"]:
        return jsii.get(self, "timeouts")

    @timeouts.setter # type: ignore
    def timeouts(
        self,
        value: typing.Optional["DataAzurermKeyVaultSecretTimeouts"],
    ) -> None:
        jsii.set(self, "timeouts", value)


@jsii.data_type(
    jsii_type="@cdktf/provider-azurerm.DataAzurermKeyVaultSecretConfig",
    jsii_struct_bases=[cdktf.TerraformMetaArguments],
    name_mapping={
        "count": "count",
        "depends_on": "dependsOn",
        "lifecycle": "lifecycle",
        "provider": "provider",
        "key_vault_id": "keyVaultId",
        "name": "name",
        "timeouts": "timeouts",
    },
)
class DataAzurermKeyVaultSecretConfig(cdktf.TerraformMetaArguments):
    def __init__(
        self,
        *,
        count: typing.Optional[jsii.Number] = None,
        depends_on: typing.Optional[typing.List[cdktf.TerraformResource]] = None,
        lifecycle: typing.Optional[cdktf.TerraformResourceLifecycle] = None,
        provider: typing.Optional[cdktf.TerraformProvider] = None,
        key_vault_id: builtins.str,
        name: builtins.str,
        timeouts: typing.Optional["DataAzurermKeyVaultSecretTimeouts"] = None,
    ) -> None:
        """
        :param count: 
        :param depends_on: 
        :param lifecycle: 
        :param provider: 
        :param key_vault_id: 
        :param name: 
        :param timeouts: timeouts block.
        """
        if isinstance(lifecycle, dict):
            lifecycle = cdktf.TerraformResourceLifecycle(**lifecycle)
        if isinstance(timeouts, dict):
            timeouts = DataAzurermKeyVaultSecretTimeouts(**timeouts)
        self._values: typing.Dict[str, typing.Any] = {
            "key_vault_id": key_vault_id,
            "name": name,
        }
        if count is not None:
            self._values["count"] = count
        if depends_on is not None:
            self._values["depends_on"] = depends_on
        if lifecycle is not None:
            self._values["lifecycle"] = lifecycle
        if provider is not None:
            self._values["provider"] = provider
        if timeouts is not None:
            self._values["timeouts"] = timeouts

    @builtins.property
    def count(self) -> typing.Optional[jsii.Number]:
        """
        :stability: experimental
        """
        result = self._values.get("count")
        return result

    @builtins.property
    def depends_on(self) -> typing.Optional[typing.List[cdktf.TerraformResource]]:
        """
        :stability: experimental
        """
        result = self._values.get("depends_on")
        return result

    @builtins.property
    def lifecycle(self) -> typing.Optional[cdktf.TerraformResourceLifecycle]:
        """
        :stability: experimental
        """
        result = self._values.get("lifecycle")
        return result

    @builtins.property
    def provider(self) -> typing.Optional[cdktf.TerraformProvider]:
        """
        :stability: experimental
        """
        result = self._values.get("provider")
        return result

    @builtins.property
    def key_vault_id(self) -> builtins.str:
        result = self._values.get("key_vault_id")
        assert result is not None, "Required property 'key_vault_id' is missing"
        return result

    @builtins.property
    def name(self) -> builtins.str:
        result = self._values.get("name")
        assert result is not None, "Required property 'name' is missing"
        return result

    @builtins.property
    def timeouts(self) -> typing.Optional["DataAzurermKeyVaultSecretTimeouts"]:
        """timeouts block."""
        result = self._values.get("timeouts")
        return result

    def __eq__(self, rhs: typing.Any) -> builtins.bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs: typing.Any) -> builtins.bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return "DataAzurermKeyVaultSecretConfig(%s)" % ", ".join(
            k + "=" + repr(v) for k, v in self._values.items()
        )


@jsii.data_type(
    jsii_type="@cdktf/provider-azurerm.DataAzurermKeyVaultSecretTimeouts",
    jsii_struct_bases=[],
    name_mapping={"read": "read"},
)
class DataAzurermKeyVaultSecretTimeouts:
    def __init__(self, *, read: typing.Optional[builtins.str] = None) -> None:
        """
        :param read: 
        """
        self._values: typing.Dict[str, typing.Any] = {}
        if read is not None:
            self._values["read"] = read

    @builtins.property
    def read(self) -> typing.Optional[builtins.str]:
        result = self._values.get("read")
        return result

    def __eq__(self, rhs: typing.Any) -> builtins.bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs: typing.Any) -> builtins.bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return "DataAzurermKeyVaultSecretTimeouts(%s)" % ", ".join(
            k + "=" + repr(v) for k, v in self._values.items()
        )


@jsii.data_type(
    jsii_type="@cdktf/provider-azurerm.DataAzurermKeyVaultTimeouts",
    jsii_struct_bases=[],
    name_mapping={"read": "read"},
)
class DataAzurermKeyVaultTimeouts:
    def __init__(self, *, read: typing.Optional[builtins.str] = None) -> None:
        """
        :param read: 
        """
        self._values: typing.Dict[str, typing.Any] = {}
        if read is not None:
            self._values["read"] = read

    @builtins.property
    def read(self) -> typing.Optional[builtins.str]:
        result = self._values.get("read")
        return result

    def __eq__(self, rhs: typing.Any) -> builtins.bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs: typing.Any) -> builtins.bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return "DataAzurermKeyVaultTimeouts(%s)" % ", ".join(
            k + "=" + repr(v) for k, v in self._values.items()
        )


class DataAzurermKubernetesCluster(
    cdktf.TerraformDataSource,
    metaclass=jsii.JSIIMeta,
    jsii_type="@cdktf/provider-azurerm.DataAzurermKubernetesCluster",
):
    def __init__(
        self,
        scope: constructs.Construct,
        id: builtins.str,
        *,
        name: builtins.str,
        resource_group_name: builtins.str,
        timeouts: typing.Optional["DataAzurermKubernetesClusterTimeouts"] = None,
        count: typing.Optional[jsii.Number] = None,
        depends_on: typing.Optional[typing.List[cdktf.TerraformResource]] = None,
        lifecycle: typing.Optional[cdktf.TerraformResourceLifecycle] = None,
        provider: typing.Optional[cdktf.TerraformProvider] = None,
    ) -> None:
        """
        :param scope: -
        :param id: -
        :param name: 
        :param resource_group_name: 
        :param timeouts: timeouts block.
        :param count: 
        :param depends_on: 
        :param lifecycle: 
        :param provider: 
        """
        config = DataAzurermKubernetesClusterConfig(
            name=name,
            resource_group_name=resource_group_name,
            timeouts=timeouts,
            count=count,
            depends_on=depends_on,
            lifecycle=lifecycle,
            provider=provider,
        )

        jsii.create(DataAzurermKubernetesCluster, self, [scope, id, config])

    @jsii.member(jsii_name="addonProfile")
    def addon_profile(
        self,
        index: builtins.str,
    ) -> "DataAzurermKubernetesClusterAddonProfile":
        """
        :param index: -
        """
        return jsii.invoke(self, "addonProfile", [index])

    @jsii.member(jsii_name="agentPoolProfile")
    def agent_pool_profile(
        self,
        index: builtins.str,
    ) -> "DataAzurermKubernetesClusterAgentPoolProfile":
        """
        :param index: -
        """
        return jsii.invoke(self, "agentPoolProfile", [index])

    @jsii.member(jsii_name="kubeAdminConfig")
    def kube_admin_config(
        self,
        index: builtins.str,
    ) -> "DataAzurermKubernetesClusterKubeAdminConfig":
        """
        :param index: -
        """
        return jsii.invoke(self, "kubeAdminConfig", [index])

    @jsii.member(jsii_name="kubeConfig")
    def kube_config(
        self,
        index: builtins.str,
    ) -> "DataAzurermKubernetesClusterKubeConfig":
        """
        :param index: -
        """
        return jsii.invoke(self, "kubeConfig", [index])

    @jsii.member(jsii_name="linuxProfile")
    def linux_profile(
        self,
        index: builtins.str,
    ) -> "DataAzurermKubernetesClusterLinuxProfile":
        """
        :param index: -
        """
        return jsii.invoke(self, "linuxProfile", [index])

    @jsii.member(jsii_name="networkProfile")
    def network_profile(
        self,
        index: builtins.str,
    ) -> "DataAzurermKubernetesClusterNetworkProfile":
        """
        :param index: -
        """
        return jsii.invoke(self, "networkProfile", [index])

    @jsii.member(jsii_name="roleBasedAccessControl")
    def role_based_access_control(
        self,
        index: builtins.str,
    ) -> "DataAzurermKubernetesClusterRoleBasedAccessControl":
        """
        :param index: -
        """
        return jsii.invoke(self, "roleBasedAccessControl", [index])

    @jsii.member(jsii_name="servicePrincipal")
    def service_principal(
        self,
        index: builtins.str,
    ) -> "DataAzurermKubernetesClusterServicePrincipal":
        """
        :param index: -
        """
        return jsii.invoke(self, "servicePrincipal", [index])

    @jsii.member(jsii_name="synthesizeAttributes")
    def _synthesize_attributes(self) -> typing.Mapping[builtins.str, typing.Any]:
        return jsii.invoke(self, "synthesizeAttributes", [])

    @jsii.member(jsii_name="tags")
    def tags(self, key: builtins.str) -> builtins.str:
        """
        :param key: -
        """
        return jsii.invoke(self, "tags", [key])

    @jsii.member(jsii_name="windowsProfile")
    def windows_profile(
        self,
        index: builtins.str,
    ) -> "DataAzurermKubernetesClusterWindowsProfile":
        """
        :param index: -
        """
        return jsii.invoke(self, "windowsProfile", [index])

    @builtins.property # type: ignore
    @jsii.member(jsii_name="apiServerAuthorizedIpRanges")
    def api_server_authorized_ip_ranges(self) -> typing.List[builtins.str]:
        return jsii.get(self, "apiServerAuthorizedIpRanges")

    @builtins.property # type: ignore
    @jsii.member(jsii_name="dnsPrefix")
    def dns_prefix(self) -> builtins.str:
        return jsii.get(self, "dnsPrefix")

    @builtins.property # type: ignore
    @jsii.member(jsii_name="fqdn")
    def fqdn(self) -> builtins.str:
        return jsii.get(self, "fqdn")

    @builtins.property # type: ignore
    @jsii.member(jsii_name="kubeAdminConfigRaw")
    def kube_admin_config_raw(self) -> builtins.str:
        return jsii.get(self, "kubeAdminConfigRaw")

    @builtins.property # type: ignore
    @jsii.member(jsii_name="kubeConfigRaw")
    def kube_config_raw(self) -> builtins.str:
        return jsii.get(self, "kubeConfigRaw")

    @builtins.property # type: ignore
    @jsii.member(jsii_name="kubernetesVersion")
    def kubernetes_version(self) -> builtins.str:
        return jsii.get(self, "kubernetesVersion")

    @builtins.property # type: ignore
    @jsii.member(jsii_name="location")
    def location(self) -> builtins.str:
        return jsii.get(self, "location")

    @builtins.property # type: ignore
    @jsii.member(jsii_name="nodeResourceGroup")
    def node_resource_group(self) -> builtins.str:
        return jsii.get(self, "nodeResourceGroup")

    @builtins.property # type: ignore
    @jsii.member(jsii_name="privateFqdn")
    def private_fqdn(self) -> builtins.str:
        return jsii.get(self, "privateFqdn")

    @builtins.property # type: ignore
    @jsii.member(jsii_name="privateLinkEnabled")
    def private_link_enabled(self) -> builtins.bool:
        return jsii.get(self, "privateLinkEnabled")

    @builtins.property # type: ignore
    @jsii.member(jsii_name="name")
    def name(self) -> builtins.str:
        return jsii.get(self, "name")

    @name.setter # type: ignore
    def name(self, value: builtins.str) -> None:
        jsii.set(self, "name", value)

    @builtins.property # type: ignore
    @jsii.member(jsii_name="resourceGroupName")
    def resource_group_name(self) -> builtins.str:
        return jsii.get(self, "resourceGroupName")

    @resource_group_name.setter # type: ignore
    def resource_group_name(self, value: builtins.str) -> None:
        jsii.set(self, "resourceGroupName", value)

    @builtins.property # type: ignore
    @jsii.member(jsii_name="id")
    def id(self) -> typing.Optional[builtins.str]:
        return jsii.get(self, "id")

    @id.setter # type: ignore
    def id(self, value: typing.Optional[builtins.str]) -> None:
        jsii.set(self, "id", value)

    @builtins.property # type: ignore
    @jsii.member(jsii_name="timeouts")
    def timeouts(self) -> typing.Optional["DataAzurermKubernetesClusterTimeouts"]:
        return jsii.get(self, "timeouts")

    @timeouts.setter # type: ignore
    def timeouts(
        self,
        value: typing.Optional["DataAzurermKubernetesClusterTimeouts"],
    ) -> None:
        jsii.set(self, "timeouts", value)


class DataAzurermKubernetesClusterAddonProfile(
    cdktf.ComplexComputedList,
    metaclass=jsii.JSIIMeta,
    jsii_type="@cdktf/provider-azurerm.DataAzurermKubernetesClusterAddonProfile",
):
    def __init__(
        self,
        terraform_resource: cdktf.ITerraformResource,
        terraform_attribute: builtins.str,
        index: builtins.str,
    ) -> None:
        """
        :param terraform_resource: -
        :param terraform_attribute: -
        :param index: -

        :stability: experimental
        """
        jsii.create(DataAzurermKubernetesClusterAddonProfile, self, [terraform_resource, terraform_attribute, index])

    @builtins.property # type: ignore
    @jsii.member(jsii_name="azurePolicy")
    def azure_policy(self) -> typing.Any:
        return jsii.get(self, "azurePolicy")

    @builtins.property # type: ignore
    @jsii.member(jsii_name="httpApplicationRouting")
    def http_application_routing(self) -> typing.Any:
        return jsii.get(self, "httpApplicationRouting")

    @builtins.property # type: ignore
    @jsii.member(jsii_name="kubeDashboard")
    def kube_dashboard(self) -> typing.Any:
        return jsii.get(self, "kubeDashboard")

    @builtins.property # type: ignore
    @jsii.member(jsii_name="omsAgent")
    def oms_agent(self) -> typing.Any:
        return jsii.get(self, "omsAgent")


class DataAzurermKubernetesClusterAddonProfileAzurePolicy(
    cdktf.ComplexComputedList,
    metaclass=jsii.JSIIMeta,
    jsii_type="@cdktf/provider-azurerm.DataAzurermKubernetesClusterAddonProfileAzurePolicy",
):
    def __init__(
        self,
        terraform_resource: cdktf.ITerraformResource,
        terraform_attribute: builtins.str,
        index: builtins.str,
    ) -> None:
        """
        :param terraform_resource: -
        :param terraform_attribute: -
        :param index: -

        :stability: experimental
        """
        jsii.create(DataAzurermKubernetesClusterAddonProfileAzurePolicy, self, [terraform_resource, terraform_attribute, index])

    @builtins.property # type: ignore
    @jsii.member(jsii_name="enabled")
    def enabled(self) -> builtins.bool:
        return jsii.get(self, "enabled")


class DataAzurermKubernetesClusterAddonProfileHttpApplicationRouting(
    cdktf.ComplexComputedList,
    metaclass=jsii.JSIIMeta,
    jsii_type="@cdktf/provider-azurerm.DataAzurermKubernetesClusterAddonProfileHttpApplicationRouting",
):
    def __init__(
        self,
        terraform_resource: cdktf.ITerraformResource,
        terraform_attribute: builtins.str,
        index: builtins.str,
    ) -> None:
        """
        :param terraform_resource: -
        :param terraform_attribute: -
        :param index: -

        :stability: experimental
        """
        jsii.create(DataAzurermKubernetesClusterAddonProfileHttpApplicationRouting, self, [terraform_resource, terraform_attribute, index])

    @builtins.property # type: ignore
    @jsii.member(jsii_name="enabled")
    def enabled(self) -> builtins.bool:
        return jsii.get(self, "enabled")

    @builtins.property # type: ignore
    @jsii.member(jsii_name="httpApplicationRoutingZoneName")
    def http_application_routing_zone_name(self) -> builtins.str:
        return jsii.get(self, "httpApplicationRoutingZoneName")


class DataAzurermKubernetesClusterAddonProfileKubeDashboard(
    cdktf.ComplexComputedList,
    metaclass=jsii.JSIIMeta,
    jsii_type="@cdktf/provider-azurerm.DataAzurermKubernetesClusterAddonProfileKubeDashboard",
):
    def __init__(
        self,
        terraform_resource: cdktf.ITerraformResource,
        terraform_attribute: builtins.str,
        index: builtins.str,
    ) -> None:
        """
        :param terraform_resource: -
        :param terraform_attribute: -
        :param index: -

        :stability: experimental
        """
        jsii.create(DataAzurermKubernetesClusterAddonProfileKubeDashboard, self, [terraform_resource, terraform_attribute, index])

    @builtins.property # type: ignore
    @jsii.member(jsii_name="enabled")
    def enabled(self) -> builtins.bool:
        return jsii.get(self, "enabled")


class DataAzurermKubernetesClusterAddonProfileOmsAgent(
    cdktf.ComplexComputedList,
    metaclass=jsii.JSIIMeta,
    jsii_type="@cdktf/provider-azurerm.DataAzurermKubernetesClusterAddonProfileOmsAgent",
):
    def __init__(
        self,
        terraform_resource: cdktf.ITerraformResource,
        terraform_attribute: builtins.str,
        index: builtins.str,
    ) -> None:
        """
        :param terraform_resource: -
        :param terraform_attribute: -
        :param index: -

        :stability: experimental
        """
        jsii.create(DataAzurermKubernetesClusterAddonProfileOmsAgent, self, [terraform_resource, terraform_attribute, index])

    @builtins.property # type: ignore
    @jsii.member(jsii_name="enabled")
    def enabled(self) -> builtins.bool:
        return jsii.get(self, "enabled")

    @builtins.property # type: ignore
    @jsii.member(jsii_name="logAnalyticsWorkspaceId")
    def log_analytics_workspace_id(self) -> builtins.str:
        return jsii.get(self, "logAnalyticsWorkspaceId")


class DataAzurermKubernetesClusterAgentPoolProfile(
    cdktf.ComplexComputedList,
    metaclass=jsii.JSIIMeta,
    jsii_type="@cdktf/provider-azurerm.DataAzurermKubernetesClusterAgentPoolProfile",
):
    def __init__(
        self,
        terraform_resource: cdktf.ITerraformResource,
        terraform_attribute: builtins.str,
        index: builtins.str,
    ) -> None:
        """
        :param terraform_resource: -
        :param terraform_attribute: -
        :param index: -

        :stability: experimental
        """
        jsii.create(DataAzurermKubernetesClusterAgentPoolProfile, self, [terraform_resource, terraform_attribute, index])

    @builtins.property # type: ignore
    @jsii.member(jsii_name="availabilityZones")
    def availability_zones(self) -> typing.List[builtins.str]:
        return jsii.get(self, "availabilityZones")

    @builtins.property # type: ignore
    @jsii.member(jsii_name="count")
    def count(self) -> jsii.Number:
        return jsii.get(self, "count")

    @builtins.property # type: ignore
    @jsii.member(jsii_name="enableAutoScaling")
    def enable_auto_scaling(self) -> builtins.bool:
        return jsii.get(self, "enableAutoScaling")

    @builtins.property # type: ignore
    @jsii.member(jsii_name="enableNodePublicIp")
    def enable_node_public_ip(self) -> builtins.bool:
        return jsii.get(self, "enableNodePublicIp")

    @builtins.property # type: ignore
    @jsii.member(jsii_name="maxCount")
    def max_count(self) -> jsii.Number:
        return jsii.get(self, "maxCount")

    @builtins.property # type: ignore
    @jsii.member(jsii_name="maxPods")
    def max_pods(self) -> jsii.Number:
        return jsii.get(self, "maxPods")

    @builtins.property # type: ignore
    @jsii.member(jsii_name="minCount")
    def min_count(self) -> jsii.Number:
        return jsii.get(self, "minCount")

    @builtins.property # type: ignore
    @jsii.member(jsii_name="name")
    def name(self) -> builtins.str:
        return jsii.get(self, "name")

    @builtins.property # type: ignore
    @jsii.member(jsii_name="nodeTaints")
    def node_taints(self) -> typing.List[builtins.str]:
        return jsii.get(self, "nodeTaints")

    @builtins.property # type: ignore
    @jsii.member(jsii_name="osDiskSizeGb")
    def os_disk_size_gb(self) -> jsii.Number:
        return jsii.get(self, "osDiskSizeGb")

    @builtins.property # type: ignore
    @jsii.member(jsii_name="osType")
    def os_type(self) -> builtins.str:
        return jsii.get(self, "osType")

    @builtins.property # type: ignore
    @jsii.member(jsii_name="type")
    def type(self) -> builtins.str:
        return jsii.get(self, "type")

    @builtins.property # type: ignore
    @jsii.member(jsii_name="vmSize")
    def vm_size(self) -> builtins.str:
        return jsii.get(self, "vmSize")

    @builtins.property # type: ignore
    @jsii.member(jsii_name="vnetSubnetId")
    def vnet_subnet_id(self) -> builtins.str:
        return jsii.get(self, "vnetSubnetId")


@jsii.data_type(
    jsii_type="@cdktf/provider-azurerm.DataAzurermKubernetesClusterConfig",
    jsii_struct_bases=[cdktf.TerraformMetaArguments],
    name_mapping={
        "count": "count",
        "depends_on": "dependsOn",
        "lifecycle": "lifecycle",
        "provider": "provider",
        "name": "name",
        "resource_group_name": "resourceGroupName",
        "timeouts": "timeouts",
    },
)
class DataAzurermKubernetesClusterConfig(cdktf.TerraformMetaArguments):
    def __init__(
        self,
        *,
        count: typing.Optional[jsii.Number] = None,
        depends_on: typing.Optional[typing.List[cdktf.TerraformResource]] = None,
        lifecycle: typing.Optional[cdktf.TerraformResourceLifecycle] = None,
        provider: typing.Optional[cdktf.TerraformProvider] = None,
        name: builtins.str,
        resource_group_name: builtins.str,
        timeouts: typing.Optional["DataAzurermKubernetesClusterTimeouts"] = None,
    ) -> None:
        """
        :param count: 
        :param depends_on: 
        :param lifecycle: 
        :param provider: 
        :param name: 
        :param resource_group_name: 
        :param timeouts: timeouts block.
        """
        if isinstance(lifecycle, dict):
            lifecycle = cdktf.TerraformResourceLifecycle(**lifecycle)
        if isinstance(timeouts, dict):
            timeouts = DataAzurermKubernetesClusterTimeouts(**timeouts)
        self._values: typing.Dict[str, typing.Any] = {
            "name": name,
            "resource_group_name": resource_group_name,
        }
        if count is not None:
            self._values["count"] = count
        if depends_on is not None:
            self._values["depends_on"] = depends_on
        if lifecycle is not None:
            self._values["lifecycle"] = lifecycle
        if provider is not None:
            self._values["provider"] = provider
        if timeouts is not None:
            self._values["timeouts"] = timeouts

    @builtins.property
    def count(self) -> typing.Optional[jsii.Number]:
        """
        :stability: experimental
        """
        result = self._values.get("count")
        return result

    @builtins.property
    def depends_on(self) -> typing.Optional[typing.List[cdktf.TerraformResource]]:
        """
        :stability: experimental
        """
        result = self._values.get("depends_on")
        return result

    @builtins.property
    def lifecycle(self) -> typing.Optional[cdktf.TerraformResourceLifecycle]:
        """
        :stability: experimental
        """
        result = self._values.get("lifecycle")
        return result

    @builtins.property
    def provider(self) -> typing.Optional[cdktf.TerraformProvider]:
        """
        :stability: experimental
        """
        result = self._values.get("provider")
        return result

    @builtins.property
    def name(self) -> builtins.str:
        result = self._values.get("name")
        assert result is not None, "Required property 'name' is missing"
        return result

    @builtins.property
    def resource_group_name(self) -> builtins.str:
        result = self._values.get("resource_group_name")
        assert result is not None, "Required property 'resource_group_name' is missing"
        return result

    @builtins.property
    def timeouts(self) -> typing.Optional["DataAzurermKubernetesClusterTimeouts"]:
        """timeouts block."""
        result = self._values.get("timeouts")
        return result

    def __eq__(self, rhs: typing.Any) -> builtins.bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs: typing.Any) -> builtins.bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return "DataAzurermKubernetesClusterConfig(%s)" % ", ".join(
            k + "=" + repr(v) for k, v in self._values.items()
        )


class DataAzurermKubernetesClusterKubeAdminConfig(
    cdktf.ComplexComputedList,
    metaclass=jsii.JSIIMeta,
    jsii_type="@cdktf/provider-azurerm.DataAzurermKubernetesClusterKubeAdminConfig",
):
    def __init__(
        self,
        terraform_resource: cdktf.ITerraformResource,
        terraform_attribute: builtins.str,
        index: builtins.str,
    ) -> None:
        """
        :param terraform_resource: -
        :param terraform_attribute: -
        :param index: -

        :stability: experimental
        """
        jsii.create(DataAzurermKubernetesClusterKubeAdminConfig, self, [terraform_resource, terraform_attribute, index])

    @builtins.property # type: ignore
    @jsii.member(jsii_name="clientCertificate")
    def client_certificate(self) -> builtins.str:
        return jsii.get(self, "clientCertificate")

    @builtins.property # type: ignore
    @jsii.member(jsii_name="clientKey")
    def client_key(self) -> builtins.str:
        return jsii.get(self, "clientKey")

    @builtins.property # type: ignore
    @jsii.member(jsii_name="clusterCaCertificate")
    def cluster_ca_certificate(self) -> builtins.str:
        return jsii.get(self, "clusterCaCertificate")

    @builtins.property # type: ignore
    @jsii.member(jsii_name="host")
    def host(self) -> builtins.str:
        return jsii.get(self, "host")

    @builtins.property # type: ignore
    @jsii.member(jsii_name="password")
    def password(self) -> builtins.str:
        return jsii.get(self, "password")

    @builtins.property # type: ignore
    @jsii.member(jsii_name="username")
    def username(self) -> builtins.str:
        return jsii.get(self, "username")


class DataAzurermKubernetesClusterKubeConfig(
    cdktf.ComplexComputedList,
    metaclass=jsii.JSIIMeta,
    jsii_type="@cdktf/provider-azurerm.DataAzurermKubernetesClusterKubeConfig",
):
    def __init__(
        self,
        terraform_resource: cdktf.ITerraformResource,
        terraform_attribute: builtins.str,
        index: builtins.str,
    ) -> None:
        """
        :param terraform_resource: -
        :param terraform_attribute: -
        :param index: -

        :stability: experimental
        """
        jsii.create(DataAzurermKubernetesClusterKubeConfig, self, [terraform_resource, terraform_attribute, index])

    @builtins.property # type: ignore
    @jsii.member(jsii_name="clientCertificate")
    def client_certificate(self) -> builtins.str:
        return jsii.get(self, "clientCertificate")

    @builtins.property # type: ignore
    @jsii.member(jsii_name="clientKey")
    def client_key(self) -> builtins.str:
        return jsii.get(self, "clientKey")

    @builtins.property # type: ignore
    @jsii.member(jsii_name="clusterCaCertificate")
    def cluster_ca_certificate(self) -> builtins.str:
        return jsii.get(self, "clusterCaCertificate")

    @builtins.property # type: ignore
    @jsii.member(jsii_name="host")
    def host(self) -> builtins.str:
        return jsii.get(self, "host")

    @builtins.property # type: ignore
    @jsii.member(jsii_name="password")
    def password(self) -> builtins.str:
        return jsii.get(self, "password")

    @builtins.property # type: ignore
    @jsii.member(jsii_name="username")
    def username(self) -> builtins.str:
        return jsii.get(self, "username")


class DataAzurermKubernetesClusterLinuxProfile(
    cdktf.ComplexComputedList,
    metaclass=jsii.JSIIMeta,
    jsii_type="@cdktf/provider-azurerm.DataAzurermKubernetesClusterLinuxProfile",
):
    def __init__(
        self,
        terraform_resource: cdktf.ITerraformResource,
        terraform_attribute: builtins.str,
        index: builtins.str,
    ) -> None:
        """
        :param terraform_resource: -
        :param terraform_attribute: -
        :param index: -

        :stability: experimental
        """
        jsii.create(DataAzurermKubernetesClusterLinuxProfile, self, [terraform_resource, terraform_attribute, index])

    @builtins.property # type: ignore
    @jsii.member(jsii_name="adminUsername")
    def admin_username(self) -> builtins.str:
        return jsii.get(self, "adminUsername")

    @builtins.property # type: ignore
    @jsii.member(jsii_name="sshKey")
    def ssh_key(self) -> typing.Any:
        return jsii.get(self, "sshKey")


class DataAzurermKubernetesClusterLinuxProfileSshKey(
    cdktf.ComplexComputedList,
    metaclass=jsii.JSIIMeta,
    jsii_type="@cdktf/provider-azurerm.DataAzurermKubernetesClusterLinuxProfileSshKey",
):
    def __init__(
        self,
        terraform_resource: cdktf.ITerraformResource,
        terraform_attribute: builtins.str,
        index: builtins.str,
    ) -> None:
        """
        :param terraform_resource: -
        :param terraform_attribute: -
        :param index: -

        :stability: experimental
        """
        jsii.create(DataAzurermKubernetesClusterLinuxProfileSshKey, self, [terraform_resource, terraform_attribute, index])

    @builtins.property # type: ignore
    @jsii.member(jsii_name="keyData")
    def key_data(self) -> builtins.str:
        return jsii.get(self, "keyData")


class DataAzurermKubernetesClusterNetworkProfile(
    cdktf.ComplexComputedList,
    metaclass=jsii.JSIIMeta,
    jsii_type="@cdktf/provider-azurerm.DataAzurermKubernetesClusterNetworkProfile",
):
    def __init__(
        self,
        terraform_resource: cdktf.ITerraformResource,
        terraform_attribute: builtins.str,
        index: builtins.str,
    ) -> None:
        """
        :param terraform_resource: -
        :param terraform_attribute: -
        :param index: -

        :stability: experimental
        """
        jsii.create(DataAzurermKubernetesClusterNetworkProfile, self, [terraform_resource, terraform_attribute, index])

    @builtins.property # type: ignore
    @jsii.member(jsii_name="dnsServiceIp")
    def dns_service_ip(self) -> builtins.str:
        return jsii.get(self, "dnsServiceIp")

    @builtins.property # type: ignore
    @jsii.member(jsii_name="dockerBridgeCidr")
    def docker_bridge_cidr(self) -> builtins.str:
        return jsii.get(self, "dockerBridgeCidr")

    @builtins.property # type: ignore
    @jsii.member(jsii_name="loadBalancerSku")
    def load_balancer_sku(self) -> builtins.str:
        return jsii.get(self, "loadBalancerSku")

    @builtins.property # type: ignore
    @jsii.member(jsii_name="networkPlugin")
    def network_plugin(self) -> builtins.str:
        return jsii.get(self, "networkPlugin")

    @builtins.property # type: ignore
    @jsii.member(jsii_name="networkPolicy")
    def network_policy(self) -> builtins.str:
        return jsii.get(self, "networkPolicy")

    @builtins.property # type: ignore
    @jsii.member(jsii_name="podCidr")
    def pod_cidr(self) -> builtins.str:
        return jsii.get(self, "podCidr")

    @builtins.property # type: ignore
    @jsii.member(jsii_name="serviceCidr")
    def service_cidr(self) -> builtins.str:
        return jsii.get(self, "serviceCidr")


class DataAzurermKubernetesClusterRoleBasedAccessControl(
    cdktf.ComplexComputedList,
    metaclass=jsii.JSIIMeta,
    jsii_type="@cdktf/provider-azurerm.DataAzurermKubernetesClusterRoleBasedAccessControl",
):
    def __init__(
        self,
        terraform_resource: cdktf.ITerraformResource,
        terraform_attribute: builtins.str,
        index: builtins.str,
    ) -> None:
        """
        :param terraform_resource: -
        :param terraform_attribute: -
        :param index: -

        :stability: experimental
        """
        jsii.create(DataAzurermKubernetesClusterRoleBasedAccessControl, self, [terraform_resource, terraform_attribute, index])

    @builtins.property # type: ignore
    @jsii.member(jsii_name="azureActiveDirectory")
    def azure_active_directory(self) -> typing.Any:
        return jsii.get(self, "azureActiveDirectory")

    @builtins.property # type: ignore
    @jsii.member(jsii_name="enabled")
    def enabled(self) -> builtins.bool:
        return jsii.get(self, "enabled")


class DataAzurermKubernetesClusterRoleBasedAccessControlAzureActiveDirectory(
    cdktf.ComplexComputedList,
    metaclass=jsii.JSIIMeta,
    jsii_type="@cdktf/provider-azurerm.DataAzurermKubernetesClusterRoleBasedAccessControlAzureActiveDirectory",
):
    def __init__(
        self,
        terraform_resource: cdktf.ITerraformResource,
        terraform_attribute: builtins.str,
        index: builtins.str,
    ) -> None:
        """
        :param terraform_resource: -
        :param terraform_attribute: -
        :param index: -

        :stability: experimental
        """
        jsii.create(DataAzurermKubernetesClusterRoleBasedAccessControlAzureActiveDirectory, self, [terraform_resource, terraform_attribute, index])

    @builtins.property # type: ignore
    @jsii.member(jsii_name="clientAppId")
    def client_app_id(self) -> builtins.str:
        return jsii.get(self, "clientAppId")

    @builtins.property # type: ignore
    @jsii.member(jsii_name="serverAppId")
    def server_app_id(self) -> builtins.str:
        return jsii.get(self, "serverAppId")

    @builtins.property # type: ignore
    @jsii.member(jsii_name="tenantId")
    def tenant_id(self) -> builtins.str:
        return jsii.get(self, "tenantId")


class DataAzurermKubernetesClusterServicePrincipal(
    cdktf.ComplexComputedList,
    metaclass=jsii.JSIIMeta,
    jsii_type="@cdktf/provider-azurerm.DataAzurermKubernetesClusterServicePrincipal",
):
    def __init__(
        self,
        terraform_resource: cdktf.ITerraformResource,
        terraform_attribute: builtins.str,
        index: builtins.str,
    ) -> None:
        """
        :param terraform_resource: -
        :param terraform_attribute: -
        :param index: -

        :stability: experimental
        """
        jsii.create(DataAzurermKubernetesClusterServicePrincipal, self, [terraform_resource, terraform_attribute, index])

    @builtins.property # type: ignore
    @jsii.member(jsii_name="clientId")
    def client_id(self) -> builtins.str:
        return jsii.get(self, "clientId")


@jsii.data_type(
    jsii_type="@cdktf/provider-azurerm.DataAzurermKubernetesClusterTimeouts",
    jsii_struct_bases=[],
    name_mapping={"read": "read"},
)
class DataAzurermKubernetesClusterTimeouts:
    def __init__(self, *, read: typing.Optional[builtins.str] = None) -> None:
        """
        :param read: 
        """
        self._values: typing.Dict[str, typing.Any] = {}
        if read is not None:
            self._values["read"] = read

    @builtins.property
    def read(self) -> typing.Optional[builtins.str]:
        result = self._values.get("read")
        return result

    def __eq__(self, rhs: typing.Any) -> builtins.bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs: typing.Any) -> builtins.bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return "DataAzurermKubernetesClusterTimeouts(%s)" % ", ".join(
            k + "=" + repr(v) for k, v in self._values.items()
        )


class DataAzurermKubernetesClusterWindowsProfile(
    cdktf.ComplexComputedList,
    metaclass=jsii.JSIIMeta,
    jsii_type="@cdktf/provider-azurerm.DataAzurermKubernetesClusterWindowsProfile",
):
    def __init__(
        self,
        terraform_resource: cdktf.ITerraformResource,
        terraform_attribute: builtins.str,
        index: builtins.str,
    ) -> None:
        """
        :param terraform_resource: -
        :param terraform_attribute: -
        :param index: -

        :stability: experimental
        """
        jsii.create(DataAzurermKubernetesClusterWindowsProfile, self, [terraform_resource, terraform_attribute, index])

    @builtins.property # type: ignore
    @jsii.member(jsii_name="adminUsername")
    def admin_username(self) -> builtins.str:
        return jsii.get(self, "adminUsername")


class DataAzurermKubernetesServiceVersions(
    cdktf.TerraformDataSource,
    metaclass=jsii.JSIIMeta,
    jsii_type="@cdktf/provider-azurerm.DataAzurermKubernetesServiceVersions",
):
    def __init__(
        self,
        scope: constructs.Construct,
        id: builtins.str,
        *,
        location: builtins.str,
        include_preview: typing.Optional[builtins.bool] = None,
        timeouts: typing.Optional["DataAzurermKubernetesServiceVersionsTimeouts"] = None,
        version_prefix: typing.Optional[builtins.str] = None,
        count: typing.Optional[jsii.Number] = None,
        depends_on: typing.Optional[typing.List[cdktf.TerraformResource]] = None,
        lifecycle: typing.Optional[cdktf.TerraformResourceLifecycle] = None,
        provider: typing.Optional[cdktf.TerraformProvider] = None,
    ) -> None:
        """
        :param scope: -
        :param id: -
        :param location: 
        :param include_preview: 
        :param timeouts: timeouts block.
        :param version_prefix: 
        :param count: 
        :param depends_on: 
        :param lifecycle: 
        :param provider: 
        """
        config = DataAzurermKubernetesServiceVersionsConfig(
            location=location,
            include_preview=include_preview,
            timeouts=timeouts,
            version_prefix=version_prefix,
            count=count,
            depends_on=depends_on,
            lifecycle=lifecycle,
            provider=provider,
        )

        jsii.create(DataAzurermKubernetesServiceVersions, self, [scope, id, config])

    @jsii.member(jsii_name="synthesizeAttributes")
    def _synthesize_attributes(self) -> typing.Mapping[builtins.str, typing.Any]:
        return jsii.invoke(self, "synthesizeAttributes", [])

    @builtins.property # type: ignore
    @jsii.member(jsii_name="latestVersion")
    def latest_version(self) -> builtins.str:
        return jsii.get(self, "latestVersion")

    @builtins.property # type: ignore
    @jsii.member(jsii_name="versions")
    def versions(self) -> typing.List[builtins.str]:
        return jsii.get(self, "versions")

    @builtins.property # type: ignore
    @jsii.member(jsii_name="location")
    def location(self) -> builtins.str:
        return jsii.get(self, "location")

    @location.setter # type: ignore
    def location(self, value: builtins.str) -> None:
        jsii.set(self, "location", value)

    @builtins.property # type: ignore
    @jsii.member(jsii_name="id")
    def id(self) -> typing.Optional[builtins.str]:
        return jsii.get(self, "id")

    @id.setter # type: ignore
    def id(self, value: typing.Optional[builtins.str]) -> None:
        jsii.set(self, "id", value)

    @builtins.property # type: ignore
    @jsii.member(jsii_name="includePreview")
    def include_preview(self) -> typing.Optional[builtins.bool]:
        return jsii.get(self, "includePreview")

    @include_preview.setter # type: ignore
    def include_preview(self, value: typing.Optional[builtins.bool]) -> None:
        jsii.set(self, "includePreview", value)

    @builtins.property # type: ignore
    @jsii.member(jsii_name="timeouts")
    def timeouts(
        self,
    ) -> typing.Optional["DataAzurermKubernetesServiceVersionsTimeouts"]:
        return jsii.get(self, "timeouts")

    @timeouts.setter # type: ignore
    def timeouts(
        self,
        value: typing.Optional["DataAzurermKubernetesServiceVersionsTimeouts"],
    ) -> None:
        jsii.set(self, "timeouts", value)

    @builtins.property # type: ignore
    @jsii.member(jsii_name="versionPrefix")
    def version_prefix(self) -> typing.Optional[builtins.str]:
        return jsii.get(self, "versionPrefix")

    @version_prefix.setter # type: ignore
    def version_prefix(self, value: typing.Optional[builtins.str]) -> None:
        jsii.set(self, "versionPrefix", value)


@jsii.data_type(
    jsii_type="@cdktf/provider-azurerm.DataAzurermKubernetesServiceVersionsConfig",
    jsii_struct_bases=[cdktf.TerraformMetaArguments],
    name_mapping={
        "count": "count",
        "depends_on": "dependsOn",
        "lifecycle": "lifecycle",
        "provider": "provider",
        "location": "location",
        "include_preview": "includePreview",
        "timeouts": "timeouts",
        "version_prefix": "versionPrefix",
    },
)
class DataAzurermKubernetesServiceVersionsConfig(cdktf.TerraformMetaArguments):
    def __init__(
        self,
        *,
        count: typing.Optional[jsii.Number] = None,
        depends_on: typing.Optional[typing.List[cdktf.TerraformResource]] = None,
        lifecycle: typing.Optional[cdktf.TerraformResourceLifecycle] = None,
        provider: typing.Optional[cdktf.TerraformProvider] = None,
        location: builtins.str,
        include_preview: typing.Optional[builtins.bool] = None,
        timeouts: typing.Optional["DataAzurermKubernetesServiceVersionsTimeouts"] = None,
        version_prefix: typing.Optional[builtins.str] = None,
    ) -> None:
        """
        :param count: 
        :param depends_on: 
        :param lifecycle: 
        :param provider: 
        :param location: 
        :param include_preview: 
        :param timeouts: timeouts block.
        :param version_prefix: 
        """
        if isinstance(lifecycle, dict):
            lifecycle = cdktf.TerraformResourceLifecycle(**lifecycle)
        if isinstance(timeouts, dict):
            timeouts = DataAzurermKubernetesServiceVersionsTimeouts(**timeouts)
        self._values: typing.Dict[str, typing.Any] = {
            "location": location,
        }
        if count is not None:
            self._values["count"] = count
        if depends_on is not None:
            self._values["depends_on"] = depends_on
        if lifecycle is not None:
            self._values["lifecycle"] = lifecycle
        if provider is not None:
            self._values["provider"] = provider
        if include_preview is not None:
            self._values["include_preview"] = include_preview
        if timeouts is not None:
            self._values["timeouts"] = timeouts
        if version_prefix is not None:
            self._values["version_prefix"] = version_prefix

    @builtins.property
    def count(self) -> typing.Optional[jsii.Number]:
        """
        :stability: experimental
        """
        result = self._values.get("count")
        return result

    @builtins.property
    def depends_on(self) -> typing.Optional[typing.List[cdktf.TerraformResource]]:
        """
        :stability: experimental
        """
        result = self._values.get("depends_on")
        return result

    @builtins.property
    def lifecycle(self) -> typing.Optional[cdktf.TerraformResourceLifecycle]:
        """
        :stability: experimental
        """
        result = self._values.get("lifecycle")
        return result

    @builtins.property
    def provider(self) -> typing.Optional[cdktf.TerraformProvider]:
        """
        :stability: experimental
        """
        result = self._values.get("provider")
        return result

    @builtins.property
    def location(self) -> builtins.str:
        result = self._values.get("location")
        assert result is not None, "Required property 'location' is missing"
        return result

    @builtins.property
    def include_preview(self) -> typing.Optional[builtins.bool]:
        result = self._values.get("include_preview")
        return result

    @builtins.property
    def timeouts(
        self,
    ) -> typing.Optional["DataAzurermKubernetesServiceVersionsTimeouts"]:
        """timeouts block."""
        result = self._values.get("timeouts")
        return result

    @builtins.property
    def version_prefix(self) -> typing.Optional[builtins.str]:
        result = self._values.get("version_prefix")
        return result

    def __eq__(self, rhs: typing.Any) -> builtins.bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs: typing.Any) -> builtins.bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return "DataAzurermKubernetesServiceVersionsConfig(%s)" % ", ".join(
            k + "=" + repr(v) for k, v in self._values.items()
        )


@jsii.data_type(
    jsii_type="@cdktf/provider-azurerm.DataAzurermKubernetesServiceVersionsTimeouts",
    jsii_struct_bases=[],
    name_mapping={"read": "read"},
)
class DataAzurermKubernetesServiceVersionsTimeouts:
    def __init__(self, *, read: typing.Optional[builtins.str] = None) -> None:
        """
        :param read: 
        """
        self._values: typing.Dict[str, typing.Any] = {}
        if read is not None:
            self._values["read"] = read

    @builtins.property
    def read(self) -> typing.Optional[builtins.str]:
        result = self._values.get("read")
        return result

    def __eq__(self, rhs: typing.Any) -> builtins.bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs: typing.Any) -> builtins.bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return "DataAzurermKubernetesServiceVersionsTimeouts(%s)" % ", ".join(
            k + "=" + repr(v) for k, v in self._values.items()
        )


class DataAzurermLb(
    cdktf.TerraformDataSource,
    metaclass=jsii.JSIIMeta,
    jsii_type="@cdktf/provider-azurerm.DataAzurermLb",
):
    def __init__(
        self,
        scope: constructs.Construct,
        id: builtins.str,
        *,
        name: builtins.str,
        resource_group_name: builtins.str,
        timeouts: typing.Optional["DataAzurermLbTimeouts"] = None,
        count: typing.Optional[jsii.Number] = None,
        depends_on: typing.Optional[typing.List[cdktf.TerraformResource]] = None,
        lifecycle: typing.Optional[cdktf.TerraformResourceLifecycle] = None,
        provider: typing.Optional[cdktf.TerraformProvider] = None,
    ) -> None:
        """
        :param scope: -
        :param id: -
        :param name: 
        :param resource_group_name: 
        :param timeouts: timeouts block.
        :param count: 
        :param depends_on: 
        :param lifecycle: 
        :param provider: 
        """
        config = DataAzurermLbConfig(
            name=name,
            resource_group_name=resource_group_name,
            timeouts=timeouts,
            count=count,
            depends_on=depends_on,
            lifecycle=lifecycle,
            provider=provider,
        )

        jsii.create(DataAzurermLb, self, [scope, id, config])

    @jsii.member(jsii_name="frontendIpConfiguration")
    def frontend_ip_configuration(
        self,
        index: builtins.str,
    ) -> "DataAzurermLbFrontendIpConfiguration":
        """
        :param index: -
        """
        return jsii.invoke(self, "frontendIpConfiguration", [index])

    @jsii.member(jsii_name="synthesizeAttributes")
    def _synthesize_attributes(self) -> typing.Mapping[builtins.str, typing.Any]:
        return jsii.invoke(self, "synthesizeAttributes", [])

    @jsii.member(jsii_name="tags")
    def tags(self, key: builtins.str) -> builtins.str:
        """
        :param key: -
        """
        return jsii.invoke(self, "tags", [key])

    @builtins.property # type: ignore
    @jsii.member(jsii_name="location")
    def location(self) -> builtins.str:
        return jsii.get(self, "location")

    @builtins.property # type: ignore
    @jsii.member(jsii_name="privateIpAddress")
    def private_ip_address(self) -> builtins.str:
        return jsii.get(self, "privateIpAddress")

    @builtins.property # type: ignore
    @jsii.member(jsii_name="privateIpAddresses")
    def private_ip_addresses(self) -> typing.List[builtins.str]:
        return jsii.get(self, "privateIpAddresses")

    @builtins.property # type: ignore
    @jsii.member(jsii_name="sku")
    def sku(self) -> builtins.str:
        return jsii.get(self, "sku")

    @builtins.property # type: ignore
    @jsii.member(jsii_name="name")
    def name(self) -> builtins.str:
        return jsii.get(self, "name")

    @name.setter # type: ignore
    def name(self, value: builtins.str) -> None:
        jsii.set(self, "name", value)

    @builtins.property # type: ignore
    @jsii.member(jsii_name="resourceGroupName")
    def resource_group_name(self) -> builtins.str:
        return jsii.get(self, "resourceGroupName")

    @resource_group_name.setter # type: ignore
    def resource_group_name(self, value: builtins.str) -> None:
        jsii.set(self, "resourceGroupName", value)

    @builtins.property # type: ignore
    @jsii.member(jsii_name="id")
    def id(self) -> typing.Optional[builtins.str]:
        return jsii.get(self, "id")

    @id.setter # type: ignore
    def id(self, value: typing.Optional[builtins.str]) -> None:
        jsii.set(self, "id", value)

    @builtins.property # type: ignore
    @jsii.member(jsii_name="timeouts")
    def timeouts(self) -> typing.Optional["DataAzurermLbTimeouts"]:
        return jsii.get(self, "timeouts")

    @timeouts.setter # type: ignore
    def timeouts(self, value: typing.Optional["DataAzurermLbTimeouts"]) -> None:
        jsii.set(self, "timeouts", value)


class DataAzurermLbBackendAddressPool(
    cdktf.TerraformDataSource,
    metaclass=jsii.JSIIMeta,
    jsii_type="@cdktf/provider-azurerm.DataAzurermLbBackendAddressPool",
):
    def __init__(
        self,
        scope: constructs.Construct,
        id: builtins.str,
        *,
        loadbalancer_id: builtins.str,
        name: builtins.str,
        timeouts: typing.Optional["DataAzurermLbBackendAddressPoolTimeouts"] = None,
        count: typing.Optional[jsii.Number] = None,
        depends_on: typing.Optional[typing.List[cdktf.TerraformResource]] = None,
        lifecycle: typing.Optional[cdktf.TerraformResourceLifecycle] = None,
        provider: typing.Optional[cdktf.TerraformProvider] = None,
    ) -> None:
        """
        :param scope: -
        :param id: -
        :param loadbalancer_id: 
        :param name: 
        :param timeouts: timeouts block.
        :param count: 
        :param depends_on: 
        :param lifecycle: 
        :param provider: 
        """
        config = DataAzurermLbBackendAddressPoolConfig(
            loadbalancer_id=loadbalancer_id,
            name=name,
            timeouts=timeouts,
            count=count,
            depends_on=depends_on,
            lifecycle=lifecycle,
            provider=provider,
        )

        jsii.create(DataAzurermLbBackendAddressPool, self, [scope, id, config])

    @jsii.member(jsii_name="backendIpConfigurations")
    def backend_ip_configurations(
        self,
        index: builtins.str,
    ) -> "DataAzurermLbBackendAddressPoolBackendIpConfigurations":
        """
        :param index: -
        """
        return jsii.invoke(self, "backendIpConfigurations", [index])

    @jsii.member(jsii_name="synthesizeAttributes")
    def _synthesize_attributes(self) -> typing.Mapping[builtins.str, typing.Any]:
        return jsii.invoke(self, "synthesizeAttributes", [])

    @builtins.property # type: ignore
    @jsii.member(jsii_name="loadbalancerId")
    def loadbalancer_id(self) -> builtins.str:
        return jsii.get(self, "loadbalancerId")

    @loadbalancer_id.setter # type: ignore
    def loadbalancer_id(self, value: builtins.str) -> None:
        jsii.set(self, "loadbalancerId", value)

    @builtins.property # type: ignore
    @jsii.member(jsii_name="name")
    def name(self) -> builtins.str:
        return jsii.get(self, "name")

    @name.setter # type: ignore
    def name(self, value: builtins.str) -> None:
        jsii.set(self, "name", value)

    @builtins.property # type: ignore
    @jsii.member(jsii_name="id")
    def id(self) -> typing.Optional[builtins.str]:
        return jsii.get(self, "id")

    @id.setter # type: ignore
    def id(self, value: typing.Optional[builtins.str]) -> None:
        jsii.set(self, "id", value)

    @builtins.property # type: ignore
    @jsii.member(jsii_name="timeouts")
    def timeouts(self) -> typing.Optional["DataAzurermLbBackendAddressPoolTimeouts"]:
        return jsii.get(self, "timeouts")

    @timeouts.setter # type: ignore
    def timeouts(
        self,
        value: typing.Optional["DataAzurermLbBackendAddressPoolTimeouts"],
    ) -> None:
        jsii.set(self, "timeouts", value)


class DataAzurermLbBackendAddressPoolBackendIpConfigurations(
    cdktf.ComplexComputedList,
    metaclass=jsii.JSIIMeta,
    jsii_type="@cdktf/provider-azurerm.DataAzurermLbBackendAddressPoolBackendIpConfigurations",
):
    def __init__(
        self,
        terraform_resource: cdktf.ITerraformResource,
        terraform_attribute: builtins.str,
        index: builtins.str,
    ) -> None:
        """
        :param terraform_resource: -
        :param terraform_attribute: -
        :param index: -

        :stability: experimental
        """
        jsii.create(DataAzurermLbBackendAddressPoolBackendIpConfigurations, self, [terraform_resource, terraform_attribute, index])

    @builtins.property # type: ignore
    @jsii.member(jsii_name="id")
    def id(self) -> builtins.str:
        return jsii.get(self, "id")


@jsii.data_type(
    jsii_type="@cdktf/provider-azurerm.DataAzurermLbBackendAddressPoolConfig",
    jsii_struct_bases=[cdktf.TerraformMetaArguments],
    name_mapping={
        "count": "count",
        "depends_on": "dependsOn",
        "lifecycle": "lifecycle",
        "provider": "provider",
        "loadbalancer_id": "loadbalancerId",
        "name": "name",
        "timeouts": "timeouts",
    },
)
class DataAzurermLbBackendAddressPoolConfig(cdktf.TerraformMetaArguments):
    def __init__(
        self,
        *,
        count: typing.Optional[jsii.Number] = None,
        depends_on: typing.Optional[typing.List[cdktf.TerraformResource]] = None,
        lifecycle: typing.Optional[cdktf.TerraformResourceLifecycle] = None,
        provider: typing.Optional[cdktf.TerraformProvider] = None,
        loadbalancer_id: builtins.str,
        name: builtins.str,
        timeouts: typing.Optional["DataAzurermLbBackendAddressPoolTimeouts"] = None,
    ) -> None:
        """
        :param count: 
        :param depends_on: 
        :param lifecycle: 
        :param provider: 
        :param loadbalancer_id: 
        :param name: 
        :param timeouts: timeouts block.
        """
        if isinstance(lifecycle, dict):
            lifecycle = cdktf.TerraformResourceLifecycle(**lifecycle)
        if isinstance(timeouts, dict):
            timeouts = DataAzurermLbBackendAddressPoolTimeouts(**timeouts)
        self._values: typing.Dict[str, typing.Any] = {
            "loadbalancer_id": loadbalancer_id,
            "name": name,
        }
        if count is not None:
            self._values["count"] = count
        if depends_on is not None:
            self._values["depends_on"] = depends_on
        if lifecycle is not None:
            self._values["lifecycle"] = lifecycle
        if provider is not None:
            self._values["provider"] = provider
        if timeouts is not None:
            self._values["timeouts"] = timeouts

    @builtins.property
    def count(self) -> typing.Optional[jsii.Number]:
        """
        :stability: experimental
        """
        result = self._values.get("count")
        return result

    @builtins.property
    def depends_on(self) -> typing.Optional[typing.List[cdktf.TerraformResource]]:
        """
        :stability: experimental
        """
        result = self._values.get("depends_on")
        return result

    @builtins.property
    def lifecycle(self) -> typing.Optional[cdktf.TerraformResourceLifecycle]:
        """
        :stability: experimental
        """
        result = self._values.get("lifecycle")
        return result

    @builtins.property
    def provider(self) -> typing.Optional[cdktf.TerraformProvider]:
        """
        :stability: experimental
        """
        result = self._values.get("provider")
        return result

    @builtins.property
    def loadbalancer_id(self) -> builtins.str:
        result = self._values.get("loadbalancer_id")
        assert result is not None, "Required property 'loadbalancer_id' is missing"
        return result

    @builtins.property
    def name(self) -> builtins.str:
        result = self._values.get("name")
        assert result is not None, "Required property 'name' is missing"
        return result

    @builtins.property
    def timeouts(self) -> typing.Optional["DataAzurermLbBackendAddressPoolTimeouts"]:
        """timeouts block."""
        result = self._values.get("timeouts")
        return result

    def __eq__(self, rhs: typing.Any) -> builtins.bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs: typing.Any) -> builtins.bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return "DataAzurermLbBackendAddressPoolConfig(%s)" % ", ".join(
            k + "=" + repr(v) for k, v in self._values.items()
        )


@jsii.data_type(
    jsii_type="@cdktf/provider-azurerm.DataAzurermLbBackendAddressPoolTimeouts",
    jsii_struct_bases=[],
    name_mapping={"read": "read"},
)
class DataAzurermLbBackendAddressPoolTimeouts:
    def __init__(self, *, read: typing.Optional[builtins.str] = None) -> None:
        """
        :param read: 
        """
        self._values: typing.Dict[str, typing.Any] = {}
        if read is not None:
            self._values["read"] = read

    @builtins.property
    def read(self) -> typing.Optional[builtins.str]:
        result = self._values.get("read")
        return result

    def __eq__(self, rhs: typing.Any) -> builtins.bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs: typing.Any) -> builtins.bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return "DataAzurermLbBackendAddressPoolTimeouts(%s)" % ", ".join(
            k + "=" + repr(v) for k, v in self._values.items()
        )


@jsii.data_type(
    jsii_type="@cdktf/provider-azurerm.DataAzurermLbConfig",
    jsii_struct_bases=[cdktf.TerraformMetaArguments],
    name_mapping={
        "count": "count",
        "depends_on": "dependsOn",
        "lifecycle": "lifecycle",
        "provider": "provider",
        "name": "name",
        "resource_group_name": "resourceGroupName",
        "timeouts": "timeouts",
    },
)
class DataAzurermLbConfig(cdktf.TerraformMetaArguments):
    def __init__(
        self,
        *,
        count: typing.Optional[jsii.Number] = None,
        depends_on: typing.Optional[typing.List[cdktf.TerraformResource]] = None,
        lifecycle: typing.Optional[cdktf.TerraformResourceLifecycle] = None,
        provider: typing.Optional[cdktf.TerraformProvider] = None,
        name: builtins.str,
        resource_group_name: builtins.str,
        timeouts: typing.Optional["DataAzurermLbTimeouts"] = None,
    ) -> None:
        """
        :param count: 
        :param depends_on: 
        :param lifecycle: 
        :param provider: 
        :param name: 
        :param resource_group_name: 
        :param timeouts: timeouts block.
        """
        if isinstance(lifecycle, dict):
            lifecycle = cdktf.TerraformResourceLifecycle(**lifecycle)
        if isinstance(timeouts, dict):
            timeouts = DataAzurermLbTimeouts(**timeouts)
        self._values: typing.Dict[str, typing.Any] = {
            "name": name,
            "resource_group_name": resource_group_name,
        }
        if count is not None:
            self._values["count"] = count
        if depends_on is not None:
            self._values["depends_on"] = depends_on
        if lifecycle is not None:
            self._values["lifecycle"] = lifecycle
        if provider is not None:
            self._values["provider"] = provider
        if timeouts is not None:
            self._values["timeouts"] = timeouts

    @builtins.property
    def count(self) -> typing.Optional[jsii.Number]:
        """
        :stability: experimental
        """
        result = self._values.get("count")
        return result

    @builtins.property
    def depends_on(self) -> typing.Optional[typing.List[cdktf.TerraformResource]]:
        """
        :stability: experimental
        """
        result = self._values.get("depends_on")
        return result

    @builtins.property
    def lifecycle(self) -> typing.Optional[cdktf.TerraformResourceLifecycle]:
        """
        :stability: experimental
        """
        result = self._values.get("lifecycle")
        return result

    @builtins.property
    def provider(self) -> typing.Optional[cdktf.TerraformProvider]:
        """
        :stability: experimental
        """
        result = self._values.get("provider")
        return result

    @builtins.property
    def name(self) -> builtins.str:
        result = self._values.get("name")
        assert result is not None, "Required property 'name' is missing"
        return result

    @builtins.property
    def resource_group_name(self) -> builtins.str:
        result = self._values.get("resource_group_name")
        assert result is not None, "Required property 'resource_group_name' is missing"
        return result

    @builtins.property
    def timeouts(self) -> typing.Optional["DataAzurermLbTimeouts"]:
        """timeouts block."""
        result = self._values.get("timeouts")
        return result

    def __eq__(self, rhs: typing.Any) -> builtins.bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs: typing.Any) -> builtins.bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return "DataAzurermLbConfig(%s)" % ", ".join(
            k + "=" + repr(v) for k, v in self._values.items()
        )


class DataAzurermLbFrontendIpConfiguration(
    cdktf.ComplexComputedList,
    metaclass=jsii.JSIIMeta,
    jsii_type="@cdktf/provider-azurerm.DataAzurermLbFrontendIpConfiguration",
):
    def __init__(
        self,
        terraform_resource: cdktf.ITerraformResource,
        terraform_attribute: builtins.str,
        index: builtins.str,
    ) -> None:
        """
        :param terraform_resource: -
        :param terraform_attribute: -
        :param index: -

        :stability: experimental
        """
        jsii.create(DataAzurermLbFrontendIpConfiguration, self, [terraform_resource, terraform_attribute, index])

    @builtins.property # type: ignore
    @jsii.member(jsii_name="id")
    def id(self) -> builtins.str:
        return jsii.get(self, "id")

    @builtins.property # type: ignore
    @jsii.member(jsii_name="name")
    def name(self) -> builtins.str:
        return jsii.get(self, "name")

    @builtins.property # type: ignore
    @jsii.member(jsii_name="privateIpAddress")
    def private_ip_address(self) -> builtins.str:
        return jsii.get(self, "privateIpAddress")

    @builtins.property # type: ignore
    @jsii.member(jsii_name="privateIpAddressAllocation")
    def private_ip_address_allocation(self) -> builtins.str:
        return jsii.get(self, "privateIpAddressAllocation")

    @builtins.property # type: ignore
    @jsii.member(jsii_name="publicIpAddressId")
    def public_ip_address_id(self) -> builtins.str:
        return jsii.get(self, "publicIpAddressId")

    @builtins.property # type: ignore
    @jsii.member(jsii_name="subnetId")
    def subnet_id(self) -> builtins.str:
        return jsii.get(self, "subnetId")

    @builtins.property # type: ignore
    @jsii.member(jsii_name="zones")
    def zones(self) -> typing.List[builtins.str]:
        return jsii.get(self, "zones")


@jsii.data_type(
    jsii_type="@cdktf/provider-azurerm.DataAzurermLbTimeouts",
    jsii_struct_bases=[],
    name_mapping={"read": "read"},
)
class DataAzurermLbTimeouts:
    def __init__(self, *, read: typing.Optional[builtins.str] = None) -> None:
        """
        :param read: 
        """
        self._values: typing.Dict[str, typing.Any] = {}
        if read is not None:
            self._values["read"] = read

    @builtins.property
    def read(self) -> typing.Optional[builtins.str]:
        result = self._values.get("read")
        return result

    def __eq__(self, rhs: typing.Any) -> builtins.bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs: typing.Any) -> builtins.bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return "DataAzurermLbTimeouts(%s)" % ", ".join(
            k + "=" + repr(v) for k, v in self._values.items()
        )


class DataAzurermLogAnalyticsWorkspace(
    cdktf.TerraformDataSource,
    metaclass=jsii.JSIIMeta,
    jsii_type="@cdktf/provider-azurerm.DataAzurermLogAnalyticsWorkspace",
):
    def __init__(
        self,
        scope: constructs.Construct,
        id: builtins.str,
        *,
        name: builtins.str,
        resource_group_name: builtins.str,
        timeouts: typing.Optional["DataAzurermLogAnalyticsWorkspaceTimeouts"] = None,
        count: typing.Optional[jsii.Number] = None,
        depends_on: typing.Optional[typing.List[cdktf.TerraformResource]] = None,
        lifecycle: typing.Optional[cdktf.TerraformResourceLifecycle] = None,
        provider: typing.Optional[cdktf.TerraformProvider] = None,
    ) -> None:
        """
        :param scope: -
        :param id: -
        :param name: 
        :param resource_group_name: 
        :param timeouts: timeouts block.
        :param count: 
        :param depends_on: 
        :param lifecycle: 
        :param provider: 
        """
        config = DataAzurermLogAnalyticsWorkspaceConfig(
            name=name,
            resource_group_name=resource_group_name,
            timeouts=timeouts,
            count=count,
            depends_on=depends_on,
            lifecycle=lifecycle,
            provider=provider,
        )

        jsii.create(DataAzurermLogAnalyticsWorkspace, self, [scope, id, config])

    @jsii.member(jsii_name="synthesizeAttributes")
    def _synthesize_attributes(self) -> typing.Mapping[builtins.str, typing.Any]:
        return jsii.invoke(self, "synthesizeAttributes", [])

    @jsii.member(jsii_name="tags")
    def tags(self, key: builtins.str) -> builtins.str:
        """
        :param key: -
        """
        return jsii.invoke(self, "tags", [key])

    @builtins.property # type: ignore
    @jsii.member(jsii_name="location")
    def location(self) -> builtins.str:
        return jsii.get(self, "location")

    @builtins.property # type: ignore
    @jsii.member(jsii_name="portalUrl")
    def portal_url(self) -> builtins.str:
        return jsii.get(self, "portalUrl")

    @builtins.property # type: ignore
    @jsii.member(jsii_name="primarySharedKey")
    def primary_shared_key(self) -> builtins.str:
        return jsii.get(self, "primarySharedKey")

    @builtins.property # type: ignore
    @jsii.member(jsii_name="retentionInDays")
    def retention_in_days(self) -> jsii.Number:
        return jsii.get(self, "retentionInDays")

    @builtins.property # type: ignore
    @jsii.member(jsii_name="secondarySharedKey")
    def secondary_shared_key(self) -> builtins.str:
        return jsii.get(self, "secondarySharedKey")

    @builtins.property # type: ignore
    @jsii.member(jsii_name="sku")
    def sku(self) -> builtins.str:
        return jsii.get(self, "sku")

    @builtins.property # type: ignore
    @jsii.member(jsii_name="workspaceId")
    def workspace_id(self) -> builtins.str:
        return jsii.get(self, "workspaceId")

    @builtins.property # type: ignore
    @jsii.member(jsii_name="name")
    def name(self) -> builtins.str:
        return jsii.get(self, "name")

    @name.setter # type: ignore
    def name(self, value: builtins.str) -> None:
        jsii.set(self, "name", value)

    @builtins.property # type: ignore
    @jsii.member(jsii_name="resourceGroupName")
    def resource_group_name(self) -> builtins.str:
        return jsii.get(self, "resourceGroupName")

    @resource_group_name.setter # type: ignore
    def resource_group_name(self, value: builtins.str) -> None:
        jsii.set(self, "resourceGroupName", value)

    @builtins.property # type: ignore
    @jsii.member(jsii_name="id")
    def id(self) -> typing.Optional[builtins.str]:
        return jsii.get(self, "id")

    @id.setter # type: ignore
    def id(self, value: typing.Optional[builtins.str]) -> None:
        jsii.set(self, "id", value)

    @builtins.property # type: ignore
    @jsii.member(jsii_name="timeouts")
    def timeouts(self) -> typing.Optional["DataAzurermLogAnalyticsWorkspaceTimeouts"]:
        return jsii.get(self, "timeouts")

    @timeouts.setter # type: ignore
    def timeouts(
        self,
        value: typing.Optional["DataAzurermLogAnalyticsWorkspaceTimeouts"],
    ) -> None:
        jsii.set(self, "timeouts", value)


@jsii.data_type(
    jsii_type="@cdktf/provider-azurerm.DataAzurermLogAnalyticsWorkspaceConfig",
    jsii_struct_bases=[cdktf.TerraformMetaArguments],
    name_mapping={
        "count": "count",
        "depends_on": "dependsOn",
        "lifecycle": "lifecycle",
        "provider": "provider",
        "name": "name",
        "resource_group_name": "resourceGroupName",
        "timeouts": "timeouts",
    },
)
class DataAzurermLogAnalyticsWorkspaceConfig(cdktf.TerraformMetaArguments):
    def __init__(
        self,
        *,
        count: typing.Optional[jsii.Number] = None,
        depends_on: typing.Optional[typing.List[cdktf.TerraformResource]] = None,
        lifecycle: typing.Optional[cdktf.TerraformResourceLifecycle] = None,
        provider: typing.Optional[cdktf.TerraformProvider] = None,
        name: builtins.str,
        resource_group_name: builtins.str,
        timeouts: typing.Optional["DataAzurermLogAnalyticsWorkspaceTimeouts"] = None,
    ) -> None:
        """
        :param count: 
        :param depends_on: 
        :param lifecycle: 
        :param provider: 
        :param name: 
        :param resource_group_name: 
        :param timeouts: timeouts block.
        """
        if isinstance(lifecycle, dict):
            lifecycle = cdktf.TerraformResourceLifecycle(**lifecycle)
        if isinstance(timeouts, dict):
            timeouts = DataAzurermLogAnalyticsWorkspaceTimeouts(**timeouts)
        self._values: typing.Dict[str, typing.Any] = {
            "name": name,
            "resource_group_name": resource_group_name,
        }
        if count is not None:
            self._values["count"] = count
        if depends_on is not None:
            self._values["depends_on"] = depends_on
        if lifecycle is not None:
            self._values["lifecycle"] = lifecycle
        if provider is not None:
            self._values["provider"] = provider
        if timeouts is not None:
            self._values["timeouts"] = timeouts

    @builtins.property
    def count(self) -> typing.Optional[jsii.Number]:
        """
        :stability: experimental
        """
        result = self._values.get("count")
        return result

    @builtins.property
    def depends_on(self) -> typing.Optional[typing.List[cdktf.TerraformResource]]:
        """
        :stability: experimental
        """
        result = self._values.get("depends_on")
        return result

    @builtins.property
    def lifecycle(self) -> typing.Optional[cdktf.TerraformResourceLifecycle]:
        """
        :stability: experimental
        """
        result = self._values.get("lifecycle")
        return result

    @builtins.property
    def provider(self) -> typing.Optional[cdktf.TerraformProvider]:
        """
        :stability: experimental
        """
        result = self._values.get("provider")
        return result

    @builtins.property
    def name(self) -> builtins.str:
        result = self._values.get("name")
        assert result is not None, "Required property 'name' is missing"
        return result

    @builtins.property
    def resource_group_name(self) -> builtins.str:
        result = self._values.get("resource_group_name")
        assert result is not None, "Required property 'resource_group_name' is missing"
        return result

    @builtins.property
    def timeouts(self) -> typing.Optional["DataAzurermLogAnalyticsWorkspaceTimeouts"]:
        """timeouts block."""
        result = self._values.get("timeouts")
        return result

    def __eq__(self, rhs: typing.Any) -> builtins.bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs: typing.Any) -> builtins.bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return "DataAzurermLogAnalyticsWorkspaceConfig(%s)" % ", ".join(
            k + "=" + repr(v) for k, v in self._values.items()
        )


@jsii.data_type(
    jsii_type="@cdktf/provider-azurerm.DataAzurermLogAnalyticsWorkspaceTimeouts",
    jsii_struct_bases=[],
    name_mapping={"read": "read"},
)
class DataAzurermLogAnalyticsWorkspaceTimeouts:
    def __init__(self, *, read: typing.Optional[builtins.str] = None) -> None:
        """
        :param read: 
        """
        self._values: typing.Dict[str, typing.Any] = {}
        if read is not None:
            self._values["read"] = read

    @builtins.property
    def read(self) -> typing.Optional[builtins.str]:
        result = self._values.get("read")
        return result

    def __eq__(self, rhs: typing.Any) -> builtins.bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs: typing.Any) -> builtins.bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return "DataAzurermLogAnalyticsWorkspaceTimeouts(%s)" % ", ".join(
            k + "=" + repr(v) for k, v in self._values.items()
        )


class DataAzurermLogicAppWorkflow(
    cdktf.TerraformDataSource,
    metaclass=jsii.JSIIMeta,
    jsii_type="@cdktf/provider-azurerm.DataAzurermLogicAppWorkflow",
):
    def __init__(
        self,
        scope: constructs.Construct,
        id: builtins.str,
        *,
        name: builtins.str,
        resource_group_name: builtins.str,
        timeouts: typing.Optional["DataAzurermLogicAppWorkflowTimeouts"] = None,
        count: typing.Optional[jsii.Number] = None,
        depends_on: typing.Optional[typing.List[cdktf.TerraformResource]] = None,
        lifecycle: typing.Optional[cdktf.TerraformResourceLifecycle] = None,
        provider: typing.Optional[cdktf.TerraformProvider] = None,
    ) -> None:
        """
        :param scope: -
        :param id: -
        :param name: 
        :param resource_group_name: 
        :param timeouts: timeouts block.
        :param count: 
        :param depends_on: 
        :param lifecycle: 
        :param provider: 
        """
        config = DataAzurermLogicAppWorkflowConfig(
            name=name,
            resource_group_name=resource_group_name,
            timeouts=timeouts,
            count=count,
            depends_on=depends_on,
            lifecycle=lifecycle,
            provider=provider,
        )

        jsii.create(DataAzurermLogicAppWorkflow, self, [scope, id, config])

    @jsii.member(jsii_name="parameters")
    def parameters(self, key: builtins.str) -> builtins.str:
        """
        :param key: -
        """
        return jsii.invoke(self, "parameters", [key])

    @jsii.member(jsii_name="synthesizeAttributes")
    def _synthesize_attributes(self) -> typing.Mapping[builtins.str, typing.Any]:
        return jsii.invoke(self, "synthesizeAttributes", [])

    @jsii.member(jsii_name="tags")
    def tags(self, key: builtins.str) -> builtins.str:
        """
        :param key: -
        """
        return jsii.invoke(self, "tags", [key])

    @builtins.property # type: ignore
    @jsii.member(jsii_name="accessEndpoint")
    def access_endpoint(self) -> builtins.str:
        return jsii.get(self, "accessEndpoint")

    @builtins.property # type: ignore
    @jsii.member(jsii_name="location")
    def location(self) -> builtins.str:
        return jsii.get(self, "location")

    @builtins.property # type: ignore
    @jsii.member(jsii_name="workflowSchema")
    def workflow_schema(self) -> builtins.str:
        return jsii.get(self, "workflowSchema")

    @builtins.property # type: ignore
    @jsii.member(jsii_name="workflowVersion")
    def workflow_version(self) -> builtins.str:
        return jsii.get(self, "workflowVersion")

    @builtins.property # type: ignore
    @jsii.member(jsii_name="name")
    def name(self) -> builtins.str:
        return jsii.get(self, "name")

    @name.setter # type: ignore
    def name(self, value: builtins.str) -> None:
        jsii.set(self, "name", value)

    @builtins.property # type: ignore
    @jsii.member(jsii_name="resourceGroupName")
    def resource_group_name(self) -> builtins.str:
        return jsii.get(self, "resourceGroupName")

    @resource_group_name.setter # type: ignore
    def resource_group_name(self, value: builtins.str) -> None:
        jsii.set(self, "resourceGroupName", value)

    @builtins.property # type: ignore
    @jsii.member(jsii_name="id")
    def id(self) -> typing.Optional[builtins.str]:
        return jsii.get(self, "id")

    @id.setter # type: ignore
    def id(self, value: typing.Optional[builtins.str]) -> None:
        jsii.set(self, "id", value)

    @builtins.property # type: ignore
    @jsii.member(jsii_name="timeouts")
    def timeouts(self) -> typing.Optional["DataAzurermLogicAppWorkflowTimeouts"]:
        return jsii.get(self, "timeouts")

    @timeouts.setter # type: ignore
    def timeouts(
        self,
        value: typing.Optional["DataAzurermLogicAppWorkflowTimeouts"],
    ) -> None:
        jsii.set(self, "timeouts", value)


@jsii.data_type(
    jsii_type="@cdktf/provider-azurerm.DataAzurermLogicAppWorkflowConfig",
    jsii_struct_bases=[cdktf.TerraformMetaArguments],
    name_mapping={
        "count": "count",
        "depends_on": "dependsOn",
        "lifecycle": "lifecycle",
        "provider": "provider",
        "name": "name",
        "resource_group_name": "resourceGroupName",
        "timeouts": "timeouts",
    },
)
class DataAzurermLogicAppWorkflowConfig(cdktf.TerraformMetaArguments):
    def __init__(
        self,
        *,
        count: typing.Optional[jsii.Number] = None,
        depends_on: typing.Optional[typing.List[cdktf.TerraformResource]] = None,
        lifecycle: typing.Optional[cdktf.TerraformResourceLifecycle] = None,
        provider: typing.Optional[cdktf.TerraformProvider] = None,
        name: builtins.str,
        resource_group_name: builtins.str,
        timeouts: typing.Optional["DataAzurermLogicAppWorkflowTimeouts"] = None,
    ) -> None:
        """
        :param count: 
        :param depends_on: 
        :param lifecycle: 
        :param provider: 
        :param name: 
        :param resource_group_name: 
        :param timeouts: timeouts block.
        """
        if isinstance(lifecycle, dict):
            lifecycle = cdktf.TerraformResourceLifecycle(**lifecycle)
        if isinstance(timeouts, dict):
            timeouts = DataAzurermLogicAppWorkflowTimeouts(**timeouts)
        self._values: typing.Dict[str, typing.Any] = {
            "name": name,
            "resource_group_name": resource_group_name,
        }
        if count is not None:
            self._values["count"] = count
        if depends_on is not None:
            self._values["depends_on"] = depends_on
        if lifecycle is not None:
            self._values["lifecycle"] = lifecycle
        if provider is not None:
            self._values["provider"] = provider
        if timeouts is not None:
            self._values["timeouts"] = timeouts

    @builtins.property
    def count(self) -> typing.Optional[jsii.Number]:
        """
        :stability: experimental
        """
        result = self._values.get("count")
        return result

    @builtins.property
    def depends_on(self) -> typing.Optional[typing.List[cdktf.TerraformResource]]:
        """
        :stability: experimental
        """
        result = self._values.get("depends_on")
        return result

    @builtins.property
    def lifecycle(self) -> typing.Optional[cdktf.TerraformResourceLifecycle]:
        """
        :stability: experimental
        """
        result = self._values.get("lifecycle")
        return result

    @builtins.property
    def provider(self) -> typing.Optional[cdktf.TerraformProvider]:
        """
        :stability: experimental
        """
        result = self._values.get("provider")
        return result

    @builtins.property
    def name(self) -> builtins.str:
        result = self._values.get("name")
        assert result is not None, "Required property 'name' is missing"
        return result

    @builtins.property
    def resource_group_name(self) -> builtins.str:
        result = self._values.get("resource_group_name")
        assert result is not None, "Required property 'resource_group_name' is missing"
        return result

    @builtins.property
    def timeouts(self) -> typing.Optional["DataAzurermLogicAppWorkflowTimeouts"]:
        """timeouts block."""
        result = self._values.get("timeouts")
        return result

    def __eq__(self, rhs: typing.Any) -> builtins.bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs: typing.Any) -> builtins.bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return "DataAzurermLogicAppWorkflowConfig(%s)" % ", ".join(
            k + "=" + repr(v) for k, v in self._values.items()
        )


@jsii.data_type(
    jsii_type="@cdktf/provider-azurerm.DataAzurermLogicAppWorkflowTimeouts",
    jsii_struct_bases=[],
    name_mapping={"read": "read"},
)
class DataAzurermLogicAppWorkflowTimeouts:
    def __init__(self, *, read: typing.Optional[builtins.str] = None) -> None:
        """
        :param read: 
        """
        self._values: typing.Dict[str, typing.Any] = {}
        if read is not None:
            self._values["read"] = read

    @builtins.property
    def read(self) -> typing.Optional[builtins.str]:
        result = self._values.get("read")
        return result

    def __eq__(self, rhs: typing.Any) -> builtins.bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs: typing.Any) -> builtins.bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return "DataAzurermLogicAppWorkflowTimeouts(%s)" % ", ".join(
            k + "=" + repr(v) for k, v in self._values.items()
        )


class DataAzurermManagedDisk(
    cdktf.TerraformDataSource,
    metaclass=jsii.JSIIMeta,
    jsii_type="@cdktf/provider-azurerm.DataAzurermManagedDisk",
):
    def __init__(
        self,
        scope: constructs.Construct,
        id: builtins.str,
        *,
        name: builtins.str,
        resource_group_name: builtins.str,
        tags: typing.Optional[typing.Mapping[builtins.str, builtins.str]] = None,
        timeouts: typing.Optional["DataAzurermManagedDiskTimeouts"] = None,
        zones: typing.Optional[typing.List[builtins.str]] = None,
        count: typing.Optional[jsii.Number] = None,
        depends_on: typing.Optional[typing.List[cdktf.TerraformResource]] = None,
        lifecycle: typing.Optional[cdktf.TerraformResourceLifecycle] = None,
        provider: typing.Optional[cdktf.TerraformProvider] = None,
    ) -> None:
        """
        :param scope: -
        :param id: -
        :param name: 
        :param resource_group_name: 
        :param tags: 
        :param timeouts: timeouts block.
        :param zones: 
        :param count: 
        :param depends_on: 
        :param lifecycle: 
        :param provider: 
        """
        config = DataAzurermManagedDiskConfig(
            name=name,
            resource_group_name=resource_group_name,
            tags=tags,
            timeouts=timeouts,
            zones=zones,
            count=count,
            depends_on=depends_on,
            lifecycle=lifecycle,
            provider=provider,
        )

        jsii.create(DataAzurermManagedDisk, self, [scope, id, config])

    @jsii.member(jsii_name="synthesizeAttributes")
    def _synthesize_attributes(self) -> typing.Mapping[builtins.str, typing.Any]:
        return jsii.invoke(self, "synthesizeAttributes", [])

    @builtins.property # type: ignore
    @jsii.member(jsii_name="createOption")
    def create_option(self) -> builtins.str:
        return jsii.get(self, "createOption")

    @builtins.property # type: ignore
    @jsii.member(jsii_name="diskEncryptionSetId")
    def disk_encryption_set_id(self) -> builtins.str:
        return jsii.get(self, "diskEncryptionSetId")

    @builtins.property # type: ignore
    @jsii.member(jsii_name="diskIopsReadWrite")
    def disk_iops_read_write(self) -> jsii.Number:
        return jsii.get(self, "diskIopsReadWrite")

    @builtins.property # type: ignore
    @jsii.member(jsii_name="diskMbpsReadWrite")
    def disk_mbps_read_write(self) -> jsii.Number:
        return jsii.get(self, "diskMbpsReadWrite")

    @builtins.property # type: ignore
    @jsii.member(jsii_name="diskSizeGb")
    def disk_size_gb(self) -> jsii.Number:
        return jsii.get(self, "diskSizeGb")

    @builtins.property # type: ignore
    @jsii.member(jsii_name="osType")
    def os_type(self) -> builtins.str:
        return jsii.get(self, "osType")

    @builtins.property # type: ignore
    @jsii.member(jsii_name="sourceResourceId")
    def source_resource_id(self) -> builtins.str:
        return jsii.get(self, "sourceResourceId")

    @builtins.property # type: ignore
    @jsii.member(jsii_name="sourceUri")
    def source_uri(self) -> builtins.str:
        return jsii.get(self, "sourceUri")

    @builtins.property # type: ignore
    @jsii.member(jsii_name="storageAccountId")
    def storage_account_id(self) -> builtins.str:
        return jsii.get(self, "storageAccountId")

    @builtins.property # type: ignore
    @jsii.member(jsii_name="storageAccountType")
    def storage_account_type(self) -> builtins.str:
        return jsii.get(self, "storageAccountType")

    @builtins.property # type: ignore
    @jsii.member(jsii_name="name")
    def name(self) -> builtins.str:
        return jsii.get(self, "name")

    @name.setter # type: ignore
    def name(self, value: builtins.str) -> None:
        jsii.set(self, "name", value)

    @builtins.property # type: ignore
    @jsii.member(jsii_name="resourceGroupName")
    def resource_group_name(self) -> builtins.str:
        return jsii.get(self, "resourceGroupName")

    @resource_group_name.setter # type: ignore
    def resource_group_name(self, value: builtins.str) -> None:
        jsii.set(self, "resourceGroupName", value)

    @builtins.property # type: ignore
    @jsii.member(jsii_name="id")
    def id(self) -> typing.Optional[builtins.str]:
        return jsii.get(self, "id")

    @id.setter # type: ignore
    def id(self, value: typing.Optional[builtins.str]) -> None:
        jsii.set(self, "id", value)

    @builtins.property # type: ignore
    @jsii.member(jsii_name="tags")
    def tags(self) -> typing.Optional[typing.Mapping[builtins.str, builtins.str]]:
        return jsii.get(self, "tags")

    @tags.setter # type: ignore
    def tags(
        self,
        value: typing.Optional[typing.Mapping[builtins.str, builtins.str]],
    ) -> None:
        jsii.set(self, "tags", value)

    @builtins.property # type: ignore
    @jsii.member(jsii_name="timeouts")
    def timeouts(self) -> typing.Optional["DataAzurermManagedDiskTimeouts"]:
        return jsii.get(self, "timeouts")

    @timeouts.setter # type: ignore
    def timeouts(
        self,
        value: typing.Optional["DataAzurermManagedDiskTimeouts"],
    ) -> None:
        jsii.set(self, "timeouts", value)

    @builtins.property # type: ignore
    @jsii.member(jsii_name="zones")
    def zones(self) -> typing.Optional[typing.List[builtins.str]]:
        return jsii.get(self, "zones")

    @zones.setter # type: ignore
    def zones(self, value: typing.Optional[typing.List[builtins.str]]) -> None:
        jsii.set(self, "zones", value)


@jsii.data_type(
    jsii_type="@cdktf/provider-azurerm.DataAzurermManagedDiskConfig",
    jsii_struct_bases=[cdktf.TerraformMetaArguments],
    name_mapping={
        "count": "count",
        "depends_on": "dependsOn",
        "lifecycle": "lifecycle",
        "provider": "provider",
        "name": "name",
        "resource_group_name": "resourceGroupName",
        "tags": "tags",
        "timeouts": "timeouts",
        "zones": "zones",
    },
)
class DataAzurermManagedDiskConfig(cdktf.TerraformMetaArguments):
    def __init__(
        self,
        *,
        count: typing.Optional[jsii.Number] = None,
        depends_on: typing.Optional[typing.List[cdktf.TerraformResource]] = None,
        lifecycle: typing.Optional[cdktf.TerraformResourceLifecycle] = None,
        provider: typing.Optional[cdktf.TerraformProvider] = None,
        name: builtins.str,
        resource_group_name: builtins.str,
        tags: typing.Optional[typing.Mapping[builtins.str, builtins.str]] = None,
        timeouts: typing.Optional["DataAzurermManagedDiskTimeouts"] = None,
        zones: typing.Optional[typing.List[builtins.str]] = None,
    ) -> None:
        """
        :param count: 
        :param depends_on: 
        :param lifecycle: 
        :param provider: 
        :param name: 
        :param resource_group_name: 
        :param tags: 
        :param timeouts: timeouts block.
        :param zones: 
        """
        if isinstance(lifecycle, dict):
            lifecycle = cdktf.TerraformResourceLifecycle(**lifecycle)
        if isinstance(timeouts, dict):
            timeouts = DataAzurermManagedDiskTimeouts(**timeouts)
        self._values: typing.Dict[str, typing.Any] = {
            "name": name,
            "resource_group_name": resource_group_name,
        }
        if count is not None:
            self._values["count"] = count
        if depends_on is not None:
            self._values["depends_on"] = depends_on
        if lifecycle is not None:
            self._values["lifecycle"] = lifecycle
        if provider is not None:
            self._values["provider"] = provider
        if tags is not None:
            self._values["tags"] = tags
        if timeouts is not None:
            self._values["timeouts"] = timeouts
        if zones is not None:
            self._values["zones"] = zones

    @builtins.property
    def count(self) -> typing.Optional[jsii.Number]:
        """
        :stability: experimental
        """
        result = self._values.get("count")
        return result

    @builtins.property
    def depends_on(self) -> typing.Optional[typing.List[cdktf.TerraformResource]]:
        """
        :stability: experimental
        """
        result = self._values.get("depends_on")
        return result

    @builtins.property
    def lifecycle(self) -> typing.Optional[cdktf.TerraformResourceLifecycle]:
        """
        :stability: experimental
        """
        result = self._values.get("lifecycle")
        return result

    @builtins.property
    def provider(self) -> typing.Optional[cdktf.TerraformProvider]:
        """
        :stability: experimental
        """
        result = self._values.get("provider")
        return result

    @builtins.property
    def name(self) -> builtins.str:
        result = self._values.get("name")
        assert result is not None, "Required property 'name' is missing"
        return result

    @builtins.property
    def resource_group_name(self) -> builtins.str:
        result = self._values.get("resource_group_name")
        assert result is not None, "Required property 'resource_group_name' is missing"
        return result

    @builtins.property
    def tags(self) -> typing.Optional[typing.Mapping[builtins.str, builtins.str]]:
        result = self._values.get("tags")
        return result

    @builtins.property
    def timeouts(self) -> typing.Optional["DataAzurermManagedDiskTimeouts"]:
        """timeouts block."""
        result = self._values.get("timeouts")
        return result

    @builtins.property
    def zones(self) -> typing.Optional[typing.List[builtins.str]]:
        result = self._values.get("zones")
        return result

    def __eq__(self, rhs: typing.Any) -> builtins.bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs: typing.Any) -> builtins.bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return "DataAzurermManagedDiskConfig(%s)" % ", ".join(
            k + "=" + repr(v) for k, v in self._values.items()
        )


@jsii.data_type(
    jsii_type="@cdktf/provider-azurerm.DataAzurermManagedDiskTimeouts",
    jsii_struct_bases=[],
    name_mapping={"read": "read"},
)
class DataAzurermManagedDiskTimeouts:
    def __init__(self, *, read: typing.Optional[builtins.str] = None) -> None:
        """
        :param read: 
        """
        self._values: typing.Dict[str, typing.Any] = {}
        if read is not None:
            self._values["read"] = read

    @builtins.property
    def read(self) -> typing.Optional[builtins.str]:
        result = self._values.get("read")
        return result

    def __eq__(self, rhs: typing.Any) -> builtins.bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs: typing.Any) -> builtins.bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return "DataAzurermManagedDiskTimeouts(%s)" % ", ".join(
            k + "=" + repr(v) for k, v in self._values.items()
        )


class DataAzurermManagementGroup(
    cdktf.TerraformDataSource,
    metaclass=jsii.JSIIMeta,
    jsii_type="@cdktf/provider-azurerm.DataAzurermManagementGroup",
):
    def __init__(
        self,
        scope: constructs.Construct,
        id: builtins.str,
        *,
        group_id: builtins.str,
        timeouts: typing.Optional["DataAzurermManagementGroupTimeouts"] = None,
        count: typing.Optional[jsii.Number] = None,
        depends_on: typing.Optional[typing.List[cdktf.TerraformResource]] = None,
        lifecycle: typing.Optional[cdktf.TerraformResourceLifecycle] = None,
        provider: typing.Optional[cdktf.TerraformProvider] = None,
    ) -> None:
        """
        :param scope: -
        :param id: -
        :param group_id: 
        :param timeouts: timeouts block.
        :param count: 
        :param depends_on: 
        :param lifecycle: 
        :param provider: 
        """
        config = DataAzurermManagementGroupConfig(
            group_id=group_id,
            timeouts=timeouts,
            count=count,
            depends_on=depends_on,
            lifecycle=lifecycle,
            provider=provider,
        )

        jsii.create(DataAzurermManagementGroup, self, [scope, id, config])

    @jsii.member(jsii_name="synthesizeAttributes")
    def _synthesize_attributes(self) -> typing.Mapping[builtins.str, typing.Any]:
        return jsii.invoke(self, "synthesizeAttributes", [])

    @builtins.property # type: ignore
    @jsii.member(jsii_name="displayName")
    def display_name(self) -> builtins.str:
        return jsii.get(self, "displayName")

    @builtins.property # type: ignore
    @jsii.member(jsii_name="parentManagementGroupId")
    def parent_management_group_id(self) -> builtins.str:
        return jsii.get(self, "parentManagementGroupId")

    @builtins.property # type: ignore
    @jsii.member(jsii_name="subscriptionIds")
    def subscription_ids(self) -> typing.List[builtins.str]:
        return jsii.get(self, "subscriptionIds")

    @builtins.property # type: ignore
    @jsii.member(jsii_name="groupId")
    def group_id(self) -> builtins.str:
        return jsii.get(self, "groupId")

    @group_id.setter # type: ignore
    def group_id(self, value: builtins.str) -> None:
        jsii.set(self, "groupId", value)

    @builtins.property # type: ignore
    @jsii.member(jsii_name="id")
    def id(self) -> typing.Optional[builtins.str]:
        return jsii.get(self, "id")

    @id.setter # type: ignore
    def id(self, value: typing.Optional[builtins.str]) -> None:
        jsii.set(self, "id", value)

    @builtins.property # type: ignore
    @jsii.member(jsii_name="timeouts")
    def timeouts(self) -> typing.Optional["DataAzurermManagementGroupTimeouts"]:
        return jsii.get(self, "timeouts")

    @timeouts.setter # type: ignore
    def timeouts(
        self,
        value: typing.Optional["DataAzurermManagementGroupTimeouts"],
    ) -> None:
        jsii.set(self, "timeouts", value)


@jsii.data_type(
    jsii_type="@cdktf/provider-azurerm.DataAzurermManagementGroupConfig",
    jsii_struct_bases=[cdktf.TerraformMetaArguments],
    name_mapping={
        "count": "count",
        "depends_on": "dependsOn",
        "lifecycle": "lifecycle",
        "provider": "provider",
        "group_id": "groupId",
        "timeouts": "timeouts",
    },
)
class DataAzurermManagementGroupConfig(cdktf.TerraformMetaArguments):
    def __init__(
        self,
        *,
        count: typing.Optional[jsii.Number] = None,
        depends_on: typing.Optional[typing.List[cdktf.TerraformResource]] = None,
        lifecycle: typing.Optional[cdktf.TerraformResourceLifecycle] = None,
        provider: typing.Optional[cdktf.TerraformProvider] = None,
        group_id: builtins.str,
        timeouts: typing.Optional["DataAzurermManagementGroupTimeouts"] = None,
    ) -> None:
        """
        :param count: 
        :param depends_on: 
        :param lifecycle: 
        :param provider: 
        :param group_id: 
        :param timeouts: timeouts block.
        """
        if isinstance(lifecycle, dict):
            lifecycle = cdktf.TerraformResourceLifecycle(**lifecycle)
        if isinstance(timeouts, dict):
            timeouts = DataAzurermManagementGroupTimeouts(**timeouts)
        self._values: typing.Dict[str, typing.Any] = {
            "group_id": group_id,
        }
        if count is not None:
            self._values["count"] = count
        if depends_on is not None:
            self._values["depends_on"] = depends_on
        if lifecycle is not None:
            self._values["lifecycle"] = lifecycle
        if provider is not None:
            self._values["provider"] = provider
        if timeouts is not None:
            self._values["timeouts"] = timeouts

    @builtins.property
    def count(self) -> typing.Optional[jsii.Number]:
        """
        :stability: experimental
        """
        result = self._values.get("count")
        return result

    @builtins.property
    def depends_on(self) -> typing.Optional[typing.List[cdktf.TerraformResource]]:
        """
        :stability: experimental
        """
        result = self._values.get("depends_on")
        return result

    @builtins.property
    def lifecycle(self) -> typing.Optional[cdktf.TerraformResourceLifecycle]:
        """
        :stability: experimental
        """
        result = self._values.get("lifecycle")
        return result

    @builtins.property
    def provider(self) -> typing.Optional[cdktf.TerraformProvider]:
        """
        :stability: experimental
        """
        result = self._values.get("provider")
        return result

    @builtins.property
    def group_id(self) -> builtins.str:
        result = self._values.get("group_id")
        assert result is not None, "Required property 'group_id' is missing"
        return result

    @builtins.property
    def timeouts(self) -> typing.Optional["DataAzurermManagementGroupTimeouts"]:
        """timeouts block."""
        result = self._values.get("timeouts")
        return result

    def __eq__(self, rhs: typing.Any) -> builtins.bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs: typing.Any) -> builtins.bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return "DataAzurermManagementGroupConfig(%s)" % ", ".join(
            k + "=" + repr(v) for k, v in self._values.items()
        )


@jsii.data_type(
    jsii_type="@cdktf/provider-azurerm.DataAzurermManagementGroupTimeouts",
    jsii_struct_bases=[],
    name_mapping={"read": "read"},
)
class DataAzurermManagementGroupTimeouts:
    def __init__(self, *, read: typing.Optional[builtins.str] = None) -> None:
        """
        :param read: 
        """
        self._values: typing.Dict[str, typing.Any] = {}
        if read is not None:
            self._values["read"] = read

    @builtins.property
    def read(self) -> typing.Optional[builtins.str]:
        result = self._values.get("read")
        return result

    def __eq__(self, rhs: typing.Any) -> builtins.bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs: typing.Any) -> builtins.bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return "DataAzurermManagementGroupTimeouts(%s)" % ", ".join(
            k + "=" + repr(v) for k, v in self._values.items()
        )


class DataAzurermMapsAccount(
    cdktf.TerraformDataSource,
    metaclass=jsii.JSIIMeta,
    jsii_type="@cdktf/provider-azurerm.DataAzurermMapsAccount",
):
    def __init__(
        self,
        scope: constructs.Construct,
        id: builtins.str,
        *,
        name: builtins.str,
        resource_group_name: builtins.str,
        tags: typing.Optional[typing.Mapping[builtins.str, builtins.str]] = None,
        timeouts: typing.Optional["DataAzurermMapsAccountTimeouts"] = None,
        count: typing.Optional[jsii.Number] = None,
        depends_on: typing.Optional[typing.List[cdktf.TerraformResource]] = None,
        lifecycle: typing.Optional[cdktf.TerraformResourceLifecycle] = None,
        provider: typing.Optional[cdktf.TerraformProvider] = None,
    ) -> None:
        """
        :param scope: -
        :param id: -
        :param name: 
        :param resource_group_name: 
        :param tags: 
        :param timeouts: timeouts block.
        :param count: 
        :param depends_on: 
        :param lifecycle: 
        :param provider: 
        """
        config = DataAzurermMapsAccountConfig(
            name=name,
            resource_group_name=resource_group_name,
            tags=tags,
            timeouts=timeouts,
            count=count,
            depends_on=depends_on,
            lifecycle=lifecycle,
            provider=provider,
        )

        jsii.create(DataAzurermMapsAccount, self, [scope, id, config])

    @jsii.member(jsii_name="synthesizeAttributes")
    def _synthesize_attributes(self) -> typing.Mapping[builtins.str, typing.Any]:
        return jsii.invoke(self, "synthesizeAttributes", [])

    @builtins.property # type: ignore
    @jsii.member(jsii_name="primaryAccessKey")
    def primary_access_key(self) -> builtins.str:
        return jsii.get(self, "primaryAccessKey")

    @builtins.property # type: ignore
    @jsii.member(jsii_name="secondaryAccessKey")
    def secondary_access_key(self) -> builtins.str:
        return jsii.get(self, "secondaryAccessKey")

    @builtins.property # type: ignore
    @jsii.member(jsii_name="skuName")
    def sku_name(self) -> builtins.str:
        return jsii.get(self, "skuName")

    @builtins.property # type: ignore
    @jsii.member(jsii_name="xMsClientId")
    def x_ms_client_id(self) -> builtins.str:
        return jsii.get(self, "xMsClientId")

    @builtins.property # type: ignore
    @jsii.member(jsii_name="name")
    def name(self) -> builtins.str:
        return jsii.get(self, "name")

    @name.setter # type: ignore
    def name(self, value: builtins.str) -> None:
        jsii.set(self, "name", value)

    @builtins.property # type: ignore
    @jsii.member(jsii_name="resourceGroupName")
    def resource_group_name(self) -> builtins.str:
        return jsii.get(self, "resourceGroupName")

    @resource_group_name.setter # type: ignore
    def resource_group_name(self, value: builtins.str) -> None:
        jsii.set(self, "resourceGroupName", value)

    @builtins.property # type: ignore
    @jsii.member(jsii_name="id")
    def id(self) -> typing.Optional[builtins.str]:
        return jsii.get(self, "id")

    @id.setter # type: ignore
    def id(self, value: typing.Optional[builtins.str]) -> None:
        jsii.set(self, "id", value)

    @builtins.property # type: ignore
    @jsii.member(jsii_name="tags")
    def tags(self) -> typing.Optional[typing.Mapping[builtins.str, builtins.str]]:
        return jsii.get(self, "tags")

    @tags.setter # type: ignore
    def tags(
        self,
        value: typing.Optional[typing.Mapping[builtins.str, builtins.str]],
    ) -> None:
        jsii.set(self, "tags", value)

    @builtins.property # type: ignore
    @jsii.member(jsii_name="timeouts")
    def timeouts(self) -> typing.Optional["DataAzurermMapsAccountTimeouts"]:
        return jsii.get(self, "timeouts")

    @timeouts.setter # type: ignore
    def timeouts(
        self,
        value: typing.Optional["DataAzurermMapsAccountTimeouts"],
    ) -> None:
        jsii.set(self, "timeouts", value)


@jsii.data_type(
    jsii_type="@cdktf/provider-azurerm.DataAzurermMapsAccountConfig",
    jsii_struct_bases=[cdktf.TerraformMetaArguments],
    name_mapping={
        "count": "count",
        "depends_on": "dependsOn",
        "lifecycle": "lifecycle",
        "provider": "provider",
        "name": "name",
        "resource_group_name": "resourceGroupName",
        "tags": "tags",
        "timeouts": "timeouts",
    },
)
class DataAzurermMapsAccountConfig(cdktf.TerraformMetaArguments):
    def __init__(
        self,
        *,
        count: typing.Optional[jsii.Number] = None,
        depends_on: typing.Optional[typing.List[cdktf.TerraformResource]] = None,
        lifecycle: typing.Optional[cdktf.TerraformResourceLifecycle] = None,
        provider: typing.Optional[cdktf.TerraformProvider] = None,
        name: builtins.str,
        resource_group_name: builtins.str,
        tags: typing.Optional[typing.Mapping[builtins.str, builtins.str]] = None,
        timeouts: typing.Optional["DataAzurermMapsAccountTimeouts"] = None,
    ) -> None:
        """
        :param count: 
        :param depends_on: 
        :param lifecycle: 
        :param provider: 
        :param name: 
        :param resource_group_name: 
        :param tags: 
        :param timeouts: timeouts block.
        """
        if isinstance(lifecycle, dict):
            lifecycle = cdktf.TerraformResourceLifecycle(**lifecycle)
        if isinstance(timeouts, dict):
            timeouts = DataAzurermMapsAccountTimeouts(**timeouts)
        self._values: typing.Dict[str, typing.Any] = {
            "name": name,
            "resource_group_name": resource_group_name,
        }
        if count is not None:
            self._values["count"] = count
        if depends_on is not None:
            self._values["depends_on"] = depends_on
        if lifecycle is not None:
            self._values["lifecycle"] = lifecycle
        if provider is not None:
            self._values["provider"] = provider
        if tags is not None:
            self._values["tags"] = tags
        if timeouts is not None:
            self._values["timeouts"] = timeouts

    @builtins.property
    def count(self) -> typing.Optional[jsii.Number]:
        """
        :stability: experimental
        """
        result = self._values.get("count")
        return result

    @builtins.property
    def depends_on(self) -> typing.Optional[typing.List[cdktf.TerraformResource]]:
        """
        :stability: experimental
        """
        result = self._values.get("depends_on")
        return result

    @builtins.property
    def lifecycle(self) -> typing.Optional[cdktf.TerraformResourceLifecycle]:
        """
        :stability: experimental
        """
        result = self._values.get("lifecycle")
        return result

    @builtins.property
    def provider(self) -> typing.Optional[cdktf.TerraformProvider]:
        """
        :stability: experimental
        """
        result = self._values.get("provider")
        return result

    @builtins.property
    def name(self) -> builtins.str:
        result = self._values.get("name")
        assert result is not None, "Required property 'name' is missing"
        return result

    @builtins.property
    def resource_group_name(self) -> builtins.str:
        result = self._values.get("resource_group_name")
        assert result is not None, "Required property 'resource_group_name' is missing"
        return result

    @builtins.property
    def tags(self) -> typing.Optional[typing.Mapping[builtins.str, builtins.str]]:
        result = self._values.get("tags")
        return result

    @builtins.property
    def timeouts(self) -> typing.Optional["DataAzurermMapsAccountTimeouts"]:
        """timeouts block."""
        result = self._values.get("timeouts")
        return result

    def __eq__(self, rhs: typing.Any) -> builtins.bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs: typing.Any) -> builtins.bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return "DataAzurermMapsAccountConfig(%s)" % ", ".join(
            k + "=" + repr(v) for k, v in self._values.items()
        )


@jsii.data_type(
    jsii_type="@cdktf/provider-azurerm.DataAzurermMapsAccountTimeouts",
    jsii_struct_bases=[],
    name_mapping={"read": "read"},
)
class DataAzurermMapsAccountTimeouts:
    def __init__(self, *, read: typing.Optional[builtins.str] = None) -> None:
        """
        :param read: 
        """
        self._values: typing.Dict[str, typing.Any] = {}
        if read is not None:
            self._values["read"] = read

    @builtins.property
    def read(self) -> typing.Optional[builtins.str]:
        result = self._values.get("read")
        return result

    def __eq__(self, rhs: typing.Any) -> builtins.bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs: typing.Any) -> builtins.bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return "DataAzurermMapsAccountTimeouts(%s)" % ", ".join(
            k + "=" + repr(v) for k, v in self._values.items()
        )


class DataAzurermMariadbServer(
    cdktf.TerraformDataSource,
    metaclass=jsii.JSIIMeta,
    jsii_type="@cdktf/provider-azurerm.DataAzurermMariadbServer",
):
    def __init__(
        self,
        scope: constructs.Construct,
        id: builtins.str,
        *,
        name: builtins.str,
        resource_group_name: builtins.str,
        timeouts: typing.Optional["DataAzurermMariadbServerTimeouts"] = None,
        count: typing.Optional[jsii.Number] = None,
        depends_on: typing.Optional[typing.List[cdktf.TerraformResource]] = None,
        lifecycle: typing.Optional[cdktf.TerraformResourceLifecycle] = None,
        provider: typing.Optional[cdktf.TerraformProvider] = None,
    ) -> None:
        """
        :param scope: -
        :param id: -
        :param name: 
        :param resource_group_name: 
        :param timeouts: timeouts block.
        :param count: 
        :param depends_on: 
        :param lifecycle: 
        :param provider: 
        """
        config = DataAzurermMariadbServerConfig(
            name=name,
            resource_group_name=resource_group_name,
            timeouts=timeouts,
            count=count,
            depends_on=depends_on,
            lifecycle=lifecycle,
            provider=provider,
        )

        jsii.create(DataAzurermMariadbServer, self, [scope, id, config])

    @jsii.member(jsii_name="storageProfile")
    def storage_profile(
        self,
        index: builtins.str,
    ) -> "DataAzurermMariadbServerStorageProfile":
        """
        :param index: -
        """
        return jsii.invoke(self, "storageProfile", [index])

    @jsii.member(jsii_name="synthesizeAttributes")
    def _synthesize_attributes(self) -> typing.Mapping[builtins.str, typing.Any]:
        return jsii.invoke(self, "synthesizeAttributes", [])

    @jsii.member(jsii_name="tags")
    def tags(self, key: builtins.str) -> builtins.str:
        """
        :param key: -
        """
        return jsii.invoke(self, "tags", [key])

    @builtins.property # type: ignore
    @jsii.member(jsii_name="administratorLogin")
    def administrator_login(self) -> builtins.str:
        return jsii.get(self, "administratorLogin")

    @builtins.property # type: ignore
    @jsii.member(jsii_name="administratorLoginPassword")
    def administrator_login_password(self) -> builtins.str:
        return jsii.get(self, "administratorLoginPassword")

    @builtins.property # type: ignore
    @jsii.member(jsii_name="fqdn")
    def fqdn(self) -> builtins.str:
        return jsii.get(self, "fqdn")

    @builtins.property # type: ignore
    @jsii.member(jsii_name="location")
    def location(self) -> builtins.str:
        return jsii.get(self, "location")

    @builtins.property # type: ignore
    @jsii.member(jsii_name="skuName")
    def sku_name(self) -> builtins.str:
        return jsii.get(self, "skuName")

    @builtins.property # type: ignore
    @jsii.member(jsii_name="sslEnforcement")
    def ssl_enforcement(self) -> builtins.str:
        return jsii.get(self, "sslEnforcement")

    @builtins.property # type: ignore
    @jsii.member(jsii_name="version")
    def version(self) -> builtins.str:
        return jsii.get(self, "version")

    @builtins.property # type: ignore
    @jsii.member(jsii_name="name")
    def name(self) -> builtins.str:
        return jsii.get(self, "name")

    @name.setter # type: ignore
    def name(self, value: builtins.str) -> None:
        jsii.set(self, "name", value)

    @builtins.property # type: ignore
    @jsii.member(jsii_name="resourceGroupName")
    def resource_group_name(self) -> builtins.str:
        return jsii.get(self, "resourceGroupName")

    @resource_group_name.setter # type: ignore
    def resource_group_name(self, value: builtins.str) -> None:
        jsii.set(self, "resourceGroupName", value)

    @builtins.property # type: ignore
    @jsii.member(jsii_name="id")
    def id(self) -> typing.Optional[builtins.str]:
        return jsii.get(self, "id")

    @id.setter # type: ignore
    def id(self, value: typing.Optional[builtins.str]) -> None:
        jsii.set(self, "id", value)

    @builtins.property # type: ignore
    @jsii.member(jsii_name="timeouts")
    def timeouts(self) -> typing.Optional["DataAzurermMariadbServerTimeouts"]:
        return jsii.get(self, "timeouts")

    @timeouts.setter # type: ignore
    def timeouts(
        self,
        value: typing.Optional["DataAzurermMariadbServerTimeouts"],
    ) -> None:
        jsii.set(self, "timeouts", value)


@jsii.data_type(
    jsii_type="@cdktf/provider-azurerm.DataAzurermMariadbServerConfig",
    jsii_struct_bases=[cdktf.TerraformMetaArguments],
    name_mapping={
        "count": "count",
        "depends_on": "dependsOn",
        "lifecycle": "lifecycle",
        "provider": "provider",
        "name": "name",
        "resource_group_name": "resourceGroupName",
        "timeouts": "timeouts",
    },
)
class DataAzurermMariadbServerConfig(cdktf.TerraformMetaArguments):
    def __init__(
        self,
        *,
        count: typing.Optional[jsii.Number] = None,
        depends_on: typing.Optional[typing.List[cdktf.TerraformResource]] = None,
        lifecycle: typing.Optional[cdktf.TerraformResourceLifecycle] = None,
        provider: typing.Optional[cdktf.TerraformProvider] = None,
        name: builtins.str,
        resource_group_name: builtins.str,
        timeouts: typing.Optional["DataAzurermMariadbServerTimeouts"] = None,
    ) -> None:
        """
        :param count: 
        :param depends_on: 
        :param lifecycle: 
        :param provider: 
        :param name: 
        :param resource_group_name: 
        :param timeouts: timeouts block.
        """
        if isinstance(lifecycle, dict):
            lifecycle = cdktf.TerraformResourceLifecycle(**lifecycle)
        if isinstance(timeouts, dict):
            timeouts = DataAzurermMariadbServerTimeouts(**timeouts)
        self._values: typing.Dict[str, typing.Any] = {
            "name": name,
            "resource_group_name": resource_group_name,
        }
        if count is not None:
            self._values["count"] = count
        if depends_on is not None:
            self._values["depends_on"] = depends_on
        if lifecycle is not None:
            self._values["lifecycle"] = lifecycle
        if provider is not None:
            self._values["provider"] = provider
        if timeouts is not None:
            self._values["timeouts"] = timeouts

    @builtins.property
    def count(self) -> typing.Optional[jsii.Number]:
        """
        :stability: experimental
        """
        result = self._values.get("count")
        return result

    @builtins.property
    def depends_on(self) -> typing.Optional[typing.List[cdktf.TerraformResource]]:
        """
        :stability: experimental
        """
        result = self._values.get("depends_on")
        return result

    @builtins.property
    def lifecycle(self) -> typing.Optional[cdktf.TerraformResourceLifecycle]:
        """
        :stability: experimental
        """
        result = self._values.get("lifecycle")
        return result

    @builtins.property
    def provider(self) -> typing.Optional[cdktf.TerraformProvider]:
        """
        :stability: experimental
        """
        result = self._values.get("provider")
        return result

    @builtins.property
    def name(self) -> builtins.str:
        result = self._values.get("name")
        assert result is not None, "Required property 'name' is missing"
        return result

    @builtins.property
    def resource_group_name(self) -> builtins.str:
        result = self._values.get("resource_group_name")
        assert result is not None, "Required property 'resource_group_name' is missing"
        return result

    @builtins.property
    def timeouts(self) -> typing.Optional["DataAzurermMariadbServerTimeouts"]:
        """timeouts block."""
        result = self._values.get("timeouts")
        return result

    def __eq__(self, rhs: typing.Any) -> builtins.bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs: typing.Any) -> builtins.bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return "DataAzurermMariadbServerConfig(%s)" % ", ".join(
            k + "=" + repr(v) for k, v in self._values.items()
        )


class DataAzurermMariadbServerStorageProfile(
    cdktf.ComplexComputedList,
    metaclass=jsii.JSIIMeta,
    jsii_type="@cdktf/provider-azurerm.DataAzurermMariadbServerStorageProfile",
):
    def __init__(
        self,
        terraform_resource: cdktf.ITerraformResource,
        terraform_attribute: builtins.str,
        index: builtins.str,
    ) -> None:
        """
        :param terraform_resource: -
        :param terraform_attribute: -
        :param index: -

        :stability: experimental
        """
        jsii.create(DataAzurermMariadbServerStorageProfile, self, [terraform_resource, terraform_attribute, index])

    @builtins.property # type: ignore
    @jsii.member(jsii_name="autoGrow")
    def auto_grow(self) -> builtins.str:
        return jsii.get(self, "autoGrow")

    @builtins.property # type: ignore
    @jsii.member(jsii_name="backupRetentionDays")
    def backup_retention_days(self) -> jsii.Number:
        return jsii.get(self, "backupRetentionDays")

    @builtins.property # type: ignore
    @jsii.member(jsii_name="geoRedundantBackup")
    def geo_redundant_backup(self) -> builtins.str:
        return jsii.get(self, "geoRedundantBackup")

    @builtins.property # type: ignore
    @jsii.member(jsii_name="storageMb")
    def storage_mb(self) -> jsii.Number:
        return jsii.get(self, "storageMb")


@jsii.data_type(
    jsii_type="@cdktf/provider-azurerm.DataAzurermMariadbServerTimeouts",
    jsii_struct_bases=[],
    name_mapping={"read": "read"},
)
class DataAzurermMariadbServerTimeouts:
    def __init__(self, *, read: typing.Optional[builtins.str] = None) -> None:
        """
        :param read: 
        """
        self._values: typing.Dict[str, typing.Any] = {}
        if read is not None:
            self._values["read"] = read

    @builtins.property
    def read(self) -> typing.Optional[builtins.str]:
        result = self._values.get("read")
        return result

    def __eq__(self, rhs: typing.Any) -> builtins.bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs: typing.Any) -> builtins.bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return "DataAzurermMariadbServerTimeouts(%s)" % ", ".join(
            k + "=" + repr(v) for k, v in self._values.items()
        )


class DataAzurermMonitorActionGroup(
    cdktf.TerraformDataSource,
    metaclass=jsii.JSIIMeta,
    jsii_type="@cdktf/provider-azurerm.DataAzurermMonitorActionGroup",
):
    def __init__(
        self,
        scope: constructs.Construct,
        id: builtins.str,
        *,
        name: builtins.str,
        resource_group_name: builtins.str,
        timeouts: typing.Optional["DataAzurermMonitorActionGroupTimeouts"] = None,
        count: typing.Optional[jsii.Number] = None,
        depends_on: typing.Optional[typing.List[cdktf.TerraformResource]] = None,
        lifecycle: typing.Optional[cdktf.TerraformResourceLifecycle] = None,
        provider: typing.Optional[cdktf.TerraformProvider] = None,
    ) -> None:
        """
        :param scope: -
        :param id: -
        :param name: 
        :param resource_group_name: 
        :param timeouts: timeouts block.
        :param count: 
        :param depends_on: 
        :param lifecycle: 
        :param provider: 
        """
        config = DataAzurermMonitorActionGroupConfig(
            name=name,
            resource_group_name=resource_group_name,
            timeouts=timeouts,
            count=count,
            depends_on=depends_on,
            lifecycle=lifecycle,
            provider=provider,
        )

        jsii.create(DataAzurermMonitorActionGroup, self, [scope, id, config])

    @jsii.member(jsii_name="armRoleReceiver")
    def arm_role_receiver(
        self,
        index: builtins.str,
    ) -> "DataAzurermMonitorActionGroupArmRoleReceiver":
        """
        :param index: -
        """
        return jsii.invoke(self, "armRoleReceiver", [index])

    @jsii.member(jsii_name="automationRunbookReceiver")
    def automation_runbook_receiver(
        self,
        index: builtins.str,
    ) -> "DataAzurermMonitorActionGroupAutomationRunbookReceiver":
        """
        :param index: -
        """
        return jsii.invoke(self, "automationRunbookReceiver", [index])

    @jsii.member(jsii_name="azureAppPushReceiver")
    def azure_app_push_receiver(
        self,
        index: builtins.str,
    ) -> "DataAzurermMonitorActionGroupAzureAppPushReceiver":
        """
        :param index: -
        """
        return jsii.invoke(self, "azureAppPushReceiver", [index])

    @jsii.member(jsii_name="azureFunctionReceiver")
    def azure_function_receiver(
        self,
        index: builtins.str,
    ) -> "DataAzurermMonitorActionGroupAzureFunctionReceiver":
        """
        :param index: -
        """
        return jsii.invoke(self, "azureFunctionReceiver", [index])

    @jsii.member(jsii_name="emailReceiver")
    def email_receiver(
        self,
        index: builtins.str,
    ) -> "DataAzurermMonitorActionGroupEmailReceiver":
        """
        :param index: -
        """
        return jsii.invoke(self, "emailReceiver", [index])

    @jsii.member(jsii_name="itsmReceiver")
    def itsm_receiver(
        self,
        index: builtins.str,
    ) -> "DataAzurermMonitorActionGroupItsmReceiver":
        """
        :param index: -
        """
        return jsii.invoke(self, "itsmReceiver", [index])

    @jsii.member(jsii_name="logicAppReceiver")
    def logic_app_receiver(
        self,
        index: builtins.str,
    ) -> "DataAzurermMonitorActionGroupLogicAppReceiver":
        """
        :param index: -
        """
        return jsii.invoke(self, "logicAppReceiver", [index])

    @jsii.member(jsii_name="smsReceiver")
    def sms_receiver(
        self,
        index: builtins.str,
    ) -> "DataAzurermMonitorActionGroupSmsReceiver":
        """
        :param index: -
        """
        return jsii.invoke(self, "smsReceiver", [index])

    @jsii.member(jsii_name="synthesizeAttributes")
    def _synthesize_attributes(self) -> typing.Mapping[builtins.str, typing.Any]:
        return jsii.invoke(self, "synthesizeAttributes", [])

    @jsii.member(jsii_name="voiceReceiver")
    def voice_receiver(
        self,
        index: builtins.str,
    ) -> "DataAzurermMonitorActionGroupVoiceReceiver":
        """
        :param index: -
        """
        return jsii.invoke(self, "voiceReceiver", [index])

    @jsii.member(jsii_name="webhookReceiver")
    def webhook_receiver(
        self,
        index: builtins.str,
    ) -> "DataAzurermMonitorActionGroupWebhookReceiver":
        """
        :param index: -
        """
        return jsii.invoke(self, "webhookReceiver", [index])

    @builtins.property # type: ignore
    @jsii.member(jsii_name="enabled")
    def enabled(self) -> builtins.bool:
        return jsii.get(self, "enabled")

    @builtins.property # type: ignore
    @jsii.member(jsii_name="shortName")
    def short_name(self) -> builtins.str:
        return jsii.get(self, "shortName")

    @builtins.property # type: ignore
    @jsii.member(jsii_name="name")
    def name(self) -> builtins.str:
        return jsii.get(self, "name")

    @name.setter # type: ignore
    def name(self, value: builtins.str) -> None:
        jsii.set(self, "name", value)

    @builtins.property # type: ignore
    @jsii.member(jsii_name="resourceGroupName")
    def resource_group_name(self) -> builtins.str:
        return jsii.get(self, "resourceGroupName")

    @resource_group_name.setter # type: ignore
    def resource_group_name(self, value: builtins.str) -> None:
        jsii.set(self, "resourceGroupName", value)

    @builtins.property # type: ignore
    @jsii.member(jsii_name="id")
    def id(self) -> typing.Optional[builtins.str]:
        return jsii.get(self, "id")

    @id.setter # type: ignore
    def id(self, value: typing.Optional[builtins.str]) -> None:
        jsii.set(self, "id", value)

    @builtins.property # type: ignore
    @jsii.member(jsii_name="timeouts")
    def timeouts(self) -> typing.Optional["DataAzurermMonitorActionGroupTimeouts"]:
        return jsii.get(self, "timeouts")

    @timeouts.setter # type: ignore
    def timeouts(
        self,
        value: typing.Optional["DataAzurermMonitorActionGroupTimeouts"],
    ) -> None:
        jsii.set(self, "timeouts", value)


class DataAzurermMonitorActionGroupArmRoleReceiver(
    cdktf.ComplexComputedList,
    metaclass=jsii.JSIIMeta,
    jsii_type="@cdktf/provider-azurerm.DataAzurermMonitorActionGroupArmRoleReceiver",
):
    def __init__(
        self,
        terraform_resource: cdktf.ITerraformResource,
        terraform_attribute: builtins.str,
        index: builtins.str,
    ) -> None:
        """
        :param terraform_resource: -
        :param terraform_attribute: -
        :param index: -

        :stability: experimental
        """
        jsii.create(DataAzurermMonitorActionGroupArmRoleReceiver, self, [terraform_resource, terraform_attribute, index])

    @builtins.property # type: ignore
    @jsii.member(jsii_name="name")
    def name(self) -> builtins.str:
        return jsii.get(self, "name")

    @builtins.property # type: ignore
    @jsii.member(jsii_name="roleId")
    def role_id(self) -> builtins.str:
        return jsii.get(self, "roleId")

    @builtins.property # type: ignore
    @jsii.member(jsii_name="useCommonAlertSchema")
    def use_common_alert_schema(self) -> builtins.bool:
        return jsii.get(self, "useCommonAlertSchema")


class DataAzurermMonitorActionGroupAutomationRunbookReceiver(
    cdktf.ComplexComputedList,
    metaclass=jsii.JSIIMeta,
    jsii_type="@cdktf/provider-azurerm.DataAzurermMonitorActionGroupAutomationRunbookReceiver",
):
    def __init__(
        self,
        terraform_resource: cdktf.ITerraformResource,
        terraform_attribute: builtins.str,
        index: builtins.str,
    ) -> None:
        """
        :param terraform_resource: -
        :param terraform_attribute: -
        :param index: -

        :stability: experimental
        """
        jsii.create(DataAzurermMonitorActionGroupAutomationRunbookReceiver, self, [terraform_resource, terraform_attribute, index])

    @builtins.property # type: ignore
    @jsii.member(jsii_name="automationAccountId")
    def automation_account_id(self) -> builtins.str:
        return jsii.get(self, "automationAccountId")

    @builtins.property # type: ignore
    @jsii.member(jsii_name="isGlobalRunbook")
    def is_global_runbook(self) -> builtins.bool:
        return jsii.get(self, "isGlobalRunbook")

    @builtins.property # type: ignore
    @jsii.member(jsii_name="name")
    def name(self) -> builtins.str:
        return jsii.get(self, "name")

    @builtins.property # type: ignore
    @jsii.member(jsii_name="runbookName")
    def runbook_name(self) -> builtins.str:
        return jsii.get(self, "runbookName")

    @builtins.property # type: ignore
    @jsii.member(jsii_name="serviceUri")
    def service_uri(self) -> builtins.str:
        return jsii.get(self, "serviceUri")

    @builtins.property # type: ignore
    @jsii.member(jsii_name="useCommonAlertSchema")
    def use_common_alert_schema(self) -> builtins.bool:
        return jsii.get(self, "useCommonAlertSchema")

    @builtins.property # type: ignore
    @jsii.member(jsii_name="webhookResourceId")
    def webhook_resource_id(self) -> builtins.str:
        return jsii.get(self, "webhookResourceId")


class DataAzurermMonitorActionGroupAzureAppPushReceiver(
    cdktf.ComplexComputedList,
    metaclass=jsii.JSIIMeta,
    jsii_type="@cdktf/provider-azurerm.DataAzurermMonitorActionGroupAzureAppPushReceiver",
):
    def __init__(
        self,
        terraform_resource: cdktf.ITerraformResource,
        terraform_attribute: builtins.str,
        index: builtins.str,
    ) -> None:
        """
        :param terraform_resource: -
        :param terraform_attribute: -
        :param index: -

        :stability: experimental
        """
        jsii.create(DataAzurermMonitorActionGroupAzureAppPushReceiver, self, [terraform_resource, terraform_attribute, index])

    @builtins.property # type: ignore
    @jsii.member(jsii_name="emailAddress")
    def email_address(self) -> builtins.str:
        return jsii.get(self, "emailAddress")

    @builtins.property # type: ignore
    @jsii.member(jsii_name="name")
    def name(self) -> builtins.str:
        return jsii.get(self, "name")


class DataAzurermMonitorActionGroupAzureFunctionReceiver(
    cdktf.ComplexComputedList,
    metaclass=jsii.JSIIMeta,
    jsii_type="@cdktf/provider-azurerm.DataAzurermMonitorActionGroupAzureFunctionReceiver",
):
    def __init__(
        self,
        terraform_resource: cdktf.ITerraformResource,
        terraform_attribute: builtins.str,
        index: builtins.str,
    ) -> None:
        """
        :param terraform_resource: -
        :param terraform_attribute: -
        :param index: -

        :stability: experimental
        """
        jsii.create(DataAzurermMonitorActionGroupAzureFunctionReceiver, self, [terraform_resource, terraform_attribute, index])

    @builtins.property # type: ignore
    @jsii.member(jsii_name="functionAppResourceId")
    def function_app_resource_id(self) -> builtins.str:
        return jsii.get(self, "functionAppResourceId")

    @builtins.property # type: ignore
    @jsii.member(jsii_name="functionName")
    def function_name(self) -> builtins.str:
        return jsii.get(self, "functionName")

    @builtins.property # type: ignore
    @jsii.member(jsii_name="httpTriggerUrl")
    def http_trigger_url(self) -> builtins.str:
        return jsii.get(self, "httpTriggerUrl")

    @builtins.property # type: ignore
    @jsii.member(jsii_name="name")
    def name(self) -> builtins.str:
        return jsii.get(self, "name")

    @builtins.property # type: ignore
    @jsii.member(jsii_name="useCommonAlertSchema")
    def use_common_alert_schema(self) -> builtins.bool:
        return jsii.get(self, "useCommonAlertSchema")


@jsii.data_type(
    jsii_type="@cdktf/provider-azurerm.DataAzurermMonitorActionGroupConfig",
    jsii_struct_bases=[cdktf.TerraformMetaArguments],
    name_mapping={
        "count": "count",
        "depends_on": "dependsOn",
        "lifecycle": "lifecycle",
        "provider": "provider",
        "name": "name",
        "resource_group_name": "resourceGroupName",
        "timeouts": "timeouts",
    },
)
class DataAzurermMonitorActionGroupConfig(cdktf.TerraformMetaArguments):
    def __init__(
        self,
        *,
        count: typing.Optional[jsii.Number] = None,
        depends_on: typing.Optional[typing.List[cdktf.TerraformResource]] = None,
        lifecycle: typing.Optional[cdktf.TerraformResourceLifecycle] = None,
        provider: typing.Optional[cdktf.TerraformProvider] = None,
        name: builtins.str,
        resource_group_name: builtins.str,
        timeouts: typing.Optional["DataAzurermMonitorActionGroupTimeouts"] = None,
    ) -> None:
        """
        :param count: 
        :param depends_on: 
        :param lifecycle: 
        :param provider: 
        :param name: 
        :param resource_group_name: 
        :param timeouts: timeouts block.
        """
        if isinstance(lifecycle, dict):
            lifecycle = cdktf.TerraformResourceLifecycle(**lifecycle)
        if isinstance(timeouts, dict):
            timeouts = DataAzurermMonitorActionGroupTimeouts(**timeouts)
        self._values: typing.Dict[str, typing.Any] = {
            "name": name,
            "resource_group_name": resource_group_name,
        }
        if count is not None:
            self._values["count"] = count
        if depends_on is not None:
            self._values["depends_on"] = depends_on
        if lifecycle is not None:
            self._values["lifecycle"] = lifecycle
        if provider is not None:
            self._values["provider"] = provider
        if timeouts is not None:
            self._values["timeouts"] = timeouts

    @builtins.property
    def count(self) -> typing.Optional[jsii.Number]:
        """
        :stability: experimental
        """
        result = self._values.get("count")
        return result

    @builtins.property
    def depends_on(self) -> typing.Optional[typing.List[cdktf.TerraformResource]]:
        """
        :stability: experimental
        """
        result = self._values.get("depends_on")
        return result

    @builtins.property
    def lifecycle(self) -> typing.Optional[cdktf.TerraformResourceLifecycle]:
        """
        :stability: experimental
        """
        result = self._values.get("lifecycle")
        return result

    @builtins.property
    def provider(self) -> typing.Optional[cdktf.TerraformProvider]:
        """
        :stability: experimental
        """
        result = self._values.get("provider")
        return result

    @builtins.property
    def name(self) -> builtins.str:
        result = self._values.get("name")
        assert result is not None, "Required property 'name' is missing"
        return result

    @builtins.property
    def resource_group_name(self) -> builtins.str:
        result = self._values.get("resource_group_name")
        assert result is not None, "Required property 'resource_group_name' is missing"
        return result

    @builtins.property
    def timeouts(self) -> typing.Optional["DataAzurermMonitorActionGroupTimeouts"]:
        """timeouts block."""
        result = self._values.get("timeouts")
        return result

    def __eq__(self, rhs: typing.Any) -> builtins.bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs: typing.Any) -> builtins.bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return "DataAzurermMonitorActionGroupConfig(%s)" % ", ".join(
            k + "=" + repr(v) for k, v in self._values.items()
        )


class DataAzurermMonitorActionGroupEmailReceiver(
    cdktf.ComplexComputedList,
    metaclass=jsii.JSIIMeta,
    jsii_type="@cdktf/provider-azurerm.DataAzurermMonitorActionGroupEmailReceiver",
):
    def __init__(
        self,
        terraform_resource: cdktf.ITerraformResource,
        terraform_attribute: builtins.str,
        index: builtins.str,
    ) -> None:
        """
        :param terraform_resource: -
        :param terraform_attribute: -
        :param index: -

        :stability: experimental
        """
        jsii.create(DataAzurermMonitorActionGroupEmailReceiver, self, [terraform_resource, terraform_attribute, index])

    @builtins.property # type: ignore
    @jsii.member(jsii_name="emailAddress")
    def email_address(self) -> builtins.str:
        return jsii.get(self, "emailAddress")

    @builtins.property # type: ignore
    @jsii.member(jsii_name="name")
    def name(self) -> builtins.str:
        return jsii.get(self, "name")

    @builtins.property # type: ignore
    @jsii.member(jsii_name="useCommonAlertSchema")
    def use_common_alert_schema(self) -> builtins.bool:
        return jsii.get(self, "useCommonAlertSchema")


class DataAzurermMonitorActionGroupItsmReceiver(
    cdktf.ComplexComputedList,
    metaclass=jsii.JSIIMeta,
    jsii_type="@cdktf/provider-azurerm.DataAzurermMonitorActionGroupItsmReceiver",
):
    def __init__(
        self,
        terraform_resource: cdktf.ITerraformResource,
        terraform_attribute: builtins.str,
        index: builtins.str,
    ) -> None:
        """
        :param terraform_resource: -
        :param terraform_attribute: -
        :param index: -

        :stability: experimental
        """
        jsii.create(DataAzurermMonitorActionGroupItsmReceiver, self, [terraform_resource, terraform_attribute, index])

    @builtins.property # type: ignore
    @jsii.member(jsii_name="connectionId")
    def connection_id(self) -> builtins.str:
        return jsii.get(self, "connectionId")

    @builtins.property # type: ignore
    @jsii.member(jsii_name="name")
    def name(self) -> builtins.str:
        return jsii.get(self, "name")

    @builtins.property # type: ignore
    @jsii.member(jsii_name="region")
    def region(self) -> builtins.str:
        return jsii.get(self, "region")

    @builtins.property # type: ignore
    @jsii.member(jsii_name="ticketConfiguration")
    def ticket_configuration(self) -> builtins.str:
        return jsii.get(self, "ticketConfiguration")

    @builtins.property # type: ignore
    @jsii.member(jsii_name="workspaceId")
    def workspace_id(self) -> builtins.str:
        return jsii.get(self, "workspaceId")


class DataAzurermMonitorActionGroupLogicAppReceiver(
    cdktf.ComplexComputedList,
    metaclass=jsii.JSIIMeta,
    jsii_type="@cdktf/provider-azurerm.DataAzurermMonitorActionGroupLogicAppReceiver",
):
    def __init__(
        self,
        terraform_resource: cdktf.ITerraformResource,
        terraform_attribute: builtins.str,
        index: builtins.str,
    ) -> None:
        """
        :param terraform_resource: -
        :param terraform_attribute: -
        :param index: -

        :stability: experimental
        """
        jsii.create(DataAzurermMonitorActionGroupLogicAppReceiver, self, [terraform_resource, terraform_attribute, index])

    @builtins.property # type: ignore
    @jsii.member(jsii_name="callbackUrl")
    def callback_url(self) -> builtins.str:
        return jsii.get(self, "callbackUrl")

    @builtins.property # type: ignore
    @jsii.member(jsii_name="name")
    def name(self) -> builtins.str:
        return jsii.get(self, "name")

    @builtins.property # type: ignore
    @jsii.member(jsii_name="resourceId")
    def resource_id(self) -> builtins.str:
        return jsii.get(self, "resourceId")

    @builtins.property # type: ignore
    @jsii.member(jsii_name="useCommonAlertSchema")
    def use_common_alert_schema(self) -> builtins.bool:
        return jsii.get(self, "useCommonAlertSchema")


class DataAzurermMonitorActionGroupSmsReceiver(
    cdktf.ComplexComputedList,
    metaclass=jsii.JSIIMeta,
    jsii_type="@cdktf/provider-azurerm.DataAzurermMonitorActionGroupSmsReceiver",
):
    def __init__(
        self,
        terraform_resource: cdktf.ITerraformResource,
        terraform_attribute: builtins.str,
        index: builtins.str,
    ) -> None:
        """
        :param terraform_resource: -
        :param terraform_attribute: -
        :param index: -

        :stability: experimental
        """
        jsii.create(DataAzurermMonitorActionGroupSmsReceiver, self, [terraform_resource, terraform_attribute, index])

    @builtins.property # type: ignore
    @jsii.member(jsii_name="countryCode")
    def country_code(self) -> builtins.str:
        return jsii.get(self, "countryCode")

    @builtins.property # type: ignore
    @jsii.member(jsii_name="name")
    def name(self) -> builtins.str:
        return jsii.get(self, "name")

    @builtins.property # type: ignore
    @jsii.member(jsii_name="phoneNumber")
    def phone_number(self) -> builtins.str:
        return jsii.get(self, "phoneNumber")


@jsii.data_type(
    jsii_type="@cdktf/provider-azurerm.DataAzurermMonitorActionGroupTimeouts",
    jsii_struct_bases=[],
    name_mapping={"read": "read"},
)
class DataAzurermMonitorActionGroupTimeouts:
    def __init__(self, *, read: typing.Optional[builtins.str] = None) -> None:
        """
        :param read: 
        """
        self._values: typing.Dict[str, typing.Any] = {}
        if read is not None:
            self._values["read"] = read

    @builtins.property
    def read(self) -> typing.Optional[builtins.str]:
        result = self._values.get("read")
        return result

    def __eq__(self, rhs: typing.Any) -> builtins.bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs: typing.Any) -> builtins.bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return "DataAzurermMonitorActionGroupTimeouts(%s)" % ", ".join(
            k + "=" + repr(v) for k, v in self._values.items()
        )


class DataAzurermMonitorActionGroupVoiceReceiver(
    cdktf.ComplexComputedList,
    metaclass=jsii.JSIIMeta,
    jsii_type="@cdktf/provider-azurerm.DataAzurermMonitorActionGroupVoiceReceiver",
):
    def __init__(
        self,
        terraform_resource: cdktf.ITerraformResource,
        terraform_attribute: builtins.str,
        index: builtins.str,
    ) -> None:
        """
        :param terraform_resource: -
        :param terraform_attribute: -
        :param index: -

        :stability: experimental
        """
        jsii.create(DataAzurermMonitorActionGroupVoiceReceiver, self, [terraform_resource, terraform_attribute, index])

    @builtins.property # type: ignore
    @jsii.member(jsii_name="countryCode")
    def country_code(self) -> builtins.str:
        return jsii.get(self, "countryCode")

    @builtins.property # type: ignore
    @jsii.member(jsii_name="name")
    def name(self) -> builtins.str:
        return jsii.get(self, "name")

    @builtins.property # type: ignore
    @jsii.member(jsii_name="phoneNumber")
    def phone_number(self) -> builtins.str:
        return jsii.get(self, "phoneNumber")


class DataAzurermMonitorActionGroupWebhookReceiver(
    cdktf.ComplexComputedList,
    metaclass=jsii.JSIIMeta,
    jsii_type="@cdktf/provider-azurerm.DataAzurermMonitorActionGroupWebhookReceiver",
):
    def __init__(
        self,
        terraform_resource: cdktf.ITerraformResource,
        terraform_attribute: builtins.str,
        index: builtins.str,
    ) -> None:
        """
        :param terraform_resource: -
        :param terraform_attribute: -
        :param index: -

        :stability: experimental
        """
        jsii.create(DataAzurermMonitorActionGroupWebhookReceiver, self, [terraform_resource, terraform_attribute, index])

    @builtins.property # type: ignore
    @jsii.member(jsii_name="name")
    def name(self) -> builtins.str:
        return jsii.get(self, "name")

    @builtins.property # type: ignore
    @jsii.member(jsii_name="serviceUri")
    def service_uri(self) -> builtins.str:
        return jsii.get(self, "serviceUri")

    @builtins.property # type: ignore
    @jsii.member(jsii_name="useCommonAlertSchema")
    def use_common_alert_schema(self) -> builtins.bool:
        return jsii.get(self, "useCommonAlertSchema")


class DataAzurermMonitorDiagnosticCategories(
    cdktf.TerraformDataSource,
    metaclass=jsii.JSIIMeta,
    jsii_type="@cdktf/provider-azurerm.DataAzurermMonitorDiagnosticCategories",
):
    def __init__(
        self,
        scope: constructs.Construct,
        id: builtins.str,
        *,
        resource_id: builtins.str,
        timeouts: typing.Optional["DataAzurermMonitorDiagnosticCategoriesTimeouts"] = None,
        count: typing.Optional[jsii.Number] = None,
        depends_on: typing.Optional[typing.List[cdktf.TerraformResource]] = None,
        lifecycle: typing.Optional[cdktf.TerraformResourceLifecycle] = None,
        provider: typing.Optional[cdktf.TerraformProvider] = None,
    ) -> None:
        """
        :param scope: -
        :param id: -
        :param resource_id: 
        :param timeouts: timeouts block.
        :param count: 
        :param depends_on: 
        :param lifecycle: 
        :param provider: 
        """
        config = DataAzurermMonitorDiagnosticCategoriesConfig(
            resource_id=resource_id,
            timeouts=timeouts,
            count=count,
            depends_on=depends_on,
            lifecycle=lifecycle,
            provider=provider,
        )

        jsii.create(DataAzurermMonitorDiagnosticCategories, self, [scope, id, config])

    @jsii.member(jsii_name="synthesizeAttributes")
    def _synthesize_attributes(self) -> typing.Mapping[builtins.str, typing.Any]:
        return jsii.invoke(self, "synthesizeAttributes", [])

    @builtins.property # type: ignore
    @jsii.member(jsii_name="logs")
    def logs(self) -> typing.List[builtins.str]:
        return jsii.get(self, "logs")

    @builtins.property # type: ignore
    @jsii.member(jsii_name="metrics")
    def metrics(self) -> typing.List[builtins.str]:
        return jsii.get(self, "metrics")

    @builtins.property # type: ignore
    @jsii.member(jsii_name="resourceId")
    def resource_id(self) -> builtins.str:
        return jsii.get(self, "resourceId")

    @resource_id.setter # type: ignore
    def resource_id(self, value: builtins.str) -> None:
        jsii.set(self, "resourceId", value)

    @builtins.property # type: ignore
    @jsii.member(jsii_name="id")
    def id(self) -> typing.Optional[builtins.str]:
        return jsii.get(self, "id")

    @id.setter # type: ignore
    def id(self, value: typing.Optional[builtins.str]) -> None:
        jsii.set(self, "id", value)

    @builtins.property # type: ignore
    @jsii.member(jsii_name="timeouts")
    def timeouts(
        self,
    ) -> typing.Optional["DataAzurermMonitorDiagnosticCategoriesTimeouts"]:
        return jsii.get(self, "timeouts")

    @timeouts.setter # type: ignore
    def timeouts(
        self,
        value: typing.Optional["DataAzurermMonitorDiagnosticCategoriesTimeouts"],
    ) -> None:
        jsii.set(self, "timeouts", value)


@jsii.data_type(
    jsii_type="@cdktf/provider-azurerm.DataAzurermMonitorDiagnosticCategoriesConfig",
    jsii_struct_bases=[cdktf.TerraformMetaArguments],
    name_mapping={
        "count": "count",
        "depends_on": "dependsOn",
        "lifecycle": "lifecycle",
        "provider": "provider",
        "resource_id": "resourceId",
        "timeouts": "timeouts",
    },
)
class DataAzurermMonitorDiagnosticCategoriesConfig(cdktf.TerraformMetaArguments):
    def __init__(
        self,
        *,
        count: typing.Optional[jsii.Number] = None,
        depends_on: typing.Optional[typing.List[cdktf.TerraformResource]] = None,
        lifecycle: typing.Optional[cdktf.TerraformResourceLifecycle] = None,
        provider: typing.Optional[cdktf.TerraformProvider] = None,
        resource_id: builtins.str,
        timeouts: typing.Optional["DataAzurermMonitorDiagnosticCategoriesTimeouts"] = None,
    ) -> None:
        """
        :param count: 
        :param depends_on: 
        :param lifecycle: 
        :param provider: 
        :param resource_id: 
        :param timeouts: timeouts block.
        """
        if isinstance(lifecycle, dict):
            lifecycle = cdktf.TerraformResourceLifecycle(**lifecycle)
        if isinstance(timeouts, dict):
            timeouts = DataAzurermMonitorDiagnosticCategoriesTimeouts(**timeouts)
        self._values: typing.Dict[str, typing.Any] = {
            "resource_id": resource_id,
        }
        if count is not None:
            self._values["count"] = count
        if depends_on is not None:
            self._values["depends_on"] = depends_on
        if lifecycle is not None:
            self._values["lifecycle"] = lifecycle
        if provider is not None:
            self._values["provider"] = provider
        if timeouts is not None:
            self._values["timeouts"] = timeouts

    @builtins.property
    def count(self) -> typing.Optional[jsii.Number]:
        """
        :stability: experimental
        """
        result = self._values.get("count")
        return result

    @builtins.property
    def depends_on(self) -> typing.Optional[typing.List[cdktf.TerraformResource]]:
        """
        :stability: experimental
        """
        result = self._values.get("depends_on")
        return result

    @builtins.property
    def lifecycle(self) -> typing.Optional[cdktf.TerraformResourceLifecycle]:
        """
        :stability: experimental
        """
        result = self._values.get("lifecycle")
        return result

    @builtins.property
    def provider(self) -> typing.Optional[cdktf.TerraformProvider]:
        """
        :stability: experimental
        """
        result = self._values.get("provider")
        return result

    @builtins.property
    def resource_id(self) -> builtins.str:
        result = self._values.get("resource_id")
        assert result is not None, "Required property 'resource_id' is missing"
        return result

    @builtins.property
    def timeouts(
        self,
    ) -> typing.Optional["DataAzurermMonitorDiagnosticCategoriesTimeouts"]:
        """timeouts block."""
        result = self._values.get("timeouts")
        return result

    def __eq__(self, rhs: typing.Any) -> builtins.bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs: typing.Any) -> builtins.bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return "DataAzurermMonitorDiagnosticCategoriesConfig(%s)" % ", ".join(
            k + "=" + repr(v) for k, v in self._values.items()
        )


@jsii.data_type(
    jsii_type="@cdktf/provider-azurerm.DataAzurermMonitorDiagnosticCategoriesTimeouts",
    jsii_struct_bases=[],
    name_mapping={"read": "read"},
)
class DataAzurermMonitorDiagnosticCategoriesTimeouts:
    def __init__(self, *, read: typing.Optional[builtins.str] = None) -> None:
        """
        :param read: 
        """
        self._values: typing.Dict[str, typing.Any] = {}
        if read is not None:
            self._values["read"] = read

    @builtins.property
    def read(self) -> typing.Optional[builtins.str]:
        result = self._values.get("read")
        return result

    def __eq__(self, rhs: typing.Any) -> builtins.bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs: typing.Any) -> builtins.bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return "DataAzurermMonitorDiagnosticCategoriesTimeouts(%s)" % ", ".join(
            k + "=" + repr(v) for k, v in self._values.items()
        )


class DataAzurermMonitorLogProfile(
    cdktf.TerraformDataSource,
    metaclass=jsii.JSIIMeta,
    jsii_type="@cdktf/provider-azurerm.DataAzurermMonitorLogProfile",
):
    def __init__(
        self,
        scope: constructs.Construct,
        id: builtins.str,
        *,
        name: builtins.str,
        timeouts: typing.Optional["DataAzurermMonitorLogProfileTimeouts"] = None,
        count: typing.Optional[jsii.Number] = None,
        depends_on: typing.Optional[typing.List[cdktf.TerraformResource]] = None,
        lifecycle: typing.Optional[cdktf.TerraformResourceLifecycle] = None,
        provider: typing.Optional[cdktf.TerraformProvider] = None,
    ) -> None:
        """
        :param scope: -
        :param id: -
        :param name: 
        :param timeouts: timeouts block.
        :param count: 
        :param depends_on: 
        :param lifecycle: 
        :param provider: 
        """
        config = DataAzurermMonitorLogProfileConfig(
            name=name,
            timeouts=timeouts,
            count=count,
            depends_on=depends_on,
            lifecycle=lifecycle,
            provider=provider,
        )

        jsii.create(DataAzurermMonitorLogProfile, self, [scope, id, config])

    @jsii.member(jsii_name="retentionPolicy")
    def retention_policy(
        self,
        index: builtins.str,
    ) -> "DataAzurermMonitorLogProfileRetentionPolicy":
        """
        :param index: -
        """
        return jsii.invoke(self, "retentionPolicy", [index])

    @jsii.member(jsii_name="synthesizeAttributes")
    def _synthesize_attributes(self) -> typing.Mapping[builtins.str, typing.Any]:
        return jsii.invoke(self, "synthesizeAttributes", [])

    @builtins.property # type: ignore
    @jsii.member(jsii_name="categories")
    def categories(self) -> typing.List[builtins.str]:
        return jsii.get(self, "categories")

    @builtins.property # type: ignore
    @jsii.member(jsii_name="locations")
    def locations(self) -> typing.List[builtins.str]:
        return jsii.get(self, "locations")

    @builtins.property # type: ignore
    @jsii.member(jsii_name="servicebusRuleId")
    def servicebus_rule_id(self) -> builtins.str:
        return jsii.get(self, "servicebusRuleId")

    @builtins.property # type: ignore
    @jsii.member(jsii_name="storageAccountId")
    def storage_account_id(self) -> builtins.str:
        return jsii.get(self, "storageAccountId")

    @builtins.property # type: ignore
    @jsii.member(jsii_name="name")
    def name(self) -> builtins.str:
        return jsii.get(self, "name")

    @name.setter # type: ignore
    def name(self, value: builtins.str) -> None:
        jsii.set(self, "name", value)

    @builtins.property # type: ignore
    @jsii.member(jsii_name="id")
    def id(self) -> typing.Optional[builtins.str]:
        return jsii.get(self, "id")

    @id.setter # type: ignore
    def id(self, value: typing.Optional[builtins.str]) -> None:
        jsii.set(self, "id", value)

    @builtins.property # type: ignore
    @jsii.member(jsii_name="timeouts")
    def timeouts(self) -> typing.Optional["DataAzurermMonitorLogProfileTimeouts"]:
        return jsii.get(self, "timeouts")

    @timeouts.setter # type: ignore
    def timeouts(
        self,
        value: typing.Optional["DataAzurermMonitorLogProfileTimeouts"],
    ) -> None:
        jsii.set(self, "timeouts", value)


@jsii.data_type(
    jsii_type="@cdktf/provider-azurerm.DataAzurermMonitorLogProfileConfig",
    jsii_struct_bases=[cdktf.TerraformMetaArguments],
    name_mapping={
        "count": "count",
        "depends_on": "dependsOn",
        "lifecycle": "lifecycle",
        "provider": "provider",
        "name": "name",
        "timeouts": "timeouts",
    },
)
class DataAzurermMonitorLogProfileConfig(cdktf.TerraformMetaArguments):
    def __init__(
        self,
        *,
        count: typing.Optional[jsii.Number] = None,
        depends_on: typing.Optional[typing.List[cdktf.TerraformResource]] = None,
        lifecycle: typing.Optional[cdktf.TerraformResourceLifecycle] = None,
        provider: typing.Optional[cdktf.TerraformProvider] = None,
        name: builtins.str,
        timeouts: typing.Optional["DataAzurermMonitorLogProfileTimeouts"] = None,
    ) -> None:
        """
        :param count: 
        :param depends_on: 
        :param lifecycle: 
        :param provider: 
        :param name: 
        :param timeouts: timeouts block.
        """
        if isinstance(lifecycle, dict):
            lifecycle = cdktf.TerraformResourceLifecycle(**lifecycle)
        if isinstance(timeouts, dict):
            timeouts = DataAzurermMonitorLogProfileTimeouts(**timeouts)
        self._values: typing.Dict[str, typing.Any] = {
            "name": name,
        }
        if count is not None:
            self._values["count"] = count
        if depends_on is not None:
            self._values["depends_on"] = depends_on
        if lifecycle is not None:
            self._values["lifecycle"] = lifecycle
        if provider is not None:
            self._values["provider"] = provider
        if timeouts is not None:
            self._values["timeouts"] = timeouts

    @builtins.property
    def count(self) -> typing.Optional[jsii.Number]:
        """
        :stability: experimental
        """
        result = self._values.get("count")
        return result

    @builtins.property
    def depends_on(self) -> typing.Optional[typing.List[cdktf.TerraformResource]]:
        """
        :stability: experimental
        """
        result = self._values.get("depends_on")
        return result

    @builtins.property
    def lifecycle(self) -> typing.Optional[cdktf.TerraformResourceLifecycle]:
        """
        :stability: experimental
        """
        result = self._values.get("lifecycle")
        return result

    @builtins.property
    def provider(self) -> typing.Optional[cdktf.TerraformProvider]:
        """
        :stability: experimental
        """
        result = self._values.get("provider")
        return result

    @builtins.property
    def name(self) -> builtins.str:
        result = self._values.get("name")
        assert result is not None, "Required property 'name' is missing"
        return result

    @builtins.property
    def timeouts(self) -> typing.Optional["DataAzurermMonitorLogProfileTimeouts"]:
        """timeouts block."""
        result = self._values.get("timeouts")
        return result

    def __eq__(self, rhs: typing.Any) -> builtins.bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs: typing.Any) -> builtins.bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return "DataAzurermMonitorLogProfileConfig(%s)" % ", ".join(
            k + "=" + repr(v) for k, v in self._values.items()
        )


class DataAzurermMonitorLogProfileRetentionPolicy(
    cdktf.ComplexComputedList,
    metaclass=jsii.JSIIMeta,
    jsii_type="@cdktf/provider-azurerm.DataAzurermMonitorLogProfileRetentionPolicy",
):
    def __init__(
        self,
        terraform_resource: cdktf.ITerraformResource,
        terraform_attribute: builtins.str,
        index: builtins.str,
    ) -> None:
        """
        :param terraform_resource: -
        :param terraform_attribute: -
        :param index: -

        :stability: experimental
        """
        jsii.create(DataAzurermMonitorLogProfileRetentionPolicy, self, [terraform_resource, terraform_attribute, index])

    @builtins.property # type: ignore
    @jsii.member(jsii_name="days")
    def days(self) -> jsii.Number:
        return jsii.get(self, "days")

    @builtins.property # type: ignore
    @jsii.member(jsii_name="enabled")
    def enabled(self) -> builtins.bool:
        return jsii.get(self, "enabled")


@jsii.data_type(
    jsii_type="@cdktf/provider-azurerm.DataAzurermMonitorLogProfileTimeouts",
    jsii_struct_bases=[],
    name_mapping={"read": "read"},
)
class DataAzurermMonitorLogProfileTimeouts:
    def __init__(self, *, read: typing.Optional[builtins.str] = None) -> None:
        """
        :param read: 
        """
        self._values: typing.Dict[str, typing.Any] = {}
        if read is not None:
            self._values["read"] = read

    @builtins.property
    def read(self) -> typing.Optional[builtins.str]:
        result = self._values.get("read")
        return result

    def __eq__(self, rhs: typing.Any) -> builtins.bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs: typing.Any) -> builtins.bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return "DataAzurermMonitorLogProfileTimeouts(%s)" % ", ".join(
            k + "=" + repr(v) for k, v in self._values.items()
        )


class DataAzurermMssqlElasticpool(
    cdktf.TerraformDataSource,
    metaclass=jsii.JSIIMeta,
    jsii_type="@cdktf/provider-azurerm.DataAzurermMssqlElasticpool",
):
    def __init__(
        self,
        scope: constructs.Construct,
        id: builtins.str,
        *,
        name: builtins.str,
        resource_group_name: builtins.str,
        server_name: builtins.str,
        timeouts: typing.Optional["DataAzurermMssqlElasticpoolTimeouts"] = None,
        count: typing.Optional[jsii.Number] = None,
        depends_on: typing.Optional[typing.List[cdktf.TerraformResource]] = None,
        lifecycle: typing.Optional[cdktf.TerraformResourceLifecycle] = None,
        provider: typing.Optional[cdktf.TerraformProvider] = None,
    ) -> None:
        """
        :param scope: -
        :param id: -
        :param name: 
        :param resource_group_name: 
        :param server_name: 
        :param timeouts: timeouts block.
        :param count: 
        :param depends_on: 
        :param lifecycle: 
        :param provider: 
        """
        config = DataAzurermMssqlElasticpoolConfig(
            name=name,
            resource_group_name=resource_group_name,
            server_name=server_name,
            timeouts=timeouts,
            count=count,
            depends_on=depends_on,
            lifecycle=lifecycle,
            provider=provider,
        )

        jsii.create(DataAzurermMssqlElasticpool, self, [scope, id, config])

    @jsii.member(jsii_name="synthesizeAttributes")
    def _synthesize_attributes(self) -> typing.Mapping[builtins.str, typing.Any]:
        return jsii.invoke(self, "synthesizeAttributes", [])

    @jsii.member(jsii_name="tags")
    def tags(self, key: builtins.str) -> builtins.str:
        """
        :param key: -
        """
        return jsii.invoke(self, "tags", [key])

    @builtins.property # type: ignore
    @jsii.member(jsii_name="location")
    def location(self) -> builtins.str:
        return jsii.get(self, "location")

    @builtins.property # type: ignore
    @jsii.member(jsii_name="maxSizeBytes")
    def max_size_bytes(self) -> jsii.Number:
        return jsii.get(self, "maxSizeBytes")

    @builtins.property # type: ignore
    @jsii.member(jsii_name="maxSizeGb")
    def max_size_gb(self) -> jsii.Number:
        return jsii.get(self, "maxSizeGb")

    @builtins.property # type: ignore
    @jsii.member(jsii_name="perDbMaxCapacity")
    def per_db_max_capacity(self) -> jsii.Number:
        return jsii.get(self, "perDbMaxCapacity")

    @builtins.property # type: ignore
    @jsii.member(jsii_name="perDbMinCapacity")
    def per_db_min_capacity(self) -> jsii.Number:
        return jsii.get(self, "perDbMinCapacity")

    @builtins.property # type: ignore
    @jsii.member(jsii_name="zoneRedundant")
    def zone_redundant(self) -> builtins.bool:
        return jsii.get(self, "zoneRedundant")

    @builtins.property # type: ignore
    @jsii.member(jsii_name="name")
    def name(self) -> builtins.str:
        return jsii.get(self, "name")

    @name.setter # type: ignore
    def name(self, value: builtins.str) -> None:
        jsii.set(self, "name", value)

    @builtins.property # type: ignore
    @jsii.member(jsii_name="resourceGroupName")
    def resource_group_name(self) -> builtins.str:
        return jsii.get(self, "resourceGroupName")

    @resource_group_name.setter # type: ignore
    def resource_group_name(self, value: builtins.str) -> None:
        jsii.set(self, "resourceGroupName", value)

    @builtins.property # type: ignore
    @jsii.member(jsii_name="serverName")
    def server_name(self) -> builtins.str:
        return jsii.get(self, "serverName")

    @server_name.setter # type: ignore
    def server_name(self, value: builtins.str) -> None:
        jsii.set(self, "serverName", value)

    @builtins.property # type: ignore
    @jsii.member(jsii_name="id")
    def id(self) -> typing.Optional[builtins.str]:
        return jsii.get(self, "id")

    @id.setter # type: ignore
    def id(self, value: typing.Optional[builtins.str]) -> None:
        jsii.set(self, "id", value)

    @builtins.property # type: ignore
    @jsii.member(jsii_name="timeouts")
    def timeouts(self) -> typing.Optional["DataAzurermMssqlElasticpoolTimeouts"]:
        return jsii.get(self, "timeouts")

    @timeouts.setter # type: ignore
    def timeouts(
        self,
        value: typing.Optional["DataAzurermMssqlElasticpoolTimeouts"],
    ) -> None:
        jsii.set(self, "timeouts", value)


@jsii.data_type(
    jsii_type="@cdktf/provider-azurerm.DataAzurermMssqlElasticpoolConfig",
    jsii_struct_bases=[cdktf.TerraformMetaArguments],
    name_mapping={
        "count": "count",
        "depends_on": "dependsOn",
        "lifecycle": "lifecycle",
        "provider": "provider",
        "name": "name",
        "resource_group_name": "resourceGroupName",
        "server_name": "serverName",
        "timeouts": "timeouts",
    },
)
class DataAzurermMssqlElasticpoolConfig(cdktf.TerraformMetaArguments):
    def __init__(
        self,
        *,
        count: typing.Optional[jsii.Number] = None,
        depends_on: typing.Optional[typing.List[cdktf.TerraformResource]] = None,
        lifecycle: typing.Optional[cdktf.TerraformResourceLifecycle] = None,
        provider: typing.Optional[cdktf.TerraformProvider] = None,
        name: builtins.str,
        resource_group_name: builtins.str,
        server_name: builtins.str,
        timeouts: typing.Optional["DataAzurermMssqlElasticpoolTimeouts"] = None,
    ) -> None:
        """
        :param count: 
        :param depends_on: 
        :param lifecycle: 
        :param provider: 
        :param name: 
        :param resource_group_name: 
        :param server_name: 
        :param timeouts: timeouts block.
        """
        if isinstance(lifecycle, dict):
            lifecycle = cdktf.TerraformResourceLifecycle(**lifecycle)
        if isinstance(timeouts, dict):
            timeouts = DataAzurermMssqlElasticpoolTimeouts(**timeouts)
        self._values: typing.Dict[str, typing.Any] = {
            "name": name,
            "resource_group_name": resource_group_name,
            "server_name": server_name,
        }
        if count is not None:
            self._values["count"] = count
        if depends_on is not None:
            self._values["depends_on"] = depends_on
        if lifecycle is not None:
            self._values["lifecycle"] = lifecycle
        if provider is not None:
            self._values["provider"] = provider
        if timeouts is not None:
            self._values["timeouts"] = timeouts

    @builtins.property
    def count(self) -> typing.Optional[jsii.Number]:
        """
        :stability: experimental
        """
        result = self._values.get("count")
        return result

    @builtins.property
    def depends_on(self) -> typing.Optional[typing.List[cdktf.TerraformResource]]:
        """
        :stability: experimental
        """
        result = self._values.get("depends_on")
        return result

    @builtins.property
    def lifecycle(self) -> typing.Optional[cdktf.TerraformResourceLifecycle]:
        """
        :stability: experimental
        """
        result = self._values.get("lifecycle")
        return result

    @builtins.property
    def provider(self) -> typing.Optional[cdktf.TerraformProvider]:
        """
        :stability: experimental
        """
        result = self._values.get("provider")
        return result

    @builtins.property
    def name(self) -> builtins.str:
        result = self._values.get("name")
        assert result is not None, "Required property 'name' is missing"
        return result

    @builtins.property
    def resource_group_name(self) -> builtins.str:
        result = self._values.get("resource_group_name")
        assert result is not None, "Required property 'resource_group_name' is missing"
        return result

    @builtins.property
    def server_name(self) -> builtins.str:
        result = self._values.get("server_name")
        assert result is not None, "Required property 'server_name' is missing"
        return result

    @builtins.property
    def timeouts(self) -> typing.Optional["DataAzurermMssqlElasticpoolTimeouts"]:
        """timeouts block."""
        result = self._values.get("timeouts")
        return result

    def __eq__(self, rhs: typing.Any) -> builtins.bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs: typing.Any) -> builtins.bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return "DataAzurermMssqlElasticpoolConfig(%s)" % ", ".join(
            k + "=" + repr(v) for k, v in self._values.items()
        )


@jsii.data_type(
    jsii_type="@cdktf/provider-azurerm.DataAzurermMssqlElasticpoolTimeouts",
    jsii_struct_bases=[],
    name_mapping={"read": "read"},
)
class DataAzurermMssqlElasticpoolTimeouts:
    def __init__(self, *, read: typing.Optional[builtins.str] = None) -> None:
        """
        :param read: 
        """
        self._values: typing.Dict[str, typing.Any] = {}
        if read is not None:
            self._values["read"] = read

    @builtins.property
    def read(self) -> typing.Optional[builtins.str]:
        result = self._values.get("read")
        return result

    def __eq__(self, rhs: typing.Any) -> builtins.bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs: typing.Any) -> builtins.bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return "DataAzurermMssqlElasticpoolTimeouts(%s)" % ", ".join(
            k + "=" + repr(v) for k, v in self._values.items()
        )


class DataAzurermNatGateway(
    cdktf.TerraformDataSource,
    metaclass=jsii.JSIIMeta,
    jsii_type="@cdktf/provider-azurerm.DataAzurermNatGateway",
):
    def __init__(
        self,
        scope: constructs.Construct,
        id: builtins.str,
        *,
        name: builtins.str,
        resource_group_name: builtins.str,
        public_ip_address_ids: typing.Optional[typing.List[builtins.str]] = None,
        public_ip_prefix_ids: typing.Optional[typing.List[builtins.str]] = None,
        timeouts: typing.Optional["DataAzurermNatGatewayTimeouts"] = None,
        count: typing.Optional[jsii.Number] = None,
        depends_on: typing.Optional[typing.List[cdktf.TerraformResource]] = None,
        lifecycle: typing.Optional[cdktf.TerraformResourceLifecycle] = None,
        provider: typing.Optional[cdktf.TerraformProvider] = None,
    ) -> None:
        """
        :param scope: -
        :param id: -
        :param name: 
        :param resource_group_name: 
        :param public_ip_address_ids: 
        :param public_ip_prefix_ids: 
        :param timeouts: timeouts block.
        :param count: 
        :param depends_on: 
        :param lifecycle: 
        :param provider: 
        """
        config = DataAzurermNatGatewayConfig(
            name=name,
            resource_group_name=resource_group_name,
            public_ip_address_ids=public_ip_address_ids,
            public_ip_prefix_ids=public_ip_prefix_ids,
            timeouts=timeouts,
            count=count,
            depends_on=depends_on,
            lifecycle=lifecycle,
            provider=provider,
        )

        jsii.create(DataAzurermNatGateway, self, [scope, id, config])

    @jsii.member(jsii_name="synthesizeAttributes")
    def _synthesize_attributes(self) -> typing.Mapping[builtins.str, typing.Any]:
        return jsii.invoke(self, "synthesizeAttributes", [])

    @jsii.member(jsii_name="tags")
    def tags(self, key: builtins.str) -> builtins.str:
        """
        :param key: -
        """
        return jsii.invoke(self, "tags", [key])

    @builtins.property # type: ignore
    @jsii.member(jsii_name="idleTimeoutInMinutes")
    def idle_timeout_in_minutes(self) -> jsii.Number:
        return jsii.get(self, "idleTimeoutInMinutes")

    @builtins.property # type: ignore
    @jsii.member(jsii_name="location")
    def location(self) -> builtins.str:
        return jsii.get(self, "location")

    @builtins.property # type: ignore
    @jsii.member(jsii_name="resourceGuid")
    def resource_guid(self) -> builtins.str:
        return jsii.get(self, "resourceGuid")

    @builtins.property # type: ignore
    @jsii.member(jsii_name="skuName")
    def sku_name(self) -> builtins.str:
        return jsii.get(self, "skuName")

    @builtins.property # type: ignore
    @jsii.member(jsii_name="zones")
    def zones(self) -> typing.List[builtins.str]:
        return jsii.get(self, "zones")

    @builtins.property # type: ignore
    @jsii.member(jsii_name="name")
    def name(self) -> builtins.str:
        return jsii.get(self, "name")

    @name.setter # type: ignore
    def name(self, value: builtins.str) -> None:
        jsii.set(self, "name", value)

    @builtins.property # type: ignore
    @jsii.member(jsii_name="resourceGroupName")
    def resource_group_name(self) -> builtins.str:
        return jsii.get(self, "resourceGroupName")

    @resource_group_name.setter # type: ignore
    def resource_group_name(self, value: builtins.str) -> None:
        jsii.set(self, "resourceGroupName", value)

    @builtins.property # type: ignore
    @jsii.member(jsii_name="id")
    def id(self) -> typing.Optional[builtins.str]:
        return jsii.get(self, "id")

    @id.setter # type: ignore
    def id(self, value: typing.Optional[builtins.str]) -> None:
        jsii.set(self, "id", value)

    @builtins.property # type: ignore
    @jsii.member(jsii_name="publicIpAddressIds")
    def public_ip_address_ids(self) -> typing.Optional[typing.List[builtins.str]]:
        return jsii.get(self, "publicIpAddressIds")

    @public_ip_address_ids.setter # type: ignore
    def public_ip_address_ids(
        self,
        value: typing.Optional[typing.List[builtins.str]],
    ) -> None:
        jsii.set(self, "publicIpAddressIds", value)

    @builtins.property # type: ignore
    @jsii.member(jsii_name="publicIpPrefixIds")
    def public_ip_prefix_ids(self) -> typing.Optional[typing.List[builtins.str]]:
        return jsii.get(self, "publicIpPrefixIds")

    @public_ip_prefix_ids.setter # type: ignore
    def public_ip_prefix_ids(
        self,
        value: typing.Optional[typing.List[builtins.str]],
    ) -> None:
        jsii.set(self, "publicIpPrefixIds", value)

    @builtins.property # type: ignore
    @jsii.member(jsii_name="timeouts")
    def timeouts(self) -> typing.Optional["DataAzurermNatGatewayTimeouts"]:
        return jsii.get(self, "timeouts")

    @timeouts.setter # type: ignore
    def timeouts(self, value: typing.Optional["DataAzurermNatGatewayTimeouts"]) -> None:
        jsii.set(self, "timeouts", value)


@jsii.data_type(
    jsii_type="@cdktf/provider-azurerm.DataAzurermNatGatewayConfig",
    jsii_struct_bases=[cdktf.TerraformMetaArguments],
    name_mapping={
        "count": "count",
        "depends_on": "dependsOn",
        "lifecycle": "lifecycle",
        "provider": "provider",
        "name": "name",
        "resource_group_name": "resourceGroupName",
        "public_ip_address_ids": "publicIpAddressIds",
        "public_ip_prefix_ids": "publicIpPrefixIds",
        "timeouts": "timeouts",
    },
)
class DataAzurermNatGatewayConfig(cdktf.TerraformMetaArguments):
    def __init__(
        self,
        *,
        count: typing.Optional[jsii.Number] = None,
        depends_on: typing.Optional[typing.List[cdktf.TerraformResource]] = None,
        lifecycle: typing.Optional[cdktf.TerraformResourceLifecycle] = None,
        provider: typing.Optional[cdktf.TerraformProvider] = None,
        name: builtins.str,
        resource_group_name: builtins.str,
        public_ip_address_ids: typing.Optional[typing.List[builtins.str]] = None,
        public_ip_prefix_ids: typing.Optional[typing.List[builtins.str]] = None,
        timeouts: typing.Optional["DataAzurermNatGatewayTimeouts"] = None,
    ) -> None:
        """
        :param count: 
        :param depends_on: 
        :param lifecycle: 
        :param provider: 
        :param name: 
        :param resource_group_name: 
        :param public_ip_address_ids: 
        :param public_ip_prefix_ids: 
        :param timeouts: timeouts block.
        """
        if isinstance(lifecycle, dict):
            lifecycle = cdktf.TerraformResourceLifecycle(**lifecycle)
        if isinstance(timeouts, dict):
            timeouts = DataAzurermNatGatewayTimeouts(**timeouts)
        self._values: typing.Dict[str, typing.Any] = {
            "name": name,
            "resource_group_name": resource_group_name,
        }
        if count is not None:
            self._values["count"] = count
        if depends_on is not None:
            self._values["depends_on"] = depends_on
        if lifecycle is not None:
            self._values["lifecycle"] = lifecycle
        if provider is not None:
            self._values["provider"] = provider
        if public_ip_address_ids is not None:
            self._values["public_ip_address_ids"] = public_ip_address_ids
        if public_ip_prefix_ids is not None:
            self._values["public_ip_prefix_ids"] = public_ip_prefix_ids
        if timeouts is not None:
            self._values["timeouts"] = timeouts

    @builtins.property
    def count(self) -> typing.Optional[jsii.Number]:
        """
        :stability: experimental
        """
        result = self._values.get("count")
        return result

    @builtins.property
    def depends_on(self) -> typing.Optional[typing.List[cdktf.TerraformResource]]:
        """
        :stability: experimental
        """
        result = self._values.get("depends_on")
        return result

    @builtins.property
    def lifecycle(self) -> typing.Optional[cdktf.TerraformResourceLifecycle]:
        """
        :stability: experimental
        """
        result = self._values.get("lifecycle")
        return result

    @builtins.property
    def provider(self) -> typing.Optional[cdktf.TerraformProvider]:
        """
        :stability: experimental
        """
        result = self._values.get("provider")
        return result

    @builtins.property
    def name(self) -> builtins.str:
        result = self._values.get("name")
        assert result is not None, "Required property 'name' is missing"
        return result

    @builtins.property
    def resource_group_name(self) -> builtins.str:
        result = self._values.get("resource_group_name")
        assert result is not None, "Required property 'resource_group_name' is missing"
        return result

    @builtins.property
    def public_ip_address_ids(self) -> typing.Optional[typing.List[builtins.str]]:
        result = self._values.get("public_ip_address_ids")
        return result

    @builtins.property
    def public_ip_prefix_ids(self) -> typing.Optional[typing.List[builtins.str]]:
        result = self._values.get("public_ip_prefix_ids")
        return result

    @builtins.property
    def timeouts(self) -> typing.Optional["DataAzurermNatGatewayTimeouts"]:
        """timeouts block."""
        result = self._values.get("timeouts")
        return result

    def __eq__(self, rhs: typing.Any) -> builtins.bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs: typing.Any) -> builtins.bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return "DataAzurermNatGatewayConfig(%s)" % ", ".join(
            k + "=" + repr(v) for k, v in self._values.items()
        )


@jsii.data_type(
    jsii_type="@cdktf/provider-azurerm.DataAzurermNatGatewayTimeouts",
    jsii_struct_bases=[],
    name_mapping={"read": "read"},
)
class DataAzurermNatGatewayTimeouts:
    def __init__(self, *, read: typing.Optional[builtins.str] = None) -> None:
        """
        :param read: 
        """
        self._values: typing.Dict[str, typing.Any] = {}
        if read is not None:
            self._values["read"] = read

    @builtins.property
    def read(self) -> typing.Optional[builtins.str]:
        result = self._values.get("read")
        return result

    def __eq__(self, rhs: typing.Any) -> builtins.bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs: typing.Any) -> builtins.bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return "DataAzurermNatGatewayTimeouts(%s)" % ", ".join(
            k + "=" + repr(v) for k, v in self._values.items()
        )


class DataAzurermNetappAccount(
    cdktf.TerraformDataSource,
    metaclass=jsii.JSIIMeta,
    jsii_type="@cdktf/provider-azurerm.DataAzurermNetappAccount",
):
    def __init__(
        self,
        scope: constructs.Construct,
        id: builtins.str,
        *,
        name: builtins.str,
        resource_group_name: builtins.str,
        timeouts: typing.Optional["DataAzurermNetappAccountTimeouts"] = None,
        count: typing.Optional[jsii.Number] = None,
        depends_on: typing.Optional[typing.List[cdktf.TerraformResource]] = None,
        lifecycle: typing.Optional[cdktf.TerraformResourceLifecycle] = None,
        provider: typing.Optional[cdktf.TerraformProvider] = None,
    ) -> None:
        """
        :param scope: -
        :param id: -
        :param name: 
        :param resource_group_name: 
        :param timeouts: timeouts block.
        :param count: 
        :param depends_on: 
        :param lifecycle: 
        :param provider: 
        """
        config = DataAzurermNetappAccountConfig(
            name=name,
            resource_group_name=resource_group_name,
            timeouts=timeouts,
            count=count,
            depends_on=depends_on,
            lifecycle=lifecycle,
            provider=provider,
        )

        jsii.create(DataAzurermNetappAccount, self, [scope, id, config])

    @jsii.member(jsii_name="synthesizeAttributes")
    def _synthesize_attributes(self) -> typing.Mapping[builtins.str, typing.Any]:
        return jsii.invoke(self, "synthesizeAttributes", [])

    @builtins.property # type: ignore
    @jsii.member(jsii_name="location")
    def location(self) -> builtins.str:
        return jsii.get(self, "location")

    @builtins.property # type: ignore
    @jsii.member(jsii_name="name")
    def name(self) -> builtins.str:
        return jsii.get(self, "name")

    @name.setter # type: ignore
    def name(self, value: builtins.str) -> None:
        jsii.set(self, "name", value)

    @builtins.property # type: ignore
    @jsii.member(jsii_name="resourceGroupName")
    def resource_group_name(self) -> builtins.str:
        return jsii.get(self, "resourceGroupName")

    @resource_group_name.setter # type: ignore
    def resource_group_name(self, value: builtins.str) -> None:
        jsii.set(self, "resourceGroupName", value)

    @builtins.property # type: ignore
    @jsii.member(jsii_name="id")
    def id(self) -> typing.Optional[builtins.str]:
        return jsii.get(self, "id")

    @id.setter # type: ignore
    def id(self, value: typing.Optional[builtins.str]) -> None:
        jsii.set(self, "id", value)

    @builtins.property # type: ignore
    @jsii.member(jsii_name="timeouts")
    def timeouts(self) -> typing.Optional["DataAzurermNetappAccountTimeouts"]:
        return jsii.get(self, "timeouts")

    @timeouts.setter # type: ignore
    def timeouts(
        self,
        value: typing.Optional["DataAzurermNetappAccountTimeouts"],
    ) -> None:
        jsii.set(self, "timeouts", value)


@jsii.data_type(
    jsii_type="@cdktf/provider-azurerm.DataAzurermNetappAccountConfig",
    jsii_struct_bases=[cdktf.TerraformMetaArguments],
    name_mapping={
        "count": "count",
        "depends_on": "dependsOn",
        "lifecycle": "lifecycle",
        "provider": "provider",
        "name": "name",
        "resource_group_name": "resourceGroupName",
        "timeouts": "timeouts",
    },
)
class DataAzurermNetappAccountConfig(cdktf.TerraformMetaArguments):
    def __init__(
        self,
        *,
        count: typing.Optional[jsii.Number] = None,
        depends_on: typing.Optional[typing.List[cdktf.TerraformResource]] = None,
        lifecycle: typing.Optional[cdktf.TerraformResourceLifecycle] = None,
        provider: typing.Optional[cdktf.TerraformProvider] = None,
        name: builtins.str,
        resource_group_name: builtins.str,
        timeouts: typing.Optional["DataAzurermNetappAccountTimeouts"] = None,
    ) -> None:
        """
        :param count: 
        :param depends_on: 
        :param lifecycle: 
        :param provider: 
        :param name: 
        :param resource_group_name: 
        :param timeouts: timeouts block.
        """
        if isinstance(lifecycle, dict):
            lifecycle = cdktf.TerraformResourceLifecycle(**lifecycle)
        if isinstance(timeouts, dict):
            timeouts = DataAzurermNetappAccountTimeouts(**timeouts)
        self._values: typing.Dict[str, typing.Any] = {
            "name": name,
            "resource_group_name": resource_group_name,
        }
        if count is not None:
            self._values["count"] = count
        if depends_on is not None:
            self._values["depends_on"] = depends_on
        if lifecycle is not None:
            self._values["lifecycle"] = lifecycle
        if provider is not None:
            self._values["provider"] = provider
        if timeouts is not None:
            self._values["timeouts"] = timeouts

    @builtins.property
    def count(self) -> typing.Optional[jsii.Number]:
        """
        :stability: experimental
        """
        result = self._values.get("count")
        return result

    @builtins.property
    def depends_on(self) -> typing.Optional[typing.List[cdktf.TerraformResource]]:
        """
        :stability: experimental
        """
        result = self._values.get("depends_on")
        return result

    @builtins.property
    def lifecycle(self) -> typing.Optional[cdktf.TerraformResourceLifecycle]:
        """
        :stability: experimental
        """
        result = self._values.get("lifecycle")
        return result

    @builtins.property
    def provider(self) -> typing.Optional[cdktf.TerraformProvider]:
        """
        :stability: experimental
        """
        result = self._values.get("provider")
        return result

    @builtins.property
    def name(self) -> builtins.str:
        result = self._values.get("name")
        assert result is not None, "Required property 'name' is missing"
        return result

    @builtins.property
    def resource_group_name(self) -> builtins.str:
        result = self._values.get("resource_group_name")
        assert result is not None, "Required property 'resource_group_name' is missing"
        return result

    @builtins.property
    def timeouts(self) -> typing.Optional["DataAzurermNetappAccountTimeouts"]:
        """timeouts block."""
        result = self._values.get("timeouts")
        return result

    def __eq__(self, rhs: typing.Any) -> builtins.bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs: typing.Any) -> builtins.bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return "DataAzurermNetappAccountConfig(%s)" % ", ".join(
            k + "=" + repr(v) for k, v in self._values.items()
        )


@jsii.data_type(
    jsii_type="@cdktf/provider-azurerm.DataAzurermNetappAccountTimeouts",
    jsii_struct_bases=[],
    name_mapping={"read": "read"},
)
class DataAzurermNetappAccountTimeouts:
    def __init__(self, *, read: typing.Optional[builtins.str] = None) -> None:
        """
        :param read: 
        """
        self._values: typing.Dict[str, typing.Any] = {}
        if read is not None:
            self._values["read"] = read

    @builtins.property
    def read(self) -> typing.Optional[builtins.str]:
        result = self._values.get("read")
        return result

    def __eq__(self, rhs: typing.Any) -> builtins.bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs: typing.Any) -> builtins.bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return "DataAzurermNetappAccountTimeouts(%s)" % ", ".join(
            k + "=" + repr(v) for k, v in self._values.items()
        )


class DataAzurermNetappPool(
    cdktf.TerraformDataSource,
    metaclass=jsii.JSIIMeta,
    jsii_type="@cdktf/provider-azurerm.DataAzurermNetappPool",
):
    def __init__(
        self,
        scope: constructs.Construct,
        id: builtins.str,
        *,
        account_name: builtins.str,
        name: builtins.str,
        resource_group_name: builtins.str,
        timeouts: typing.Optional["DataAzurermNetappPoolTimeouts"] = None,
        count: typing.Optional[jsii.Number] = None,
        depends_on: typing.Optional[typing.List[cdktf.TerraformResource]] = None,
        lifecycle: typing.Optional[cdktf.TerraformResourceLifecycle] = None,
        provider: typing.Optional[cdktf.TerraformProvider] = None,
    ) -> None:
        """
        :param scope: -
        :param id: -
        :param account_name: 
        :param name: 
        :param resource_group_name: 
        :param timeouts: timeouts block.
        :param count: 
        :param depends_on: 
        :param lifecycle: 
        :param provider: 
        """
        config = DataAzurermNetappPoolConfig(
            account_name=account_name,
            name=name,
            resource_group_name=resource_group_name,
            timeouts=timeouts,
            count=count,
            depends_on=depends_on,
            lifecycle=lifecycle,
            provider=provider,
        )

        jsii.create(DataAzurermNetappPool, self, [scope, id, config])

    @jsii.member(jsii_name="synthesizeAttributes")
    def _synthesize_attributes(self) -> typing.Mapping[builtins.str, typing.Any]:
        return jsii.invoke(self, "synthesizeAttributes", [])

    @builtins.property # type: ignore
    @jsii.member(jsii_name="location")
    def location(self) -> builtins.str:
        return jsii.get(self, "location")

    @builtins.property # type: ignore
    @jsii.member(jsii_name="serviceLevel")
    def service_level(self) -> builtins.str:
        return jsii.get(self, "serviceLevel")

    @builtins.property # type: ignore
    @jsii.member(jsii_name="sizeInTb")
    def size_in_tb(self) -> jsii.Number:
        return jsii.get(self, "sizeInTb")

    @builtins.property # type: ignore
    @jsii.member(jsii_name="accountName")
    def account_name(self) -> builtins.str:
        return jsii.get(self, "accountName")

    @account_name.setter # type: ignore
    def account_name(self, value: builtins.str) -> None:
        jsii.set(self, "accountName", value)

    @builtins.property # type: ignore
    @jsii.member(jsii_name="name")
    def name(self) -> builtins.str:
        return jsii.get(self, "name")

    @name.setter # type: ignore
    def name(self, value: builtins.str) -> None:
        jsii.set(self, "name", value)

    @builtins.property # type: ignore
    @jsii.member(jsii_name="resourceGroupName")
    def resource_group_name(self) -> builtins.str:
        return jsii.get(self, "resourceGroupName")

    @resource_group_name.setter # type: ignore
    def resource_group_name(self, value: builtins.str) -> None:
        jsii.set(self, "resourceGroupName", value)

    @builtins.property # type: ignore
    @jsii.member(jsii_name="id")
    def id(self) -> typing.Optional[builtins.str]:
        return jsii.get(self, "id")

    @id.setter # type: ignore
    def id(self, value: typing.Optional[builtins.str]) -> None:
        jsii.set(self, "id", value)

    @builtins.property # type: ignore
    @jsii.member(jsii_name="timeouts")
    def timeouts(self) -> typing.Optional["DataAzurermNetappPoolTimeouts"]:
        return jsii.get(self, "timeouts")

    @timeouts.setter # type: ignore
    def timeouts(self, value: typing.Optional["DataAzurermNetappPoolTimeouts"]) -> None:
        jsii.set(self, "timeouts", value)


@jsii.data_type(
    jsii_type="@cdktf/provider-azurerm.DataAzurermNetappPoolConfig",
    jsii_struct_bases=[cdktf.TerraformMetaArguments],
    name_mapping={
        "count": "count",
        "depends_on": "dependsOn",
        "lifecycle": "lifecycle",
        "provider": "provider",
        "account_name": "accountName",
        "name": "name",
        "resource_group_name": "resourceGroupName",
        "timeouts": "timeouts",
    },
)
class DataAzurermNetappPoolConfig(cdktf.TerraformMetaArguments):
    def __init__(
        self,
        *,
        count: typing.Optional[jsii.Number] = None,
        depends_on: typing.Optional[typing.List[cdktf.TerraformResource]] = None,
        lifecycle: typing.Optional[cdktf.TerraformResourceLifecycle] = None,
        provider: typing.Optional[cdktf.TerraformProvider] = None,
        account_name: builtins.str,
        name: builtins.str,
        resource_group_name: builtins.str,
        timeouts: typing.Optional["DataAzurermNetappPoolTimeouts"] = None,
    ) -> None:
        """
        :param count: 
        :param depends_on: 
        :param lifecycle: 
        :param provider: 
        :param account_name: 
        :param name: 
        :param resource_group_name: 
        :param timeouts: timeouts block.
        """
        if isinstance(lifecycle, dict):
            lifecycle = cdktf.TerraformResourceLifecycle(**lifecycle)
        if isinstance(timeouts, dict):
            timeouts = DataAzurermNetappPoolTimeouts(**timeouts)
        self._values: typing.Dict[str, typing.Any] = {
            "account_name": account_name,
            "name": name,
            "resource_group_name": resource_group_name,
        }
        if count is not None:
            self._values["count"] = count
        if depends_on is not None:
            self._values["depends_on"] = depends_on
        if lifecycle is not None:
            self._values["lifecycle"] = lifecycle
        if provider is not None:
            self._values["provider"] = provider
        if timeouts is not None:
            self._values["timeouts"] = timeouts

    @builtins.property
    def count(self) -> typing.Optional[jsii.Number]:
        """
        :stability: experimental
        """
        result = self._values.get("count")
        return result

    @builtins.property
    def depends_on(self) -> typing.Optional[typing.List[cdktf.TerraformResource]]:
        """
        :stability: experimental
        """
        result = self._values.get("depends_on")
        return result

    @builtins.property
    def lifecycle(self) -> typing.Optional[cdktf.TerraformResourceLifecycle]:
        """
        :stability: experimental
        """
        result = self._values.get("lifecycle")
        return result

    @builtins.property
    def provider(self) -> typing.Optional[cdktf.TerraformProvider]:
        """
        :stability: experimental
        """
        result = self._values.get("provider")
        return result

    @builtins.property
    def account_name(self) -> builtins.str:
        result = self._values.get("account_name")
        assert result is not None, "Required property 'account_name' is missing"
        return result

    @builtins.property
    def name(self) -> builtins.str:
        result = self._values.get("name")
        assert result is not None, "Required property 'name' is missing"
        return result

    @builtins.property
    def resource_group_name(self) -> builtins.str:
        result = self._values.get("resource_group_name")
        assert result is not None, "Required property 'resource_group_name' is missing"
        return result

    @builtins.property
    def timeouts(self) -> typing.Optional["DataAzurermNetappPoolTimeouts"]:
        """timeouts block."""
        result = self._values.get("timeouts")
        return result

    def __eq__(self, rhs: typing.Any) -> builtins.bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs: typing.Any) -> builtins.bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return "DataAzurermNetappPoolConfig(%s)" % ", ".join(
            k + "=" + repr(v) for k, v in self._values.items()
        )


@jsii.data_type(
    jsii_type="@cdktf/provider-azurerm.DataAzurermNetappPoolTimeouts",
    jsii_struct_bases=[],
    name_mapping={"read": "read"},
)
class DataAzurermNetappPoolTimeouts:
    def __init__(self, *, read: typing.Optional[builtins.str] = None) -> None:
        """
        :param read: 
        """
        self._values: typing.Dict[str, typing.Any] = {}
        if read is not None:
            self._values["read"] = read

    @builtins.property
    def read(self) -> typing.Optional[builtins.str]:
        result = self._values.get("read")
        return result

    def __eq__(self, rhs: typing.Any) -> builtins.bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs: typing.Any) -> builtins.bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return "DataAzurermNetappPoolTimeouts(%s)" % ", ".join(
            k + "=" + repr(v) for k, v in self._values.items()
        )


class DataAzurermNetappSnapshot(
    cdktf.TerraformDataSource,
    metaclass=jsii.JSIIMeta,
    jsii_type="@cdktf/provider-azurerm.DataAzurermNetappSnapshot",
):
    def __init__(
        self,
        scope: constructs.Construct,
        id: builtins.str,
        *,
        account_name: builtins.str,
        name: builtins.str,
        pool_name: builtins.str,
        resource_group_name: builtins.str,
        volume_name: builtins.str,
        timeouts: typing.Optional["DataAzurermNetappSnapshotTimeouts"] = None,
        count: typing.Optional[jsii.Number] = None,
        depends_on: typing.Optional[typing.List[cdktf.TerraformResource]] = None,
        lifecycle: typing.Optional[cdktf.TerraformResourceLifecycle] = None,
        provider: typing.Optional[cdktf.TerraformProvider] = None,
    ) -> None:
        """
        :param scope: -
        :param id: -
        :param account_name: 
        :param name: 
        :param pool_name: 
        :param resource_group_name: 
        :param volume_name: 
        :param timeouts: timeouts block.
        :param count: 
        :param depends_on: 
        :param lifecycle: 
        :param provider: 
        """
        config = DataAzurermNetappSnapshotConfig(
            account_name=account_name,
            name=name,
            pool_name=pool_name,
            resource_group_name=resource_group_name,
            volume_name=volume_name,
            timeouts=timeouts,
            count=count,
            depends_on=depends_on,
            lifecycle=lifecycle,
            provider=provider,
        )

        jsii.create(DataAzurermNetappSnapshot, self, [scope, id, config])

    @jsii.member(jsii_name="synthesizeAttributes")
    def _synthesize_attributes(self) -> typing.Mapping[builtins.str, typing.Any]:
        return jsii.invoke(self, "synthesizeAttributes", [])

    @builtins.property # type: ignore
    @jsii.member(jsii_name="location")
    def location(self) -> builtins.str:
        return jsii.get(self, "location")

    @builtins.property # type: ignore
    @jsii.member(jsii_name="accountName")
    def account_name(self) -> builtins.str:
        return jsii.get(self, "accountName")

    @account_name.setter # type: ignore
    def account_name(self, value: builtins.str) -> None:
        jsii.set(self, "accountName", value)

    @builtins.property # type: ignore
    @jsii.member(jsii_name="name")
    def name(self) -> builtins.str:
        return jsii.get(self, "name")

    @name.setter # type: ignore
    def name(self, value: builtins.str) -> None:
        jsii.set(self, "name", value)

    @builtins.property # type: ignore
    @jsii.member(jsii_name="poolName")
    def pool_name(self) -> builtins.str:
        return jsii.get(self, "poolName")

    @pool_name.setter # type: ignore
    def pool_name(self, value: builtins.str) -> None:
        jsii.set(self, "poolName", value)

    @builtins.property # type: ignore
    @jsii.member(jsii_name="resourceGroupName")
    def resource_group_name(self) -> builtins.str:
        return jsii.get(self, "resourceGroupName")

    @resource_group_name.setter # type: ignore
    def resource_group_name(self, value: builtins.str) -> None:
        jsii.set(self, "resourceGroupName", value)

    @builtins.property # type: ignore
    @jsii.member(jsii_name="volumeName")
    def volume_name(self) -> builtins.str:
        return jsii.get(self, "volumeName")

    @volume_name.setter # type: ignore
    def volume_name(self, value: builtins.str) -> None:
        jsii.set(self, "volumeName", value)

    @builtins.property # type: ignore
    @jsii.member(jsii_name="id")
    def id(self) -> typing.Optional[builtins.str]:
        return jsii.get(self, "id")

    @id.setter # type: ignore
    def id(self, value: typing.Optional[builtins.str]) -> None:
        jsii.set(self, "id", value)

    @builtins.property # type: ignore
    @jsii.member(jsii_name="timeouts")
    def timeouts(self) -> typing.Optional["DataAzurermNetappSnapshotTimeouts"]:
        return jsii.get(self, "timeouts")

    @timeouts.setter # type: ignore
    def timeouts(
        self,
        value: typing.Optional["DataAzurermNetappSnapshotTimeouts"],
    ) -> None:
        jsii.set(self, "timeouts", value)


@jsii.data_type(
    jsii_type="@cdktf/provider-azurerm.DataAzurermNetappSnapshotConfig",
    jsii_struct_bases=[cdktf.TerraformMetaArguments],
    name_mapping={
        "count": "count",
        "depends_on": "dependsOn",
        "lifecycle": "lifecycle",
        "provider": "provider",
        "account_name": "accountName",
        "name": "name",
        "pool_name": "poolName",
        "resource_group_name": "resourceGroupName",
        "volume_name": "volumeName",
        "timeouts": "timeouts",
    },
)
class DataAzurermNetappSnapshotConfig(cdktf.TerraformMetaArguments):
    def __init__(
        self,
        *,
        count: typing.Optional[jsii.Number] = None,
        depends_on: typing.Optional[typing.List[cdktf.TerraformResource]] = None,
        lifecycle: typing.Optional[cdktf.TerraformResourceLifecycle] = None,
        provider: typing.Optional[cdktf.TerraformProvider] = None,
        account_name: builtins.str,
        name: builtins.str,
        pool_name: builtins.str,
        resource_group_name: builtins.str,
        volume_name: builtins.str,
        timeouts: typing.Optional["DataAzurermNetappSnapshotTimeouts"] = None,
    ) -> None:
        """
        :param count: 
        :param depends_on: 
        :param lifecycle: 
        :param provider: 
        :param account_name: 
        :param name: 
        :param pool_name: 
        :param resource_group_name: 
        :param volume_name: 
        :param timeouts: timeouts block.
        """
        if isinstance(lifecycle, dict):
            lifecycle = cdktf.TerraformResourceLifecycle(**lifecycle)
        if isinstance(timeouts, dict):
            timeouts = DataAzurermNetappSnapshotTimeouts(**timeouts)
        self._values: typing.Dict[str, typing.Any] = {
            "account_name": account_name,
            "name": name,
            "pool_name": pool_name,
            "resource_group_name": resource_group_name,
            "volume_name": volume_name,
        }
        if count is not None:
            self._values["count"] = count
        if depends_on is not None:
            self._values["depends_on"] = depends_on
        if lifecycle is not None:
            self._values["lifecycle"] = lifecycle
        if provider is not None:
            self._values["provider"] = provider
        if timeouts is not None:
            self._values["timeouts"] = timeouts

    @builtins.property
    def count(self) -> typing.Optional[jsii.Number]:
        """
        :stability: experimental
        """
        result = self._values.get("count")
        return result

    @builtins.property
    def depends_on(self) -> typing.Optional[typing.List[cdktf.TerraformResource]]:
        """
        :stability: experimental
        """
        result = self._values.get("depends_on")
        return result

    @builtins.property
    def lifecycle(self) -> typing.Optional[cdktf.TerraformResourceLifecycle]:
        """
        :stability: experimental
        """
        result = self._values.get("lifecycle")
        return result

    @builtins.property
    def provider(self) -> typing.Optional[cdktf.TerraformProvider]:
        """
        :stability: experimental
        """
        result = self._values.get("provider")
        return result

    @builtins.property
    def account_name(self) -> builtins.str:
        result = self._values.get("account_name")
        assert result is not None, "Required property 'account_name' is missing"
        return result

    @builtins.property
    def name(self) -> builtins.str:
        result = self._values.get("name")
        assert result is not None, "Required property 'name' is missing"
        return result

    @builtins.property
    def pool_name(self) -> builtins.str:
        result = self._values.get("pool_name")
        assert result is not None, "Required property 'pool_name' is missing"
        return result

    @builtins.property
    def resource_group_name(self) -> builtins.str:
        result = self._values.get("resource_group_name")
        assert result is not None, "Required property 'resource_group_name' is missing"
        return result

    @builtins.property
    def volume_name(self) -> builtins.str:
        result = self._values.get("volume_name")
        assert result is not None, "Required property 'volume_name' is missing"
        return result

    @builtins.property
    def timeouts(self) -> typing.Optional["DataAzurermNetappSnapshotTimeouts"]:
        """timeouts block."""
        result = self._values.get("timeouts")
        return result

    def __eq__(self, rhs: typing.Any) -> builtins.bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs: typing.Any) -> builtins.bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return "DataAzurermNetappSnapshotConfig(%s)" % ", ".join(
            k + "=" + repr(v) for k, v in self._values.items()
        )


@jsii.data_type(
    jsii_type="@cdktf/provider-azurerm.DataAzurermNetappSnapshotTimeouts",
    jsii_struct_bases=[],
    name_mapping={"read": "read"},
)
class DataAzurermNetappSnapshotTimeouts:
    def __init__(self, *, read: typing.Optional[builtins.str] = None) -> None:
        """
        :param read: 
        """
        self._values: typing.Dict[str, typing.Any] = {}
        if read is not None:
            self._values["read"] = read

    @builtins.property
    def read(self) -> typing.Optional[builtins.str]:
        result = self._values.get("read")
        return result

    def __eq__(self, rhs: typing.Any) -> builtins.bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs: typing.Any) -> builtins.bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return "DataAzurermNetappSnapshotTimeouts(%s)" % ", ".join(
            k + "=" + repr(v) for k, v in self._values.items()
        )


class DataAzurermNetappVolume(
    cdktf.TerraformDataSource,
    metaclass=jsii.JSIIMeta,
    jsii_type="@cdktf/provider-azurerm.DataAzurermNetappVolume",
):
    def __init__(
        self,
        scope: constructs.Construct,
        id: builtins.str,
        *,
        account_name: builtins.str,
        name: builtins.str,
        pool_name: builtins.str,
        resource_group_name: builtins.str,
        timeouts: typing.Optional["DataAzurermNetappVolumeTimeouts"] = None,
        count: typing.Optional[jsii.Number] = None,
        depends_on: typing.Optional[typing.List[cdktf.TerraformResource]] = None,
        lifecycle: typing.Optional[cdktf.TerraformResourceLifecycle] = None,
        provider: typing.Optional[cdktf.TerraformProvider] = None,
    ) -> None:
        """
        :param scope: -
        :param id: -
        :param account_name: 
        :param name: 
        :param pool_name: 
        :param resource_group_name: 
        :param timeouts: timeouts block.
        :param count: 
        :param depends_on: 
        :param lifecycle: 
        :param provider: 
        """
        config = DataAzurermNetappVolumeConfig(
            account_name=account_name,
            name=name,
            pool_name=pool_name,
            resource_group_name=resource_group_name,
            timeouts=timeouts,
            count=count,
            depends_on=depends_on,
            lifecycle=lifecycle,
            provider=provider,
        )

        jsii.create(DataAzurermNetappVolume, self, [scope, id, config])

    @jsii.member(jsii_name="synthesizeAttributes")
    def _synthesize_attributes(self) -> typing.Mapping[builtins.str, typing.Any]:
        return jsii.invoke(self, "synthesizeAttributes", [])

    @builtins.property # type: ignore
    @jsii.member(jsii_name="location")
    def location(self) -> builtins.str:
        return jsii.get(self, "location")

    @builtins.property # type: ignore
    @jsii.member(jsii_name="serviceLevel")
    def service_level(self) -> builtins.str:
        return jsii.get(self, "serviceLevel")

    @builtins.property # type: ignore
    @jsii.member(jsii_name="storageQuotaInGb")
    def storage_quota_in_gb(self) -> jsii.Number:
        return jsii.get(self, "storageQuotaInGb")

    @builtins.property # type: ignore
    @jsii.member(jsii_name="subnetId")
    def subnet_id(self) -> builtins.str:
        return jsii.get(self, "subnetId")

    @builtins.property # type: ignore
    @jsii.member(jsii_name="volumePath")
    def volume_path(self) -> builtins.str:
        return jsii.get(self, "volumePath")

    @builtins.property # type: ignore
    @jsii.member(jsii_name="accountName")
    def account_name(self) -> builtins.str:
        return jsii.get(self, "accountName")

    @account_name.setter # type: ignore
    def account_name(self, value: builtins.str) -> None:
        jsii.set(self, "accountName", value)

    @builtins.property # type: ignore
    @jsii.member(jsii_name="name")
    def name(self) -> builtins.str:
        return jsii.get(self, "name")

    @name.setter # type: ignore
    def name(self, value: builtins.str) -> None:
        jsii.set(self, "name", value)

    @builtins.property # type: ignore
    @jsii.member(jsii_name="poolName")
    def pool_name(self) -> builtins.str:
        return jsii.get(self, "poolName")

    @pool_name.setter # type: ignore
    def pool_name(self, value: builtins.str) -> None:
        jsii.set(self, "poolName", value)

    @builtins.property # type: ignore
    @jsii.member(jsii_name="resourceGroupName")
    def resource_group_name(self) -> builtins.str:
        return jsii.get(self, "resourceGroupName")

    @resource_group_name.setter # type: ignore
    def resource_group_name(self, value: builtins.str) -> None:
        jsii.set(self, "resourceGroupName", value)

    @builtins.property # type: ignore
    @jsii.member(jsii_name="id")
    def id(self) -> typing.Optional[builtins.str]:
        return jsii.get(self, "id")

    @id.setter # type: ignore
    def id(self, value: typing.Optional[builtins.str]) -> None:
        jsii.set(self, "id", value)

    @builtins.property # type: ignore
    @jsii.member(jsii_name="timeouts")
    def timeouts(self) -> typing.Optional["DataAzurermNetappVolumeTimeouts"]:
        return jsii.get(self, "timeouts")

    @timeouts.setter # type: ignore
    def timeouts(
        self,
        value: typing.Optional["DataAzurermNetappVolumeTimeouts"],
    ) -> None:
        jsii.set(self, "timeouts", value)


@jsii.data_type(
    jsii_type="@cdktf/provider-azurerm.DataAzurermNetappVolumeConfig",
    jsii_struct_bases=[cdktf.TerraformMetaArguments],
    name_mapping={
        "count": "count",
        "depends_on": "dependsOn",
        "lifecycle": "lifecycle",
        "provider": "provider",
        "account_name": "accountName",
        "name": "name",
        "pool_name": "poolName",
        "resource_group_name": "resourceGroupName",
        "timeouts": "timeouts",
    },
)
class DataAzurermNetappVolumeConfig(cdktf.TerraformMetaArguments):
    def __init__(
        self,
        *,
        count: typing.Optional[jsii.Number] = None,
        depends_on: typing.Optional[typing.List[cdktf.TerraformResource]] = None,
        lifecycle: typing.Optional[cdktf.TerraformResourceLifecycle] = None,
        provider: typing.Optional[cdktf.TerraformProvider] = None,
        account_name: builtins.str,
        name: builtins.str,
        pool_name: builtins.str,
        resource_group_name: builtins.str,
        timeouts: typing.Optional["DataAzurermNetappVolumeTimeouts"] = None,
    ) -> None:
        """
        :param count: 
        :param depends_on: 
        :param lifecycle: 
        :param provider: 
        :param account_name: 
        :param name: 
        :param pool_name: 
        :param resource_group_name: 
        :param timeouts: timeouts block.
        """
        if isinstance(lifecycle, dict):
            lifecycle = cdktf.TerraformResourceLifecycle(**lifecycle)
        if isinstance(timeouts, dict):
            timeouts = DataAzurermNetappVolumeTimeouts(**timeouts)
        self._values: typing.Dict[str, typing.Any] = {
            "account_name": account_name,
            "name": name,
            "pool_name": pool_name,
            "resource_group_name": resource_group_name,
        }
        if count is not None:
            self._values["count"] = count
        if depends_on is not None:
            self._values["depends_on"] = depends_on
        if lifecycle is not None:
            self._values["lifecycle"] = lifecycle
        if provider is not None:
            self._values["provider"] = provider
        if timeouts is not None:
            self._values["timeouts"] = timeouts

    @builtins.property
    def count(self) -> typing.Optional[jsii.Number]:
        """
        :stability: experimental
        """
        result = self._values.get("count")
        return result

    @builtins.property
    def depends_on(self) -> typing.Optional[typing.List[cdktf.TerraformResource]]:
        """
        :stability: experimental
        """
        result = self._values.get("depends_on")
        return result

    @builtins.property
    def lifecycle(self) -> typing.Optional[cdktf.TerraformResourceLifecycle]:
        """
        :stability: experimental
        """
        result = self._values.get("lifecycle")
        return result

    @builtins.property
    def provider(self) -> typing.Optional[cdktf.TerraformProvider]:
        """
        :stability: experimental
        """
        result = self._values.get("provider")
        return result

    @builtins.property
    def account_name(self) -> builtins.str:
        result = self._values.get("account_name")
        assert result is not None, "Required property 'account_name' is missing"
        return result

    @builtins.property
    def name(self) -> builtins.str:
        result = self._values.get("name")
        assert result is not None, "Required property 'name' is missing"
        return result

    @builtins.property
    def pool_name(self) -> builtins.str:
        result = self._values.get("pool_name")
        assert result is not None, "Required property 'pool_name' is missing"
        return result

    @builtins.property
    def resource_group_name(self) -> builtins.str:
        result = self._values.get("resource_group_name")
        assert result is not None, "Required property 'resource_group_name' is missing"
        return result

    @builtins.property
    def timeouts(self) -> typing.Optional["DataAzurermNetappVolumeTimeouts"]:
        """timeouts block."""
        result = self._values.get("timeouts")
        return result

    def __eq__(self, rhs: typing.Any) -> builtins.bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs: typing.Any) -> builtins.bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return "DataAzurermNetappVolumeConfig(%s)" % ", ".join(
            k + "=" + repr(v) for k, v in self._values.items()
        )


@jsii.data_type(
    jsii_type="@cdktf/provider-azurerm.DataAzurermNetappVolumeTimeouts",
    jsii_struct_bases=[],
    name_mapping={"read": "read"},
)
class DataAzurermNetappVolumeTimeouts:
    def __init__(self, *, read: typing.Optional[builtins.str] = None) -> None:
        """
        :param read: 
        """
        self._values: typing.Dict[str, typing.Any] = {}
        if read is not None:
            self._values["read"] = read

    @builtins.property
    def read(self) -> typing.Optional[builtins.str]:
        result = self._values.get("read")
        return result

    def __eq__(self, rhs: typing.Any) -> builtins.bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs: typing.Any) -> builtins.bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return "DataAzurermNetappVolumeTimeouts(%s)" % ", ".join(
            k + "=" + repr(v) for k, v in self._values.items()
        )


class DataAzurermNetworkDdosProtectionPlan(
    cdktf.TerraformDataSource,
    metaclass=jsii.JSIIMeta,
    jsii_type="@cdktf/provider-azurerm.DataAzurermNetworkDdosProtectionPlan",
):
    def __init__(
        self,
        scope: constructs.Construct,
        id: builtins.str,
        *,
        name: builtins.str,
        resource_group_name: builtins.str,
        tags: typing.Optional[typing.Mapping[builtins.str, builtins.str]] = None,
        timeouts: typing.Optional["DataAzurermNetworkDdosProtectionPlanTimeouts"] = None,
        count: typing.Optional[jsii.Number] = None,
        depends_on: typing.Optional[typing.List[cdktf.TerraformResource]] = None,
        lifecycle: typing.Optional[cdktf.TerraformResourceLifecycle] = None,
        provider: typing.Optional[cdktf.TerraformProvider] = None,
    ) -> None:
        """
        :param scope: -
        :param id: -
        :param name: 
        :param resource_group_name: 
        :param tags: 
        :param timeouts: timeouts block.
        :param count: 
        :param depends_on: 
        :param lifecycle: 
        :param provider: 
        """
        config = DataAzurermNetworkDdosProtectionPlanConfig(
            name=name,
            resource_group_name=resource_group_name,
            tags=tags,
            timeouts=timeouts,
            count=count,
            depends_on=depends_on,
            lifecycle=lifecycle,
            provider=provider,
        )

        jsii.create(DataAzurermNetworkDdosProtectionPlan, self, [scope, id, config])

    @jsii.member(jsii_name="synthesizeAttributes")
    def _synthesize_attributes(self) -> typing.Mapping[builtins.str, typing.Any]:
        return jsii.invoke(self, "synthesizeAttributes", [])

    @builtins.property # type: ignore
    @jsii.member(jsii_name="location")
    def location(self) -> builtins.str:
        return jsii.get(self, "location")

    @builtins.property # type: ignore
    @jsii.member(jsii_name="virtualNetworkIds")
    def virtual_network_ids(self) -> typing.List[builtins.str]:
        return jsii.get(self, "virtualNetworkIds")

    @builtins.property # type: ignore
    @jsii.member(jsii_name="name")
    def name(self) -> builtins.str:
        return jsii.get(self, "name")

    @name.setter # type: ignore
    def name(self, value: builtins.str) -> None:
        jsii.set(self, "name", value)

    @builtins.property # type: ignore
    @jsii.member(jsii_name="resourceGroupName")
    def resource_group_name(self) -> builtins.str:
        return jsii.get(self, "resourceGroupName")

    @resource_group_name.setter # type: ignore
    def resource_group_name(self, value: builtins.str) -> None:
        jsii.set(self, "resourceGroupName", value)

    @builtins.property # type: ignore
    @jsii.member(jsii_name="id")
    def id(self) -> typing.Optional[builtins.str]:
        return jsii.get(self, "id")

    @id.setter # type: ignore
    def id(self, value: typing.Optional[builtins.str]) -> None:
        jsii.set(self, "id", value)

    @builtins.property # type: ignore
    @jsii.member(jsii_name="tags")
    def tags(self) -> typing.Optional[typing.Mapping[builtins.str, builtins.str]]:
        return jsii.get(self, "tags")

    @tags.setter # type: ignore
    def tags(
        self,
        value: typing.Optional[typing.Mapping[builtins.str, builtins.str]],
    ) -> None:
        jsii.set(self, "tags", value)

    @builtins.property # type: ignore
    @jsii.member(jsii_name="timeouts")
    def timeouts(
        self,
    ) -> typing.Optional["DataAzurermNetworkDdosProtectionPlanTimeouts"]:
        return jsii.get(self, "timeouts")

    @timeouts.setter # type: ignore
    def timeouts(
        self,
        value: typing.Optional["DataAzurermNetworkDdosProtectionPlanTimeouts"],
    ) -> None:
        jsii.set(self, "timeouts", value)


@jsii.data_type(
    jsii_type="@cdktf/provider-azurerm.DataAzurermNetworkDdosProtectionPlanConfig",
    jsii_struct_bases=[cdktf.TerraformMetaArguments],
    name_mapping={
        "count": "count",
        "depends_on": "dependsOn",
        "lifecycle": "lifecycle",
        "provider": "provider",
        "name": "name",
        "resource_group_name": "resourceGroupName",
        "tags": "tags",
        "timeouts": "timeouts",
    },
)
class DataAzurermNetworkDdosProtectionPlanConfig(cdktf.TerraformMetaArguments):
    def __init__(
        self,
        *,
        count: typing.Optional[jsii.Number] = None,
        depends_on: typing.Optional[typing.List[cdktf.TerraformResource]] = None,
        lifecycle: typing.Optional[cdktf.TerraformResourceLifecycle] = None,
        provider: typing.Optional[cdktf.TerraformProvider] = None,
        name: builtins.str,
        resource_group_name: builtins.str,
        tags: typing.Optional[typing.Mapping[builtins.str, builtins.str]] = None,
        timeouts: typing.Optional["DataAzurermNetworkDdosProtectionPlanTimeouts"] = None,
    ) -> None:
        """
        :param count: 
        :param depends_on: 
        :param lifecycle: 
        :param provider: 
        :param name: 
        :param resource_group_name: 
        :param tags: 
        :param timeouts: timeouts block.
        """
        if isinstance(lifecycle, dict):
            lifecycle = cdktf.TerraformResourceLifecycle(**lifecycle)
        if isinstance(timeouts, dict):
            timeouts = DataAzurermNetworkDdosProtectionPlanTimeouts(**timeouts)
        self._values: typing.Dict[str, typing.Any] = {
            "name": name,
            "resource_group_name": resource_group_name,
        }
        if count is not None:
            self._values["count"] = count
        if depends_on is not None:
            self._values["depends_on"] = depends_on
        if lifecycle is not None:
            self._values["lifecycle"] = lifecycle
        if provider is not None:
            self._values["provider"] = provider
        if tags is not None:
            self._values["tags"] = tags
        if timeouts is not None:
            self._values["timeouts"] = timeouts

    @builtins.property
    def count(self) -> typing.Optional[jsii.Number]:
        """
        :stability: experimental
        """
        result = self._values.get("count")
        return result

    @builtins.property
    def depends_on(self) -> typing.Optional[typing.List[cdktf.TerraformResource]]:
        """
        :stability: experimental
        """
        result = self._values.get("depends_on")
        return result

    @builtins.property
    def lifecycle(self) -> typing.Optional[cdktf.TerraformResourceLifecycle]:
        """
        :stability: experimental
        """
        result = self._values.get("lifecycle")
        return result

    @builtins.property
    def provider(self) -> typing.Optional[cdktf.TerraformProvider]:
        """
        :stability: experimental
        """
        result = self._values.get("provider")
        return result

    @builtins.property
    def name(self) -> builtins.str:
        result = self._values.get("name")
        assert result is not None, "Required property 'name' is missing"
        return result

    @builtins.property
    def resource_group_name(self) -> builtins.str:
        result = self._values.get("resource_group_name")
        assert result is not None, "Required property 'resource_group_name' is missing"
        return result

    @builtins.property
    def tags(self) -> typing.Optional[typing.Mapping[builtins.str, builtins.str]]:
        result = self._values.get("tags")
        return result

    @builtins.property
    def timeouts(
        self,
    ) -> typing.Optional["DataAzurermNetworkDdosProtectionPlanTimeouts"]:
        """timeouts block."""
        result = self._values.get("timeouts")
        return result

    def __eq__(self, rhs: typing.Any) -> builtins.bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs: typing.Any) -> builtins.bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return "DataAzurermNetworkDdosProtectionPlanConfig(%s)" % ", ".join(
            k + "=" + repr(v) for k, v in self._values.items()
        )


@jsii.data_type(
    jsii_type="@cdktf/provider-azurerm.DataAzurermNetworkDdosProtectionPlanTimeouts",
    jsii_struct_bases=[],
    name_mapping={"read": "read"},
)
class DataAzurermNetworkDdosProtectionPlanTimeouts:
    def __init__(self, *, read: typing.Optional[builtins.str] = None) -> None:
        """
        :param read: 
        """
        self._values: typing.Dict[str, typing.Any] = {}
        if read is not None:
            self._values["read"] = read

    @builtins.property
    def read(self) -> typing.Optional[builtins.str]:
        result = self._values.get("read")
        return result

    def __eq__(self, rhs: typing.Any) -> builtins.bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs: typing.Any) -> builtins.bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return "DataAzurermNetworkDdosProtectionPlanTimeouts(%s)" % ", ".join(
            k + "=" + repr(v) for k, v in self._values.items()
        )


class DataAzurermNetworkInterface(
    cdktf.TerraformDataSource,
    metaclass=jsii.JSIIMeta,
    jsii_type="@cdktf/provider-azurerm.DataAzurermNetworkInterface",
):
    def __init__(
        self,
        scope: constructs.Construct,
        id: builtins.str,
        *,
        name: builtins.str,
        resource_group_name: builtins.str,
        timeouts: typing.Optional["DataAzurermNetworkInterfaceTimeouts"] = None,
        count: typing.Optional[jsii.Number] = None,
        depends_on: typing.Optional[typing.List[cdktf.TerraformResource]] = None,
        lifecycle: typing.Optional[cdktf.TerraformResourceLifecycle] = None,
        provider: typing.Optional[cdktf.TerraformProvider] = None,
    ) -> None:
        """
        :param scope: -
        :param id: -
        :param name: 
        :param resource_group_name: 
        :param timeouts: timeouts block.
        :param count: 
        :param depends_on: 
        :param lifecycle: 
        :param provider: 
        """
        config = DataAzurermNetworkInterfaceConfig(
            name=name,
            resource_group_name=resource_group_name,
            timeouts=timeouts,
            count=count,
            depends_on=depends_on,
            lifecycle=lifecycle,
            provider=provider,
        )

        jsii.create(DataAzurermNetworkInterface, self, [scope, id, config])

    @jsii.member(jsii_name="ipConfiguration")
    def ip_configuration(
        self,
        index: builtins.str,
    ) -> "DataAzurermNetworkInterfaceIpConfiguration":
        """
        :param index: -
        """
        return jsii.invoke(self, "ipConfiguration", [index])

    @jsii.member(jsii_name="synthesizeAttributes")
    def _synthesize_attributes(self) -> typing.Mapping[builtins.str, typing.Any]:
        return jsii.invoke(self, "synthesizeAttributes", [])

    @jsii.member(jsii_name="tags")
    def tags(self, key: builtins.str) -> builtins.str:
        """
        :param key: -
        """
        return jsii.invoke(self, "tags", [key])

    @builtins.property # type: ignore
    @jsii.member(jsii_name="appliedDnsServers")
    def applied_dns_servers(self) -> typing.List[builtins.str]:
        return jsii.get(self, "appliedDnsServers")

    @builtins.property # type: ignore
    @jsii.member(jsii_name="dnsServers")
    def dns_servers(self) -> typing.List[builtins.str]:
        return jsii.get(self, "dnsServers")

    @builtins.property # type: ignore
    @jsii.member(jsii_name="enableAcceleratedNetworking")
    def enable_accelerated_networking(self) -> builtins.bool:
        return jsii.get(self, "enableAcceleratedNetworking")

    @builtins.property # type: ignore
    @jsii.member(jsii_name="enableIpForwarding")
    def enable_ip_forwarding(self) -> builtins.bool:
        return jsii.get(self, "enableIpForwarding")

    @builtins.property # type: ignore
    @jsii.member(jsii_name="internalDnsNameLabel")
    def internal_dns_name_label(self) -> builtins.str:
        return jsii.get(self, "internalDnsNameLabel")

    @builtins.property # type: ignore
    @jsii.member(jsii_name="location")
    def location(self) -> builtins.str:
        return jsii.get(self, "location")

    @builtins.property # type: ignore
    @jsii.member(jsii_name="macAddress")
    def mac_address(self) -> builtins.str:
        return jsii.get(self, "macAddress")

    @builtins.property # type: ignore
    @jsii.member(jsii_name="networkSecurityGroupId")
    def network_security_group_id(self) -> builtins.str:
        return jsii.get(self, "networkSecurityGroupId")

    @builtins.property # type: ignore
    @jsii.member(jsii_name="privateIpAddress")
    def private_ip_address(self) -> builtins.str:
        return jsii.get(self, "privateIpAddress")

    @builtins.property # type: ignore
    @jsii.member(jsii_name="privateIpAddresses")
    def private_ip_addresses(self) -> typing.List[builtins.str]:
        return jsii.get(self, "privateIpAddresses")

    @builtins.property # type: ignore
    @jsii.member(jsii_name="virtualMachineId")
    def virtual_machine_id(self) -> builtins.str:
        return jsii.get(self, "virtualMachineId")

    @builtins.property # type: ignore
    @jsii.member(jsii_name="name")
    def name(self) -> builtins.str:
        return jsii.get(self, "name")

    @name.setter # type: ignore
    def name(self, value: builtins.str) -> None:
        jsii.set(self, "name", value)

    @builtins.property # type: ignore
    @jsii.member(jsii_name="resourceGroupName")
    def resource_group_name(self) -> builtins.str:
        return jsii.get(self, "resourceGroupName")

    @resource_group_name.setter # type: ignore
    def resource_group_name(self, value: builtins.str) -> None:
        jsii.set(self, "resourceGroupName", value)

    @builtins.property # type: ignore
    @jsii.member(jsii_name="id")
    def id(self) -> typing.Optional[builtins.str]:
        return jsii.get(self, "id")

    @id.setter # type: ignore
    def id(self, value: typing.Optional[builtins.str]) -> None:
        jsii.set(self, "id", value)

    @builtins.property # type: ignore
    @jsii.member(jsii_name="timeouts")
    def timeouts(self) -> typing.Optional["DataAzurermNetworkInterfaceTimeouts"]:
        return jsii.get(self, "timeouts")

    @timeouts.setter # type: ignore
    def timeouts(
        self,
        value: typing.Optional["DataAzurermNetworkInterfaceTimeouts"],
    ) -> None:
        jsii.set(self, "timeouts", value)


@jsii.data_type(
    jsii_type="@cdktf/provider-azurerm.DataAzurermNetworkInterfaceConfig",
    jsii_struct_bases=[cdktf.TerraformMetaArguments],
    name_mapping={
        "count": "count",
        "depends_on": "dependsOn",
        "lifecycle": "lifecycle",
        "provider": "provider",
        "name": "name",
        "resource_group_name": "resourceGroupName",
        "timeouts": "timeouts",
    },
)
class DataAzurermNetworkInterfaceConfig(cdktf.TerraformMetaArguments):
    def __init__(
        self,
        *,
        count: typing.Optional[jsii.Number] = None,
        depends_on: typing.Optional[typing.List[cdktf.TerraformResource]] = None,
        lifecycle: typing.Optional[cdktf.TerraformResourceLifecycle] = None,
        provider: typing.Optional[cdktf.TerraformProvider] = None,
        name: builtins.str,
        resource_group_name: builtins.str,
        timeouts: typing.Optional["DataAzurermNetworkInterfaceTimeouts"] = None,
    ) -> None:
        """
        :param count: 
        :param depends_on: 
        :param lifecycle: 
        :param provider: 
        :param name: 
        :param resource_group_name: 
        :param timeouts: timeouts block.
        """
        if isinstance(lifecycle, dict):
            lifecycle = cdktf.TerraformResourceLifecycle(**lifecycle)
        if isinstance(timeouts, dict):
            timeouts = DataAzurermNetworkInterfaceTimeouts(**timeouts)
        self._values: typing.Dict[str, typing.Any] = {
            "name": name,
            "resource_group_name": resource_group_name,
        }
        if count is not None:
            self._values["count"] = count
        if depends_on is not None:
            self._values["depends_on"] = depends_on
        if lifecycle is not None:
            self._values["lifecycle"] = lifecycle
        if provider is not None:
            self._values["provider"] = provider
        if timeouts is not None:
            self._values["timeouts"] = timeouts

    @builtins.property
    def count(self) -> typing.Optional[jsii.Number]:
        """
        :stability: experimental
        """
        result = self._values.get("count")
        return result

    @builtins.property
    def depends_on(self) -> typing.Optional[typing.List[cdktf.TerraformResource]]:
        """
        :stability: experimental
        """
        result = self._values.get("depends_on")
        return result

    @builtins.property
    def lifecycle(self) -> typing.Optional[cdktf.TerraformResourceLifecycle]:
        """
        :stability: experimental
        """
        result = self._values.get("lifecycle")
        return result

    @builtins.property
    def provider(self) -> typing.Optional[cdktf.TerraformProvider]:
        """
        :stability: experimental
        """
        result = self._values.get("provider")
        return result

    @builtins.property
    def name(self) -> builtins.str:
        result = self._values.get("name")
        assert result is not None, "Required property 'name' is missing"
        return result

    @builtins.property
    def resource_group_name(self) -> builtins.str:
        result = self._values.get("resource_group_name")
        assert result is not None, "Required property 'resource_group_name' is missing"
        return result

    @builtins.property
    def timeouts(self) -> typing.Optional["DataAzurermNetworkInterfaceTimeouts"]:
        """timeouts block."""
        result = self._values.get("timeouts")
        return result

    def __eq__(self, rhs: typing.Any) -> builtins.bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs: typing.Any) -> builtins.bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return "DataAzurermNetworkInterfaceConfig(%s)" % ", ".join(
            k + "=" + repr(v) for k, v in self._values.items()
        )


class DataAzurermNetworkInterfaceIpConfiguration(
    cdktf.ComplexComputedList,
    metaclass=jsii.JSIIMeta,
    jsii_type="@cdktf/provider-azurerm.DataAzurermNetworkInterfaceIpConfiguration",
):
    def __init__(
        self,
        terraform_resource: cdktf.ITerraformResource,
        terraform_attribute: builtins.str,
        index: builtins.str,
    ) -> None:
        """
        :param terraform_resource: -
        :param terraform_attribute: -
        :param index: -

        :stability: experimental
        """
        jsii.create(DataAzurermNetworkInterfaceIpConfiguration, self, [terraform_resource, terraform_attribute, index])

    @builtins.property # type: ignore
    @jsii.member(jsii_name="applicationGatewayBackendAddressPoolsIds")
    def application_gateway_backend_address_pools_ids(
        self,
    ) -> typing.List[builtins.str]:
        return jsii.get(self, "applicationGatewayBackendAddressPoolsIds")

    @builtins.property # type: ignore
    @jsii.member(jsii_name="applicationSecurityGroupIds")
    def application_security_group_ids(self) -> typing.List[builtins.str]:
        return jsii.get(self, "applicationSecurityGroupIds")

    @builtins.property # type: ignore
    @jsii.member(jsii_name="loadBalancerBackendAddressPoolsIds")
    def load_balancer_backend_address_pools_ids(self) -> typing.List[builtins.str]:
        return jsii.get(self, "loadBalancerBackendAddressPoolsIds")

    @builtins.property # type: ignore
    @jsii.member(jsii_name="loadBalancerInboundNatRulesIds")
    def load_balancer_inbound_nat_rules_ids(self) -> typing.List[builtins.str]:
        return jsii.get(self, "loadBalancerInboundNatRulesIds")

    @builtins.property # type: ignore
    @jsii.member(jsii_name="name")
    def name(self) -> builtins.str:
        return jsii.get(self, "name")

    @builtins.property # type: ignore
    @jsii.member(jsii_name="primary")
    def primary(self) -> builtins.bool:
        return jsii.get(self, "primary")

    @builtins.property # type: ignore
    @jsii.member(jsii_name="privateIpAddress")
    def private_ip_address(self) -> builtins.str:
        return jsii.get(self, "privateIpAddress")

    @builtins.property # type: ignore
    @jsii.member(jsii_name="privateIpAddressAllocation")
    def private_ip_address_allocation(self) -> builtins.str:
        return jsii.get(self, "privateIpAddressAllocation")

    @builtins.property # type: ignore
    @jsii.member(jsii_name="privateIpAddressVersion")
    def private_ip_address_version(self) -> builtins.str:
        return jsii.get(self, "privateIpAddressVersion")

    @builtins.property # type: ignore
    @jsii.member(jsii_name="publicIpAddressId")
    def public_ip_address_id(self) -> builtins.str:
        return jsii.get(self, "publicIpAddressId")

    @builtins.property # type: ignore
    @jsii.member(jsii_name="subnetId")
    def subnet_id(self) -> builtins.str:
        return jsii.get(self, "subnetId")


@jsii.data_type(
    jsii_type="@cdktf/provider-azurerm.DataAzurermNetworkInterfaceTimeouts",
    jsii_struct_bases=[],
    name_mapping={"read": "read"},
)
class DataAzurermNetworkInterfaceTimeouts:
    def __init__(self, *, read: typing.Optional[builtins.str] = None) -> None:
        """
        :param read: 
        """
        self._values: typing.Dict[str, typing.Any] = {}
        if read is not None:
            self._values["read"] = read

    @builtins.property
    def read(self) -> typing.Optional[builtins.str]:
        result = self._values.get("read")
        return result

    def __eq__(self, rhs: typing.Any) -> builtins.bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs: typing.Any) -> builtins.bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return "DataAzurermNetworkInterfaceTimeouts(%s)" % ", ".join(
            k + "=" + repr(v) for k, v in self._values.items()
        )


class DataAzurermNetworkSecurityGroup(
    cdktf.TerraformDataSource,
    metaclass=jsii.JSIIMeta,
    jsii_type="@cdktf/provider-azurerm.DataAzurermNetworkSecurityGroup",
):
    def __init__(
        self,
        scope: constructs.Construct,
        id: builtins.str,
        *,
        name: builtins.str,
        resource_group_name: builtins.str,
        timeouts: typing.Optional["DataAzurermNetworkSecurityGroupTimeouts"] = None,
        count: typing.Optional[jsii.Number] = None,
        depends_on: typing.Optional[typing.List[cdktf.TerraformResource]] = None,
        lifecycle: typing.Optional[cdktf.TerraformResourceLifecycle] = None,
        provider: typing.Optional[cdktf.TerraformProvider] = None,
    ) -> None:
        """
        :param scope: -
        :param id: -
        :param name: 
        :param resource_group_name: 
        :param timeouts: timeouts block.
        :param count: 
        :param depends_on: 
        :param lifecycle: 
        :param provider: 
        """
        config = DataAzurermNetworkSecurityGroupConfig(
            name=name,
            resource_group_name=resource_group_name,
            timeouts=timeouts,
            count=count,
            depends_on=depends_on,
            lifecycle=lifecycle,
            provider=provider,
        )

        jsii.create(DataAzurermNetworkSecurityGroup, self, [scope, id, config])

    @jsii.member(jsii_name="securityRule")
    def security_rule(
        self,
        index: builtins.str,
    ) -> "DataAzurermNetworkSecurityGroupSecurityRule":
        """
        :param index: -
        """
        return jsii.invoke(self, "securityRule", [index])

    @jsii.member(jsii_name="synthesizeAttributes")
    def _synthesize_attributes(self) -> typing.Mapping[builtins.str, typing.Any]:
        return jsii.invoke(self, "synthesizeAttributes", [])

    @jsii.member(jsii_name="tags")
    def tags(self, key: builtins.str) -> builtins.str:
        """
        :param key: -
        """
        return jsii.invoke(self, "tags", [key])

    @builtins.property # type: ignore
    @jsii.member(jsii_name="location")
    def location(self) -> builtins.str:
        return jsii.get(self, "location")

    @builtins.property # type: ignore
    @jsii.member(jsii_name="name")
    def name(self) -> builtins.str:
        return jsii.get(self, "name")

    @name.setter # type: ignore
    def name(self, value: builtins.str) -> None:
        jsii.set(self, "name", value)

    @builtins.property # type: ignore
    @jsii.member(jsii_name="resourceGroupName")
    def resource_group_name(self) -> builtins.str:
        return jsii.get(self, "resourceGroupName")

    @resource_group_name.setter # type: ignore
    def resource_group_name(self, value: builtins.str) -> None:
        jsii.set(self, "resourceGroupName", value)

    @builtins.property # type: ignore
    @jsii.member(jsii_name="id")
    def id(self) -> typing.Optional[builtins.str]:
        return jsii.get(self, "id")

    @id.setter # type: ignore
    def id(self, value: typing.Optional[builtins.str]) -> None:
        jsii.set(self, "id", value)

    @builtins.property # type: ignore
    @jsii.member(jsii_name="timeouts")
    def timeouts(self) -> typing.Optional["DataAzurermNetworkSecurityGroupTimeouts"]:
        return jsii.get(self, "timeouts")

    @timeouts.setter # type: ignore
    def timeouts(
        self,
        value: typing.Optional["DataAzurermNetworkSecurityGroupTimeouts"],
    ) -> None:
        jsii.set(self, "timeouts", value)


@jsii.data_type(
    jsii_type="@cdktf/provider-azurerm.DataAzurermNetworkSecurityGroupConfig",
    jsii_struct_bases=[cdktf.TerraformMetaArguments],
    name_mapping={
        "count": "count",
        "depends_on": "dependsOn",
        "lifecycle": "lifecycle",
        "provider": "provider",
        "name": "name",
        "resource_group_name": "resourceGroupName",
        "timeouts": "timeouts",
    },
)
class DataAzurermNetworkSecurityGroupConfig(cdktf.TerraformMetaArguments):
    def __init__(
        self,
        *,
        count: typing.Optional[jsii.Number] = None,
        depends_on: typing.Optional[typing.List[cdktf.TerraformResource]] = None,
        lifecycle: typing.Optional[cdktf.TerraformResourceLifecycle] = None,
        provider: typing.Optional[cdktf.TerraformProvider] = None,
        name: builtins.str,
        resource_group_name: builtins.str,
        timeouts: typing.Optional["DataAzurermNetworkSecurityGroupTimeouts"] = None,
    ) -> None:
        """
        :param count: 
        :param depends_on: 
        :param lifecycle: 
        :param provider: 
        :param name: 
        :param resource_group_name: 
        :param timeouts: timeouts block.
        """
        if isinstance(lifecycle, dict):
            lifecycle = cdktf.TerraformResourceLifecycle(**lifecycle)
        if isinstance(timeouts, dict):
            timeouts = DataAzurermNetworkSecurityGroupTimeouts(**timeouts)
        self._values: typing.Dict[str, typing.Any] = {
            "name": name,
            "resource_group_name": resource_group_name,
        }
        if count is not None:
            self._values["count"] = count
        if depends_on is not None:
            self._values["depends_on"] = depends_on
        if lifecycle is not None:
            self._values["lifecycle"] = lifecycle
        if provider is not None:
            self._values["provider"] = provider
        if timeouts is not None:
            self._values["timeouts"] = timeouts

    @builtins.property
    def count(self) -> typing.Optional[jsii.Number]:
        """
        :stability: experimental
        """
        result = self._values.get("count")
        return result

    @builtins.property
    def depends_on(self) -> typing.Optional[typing.List[cdktf.TerraformResource]]:
        """
        :stability: experimental
        """
        result = self._values.get("depends_on")
        return result

    @builtins.property
    def lifecycle(self) -> typing.Optional[cdktf.TerraformResourceLifecycle]:
        """
        :stability: experimental
        """
        result = self._values.get("lifecycle")
        return result

    @builtins.property
    def provider(self) -> typing.Optional[cdktf.TerraformProvider]:
        """
        :stability: experimental
        """
        result = self._values.get("provider")
        return result

    @builtins.property
    def name(self) -> builtins.str:
        result = self._values.get("name")
        assert result is not None, "Required property 'name' is missing"
        return result

    @builtins.property
    def resource_group_name(self) -> builtins.str:
        result = self._values.get("resource_group_name")
        assert result is not None, "Required property 'resource_group_name' is missing"
        return result

    @builtins.property
    def timeouts(self) -> typing.Optional["DataAzurermNetworkSecurityGroupTimeouts"]:
        """timeouts block."""
        result = self._values.get("timeouts")
        return result

    def __eq__(self, rhs: typing.Any) -> builtins.bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs: typing.Any) -> builtins.bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return "DataAzurermNetworkSecurityGroupConfig(%s)" % ", ".join(
            k + "=" + repr(v) for k, v in self._values.items()
        )


class DataAzurermNetworkSecurityGroupSecurityRule(
    cdktf.ComplexComputedList,
    metaclass=jsii.JSIIMeta,
    jsii_type="@cdktf/provider-azurerm.DataAzurermNetworkSecurityGroupSecurityRule",
):
    def __init__(
        self,
        terraform_resource: cdktf.ITerraformResource,
        terraform_attribute: builtins.str,
        index: builtins.str,
    ) -> None:
        """
        :param terraform_resource: -
        :param terraform_attribute: -
        :param index: -

        :stability: experimental
        """
        jsii.create(DataAzurermNetworkSecurityGroupSecurityRule, self, [terraform_resource, terraform_attribute, index])

    @builtins.property # type: ignore
    @jsii.member(jsii_name="access")
    def access(self) -> builtins.str:
        return jsii.get(self, "access")

    @builtins.property # type: ignore
    @jsii.member(jsii_name="description")
    def description(self) -> builtins.str:
        return jsii.get(self, "description")

    @builtins.property # type: ignore
    @jsii.member(jsii_name="destinationAddressPrefix")
    def destination_address_prefix(self) -> builtins.str:
        return jsii.get(self, "destinationAddressPrefix")

    @builtins.property # type: ignore
    @jsii.member(jsii_name="destinationAddressPrefixes")
    def destination_address_prefixes(self) -> typing.List[builtins.str]:
        return jsii.get(self, "destinationAddressPrefixes")

    @builtins.property # type: ignore
    @jsii.member(jsii_name="destinationApplicationSecurityGroupIds")
    def destination_application_security_group_ids(self) -> typing.List[builtins.str]:
        return jsii.get(self, "destinationApplicationSecurityGroupIds")

    @builtins.property # type: ignore
    @jsii.member(jsii_name="destinationPortRange")
    def destination_port_range(self) -> builtins.str:
        return jsii.get(self, "destinationPortRange")

    @builtins.property # type: ignore
    @jsii.member(jsii_name="destinationPortRanges")
    def destination_port_ranges(self) -> typing.List[builtins.str]:
        return jsii.get(self, "destinationPortRanges")

    @builtins.property # type: ignore
    @jsii.member(jsii_name="direction")
    def direction(self) -> builtins.str:
        return jsii.get(self, "direction")

    @builtins.property # type: ignore
    @jsii.member(jsii_name="name")
    def name(self) -> builtins.str:
        return jsii.get(self, "name")

    @builtins.property # type: ignore
    @jsii.member(jsii_name="priority")
    def priority(self) -> jsii.Number:
        return jsii.get(self, "priority")

    @builtins.property # type: ignore
    @jsii.member(jsii_name="protocol")
    def protocol(self) -> builtins.str:
        return jsii.get(self, "protocol")

    @builtins.property # type: ignore
    @jsii.member(jsii_name="sourceAddressPrefix")
    def source_address_prefix(self) -> builtins.str:
        return jsii.get(self, "sourceAddressPrefix")

    @builtins.property # type: ignore
    @jsii.member(jsii_name="sourceAddressPrefixes")
    def source_address_prefixes(self) -> typing.List[builtins.str]:
        return jsii.get(self, "sourceAddressPrefixes")

    @builtins.property # type: ignore
    @jsii.member(jsii_name="sourceApplicationSecurityGroupIds")
    def source_application_security_group_ids(self) -> typing.List[builtins.str]:
        return jsii.get(self, "sourceApplicationSecurityGroupIds")

    @builtins.property # type: ignore
    @jsii.member(jsii_name="sourcePortRange")
    def source_port_range(self) -> builtins.str:
        return jsii.get(self, "sourcePortRange")

    @builtins.property # type: ignore
    @jsii.member(jsii_name="sourcePortRanges")
    def source_port_ranges(self) -> typing.List[builtins.str]:
        return jsii.get(self, "sourcePortRanges")


@jsii.data_type(
    jsii_type="@cdktf/provider-azurerm.DataAzurermNetworkSecurityGroupTimeouts",
    jsii_struct_bases=[],
    name_mapping={"read": "read"},
)
class DataAzurermNetworkSecurityGroupTimeouts:
    def __init__(self, *, read: typing.Optional[builtins.str] = None) -> None:
        """
        :param read: 
        """
        self._values: typing.Dict[str, typing.Any] = {}
        if read is not None:
            self._values["read"] = read

    @builtins.property
    def read(self) -> typing.Optional[builtins.str]:
        result = self._values.get("read")
        return result

    def __eq__(self, rhs: typing.Any) -> builtins.bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs: typing.Any) -> builtins.bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return "DataAzurermNetworkSecurityGroupTimeouts(%s)" % ", ".join(
            k + "=" + repr(v) for k, v in self._values.items()
        )


class DataAzurermNetworkWatcher(
    cdktf.TerraformDataSource,
    metaclass=jsii.JSIIMeta,
    jsii_type="@cdktf/provider-azurerm.DataAzurermNetworkWatcher",
):
    def __init__(
        self,
        scope: constructs.Construct,
        id: builtins.str,
        *,
        name: builtins.str,
        resource_group_name: builtins.str,
        timeouts: typing.Optional["DataAzurermNetworkWatcherTimeouts"] = None,
        count: typing.Optional[jsii.Number] = None,
        depends_on: typing.Optional[typing.List[cdktf.TerraformResource]] = None,
        lifecycle: typing.Optional[cdktf.TerraformResourceLifecycle] = None,
        provider: typing.Optional[cdktf.TerraformProvider] = None,
    ) -> None:
        """
        :param scope: -
        :param id: -
        :param name: 
        :param resource_group_name: 
        :param timeouts: timeouts block.
        :param count: 
        :param depends_on: 
        :param lifecycle: 
        :param provider: 
        """
        config = DataAzurermNetworkWatcherConfig(
            name=name,
            resource_group_name=resource_group_name,
            timeouts=timeouts,
            count=count,
            depends_on=depends_on,
            lifecycle=lifecycle,
            provider=provider,
        )

        jsii.create(DataAzurermNetworkWatcher, self, [scope, id, config])

    @jsii.member(jsii_name="synthesizeAttributes")
    def _synthesize_attributes(self) -> typing.Mapping[builtins.str, typing.Any]:
        return jsii.invoke(self, "synthesizeAttributes", [])

    @jsii.member(jsii_name="tags")
    def tags(self, key: builtins.str) -> builtins.str:
        """
        :param key: -
        """
        return jsii.invoke(self, "tags", [key])

    @builtins.property # type: ignore
    @jsii.member(jsii_name="location")
    def location(self) -> builtins.str:
        return jsii.get(self, "location")

    @builtins.property # type: ignore
    @jsii.member(jsii_name="name")
    def name(self) -> builtins.str:
        return jsii.get(self, "name")

    @name.setter # type: ignore
    def name(self, value: builtins.str) -> None:
        jsii.set(self, "name", value)

    @builtins.property # type: ignore
    @jsii.member(jsii_name="resourceGroupName")
    def resource_group_name(self) -> builtins.str:
        return jsii.get(self, "resourceGroupName")

    @resource_group_name.setter # type: ignore
    def resource_group_name(self, value: builtins.str) -> None:
        jsii.set(self, "resourceGroupName", value)

    @builtins.property # type: ignore
    @jsii.member(jsii_name="id")
    def id(self) -> typing.Optional[builtins.str]:
        return jsii.get(self, "id")

    @id.setter # type: ignore
    def id(self, value: typing.Optional[builtins.str]) -> None:
        jsii.set(self, "id", value)

    @builtins.property # type: ignore
    @jsii.member(jsii_name="timeouts")
    def timeouts(self) -> typing.Optional["DataAzurermNetworkWatcherTimeouts"]:
        return jsii.get(self, "timeouts")

    @timeouts.setter # type: ignore
    def timeouts(
        self,
        value: typing.Optional["DataAzurermNetworkWatcherTimeouts"],
    ) -> None:
        jsii.set(self, "timeouts", value)


@jsii.data_type(
    jsii_type="@cdktf/provider-azurerm.DataAzurermNetworkWatcherConfig",
    jsii_struct_bases=[cdktf.TerraformMetaArguments],
    name_mapping={
        "count": "count",
        "depends_on": "dependsOn",
        "lifecycle": "lifecycle",
        "provider": "provider",
        "name": "name",
        "resource_group_name": "resourceGroupName",
        "timeouts": "timeouts",
    },
)
class DataAzurermNetworkWatcherConfig(cdktf.TerraformMetaArguments):
    def __init__(
        self,
        *,
        count: typing.Optional[jsii.Number] = None,
        depends_on: typing.Optional[typing.List[cdktf.TerraformResource]] = None,
        lifecycle: typing.Optional[cdktf.TerraformResourceLifecycle] = None,
        provider: typing.Optional[cdktf.TerraformProvider] = None,
        name: builtins.str,
        resource_group_name: builtins.str,
        timeouts: typing.Optional["DataAzurermNetworkWatcherTimeouts"] = None,
    ) -> None:
        """
        :param count: 
        :param depends_on: 
        :param lifecycle: 
        :param provider: 
        :param name: 
        :param resource_group_name: 
        :param timeouts: timeouts block.
        """
        if isinstance(lifecycle, dict):
            lifecycle = cdktf.TerraformResourceLifecycle(**lifecycle)
        if isinstance(timeouts, dict):
            timeouts = DataAzurermNetworkWatcherTimeouts(**timeouts)
        self._values: typing.Dict[str, typing.Any] = {
            "name": name,
            "resource_group_name": resource_group_name,
        }
        if count is not None:
            self._values["count"] = count
        if depends_on is not None:
            self._values["depends_on"] = depends_on
        if lifecycle is not None:
            self._values["lifecycle"] = lifecycle
        if provider is not None:
            self._values["provider"] = provider
        if timeouts is not None:
            self._values["timeouts"] = timeouts

    @builtins.property
    def count(self) -> typing.Optional[jsii.Number]:
        """
        :stability: experimental
        """
        result = self._values.get("count")
        return result

    @builtins.property
    def depends_on(self) -> typing.Optional[typing.List[cdktf.TerraformResource]]:
        """
        :stability: experimental
        """
        result = self._values.get("depends_on")
        return result

    @builtins.property
    def lifecycle(self) -> typing.Optional[cdktf.TerraformResourceLifecycle]:
        """
        :stability: experimental
        """
        result = self._values.get("lifecycle")
        return result

    @builtins.property
    def provider(self) -> typing.Optional[cdktf.TerraformProvider]:
        """
        :stability: experimental
        """
        result = self._values.get("provider")
        return result

    @builtins.property
    def name(self) -> builtins.str:
        result = self._values.get("name")
        assert result is not None, "Required property 'name' is missing"
        return result

    @builtins.property
    def resource_group_name(self) -> builtins.str:
        result = self._values.get("resource_group_name")
        assert result is not None, "Required property 'resource_group_name' is missing"
        return result

    @builtins.property
    def timeouts(self) -> typing.Optional["DataAzurermNetworkWatcherTimeouts"]:
        """timeouts block."""
        result = self._values.get("timeouts")
        return result

    def __eq__(self, rhs: typing.Any) -> builtins.bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs: typing.Any) -> builtins.bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return "DataAzurermNetworkWatcherConfig(%s)" % ", ".join(
            k + "=" + repr(v) for k, v in self._values.items()
        )


@jsii.data_type(
    jsii_type="@cdktf/provider-azurerm.DataAzurermNetworkWatcherTimeouts",
    jsii_struct_bases=[],
    name_mapping={"read": "read"},
)
class DataAzurermNetworkWatcherTimeouts:
    def __init__(self, *, read: typing.Optional[builtins.str] = None) -> None:
        """
        :param read: 
        """
        self._values: typing.Dict[str, typing.Any] = {}
        if read is not None:
            self._values["read"] = read

    @builtins.property
    def read(self) -> typing.Optional[builtins.str]:
        result = self._values.get("read")
        return result

    def __eq__(self, rhs: typing.Any) -> builtins.bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs: typing.Any) -> builtins.bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return "DataAzurermNetworkWatcherTimeouts(%s)" % ", ".join(
            k + "=" + repr(v) for k, v in self._values.items()
        )


class DataAzurermNotificationHub(
    cdktf.TerraformDataSource,
    metaclass=jsii.JSIIMeta,
    jsii_type="@cdktf/provider-azurerm.DataAzurermNotificationHub",
):
    def __init__(
        self,
        scope: constructs.Construct,
        id: builtins.str,
        *,
        name: builtins.str,
        namespace_name: builtins.str,
        resource_group_name: builtins.str,
        timeouts: typing.Optional["DataAzurermNotificationHubTimeouts"] = None,
        count: typing.Optional[jsii.Number] = None,
        depends_on: typing.Optional[typing.List[cdktf.TerraformResource]] = None,
        lifecycle: typing.Optional[cdktf.TerraformResourceLifecycle] = None,
        provider: typing.Optional[cdktf.TerraformProvider] = None,
    ) -> None:
        """
        :param scope: -
        :param id: -
        :param name: 
        :param namespace_name: 
        :param resource_group_name: 
        :param timeouts: timeouts block.
        :param count: 
        :param depends_on: 
        :param lifecycle: 
        :param provider: 
        """
        config = DataAzurermNotificationHubConfig(
            name=name,
            namespace_name=namespace_name,
            resource_group_name=resource_group_name,
            timeouts=timeouts,
            count=count,
            depends_on=depends_on,
            lifecycle=lifecycle,
            provider=provider,
        )

        jsii.create(DataAzurermNotificationHub, self, [scope, id, config])

    @jsii.member(jsii_name="apnsCredential")
    def apns_credential(
        self,
        index: builtins.str,
    ) -> "DataAzurermNotificationHubApnsCredential":
        """
        :param index: -
        """
        return jsii.invoke(self, "apnsCredential", [index])

    @jsii.member(jsii_name="gcmCredential")
    def gcm_credential(
        self,
        index: builtins.str,
    ) -> "DataAzurermNotificationHubGcmCredential":
        """
        :param index: -
        """
        return jsii.invoke(self, "gcmCredential", [index])

    @jsii.member(jsii_name="synthesizeAttributes")
    def _synthesize_attributes(self) -> typing.Mapping[builtins.str, typing.Any]:
        return jsii.invoke(self, "synthesizeAttributes", [])

    @builtins.property # type: ignore
    @jsii.member(jsii_name="location")
    def location(self) -> builtins.str:
        return jsii.get(self, "location")

    @builtins.property # type: ignore
    @jsii.member(jsii_name="name")
    def name(self) -> builtins.str:
        return jsii.get(self, "name")

    @name.setter # type: ignore
    def name(self, value: builtins.str) -> None:
        jsii.set(self, "name", value)

    @builtins.property # type: ignore
    @jsii.member(jsii_name="namespaceName")
    def namespace_name(self) -> builtins.str:
        return jsii.get(self, "namespaceName")

    @namespace_name.setter # type: ignore
    def namespace_name(self, value: builtins.str) -> None:
        jsii.set(self, "namespaceName", value)

    @builtins.property # type: ignore
    @jsii.member(jsii_name="resourceGroupName")
    def resource_group_name(self) -> builtins.str:
        return jsii.get(self, "resourceGroupName")

    @resource_group_name.setter # type: ignore
    def resource_group_name(self, value: builtins.str) -> None:
        jsii.set(self, "resourceGroupName", value)

    @builtins.property # type: ignore
    @jsii.member(jsii_name="id")
    def id(self) -> typing.Optional[builtins.str]:
        return jsii.get(self, "id")

    @id.setter # type: ignore
    def id(self, value: typing.Optional[builtins.str]) -> None:
        jsii.set(self, "id", value)

    @builtins.property # type: ignore
    @jsii.member(jsii_name="timeouts")
    def timeouts(self) -> typing.Optional["DataAzurermNotificationHubTimeouts"]:
        return jsii.get(self, "timeouts")

    @timeouts.setter # type: ignore
    def timeouts(
        self,
        value: typing.Optional["DataAzurermNotificationHubTimeouts"],
    ) -> None:
        jsii.set(self, "timeouts", value)


class DataAzurermNotificationHubApnsCredential(
    cdktf.ComplexComputedList,
    metaclass=jsii.JSIIMeta,
    jsii_type="@cdktf/provider-azurerm.DataAzurermNotificationHubApnsCredential",
):
    def __init__(
        self,
        terraform_resource: cdktf.ITerraformResource,
        terraform_attribute: builtins.str,
        index: builtins.str,
    ) -> None:
        """
        :param terraform_resource: -
        :param terraform_attribute: -
        :param index: -

        :stability: experimental
        """
        jsii.create(DataAzurermNotificationHubApnsCredential, self, [terraform_resource, terraform_attribute, index])

    @builtins.property # type: ignore
    @jsii.member(jsii_name="applicationMode")
    def application_mode(self) -> builtins.str:
        return jsii.get(self, "applicationMode")

    @builtins.property # type: ignore
    @jsii.member(jsii_name="bundleId")
    def bundle_id(self) -> builtins.str:
        return jsii.get(self, "bundleId")

    @builtins.property # type: ignore
    @jsii.member(jsii_name="keyId")
    def key_id(self) -> builtins.str:
        return jsii.get(self, "keyId")

    @builtins.property # type: ignore
    @jsii.member(jsii_name="teamId")
    def team_id(self) -> builtins.str:
        return jsii.get(self, "teamId")

    @builtins.property # type: ignore
    @jsii.member(jsii_name="token")
    def token(self) -> builtins.str:
        return jsii.get(self, "token")


@jsii.data_type(
    jsii_type="@cdktf/provider-azurerm.DataAzurermNotificationHubConfig",
    jsii_struct_bases=[cdktf.TerraformMetaArguments],
    name_mapping={
        "count": "count",
        "depends_on": "dependsOn",
        "lifecycle": "lifecycle",
        "provider": "provider",
        "name": "name",
        "namespace_name": "namespaceName",
        "resource_group_name": "resourceGroupName",
        "timeouts": "timeouts",
    },
)
class DataAzurermNotificationHubConfig(cdktf.TerraformMetaArguments):
    def __init__(
        self,
        *,
        count: typing.Optional[jsii.Number] = None,
        depends_on: typing.Optional[typing.List[cdktf.TerraformResource]] = None,
        lifecycle: typing.Optional[cdktf.TerraformResourceLifecycle] = None,
        provider: typing.Optional[cdktf.TerraformProvider] = None,
        name: builtins.str,
        namespace_name: builtins.str,
        resource_group_name: builtins.str,
        timeouts: typing.Optional["DataAzurermNotificationHubTimeouts"] = None,
    ) -> None:
        """
        :param count: 
        :param depends_on: 
        :param lifecycle: 
        :param provider: 
        :param name: 
        :param namespace_name: 
        :param resource_group_name: 
        :param timeouts: timeouts block.
        """
        if isinstance(lifecycle, dict):
            lifecycle = cdktf.TerraformResourceLifecycle(**lifecycle)
        if isinstance(timeouts, dict):
            timeouts = DataAzurermNotificationHubTimeouts(**timeouts)
        self._values: typing.Dict[str, typing.Any] = {
            "name": name,
            "namespace_name": namespace_name,
            "resource_group_name": resource_group_name,
        }
        if count is not None:
            self._values["count"] = count
        if depends_on is not None:
            self._values["depends_on"] = depends_on
        if lifecycle is not None:
            self._values["lifecycle"] = lifecycle
        if provider is not None:
            self._values["provider"] = provider
        if timeouts is not None:
            self._values["timeouts"] = timeouts

    @builtins.property
    def count(self) -> typing.Optional[jsii.Number]:
        """
        :stability: experimental
        """
        result = self._values.get("count")
        return result

    @builtins.property
    def depends_on(self) -> typing.Optional[typing.List[cdktf.TerraformResource]]:
        """
        :stability: experimental
        """
        result = self._values.get("depends_on")
        return result

    @builtins.property
    def lifecycle(self) -> typing.Optional[cdktf.TerraformResourceLifecycle]:
        """
        :stability: experimental
        """
        result = self._values.get("lifecycle")
        return result

    @builtins.property
    def provider(self) -> typing.Optional[cdktf.TerraformProvider]:
        """
        :stability: experimental
        """
        result = self._values.get("provider")
        return result

    @builtins.property
    def name(self) -> builtins.str:
        result = self._values.get("name")
        assert result is not None, "Required property 'name' is missing"
        return result

    @builtins.property
    def namespace_name(self) -> builtins.str:
        result = self._values.get("namespace_name")
        assert result is not None, "Required property 'namespace_name' is missing"
        return result

    @builtins.property
    def resource_group_name(self) -> builtins.str:
        result = self._values.get("resource_group_name")
        assert result is not None, "Required property 'resource_group_name' is missing"
        return result

    @builtins.property
    def timeouts(self) -> typing.Optional["DataAzurermNotificationHubTimeouts"]:
        """timeouts block."""
        result = self._values.get("timeouts")
        return result

    def __eq__(self, rhs: typing.Any) -> builtins.bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs: typing.Any) -> builtins.bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return "DataAzurermNotificationHubConfig(%s)" % ", ".join(
            k + "=" + repr(v) for k, v in self._values.items()
        )


class DataAzurermNotificationHubGcmCredential(
    cdktf.ComplexComputedList,
    metaclass=jsii.JSIIMeta,
    jsii_type="@cdktf/provider-azurerm.DataAzurermNotificationHubGcmCredential",
):
    def __init__(
        self,
        terraform_resource: cdktf.ITerraformResource,
        terraform_attribute: builtins.str,
        index: builtins.str,
    ) -> None:
        """
        :param terraform_resource: -
        :param terraform_attribute: -
        :param index: -

        :stability: experimental
        """
        jsii.create(DataAzurermNotificationHubGcmCredential, self, [terraform_resource, terraform_attribute, index])

    @builtins.property # type: ignore
    @jsii.member(jsii_name="apiKey")
    def api_key(self) -> builtins.str:
        return jsii.get(self, "apiKey")


class DataAzurermNotificationHubNamespace(
    cdktf.TerraformDataSource,
    metaclass=jsii.JSIIMeta,
    jsii_type="@cdktf/provider-azurerm.DataAzurermNotificationHubNamespace",
):
    def __init__(
        self,
        scope: constructs.Construct,
        id: builtins.str,
        *,
        name: builtins.str,
        resource_group_name: builtins.str,
        timeouts: typing.Optional["DataAzurermNotificationHubNamespaceTimeouts"] = None,
        count: typing.Optional[jsii.Number] = None,
        depends_on: typing.Optional[typing.List[cdktf.TerraformResource]] = None,
        lifecycle: typing.Optional[cdktf.TerraformResourceLifecycle] = None,
        provider: typing.Optional[cdktf.TerraformProvider] = None,
    ) -> None:
        """
        :param scope: -
        :param id: -
        :param name: 
        :param resource_group_name: 
        :param timeouts: timeouts block.
        :param count: 
        :param depends_on: 
        :param lifecycle: 
        :param provider: 
        """
        config = DataAzurermNotificationHubNamespaceConfig(
            name=name,
            resource_group_name=resource_group_name,
            timeouts=timeouts,
            count=count,
            depends_on=depends_on,
            lifecycle=lifecycle,
            provider=provider,
        )

        jsii.create(DataAzurermNotificationHubNamespace, self, [scope, id, config])

    @jsii.member(jsii_name="sku")
    def sku(self, index: builtins.str) -> "DataAzurermNotificationHubNamespaceSku":
        """
        :param index: -
        """
        return jsii.invoke(self, "sku", [index])

    @jsii.member(jsii_name="synthesizeAttributes")
    def _synthesize_attributes(self) -> typing.Mapping[builtins.str, typing.Any]:
        return jsii.invoke(self, "synthesizeAttributes", [])

    @builtins.property # type: ignore
    @jsii.member(jsii_name="enabled")
    def enabled(self) -> builtins.bool:
        return jsii.get(self, "enabled")

    @builtins.property # type: ignore
    @jsii.member(jsii_name="location")
    def location(self) -> builtins.str:
        return jsii.get(self, "location")

    @builtins.property # type: ignore
    @jsii.member(jsii_name="namespaceType")
    def namespace_type(self) -> builtins.str:
        return jsii.get(self, "namespaceType")

    @builtins.property # type: ignore
    @jsii.member(jsii_name="servicebusEndpoint")
    def servicebus_endpoint(self) -> builtins.str:
        return jsii.get(self, "servicebusEndpoint")

    @builtins.property # type: ignore
    @jsii.member(jsii_name="name")
    def name(self) -> builtins.str:
        return jsii.get(self, "name")

    @name.setter # type: ignore
    def name(self, value: builtins.str) -> None:
        jsii.set(self, "name", value)

    @builtins.property # type: ignore
    @jsii.member(jsii_name="resourceGroupName")
    def resource_group_name(self) -> builtins.str:
        return jsii.get(self, "resourceGroupName")

    @resource_group_name.setter # type: ignore
    def resource_group_name(self, value: builtins.str) -> None:
        jsii.set(self, "resourceGroupName", value)

    @builtins.property # type: ignore
    @jsii.member(jsii_name="id")
    def id(self) -> typing.Optional[builtins.str]:
        return jsii.get(self, "id")

    @id.setter # type: ignore
    def id(self, value: typing.Optional[builtins.str]) -> None:
        jsii.set(self, "id", value)

    @builtins.property # type: ignore
    @jsii.member(jsii_name="timeouts")
    def timeouts(
        self,
    ) -> typing.Optional["DataAzurermNotificationHubNamespaceTimeouts"]:
        return jsii.get(self, "timeouts")

    @timeouts.setter # type: ignore
    def timeouts(
        self,
        value: typing.Optional["DataAzurermNotificationHubNamespaceTimeouts"],
    ) -> None:
        jsii.set(self, "timeouts", value)


@jsii.data_type(
    jsii_type="@cdktf/provider-azurerm.DataAzurermNotificationHubNamespaceConfig",
    jsii_struct_bases=[cdktf.TerraformMetaArguments],
    name_mapping={
        "count": "count",
        "depends_on": "dependsOn",
        "lifecycle": "lifecycle",
        "provider": "provider",
        "name": "name",
        "resource_group_name": "resourceGroupName",
        "timeouts": "timeouts",
    },
)
class DataAzurermNotificationHubNamespaceConfig(cdktf.TerraformMetaArguments):
    def __init__(
        self,
        *,
        count: typing.Optional[jsii.Number] = None,
        depends_on: typing.Optional[typing.List[cdktf.TerraformResource]] = None,
        lifecycle: typing.Optional[cdktf.TerraformResourceLifecycle] = None,
        provider: typing.Optional[cdktf.TerraformProvider] = None,
        name: builtins.str,
        resource_group_name: builtins.str,
        timeouts: typing.Optional["DataAzurermNotificationHubNamespaceTimeouts"] = None,
    ) -> None:
        """
        :param count: 
        :param depends_on: 
        :param lifecycle: 
        :param provider: 
        :param name: 
        :param resource_group_name: 
        :param timeouts: timeouts block.
        """
        if isinstance(lifecycle, dict):
            lifecycle = cdktf.TerraformResourceLifecycle(**lifecycle)
        if isinstance(timeouts, dict):
            timeouts = DataAzurermNotificationHubNamespaceTimeouts(**timeouts)
        self._values: typing.Dict[str, typing.Any] = {
            "name": name,
            "resource_group_name": resource_group_name,
        }
        if count is not None:
            self._values["count"] = count
        if depends_on is not None:
            self._values["depends_on"] = depends_on
        if lifecycle is not None:
            self._values["lifecycle"] = lifecycle
        if provider is not None:
            self._values["provider"] = provider
        if timeouts is not None:
            self._values["timeouts"] = timeouts

    @builtins.property
    def count(self) -> typing.Optional[jsii.Number]:
        """
        :stability: experimental
        """
        result = self._values.get("count")
        return result

    @builtins.property
    def depends_on(self) -> typing.Optional[typing.List[cdktf.TerraformResource]]:
        """
        :stability: experimental
        """
        result = self._values.get("depends_on")
        return result

    @builtins.property
    def lifecycle(self) -> typing.Optional[cdktf.TerraformResourceLifecycle]:
        """
        :stability: experimental
        """
        result = self._values.get("lifecycle")
        return result

    @builtins.property
    def provider(self) -> typing.Optional[cdktf.TerraformProvider]:
        """
        :stability: experimental
        """
        result = self._values.get("provider")
        return result

    @builtins.property
    def name(self) -> builtins.str:
        result = self._values.get("name")
        assert result is not None, "Required property 'name' is missing"
        return result

    @builtins.property
    def resource_group_name(self) -> builtins.str:
        result = self._values.get("resource_group_name")
        assert result is not None, "Required property 'resource_group_name' is missing"
        return result

    @builtins.property
    def timeouts(
        self,
    ) -> typing.Optional["DataAzurermNotificationHubNamespaceTimeouts"]:
        """timeouts block."""
        result = self._values.get("timeouts")
        return result

    def __eq__(self, rhs: typing.Any) -> builtins.bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs: typing.Any) -> builtins.bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return "DataAzurermNotificationHubNamespaceConfig(%s)" % ", ".join(
            k + "=" + repr(v) for k, v in self._values.items()
        )


class DataAzurermNotificationHubNamespaceSku(
    cdktf.ComplexComputedList,
    metaclass=jsii.JSIIMeta,
    jsii_type="@cdktf/provider-azurerm.DataAzurermNotificationHubNamespaceSku",
):
    def __init__(
        self,
        terraform_resource: cdktf.ITerraformResource,
        terraform_attribute: builtins.str,
        index: builtins.str,
    ) -> None:
        """
        :param terraform_resource: -
        :param terraform_attribute: -
        :param index: -

        :stability: experimental
        """
        jsii.create(DataAzurermNotificationHubNamespaceSku, self, [terraform_resource, terraform_attribute, index])

    @builtins.property # type: ignore
    @jsii.member(jsii_name="name")
    def name(self) -> builtins.str:
        return jsii.get(self, "name")


@jsii.data_type(
    jsii_type="@cdktf/provider-azurerm.DataAzurermNotificationHubNamespaceTimeouts",
    jsii_struct_bases=[],
    name_mapping={"read": "read"},
)
class DataAzurermNotificationHubNamespaceTimeouts:
    def __init__(self, *, read: typing.Optional[builtins.str] = None) -> None:
        """
        :param read: 
        """
        self._values: typing.Dict[str, typing.Any] = {}
        if read is not None:
            self._values["read"] = read

    @builtins.property
    def read(self) -> typing.Optional[builtins.str]:
        result = self._values.get("read")
        return result

    def __eq__(self, rhs: typing.Any) -> builtins.bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs: typing.Any) -> builtins.bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return "DataAzurermNotificationHubNamespaceTimeouts(%s)" % ", ".join(
            k + "=" + repr(v) for k, v in self._values.items()
        )


@jsii.data_type(
    jsii_type="@cdktf/provider-azurerm.DataAzurermNotificationHubTimeouts",
    jsii_struct_bases=[],
    name_mapping={"read": "read"},
)
class DataAzurermNotificationHubTimeouts:
    def __init__(self, *, read: typing.Optional[builtins.str] = None) -> None:
        """
        :param read: 
        """
        self._values: typing.Dict[str, typing.Any] = {}
        if read is not None:
            self._values["read"] = read

    @builtins.property
    def read(self) -> typing.Optional[builtins.str]:
        result = self._values.get("read")
        return result

    def __eq__(self, rhs: typing.Any) -> builtins.bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs: typing.Any) -> builtins.bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return "DataAzurermNotificationHubTimeouts(%s)" % ", ".join(
            k + "=" + repr(v) for k, v in self._values.items()
        )


class DataAzurermPlatformImage(
    cdktf.TerraformDataSource,
    metaclass=jsii.JSIIMeta,
    jsii_type="@cdktf/provider-azurerm.DataAzurermPlatformImage",
):
    def __init__(
        self,
        scope: constructs.Construct,
        id: builtins.str,
        *,
        location: builtins.str,
        offer: builtins.str,
        publisher: builtins.str,
        sku: builtins.str,
        timeouts: typing.Optional["DataAzurermPlatformImageTimeouts"] = None,
        count: typing.Optional[jsii.Number] = None,
        depends_on: typing.Optional[typing.List[cdktf.TerraformResource]] = None,
        lifecycle: typing.Optional[cdktf.TerraformResourceLifecycle] = None,
        provider: typing.Optional[cdktf.TerraformProvider] = None,
    ) -> None:
        """
        :param scope: -
        :param id: -
        :param location: 
        :param offer: 
        :param publisher: 
        :param sku: 
        :param timeouts: timeouts block.
        :param count: 
        :param depends_on: 
        :param lifecycle: 
        :param provider: 
        """
        config = DataAzurermPlatformImageConfig(
            location=location,
            offer=offer,
            publisher=publisher,
            sku=sku,
            timeouts=timeouts,
            count=count,
            depends_on=depends_on,
            lifecycle=lifecycle,
            provider=provider,
        )

        jsii.create(DataAzurermPlatformImage, self, [scope, id, config])

    @jsii.member(jsii_name="synthesizeAttributes")
    def _synthesize_attributes(self) -> typing.Mapping[builtins.str, typing.Any]:
        return jsii.invoke(self, "synthesizeAttributes", [])

    @builtins.property # type: ignore
    @jsii.member(jsii_name="version")
    def version(self) -> builtins.str:
        return jsii.get(self, "version")

    @builtins.property # type: ignore
    @jsii.member(jsii_name="location")
    def location(self) -> builtins.str:
        return jsii.get(self, "location")

    @location.setter # type: ignore
    def location(self, value: builtins.str) -> None:
        jsii.set(self, "location", value)

    @builtins.property # type: ignore
    @jsii.member(jsii_name="offer")
    def offer(self) -> builtins.str:
        return jsii.get(self, "offer")

    @offer.setter # type: ignore
    def offer(self, value: builtins.str) -> None:
        jsii.set(self, "offer", value)

    @builtins.property # type: ignore
    @jsii.member(jsii_name="publisher")
    def publisher(self) -> builtins.str:
        return jsii.get(self, "publisher")

    @publisher.setter # type: ignore
    def publisher(self, value: builtins.str) -> None:
        jsii.set(self, "publisher", value)

    @builtins.property # type: ignore
    @jsii.member(jsii_name="sku")
    def sku(self) -> builtins.str:
        return jsii.get(self, "sku")

    @sku.setter # type: ignore
    def sku(self, value: builtins.str) -> None:
        jsii.set(self, "sku", value)

    @builtins.property # type: ignore
    @jsii.member(jsii_name="id")
    def id(self) -> typing.Optional[builtins.str]:
        return jsii.get(self, "id")

    @id.setter # type: ignore
    def id(self, value: typing.Optional[builtins.str]) -> None:
        jsii.set(self, "id", value)

    @builtins.property # type: ignore
    @jsii.member(jsii_name="timeouts")
    def timeouts(self) -> typing.Optional["DataAzurermPlatformImageTimeouts"]:
        return jsii.get(self, "timeouts")

    @timeouts.setter # type: ignore
    def timeouts(
        self,
        value: typing.Optional["DataAzurermPlatformImageTimeouts"],
    ) -> None:
        jsii.set(self, "timeouts", value)


@jsii.data_type(
    jsii_type="@cdktf/provider-azurerm.DataAzurermPlatformImageConfig",
    jsii_struct_bases=[cdktf.TerraformMetaArguments],
    name_mapping={
        "count": "count",
        "depends_on": "dependsOn",
        "lifecycle": "lifecycle",
        "provider": "provider",
        "location": "location",
        "offer": "offer",
        "publisher": "publisher",
        "sku": "sku",
        "timeouts": "timeouts",
    },
)
class DataAzurermPlatformImageConfig(cdktf.TerraformMetaArguments):
    def __init__(
        self,
        *,
        count: typing.Optional[jsii.Number] = None,
        depends_on: typing.Optional[typing.List[cdktf.TerraformResource]] = None,
        lifecycle: typing.Optional[cdktf.TerraformResourceLifecycle] = None,
        provider: typing.Optional[cdktf.TerraformProvider] = None,
        location: builtins.str,
        offer: builtins.str,
        publisher: builtins.str,
        sku: builtins.str,
        timeouts: typing.Optional["DataAzurermPlatformImageTimeouts"] = None,
    ) -> None:
        """
        :param count: 
        :param depends_on: 
        :param lifecycle: 
        :param provider: 
        :param location: 
        :param offer: 
        :param publisher: 
        :param sku: 
        :param timeouts: timeouts block.
        """
        if isinstance(lifecycle, dict):
            lifecycle = cdktf.TerraformResourceLifecycle(**lifecycle)
        if isinstance(timeouts, dict):
            timeouts = DataAzurermPlatformImageTimeouts(**timeouts)
        self._values: typing.Dict[str, typing.Any] = {
            "location": location,
            "offer": offer,
            "publisher": publisher,
            "sku": sku,
        }
        if count is not None:
            self._values["count"] = count
        if depends_on is not None:
            self._values["depends_on"] = depends_on
        if lifecycle is not None:
            self._values["lifecycle"] = lifecycle
        if provider is not None:
            self._values["provider"] = provider
        if timeouts is not None:
            self._values["timeouts"] = timeouts

    @builtins.property
    def count(self) -> typing.Optional[jsii.Number]:
        """
        :stability: experimental
        """
        result = self._values.get("count")
        return result

    @builtins.property
    def depends_on(self) -> typing.Optional[typing.List[cdktf.TerraformResource]]:
        """
        :stability: experimental
        """
        result = self._values.get("depends_on")
        return result

    @builtins.property
    def lifecycle(self) -> typing.Optional[cdktf.TerraformResourceLifecycle]:
        """
        :stability: experimental
        """
        result = self._values.get("lifecycle")
        return result

    @builtins.property
    def provider(self) -> typing.Optional[cdktf.TerraformProvider]:
        """
        :stability: experimental
        """
        result = self._values.get("provider")
        return result

    @builtins.property
    def location(self) -> builtins.str:
        result = self._values.get("location")
        assert result is not None, "Required property 'location' is missing"
        return result

    @builtins.property
    def offer(self) -> builtins.str:
        result = self._values.get("offer")
        assert result is not None, "Required property 'offer' is missing"
        return result

    @builtins.property
    def publisher(self) -> builtins.str:
        result = self._values.get("publisher")
        assert result is not None, "Required property 'publisher' is missing"
        return result

    @builtins.property
    def sku(self) -> builtins.str:
        result = self._values.get("sku")
        assert result is not None, "Required property 'sku' is missing"
        return result

    @builtins.property
    def timeouts(self) -> typing.Optional["DataAzurermPlatformImageTimeouts"]:
        """timeouts block."""
        result = self._values.get("timeouts")
        return result

    def __eq__(self, rhs: typing.Any) -> builtins.bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs: typing.Any) -> builtins.bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return "DataAzurermPlatformImageConfig(%s)" % ", ".join(
            k + "=" + repr(v) for k, v in self._values.items()
        )


@jsii.data_type(
    jsii_type="@cdktf/provider-azurerm.DataAzurermPlatformImageTimeouts",
    jsii_struct_bases=[],
    name_mapping={"read": "read"},
)
class DataAzurermPlatformImageTimeouts:
    def __init__(self, *, read: typing.Optional[builtins.str] = None) -> None:
        """
        :param read: 
        """
        self._values: typing.Dict[str, typing.Any] = {}
        if read is not None:
            self._values["read"] = read

    @builtins.property
    def read(self) -> typing.Optional[builtins.str]:
        result = self._values.get("read")
        return result

    def __eq__(self, rhs: typing.Any) -> builtins.bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs: typing.Any) -> builtins.bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return "DataAzurermPlatformImageTimeouts(%s)" % ", ".join(
            k + "=" + repr(v) for k, v in self._values.items()
        )


class DataAzurermPolicyDefinition(
    cdktf.TerraformDataSource,
    metaclass=jsii.JSIIMeta,
    jsii_type="@cdktf/provider-azurerm.DataAzurermPolicyDefinition",
):
    def __init__(
        self,
        scope: constructs.Construct,
        id: builtins.str,
        *,
        display_name: builtins.str,
        management_group_id: typing.Optional[builtins.str] = None,
        timeouts: typing.Optional["DataAzurermPolicyDefinitionTimeouts"] = None,
        count: typing.Optional[jsii.Number] = None,
        depends_on: typing.Optional[typing.List[cdktf.TerraformResource]] = None,
        lifecycle: typing.Optional[cdktf.TerraformResourceLifecycle] = None,
        provider: typing.Optional[cdktf.TerraformProvider] = None,
    ) -> None:
        """
        :param scope: -
        :param id: -
        :param display_name: 
        :param management_group_id: 
        :param timeouts: timeouts block.
        :param count: 
        :param depends_on: 
        :param lifecycle: 
        :param provider: 
        """
        config = DataAzurermPolicyDefinitionConfig(
            display_name=display_name,
            management_group_id=management_group_id,
            timeouts=timeouts,
            count=count,
            depends_on=depends_on,
            lifecycle=lifecycle,
            provider=provider,
        )

        jsii.create(DataAzurermPolicyDefinition, self, [scope, id, config])

    @jsii.member(jsii_name="synthesizeAttributes")
    def _synthesize_attributes(self) -> typing.Mapping[builtins.str, typing.Any]:
        return jsii.invoke(self, "synthesizeAttributes", [])

    @builtins.property # type: ignore
    @jsii.member(jsii_name="description")
    def description(self) -> builtins.str:
        return jsii.get(self, "description")

    @builtins.property # type: ignore
    @jsii.member(jsii_name="metadata")
    def metadata(self) -> builtins.str:
        return jsii.get(self, "metadata")

    @builtins.property # type: ignore
    @jsii.member(jsii_name="name")
    def name(self) -> builtins.str:
        return jsii.get(self, "name")

    @builtins.property # type: ignore
    @jsii.member(jsii_name="parameters")
    def parameters(self) -> builtins.str:
        return jsii.get(self, "parameters")

    @builtins.property # type: ignore
    @jsii.member(jsii_name="policyRule")
    def policy_rule(self) -> builtins.str:
        return jsii.get(self, "policyRule")

    @builtins.property # type: ignore
    @jsii.member(jsii_name="policyType")
    def policy_type(self) -> builtins.str:
        return jsii.get(self, "policyType")

    @builtins.property # type: ignore
    @jsii.member(jsii_name="type")
    def type(self) -> builtins.str:
        return jsii.get(self, "type")

    @builtins.property # type: ignore
    @jsii.member(jsii_name="displayName")
    def display_name(self) -> builtins.str:
        return jsii.get(self, "displayName")

    @display_name.setter # type: ignore
    def display_name(self, value: builtins.str) -> None:
        jsii.set(self, "displayName", value)

    @builtins.property # type: ignore
    @jsii.member(jsii_name="id")
    def id(self) -> typing.Optional[builtins.str]:
        return jsii.get(self, "id")

    @id.setter # type: ignore
    def id(self, value: typing.Optional[builtins.str]) -> None:
        jsii.set(self, "id", value)

    @builtins.property # type: ignore
    @jsii.member(jsii_name="managementGroupId")
    def management_group_id(self) -> typing.Optional[builtins.str]:
        return jsii.get(self, "managementGroupId")

    @management_group_id.setter # type: ignore
    def management_group_id(self, value: typing.Optional[builtins.str]) -> None:
        jsii.set(self, "managementGroupId", value)

    @builtins.property # type: ignore
    @jsii.member(jsii_name="timeouts")
    def timeouts(self) -> typing.Optional["DataAzurermPolicyDefinitionTimeouts"]:
        return jsii.get(self, "timeouts")

    @timeouts.setter # type: ignore
    def timeouts(
        self,
        value: typing.Optional["DataAzurermPolicyDefinitionTimeouts"],
    ) -> None:
        jsii.set(self, "timeouts", value)


@jsii.data_type(
    jsii_type="@cdktf/provider-azurerm.DataAzurermPolicyDefinitionConfig",
    jsii_struct_bases=[cdktf.TerraformMetaArguments],
    name_mapping={
        "count": "count",
        "depends_on": "dependsOn",
        "lifecycle": "lifecycle",
        "provider": "provider",
        "display_name": "displayName",
        "management_group_id": "managementGroupId",
        "timeouts": "timeouts",
    },
)
class DataAzurermPolicyDefinitionConfig(cdktf.TerraformMetaArguments):
    def __init__(
        self,
        *,
        count: typing.Optional[jsii.Number] = None,
        depends_on: typing.Optional[typing.List[cdktf.TerraformResource]] = None,
        lifecycle: typing.Optional[cdktf.TerraformResourceLifecycle] = None,
        provider: typing.Optional[cdktf.TerraformProvider] = None,
        display_name: builtins.str,
        management_group_id: typing.Optional[builtins.str] = None,
        timeouts: typing.Optional["DataAzurermPolicyDefinitionTimeouts"] = None,
    ) -> None:
        """
        :param count: 
        :param depends_on: 
        :param lifecycle: 
        :param provider: 
        :param display_name: 
        :param management_group_id: 
        :param timeouts: timeouts block.
        """
        if isinstance(lifecycle, dict):
            lifecycle = cdktf.TerraformResourceLifecycle(**lifecycle)
        if isinstance(timeouts, dict):
            timeouts = DataAzurermPolicyDefinitionTimeouts(**timeouts)
        self._values: typing.Dict[str, typing.Any] = {
            "display_name": display_name,
        }
        if count is not None:
            self._values["count"] = count
        if depends_on is not None:
            self._values["depends_on"] = depends_on
        if lifecycle is not None:
            self._values["lifecycle"] = lifecycle
        if provider is not None:
            self._values["provider"] = provider
        if management_group_id is not None:
            self._values["management_group_id"] = management_group_id
        if timeouts is not None:
            self._values["timeouts"] = timeouts

    @builtins.property
    def count(self) -> typing.Optional[jsii.Number]:
        """
        :stability: experimental
        """
        result = self._values.get("count")
        return result

    @builtins.property
    def depends_on(self) -> typing.Optional[typing.List[cdktf.TerraformResource]]:
        """
        :stability: experimental
        """
        result = self._values.get("depends_on")
        return result

    @builtins.property
    def lifecycle(self) -> typing.Optional[cdktf.TerraformResourceLifecycle]:
        """
        :stability: experimental
        """
        result = self._values.get("lifecycle")
        return result

    @builtins.property
    def provider(self) -> typing.Optional[cdktf.TerraformProvider]:
        """
        :stability: experimental
        """
        result = self._values.get("provider")
        return result

    @builtins.property
    def display_name(self) -> builtins.str:
        result = self._values.get("display_name")
        assert result is not None, "Required property 'display_name' is missing"
        return result

    @builtins.property
    def management_group_id(self) -> typing.Optional[builtins.str]:
        result = self._values.get("management_group_id")
        return result

    @builtins.property
    def timeouts(self) -> typing.Optional["DataAzurermPolicyDefinitionTimeouts"]:
        """timeouts block."""
        result = self._values.get("timeouts")
        return result

    def __eq__(self, rhs: typing.Any) -> builtins.bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs: typing.Any) -> builtins.bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return "DataAzurermPolicyDefinitionConfig(%s)" % ", ".join(
            k + "=" + repr(v) for k, v in self._values.items()
        )


@jsii.data_type(
    jsii_type="@cdktf/provider-azurerm.DataAzurermPolicyDefinitionTimeouts",
    jsii_struct_bases=[],
    name_mapping={"read": "read"},
)
class DataAzurermPolicyDefinitionTimeouts:
    def __init__(self, *, read: typing.Optional[builtins.str] = None) -> None:
        """
        :param read: 
        """
        self._values: typing.Dict[str, typing.Any] = {}
        if read is not None:
            self._values["read"] = read

    @builtins.property
    def read(self) -> typing.Optional[builtins.str]:
        result = self._values.get("read")
        return result

    def __eq__(self, rhs: typing.Any) -> builtins.bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs: typing.Any) -> builtins.bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return "DataAzurermPolicyDefinitionTimeouts(%s)" % ", ".join(
            k + "=" + repr(v) for k, v in self._values.items()
        )


class DataAzurermPostgresqlServer(
    cdktf.TerraformDataSource,
    metaclass=jsii.JSIIMeta,
    jsii_type="@cdktf/provider-azurerm.DataAzurermPostgresqlServer",
):
    def __init__(
        self,
        scope: constructs.Construct,
        id: builtins.str,
        *,
        name: builtins.str,
        resource_group_name: builtins.str,
        timeouts: typing.Optional["DataAzurermPostgresqlServerTimeouts"] = None,
        count: typing.Optional[jsii.Number] = None,
        depends_on: typing.Optional[typing.List[cdktf.TerraformResource]] = None,
        lifecycle: typing.Optional[cdktf.TerraformResourceLifecycle] = None,
        provider: typing.Optional[cdktf.TerraformProvider] = None,
    ) -> None:
        """
        :param scope: -
        :param id: -
        :param name: 
        :param resource_group_name: 
        :param timeouts: timeouts block.
        :param count: 
        :param depends_on: 
        :param lifecycle: 
        :param provider: 
        """
        config = DataAzurermPostgresqlServerConfig(
            name=name,
            resource_group_name=resource_group_name,
            timeouts=timeouts,
            count=count,
            depends_on=depends_on,
            lifecycle=lifecycle,
            provider=provider,
        )

        jsii.create(DataAzurermPostgresqlServer, self, [scope, id, config])

    @jsii.member(jsii_name="synthesizeAttributes")
    def _synthesize_attributes(self) -> typing.Mapping[builtins.str, typing.Any]:
        return jsii.invoke(self, "synthesizeAttributes", [])

    @jsii.member(jsii_name="tags")
    def tags(self, key: builtins.str) -> builtins.str:
        """
        :param key: -
        """
        return jsii.invoke(self, "tags", [key])

    @builtins.property # type: ignore
    @jsii.member(jsii_name="administratorLogin")
    def administrator_login(self) -> builtins.str:
        return jsii.get(self, "administratorLogin")

    @builtins.property # type: ignore
    @jsii.member(jsii_name="fqdn")
    def fqdn(self) -> builtins.str:
        return jsii.get(self, "fqdn")

    @builtins.property # type: ignore
    @jsii.member(jsii_name="location")
    def location(self) -> builtins.str:
        return jsii.get(self, "location")

    @builtins.property # type: ignore
    @jsii.member(jsii_name="version")
    def version(self) -> builtins.str:
        return jsii.get(self, "version")

    @builtins.property # type: ignore
    @jsii.member(jsii_name="name")
    def name(self) -> builtins.str:
        return jsii.get(self, "name")

    @name.setter # type: ignore
    def name(self, value: builtins.str) -> None:
        jsii.set(self, "name", value)

    @builtins.property # type: ignore
    @jsii.member(jsii_name="resourceGroupName")
    def resource_group_name(self) -> builtins.str:
        return jsii.get(self, "resourceGroupName")

    @resource_group_name.setter # type: ignore
    def resource_group_name(self, value: builtins.str) -> None:
        jsii.set(self, "resourceGroupName", value)

    @builtins.property # type: ignore
    @jsii.member(jsii_name="id")
    def id(self) -> typing.Optional[builtins.str]:
        return jsii.get(self, "id")

    @id.setter # type: ignore
    def id(self, value: typing.Optional[builtins.str]) -> None:
        jsii.set(self, "id", value)

    @builtins.property # type: ignore
    @jsii.member(jsii_name="timeouts")
    def timeouts(self) -> typing.Optional["DataAzurermPostgresqlServerTimeouts"]:
        return jsii.get(self, "timeouts")

    @timeouts.setter # type: ignore
    def timeouts(
        self,
        value: typing.Optional["DataAzurermPostgresqlServerTimeouts"],
    ) -> None:
        jsii.set(self, "timeouts", value)


@jsii.data_type(
    jsii_type="@cdktf/provider-azurerm.DataAzurermPostgresqlServerConfig",
    jsii_struct_bases=[cdktf.TerraformMetaArguments],
    name_mapping={
        "count": "count",
        "depends_on": "dependsOn",
        "lifecycle": "lifecycle",
        "provider": "provider",
        "name": "name",
        "resource_group_name": "resourceGroupName",
        "timeouts": "timeouts",
    },
)
class DataAzurermPostgresqlServerConfig(cdktf.TerraformMetaArguments):
    def __init__(
        self,
        *,
        count: typing.Optional[jsii.Number] = None,
        depends_on: typing.Optional[typing.List[cdktf.TerraformResource]] = None,
        lifecycle: typing.Optional[cdktf.TerraformResourceLifecycle] = None,
        provider: typing.Optional[cdktf.TerraformProvider] = None,
        name: builtins.str,
        resource_group_name: builtins.str,
        timeouts: typing.Optional["DataAzurermPostgresqlServerTimeouts"] = None,
    ) -> None:
        """
        :param count: 
        :param depends_on: 
        :param lifecycle: 
        :param provider: 
        :param name: 
        :param resource_group_name: 
        :param timeouts: timeouts block.
        """
        if isinstance(lifecycle, dict):
            lifecycle = cdktf.TerraformResourceLifecycle(**lifecycle)
        if isinstance(timeouts, dict):
            timeouts = DataAzurermPostgresqlServerTimeouts(**timeouts)
        self._values: typing.Dict[str, typing.Any] = {
            "name": name,
            "resource_group_name": resource_group_name,
        }
        if count is not None:
            self._values["count"] = count
        if depends_on is not None:
            self._values["depends_on"] = depends_on
        if lifecycle is not None:
            self._values["lifecycle"] = lifecycle
        if provider is not None:
            self._values["provider"] = provider
        if timeouts is not None:
            self._values["timeouts"] = timeouts

    @builtins.property
    def count(self) -> typing.Optional[jsii.Number]:
        """
        :stability: experimental
        """
        result = self._values.get("count")
        return result

    @builtins.property
    def depends_on(self) -> typing.Optional[typing.List[cdktf.TerraformResource]]:
        """
        :stability: experimental
        """
        result = self._values.get("depends_on")
        return result

    @builtins.property
    def lifecycle(self) -> typing.Optional[cdktf.TerraformResourceLifecycle]:
        """
        :stability: experimental
        """
        result = self._values.get("lifecycle")
        return result

    @builtins.property
    def provider(self) -> typing.Optional[cdktf.TerraformProvider]:
        """
        :stability: experimental
        """
        result = self._values.get("provider")
        return result

    @builtins.property
    def name(self) -> builtins.str:
        result = self._values.get("name")
        assert result is not None, "Required property 'name' is missing"
        return result

    @builtins.property
    def resource_group_name(self) -> builtins.str:
        result = self._values.get("resource_group_name")
        assert result is not None, "Required property 'resource_group_name' is missing"
        return result

    @builtins.property
    def timeouts(self) -> typing.Optional["DataAzurermPostgresqlServerTimeouts"]:
        """timeouts block."""
        result = self._values.get("timeouts")
        return result

    def __eq__(self, rhs: typing.Any) -> builtins.bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs: typing.Any) -> builtins.bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return "DataAzurermPostgresqlServerConfig(%s)" % ", ".join(
            k + "=" + repr(v) for k, v in self._values.items()
        )


@jsii.data_type(
    jsii_type="@cdktf/provider-azurerm.DataAzurermPostgresqlServerTimeouts",
    jsii_struct_bases=[],
    name_mapping={"read": "read"},
)
class DataAzurermPostgresqlServerTimeouts:
    def __init__(self, *, read: typing.Optional[builtins.str] = None) -> None:
        """
        :param read: 
        """
        self._values: typing.Dict[str, typing.Any] = {}
        if read is not None:
            self._values["read"] = read

    @builtins.property
    def read(self) -> typing.Optional[builtins.str]:
        result = self._values.get("read")
        return result

    def __eq__(self, rhs: typing.Any) -> builtins.bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs: typing.Any) -> builtins.bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return "DataAzurermPostgresqlServerTimeouts(%s)" % ", ".join(
            k + "=" + repr(v) for k, v in self._values.items()
        )


class DataAzurermPrivateEndpointConnection(
    cdktf.TerraformDataSource,
    metaclass=jsii.JSIIMeta,
    jsii_type="@cdktf/provider-azurerm.DataAzurermPrivateEndpointConnection",
):
    def __init__(
        self,
        scope: constructs.Construct,
        id: builtins.str,
        *,
        name: builtins.str,
        resource_group_name: builtins.str,
        timeouts: typing.Optional["DataAzurermPrivateEndpointConnectionTimeouts"] = None,
        count: typing.Optional[jsii.Number] = None,
        depends_on: typing.Optional[typing.List[cdktf.TerraformResource]] = None,
        lifecycle: typing.Optional[cdktf.TerraformResourceLifecycle] = None,
        provider: typing.Optional[cdktf.TerraformProvider] = None,
    ) -> None:
        """
        :param scope: -
        :param id: -
        :param name: 
        :param resource_group_name: 
        :param timeouts: timeouts block.
        :param count: 
        :param depends_on: 
        :param lifecycle: 
        :param provider: 
        """
        config = DataAzurermPrivateEndpointConnectionConfig(
            name=name,
            resource_group_name=resource_group_name,
            timeouts=timeouts,
            count=count,
            depends_on=depends_on,
            lifecycle=lifecycle,
            provider=provider,
        )

        jsii.create(DataAzurermPrivateEndpointConnection, self, [scope, id, config])

    @jsii.member(jsii_name="privateServiceConnection")
    def private_service_connection(
        self,
        index: builtins.str,
    ) -> "DataAzurermPrivateEndpointConnectionPrivateServiceConnection":
        """
        :param index: -
        """
        return jsii.invoke(self, "privateServiceConnection", [index])

    @jsii.member(jsii_name="synthesizeAttributes")
    def _synthesize_attributes(self) -> typing.Mapping[builtins.str, typing.Any]:
        return jsii.invoke(self, "synthesizeAttributes", [])

    @builtins.property # type: ignore
    @jsii.member(jsii_name="location")
    def location(self) -> builtins.str:
        return jsii.get(self, "location")

    @builtins.property # type: ignore
    @jsii.member(jsii_name="name")
    def name(self) -> builtins.str:
        return jsii.get(self, "name")

    @name.setter # type: ignore
    def name(self, value: builtins.str) -> None:
        jsii.set(self, "name", value)

    @builtins.property # type: ignore
    @jsii.member(jsii_name="resourceGroupName")
    def resource_group_name(self) -> builtins.str:
        return jsii.get(self, "resourceGroupName")

    @resource_group_name.setter # type: ignore
    def resource_group_name(self, value: builtins.str) -> None:
        jsii.set(self, "resourceGroupName", value)

    @builtins.property # type: ignore
    @jsii.member(jsii_name="id")
    def id(self) -> typing.Optional[builtins.str]:
        return jsii.get(self, "id")

    @id.setter # type: ignore
    def id(self, value: typing.Optional[builtins.str]) -> None:
        jsii.set(self, "id", value)

    @builtins.property # type: ignore
    @jsii.member(jsii_name="timeouts")
    def timeouts(
        self,
    ) -> typing.Optional["DataAzurermPrivateEndpointConnectionTimeouts"]:
        return jsii.get(self, "timeouts")

    @timeouts.setter # type: ignore
    def timeouts(
        self,
        value: typing.Optional["DataAzurermPrivateEndpointConnectionTimeouts"],
    ) -> None:
        jsii.set(self, "timeouts", value)


@jsii.data_type(
    jsii_type="@cdktf/provider-azurerm.DataAzurermPrivateEndpointConnectionConfig",
    jsii_struct_bases=[cdktf.TerraformMetaArguments],
    name_mapping={
        "count": "count",
        "depends_on": "dependsOn",
        "lifecycle": "lifecycle",
        "provider": "provider",
        "name": "name",
        "resource_group_name": "resourceGroupName",
        "timeouts": "timeouts",
    },
)
class DataAzurermPrivateEndpointConnectionConfig(cdktf.TerraformMetaArguments):
    def __init__(
        self,
        *,
        count: typing.Optional[jsii.Number] = None,
        depends_on: typing.Optional[typing.List[cdktf.TerraformResource]] = None,
        lifecycle: typing.Optional[cdktf.TerraformResourceLifecycle] = None,
        provider: typing.Optional[cdktf.TerraformProvider] = None,
        name: builtins.str,
        resource_group_name: builtins.str,
        timeouts: typing.Optional["DataAzurermPrivateEndpointConnectionTimeouts"] = None,
    ) -> None:
        """
        :param count: 
        :param depends_on: 
        :param lifecycle: 
        :param provider: 
        :param name: 
        :param resource_group_name: 
        :param timeouts: timeouts block.
        """
        if isinstance(lifecycle, dict):
            lifecycle = cdktf.TerraformResourceLifecycle(**lifecycle)
        if isinstance(timeouts, dict):
            timeouts = DataAzurermPrivateEndpointConnectionTimeouts(**timeouts)
        self._values: typing.Dict[str, typing.Any] = {
            "name": name,
            "resource_group_name": resource_group_name,
        }
        if count is not None:
            self._values["count"] = count
        if depends_on is not None:
            self._values["depends_on"] = depends_on
        if lifecycle is not None:
            self._values["lifecycle"] = lifecycle
        if provider is not None:
            self._values["provider"] = provider
        if timeouts is not None:
            self._values["timeouts"] = timeouts

    @builtins.property
    def count(self) -> typing.Optional[jsii.Number]:
        """
        :stability: experimental
        """
        result = self._values.get("count")
        return result

    @builtins.property
    def depends_on(self) -> typing.Optional[typing.List[cdktf.TerraformResource]]:
        """
        :stability: experimental
        """
        result = self._values.get("depends_on")
        return result

    @builtins.property
    def lifecycle(self) -> typing.Optional[cdktf.TerraformResourceLifecycle]:
        """
        :stability: experimental
        """
        result = self._values.get("lifecycle")
        return result

    @builtins.property
    def provider(self) -> typing.Optional[cdktf.TerraformProvider]:
        """
        :stability: experimental
        """
        result = self._values.get("provider")
        return result

    @builtins.property
    def name(self) -> builtins.str:
        result = self._values.get("name")
        assert result is not None, "Required property 'name' is missing"
        return result

    @builtins.property
    def resource_group_name(self) -> builtins.str:
        result = self._values.get("resource_group_name")
        assert result is not None, "Required property 'resource_group_name' is missing"
        return result

    @builtins.property
    def timeouts(
        self,
    ) -> typing.Optional["DataAzurermPrivateEndpointConnectionTimeouts"]:
        """timeouts block."""
        result = self._values.get("timeouts")
        return result

    def __eq__(self, rhs: typing.Any) -> builtins.bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs: typing.Any) -> builtins.bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return "DataAzurermPrivateEndpointConnectionConfig(%s)" % ", ".join(
            k + "=" + repr(v) for k, v in self._values.items()
        )


class DataAzurermPrivateEndpointConnectionPrivateServiceConnection(
    cdktf.ComplexComputedList,
    metaclass=jsii.JSIIMeta,
    jsii_type="@cdktf/provider-azurerm.DataAzurermPrivateEndpointConnectionPrivateServiceConnection",
):
    def __init__(
        self,
        terraform_resource: cdktf.ITerraformResource,
        terraform_attribute: builtins.str,
        index: builtins.str,
    ) -> None:
        """
        :param terraform_resource: -
        :param terraform_attribute: -
        :param index: -

        :stability: experimental
        """
        jsii.create(DataAzurermPrivateEndpointConnectionPrivateServiceConnection, self, [terraform_resource, terraform_attribute, index])

    @builtins.property # type: ignore
    @jsii.member(jsii_name="name")
    def name(self) -> builtins.str:
        return jsii.get(self, "name")

    @builtins.property # type: ignore
    @jsii.member(jsii_name="privateIpAddress")
    def private_ip_address(self) -> builtins.str:
        return jsii.get(self, "privateIpAddress")

    @builtins.property # type: ignore
    @jsii.member(jsii_name="requestResponse")
    def request_response(self) -> builtins.str:
        return jsii.get(self, "requestResponse")

    @builtins.property # type: ignore
    @jsii.member(jsii_name="status")
    def status(self) -> builtins.str:
        return jsii.get(self, "status")


@jsii.data_type(
    jsii_type="@cdktf/provider-azurerm.DataAzurermPrivateEndpointConnectionTimeouts",
    jsii_struct_bases=[],
    name_mapping={"read": "read"},
)
class DataAzurermPrivateEndpointConnectionTimeouts:
    def __init__(self, *, read: typing.Optional[builtins.str] = None) -> None:
        """
        :param read: 
        """
        self._values: typing.Dict[str, typing.Any] = {}
        if read is not None:
            self._values["read"] = read

    @builtins.property
    def read(self) -> typing.Optional[builtins.str]:
        result = self._values.get("read")
        return result

    def __eq__(self, rhs: typing.Any) -> builtins.bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs: typing.Any) -> builtins.bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return "DataAzurermPrivateEndpointConnectionTimeouts(%s)" % ", ".join(
            k + "=" + repr(v) for k, v in self._values.items()
        )


class DataAzurermPrivateLinkService(
    cdktf.TerraformDataSource,
    metaclass=jsii.JSIIMeta,
    jsii_type="@cdktf/provider-azurerm.DataAzurermPrivateLinkService",
):
    def __init__(
        self,
        scope: constructs.Construct,
        id: builtins.str,
        *,
        name: builtins.str,
        resource_group_name: builtins.str,
        timeouts: typing.Optional["DataAzurermPrivateLinkServiceTimeouts"] = None,
        count: typing.Optional[jsii.Number] = None,
        depends_on: typing.Optional[typing.List[cdktf.TerraformResource]] = None,
        lifecycle: typing.Optional[cdktf.TerraformResourceLifecycle] = None,
        provider: typing.Optional[cdktf.TerraformProvider] = None,
    ) -> None:
        """
        :param scope: -
        :param id: -
        :param name: 
        :param resource_group_name: 
        :param timeouts: timeouts block.
        :param count: 
        :param depends_on: 
        :param lifecycle: 
        :param provider: 
        """
        config = DataAzurermPrivateLinkServiceConfig(
            name=name,
            resource_group_name=resource_group_name,
            timeouts=timeouts,
            count=count,
            depends_on=depends_on,
            lifecycle=lifecycle,
            provider=provider,
        )

        jsii.create(DataAzurermPrivateLinkService, self, [scope, id, config])

    @jsii.member(jsii_name="natIpConfiguration")
    def nat_ip_configuration(
        self,
        index: builtins.str,
    ) -> "DataAzurermPrivateLinkServiceNatIpConfiguration":
        """
        :param index: -
        """
        return jsii.invoke(self, "natIpConfiguration", [index])

    @jsii.member(jsii_name="synthesizeAttributes")
    def _synthesize_attributes(self) -> typing.Mapping[builtins.str, typing.Any]:
        return jsii.invoke(self, "synthesizeAttributes", [])

    @jsii.member(jsii_name="tags")
    def tags(self, key: builtins.str) -> builtins.str:
        """
        :param key: -
        """
        return jsii.invoke(self, "tags", [key])

    @builtins.property # type: ignore
    @jsii.member(jsii_name="alias")
    def alias(self) -> builtins.str:
        return jsii.get(self, "alias")

    @builtins.property # type: ignore
    @jsii.member(jsii_name="autoApprovalSubscriptionIds")
    def auto_approval_subscription_ids(self) -> typing.List[builtins.str]:
        return jsii.get(self, "autoApprovalSubscriptionIds")

    @builtins.property # type: ignore
    @jsii.member(jsii_name="enableProxyProtocol")
    def enable_proxy_protocol(self) -> builtins.bool:
        return jsii.get(self, "enableProxyProtocol")

    @builtins.property # type: ignore
    @jsii.member(jsii_name="loadBalancerFrontendIpConfigurationIds")
    def load_balancer_frontend_ip_configuration_ids(self) -> typing.List[builtins.str]:
        return jsii.get(self, "loadBalancerFrontendIpConfigurationIds")

    @builtins.property # type: ignore
    @jsii.member(jsii_name="location")
    def location(self) -> builtins.str:
        return jsii.get(self, "location")

    @builtins.property # type: ignore
    @jsii.member(jsii_name="visibilitySubscriptionIds")
    def visibility_subscription_ids(self) -> typing.List[builtins.str]:
        return jsii.get(self, "visibilitySubscriptionIds")

    @builtins.property # type: ignore
    @jsii.member(jsii_name="name")
    def name(self) -> builtins.str:
        return jsii.get(self, "name")

    @name.setter # type: ignore
    def name(self, value: builtins.str) -> None:
        jsii.set(self, "name", value)

    @builtins.property # type: ignore
    @jsii.member(jsii_name="resourceGroupName")
    def resource_group_name(self) -> builtins.str:
        return jsii.get(self, "resourceGroupName")

    @resource_group_name.setter # type: ignore
    def resource_group_name(self, value: builtins.str) -> None:
        jsii.set(self, "resourceGroupName", value)

    @builtins.property # type: ignore
    @jsii.member(jsii_name="id")
    def id(self) -> typing.Optional[builtins.str]:
        return jsii.get(self, "id")

    @id.setter # type: ignore
    def id(self, value: typing.Optional[builtins.str]) -> None:
        jsii.set(self, "id", value)

    @builtins.property # type: ignore
    @jsii.member(jsii_name="timeouts")
    def timeouts(self) -> typing.Optional["DataAzurermPrivateLinkServiceTimeouts"]:
        return jsii.get(self, "timeouts")

    @timeouts.setter # type: ignore
    def timeouts(
        self,
        value: typing.Optional["DataAzurermPrivateLinkServiceTimeouts"],
    ) -> None:
        jsii.set(self, "timeouts", value)


@jsii.data_type(
    jsii_type="@cdktf/provider-azurerm.DataAzurermPrivateLinkServiceConfig",
    jsii_struct_bases=[cdktf.TerraformMetaArguments],
    name_mapping={
        "count": "count",
        "depends_on": "dependsOn",
        "lifecycle": "lifecycle",
        "provider": "provider",
        "name": "name",
        "resource_group_name": "resourceGroupName",
        "timeouts": "timeouts",
    },
)
class DataAzurermPrivateLinkServiceConfig(cdktf.TerraformMetaArguments):
    def __init__(
        self,
        *,
        count: typing.Optional[jsii.Number] = None,
        depends_on: typing.Optional[typing.List[cdktf.TerraformResource]] = None,
        lifecycle: typing.Optional[cdktf.TerraformResourceLifecycle] = None,
        provider: typing.Optional[cdktf.TerraformProvider] = None,
        name: builtins.str,
        resource_group_name: builtins.str,
        timeouts: typing.Optional["DataAzurermPrivateLinkServiceTimeouts"] = None,
    ) -> None:
        """
        :param count: 
        :param depends_on: 
        :param lifecycle: 
        :param provider: 
        :param name: 
        :param resource_group_name: 
        :param timeouts: timeouts block.
        """
        if isinstance(lifecycle, dict):
            lifecycle = cdktf.TerraformResourceLifecycle(**lifecycle)
        if isinstance(timeouts, dict):
            timeouts = DataAzurermPrivateLinkServiceTimeouts(**timeouts)
        self._values: typing.Dict[str, typing.Any] = {
            "name": name,
            "resource_group_name": resource_group_name,
        }
        if count is not None:
            self._values["count"] = count
        if depends_on is not None:
            self._values["depends_on"] = depends_on
        if lifecycle is not None:
            self._values["lifecycle"] = lifecycle
        if provider is not None:
            self._values["provider"] = provider
        if timeouts is not None:
            self._values["timeouts"] = timeouts

    @builtins.property
    def count(self) -> typing.Optional[jsii.Number]:
        """
        :stability: experimental
        """
        result = self._values.get("count")
        return result

    @builtins.property
    def depends_on(self) -> typing.Optional[typing.List[cdktf.TerraformResource]]:
        """
        :stability: experimental
        """
        result = self._values.get("depends_on")
        return result

    @builtins.property
    def lifecycle(self) -> typing.Optional[cdktf.TerraformResourceLifecycle]:
        """
        :stability: experimental
        """
        result = self._values.get("lifecycle")
        return result

    @builtins.property
    def provider(self) -> typing.Optional[cdktf.TerraformProvider]:
        """
        :stability: experimental
        """
        result = self._values.get("provider")
        return result

    @builtins.property
    def name(self) -> builtins.str:
        result = self._values.get("name")
        assert result is not None, "Required property 'name' is missing"
        return result

    @builtins.property
    def resource_group_name(self) -> builtins.str:
        result = self._values.get("resource_group_name")
        assert result is not None, "Required property 'resource_group_name' is missing"
        return result

    @builtins.property
    def timeouts(self) -> typing.Optional["DataAzurermPrivateLinkServiceTimeouts"]:
        """timeouts block."""
        result = self._values.get("timeouts")
        return result

    def __eq__(self, rhs: typing.Any) -> builtins.bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs: typing.Any) -> builtins.bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return "DataAzurermPrivateLinkServiceConfig(%s)" % ", ".join(
            k + "=" + repr(v) for k, v in self._values.items()
        )


class DataAzurermPrivateLinkServiceEndpointConnections(
    cdktf.TerraformDataSource,
    metaclass=jsii.JSIIMeta,
    jsii_type="@cdktf/provider-azurerm.DataAzurermPrivateLinkServiceEndpointConnections",
):
    def __init__(
        self,
        scope: constructs.Construct,
        id: builtins.str,
        *,
        resource_group_name: builtins.str,
        service_id: builtins.str,
        timeouts: typing.Optional["DataAzurermPrivateLinkServiceEndpointConnectionsTimeouts"] = None,
        count: typing.Optional[jsii.Number] = None,
        depends_on: typing.Optional[typing.List[cdktf.TerraformResource]] = None,
        lifecycle: typing.Optional[cdktf.TerraformResourceLifecycle] = None,
        provider: typing.Optional[cdktf.TerraformProvider] = None,
    ) -> None:
        """
        :param scope: -
        :param id: -
        :param resource_group_name: 
        :param service_id: 
        :param timeouts: timeouts block.
        :param count: 
        :param depends_on: 
        :param lifecycle: 
        :param provider: 
        """
        config = DataAzurermPrivateLinkServiceEndpointConnectionsConfig(
            resource_group_name=resource_group_name,
            service_id=service_id,
            timeouts=timeouts,
            count=count,
            depends_on=depends_on,
            lifecycle=lifecycle,
            provider=provider,
        )

        jsii.create(DataAzurermPrivateLinkServiceEndpointConnections, self, [scope, id, config])

    @jsii.member(jsii_name="privateEndpointConnections")
    def private_endpoint_connections(
        self,
        index: builtins.str,
    ) -> "DataAzurermPrivateLinkServiceEndpointConnectionsPrivateEndpointConnections":
        """
        :param index: -
        """
        return jsii.invoke(self, "privateEndpointConnections", [index])

    @jsii.member(jsii_name="synthesizeAttributes")
    def _synthesize_attributes(self) -> typing.Mapping[builtins.str, typing.Any]:
        return jsii.invoke(self, "synthesizeAttributes", [])

    @builtins.property # type: ignore
    @jsii.member(jsii_name="location")
    def location(self) -> builtins.str:
        return jsii.get(self, "location")

    @builtins.property # type: ignore
    @jsii.member(jsii_name="serviceName")
    def service_name(self) -> builtins.str:
        return jsii.get(self, "serviceName")

    @builtins.property # type: ignore
    @jsii.member(jsii_name="resourceGroupName")
    def resource_group_name(self) -> builtins.str:
        return jsii.get(self, "resourceGroupName")

    @resource_group_name.setter # type: ignore
    def resource_group_name(self, value: builtins.str) -> None:
        jsii.set(self, "resourceGroupName", value)

    @builtins.property # type: ignore
    @jsii.member(jsii_name="serviceId")
    def service_id(self) -> builtins.str:
        return jsii.get(self, "serviceId")

    @service_id.setter # type: ignore
    def service_id(self, value: builtins.str) -> None:
        jsii.set(self, "serviceId", value)

    @builtins.property # type: ignore
    @jsii.member(jsii_name="id")
    def id(self) -> typing.Optional[builtins.str]:
        return jsii.get(self, "id")

    @id.setter # type: ignore
    def id(self, value: typing.Optional[builtins.str]) -> None:
        jsii.set(self, "id", value)

    @builtins.property # type: ignore
    @jsii.member(jsii_name="timeouts")
    def timeouts(
        self,
    ) -> typing.Optional["DataAzurermPrivateLinkServiceEndpointConnectionsTimeouts"]:
        return jsii.get(self, "timeouts")

    @timeouts.setter # type: ignore
    def timeouts(
        self,
        value: typing.Optional["DataAzurermPrivateLinkServiceEndpointConnectionsTimeouts"],
    ) -> None:
        jsii.set(self, "timeouts", value)


@jsii.data_type(
    jsii_type="@cdktf/provider-azurerm.DataAzurermPrivateLinkServiceEndpointConnectionsConfig",
    jsii_struct_bases=[cdktf.TerraformMetaArguments],
    name_mapping={
        "count": "count",
        "depends_on": "dependsOn",
        "lifecycle": "lifecycle",
        "provider": "provider",
        "resource_group_name": "resourceGroupName",
        "service_id": "serviceId",
        "timeouts": "timeouts",
    },
)
class DataAzurermPrivateLinkServiceEndpointConnectionsConfig(
    cdktf.TerraformMetaArguments,
):
    def __init__(
        self,
        *,
        count: typing.Optional[jsii.Number] = None,
        depends_on: typing.Optional[typing.List[cdktf.TerraformResource]] = None,
        lifecycle: typing.Optional[cdktf.TerraformResourceLifecycle] = None,
        provider: typing.Optional[cdktf.TerraformProvider] = None,
        resource_group_name: builtins.str,
        service_id: builtins.str,
        timeouts: typing.Optional["DataAzurermPrivateLinkServiceEndpointConnectionsTimeouts"] = None,
    ) -> None:
        """
        :param count: 
        :param depends_on: 
        :param lifecycle: 
        :param provider: 
        :param resource_group_name: 
        :param service_id: 
        :param timeouts: timeouts block.
        """
        if isinstance(lifecycle, dict):
            lifecycle = cdktf.TerraformResourceLifecycle(**lifecycle)
        if isinstance(timeouts, dict):
            timeouts = DataAzurermPrivateLinkServiceEndpointConnectionsTimeouts(**timeouts)
        self._values: typing.Dict[str, typing.Any] = {
            "resource_group_name": resource_group_name,
            "service_id": service_id,
        }
        if count is not None:
            self._values["count"] = count
        if depends_on is not None:
            self._values["depends_on"] = depends_on
        if lifecycle is not None:
            self._values["lifecycle"] = lifecycle
        if provider is not None:
            self._values["provider"] = provider
        if timeouts is not None:
            self._values["timeouts"] = timeouts

    @builtins.property
    def count(self) -> typing.Optional[jsii.Number]:
        """
        :stability: experimental
        """
        result = self._values.get("count")
        return result

    @builtins.property
    def depends_on(self) -> typing.Optional[typing.List[cdktf.TerraformResource]]:
        """
        :stability: experimental
        """
        result = self._values.get("depends_on")
        return result

    @builtins.property
    def lifecycle(self) -> typing.Optional[cdktf.TerraformResourceLifecycle]:
        """
        :stability: experimental
        """
        result = self._values.get("lifecycle")
        return result

    @builtins.property
    def provider(self) -> typing.Optional[cdktf.TerraformProvider]:
        """
        :stability: experimental
        """
        result = self._values.get("provider")
        return result

    @builtins.property
    def resource_group_name(self) -> builtins.str:
        result = self._values.get("resource_group_name")
        assert result is not None, "Required property 'resource_group_name' is missing"
        return result

    @builtins.property
    def service_id(self) -> builtins.str:
        result = self._values.get("service_id")
        assert result is not None, "Required property 'service_id' is missing"
        return result

    @builtins.property
    def timeouts(
        self,
    ) -> typing.Optional["DataAzurermPrivateLinkServiceEndpointConnectionsTimeouts"]:
        """timeouts block."""
        result = self._values.get("timeouts")
        return result

    def __eq__(self, rhs: typing.Any) -> builtins.bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs: typing.Any) -> builtins.bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return "DataAzurermPrivateLinkServiceEndpointConnectionsConfig(%s)" % ", ".join(
            k + "=" + repr(v) for k, v in self._values.items()
        )


class DataAzurermPrivateLinkServiceEndpointConnectionsPrivateEndpointConnections(
    cdktf.ComplexComputedList,
    metaclass=jsii.JSIIMeta,
    jsii_type="@cdktf/provider-azurerm.DataAzurermPrivateLinkServiceEndpointConnectionsPrivateEndpointConnections",
):
    def __init__(
        self,
        terraform_resource: cdktf.ITerraformResource,
        terraform_attribute: builtins.str,
        index: builtins.str,
    ) -> None:
        """
        :param terraform_resource: -
        :param terraform_attribute: -
        :param index: -

        :stability: experimental
        """
        jsii.create(DataAzurermPrivateLinkServiceEndpointConnectionsPrivateEndpointConnections, self, [terraform_resource, terraform_attribute, index])

    @builtins.property # type: ignore
    @jsii.member(jsii_name="actionRequired")
    def action_required(self) -> builtins.str:
        return jsii.get(self, "actionRequired")

    @builtins.property # type: ignore
    @jsii.member(jsii_name="connectionId")
    def connection_id(self) -> builtins.str:
        return jsii.get(self, "connectionId")

    @builtins.property # type: ignore
    @jsii.member(jsii_name="connectionName")
    def connection_name(self) -> builtins.str:
        return jsii.get(self, "connectionName")

    @builtins.property # type: ignore
    @jsii.member(jsii_name="description")
    def description(self) -> builtins.str:
        return jsii.get(self, "description")

    @builtins.property # type: ignore
    @jsii.member(jsii_name="privateEndpointId")
    def private_endpoint_id(self) -> builtins.str:
        return jsii.get(self, "privateEndpointId")

    @builtins.property # type: ignore
    @jsii.member(jsii_name="privateEndpointName")
    def private_endpoint_name(self) -> builtins.str:
        return jsii.get(self, "privateEndpointName")

    @builtins.property # type: ignore
    @jsii.member(jsii_name="status")
    def status(self) -> builtins.str:
        return jsii.get(self, "status")


@jsii.data_type(
    jsii_type="@cdktf/provider-azurerm.DataAzurermPrivateLinkServiceEndpointConnectionsTimeouts",
    jsii_struct_bases=[],
    name_mapping={"read": "read"},
)
class DataAzurermPrivateLinkServiceEndpointConnectionsTimeouts:
    def __init__(self, *, read: typing.Optional[builtins.str] = None) -> None:
        """
        :param read: 
        """
        self._values: typing.Dict[str, typing.Any] = {}
        if read is not None:
            self._values["read"] = read

    @builtins.property
    def read(self) -> typing.Optional[builtins.str]:
        result = self._values.get("read")
        return result

    def __eq__(self, rhs: typing.Any) -> builtins.bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs: typing.Any) -> builtins.bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return "DataAzurermPrivateLinkServiceEndpointConnectionsTimeouts(%s)" % ", ".join(
            k + "=" + repr(v) for k, v in self._values.items()
        )


class DataAzurermPrivateLinkServiceNatIpConfiguration(
    cdktf.ComplexComputedList,
    metaclass=jsii.JSIIMeta,
    jsii_type="@cdktf/provider-azurerm.DataAzurermPrivateLinkServiceNatIpConfiguration",
):
    def __init__(
        self,
        terraform_resource: cdktf.ITerraformResource,
        terraform_attribute: builtins.str,
        index: builtins.str,
    ) -> None:
        """
        :param terraform_resource: -
        :param terraform_attribute: -
        :param index: -

        :stability: experimental
        """
        jsii.create(DataAzurermPrivateLinkServiceNatIpConfiguration, self, [terraform_resource, terraform_attribute, index])

    @builtins.property # type: ignore
    @jsii.member(jsii_name="name")
    def name(self) -> builtins.str:
        return jsii.get(self, "name")

    @builtins.property # type: ignore
    @jsii.member(jsii_name="primary")
    def primary(self) -> builtins.bool:
        return jsii.get(self, "primary")

    @builtins.property # type: ignore
    @jsii.member(jsii_name="privateIpAddress")
    def private_ip_address(self) -> builtins.str:
        return jsii.get(self, "privateIpAddress")

    @builtins.property # type: ignore
    @jsii.member(jsii_name="privateIpAddressVersion")
    def private_ip_address_version(self) -> builtins.str:
        return jsii.get(self, "privateIpAddressVersion")

    @builtins.property # type: ignore
    @jsii.member(jsii_name="subnetId")
    def subnet_id(self) -> builtins.str:
        return jsii.get(self, "subnetId")


@jsii.data_type(
    jsii_type="@cdktf/provider-azurerm.DataAzurermPrivateLinkServiceTimeouts",
    jsii_struct_bases=[],
    name_mapping={"read": "read"},
)
class DataAzurermPrivateLinkServiceTimeouts:
    def __init__(self, *, read: typing.Optional[builtins.str] = None) -> None:
        """
        :param read: 
        """
        self._values: typing.Dict[str, typing.Any] = {}
        if read is not None:
            self._values["read"] = read

    @builtins.property
    def read(self) -> typing.Optional[builtins.str]:
        result = self._values.get("read")
        return result

    def __eq__(self, rhs: typing.Any) -> builtins.bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs: typing.Any) -> builtins.bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return "DataAzurermPrivateLinkServiceTimeouts(%s)" % ", ".join(
            k + "=" + repr(v) for k, v in self._values.items()
        )


class DataAzurermProximityPlacementGroup(
    cdktf.TerraformDataSource,
    metaclass=jsii.JSIIMeta,
    jsii_type="@cdktf/provider-azurerm.DataAzurermProximityPlacementGroup",
):
    def __init__(
        self,
        scope: constructs.Construct,
        id: builtins.str,
        *,
        name: builtins.str,
        resource_group_name: builtins.str,
        timeouts: typing.Optional["DataAzurermProximityPlacementGroupTimeouts"] = None,
        count: typing.Optional[jsii.Number] = None,
        depends_on: typing.Optional[typing.List[cdktf.TerraformResource]] = None,
        lifecycle: typing.Optional[cdktf.TerraformResourceLifecycle] = None,
        provider: typing.Optional[cdktf.TerraformProvider] = None,
    ) -> None:
        """
        :param scope: -
        :param id: -
        :param name: 
        :param resource_group_name: 
        :param timeouts: timeouts block.
        :param count: 
        :param depends_on: 
        :param lifecycle: 
        :param provider: 
        """
        config = DataAzurermProximityPlacementGroupConfig(
            name=name,
            resource_group_name=resource_group_name,
            timeouts=timeouts,
            count=count,
            depends_on=depends_on,
            lifecycle=lifecycle,
            provider=provider,
        )

        jsii.create(DataAzurermProximityPlacementGroup, self, [scope, id, config])

    @jsii.member(jsii_name="synthesizeAttributes")
    def _synthesize_attributes(self) -> typing.Mapping[builtins.str, typing.Any]:
        return jsii.invoke(self, "synthesizeAttributes", [])

    @jsii.member(jsii_name="tags")
    def tags(self, key: builtins.str) -> builtins.str:
        """
        :param key: -
        """
        return jsii.invoke(self, "tags", [key])

    @builtins.property # type: ignore
    @jsii.member(jsii_name="location")
    def location(self) -> builtins.str:
        return jsii.get(self, "location")

    @builtins.property # type: ignore
    @jsii.member(jsii_name="name")
    def name(self) -> builtins.str:
        return jsii.get(self, "name")

    @name.setter # type: ignore
    def name(self, value: builtins.str) -> None:
        jsii.set(self, "name", value)

    @builtins.property # type: ignore
    @jsii.member(jsii_name="resourceGroupName")
    def resource_group_name(self) -> builtins.str:
        return jsii.get(self, "resourceGroupName")

    @resource_group_name.setter # type: ignore
    def resource_group_name(self, value: builtins.str) -> None:
        jsii.set(self, "resourceGroupName", value)

    @builtins.property # type: ignore
    @jsii.member(jsii_name="id")
    def id(self) -> typing.Optional[builtins.str]:
        return jsii.get(self, "id")

    @id.setter # type: ignore
    def id(self, value: typing.Optional[builtins.str]) -> None:
        jsii.set(self, "id", value)

    @builtins.property # type: ignore
    @jsii.member(jsii_name="timeouts")
    def timeouts(self) -> typing.Optional["DataAzurermProximityPlacementGroupTimeouts"]:
        return jsii.get(self, "timeouts")

    @timeouts.setter # type: ignore
    def timeouts(
        self,
        value: typing.Optional["DataAzurermProximityPlacementGroupTimeouts"],
    ) -> None:
        jsii.set(self, "timeouts", value)


@jsii.data_type(
    jsii_type="@cdktf/provider-azurerm.DataAzurermProximityPlacementGroupConfig",
    jsii_struct_bases=[cdktf.TerraformMetaArguments],
    name_mapping={
        "count": "count",
        "depends_on": "dependsOn",
        "lifecycle": "lifecycle",
        "provider": "provider",
        "name": "name",
        "resource_group_name": "resourceGroupName",
        "timeouts": "timeouts",
    },
)
class DataAzurermProximityPlacementGroupConfig(cdktf.TerraformMetaArguments):
    def __init__(
        self,
        *,
        count: typing.Optional[jsii.Number] = None,
        depends_on: typing.Optional[typing.List[cdktf.TerraformResource]] = None,
        lifecycle: typing.Optional[cdktf.TerraformResourceLifecycle] = None,
        provider: typing.Optional[cdktf.TerraformProvider] = None,
        name: builtins.str,
        resource_group_name: builtins.str,
        timeouts: typing.Optional["DataAzurermProximityPlacementGroupTimeouts"] = None,
    ) -> None:
        """
        :param count: 
        :param depends_on: 
        :param lifecycle: 
        :param provider: 
        :param name: 
        :param resource_group_name: 
        :param timeouts: timeouts block.
        """
        if isinstance(lifecycle, dict):
            lifecycle = cdktf.TerraformResourceLifecycle(**lifecycle)
        if isinstance(timeouts, dict):
            timeouts = DataAzurermProximityPlacementGroupTimeouts(**timeouts)
        self._values: typing.Dict[str, typing.Any] = {
            "name": name,
            "resource_group_name": resource_group_name,
        }
        if count is not None:
            self._values["count"] = count
        if depends_on is not None:
            self._values["depends_on"] = depends_on
        if lifecycle is not None:
            self._values["lifecycle"] = lifecycle
        if provider is not None:
            self._values["provider"] = provider
        if timeouts is not None:
            self._values["timeouts"] = timeouts

    @builtins.property
    def count(self) -> typing.Optional[jsii.Number]:
        """
        :stability: experimental
        """
        result = self._values.get("count")
        return result

    @builtins.property
    def depends_on(self) -> typing.Optional[typing.List[cdktf.TerraformResource]]:
        """
        :stability: experimental
        """
        result = self._values.get("depends_on")
        return result

    @builtins.property
    def lifecycle(self) -> typing.Optional[cdktf.TerraformResourceLifecycle]:
        """
        :stability: experimental
        """
        result = self._values.get("lifecycle")
        return result

    @builtins.property
    def provider(self) -> typing.Optional[cdktf.TerraformProvider]:
        """
        :stability: experimental
        """
        result = self._values.get("provider")
        return result

    @builtins.property
    def name(self) -> builtins.str:
        result = self._values.get("name")
        assert result is not None, "Required property 'name' is missing"
        return result

    @builtins.property
    def resource_group_name(self) -> builtins.str:
        result = self._values.get("resource_group_name")
        assert result is not None, "Required property 'resource_group_name' is missing"
        return result

    @builtins.property
    def timeouts(self) -> typing.Optional["DataAzurermProximityPlacementGroupTimeouts"]:
        """timeouts block."""
        result = self._values.get("timeouts")
        return result

    def __eq__(self, rhs: typing.Any) -> builtins.bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs: typing.Any) -> builtins.bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return "DataAzurermProximityPlacementGroupConfig(%s)" % ", ".join(
            k + "=" + repr(v) for k, v in self._values.items()
        )


@jsii.data_type(
    jsii_type="@cdktf/provider-azurerm.DataAzurermProximityPlacementGroupTimeouts",
    jsii_struct_bases=[],
    name_mapping={"read": "read"},
)
class DataAzurermProximityPlacementGroupTimeouts:
    def __init__(self, *, read: typing.Optional[builtins.str] = None) -> None:
        """
        :param read: 
        """
        self._values: typing.Dict[str, typing.Any] = {}
        if read is not None:
            self._values["read"] = read

    @builtins.property
    def read(self) -> typing.Optional[builtins.str]:
        result = self._values.get("read")
        return result

    def __eq__(self, rhs: typing.Any) -> builtins.bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs: typing.Any) -> builtins.bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return "DataAzurermProximityPlacementGroupTimeouts(%s)" % ", ".join(
            k + "=" + repr(v) for k, v in self._values.items()
        )


class DataAzurermPublicIp(
    cdktf.TerraformDataSource,
    metaclass=jsii.JSIIMeta,
    jsii_type="@cdktf/provider-azurerm.DataAzurermPublicIp",
):
    def __init__(
        self,
        scope: constructs.Construct,
        id: builtins.str,
        *,
        name: builtins.str,
        resource_group_name: builtins.str,
        tags: typing.Optional[typing.Mapping[builtins.str, builtins.str]] = None,
        timeouts: typing.Optional["DataAzurermPublicIpTimeouts"] = None,
        zones: typing.Optional[typing.List[builtins.str]] = None,
        count: typing.Optional[jsii.Number] = None,
        depends_on: typing.Optional[typing.List[cdktf.TerraformResource]] = None,
        lifecycle: typing.Optional[cdktf.TerraformResourceLifecycle] = None,
        provider: typing.Optional[cdktf.TerraformProvider] = None,
    ) -> None:
        """
        :param scope: -
        :param id: -
        :param name: 
        :param resource_group_name: 
        :param tags: 
        :param timeouts: timeouts block.
        :param zones: 
        :param count: 
        :param depends_on: 
        :param lifecycle: 
        :param provider: 
        """
        config = DataAzurermPublicIpConfig(
            name=name,
            resource_group_name=resource_group_name,
            tags=tags,
            timeouts=timeouts,
            zones=zones,
            count=count,
            depends_on=depends_on,
            lifecycle=lifecycle,
            provider=provider,
        )

        jsii.create(DataAzurermPublicIp, self, [scope, id, config])

    @jsii.member(jsii_name="synthesizeAttributes")
    def _synthesize_attributes(self) -> typing.Mapping[builtins.str, typing.Any]:
        return jsii.invoke(self, "synthesizeAttributes", [])

    @builtins.property # type: ignore
    @jsii.member(jsii_name="allocationMethod")
    def allocation_method(self) -> builtins.str:
        return jsii.get(self, "allocationMethod")

    @builtins.property # type: ignore
    @jsii.member(jsii_name="domainNameLabel")
    def domain_name_label(self) -> builtins.str:
        return jsii.get(self, "domainNameLabel")

    @builtins.property # type: ignore
    @jsii.member(jsii_name="fqdn")
    def fqdn(self) -> builtins.str:
        return jsii.get(self, "fqdn")

    @builtins.property # type: ignore
    @jsii.member(jsii_name="idleTimeoutInMinutes")
    def idle_timeout_in_minutes(self) -> jsii.Number:
        return jsii.get(self, "idleTimeoutInMinutes")

    @builtins.property # type: ignore
    @jsii.member(jsii_name="ipAddress")
    def ip_address(self) -> builtins.str:
        return jsii.get(self, "ipAddress")

    @builtins.property # type: ignore
    @jsii.member(jsii_name="ipVersion")
    def ip_version(self) -> builtins.str:
        return jsii.get(self, "ipVersion")

    @builtins.property # type: ignore
    @jsii.member(jsii_name="location")
    def location(self) -> builtins.str:
        return jsii.get(self, "location")

    @builtins.property # type: ignore
    @jsii.member(jsii_name="reverseFqdn")
    def reverse_fqdn(self) -> builtins.str:
        return jsii.get(self, "reverseFqdn")

    @builtins.property # type: ignore
    @jsii.member(jsii_name="sku")
    def sku(self) -> builtins.str:
        return jsii.get(self, "sku")

    @builtins.property # type: ignore
    @jsii.member(jsii_name="name")
    def name(self) -> builtins.str:
        return jsii.get(self, "name")

    @name.setter # type: ignore
    def name(self, value: builtins.str) -> None:
        jsii.set(self, "name", value)

    @builtins.property # type: ignore
    @jsii.member(jsii_name="resourceGroupName")
    def resource_group_name(self) -> builtins.str:
        return jsii.get(self, "resourceGroupName")

    @resource_group_name.setter # type: ignore
    def resource_group_name(self, value: builtins.str) -> None:
        jsii.set(self, "resourceGroupName", value)

    @builtins.property # type: ignore
    @jsii.member(jsii_name="id")
    def id(self) -> typing.Optional[builtins.str]:
        return jsii.get(self, "id")

    @id.setter # type: ignore
    def id(self, value: typing.Optional[builtins.str]) -> None:
        jsii.set(self, "id", value)

    @builtins.property # type: ignore
    @jsii.member(jsii_name="tags")
    def tags(self) -> typing.Optional[typing.Mapping[builtins.str, builtins.str]]:
        return jsii.get(self, "tags")

    @tags.setter # type: ignore
    def tags(
        self,
        value: typing.Optional[typing.Mapping[builtins.str, builtins.str]],
    ) -> None:
        jsii.set(self, "tags", value)

    @builtins.property # type: ignore
    @jsii.member(jsii_name="timeouts")
    def timeouts(self) -> typing.Optional["DataAzurermPublicIpTimeouts"]:
        return jsii.get(self, "timeouts")

    @timeouts.setter # type: ignore
    def timeouts(self, value: typing.Optional["DataAzurermPublicIpTimeouts"]) -> None:
        jsii.set(self, "timeouts", value)

    @builtins.property # type: ignore
    @jsii.member(jsii_name="zones")
    def zones(self) -> typing.Optional[typing.List[builtins.str]]:
        return jsii.get(self, "zones")

    @zones.setter # type: ignore
    def zones(self, value: typing.Optional[typing.List[builtins.str]]) -> None:
        jsii.set(self, "zones", value)


@jsii.data_type(
    jsii_type="@cdktf/provider-azurerm.DataAzurermPublicIpConfig",
    jsii_struct_bases=[cdktf.TerraformMetaArguments],
    name_mapping={
        "count": "count",
        "depends_on": "dependsOn",
        "lifecycle": "lifecycle",
        "provider": "provider",
        "name": "name",
        "resource_group_name": "resourceGroupName",
        "tags": "tags",
        "timeouts": "timeouts",
        "zones": "zones",
    },
)
class DataAzurermPublicIpConfig(cdktf.TerraformMetaArguments):
    def __init__(
        self,
        *,
        count: typing.Optional[jsii.Number] = None,
        depends_on: typing.Optional[typing.List[cdktf.TerraformResource]] = None,
        lifecycle: typing.Optional[cdktf.TerraformResourceLifecycle] = None,
        provider: typing.Optional[cdktf.TerraformProvider] = None,
        name: builtins.str,
        resource_group_name: builtins.str,
        tags: typing.Optional[typing.Mapping[builtins.str, builtins.str]] = None,
        timeouts: typing.Optional["DataAzurermPublicIpTimeouts"] = None,
        zones: typing.Optional[typing.List[builtins.str]] = None,
    ) -> None:
        """
        :param count: 
        :param depends_on: 
        :param lifecycle: 
        :param provider: 
        :param name: 
        :param resource_group_name: 
        :param tags: 
        :param timeouts: timeouts block.
        :param zones: 
        """
        if isinstance(lifecycle, dict):
            lifecycle = cdktf.TerraformResourceLifecycle(**lifecycle)
        if isinstance(timeouts, dict):
            timeouts = DataAzurermPublicIpTimeouts(**timeouts)
        self._values: typing.Dict[str, typing.Any] = {
            "name": name,
            "resource_group_name": resource_group_name,
        }
        if count is not None:
            self._values["count"] = count
        if depends_on is not None:
            self._values["depends_on"] = depends_on
        if lifecycle is not None:
            self._values["lifecycle"] = lifecycle
        if provider is not None:
            self._values["provider"] = provider
        if tags is not None:
            self._values["tags"] = tags
        if timeouts is not None:
            self._values["timeouts"] = timeouts
        if zones is not None:
            self._values["zones"] = zones

    @builtins.property
    def count(self) -> typing.Optional[jsii.Number]:
        """
        :stability: experimental
        """
        result = self._values.get("count")
        return result

    @builtins.property
    def depends_on(self) -> typing.Optional[typing.List[cdktf.TerraformResource]]:
        """
        :stability: experimental
        """
        result = self._values.get("depends_on")
        return result

    @builtins.property
    def lifecycle(self) -> typing.Optional[cdktf.TerraformResourceLifecycle]:
        """
        :stability: experimental
        """
        result = self._values.get("lifecycle")
        return result

    @builtins.property
    def provider(self) -> typing.Optional[cdktf.TerraformProvider]:
        """
        :stability: experimental
        """
        result = self._values.get("provider")
        return result

    @builtins.property
    def name(self) -> builtins.str:
        result = self._values.get("name")
        assert result is not None, "Required property 'name' is missing"
        return result

    @builtins.property
    def resource_group_name(self) -> builtins.str:
        result = self._values.get("resource_group_name")
        assert result is not None, "Required property 'resource_group_name' is missing"
        return result

    @builtins.property
    def tags(self) -> typing.Optional[typing.Mapping[builtins.str, builtins.str]]:
        result = self._values.get("tags")
        return result

    @builtins.property
    def timeouts(self) -> typing.Optional["DataAzurermPublicIpTimeouts"]:
        """timeouts block."""
        result = self._values.get("timeouts")
        return result

    @builtins.property
    def zones(self) -> typing.Optional[typing.List[builtins.str]]:
        result = self._values.get("zones")
        return result

    def __eq__(self, rhs: typing.Any) -> builtins.bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs: typing.Any) -> builtins.bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return "DataAzurermPublicIpConfig(%s)" % ", ".join(
            k + "=" + repr(v) for k, v in self._values.items()
        )


class DataAzurermPublicIpPrefix(
    cdktf.TerraformDataSource,
    metaclass=jsii.JSIIMeta,
    jsii_type="@cdktf/provider-azurerm.DataAzurermPublicIpPrefix",
):
    def __init__(
        self,
        scope: constructs.Construct,
        id: builtins.str,
        *,
        name: builtins.str,
        resource_group_name: builtins.str,
        timeouts: typing.Optional["DataAzurermPublicIpPrefixTimeouts"] = None,
        zones: typing.Optional[typing.List[builtins.str]] = None,
        count: typing.Optional[jsii.Number] = None,
        depends_on: typing.Optional[typing.List[cdktf.TerraformResource]] = None,
        lifecycle: typing.Optional[cdktf.TerraformResourceLifecycle] = None,
        provider: typing.Optional[cdktf.TerraformProvider] = None,
    ) -> None:
        """
        :param scope: -
        :param id: -
        :param name: 
        :param resource_group_name: 
        :param timeouts: timeouts block.
        :param zones: 
        :param count: 
        :param depends_on: 
        :param lifecycle: 
        :param provider: 
        """
        config = DataAzurermPublicIpPrefixConfig(
            name=name,
            resource_group_name=resource_group_name,
            timeouts=timeouts,
            zones=zones,
            count=count,
            depends_on=depends_on,
            lifecycle=lifecycle,
            provider=provider,
        )

        jsii.create(DataAzurermPublicIpPrefix, self, [scope, id, config])

    @jsii.member(jsii_name="synthesizeAttributes")
    def _synthesize_attributes(self) -> typing.Mapping[builtins.str, typing.Any]:
        return jsii.invoke(self, "synthesizeAttributes", [])

    @jsii.member(jsii_name="tags")
    def tags(self, key: builtins.str) -> builtins.str:
        """
        :param key: -
        """
        return jsii.invoke(self, "tags", [key])

    @builtins.property # type: ignore
    @jsii.member(jsii_name="ipPrefix")
    def ip_prefix(self) -> builtins.str:
        return jsii.get(self, "ipPrefix")

    @builtins.property # type: ignore
    @jsii.member(jsii_name="location")
    def location(self) -> builtins.str:
        return jsii.get(self, "location")

    @builtins.property # type: ignore
    @jsii.member(jsii_name="prefixLength")
    def prefix_length(self) -> jsii.Number:
        return jsii.get(self, "prefixLength")

    @builtins.property # type: ignore
    @jsii.member(jsii_name="sku")
    def sku(self) -> builtins.str:
        return jsii.get(self, "sku")

    @builtins.property # type: ignore
    @jsii.member(jsii_name="name")
    def name(self) -> builtins.str:
        return jsii.get(self, "name")

    @name.setter # type: ignore
    def name(self, value: builtins.str) -> None:
        jsii.set(self, "name", value)

    @builtins.property # type: ignore
    @jsii.member(jsii_name="resourceGroupName")
    def resource_group_name(self) -> builtins.str:
        return jsii.get(self, "resourceGroupName")

    @resource_group_name.setter # type: ignore
    def resource_group_name(self, value: builtins.str) -> None:
        jsii.set(self, "resourceGroupName", value)

    @builtins.property # type: ignore
    @jsii.member(jsii_name="id")
    def id(self) -> typing.Optional[builtins.str]:
        return jsii.get(self, "id")

    @id.setter # type: ignore
    def id(self, value: typing.Optional[builtins.str]) -> None:
        jsii.set(self, "id", value)

    @builtins.property # type: ignore
    @jsii.member(jsii_name="timeouts")
    def timeouts(self) -> typing.Optional["DataAzurermPublicIpPrefixTimeouts"]:
        return jsii.get(self, "timeouts")

    @timeouts.setter # type: ignore
    def timeouts(
        self,
        value: typing.Optional["DataAzurermPublicIpPrefixTimeouts"],
    ) -> None:
        jsii.set(self, "timeouts", value)

    @builtins.property # type: ignore
    @jsii.member(jsii_name="zones")
    def zones(self) -> typing.Optional[typing.List[builtins.str]]:
        return jsii.get(self, "zones")

    @zones.setter # type: ignore
    def zones(self, value: typing.Optional[typing.List[builtins.str]]) -> None:
        jsii.set(self, "zones", value)


@jsii.data_type(
    jsii_type="@cdktf/provider-azurerm.DataAzurermPublicIpPrefixConfig",
    jsii_struct_bases=[cdktf.TerraformMetaArguments],
    name_mapping={
        "count": "count",
        "depends_on": "dependsOn",
        "lifecycle": "lifecycle",
        "provider": "provider",
        "name": "name",
        "resource_group_name": "resourceGroupName",
        "timeouts": "timeouts",
        "zones": "zones",
    },
)
class DataAzurermPublicIpPrefixConfig(cdktf.TerraformMetaArguments):
    def __init__(
        self,
        *,
        count: typing.Optional[jsii.Number] = None,
        depends_on: typing.Optional[typing.List[cdktf.TerraformResource]] = None,
        lifecycle: typing.Optional[cdktf.TerraformResourceLifecycle] = None,
        provider: typing.Optional[cdktf.TerraformProvider] = None,
        name: builtins.str,
        resource_group_name: builtins.str,
        timeouts: typing.Optional["DataAzurermPublicIpPrefixTimeouts"] = None,
        zones: typing.Optional[typing.List[builtins.str]] = None,
    ) -> None:
        """
        :param count: 
        :param depends_on: 
        :param lifecycle: 
        :param provider: 
        :param name: 
        :param resource_group_name: 
        :param timeouts: timeouts block.
        :param zones: 
        """
        if isinstance(lifecycle, dict):
            lifecycle = cdktf.TerraformResourceLifecycle(**lifecycle)
        if isinstance(timeouts, dict):
            timeouts = DataAzurermPublicIpPrefixTimeouts(**timeouts)
        self._values: typing.Dict[str, typing.Any] = {
            "name": name,
            "resource_group_name": resource_group_name,
        }
        if count is not None:
            self._values["count"] = count
        if depends_on is not None:
            self._values["depends_on"] = depends_on
        if lifecycle is not None:
            self._values["lifecycle"] = lifecycle
        if provider is not None:
            self._values["provider"] = provider
        if timeouts is not None:
            self._values["timeouts"] = timeouts
        if zones is not None:
            self._values["zones"] = zones

    @builtins.property
    def count(self) -> typing.Optional[jsii.Number]:
        """
        :stability: experimental
        """
        result = self._values.get("count")
        return result

    @builtins.property
    def depends_on(self) -> typing.Optional[typing.List[cdktf.TerraformResource]]:
        """
        :stability: experimental
        """
        result = self._values.get("depends_on")
        return result

    @builtins.property
    def lifecycle(self) -> typing.Optional[cdktf.TerraformResourceLifecycle]:
        """
        :stability: experimental
        """
        result = self._values.get("lifecycle")
        return result

    @builtins.property
    def provider(self) -> typing.Optional[cdktf.TerraformProvider]:
        """
        :stability: experimental
        """
        result = self._values.get("provider")
        return result

    @builtins.property
    def name(self) -> builtins.str:
        result = self._values.get("name")
        assert result is not None, "Required property 'name' is missing"
        return result

    @builtins.property
    def resource_group_name(self) -> builtins.str:
        result = self._values.get("resource_group_name")
        assert result is not None, "Required property 'resource_group_name' is missing"
        return result

    @builtins.property
    def timeouts(self) -> typing.Optional["DataAzurermPublicIpPrefixTimeouts"]:
        """timeouts block."""
        result = self._values.get("timeouts")
        return result

    @builtins.property
    def zones(self) -> typing.Optional[typing.List[builtins.str]]:
        result = self._values.get("zones")
        return result

    def __eq__(self, rhs: typing.Any) -> builtins.bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs: typing.Any) -> builtins.bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return "DataAzurermPublicIpPrefixConfig(%s)" % ", ".join(
            k + "=" + repr(v) for k, v in self._values.items()
        )


@jsii.data_type(
    jsii_type="@cdktf/provider-azurerm.DataAzurermPublicIpPrefixTimeouts",
    jsii_struct_bases=[],
    name_mapping={"read": "read"},
)
class DataAzurermPublicIpPrefixTimeouts:
    def __init__(self, *, read: typing.Optional[builtins.str] = None) -> None:
        """
        :param read: 
        """
        self._values: typing.Dict[str, typing.Any] = {}
        if read is not None:
            self._values["read"] = read

    @builtins.property
    def read(self) -> typing.Optional[builtins.str]:
        result = self._values.get("read")
        return result

    def __eq__(self, rhs: typing.Any) -> builtins.bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs: typing.Any) -> builtins.bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return "DataAzurermPublicIpPrefixTimeouts(%s)" % ", ".join(
            k + "=" + repr(v) for k, v in self._values.items()
        )


@jsii.data_type(
    jsii_type="@cdktf/provider-azurerm.DataAzurermPublicIpTimeouts",
    jsii_struct_bases=[],
    name_mapping={"read": "read"},
)
class DataAzurermPublicIpTimeouts:
    def __init__(self, *, read: typing.Optional[builtins.str] = None) -> None:
        """
        :param read: 
        """
        self._values: typing.Dict[str, typing.Any] = {}
        if read is not None:
            self._values["read"] = read

    @builtins.property
    def read(self) -> typing.Optional[builtins.str]:
        result = self._values.get("read")
        return result

    def __eq__(self, rhs: typing.Any) -> builtins.bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs: typing.Any) -> builtins.bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return "DataAzurermPublicIpTimeouts(%s)" % ", ".join(
            k + "=" + repr(v) for k, v in self._values.items()
        )


class DataAzurermPublicIps(
    cdktf.TerraformDataSource,
    metaclass=jsii.JSIIMeta,
    jsii_type="@cdktf/provider-azurerm.DataAzurermPublicIps",
):
    def __init__(
        self,
        scope: constructs.Construct,
        id: builtins.str,
        *,
        resource_group_name: builtins.str,
        allocation_type: typing.Optional[builtins.str] = None,
        attached: typing.Optional[builtins.bool] = None,
        name_prefix: typing.Optional[builtins.str] = None,
        timeouts: typing.Optional["DataAzurermPublicIpsTimeouts"] = None,
        count: typing.Optional[jsii.Number] = None,
        depends_on: typing.Optional[typing.List[cdktf.TerraformResource]] = None,
        lifecycle: typing.Optional[cdktf.TerraformResourceLifecycle] = None,
        provider: typing.Optional[cdktf.TerraformProvider] = None,
    ) -> None:
        """
        :param scope: -
        :param id: -
        :param resource_group_name: 
        :param allocation_type: 
        :param attached: 
        :param name_prefix: 
        :param timeouts: timeouts block.
        :param count: 
        :param depends_on: 
        :param lifecycle: 
        :param provider: 
        """
        config = DataAzurermPublicIpsConfig(
            resource_group_name=resource_group_name,
            allocation_type=allocation_type,
            attached=attached,
            name_prefix=name_prefix,
            timeouts=timeouts,
            count=count,
            depends_on=depends_on,
            lifecycle=lifecycle,
            provider=provider,
        )

        jsii.create(DataAzurermPublicIps, self, [scope, id, config])

    @jsii.member(jsii_name="publicIps")
    def public_ips(self, index: builtins.str) -> "DataAzurermPublicIpsPublicIps":
        """
        :param index: -
        """
        return jsii.invoke(self, "publicIps", [index])

    @jsii.member(jsii_name="synthesizeAttributes")
    def _synthesize_attributes(self) -> typing.Mapping[builtins.str, typing.Any]:
        return jsii.invoke(self, "synthesizeAttributes", [])

    @builtins.property # type: ignore
    @jsii.member(jsii_name="resourceGroupName")
    def resource_group_name(self) -> builtins.str:
        return jsii.get(self, "resourceGroupName")

    @resource_group_name.setter # type: ignore
    def resource_group_name(self, value: builtins.str) -> None:
        jsii.set(self, "resourceGroupName", value)

    @builtins.property # type: ignore
    @jsii.member(jsii_name="allocationType")
    def allocation_type(self) -> typing.Optional[builtins.str]:
        return jsii.get(self, "allocationType")

    @allocation_type.setter # type: ignore
    def allocation_type(self, value: typing.Optional[builtins.str]) -> None:
        jsii.set(self, "allocationType", value)

    @builtins.property # type: ignore
    @jsii.member(jsii_name="attached")
    def attached(self) -> typing.Optional[builtins.bool]:
        return jsii.get(self, "attached")

    @attached.setter # type: ignore
    def attached(self, value: typing.Optional[builtins.bool]) -> None:
        jsii.set(self, "attached", value)

    @builtins.property # type: ignore
    @jsii.member(jsii_name="id")
    def id(self) -> typing.Optional[builtins.str]:
        return jsii.get(self, "id")

    @id.setter # type: ignore
    def id(self, value: typing.Optional[builtins.str]) -> None:
        jsii.set(self, "id", value)

    @builtins.property # type: ignore
    @jsii.member(jsii_name="namePrefix")
    def name_prefix(self) -> typing.Optional[builtins.str]:
        return jsii.get(self, "namePrefix")

    @name_prefix.setter # type: ignore
    def name_prefix(self, value: typing.Optional[builtins.str]) -> None:
        jsii.set(self, "namePrefix", value)

    @builtins.property # type: ignore
    @jsii.member(jsii_name="timeouts")
    def timeouts(self) -> typing.Optional["DataAzurermPublicIpsTimeouts"]:
        return jsii.get(self, "timeouts")

    @timeouts.setter # type: ignore
    def timeouts(self, value: typing.Optional["DataAzurermPublicIpsTimeouts"]) -> None:
        jsii.set(self, "timeouts", value)


@jsii.data_type(
    jsii_type="@cdktf/provider-azurerm.DataAzurermPublicIpsConfig",
    jsii_struct_bases=[cdktf.TerraformMetaArguments],
    name_mapping={
        "count": "count",
        "depends_on": "dependsOn",
        "lifecycle": "lifecycle",
        "provider": "provider",
        "resource_group_name": "resourceGroupName",
        "allocation_type": "allocationType",
        "attached": "attached",
        "name_prefix": "namePrefix",
        "timeouts": "timeouts",
    },
)
class DataAzurermPublicIpsConfig(cdktf.TerraformMetaArguments):
    def __init__(
        self,
        *,
        count: typing.Optional[jsii.Number] = None,
        depends_on: typing.Optional[typing.List[cdktf.TerraformResource]] = None,
        lifecycle: typing.Optional[cdktf.TerraformResourceLifecycle] = None,
        provider: typing.Optional[cdktf.TerraformProvider] = None,
        resource_group_name: builtins.str,
        allocation_type: typing.Optional[builtins.str] = None,
        attached: typing.Optional[builtins.bool] = None,
        name_prefix: typing.Optional[builtins.str] = None,
        timeouts: typing.Optional["DataAzurermPublicIpsTimeouts"] = None,
    ) -> None:
        """
        :param count: 
        :param depends_on: 
        :param lifecycle: 
        :param provider: 
        :param resource_group_name: 
        :param allocation_type: 
        :param attached: 
        :param name_prefix: 
        :param timeouts: timeouts block.
        """
        if isinstance(lifecycle, dict):
            lifecycle = cdktf.TerraformResourceLifecycle(**lifecycle)
        if isinstance(timeouts, dict):
            timeouts = DataAzurermPublicIpsTimeouts(**timeouts)
        self._values: typing.Dict[str, typing.Any] = {
            "resource_group_name": resource_group_name,
        }
        if count is not None:
            self._values["count"] = count
        if depends_on is not None:
            self._values["depends_on"] = depends_on
        if lifecycle is not None:
            self._values["lifecycle"] = lifecycle
        if provider is not None:
            self._values["provider"] = provider
        if allocation_type is not None:
            self._values["allocation_type"] = allocation_type
        if attached is not None:
            self._values["attached"] = attached
        if name_prefix is not None:
            self._values["name_prefix"] = name_prefix
        if timeouts is not None:
            self._values["timeouts"] = timeouts

    @builtins.property
    def count(self) -> typing.Optional[jsii.Number]:
        """
        :stability: experimental
        """
        result = self._values.get("count")
        return result

    @builtins.property
    def depends_on(self) -> typing.Optional[typing.List[cdktf.TerraformResource]]:
        """
        :stability: experimental
        """
        result = self._values.get("depends_on")
        return result

    @builtins.property
    def lifecycle(self) -> typing.Optional[cdktf.TerraformResourceLifecycle]:
        """
        :stability: experimental
        """
        result = self._values.get("lifecycle")
        return result

    @builtins.property
    def provider(self) -> typing.Optional[cdktf.TerraformProvider]:
        """
        :stability: experimental
        """
        result = self._values.get("provider")
        return result

    @builtins.property
    def resource_group_name(self) -> builtins.str:
        result = self._values.get("resource_group_name")
        assert result is not None, "Required property 'resource_group_name' is missing"
        return result

    @builtins.property
    def allocation_type(self) -> typing.Optional[builtins.str]:
        result = self._values.get("allocation_type")
        return result

    @builtins.property
    def attached(self) -> typing.Optional[builtins.bool]:
        result = self._values.get("attached")
        return result

    @builtins.property
    def name_prefix(self) -> typing.Optional[builtins.str]:
        result = self._values.get("name_prefix")
        return result

    @builtins.property
    def timeouts(self) -> typing.Optional["DataAzurermPublicIpsTimeouts"]:
        """timeouts block."""
        result = self._values.get("timeouts")
        return result

    def __eq__(self, rhs: typing.Any) -> builtins.bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs: typing.Any) -> builtins.bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return "DataAzurermPublicIpsConfig(%s)" % ", ".join(
            k + "=" + repr(v) for k, v in self._values.items()
        )


class DataAzurermPublicIpsPublicIps(
    cdktf.ComplexComputedList,
    metaclass=jsii.JSIIMeta,
    jsii_type="@cdktf/provider-azurerm.DataAzurermPublicIpsPublicIps",
):
    def __init__(
        self,
        terraform_resource: cdktf.ITerraformResource,
        terraform_attribute: builtins.str,
        index: builtins.str,
    ) -> None:
        """
        :param terraform_resource: -
        :param terraform_attribute: -
        :param index: -

        :stability: experimental
        """
        jsii.create(DataAzurermPublicIpsPublicIps, self, [terraform_resource, terraform_attribute, index])

    @builtins.property # type: ignore
    @jsii.member(jsii_name="domainNameLabel")
    def domain_name_label(self) -> builtins.str:
        return jsii.get(self, "domainNameLabel")

    @builtins.property # type: ignore
    @jsii.member(jsii_name="fqdn")
    def fqdn(self) -> builtins.str:
        return jsii.get(self, "fqdn")

    @builtins.property # type: ignore
    @jsii.member(jsii_name="id")
    def id(self) -> builtins.str:
        return jsii.get(self, "id")

    @builtins.property # type: ignore
    @jsii.member(jsii_name="ipAddress")
    def ip_address(self) -> builtins.str:
        return jsii.get(self, "ipAddress")

    @builtins.property # type: ignore
    @jsii.member(jsii_name="name")
    def name(self) -> builtins.str:
        return jsii.get(self, "name")


@jsii.data_type(
    jsii_type="@cdktf/provider-azurerm.DataAzurermPublicIpsTimeouts",
    jsii_struct_bases=[],
    name_mapping={"read": "read"},
)
class DataAzurermPublicIpsTimeouts:
    def __init__(self, *, read: typing.Optional[builtins.str] = None) -> None:
        """
        :param read: 
        """
        self._values: typing.Dict[str, typing.Any] = {}
        if read is not None:
            self._values["read"] = read

    @builtins.property
    def read(self) -> typing.Optional[builtins.str]:
        result = self._values.get("read")
        return result

    def __eq__(self, rhs: typing.Any) -> builtins.bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs: typing.Any) -> builtins.bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return "DataAzurermPublicIpsTimeouts(%s)" % ", ".join(
            k + "=" + repr(v) for k, v in self._values.items()
        )


class DataAzurermRecoveryServicesVault(
    cdktf.TerraformDataSource,
    metaclass=jsii.JSIIMeta,
    jsii_type="@cdktf/provider-azurerm.DataAzurermRecoveryServicesVault",
):
    def __init__(
        self,
        scope: constructs.Construct,
        id: builtins.str,
        *,
        name: builtins.str,
        resource_group_name: builtins.str,
        timeouts: typing.Optional["DataAzurermRecoveryServicesVaultTimeouts"] = None,
        count: typing.Optional[jsii.Number] = None,
        depends_on: typing.Optional[typing.List[cdktf.TerraformResource]] = None,
        lifecycle: typing.Optional[cdktf.TerraformResourceLifecycle] = None,
        provider: typing.Optional[cdktf.TerraformProvider] = None,
    ) -> None:
        """
        :param scope: -
        :param id: -
        :param name: 
        :param resource_group_name: 
        :param timeouts: timeouts block.
        :param count: 
        :param depends_on: 
        :param lifecycle: 
        :param provider: 
        """
        config = DataAzurermRecoveryServicesVaultConfig(
            name=name,
            resource_group_name=resource_group_name,
            timeouts=timeouts,
            count=count,
            depends_on=depends_on,
            lifecycle=lifecycle,
            provider=provider,
        )

        jsii.create(DataAzurermRecoveryServicesVault, self, [scope, id, config])

    @jsii.member(jsii_name="synthesizeAttributes")
    def _synthesize_attributes(self) -> typing.Mapping[builtins.str, typing.Any]:
        return jsii.invoke(self, "synthesizeAttributes", [])

    @jsii.member(jsii_name="tags")
    def tags(self, key: builtins.str) -> builtins.str:
        """
        :param key: -
        """
        return jsii.invoke(self, "tags", [key])

    @builtins.property # type: ignore
    @jsii.member(jsii_name="location")
    def location(self) -> builtins.str:
        return jsii.get(self, "location")

    @builtins.property # type: ignore
    @jsii.member(jsii_name="sku")
    def sku(self) -> builtins.str:
        return jsii.get(self, "sku")

    @builtins.property # type: ignore
    @jsii.member(jsii_name="name")
    def name(self) -> builtins.str:
        return jsii.get(self, "name")

    @name.setter # type: ignore
    def name(self, value: builtins.str) -> None:
        jsii.set(self, "name", value)

    @builtins.property # type: ignore
    @jsii.member(jsii_name="resourceGroupName")
    def resource_group_name(self) -> builtins.str:
        return jsii.get(self, "resourceGroupName")

    @resource_group_name.setter # type: ignore
    def resource_group_name(self, value: builtins.str) -> None:
        jsii.set(self, "resourceGroupName", value)

    @builtins.property # type: ignore
    @jsii.member(jsii_name="id")
    def id(self) -> typing.Optional[builtins.str]:
        return jsii.get(self, "id")

    @id.setter # type: ignore
    def id(self, value: typing.Optional[builtins.str]) -> None:
        jsii.set(self, "id", value)

    @builtins.property # type: ignore
    @jsii.member(jsii_name="timeouts")
    def timeouts(self) -> typing.Optional["DataAzurermRecoveryServicesVaultTimeouts"]:
        return jsii.get(self, "timeouts")

    @timeouts.setter # type: ignore
    def timeouts(
        self,
        value: typing.Optional["DataAzurermRecoveryServicesVaultTimeouts"],
    ) -> None:
        jsii.set(self, "timeouts", value)


@jsii.data_type(
    jsii_type="@cdktf/provider-azurerm.DataAzurermRecoveryServicesVaultConfig",
    jsii_struct_bases=[cdktf.TerraformMetaArguments],
    name_mapping={
        "count": "count",
        "depends_on": "dependsOn",
        "lifecycle": "lifecycle",
        "provider": "provider",
        "name": "name",
        "resource_group_name": "resourceGroupName",
        "timeouts": "timeouts",
    },
)
class DataAzurermRecoveryServicesVaultConfig(cdktf.TerraformMetaArguments):
    def __init__(
        self,
        *,
        count: typing.Optional[jsii.Number] = None,
        depends_on: typing.Optional[typing.List[cdktf.TerraformResource]] = None,
        lifecycle: typing.Optional[cdktf.TerraformResourceLifecycle] = None,
        provider: typing.Optional[cdktf.TerraformProvider] = None,
        name: builtins.str,
        resource_group_name: builtins.str,
        timeouts: typing.Optional["DataAzurermRecoveryServicesVaultTimeouts"] = None,
    ) -> None:
        """
        :param count: 
        :param depends_on: 
        :param lifecycle: 
        :param provider: 
        :param name: 
        :param resource_group_name: 
        :param timeouts: timeouts block.
        """
        if isinstance(lifecycle, dict):
            lifecycle = cdktf.TerraformResourceLifecycle(**lifecycle)
        if isinstance(timeouts, dict):
            timeouts = DataAzurermRecoveryServicesVaultTimeouts(**timeouts)
        self._values: typing.Dict[str, typing.Any] = {
            "name": name,
            "resource_group_name": resource_group_name,
        }
        if count is not None:
            self._values["count"] = count
        if depends_on is not None:
            self._values["depends_on"] = depends_on
        if lifecycle is not None:
            self._values["lifecycle"] = lifecycle
        if provider is not None:
            self._values["provider"] = provider
        if timeouts is not None:
            self._values["timeouts"] = timeouts

    @builtins.property
    def count(self) -> typing.Optional[jsii.Number]:
        """
        :stability: experimental
        """
        result = self._values.get("count")
        return result

    @builtins.property
    def depends_on(self) -> typing.Optional[typing.List[cdktf.TerraformResource]]:
        """
        :stability: experimental
        """
        result = self._values.get("depends_on")
        return result

    @builtins.property
    def lifecycle(self) -> typing.Optional[cdktf.TerraformResourceLifecycle]:
        """
        :stability: experimental
        """
        result = self._values.get("lifecycle")
        return result

    @builtins.property
    def provider(self) -> typing.Optional[cdktf.TerraformProvider]:
        """
        :stability: experimental
        """
        result = self._values.get("provider")
        return result

    @builtins.property
    def name(self) -> builtins.str:
        result = self._values.get("name")
        assert result is not None, "Required property 'name' is missing"
        return result

    @builtins.property
    def resource_group_name(self) -> builtins.str:
        result = self._values.get("resource_group_name")
        assert result is not None, "Required property 'resource_group_name' is missing"
        return result

    @builtins.property
    def timeouts(self) -> typing.Optional["DataAzurermRecoveryServicesVaultTimeouts"]:
        """timeouts block."""
        result = self._values.get("timeouts")
        return result

    def __eq__(self, rhs: typing.Any) -> builtins.bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs: typing.Any) -> builtins.bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return "DataAzurermRecoveryServicesVaultConfig(%s)" % ", ".join(
            k + "=" + repr(v) for k, v in self._values.items()
        )


@jsii.data_type(
    jsii_type="@cdktf/provider-azurerm.DataAzurermRecoveryServicesVaultTimeouts",
    jsii_struct_bases=[],
    name_mapping={"read": "read"},
)
class DataAzurermRecoveryServicesVaultTimeouts:
    def __init__(self, *, read: typing.Optional[builtins.str] = None) -> None:
        """
        :param read: 
        """
        self._values: typing.Dict[str, typing.Any] = {}
        if read is not None:
            self._values["read"] = read

    @builtins.property
    def read(self) -> typing.Optional[builtins.str]:
        result = self._values.get("read")
        return result

    def __eq__(self, rhs: typing.Any) -> builtins.bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs: typing.Any) -> builtins.bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return "DataAzurermRecoveryServicesVaultTimeouts(%s)" % ", ".join(
            k + "=" + repr(v) for k, v in self._values.items()
        )


class DataAzurermRedisCache(
    cdktf.TerraformDataSource,
    metaclass=jsii.JSIIMeta,
    jsii_type="@cdktf/provider-azurerm.DataAzurermRedisCache",
):
    def __init__(
        self,
        scope: constructs.Construct,
        id: builtins.str,
        *,
        name: builtins.str,
        resource_group_name: builtins.str,
        timeouts: typing.Optional["DataAzurermRedisCacheTimeouts"] = None,
        zones: typing.Optional[typing.List[builtins.str]] = None,
        count: typing.Optional[jsii.Number] = None,
        depends_on: typing.Optional[typing.List[cdktf.TerraformResource]] = None,
        lifecycle: typing.Optional[cdktf.TerraformResourceLifecycle] = None,
        provider: typing.Optional[cdktf.TerraformProvider] = None,
    ) -> None:
        """
        :param scope: -
        :param id: -
        :param name: 
        :param resource_group_name: 
        :param timeouts: timeouts block.
        :param zones: 
        :param count: 
        :param depends_on: 
        :param lifecycle: 
        :param provider: 
        """
        config = DataAzurermRedisCacheConfig(
            name=name,
            resource_group_name=resource_group_name,
            timeouts=timeouts,
            zones=zones,
            count=count,
            depends_on=depends_on,
            lifecycle=lifecycle,
            provider=provider,
        )

        jsii.create(DataAzurermRedisCache, self, [scope, id, config])

    @jsii.member(jsii_name="patchSchedule")
    def patch_schedule(
        self,
        index: builtins.str,
    ) -> "DataAzurermRedisCachePatchSchedule":
        """
        :param index: -
        """
        return jsii.invoke(self, "patchSchedule", [index])

    @jsii.member(jsii_name="redisConfiguration")
    def redis_configuration(
        self,
        index: builtins.str,
    ) -> "DataAzurermRedisCacheRedisConfiguration":
        """
        :param index: -
        """
        return jsii.invoke(self, "redisConfiguration", [index])

    @jsii.member(jsii_name="synthesizeAttributes")
    def _synthesize_attributes(self) -> typing.Mapping[builtins.str, typing.Any]:
        return jsii.invoke(self, "synthesizeAttributes", [])

    @jsii.member(jsii_name="tags")
    def tags(self, key: builtins.str) -> builtins.str:
        """
        :param key: -
        """
        return jsii.invoke(self, "tags", [key])

    @builtins.property # type: ignore
    @jsii.member(jsii_name="capacity")
    def capacity(self) -> jsii.Number:
        return jsii.get(self, "capacity")

    @builtins.property # type: ignore
    @jsii.member(jsii_name="enableNonSslPort")
    def enable_non_ssl_port(self) -> builtins.bool:
        return jsii.get(self, "enableNonSslPort")

    @builtins.property # type: ignore
    @jsii.member(jsii_name="family")
    def family(self) -> builtins.str:
        return jsii.get(self, "family")

    @builtins.property # type: ignore
    @jsii.member(jsii_name="hostname")
    def hostname(self) -> builtins.str:
        return jsii.get(self, "hostname")

    @builtins.property # type: ignore
    @jsii.member(jsii_name="location")
    def location(self) -> builtins.str:
        return jsii.get(self, "location")

    @builtins.property # type: ignore
    @jsii.member(jsii_name="minimumTlsVersion")
    def minimum_tls_version(self) -> builtins.str:
        return jsii.get(self, "minimumTlsVersion")

    @builtins.property # type: ignore
    @jsii.member(jsii_name="port")
    def port(self) -> jsii.Number:
        return jsii.get(self, "port")

    @builtins.property # type: ignore
    @jsii.member(jsii_name="primaryAccessKey")
    def primary_access_key(self) -> builtins.str:
        return jsii.get(self, "primaryAccessKey")

    @builtins.property # type: ignore
    @jsii.member(jsii_name="privateStaticIpAddress")
    def private_static_ip_address(self) -> builtins.str:
        return jsii.get(self, "privateStaticIpAddress")

    @builtins.property # type: ignore
    @jsii.member(jsii_name="secondaryAccessKey")
    def secondary_access_key(self) -> builtins.str:
        return jsii.get(self, "secondaryAccessKey")

    @builtins.property # type: ignore
    @jsii.member(jsii_name="shardCount")
    def shard_count(self) -> jsii.Number:
        return jsii.get(self, "shardCount")

    @builtins.property # type: ignore
    @jsii.member(jsii_name="skuName")
    def sku_name(self) -> builtins.str:
        return jsii.get(self, "skuName")

    @builtins.property # type: ignore
    @jsii.member(jsii_name="sslPort")
    def ssl_port(self) -> jsii.Number:
        return jsii.get(self, "sslPort")

    @builtins.property # type: ignore
    @jsii.member(jsii_name="subnetId")
    def subnet_id(self) -> builtins.str:
        return jsii.get(self, "subnetId")

    @builtins.property # type: ignore
    @jsii.member(jsii_name="name")
    def name(self) -> builtins.str:
        return jsii.get(self, "name")

    @name.setter # type: ignore
    def name(self, value: builtins.str) -> None:
        jsii.set(self, "name", value)

    @builtins.property # type: ignore
    @jsii.member(jsii_name="resourceGroupName")
    def resource_group_name(self) -> builtins.str:
        return jsii.get(self, "resourceGroupName")

    @resource_group_name.setter # type: ignore
    def resource_group_name(self, value: builtins.str) -> None:
        jsii.set(self, "resourceGroupName", value)

    @builtins.property # type: ignore
    @jsii.member(jsii_name="id")
    def id(self) -> typing.Optional[builtins.str]:
        return jsii.get(self, "id")

    @id.setter # type: ignore
    def id(self, value: typing.Optional[builtins.str]) -> None:
        jsii.set(self, "id", value)

    @builtins.property # type: ignore
    @jsii.member(jsii_name="timeouts")
    def timeouts(self) -> typing.Optional["DataAzurermRedisCacheTimeouts"]:
        return jsii.get(self, "timeouts")

    @timeouts.setter # type: ignore
    def timeouts(self, value: typing.Optional["DataAzurermRedisCacheTimeouts"]) -> None:
        jsii.set(self, "timeouts", value)

    @builtins.property # type: ignore
    @jsii.member(jsii_name="zones")
    def zones(self) -> typing.Optional[typing.List[builtins.str]]:
        return jsii.get(self, "zones")

    @zones.setter # type: ignore
    def zones(self, value: typing.Optional[typing.List[builtins.str]]) -> None:
        jsii.set(self, "zones", value)


@jsii.data_type(
    jsii_type="@cdktf/provider-azurerm.DataAzurermRedisCacheConfig",
    jsii_struct_bases=[cdktf.TerraformMetaArguments],
    name_mapping={
        "count": "count",
        "depends_on": "dependsOn",
        "lifecycle": "lifecycle",
        "provider": "provider",
        "name": "name",
        "resource_group_name": "resourceGroupName",
        "timeouts": "timeouts",
        "zones": "zones",
    },
)
class DataAzurermRedisCacheConfig(cdktf.TerraformMetaArguments):
    def __init__(
        self,
        *,
        count: typing.Optional[jsii.Number] = None,
        depends_on: typing.Optional[typing.List[cdktf.TerraformResource]] = None,
        lifecycle: typing.Optional[cdktf.TerraformResourceLifecycle] = None,
        provider: typing.Optional[cdktf.TerraformProvider] = None,
        name: builtins.str,
        resource_group_name: builtins.str,
        timeouts: typing.Optional["DataAzurermRedisCacheTimeouts"] = None,
        zones: typing.Optional[typing.List[builtins.str]] = None,
    ) -> None:
        """
        :param count: 
        :param depends_on: 
        :param lifecycle: 
        :param provider: 
        :param name: 
        :param resource_group_name: 
        :param timeouts: timeouts block.
        :param zones: 
        """
        if isinstance(lifecycle, dict):
            lifecycle = cdktf.TerraformResourceLifecycle(**lifecycle)
        if isinstance(timeouts, dict):
            timeouts = DataAzurermRedisCacheTimeouts(**timeouts)
        self._values: typing.Dict[str, typing.Any] = {
            "name": name,
            "resource_group_name": resource_group_name,
        }
        if count is not None:
            self._values["count"] = count
        if depends_on is not None:
            self._values["depends_on"] = depends_on
        if lifecycle is not None:
            self._values["lifecycle"] = lifecycle
        if provider is not None:
            self._values["provider"] = provider
        if timeouts is not None:
            self._values["timeouts"] = timeouts
        if zones is not None:
            self._values["zones"] = zones

    @builtins.property
    def count(self) -> typing.Optional[jsii.Number]:
        """
        :stability: experimental
        """
        result = self._values.get("count")
        return result

    @builtins.property
    def depends_on(self) -> typing.Optional[typing.List[cdktf.TerraformResource]]:
        """
        :stability: experimental
        """
        result = self._values.get("depends_on")
        return result

    @builtins.property
    def lifecycle(self) -> typing.Optional[cdktf.TerraformResourceLifecycle]:
        """
        :stability: experimental
        """
        result = self._values.get("lifecycle")
        return result

    @builtins.property
    def provider(self) -> typing.Optional[cdktf.TerraformProvider]:
        """
        :stability: experimental
        """
        result = self._values.get("provider")
        return result

    @builtins.property
    def name(self) -> builtins.str:
        result = self._values.get("name")
        assert result is not None, "Required property 'name' is missing"
        return result

    @builtins.property
    def resource_group_name(self) -> builtins.str:
        result = self._values.get("resource_group_name")
        assert result is not None, "Required property 'resource_group_name' is missing"
        return result

    @builtins.property
    def timeouts(self) -> typing.Optional["DataAzurermRedisCacheTimeouts"]:
        """timeouts block."""
        result = self._values.get("timeouts")
        return result

    @builtins.property
    def zones(self) -> typing.Optional[typing.List[builtins.str]]:
        result = self._values.get("zones")
        return result

    def __eq__(self, rhs: typing.Any) -> builtins.bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs: typing.Any) -> builtins.bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return "DataAzurermRedisCacheConfig(%s)" % ", ".join(
            k + "=" + repr(v) for k, v in self._values.items()
        )


class DataAzurermRedisCachePatchSchedule(
    cdktf.ComplexComputedList,
    metaclass=jsii.JSIIMeta,
    jsii_type="@cdktf/provider-azurerm.DataAzurermRedisCachePatchSchedule",
):
    def __init__(
        self,
        terraform_resource: cdktf.ITerraformResource,
        terraform_attribute: builtins.str,
        index: builtins.str,
    ) -> None:
        """
        :param terraform_resource: -
        :param terraform_attribute: -
        :param index: -

        :stability: experimental
        """
        jsii.create(DataAzurermRedisCachePatchSchedule, self, [terraform_resource, terraform_attribute, index])

    @builtins.property # type: ignore
    @jsii.member(jsii_name="dayOfWeek")
    def day_of_week(self) -> builtins.str:
        return jsii.get(self, "dayOfWeek")

    @builtins.property # type: ignore
    @jsii.member(jsii_name="startHourUtc")
    def start_hour_utc(self) -> jsii.Number:
        return jsii.get(self, "startHourUtc")


class DataAzurermRedisCacheRedisConfiguration(
    cdktf.ComplexComputedList,
    metaclass=jsii.JSIIMeta,
    jsii_type="@cdktf/provider-azurerm.DataAzurermRedisCacheRedisConfiguration",
):
    def __init__(
        self,
        terraform_resource: cdktf.ITerraformResource,
        terraform_attribute: builtins.str,
        index: builtins.str,
    ) -> None:
        """
        :param terraform_resource: -
        :param terraform_attribute: -
        :param index: -

        :stability: experimental
        """
        jsii.create(DataAzurermRedisCacheRedisConfiguration, self, [terraform_resource, terraform_attribute, index])

    @builtins.property # type: ignore
    @jsii.member(jsii_name="aofBackupEnabled")
    def aof_backup_enabled(self) -> builtins.bool:
        return jsii.get(self, "aofBackupEnabled")

    @builtins.property # type: ignore
    @jsii.member(jsii_name="aofStorageConnectionString0")
    def aof_storage_connection_string0(self) -> builtins.str:
        return jsii.get(self, "aofStorageConnectionString0")

    @builtins.property # type: ignore
    @jsii.member(jsii_name="aofStorageConnectionString1")
    def aof_storage_connection_string1(self) -> builtins.str:
        return jsii.get(self, "aofStorageConnectionString1")

    @builtins.property # type: ignore
    @jsii.member(jsii_name="enableAuthentication")
    def enable_authentication(self) -> builtins.bool:
        return jsii.get(self, "enableAuthentication")

    @builtins.property # type: ignore
    @jsii.member(jsii_name="maxclients")
    def maxclients(self) -> jsii.Number:
        return jsii.get(self, "maxclients")

    @builtins.property # type: ignore
    @jsii.member(jsii_name="maxfragmentationmemoryReserved")
    def maxfragmentationmemory_reserved(self) -> jsii.Number:
        return jsii.get(self, "maxfragmentationmemoryReserved")

    @builtins.property # type: ignore
    @jsii.member(jsii_name="maxmemoryDelta")
    def maxmemory_delta(self) -> jsii.Number:
        return jsii.get(self, "maxmemoryDelta")

    @builtins.property # type: ignore
    @jsii.member(jsii_name="maxmemoryPolicy")
    def maxmemory_policy(self) -> builtins.str:
        return jsii.get(self, "maxmemoryPolicy")

    @builtins.property # type: ignore
    @jsii.member(jsii_name="maxmemoryReserved")
    def maxmemory_reserved(self) -> jsii.Number:
        return jsii.get(self, "maxmemoryReserved")

    @builtins.property # type: ignore
    @jsii.member(jsii_name="notifyKeyspaceEvents")
    def notify_keyspace_events(self) -> builtins.str:
        return jsii.get(self, "notifyKeyspaceEvents")

    @builtins.property # type: ignore
    @jsii.member(jsii_name="rdbBackupEnabled")
    def rdb_backup_enabled(self) -> builtins.bool:
        return jsii.get(self, "rdbBackupEnabled")

    @builtins.property # type: ignore
    @jsii.member(jsii_name="rdbBackupFrequency")
    def rdb_backup_frequency(self) -> jsii.Number:
        return jsii.get(self, "rdbBackupFrequency")

    @builtins.property # type: ignore
    @jsii.member(jsii_name="rdbBackupMaxSnapshotCount")
    def rdb_backup_max_snapshot_count(self) -> jsii.Number:
        return jsii.get(self, "rdbBackupMaxSnapshotCount")

    @builtins.property # type: ignore
    @jsii.member(jsii_name="rdbStorageConnectionString")
    def rdb_storage_connection_string(self) -> builtins.str:
        return jsii.get(self, "rdbStorageConnectionString")


@jsii.data_type(
    jsii_type="@cdktf/provider-azurerm.DataAzurermRedisCacheTimeouts",
    jsii_struct_bases=[],
    name_mapping={"read": "read"},
)
class DataAzurermRedisCacheTimeouts:
    def __init__(self, *, read: typing.Optional[builtins.str] = None) -> None:
        """
        :param read: 
        """
        self._values: typing.Dict[str, typing.Any] = {}
        if read is not None:
            self._values["read"] = read

    @builtins.property
    def read(self) -> typing.Optional[builtins.str]:
        result = self._values.get("read")
        return result

    def __eq__(self, rhs: typing.Any) -> builtins.bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs: typing.Any) -> builtins.bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return "DataAzurermRedisCacheTimeouts(%s)" % ", ".join(
            k + "=" + repr(v) for k, v in self._values.items()
        )


class DataAzurermResourceGroup(
    cdktf.TerraformDataSource,
    metaclass=jsii.JSIIMeta,
    jsii_type="@cdktf/provider-azurerm.DataAzurermResourceGroup",
):
    def __init__(
        self,
        scope: constructs.Construct,
        id: builtins.str,
        *,
        name: builtins.str,
        timeouts: typing.Optional["DataAzurermResourceGroupTimeouts"] = None,
        count: typing.Optional[jsii.Number] = None,
        depends_on: typing.Optional[typing.List[cdktf.TerraformResource]] = None,
        lifecycle: typing.Optional[cdktf.TerraformResourceLifecycle] = None,
        provider: typing.Optional[cdktf.TerraformProvider] = None,
    ) -> None:
        """
        :param scope: -
        :param id: -
        :param name: 
        :param timeouts: timeouts block.
        :param count: 
        :param depends_on: 
        :param lifecycle: 
        :param provider: 
        """
        config = DataAzurermResourceGroupConfig(
            name=name,
            timeouts=timeouts,
            count=count,
            depends_on=depends_on,
            lifecycle=lifecycle,
            provider=provider,
        )

        jsii.create(DataAzurermResourceGroup, self, [scope, id, config])

    @jsii.member(jsii_name="synthesizeAttributes")
    def _synthesize_attributes(self) -> typing.Mapping[builtins.str, typing.Any]:
        return jsii.invoke(self, "synthesizeAttributes", [])

    @jsii.member(jsii_name="tags")
    def tags(self, key: builtins.str) -> builtins.str:
        """
        :param key: -
        """
        return jsii.invoke(self, "tags", [key])

    @builtins.property # type: ignore
    @jsii.member(jsii_name="location")
    def location(self) -> builtins.str:
        return jsii.get(self, "location")

    @builtins.property # type: ignore
    @jsii.member(jsii_name="name")
    def name(self) -> builtins.str:
        return jsii.get(self, "name")

    @name.setter # type: ignore
    def name(self, value: builtins.str) -> None:
        jsii.set(self, "name", value)

    @builtins.property # type: ignore
    @jsii.member(jsii_name="id")
    def id(self) -> typing.Optional[builtins.str]:
        return jsii.get(self, "id")

    @id.setter # type: ignore
    def id(self, value: typing.Optional[builtins.str]) -> None:
        jsii.set(self, "id", value)

    @builtins.property # type: ignore
    @jsii.member(jsii_name="timeouts")
    def timeouts(self) -> typing.Optional["DataAzurermResourceGroupTimeouts"]:
        return jsii.get(self, "timeouts")

    @timeouts.setter # type: ignore
    def timeouts(
        self,
        value: typing.Optional["DataAzurermResourceGroupTimeouts"],
    ) -> None:
        jsii.set(self, "timeouts", value)


@jsii.data_type(
    jsii_type="@cdktf/provider-azurerm.DataAzurermResourceGroupConfig",
    jsii_struct_bases=[cdktf.TerraformMetaArguments],
    name_mapping={
        "count": "count",
        "depends_on": "dependsOn",
        "lifecycle": "lifecycle",
        "provider": "provider",
        "name": "name",
        "timeouts": "timeouts",
    },
)
class DataAzurermResourceGroupConfig(cdktf.TerraformMetaArguments):
    def __init__(
        self,
        *,
        count: typing.Optional[jsii.Number] = None,
        depends_on: typing.Optional[typing.List[cdktf.TerraformResource]] = None,
        lifecycle: typing.Optional[cdktf.TerraformResourceLifecycle] = None,
        provider: typing.Optional[cdktf.TerraformProvider] = None,
        name: builtins.str,
        timeouts: typing.Optional["DataAzurermResourceGroupTimeouts"] = None,
    ) -> None:
        """
        :param count: 
        :param depends_on: 
        :param lifecycle: 
        :param provider: 
        :param name: 
        :param timeouts: timeouts block.
        """
        if isinstance(lifecycle, dict):
            lifecycle = cdktf.TerraformResourceLifecycle(**lifecycle)
        if isinstance(timeouts, dict):
            timeouts = DataAzurermResourceGroupTimeouts(**timeouts)
        self._values: typing.Dict[str, typing.Any] = {
            "name": name,
        }
        if count is not None:
            self._values["count"] = count
        if depends_on is not None:
            self._values["depends_on"] = depends_on
        if lifecycle is not None:
            self._values["lifecycle"] = lifecycle
        if provider is not None:
            self._values["provider"] = provider
        if timeouts is not None:
            self._values["timeouts"] = timeouts

    @builtins.property
    def count(self) -> typing.Optional[jsii.Number]:
        """
        :stability: experimental
        """
        result = self._values.get("count")
        return result

    @builtins.property
    def depends_on(self) -> typing.Optional[typing.List[cdktf.TerraformResource]]:
        """
        :stability: experimental
        """
        result = self._values.get("depends_on")
        return result

    @builtins.property
    def lifecycle(self) -> typing.Optional[cdktf.TerraformResourceLifecycle]:
        """
        :stability: experimental
        """
        result = self._values.get("lifecycle")
        return result

    @builtins.property
    def provider(self) -> typing.Optional[cdktf.TerraformProvider]:
        """
        :stability: experimental
        """
        result = self._values.get("provider")
        return result

    @builtins.property
    def name(self) -> builtins.str:
        result = self._values.get("name")
        assert result is not None, "Required property 'name' is missing"
        return result

    @builtins.property
    def timeouts(self) -> typing.Optional["DataAzurermResourceGroupTimeouts"]:
        """timeouts block."""
        result = self._values.get("timeouts")
        return result

    def __eq__(self, rhs: typing.Any) -> builtins.bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs: typing.Any) -> builtins.bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return "DataAzurermResourceGroupConfig(%s)" % ", ".join(
            k + "=" + repr(v) for k, v in self._values.items()
        )


@jsii.data_type(
    jsii_type="@cdktf/provider-azurerm.DataAzurermResourceGroupTimeouts",
    jsii_struct_bases=[],
    name_mapping={"read": "read"},
)
class DataAzurermResourceGroupTimeouts:
    def __init__(self, *, read: typing.Optional[builtins.str] = None) -> None:
        """
        :param read: 
        """
        self._values: typing.Dict[str, typing.Any] = {}
        if read is not None:
            self._values["read"] = read

    @builtins.property
    def read(self) -> typing.Optional[builtins.str]:
        result = self._values.get("read")
        return result

    def __eq__(self, rhs: typing.Any) -> builtins.bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs: typing.Any) -> builtins.bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return "DataAzurermResourceGroupTimeouts(%s)" % ", ".join(
            k + "=" + repr(v) for k, v in self._values.items()
        )


class DataAzurermResources(
    cdktf.TerraformDataSource,
    metaclass=jsii.JSIIMeta,
    jsii_type="@cdktf/provider-azurerm.DataAzurermResources",
):
    def __init__(
        self,
        scope: constructs.Construct,
        id: builtins.str,
        *,
        name: typing.Optional[builtins.str] = None,
        required_tags: typing.Optional[typing.Mapping[builtins.str, builtins.str]] = None,
        resource_group_name: typing.Optional[builtins.str] = None,
        timeouts: typing.Optional["DataAzurermResourcesTimeouts"] = None,
        type: typing.Optional[builtins.str] = None,
        count: typing.Optional[jsii.Number] = None,
        depends_on: typing.Optional[typing.List[cdktf.TerraformResource]] = None,
        lifecycle: typing.Optional[cdktf.TerraformResourceLifecycle] = None,
        provider: typing.Optional[cdktf.TerraformProvider] = None,
    ) -> None:
        """
        :param scope: -
        :param id: -
        :param name: 
        :param required_tags: 
        :param resource_group_name: 
        :param timeouts: timeouts block.
        :param type: 
        :param count: 
        :param depends_on: 
        :param lifecycle: 
        :param provider: 
        """
        config = DataAzurermResourcesConfig(
            name=name,
            required_tags=required_tags,
            resource_group_name=resource_group_name,
            timeouts=timeouts,
            type=type,
            count=count,
            depends_on=depends_on,
            lifecycle=lifecycle,
            provider=provider,
        )

        jsii.create(DataAzurermResources, self, [scope, id, config])

    @jsii.member(jsii_name="resources")
    def resources(self, index: builtins.str) -> "DataAzurermResourcesResources":
        """
        :param index: -
        """
        return jsii.invoke(self, "resources", [index])

    @jsii.member(jsii_name="synthesizeAttributes")
    def _synthesize_attributes(self) -> typing.Mapping[builtins.str, typing.Any]:
        return jsii.invoke(self, "synthesizeAttributes", [])

    @builtins.property # type: ignore
    @jsii.member(jsii_name="id")
    def id(self) -> typing.Optional[builtins.str]:
        return jsii.get(self, "id")

    @id.setter # type: ignore
    def id(self, value: typing.Optional[builtins.str]) -> None:
        jsii.set(self, "id", value)

    @builtins.property # type: ignore
    @jsii.member(jsii_name="name")
    def name(self) -> typing.Optional[builtins.str]:
        return jsii.get(self, "name")

    @name.setter # type: ignore
    def name(self, value: typing.Optional[builtins.str]) -> None:
        jsii.set(self, "name", value)

    @builtins.property # type: ignore
    @jsii.member(jsii_name="requiredTags")
    def required_tags(
        self,
    ) -> typing.Optional[typing.Mapping[builtins.str, builtins.str]]:
        return jsii.get(self, "requiredTags")

    @required_tags.setter # type: ignore
    def required_tags(
        self,
        value: typing.Optional[typing.Mapping[builtins.str, builtins.str]],
    ) -> None:
        jsii.set(self, "requiredTags", value)

    @builtins.property # type: ignore
    @jsii.member(jsii_name="resourceGroupName")
    def resource_group_name(self) -> typing.Optional[builtins.str]:
        return jsii.get(self, "resourceGroupName")

    @resource_group_name.setter # type: ignore
    def resource_group_name(self, value: typing.Optional[builtins.str]) -> None:
        jsii.set(self, "resourceGroupName", value)

    @builtins.property # type: ignore
    @jsii.member(jsii_name="timeouts")
    def timeouts(self) -> typing.Optional["DataAzurermResourcesTimeouts"]:
        return jsii.get(self, "timeouts")

    @timeouts.setter # type: ignore
    def timeouts(self, value: typing.Optional["DataAzurermResourcesTimeouts"]) -> None:
        jsii.set(self, "timeouts", value)

    @builtins.property # type: ignore
    @jsii.member(jsii_name="type")
    def type(self) -> typing.Optional[builtins.str]:
        return jsii.get(self, "type")

    @type.setter # type: ignore
    def type(self, value: typing.Optional[builtins.str]) -> None:
        jsii.set(self, "type", value)


@jsii.data_type(
    jsii_type="@cdktf/provider-azurerm.DataAzurermResourcesConfig",
    jsii_struct_bases=[cdktf.TerraformMetaArguments],
    name_mapping={
        "count": "count",
        "depends_on": "dependsOn",
        "lifecycle": "lifecycle",
        "provider": "provider",
        "name": "name",
        "required_tags": "requiredTags",
        "resource_group_name": "resourceGroupName",
        "timeouts": "timeouts",
        "type": "type",
    },
)
class DataAzurermResourcesConfig(cdktf.TerraformMetaArguments):
    def __init__(
        self,
        *,
        count: typing.Optional[jsii.Number] = None,
        depends_on: typing.Optional[typing.List[cdktf.TerraformResource]] = None,
        lifecycle: typing.Optional[cdktf.TerraformResourceLifecycle] = None,
        provider: typing.Optional[cdktf.TerraformProvider] = None,
        name: typing.Optional[builtins.str] = None,
        required_tags: typing.Optional[typing.Mapping[builtins.str, builtins.str]] = None,
        resource_group_name: typing.Optional[builtins.str] = None,
        timeouts: typing.Optional["DataAzurermResourcesTimeouts"] = None,
        type: typing.Optional[builtins.str] = None,
    ) -> None:
        """
        :param count: 
        :param depends_on: 
        :param lifecycle: 
        :param provider: 
        :param name: 
        :param required_tags: 
        :param resource_group_name: 
        :param timeouts: timeouts block.
        :param type: 
        """
        if isinstance(lifecycle, dict):
            lifecycle = cdktf.TerraformResourceLifecycle(**lifecycle)
        if isinstance(timeouts, dict):
            timeouts = DataAzurermResourcesTimeouts(**timeouts)
        self._values: typing.Dict[str, typing.Any] = {}
        if count is not None:
            self._values["count"] = count
        if depends_on is not None:
            self._values["depends_on"] = depends_on
        if lifecycle is not None:
            self._values["lifecycle"] = lifecycle
        if provider is not None:
            self._values["provider"] = provider
        if name is not None:
            self._values["name"] = name
        if required_tags is not None:
            self._values["required_tags"] = required_tags
        if resource_group_name is not None:
            self._values["resource_group_name"] = resource_group_name
        if timeouts is not None:
            self._values["timeouts"] = timeouts
        if type is not None:
            self._values["type"] = type

    @builtins.property
    def count(self) -> typing.Optional[jsii.Number]:
        """
        :stability: experimental
        """
        result = self._values.get("count")
        return result

    @builtins.property
    def depends_on(self) -> typing.Optional[typing.List[cdktf.TerraformResource]]:
        """
        :stability: experimental
        """
        result = self._values.get("depends_on")
        return result

    @builtins.property
    def lifecycle(self) -> typing.Optional[cdktf.TerraformResourceLifecycle]:
        """
        :stability: experimental
        """
        result = self._values.get("lifecycle")
        return result

    @builtins.property
    def provider(self) -> typing.Optional[cdktf.TerraformProvider]:
        """
        :stability: experimental
        """
        result = self._values.get("provider")
        return result

    @builtins.property
    def name(self) -> typing.Optional[builtins.str]:
        result = self._values.get("name")
        return result

    @builtins.property
    def required_tags(
        self,
    ) -> typing.Optional[typing.Mapping[builtins.str, builtins.str]]:
        result = self._values.get("required_tags")
        return result

    @builtins.property
    def resource_group_name(self) -> typing.Optional[builtins.str]:
        result = self._values.get("resource_group_name")
        return result

    @builtins.property
    def timeouts(self) -> typing.Optional["DataAzurermResourcesTimeouts"]:
        """timeouts block."""
        result = self._values.get("timeouts")
        return result

    @builtins.property
    def type(self) -> typing.Optional[builtins.str]:
        result = self._values.get("type")
        return result

    def __eq__(self, rhs: typing.Any) -> builtins.bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs: typing.Any) -> builtins.bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return "DataAzurermResourcesConfig(%s)" % ", ".join(
            k + "=" + repr(v) for k, v in self._values.items()
        )


class DataAzurermResourcesResources(
    cdktf.ComplexComputedList,
    metaclass=jsii.JSIIMeta,
    jsii_type="@cdktf/provider-azurerm.DataAzurermResourcesResources",
):
    def __init__(
        self,
        terraform_resource: cdktf.ITerraformResource,
        terraform_attribute: builtins.str,
        index: builtins.str,
    ) -> None:
        """
        :param terraform_resource: -
        :param terraform_attribute: -
        :param index: -

        :stability: experimental
        """
        jsii.create(DataAzurermResourcesResources, self, [terraform_resource, terraform_attribute, index])

    @builtins.property # type: ignore
    @jsii.member(jsii_name="id")
    def id(self) -> builtins.str:
        return jsii.get(self, "id")

    @builtins.property # type: ignore
    @jsii.member(jsii_name="location")
    def location(self) -> builtins.str:
        return jsii.get(self, "location")

    @builtins.property # type: ignore
    @jsii.member(jsii_name="name")
    def name(self) -> builtins.str:
        return jsii.get(self, "name")

    @builtins.property # type: ignore
    @jsii.member(jsii_name="tags")
    def tags(self) -> typing.Any:
        return jsii.get(self, "tags")

    @builtins.property # type: ignore
    @jsii.member(jsii_name="type")
    def type(self) -> builtins.str:
        return jsii.get(self, "type")


@jsii.data_type(
    jsii_type="@cdktf/provider-azurerm.DataAzurermResourcesTimeouts",
    jsii_struct_bases=[],
    name_mapping={"read": "read"},
)
class DataAzurermResourcesTimeouts:
    def __init__(self, *, read: typing.Optional[builtins.str] = None) -> None:
        """
        :param read: 
        """
        self._values: typing.Dict[str, typing.Any] = {}
        if read is not None:
            self._values["read"] = read

    @builtins.property
    def read(self) -> typing.Optional[builtins.str]:
        result = self._values.get("read")
        return result

    def __eq__(self, rhs: typing.Any) -> builtins.bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs: typing.Any) -> builtins.bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return "DataAzurermResourcesTimeouts(%s)" % ", ".join(
            k + "=" + repr(v) for k, v in self._values.items()
        )


class DataAzurermRoleDefinition(
    cdktf.TerraformDataSource,
    metaclass=jsii.JSIIMeta,
    jsii_type="@cdktf/provider-azurerm.DataAzurermRoleDefinition",
):
    def __init__(
        self,
        scope_: constructs.Construct,
        id: builtins.str,
        *,
        name: typing.Optional[builtins.str] = None,
        role_definition_id: typing.Optional[builtins.str] = None,
        scope: typing.Optional[builtins.str] = None,
        timeouts: typing.Optional["DataAzurermRoleDefinitionTimeouts"] = None,
        count: typing.Optional[jsii.Number] = None,
        depends_on: typing.Optional[typing.List[cdktf.TerraformResource]] = None,
        lifecycle: typing.Optional[cdktf.TerraformResourceLifecycle] = None,
        provider: typing.Optional[cdktf.TerraformProvider] = None,
    ) -> None:
        """
        :param scope_: -
        :param id: -
        :param name: 
        :param role_definition_id: 
        :param scope: 
        :param timeouts: timeouts block.
        :param count: 
        :param depends_on: 
        :param lifecycle: 
        :param provider: 
        """
        config = DataAzurermRoleDefinitionConfig(
            name=name,
            role_definition_id=role_definition_id,
            scope=scope,
            timeouts=timeouts,
            count=count,
            depends_on=depends_on,
            lifecycle=lifecycle,
            provider=provider,
        )

        jsii.create(DataAzurermRoleDefinition, self, [scope_, id, config])

    @jsii.member(jsii_name="permissions")
    def permissions(
        self,
        index: builtins.str,
    ) -> "DataAzurermRoleDefinitionPermissions":
        """
        :param index: -
        """
        return jsii.invoke(self, "permissions", [index])

    @jsii.member(jsii_name="synthesizeAttributes")
    def _synthesize_attributes(self) -> typing.Mapping[builtins.str, typing.Any]:
        return jsii.invoke(self, "synthesizeAttributes", [])

    @builtins.property # type: ignore
    @jsii.member(jsii_name="assignableScopes")
    def assignable_scopes(self) -> typing.List[builtins.str]:
        return jsii.get(self, "assignableScopes")

    @builtins.property # type: ignore
    @jsii.member(jsii_name="description")
    def description(self) -> builtins.str:
        return jsii.get(self, "description")

    @builtins.property # type: ignore
    @jsii.member(jsii_name="type")
    def type(self) -> builtins.str:
        return jsii.get(self, "type")

    @builtins.property # type: ignore
    @jsii.member(jsii_name="id")
    def id(self) -> typing.Optional[builtins.str]:
        return jsii.get(self, "id")

    @id.setter # type: ignore
    def id(self, value: typing.Optional[builtins.str]) -> None:
        jsii.set(self, "id", value)

    @builtins.property # type: ignore
    @jsii.member(jsii_name="name")
    def name(self) -> typing.Optional[builtins.str]:
        return jsii.get(self, "name")

    @name.setter # type: ignore
    def name(self, value: typing.Optional[builtins.str]) -> None:
        jsii.set(self, "name", value)

    @builtins.property # type: ignore
    @jsii.member(jsii_name="roleDefinitionId")
    def role_definition_id(self) -> typing.Optional[builtins.str]:
        return jsii.get(self, "roleDefinitionId")

    @role_definition_id.setter # type: ignore
    def role_definition_id(self, value: typing.Optional[builtins.str]) -> None:
        jsii.set(self, "roleDefinitionId", value)

    @builtins.property # type: ignore
    @jsii.member(jsii_name="scope")
    def scope(self) -> typing.Optional[builtins.str]:
        return jsii.get(self, "scope")

    @scope.setter # type: ignore
    def scope(self, value: typing.Optional[builtins.str]) -> None:
        jsii.set(self, "scope", value)

    @builtins.property # type: ignore
    @jsii.member(jsii_name="timeouts")
    def timeouts(self) -> typing.Optional["DataAzurermRoleDefinitionTimeouts"]:
        return jsii.get(self, "timeouts")

    @timeouts.setter # type: ignore
    def timeouts(
        self,
        value: typing.Optional["DataAzurermRoleDefinitionTimeouts"],
    ) -> None:
        jsii.set(self, "timeouts", value)


@jsii.data_type(
    jsii_type="@cdktf/provider-azurerm.DataAzurermRoleDefinitionConfig",
    jsii_struct_bases=[cdktf.TerraformMetaArguments],
    name_mapping={
        "count": "count",
        "depends_on": "dependsOn",
        "lifecycle": "lifecycle",
        "provider": "provider",
        "name": "name",
        "role_definition_id": "roleDefinitionId",
        "scope": "scope",
        "timeouts": "timeouts",
    },
)
class DataAzurermRoleDefinitionConfig(cdktf.TerraformMetaArguments):
    def __init__(
        self,
        *,
        count: typing.Optional[jsii.Number] = None,
        depends_on: typing.Optional[typing.List[cdktf.TerraformResource]] = None,
        lifecycle: typing.Optional[cdktf.TerraformResourceLifecycle] = None,
        provider: typing.Optional[cdktf.TerraformProvider] = None,
        name: typing.Optional[builtins.str] = None,
        role_definition_id: typing.Optional[builtins.str] = None,
        scope: typing.Optional[builtins.str] = None,
        timeouts: typing.Optional["DataAzurermRoleDefinitionTimeouts"] = None,
    ) -> None:
        """
        :param count: 
        :param depends_on: 
        :param lifecycle: 
        :param provider: 
        :param name: 
        :param role_definition_id: 
        :param scope: 
        :param timeouts: timeouts block.
        """
        if isinstance(lifecycle, dict):
            lifecycle = cdktf.TerraformResourceLifecycle(**lifecycle)
        if isinstance(timeouts, dict):
            timeouts = DataAzurermRoleDefinitionTimeouts(**timeouts)
        self._values: typing.Dict[str, typing.Any] = {}
        if count is not None:
            self._values["count"] = count
        if depends_on is not None:
            self._values["depends_on"] = depends_on
        if lifecycle is not None:
            self._values["lifecycle"] = lifecycle
        if provider is not None:
            self._values["provider"] = provider
        if name is not None:
            self._values["name"] = name
        if role_definition_id is not None:
            self._values["role_definition_id"] = role_definition_id
        if scope is not None:
            self._values["scope"] = scope
        if timeouts is not None:
            self._values["timeouts"] = timeouts

    @builtins.property
    def count(self) -> typing.Optional[jsii.Number]:
        """
        :stability: experimental
        """
        result = self._values.get("count")
        return result

    @builtins.property
    def depends_on(self) -> typing.Optional[typing.List[cdktf.TerraformResource]]:
        """
        :stability: experimental
        """
        result = self._values.get("depends_on")
        return result

    @builtins.property
    def lifecycle(self) -> typing.Optional[cdktf.TerraformResourceLifecycle]:
        """
        :stability: experimental
        """
        result = self._values.get("lifecycle")
        return result

    @builtins.property
    def provider(self) -> typing.Optional[cdktf.TerraformProvider]:
        """
        :stability: experimental
        """
        result = self._values.get("provider")
        return result

    @builtins.property
    def name(self) -> typing.Optional[builtins.str]:
        result = self._values.get("name")
        return result

    @builtins.property
    def role_definition_id(self) -> typing.Optional[builtins.str]:
        result = self._values.get("role_definition_id")
        return result

    @builtins.property
    def scope(self) -> typing.Optional[builtins.str]:
        result = self._values.get("scope")
        return result

    @builtins.property
    def timeouts(self) -> typing.Optional["DataAzurermRoleDefinitionTimeouts"]:
        """timeouts block."""
        result = self._values.get("timeouts")
        return result

    def __eq__(self, rhs: typing.Any) -> builtins.bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs: typing.Any) -> builtins.bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return "DataAzurermRoleDefinitionConfig(%s)" % ", ".join(
            k + "=" + repr(v) for k, v in self._values.items()
        )


class DataAzurermRoleDefinitionPermissions(
    cdktf.ComplexComputedList,
    metaclass=jsii.JSIIMeta,
    jsii_type="@cdktf/provider-azurerm.DataAzurermRoleDefinitionPermissions",
):
    def __init__(
        self,
        terraform_resource: cdktf.ITerraformResource,
        terraform_attribute: builtins.str,
        index: builtins.str,
    ) -> None:
        """
        :param terraform_resource: -
        :param terraform_attribute: -
        :param index: -

        :stability: experimental
        """
        jsii.create(DataAzurermRoleDefinitionPermissions, self, [terraform_resource, terraform_attribute, index])

    @builtins.property # type: ignore
    @jsii.member(jsii_name="actions")
    def actions(self) -> typing.List[builtins.str]:
        return jsii.get(self, "actions")

    @builtins.property # type: ignore
    @jsii.member(jsii_name="dataActions")
    def data_actions(self) -> typing.List[builtins.str]:
        return jsii.get(self, "dataActions")

    @builtins.property # type: ignore
    @jsii.member(jsii_name="notActions")
    def not_actions(self) -> typing.List[builtins.str]:
        return jsii.get(self, "notActions")

    @builtins.property # type: ignore
    @jsii.member(jsii_name="notDataActions")
    def not_data_actions(self) -> typing.List[builtins.str]:
        return jsii.get(self, "notDataActions")


@jsii.data_type(
    jsii_type="@cdktf/provider-azurerm.DataAzurermRoleDefinitionTimeouts",
    jsii_struct_bases=[],
    name_mapping={"read": "read"},
)
class DataAzurermRoleDefinitionTimeouts:
    def __init__(self, *, read: typing.Optional[builtins.str] = None) -> None:
        """
        :param read: 
        """
        self._values: typing.Dict[str, typing.Any] = {}
        if read is not None:
            self._values["read"] = read

    @builtins.property
    def read(self) -> typing.Optional[builtins.str]:
        result = self._values.get("read")
        return result

    def __eq__(self, rhs: typing.Any) -> builtins.bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs: typing.Any) -> builtins.bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return "DataAzurermRoleDefinitionTimeouts(%s)" % ", ".join(
            k + "=" + repr(v) for k, v in self._values.items()
        )


class DataAzurermRouteTable(
    cdktf.TerraformDataSource,
    metaclass=jsii.JSIIMeta,
    jsii_type="@cdktf/provider-azurerm.DataAzurermRouteTable",
):
    def __init__(
        self,
        scope: constructs.Construct,
        id: builtins.str,
        *,
        name: builtins.str,
        resource_group_name: builtins.str,
        timeouts: typing.Optional["DataAzurermRouteTableTimeouts"] = None,
        count: typing.Optional[jsii.Number] = None,
        depends_on: typing.Optional[typing.List[cdktf.TerraformResource]] = None,
        lifecycle: typing.Optional[cdktf.TerraformResourceLifecycle] = None,
        provider: typing.Optional[cdktf.TerraformProvider] = None,
    ) -> None:
        """
        :param scope: -
        :param id: -
        :param name: 
        :param resource_group_name: 
        :param timeouts: timeouts block.
        :param count: 
        :param depends_on: 
        :param lifecycle: 
        :param provider: 
        """
        config = DataAzurermRouteTableConfig(
            name=name,
            resource_group_name=resource_group_name,
            timeouts=timeouts,
            count=count,
            depends_on=depends_on,
            lifecycle=lifecycle,
            provider=provider,
        )

        jsii.create(DataAzurermRouteTable, self, [scope, id, config])

    @jsii.member(jsii_name="route")
    def route(self, index: builtins.str) -> "DataAzurermRouteTableRoute":
        """
        :param index: -
        """
        return jsii.invoke(self, "route", [index])

    @jsii.member(jsii_name="synthesizeAttributes")
    def _synthesize_attributes(self) -> typing.Mapping[builtins.str, typing.Any]:
        return jsii.invoke(self, "synthesizeAttributes", [])

    @jsii.member(jsii_name="tags")
    def tags(self, key: builtins.str) -> builtins.str:
        """
        :param key: -
        """
        return jsii.invoke(self, "tags", [key])

    @builtins.property # type: ignore
    @jsii.member(jsii_name="location")
    def location(self) -> builtins.str:
        return jsii.get(self, "location")

    @builtins.property # type: ignore
    @jsii.member(jsii_name="subnets")
    def subnets(self) -> typing.List[builtins.str]:
        return jsii.get(self, "subnets")

    @builtins.property # type: ignore
    @jsii.member(jsii_name="name")
    def name(self) -> builtins.str:
        return jsii.get(self, "name")

    @name.setter # type: ignore
    def name(self, value: builtins.str) -> None:
        jsii.set(self, "name", value)

    @builtins.property # type: ignore
    @jsii.member(jsii_name="resourceGroupName")
    def resource_group_name(self) -> builtins.str:
        return jsii.get(self, "resourceGroupName")

    @resource_group_name.setter # type: ignore
    def resource_group_name(self, value: builtins.str) -> None:
        jsii.set(self, "resourceGroupName", value)

    @builtins.property # type: ignore
    @jsii.member(jsii_name="id")
    def id(self) -> typing.Optional[builtins.str]:
        return jsii.get(self, "id")

    @id.setter # type: ignore
    def id(self, value: typing.Optional[builtins.str]) -> None:
        jsii.set(self, "id", value)

    @builtins.property # type: ignore
    @jsii.member(jsii_name="timeouts")
    def timeouts(self) -> typing.Optional["DataAzurermRouteTableTimeouts"]:
        return jsii.get(self, "timeouts")

    @timeouts.setter # type: ignore
    def timeouts(self, value: typing.Optional["DataAzurermRouteTableTimeouts"]) -> None:
        jsii.set(self, "timeouts", value)


@jsii.data_type(
    jsii_type="@cdktf/provider-azurerm.DataAzurermRouteTableConfig",
    jsii_struct_bases=[cdktf.TerraformMetaArguments],
    name_mapping={
        "count": "count",
        "depends_on": "dependsOn",
        "lifecycle": "lifecycle",
        "provider": "provider",
        "name": "name",
        "resource_group_name": "resourceGroupName",
        "timeouts": "timeouts",
    },
)
class DataAzurermRouteTableConfig(cdktf.TerraformMetaArguments):
    def __init__(
        self,
        *,
        count: typing.Optional[jsii.Number] = None,
        depends_on: typing.Optional[typing.List[cdktf.TerraformResource]] = None,
        lifecycle: typing.Optional[cdktf.TerraformResourceLifecycle] = None,
        provider: typing.Optional[cdktf.TerraformProvider] = None,
        name: builtins.str,
        resource_group_name: builtins.str,
        timeouts: typing.Optional["DataAzurermRouteTableTimeouts"] = None,
    ) -> None:
        """
        :param count: 
        :param depends_on: 
        :param lifecycle: 
        :param provider: 
        :param name: 
        :param resource_group_name: 
        :param timeouts: timeouts block.
        """
        if isinstance(lifecycle, dict):
            lifecycle = cdktf.TerraformResourceLifecycle(**lifecycle)
        if isinstance(timeouts, dict):
            timeouts = DataAzurermRouteTableTimeouts(**timeouts)
        self._values: typing.Dict[str, typing.Any] = {
            "name": name,
            "resource_group_name": resource_group_name,
        }
        if count is not None:
            self._values["count"] = count
        if depends_on is not None:
            self._values["depends_on"] = depends_on
        if lifecycle is not None:
            self._values["lifecycle"] = lifecycle
        if provider is not None:
            self._values["provider"] = provider
        if timeouts is not None:
            self._values["timeouts"] = timeouts

    @builtins.property
    def count(self) -> typing.Optional[jsii.Number]:
        """
        :stability: experimental
        """
        result = self._values.get("count")
        return result

    @builtins.property
    def depends_on(self) -> typing.Optional[typing.List[cdktf.TerraformResource]]:
        """
        :stability: experimental
        """
        result = self._values.get("depends_on")
        return result

    @builtins.property
    def lifecycle(self) -> typing.Optional[cdktf.TerraformResourceLifecycle]:
        """
        :stability: experimental
        """
        result = self._values.get("lifecycle")
        return result

    @builtins.property
    def provider(self) -> typing.Optional[cdktf.TerraformProvider]:
        """
        :stability: experimental
        """
        result = self._values.get("provider")
        return result

    @builtins.property
    def name(self) -> builtins.str:
        result = self._values.get("name")
        assert result is not None, "Required property 'name' is missing"
        return result

    @builtins.property
    def resource_group_name(self) -> builtins.str:
        result = self._values.get("resource_group_name")
        assert result is not None, "Required property 'resource_group_name' is missing"
        return result

    @builtins.property
    def timeouts(self) -> typing.Optional["DataAzurermRouteTableTimeouts"]:
        """timeouts block."""
        result = self._values.get("timeouts")
        return result

    def __eq__(self, rhs: typing.Any) -> builtins.bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs: typing.Any) -> builtins.bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return "DataAzurermRouteTableConfig(%s)" % ", ".join(
            k + "=" + repr(v) for k, v in self._values.items()
        )


class DataAzurermRouteTableRoute(
    cdktf.ComplexComputedList,
    metaclass=jsii.JSIIMeta,
    jsii_type="@cdktf/provider-azurerm.DataAzurermRouteTableRoute",
):
    def __init__(
        self,
        terraform_resource: cdktf.ITerraformResource,
        terraform_attribute: builtins.str,
        index: builtins.str,
    ) -> None:
        """
        :param terraform_resource: -
        :param terraform_attribute: -
        :param index: -

        :stability: experimental
        """
        jsii.create(DataAzurermRouteTableRoute, self, [terraform_resource, terraform_attribute, index])

    @builtins.property # type: ignore
    @jsii.member(jsii_name="addressPrefix")
    def address_prefix(self) -> builtins.str:
        return jsii.get(self, "addressPrefix")

    @builtins.property # type: ignore
    @jsii.member(jsii_name="name")
    def name(self) -> builtins.str:
        return jsii.get(self, "name")

    @builtins.property # type: ignore
    @jsii.member(jsii_name="nextHopInIpAddress")
    def next_hop_in_ip_address(self) -> builtins.str:
        return jsii.get(self, "nextHopInIpAddress")

    @builtins.property # type: ignore
    @jsii.member(jsii_name="nextHopType")
    def next_hop_type(self) -> builtins.str:
        return jsii.get(self, "nextHopType")


@jsii.data_type(
    jsii_type="@cdktf/provider-azurerm.DataAzurermRouteTableTimeouts",
    jsii_struct_bases=[],
    name_mapping={"read": "read"},
)
class DataAzurermRouteTableTimeouts:
    def __init__(self, *, read: typing.Optional[builtins.str] = None) -> None:
        """
        :param read: 
        """
        self._values: typing.Dict[str, typing.Any] = {}
        if read is not None:
            self._values["read"] = read

    @builtins.property
    def read(self) -> typing.Optional[builtins.str]:
        result = self._values.get("read")
        return result

    def __eq__(self, rhs: typing.Any) -> builtins.bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs: typing.Any) -> builtins.bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return "DataAzurermRouteTableTimeouts(%s)" % ", ".join(
            k + "=" + repr(v) for k, v in self._values.items()
        )


class DataAzurermServicebusNamespace(
    cdktf.TerraformDataSource,
    metaclass=jsii.JSIIMeta,
    jsii_type="@cdktf/provider-azurerm.DataAzurermServicebusNamespace",
):
    def __init__(
        self,
        scope: constructs.Construct,
        id: builtins.str,
        *,
        name: builtins.str,
        resource_group_name: builtins.str,
        timeouts: typing.Optional["DataAzurermServicebusNamespaceTimeouts"] = None,
        count: typing.Optional[jsii.Number] = None,
        depends_on: typing.Optional[typing.List[cdktf.TerraformResource]] = None,
        lifecycle: typing.Optional[cdktf.TerraformResourceLifecycle] = None,
        provider: typing.Optional[cdktf.TerraformProvider] = None,
    ) -> None:
        """
        :param scope: -
        :param id: -
        :param name: 
        :param resource_group_name: 
        :param timeouts: timeouts block.
        :param count: 
        :param depends_on: 
        :param lifecycle: 
        :param provider: 
        """
        config = DataAzurermServicebusNamespaceConfig(
            name=name,
            resource_group_name=resource_group_name,
            timeouts=timeouts,
            count=count,
            depends_on=depends_on,
            lifecycle=lifecycle,
            provider=provider,
        )

        jsii.create(DataAzurermServicebusNamespace, self, [scope, id, config])

    @jsii.member(jsii_name="synthesizeAttributes")
    def _synthesize_attributes(self) -> typing.Mapping[builtins.str, typing.Any]:
        return jsii.invoke(self, "synthesizeAttributes", [])

    @jsii.member(jsii_name="tags")
    def tags(self, key: builtins.str) -> builtins.str:
        """
        :param key: -
        """
        return jsii.invoke(self, "tags", [key])

    @builtins.property # type: ignore
    @jsii.member(jsii_name="capacity")
    def capacity(self) -> jsii.Number:
        return jsii.get(self, "capacity")

    @builtins.property # type: ignore
    @jsii.member(jsii_name="defaultPrimaryConnectionString")
    def default_primary_connection_string(self) -> builtins.str:
        return jsii.get(self, "defaultPrimaryConnectionString")

    @builtins.property # type: ignore
    @jsii.member(jsii_name="defaultPrimaryKey")
    def default_primary_key(self) -> builtins.str:
        return jsii.get(self, "defaultPrimaryKey")

    @builtins.property # type: ignore
    @jsii.member(jsii_name="defaultSecondaryConnectionString")
    def default_secondary_connection_string(self) -> builtins.str:
        return jsii.get(self, "defaultSecondaryConnectionString")

    @builtins.property # type: ignore
    @jsii.member(jsii_name="defaultSecondaryKey")
    def default_secondary_key(self) -> builtins.str:
        return jsii.get(self, "defaultSecondaryKey")

    @builtins.property # type: ignore
    @jsii.member(jsii_name="location")
    def location(self) -> builtins.str:
        return jsii.get(self, "location")

    @builtins.property # type: ignore
    @jsii.member(jsii_name="sku")
    def sku(self) -> builtins.str:
        return jsii.get(self, "sku")

    @builtins.property # type: ignore
    @jsii.member(jsii_name="zoneRedundant")
    def zone_redundant(self) -> builtins.bool:
        return jsii.get(self, "zoneRedundant")

    @builtins.property # type: ignore
    @jsii.member(jsii_name="name")
    def name(self) -> builtins.str:
        return jsii.get(self, "name")

    @name.setter # type: ignore
    def name(self, value: builtins.str) -> None:
        jsii.set(self, "name", value)

    @builtins.property # type: ignore
    @jsii.member(jsii_name="resourceGroupName")
    def resource_group_name(self) -> builtins.str:
        return jsii.get(self, "resourceGroupName")

    @resource_group_name.setter # type: ignore
    def resource_group_name(self, value: builtins.str) -> None:
        jsii.set(self, "resourceGroupName", value)

    @builtins.property # type: ignore
    @jsii.member(jsii_name="id")
    def id(self) -> typing.Optional[builtins.str]:
        return jsii.get(self, "id")

    @id.setter # type: ignore
    def id(self, value: typing.Optional[builtins.str]) -> None:
        jsii.set(self, "id", value)

    @builtins.property # type: ignore
    @jsii.member(jsii_name="timeouts")
    def timeouts(self) -> typing.Optional["DataAzurermServicebusNamespaceTimeouts"]:
        return jsii.get(self, "timeouts")

    @timeouts.setter # type: ignore
    def timeouts(
        self,
        value: typing.Optional["DataAzurermServicebusNamespaceTimeouts"],
    ) -> None:
        jsii.set(self, "timeouts", value)


class DataAzurermServicebusNamespaceAuthorizationRule(
    cdktf.TerraformDataSource,
    metaclass=jsii.JSIIMeta,
    jsii_type="@cdktf/provider-azurerm.DataAzurermServicebusNamespaceAuthorizationRule",
):
    def __init__(
        self,
        scope: constructs.Construct,
        id: builtins.str,
        *,
        name: builtins.str,
        namespace_name: builtins.str,
        resource_group_name: builtins.str,
        timeouts: typing.Optional["DataAzurermServicebusNamespaceAuthorizationRuleTimeouts"] = None,
        count: typing.Optional[jsii.Number] = None,
        depends_on: typing.Optional[typing.List[cdktf.TerraformResource]] = None,
        lifecycle: typing.Optional[cdktf.TerraformResourceLifecycle] = None,
        provider: typing.Optional[cdktf.TerraformProvider] = None,
    ) -> None:
        """
        :param scope: -
        :param id: -
        :param name: 
        :param namespace_name: 
        :param resource_group_name: 
        :param timeouts: timeouts block.
        :param count: 
        :param depends_on: 
        :param lifecycle: 
        :param provider: 
        """
        config = DataAzurermServicebusNamespaceAuthorizationRuleConfig(
            name=name,
            namespace_name=namespace_name,
            resource_group_name=resource_group_name,
            timeouts=timeouts,
            count=count,
            depends_on=depends_on,
            lifecycle=lifecycle,
            provider=provider,
        )

        jsii.create(DataAzurermServicebusNamespaceAuthorizationRule, self, [scope, id, config])

    @jsii.member(jsii_name="synthesizeAttributes")
    def _synthesize_attributes(self) -> typing.Mapping[builtins.str, typing.Any]:
        return jsii.invoke(self, "synthesizeAttributes", [])

    @builtins.property # type: ignore
    @jsii.member(jsii_name="primaryConnectionString")
    def primary_connection_string(self) -> builtins.str:
        return jsii.get(self, "primaryConnectionString")

    @builtins.property # type: ignore
    @jsii.member(jsii_name="primaryKey")
    def primary_key(self) -> builtins.str:
        return jsii.get(self, "primaryKey")

    @builtins.property # type: ignore
    @jsii.member(jsii_name="secondaryConnectionString")
    def secondary_connection_string(self) -> builtins.str:
        return jsii.get(self, "secondaryConnectionString")

    @builtins.property # type: ignore
    @jsii.member(jsii_name="secondaryKey")
    def secondary_key(self) -> builtins.str:
        return jsii.get(self, "secondaryKey")

    @builtins.property # type: ignore
    @jsii.member(jsii_name="name")
    def name(self) -> builtins.str:
        return jsii.get(self, "name")

    @name.setter # type: ignore
    def name(self, value: builtins.str) -> None:
        jsii.set(self, "name", value)

    @builtins.property # type: ignore
    @jsii.member(jsii_name="namespaceName")
    def namespace_name(self) -> builtins.str:
        return jsii.get(self, "namespaceName")

    @namespace_name.setter # type: ignore
    def namespace_name(self, value: builtins.str) -> None:
        jsii.set(self, "namespaceName", value)

    @builtins.property # type: ignore
    @jsii.member(jsii_name="resourceGroupName")
    def resource_group_name(self) -> builtins.str:
        return jsii.get(self, "resourceGroupName")

    @resource_group_name.setter # type: ignore
    def resource_group_name(self, value: builtins.str) -> None:
        jsii.set(self, "resourceGroupName", value)

    @builtins.property # type: ignore
    @jsii.member(jsii_name="id")
    def id(self) -> typing.Optional[builtins.str]:
        return jsii.get(self, "id")

    @id.setter # type: ignore
    def id(self, value: typing.Optional[builtins.str]) -> None:
        jsii.set(self, "id", value)

    @builtins.property # type: ignore
    @jsii.member(jsii_name="timeouts")
    def timeouts(
        self,
    ) -> typing.Optional["DataAzurermServicebusNamespaceAuthorizationRuleTimeouts"]:
        return jsii.get(self, "timeouts")

    @timeouts.setter # type: ignore
    def timeouts(
        self,
        value: typing.Optional["DataAzurermServicebusNamespaceAuthorizationRuleTimeouts"],
    ) -> None:
        jsii.set(self, "timeouts", value)


@jsii.data_type(
    jsii_type="@cdktf/provider-azurerm.DataAzurermServicebusNamespaceAuthorizationRuleConfig",
    jsii_struct_bases=[cdktf.TerraformMetaArguments],
    name_mapping={
        "count": "count",
        "depends_on": "dependsOn",
        "lifecycle": "lifecycle",
        "provider": "provider",
        "name": "name",
        "namespace_name": "namespaceName",
        "resource_group_name": "resourceGroupName",
        "timeouts": "timeouts",
    },
)
class DataAzurermServicebusNamespaceAuthorizationRuleConfig(
    cdktf.TerraformMetaArguments,
):
    def __init__(
        self,
        *,
        count: typing.Optional[jsii.Number] = None,
        depends_on: typing.Optional[typing.List[cdktf.TerraformResource]] = None,
        lifecycle: typing.Optional[cdktf.TerraformResourceLifecycle] = None,
        provider: typing.Optional[cdktf.TerraformProvider] = None,
        name: builtins.str,
        namespace_name: builtins.str,
        resource_group_name: builtins.str,
        timeouts: typing.Optional["DataAzurermServicebusNamespaceAuthorizationRuleTimeouts"] = None,
    ) -> None:
        """
        :param count: 
        :param depends_on: 
        :param lifecycle: 
        :param provider: 
        :param name: 
        :param namespace_name: 
        :param resource_group_name: 
        :param timeouts: timeouts block.
        """
        if isinstance(lifecycle, dict):
            lifecycle = cdktf.TerraformResourceLifecycle(**lifecycle)
        if isinstance(timeouts, dict):
            timeouts = DataAzurermServicebusNamespaceAuthorizationRuleTimeouts(**timeouts)
        self._values: typing.Dict[str, typing.Any] = {
            "name": name,
            "namespace_name": namespace_name,
            "resource_group_name": resource_group_name,
        }
        if count is not None:
            self._values["count"] = count
        if depends_on is not None:
            self._values["depends_on"] = depends_on
        if lifecycle is not None:
            self._values["lifecycle"] = lifecycle
        if provider is not None:
            self._values["provider"] = provider
        if timeouts is not None:
            self._values["timeouts"] = timeouts

    @builtins.property
    def count(self) -> typing.Optional[jsii.Number]:
        """
        :stability: experimental
        """
        result = self._values.get("count")
        return result

    @builtins.property
    def depends_on(self) -> typing.Optional[typing.List[cdktf.TerraformResource]]:
        """
        :stability: experimental
        """
        result = self._values.get("depends_on")
        return result

    @builtins.property
    def lifecycle(self) -> typing.Optional[cdktf.TerraformResourceLifecycle]:
        """
        :stability: experimental
        """
        result = self._values.get("lifecycle")
        return result

    @builtins.property
    def provider(self) -> typing.Optional[cdktf.TerraformProvider]:
        """
        :stability: experimental
        """
        result = self._values.get("provider")
        return result

    @builtins.property
    def name(self) -> builtins.str:
        result = self._values.get("name")
        assert result is not None, "Required property 'name' is missing"
        return result

    @builtins.property
    def namespace_name(self) -> builtins.str:
        result = self._values.get("namespace_name")
        assert result is not None, "Required property 'namespace_name' is missing"
        return result

    @builtins.property
    def resource_group_name(self) -> builtins.str:
        result = self._values.get("resource_group_name")
        assert result is not None, "Required property 'resource_group_name' is missing"
        return result

    @builtins.property
    def timeouts(
        self,
    ) -> typing.Optional["DataAzurermServicebusNamespaceAuthorizationRuleTimeouts"]:
        """timeouts block."""
        result = self._values.get("timeouts")
        return result

    def __eq__(self, rhs: typing.Any) -> builtins.bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs: typing.Any) -> builtins.bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return "DataAzurermServicebusNamespaceAuthorizationRuleConfig(%s)" % ", ".join(
            k + "=" + repr(v) for k, v in self._values.items()
        )


@jsii.data_type(
    jsii_type="@cdktf/provider-azurerm.DataAzurermServicebusNamespaceAuthorizationRuleTimeouts",
    jsii_struct_bases=[],
    name_mapping={"read": "read"},
)
class DataAzurermServicebusNamespaceAuthorizationRuleTimeouts:
    def __init__(self, *, read: typing.Optional[builtins.str] = None) -> None:
        """
        :param read: 
        """
        self._values: typing.Dict[str, typing.Any] = {}
        if read is not None:
            self._values["read"] = read

    @builtins.property
    def read(self) -> typing.Optional[builtins.str]:
        result = self._values.get("read")
        return result

    def __eq__(self, rhs: typing.Any) -> builtins.bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs: typing.Any) -> builtins.bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return "DataAzurermServicebusNamespaceAuthorizationRuleTimeouts(%s)" % ", ".join(
            k + "=" + repr(v) for k, v in self._values.items()
        )


@jsii.data_type(
    jsii_type="@cdktf/provider-azurerm.DataAzurermServicebusNamespaceConfig",
    jsii_struct_bases=[cdktf.TerraformMetaArguments],
    name_mapping={
        "count": "count",
        "depends_on": "dependsOn",
        "lifecycle": "lifecycle",
        "provider": "provider",
        "name": "name",
        "resource_group_name": "resourceGroupName",
        "timeouts": "timeouts",
    },
)
class DataAzurermServicebusNamespaceConfig(cdktf.TerraformMetaArguments):
    def __init__(
        self,
        *,
        count: typing.Optional[jsii.Number] = None,
        depends_on: typing.Optional[typing.List[cdktf.TerraformResource]] = None,
        lifecycle: typing.Optional[cdktf.TerraformResourceLifecycle] = None,
        provider: typing.Optional[cdktf.TerraformProvider] = None,
        name: builtins.str,
        resource_group_name: builtins.str,
        timeouts: typing.Optional["DataAzurermServicebusNamespaceTimeouts"] = None,
    ) -> None:
        """
        :param count: 
        :param depends_on: 
        :param lifecycle: 
        :param provider: 
        :param name: 
        :param resource_group_name: 
        :param timeouts: timeouts block.
        """
        if isinstance(lifecycle, dict):
            lifecycle = cdktf.TerraformResourceLifecycle(**lifecycle)
        if isinstance(timeouts, dict):
            timeouts = DataAzurermServicebusNamespaceTimeouts(**timeouts)
        self._values: typing.Dict[str, typing.Any] = {
            "name": name,
            "resource_group_name": resource_group_name,
        }
        if count is not None:
            self._values["count"] = count
        if depends_on is not None:
            self._values["depends_on"] = depends_on
        if lifecycle is not None:
            self._values["lifecycle"] = lifecycle
        if provider is not None:
            self._values["provider"] = provider
        if timeouts is not None:
            self._values["timeouts"] = timeouts

    @builtins.property
    def count(self) -> typing.Optional[jsii.Number]:
        """
        :stability: experimental
        """
        result = self._values.get("count")
        return result

    @builtins.property
    def depends_on(self) -> typing.Optional[typing.List[cdktf.TerraformResource]]:
        """
        :stability: experimental
        """
        result = self._values.get("depends_on")
        return result

    @builtins.property
    def lifecycle(self) -> typing.Optional[cdktf.TerraformResourceLifecycle]:
        """
        :stability: experimental
        """
        result = self._values.get("lifecycle")
        return result

    @builtins.property
    def provider(self) -> typing.Optional[cdktf.TerraformProvider]:
        """
        :stability: experimental
        """
        result = self._values.get("provider")
        return result

    @builtins.property
    def name(self) -> builtins.str:
        result = self._values.get("name")
        assert result is not None, "Required property 'name' is missing"
        return result

    @builtins.property
    def resource_group_name(self) -> builtins.str:
        result = self._values.get("resource_group_name")
        assert result is not None, "Required property 'resource_group_name' is missing"
        return result

    @builtins.property
    def timeouts(self) -> typing.Optional["DataAzurermServicebusNamespaceTimeouts"]:
        """timeouts block."""
        result = self._values.get("timeouts")
        return result

    def __eq__(self, rhs: typing.Any) -> builtins.bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs: typing.Any) -> builtins.bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return "DataAzurermServicebusNamespaceConfig(%s)" % ", ".join(
            k + "=" + repr(v) for k, v in self._values.items()
        )


@jsii.data_type(
    jsii_type="@cdktf/provider-azurerm.DataAzurermServicebusNamespaceTimeouts",
    jsii_struct_bases=[],
    name_mapping={"read": "read"},
)
class DataAzurermServicebusNamespaceTimeouts:
    def __init__(self, *, read: typing.Optional[builtins.str] = None) -> None:
        """
        :param read: 
        """
        self._values: typing.Dict[str, typing.Any] = {}
        if read is not None:
            self._values["read"] = read

    @builtins.property
    def read(self) -> typing.Optional[builtins.str]:
        result = self._values.get("read")
        return result

    def __eq__(self, rhs: typing.Any) -> builtins.bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs: typing.Any) -> builtins.bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return "DataAzurermServicebusNamespaceTimeouts(%s)" % ", ".join(
            k + "=" + repr(v) for k, v in self._values.items()
        )


class DataAzurermSharedImage(
    cdktf.TerraformDataSource,
    metaclass=jsii.JSIIMeta,
    jsii_type="@cdktf/provider-azurerm.DataAzurermSharedImage",
):
    def __init__(
        self,
        scope: constructs.Construct,
        id: builtins.str,
        *,
        gallery_name: builtins.str,
        name: builtins.str,
        resource_group_name: builtins.str,
        timeouts: typing.Optional["DataAzurermSharedImageTimeouts"] = None,
        count: typing.Optional[jsii.Number] = None,
        depends_on: typing.Optional[typing.List[cdktf.TerraformResource]] = None,
        lifecycle: typing.Optional[cdktf.TerraformResourceLifecycle] = None,
        provider: typing.Optional[cdktf.TerraformProvider] = None,
    ) -> None:
        """
        :param scope: -
        :param id: -
        :param gallery_name: 
        :param name: 
        :param resource_group_name: 
        :param timeouts: timeouts block.
        :param count: 
        :param depends_on: 
        :param lifecycle: 
        :param provider: 
        """
        config = DataAzurermSharedImageConfig(
            gallery_name=gallery_name,
            name=name,
            resource_group_name=resource_group_name,
            timeouts=timeouts,
            count=count,
            depends_on=depends_on,
            lifecycle=lifecycle,
            provider=provider,
        )

        jsii.create(DataAzurermSharedImage, self, [scope, id, config])

    @jsii.member(jsii_name="identifier")
    def identifier(self, index: builtins.str) -> "DataAzurermSharedImageIdentifier":
        """
        :param index: -
        """
        return jsii.invoke(self, "identifier", [index])

    @jsii.member(jsii_name="synthesizeAttributes")
    def _synthesize_attributes(self) -> typing.Mapping[builtins.str, typing.Any]:
        return jsii.invoke(self, "synthesizeAttributes", [])

    @jsii.member(jsii_name="tags")
    def tags(self, key: builtins.str) -> builtins.str:
        """
        :param key: -
        """
        return jsii.invoke(self, "tags", [key])

    @builtins.property # type: ignore
    @jsii.member(jsii_name="description")
    def description(self) -> builtins.str:
        return jsii.get(self, "description")

    @builtins.property # type: ignore
    @jsii.member(jsii_name="eula")
    def eula(self) -> builtins.str:
        return jsii.get(self, "eula")

    @builtins.property # type: ignore
    @jsii.member(jsii_name="location")
    def location(self) -> builtins.str:
        return jsii.get(self, "location")

    @builtins.property # type: ignore
    @jsii.member(jsii_name="osType")
    def os_type(self) -> builtins.str:
        return jsii.get(self, "osType")

    @builtins.property # type: ignore
    @jsii.member(jsii_name="privacyStatementUri")
    def privacy_statement_uri(self) -> builtins.str:
        return jsii.get(self, "privacyStatementUri")

    @builtins.property # type: ignore
    @jsii.member(jsii_name="releaseNoteUri")
    def release_note_uri(self) -> builtins.str:
        return jsii.get(self, "releaseNoteUri")

    @builtins.property # type: ignore
    @jsii.member(jsii_name="galleryName")
    def gallery_name(self) -> builtins.str:
        return jsii.get(self, "galleryName")

    @gallery_name.setter # type: ignore
    def gallery_name(self, value: builtins.str) -> None:
        jsii.set(self, "galleryName", value)

    @builtins.property # type: ignore
    @jsii.member(jsii_name="name")
    def name(self) -> builtins.str:
        return jsii.get(self, "name")

    @name.setter # type: ignore
    def name(self, value: builtins.str) -> None:
        jsii.set(self, "name", value)

    @builtins.property # type: ignore
    @jsii.member(jsii_name="resourceGroupName")
    def resource_group_name(self) -> builtins.str:
        return jsii.get(self, "resourceGroupName")

    @resource_group_name.setter # type: ignore
    def resource_group_name(self, value: builtins.str) -> None:
        jsii.set(self, "resourceGroupName", value)

    @builtins.property # type: ignore
    @jsii.member(jsii_name="id")
    def id(self) -> typing.Optional[builtins.str]:
        return jsii.get(self, "id")

    @id.setter # type: ignore
    def id(self, value: typing.Optional[builtins.str]) -> None:
        jsii.set(self, "id", value)

    @builtins.property # type: ignore
    @jsii.member(jsii_name="timeouts")
    def timeouts(self) -> typing.Optional["DataAzurermSharedImageTimeouts"]:
        return jsii.get(self, "timeouts")

    @timeouts.setter # type: ignore
    def timeouts(
        self,
        value: typing.Optional["DataAzurermSharedImageTimeouts"],
    ) -> None:
        jsii.set(self, "timeouts", value)


@jsii.data_type(
    jsii_type="@cdktf/provider-azurerm.DataAzurermSharedImageConfig",
    jsii_struct_bases=[cdktf.TerraformMetaArguments],
    name_mapping={
        "count": "count",
        "depends_on": "dependsOn",
        "lifecycle": "lifecycle",
        "provider": "provider",
        "gallery_name": "galleryName",
        "name": "name",
        "resource_group_name": "resourceGroupName",
        "timeouts": "timeouts",
    },
)
class DataAzurermSharedImageConfig(cdktf.TerraformMetaArguments):
    def __init__(
        self,
        *,
        count: typing.Optional[jsii.Number] = None,
        depends_on: typing.Optional[typing.List[cdktf.TerraformResource]] = None,
        lifecycle: typing.Optional[cdktf.TerraformResourceLifecycle] = None,
        provider: typing.Optional[cdktf.TerraformProvider] = None,
        gallery_name: builtins.str,
        name: builtins.str,
        resource_group_name: builtins.str,
        timeouts: typing.Optional["DataAzurermSharedImageTimeouts"] = None,
    ) -> None:
        """
        :param count: 
        :param depends_on: 
        :param lifecycle: 
        :param provider: 
        :param gallery_name: 
        :param name: 
        :param resource_group_name: 
        :param timeouts: timeouts block.
        """
        if isinstance(lifecycle, dict):
            lifecycle = cdktf.TerraformResourceLifecycle(**lifecycle)
        if isinstance(timeouts, dict):
            timeouts = DataAzurermSharedImageTimeouts(**timeouts)
        self._values: typing.Dict[str, typing.Any] = {
            "gallery_name": gallery_name,
            "name": name,
            "resource_group_name": resource_group_name,
        }
        if count is not None:
            self._values["count"] = count
        if depends_on is not None:
            self._values["depends_on"] = depends_on
        if lifecycle is not None:
            self._values["lifecycle"] = lifecycle
        if provider is not None:
            self._values["provider"] = provider
        if timeouts is not None:
            self._values["timeouts"] = timeouts

    @builtins.property
    def count(self) -> typing.Optional[jsii.Number]:
        """
        :stability: experimental
        """
        result = self._values.get("count")
        return result

    @builtins.property
    def depends_on(self) -> typing.Optional[typing.List[cdktf.TerraformResource]]:
        """
        :stability: experimental
        """
        result = self._values.get("depends_on")
        return result

    @builtins.property
    def lifecycle(self) -> typing.Optional[cdktf.TerraformResourceLifecycle]:
        """
        :stability: experimental
        """
        result = self._values.get("lifecycle")
        return result

    @builtins.property
    def provider(self) -> typing.Optional[cdktf.TerraformProvider]:
        """
        :stability: experimental
        """
        result = self._values.get("provider")
        return result

    @builtins.property
    def gallery_name(self) -> builtins.str:
        result = self._values.get("gallery_name")
        assert result is not None, "Required property 'gallery_name' is missing"
        return result

    @builtins.property
    def name(self) -> builtins.str:
        result = self._values.get("name")
        assert result is not None, "Required property 'name' is missing"
        return result

    @builtins.property
    def resource_group_name(self) -> builtins.str:
        result = self._values.get("resource_group_name")
        assert result is not None, "Required property 'resource_group_name' is missing"
        return result

    @builtins.property
    def timeouts(self) -> typing.Optional["DataAzurermSharedImageTimeouts"]:
        """timeouts block."""
        result = self._values.get("timeouts")
        return result

    def __eq__(self, rhs: typing.Any) -> builtins.bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs: typing.Any) -> builtins.bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return "DataAzurermSharedImageConfig(%s)" % ", ".join(
            k + "=" + repr(v) for k, v in self._values.items()
        )


class DataAzurermSharedImageGallery(
    cdktf.TerraformDataSource,
    metaclass=jsii.JSIIMeta,
    jsii_type="@cdktf/provider-azurerm.DataAzurermSharedImageGallery",
):
    def __init__(
        self,
        scope: constructs.Construct,
        id: builtins.str,
        *,
        name: builtins.str,
        resource_group_name: builtins.str,
        timeouts: typing.Optional["DataAzurermSharedImageGalleryTimeouts"] = None,
        count: typing.Optional[jsii.Number] = None,
        depends_on: typing.Optional[typing.List[cdktf.TerraformResource]] = None,
        lifecycle: typing.Optional[cdktf.TerraformResourceLifecycle] = None,
        provider: typing.Optional[cdktf.TerraformProvider] = None,
    ) -> None:
        """
        :param scope: -
        :param id: -
        :param name: 
        :param resource_group_name: 
        :param timeouts: timeouts block.
        :param count: 
        :param depends_on: 
        :param lifecycle: 
        :param provider: 
        """
        config = DataAzurermSharedImageGalleryConfig(
            name=name,
            resource_group_name=resource_group_name,
            timeouts=timeouts,
            count=count,
            depends_on=depends_on,
            lifecycle=lifecycle,
            provider=provider,
        )

        jsii.create(DataAzurermSharedImageGallery, self, [scope, id, config])

    @jsii.member(jsii_name="synthesizeAttributes")
    def _synthesize_attributes(self) -> typing.Mapping[builtins.str, typing.Any]:
        return jsii.invoke(self, "synthesizeAttributes", [])

    @jsii.member(jsii_name="tags")
    def tags(self, key: builtins.str) -> builtins.str:
        """
        :param key: -
        """
        return jsii.invoke(self, "tags", [key])

    @builtins.property # type: ignore
    @jsii.member(jsii_name="description")
    def description(self) -> builtins.str:
        return jsii.get(self, "description")

    @builtins.property # type: ignore
    @jsii.member(jsii_name="location")
    def location(self) -> builtins.str:
        return jsii.get(self, "location")

    @builtins.property # type: ignore
    @jsii.member(jsii_name="uniqueName")
    def unique_name(self) -> builtins.str:
        return jsii.get(self, "uniqueName")

    @builtins.property # type: ignore
    @jsii.member(jsii_name="name")
    def name(self) -> builtins.str:
        return jsii.get(self, "name")

    @name.setter # type: ignore
    def name(self, value: builtins.str) -> None:
        jsii.set(self, "name", value)

    @builtins.property # type: ignore
    @jsii.member(jsii_name="resourceGroupName")
    def resource_group_name(self) -> builtins.str:
        return jsii.get(self, "resourceGroupName")

    @resource_group_name.setter # type: ignore
    def resource_group_name(self, value: builtins.str) -> None:
        jsii.set(self, "resourceGroupName", value)

    @builtins.property # type: ignore
    @jsii.member(jsii_name="id")
    def id(self) -> typing.Optional[builtins.str]:
        return jsii.get(self, "id")

    @id.setter # type: ignore
    def id(self, value: typing.Optional[builtins.str]) -> None:
        jsii.set(self, "id", value)

    @builtins.property # type: ignore
    @jsii.member(jsii_name="timeouts")
    def timeouts(self) -> typing.Optional["DataAzurermSharedImageGalleryTimeouts"]:
        return jsii.get(self, "timeouts")

    @timeouts.setter # type: ignore
    def timeouts(
        self,
        value: typing.Optional["DataAzurermSharedImageGalleryTimeouts"],
    ) -> None:
        jsii.set(self, "timeouts", value)


@jsii.data_type(
    jsii_type="@cdktf/provider-azurerm.DataAzurermSharedImageGalleryConfig",
    jsii_struct_bases=[cdktf.TerraformMetaArguments],
    name_mapping={
        "count": "count",
        "depends_on": "dependsOn",
        "lifecycle": "lifecycle",
        "provider": "provider",
        "name": "name",
        "resource_group_name": "resourceGroupName",
        "timeouts": "timeouts",
    },
)
class DataAzurermSharedImageGalleryConfig(cdktf.TerraformMetaArguments):
    def __init__(
        self,
        *,
        count: typing.Optional[jsii.Number] = None,
        depends_on: typing.Optional[typing.List[cdktf.TerraformResource]] = None,
        lifecycle: typing.Optional[cdktf.TerraformResourceLifecycle] = None,
        provider: typing.Optional[cdktf.TerraformProvider] = None,
        name: builtins.str,
        resource_group_name: builtins.str,
        timeouts: typing.Optional["DataAzurermSharedImageGalleryTimeouts"] = None,
    ) -> None:
        """
        :param count: 
        :param depends_on: 
        :param lifecycle: 
        :param provider: 
        :param name: 
        :param resource_group_name: 
        :param timeouts: timeouts block.
        """
        if isinstance(lifecycle, dict):
            lifecycle = cdktf.TerraformResourceLifecycle(**lifecycle)
        if isinstance(timeouts, dict):
            timeouts = DataAzurermSharedImageGalleryTimeouts(**timeouts)
        self._values: typing.Dict[str, typing.Any] = {
            "name": name,
            "resource_group_name": resource_group_name,
        }
        if count is not None:
            self._values["count"] = count
        if depends_on is not None:
            self._values["depends_on"] = depends_on
        if lifecycle is not None:
            self._values["lifecycle"] = lifecycle
        if provider is not None:
            self._values["provider"] = provider
        if timeouts is not None:
            self._values["timeouts"] = timeouts

    @builtins.property
    def count(self) -> typing.Optional[jsii.Number]:
        """
        :stability: experimental
        """
        result = self._values.get("count")
        return result

    @builtins.property
    def depends_on(self) -> typing.Optional[typing.List[cdktf.TerraformResource]]:
        """
        :stability: experimental
        """
        result = self._values.get("depends_on")
        return result

    @builtins.property
    def lifecycle(self) -> typing.Optional[cdktf.TerraformResourceLifecycle]:
        """
        :stability: experimental
        """
        result = self._values.get("lifecycle")
        return result

    @builtins.property
    def provider(self) -> typing.Optional[cdktf.TerraformProvider]:
        """
        :stability: experimental
        """
        result = self._values.get("provider")
        return result

    @builtins.property
    def name(self) -> builtins.str:
        result = self._values.get("name")
        assert result is not None, "Required property 'name' is missing"
        return result

    @builtins.property
    def resource_group_name(self) -> builtins.str:
        result = self._values.get("resource_group_name")
        assert result is not None, "Required property 'resource_group_name' is missing"
        return result

    @builtins.property
    def timeouts(self) -> typing.Optional["DataAzurermSharedImageGalleryTimeouts"]:
        """timeouts block."""
        result = self._values.get("timeouts")
        return result

    def __eq__(self, rhs: typing.Any) -> builtins.bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs: typing.Any) -> builtins.bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return "DataAzurermSharedImageGalleryConfig(%s)" % ", ".join(
            k + "=" + repr(v) for k, v in self._values.items()
        )


@jsii.data_type(
    jsii_type="@cdktf/provider-azurerm.DataAzurermSharedImageGalleryTimeouts",
    jsii_struct_bases=[],
    name_mapping={"read": "read"},
)
class DataAzurermSharedImageGalleryTimeouts:
    def __init__(self, *, read: typing.Optional[builtins.str] = None) -> None:
        """
        :param read: 
        """
        self._values: typing.Dict[str, typing.Any] = {}
        if read is not None:
            self._values["read"] = read

    @builtins.property
    def read(self) -> typing.Optional[builtins.str]:
        result = self._values.get("read")
        return result

    def __eq__(self, rhs: typing.Any) -> builtins.bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs: typing.Any) -> builtins.bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return "DataAzurermSharedImageGalleryTimeouts(%s)" % ", ".join(
            k + "=" + repr(v) for k, v in self._values.items()
        )


class DataAzurermSharedImageIdentifier(
    cdktf.ComplexComputedList,
    metaclass=jsii.JSIIMeta,
    jsii_type="@cdktf/provider-azurerm.DataAzurermSharedImageIdentifier",
):
    def __init__(
        self,
        terraform_resource: cdktf.ITerraformResource,
        terraform_attribute: builtins.str,
        index: builtins.str,
    ) -> None:
        """
        :param terraform_resource: -
        :param terraform_attribute: -
        :param index: -

        :stability: experimental
        """
        jsii.create(DataAzurermSharedImageIdentifier, self, [terraform_resource, terraform_attribute, index])

    @builtins.property # type: ignore
    @jsii.member(jsii_name="offer")
    def offer(self) -> builtins.str:
        return jsii.get(self, "offer")

    @builtins.property # type: ignore
    @jsii.member(jsii_name="publisher")
    def publisher(self) -> builtins.str:
        return jsii.get(self, "publisher")

    @builtins.property # type: ignore
    @jsii.member(jsii_name="sku")
    def sku(self) -> builtins.str:
        return jsii.get(self, "sku")


@jsii.data_type(
    jsii_type="@cdktf/provider-azurerm.DataAzurermSharedImageTimeouts",
    jsii_struct_bases=[],
    name_mapping={"read": "read"},
)
class DataAzurermSharedImageTimeouts:
    def __init__(self, *, read: typing.Optional[builtins.str] = None) -> None:
        """
        :param read: 
        """
        self._values: typing.Dict[str, typing.Any] = {}
        if read is not None:
            self._values["read"] = read

    @builtins.property
    def read(self) -> typing.Optional[builtins.str]:
        result = self._values.get("read")
        return result

    def __eq__(self, rhs: typing.Any) -> builtins.bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs: typing.Any) -> builtins.bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return "DataAzurermSharedImageTimeouts(%s)" % ", ".join(
            k + "=" + repr(v) for k, v in self._values.items()
        )


class DataAzurermSharedImageVersion(
    cdktf.TerraformDataSource,
    metaclass=jsii.JSIIMeta,
    jsii_type="@cdktf/provider-azurerm.DataAzurermSharedImageVersion",
):
    def __init__(
        self,
        scope: constructs.Construct,
        id: builtins.str,
        *,
        gallery_name: builtins.str,
        image_name: builtins.str,
        name: builtins.str,
        resource_group_name: builtins.str,
        timeouts: typing.Optional["DataAzurermSharedImageVersionTimeouts"] = None,
        count: typing.Optional[jsii.Number] = None,
        depends_on: typing.Optional[typing.List[cdktf.TerraformResource]] = None,
        lifecycle: typing.Optional[cdktf.TerraformResourceLifecycle] = None,
        provider: typing.Optional[cdktf.TerraformProvider] = None,
    ) -> None:
        """
        :param scope: -
        :param id: -
        :param gallery_name: 
        :param image_name: 
        :param name: 
        :param resource_group_name: 
        :param timeouts: timeouts block.
        :param count: 
        :param depends_on: 
        :param lifecycle: 
        :param provider: 
        """
        config = DataAzurermSharedImageVersionConfig(
            gallery_name=gallery_name,
            image_name=image_name,
            name=name,
            resource_group_name=resource_group_name,
            timeouts=timeouts,
            count=count,
            depends_on=depends_on,
            lifecycle=lifecycle,
            provider=provider,
        )

        jsii.create(DataAzurermSharedImageVersion, self, [scope, id, config])

    @jsii.member(jsii_name="synthesizeAttributes")
    def _synthesize_attributes(self) -> typing.Mapping[builtins.str, typing.Any]:
        return jsii.invoke(self, "synthesizeAttributes", [])

    @jsii.member(jsii_name="tags")
    def tags(self, key: builtins.str) -> builtins.str:
        """
        :param key: -
        """
        return jsii.invoke(self, "tags", [key])

    @jsii.member(jsii_name="targetRegion")
    def target_region(
        self,
        index: builtins.str,
    ) -> "DataAzurermSharedImageVersionTargetRegion":
        """
        :param index: -
        """
        return jsii.invoke(self, "targetRegion", [index])

    @builtins.property # type: ignore
    @jsii.member(jsii_name="excludeFromLatest")
    def exclude_from_latest(self) -> builtins.bool:
        return jsii.get(self, "excludeFromLatest")

    @builtins.property # type: ignore
    @jsii.member(jsii_name="location")
    def location(self) -> builtins.str:
        return jsii.get(self, "location")

    @builtins.property # type: ignore
    @jsii.member(jsii_name="managedImageId")
    def managed_image_id(self) -> builtins.str:
        return jsii.get(self, "managedImageId")

    @builtins.property # type: ignore
    @jsii.member(jsii_name="galleryName")
    def gallery_name(self) -> builtins.str:
        return jsii.get(self, "galleryName")

    @gallery_name.setter # type: ignore
    def gallery_name(self, value: builtins.str) -> None:
        jsii.set(self, "galleryName", value)

    @builtins.property # type: ignore
    @jsii.member(jsii_name="imageName")
    def image_name(self) -> builtins.str:
        return jsii.get(self, "imageName")

    @image_name.setter # type: ignore
    def image_name(self, value: builtins.str) -> None:
        jsii.set(self, "imageName", value)

    @builtins.property # type: ignore
    @jsii.member(jsii_name="name")
    def name(self) -> builtins.str:
        return jsii.get(self, "name")

    @name.setter # type: ignore
    def name(self, value: builtins.str) -> None:
        jsii.set(self, "name", value)

    @builtins.property # type: ignore
    @jsii.member(jsii_name="resourceGroupName")
    def resource_group_name(self) -> builtins.str:
        return jsii.get(self, "resourceGroupName")

    @resource_group_name.setter # type: ignore
    def resource_group_name(self, value: builtins.str) -> None:
        jsii.set(self, "resourceGroupName", value)

    @builtins.property # type: ignore
    @jsii.member(jsii_name="id")
    def id(self) -> typing.Optional[builtins.str]:
        return jsii.get(self, "id")

    @id.setter # type: ignore
    def id(self, value: typing.Optional[builtins.str]) -> None:
        jsii.set(self, "id", value)

    @builtins.property # type: ignore
    @jsii.member(jsii_name="timeouts")
    def timeouts(self) -> typing.Optional["DataAzurermSharedImageVersionTimeouts"]:
        return jsii.get(self, "timeouts")

    @timeouts.setter # type: ignore
    def timeouts(
        self,
        value: typing.Optional["DataAzurermSharedImageVersionTimeouts"],
    ) -> None:
        jsii.set(self, "timeouts", value)


@jsii.data_type(
    jsii_type="@cdktf/provider-azurerm.DataAzurermSharedImageVersionConfig",
    jsii_struct_bases=[cdktf.TerraformMetaArguments],
    name_mapping={
        "count": "count",
        "depends_on": "dependsOn",
        "lifecycle": "lifecycle",
        "provider": "provider",
        "gallery_name": "galleryName",
        "image_name": "imageName",
        "name": "name",
        "resource_group_name": "resourceGroupName",
        "timeouts": "timeouts",
    },
)
class DataAzurermSharedImageVersionConfig(cdktf.TerraformMetaArguments):
    def __init__(
        self,
        *,
        count: typing.Optional[jsii.Number] = None,
        depends_on: typing.Optional[typing.List[cdktf.TerraformResource]] = None,
        lifecycle: typing.Optional[cdktf.TerraformResourceLifecycle] = None,
        provider: typing.Optional[cdktf.TerraformProvider] = None,
        gallery_name: builtins.str,
        image_name: builtins.str,
        name: builtins.str,
        resource_group_name: builtins.str,
        timeouts: typing.Optional["DataAzurermSharedImageVersionTimeouts"] = None,
    ) -> None:
        """
        :param count: 
        :param depends_on: 
        :param lifecycle: 
        :param provider: 
        :param gallery_name: 
        :param image_name: 
        :param name: 
        :param resource_group_name: 
        :param timeouts: timeouts block.
        """
        if isinstance(lifecycle, dict):
            lifecycle = cdktf.TerraformResourceLifecycle(**lifecycle)
        if isinstance(timeouts, dict):
            timeouts = DataAzurermSharedImageVersionTimeouts(**timeouts)
        self._values: typing.Dict[str, typing.Any] = {
            "gallery_name": gallery_name,
            "image_name": image_name,
            "name": name,
            "resource_group_name": resource_group_name,
        }
        if count is not None:
            self._values["count"] = count
        if depends_on is not None:
            self._values["depends_on"] = depends_on
        if lifecycle is not None:
            self._values["lifecycle"] = lifecycle
        if provider is not None:
            self._values["provider"] = provider
        if timeouts is not None:
            self._values["timeouts"] = timeouts

    @builtins.property
    def count(self) -> typing.Optional[jsii.Number]:
        """
        :stability: experimental
        """
        result = self._values.get("count")
        return result

    @builtins.property
    def depends_on(self) -> typing.Optional[typing.List[cdktf.TerraformResource]]:
        """
        :stability: experimental
        """
        result = self._values.get("depends_on")
        return result

    @builtins.property
    def lifecycle(self) -> typing.Optional[cdktf.TerraformResourceLifecycle]:
        """
        :stability: experimental
        """
        result = self._values.get("lifecycle")
        return result

    @builtins.property
    def provider(self) -> typing.Optional[cdktf.TerraformProvider]:
        """
        :stability: experimental
        """
        result = self._values.get("provider")
        return result

    @builtins.property
    def gallery_name(self) -> builtins.str:
        result = self._values.get("gallery_name")
        assert result is not None, "Required property 'gallery_name' is missing"
        return result

    @builtins.property
    def image_name(self) -> builtins.str:
        result = self._values.get("image_name")
        assert result is not None, "Required property 'image_name' is missing"
        return result

    @builtins.property
    def name(self) -> builtins.str:
        result = self._values.get("name")
        assert result is not None, "Required property 'name' is missing"
        return result

    @builtins.property
    def resource_group_name(self) -> builtins.str:
        result = self._values.get("resource_group_name")
        assert result is not None, "Required property 'resource_group_name' is missing"
        return result

    @builtins.property
    def timeouts(self) -> typing.Optional["DataAzurermSharedImageVersionTimeouts"]:
        """timeouts block."""
        result = self._values.get("timeouts")
        return result

    def __eq__(self, rhs: typing.Any) -> builtins.bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs: typing.Any) -> builtins.bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return "DataAzurermSharedImageVersionConfig(%s)" % ", ".join(
            k + "=" + repr(v) for k, v in self._values.items()
        )


class DataAzurermSharedImageVersionTargetRegion(
    cdktf.ComplexComputedList,
    metaclass=jsii.JSIIMeta,
    jsii_type="@cdktf/provider-azurerm.DataAzurermSharedImageVersionTargetRegion",
):
    def __init__(
        self,
        terraform_resource: cdktf.ITerraformResource,
        terraform_attribute: builtins.str,
        index: builtins.str,
    ) -> None:
        """
        :param terraform_resource: -
        :param terraform_attribute: -
        :param index: -

        :stability: experimental
        """
        jsii.create(DataAzurermSharedImageVersionTargetRegion, self, [terraform_resource, terraform_attribute, index])

    @builtins.property # type: ignore
    @jsii.member(jsii_name="name")
    def name(self) -> builtins.str:
        return jsii.get(self, "name")

    @builtins.property # type: ignore
    @jsii.member(jsii_name="regionalReplicaCount")
    def regional_replica_count(self) -> jsii.Number:
        return jsii.get(self, "regionalReplicaCount")

    @builtins.property # type: ignore
    @jsii.member(jsii_name="storageAccountType")
    def storage_account_type(self) -> builtins.str:
        return jsii.get(self, "storageAccountType")


@jsii.data_type(
    jsii_type="@cdktf/provider-azurerm.DataAzurermSharedImageVersionTimeouts",
    jsii_struct_bases=[],
    name_mapping={"read": "read"},
)
class DataAzurermSharedImageVersionTimeouts:
    def __init__(self, *, read: typing.Optional[builtins.str] = None) -> None:
        """
        :param read: 
        """
        self._values: typing.Dict[str, typing.Any] = {}
        if read is not None:
            self._values["read"] = read

    @builtins.property
    def read(self) -> typing.Optional[builtins.str]:
        result = self._values.get("read")
        return result

    def __eq__(self, rhs: typing.Any) -> builtins.bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs: typing.Any) -> builtins.bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return "DataAzurermSharedImageVersionTimeouts(%s)" % ", ".join(
            k + "=" + repr(v) for k, v in self._values.items()
        )


class DataAzurermSignalrService(
    cdktf.TerraformDataSource,
    metaclass=jsii.JSIIMeta,
    jsii_type="@cdktf/provider-azurerm.DataAzurermSignalrService",
):
    def __init__(
        self,
        scope: constructs.Construct,
        id: builtins.str,
        *,
        name: builtins.str,
        resource_group_name: builtins.str,
        timeouts: typing.Optional["DataAzurermSignalrServiceTimeouts"] = None,
        count: typing.Optional[jsii.Number] = None,
        depends_on: typing.Optional[typing.List[cdktf.TerraformResource]] = None,
        lifecycle: typing.Optional[cdktf.TerraformResourceLifecycle] = None,
        provider: typing.Optional[cdktf.TerraformProvider] = None,
    ) -> None:
        """
        :param scope: -
        :param id: -
        :param name: 
        :param resource_group_name: 
        :param timeouts: timeouts block.
        :param count: 
        :param depends_on: 
        :param lifecycle: 
        :param provider: 
        """
        config = DataAzurermSignalrServiceConfig(
            name=name,
            resource_group_name=resource_group_name,
            timeouts=timeouts,
            count=count,
            depends_on=depends_on,
            lifecycle=lifecycle,
            provider=provider,
        )

        jsii.create(DataAzurermSignalrService, self, [scope, id, config])

    @jsii.member(jsii_name="synthesizeAttributes")
    def _synthesize_attributes(self) -> typing.Mapping[builtins.str, typing.Any]:
        return jsii.invoke(self, "synthesizeAttributes", [])

    @jsii.member(jsii_name="tags")
    def tags(self, key: builtins.str) -> builtins.str:
        """
        :param key: -
        """
        return jsii.invoke(self, "tags", [key])

    @builtins.property # type: ignore
    @jsii.member(jsii_name="hostname")
    def hostname(self) -> builtins.str:
        return jsii.get(self, "hostname")

    @builtins.property # type: ignore
    @jsii.member(jsii_name="ipAddress")
    def ip_address(self) -> builtins.str:
        return jsii.get(self, "ipAddress")

    @builtins.property # type: ignore
    @jsii.member(jsii_name="location")
    def location(self) -> builtins.str:
        return jsii.get(self, "location")

    @builtins.property # type: ignore
    @jsii.member(jsii_name="primaryAccessKey")
    def primary_access_key(self) -> builtins.str:
        return jsii.get(self, "primaryAccessKey")

    @builtins.property # type: ignore
    @jsii.member(jsii_name="primaryConnectionString")
    def primary_connection_string(self) -> builtins.str:
        return jsii.get(self, "primaryConnectionString")

    @builtins.property # type: ignore
    @jsii.member(jsii_name="publicPort")
    def public_port(self) -> jsii.Number:
        return jsii.get(self, "publicPort")

    @builtins.property # type: ignore
    @jsii.member(jsii_name="secondaryAccessKey")
    def secondary_access_key(self) -> builtins.str:
        return jsii.get(self, "secondaryAccessKey")

    @builtins.property # type: ignore
    @jsii.member(jsii_name="secondaryConnectionString")
    def secondary_connection_string(self) -> builtins.str:
        return jsii.get(self, "secondaryConnectionString")

    @builtins.property # type: ignore
    @jsii.member(jsii_name="serverPort")
    def server_port(self) -> jsii.Number:
        return jsii.get(self, "serverPort")

    @builtins.property # type: ignore
    @jsii.member(jsii_name="name")
    def name(self) -> builtins.str:
        return jsii.get(self, "name")

    @name.setter # type: ignore
    def name(self, value: builtins.str) -> None:
        jsii.set(self, "name", value)

    @builtins.property # type: ignore
    @jsii.member(jsii_name="resourceGroupName")
    def resource_group_name(self) -> builtins.str:
        return jsii.get(self, "resourceGroupName")

    @resource_group_name.setter # type: ignore
    def resource_group_name(self, value: builtins.str) -> None:
        jsii.set(self, "resourceGroupName", value)

    @builtins.property # type: ignore
    @jsii.member(jsii_name="id")
    def id(self) -> typing.Optional[builtins.str]:
        return jsii.get(self, "id")

    @id.setter # type: ignore
    def id(self, value: typing.Optional[builtins.str]) -> None:
        jsii.set(self, "id", value)

    @builtins.property # type: ignore
    @jsii.member(jsii_name="timeouts")
    def timeouts(self) -> typing.Optional["DataAzurermSignalrServiceTimeouts"]:
        return jsii.get(self, "timeouts")

    @timeouts.setter # type: ignore
    def timeouts(
        self,
        value: typing.Optional["DataAzurermSignalrServiceTimeouts"],
    ) -> None:
        jsii.set(self, "timeouts", value)


@jsii.data_type(
    jsii_type="@cdktf/provider-azurerm.DataAzurermSignalrServiceConfig",
    jsii_struct_bases=[cdktf.TerraformMetaArguments],
    name_mapping={
        "count": "count",
        "depends_on": "dependsOn",
        "lifecycle": "lifecycle",
        "provider": "provider",
        "name": "name",
        "resource_group_name": "resourceGroupName",
        "timeouts": "timeouts",
    },
)
class DataAzurermSignalrServiceConfig(cdktf.TerraformMetaArguments):
    def __init__(
        self,
        *,
        count: typing.Optional[jsii.Number] = None,
        depends_on: typing.Optional[typing.List[cdktf.TerraformResource]] = None,
        lifecycle: typing.Optional[cdktf.TerraformResourceLifecycle] = None,
        provider: typing.Optional[cdktf.TerraformProvider] = None,
        name: builtins.str,
        resource_group_name: builtins.str,
        timeouts: typing.Optional["DataAzurermSignalrServiceTimeouts"] = None,
    ) -> None:
        """
        :param count: 
        :param depends_on: 
        :param lifecycle: 
        :param provider: 
        :param name: 
        :param resource_group_name: 
        :param timeouts: timeouts block.
        """
        if isinstance(lifecycle, dict):
            lifecycle = cdktf.TerraformResourceLifecycle(**lifecycle)
        if isinstance(timeouts, dict):
            timeouts = DataAzurermSignalrServiceTimeouts(**timeouts)
        self._values: typing.Dict[str, typing.Any] = {
            "name": name,
            "resource_group_name": resource_group_name,
        }
        if count is not None:
            self._values["count"] = count
        if depends_on is not None:
            self._values["depends_on"] = depends_on
        if lifecycle is not None:
            self._values["lifecycle"] = lifecycle
        if provider is not None:
            self._values["provider"] = provider
        if timeouts is not None:
            self._values["timeouts"] = timeouts

    @builtins.property
    def count(self) -> typing.Optional[jsii.Number]:
        """
        :stability: experimental
        """
        result = self._values.get("count")
        return result

    @builtins.property
    def depends_on(self) -> typing.Optional[typing.List[cdktf.TerraformResource]]:
        """
        :stability: experimental
        """
        result = self._values.get("depends_on")
        return result

    @builtins.property
    def lifecycle(self) -> typing.Optional[cdktf.TerraformResourceLifecycle]:
        """
        :stability: experimental
        """
        result = self._values.get("lifecycle")
        return result

    @builtins.property
    def provider(self) -> typing.Optional[cdktf.TerraformProvider]:
        """
        :stability: experimental
        """
        result = self._values.get("provider")
        return result

    @builtins.property
    def name(self) -> builtins.str:
        result = self._values.get("name")
        assert result is not None, "Required property 'name' is missing"
        return result

    @builtins.property
    def resource_group_name(self) -> builtins.str:
        result = self._values.get("resource_group_name")
        assert result is not None, "Required property 'resource_group_name' is missing"
        return result

    @builtins.property
    def timeouts(self) -> typing.Optional["DataAzurermSignalrServiceTimeouts"]:
        """timeouts block."""
        result = self._values.get("timeouts")
        return result

    def __eq__(self, rhs: typing.Any) -> builtins.bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs: typing.Any) -> builtins.bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return "DataAzurermSignalrServiceConfig(%s)" % ", ".join(
            k + "=" + repr(v) for k, v in self._values.items()
        )


@jsii.data_type(
    jsii_type="@cdktf/provider-azurerm.DataAzurermSignalrServiceTimeouts",
    jsii_struct_bases=[],
    name_mapping={"read": "read"},
)
class DataAzurermSignalrServiceTimeouts:
    def __init__(self, *, read: typing.Optional[builtins.str] = None) -> None:
        """
        :param read: 
        """
        self._values: typing.Dict[str, typing.Any] = {}
        if read is not None:
            self._values["read"] = read

    @builtins.property
    def read(self) -> typing.Optional[builtins.str]:
        result = self._values.get("read")
        return result

    def __eq__(self, rhs: typing.Any) -> builtins.bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs: typing.Any) -> builtins.bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return "DataAzurermSignalrServiceTimeouts(%s)" % ", ".join(
            k + "=" + repr(v) for k, v in self._values.items()
        )


class DataAzurermSnapshot(
    cdktf.TerraformDataSource,
    metaclass=jsii.JSIIMeta,
    jsii_type="@cdktf/provider-azurerm.DataAzurermSnapshot",
):
    def __init__(
        self,
        scope: constructs.Construct,
        id: builtins.str,
        *,
        name: builtins.str,
        resource_group_name: builtins.str,
        timeouts: typing.Optional["DataAzurermSnapshotTimeouts"] = None,
        count: typing.Optional[jsii.Number] = None,
        depends_on: typing.Optional[typing.List[cdktf.TerraformResource]] = None,
        lifecycle: typing.Optional[cdktf.TerraformResourceLifecycle] = None,
        provider: typing.Optional[cdktf.TerraformProvider] = None,
    ) -> None:
        """
        :param scope: -
        :param id: -
        :param name: 
        :param resource_group_name: 
        :param timeouts: timeouts block.
        :param count: 
        :param depends_on: 
        :param lifecycle: 
        :param provider: 
        """
        config = DataAzurermSnapshotConfig(
            name=name,
            resource_group_name=resource_group_name,
            timeouts=timeouts,
            count=count,
            depends_on=depends_on,
            lifecycle=lifecycle,
            provider=provider,
        )

        jsii.create(DataAzurermSnapshot, self, [scope, id, config])

    @jsii.member(jsii_name="encryptionSettings")
    def encryption_settings(
        self,
        index: builtins.str,
    ) -> "DataAzurermSnapshotEncryptionSettings":
        """
        :param index: -
        """
        return jsii.invoke(self, "encryptionSettings", [index])

    @jsii.member(jsii_name="synthesizeAttributes")
    def _synthesize_attributes(self) -> typing.Mapping[builtins.str, typing.Any]:
        return jsii.invoke(self, "synthesizeAttributes", [])

    @builtins.property # type: ignore
    @jsii.member(jsii_name="creationOption")
    def creation_option(self) -> builtins.str:
        return jsii.get(self, "creationOption")

    @builtins.property # type: ignore
    @jsii.member(jsii_name="diskSizeGb")
    def disk_size_gb(self) -> jsii.Number:
        return jsii.get(self, "diskSizeGb")

    @builtins.property # type: ignore
    @jsii.member(jsii_name="osType")
    def os_type(self) -> builtins.str:
        return jsii.get(self, "osType")

    @builtins.property # type: ignore
    @jsii.member(jsii_name="sourceResourceId")
    def source_resource_id(self) -> builtins.str:
        return jsii.get(self, "sourceResourceId")

    @builtins.property # type: ignore
    @jsii.member(jsii_name="sourceUri")
    def source_uri(self) -> builtins.str:
        return jsii.get(self, "sourceUri")

    @builtins.property # type: ignore
    @jsii.member(jsii_name="storageAccountId")
    def storage_account_id(self) -> builtins.str:
        return jsii.get(self, "storageAccountId")

    @builtins.property # type: ignore
    @jsii.member(jsii_name="timeCreated")
    def time_created(self) -> builtins.str:
        return jsii.get(self, "timeCreated")

    @builtins.property # type: ignore
    @jsii.member(jsii_name="name")
    def name(self) -> builtins.str:
        return jsii.get(self, "name")

    @name.setter # type: ignore
    def name(self, value: builtins.str) -> None:
        jsii.set(self, "name", value)

    @builtins.property # type: ignore
    @jsii.member(jsii_name="resourceGroupName")
    def resource_group_name(self) -> builtins.str:
        return jsii.get(self, "resourceGroupName")

    @resource_group_name.setter # type: ignore
    def resource_group_name(self, value: builtins.str) -> None:
        jsii.set(self, "resourceGroupName", value)

    @builtins.property # type: ignore
    @jsii.member(jsii_name="id")
    def id(self) -> typing.Optional[builtins.str]:
        return jsii.get(self, "id")

    @id.setter # type: ignore
    def id(self, value: typing.Optional[builtins.str]) -> None:
        jsii.set(self, "id", value)

    @builtins.property # type: ignore
    @jsii.member(jsii_name="timeouts")
    def timeouts(self) -> typing.Optional["DataAzurermSnapshotTimeouts"]:
        return jsii.get(self, "timeouts")

    @timeouts.setter # type: ignore
    def timeouts(self, value: typing.Optional["DataAzurermSnapshotTimeouts"]) -> None:
        jsii.set(self, "timeouts", value)


@jsii.data_type(
    jsii_type="@cdktf/provider-azurerm.DataAzurermSnapshotConfig",
    jsii_struct_bases=[cdktf.TerraformMetaArguments],
    name_mapping={
        "count": "count",
        "depends_on": "dependsOn",
        "lifecycle": "lifecycle",
        "provider": "provider",
        "name": "name",
        "resource_group_name": "resourceGroupName",
        "timeouts": "timeouts",
    },
)
class DataAzurermSnapshotConfig(cdktf.TerraformMetaArguments):
    def __init__(
        self,
        *,
        count: typing.Optional[jsii.Number] = None,
        depends_on: typing.Optional[typing.List[cdktf.TerraformResource]] = None,
        lifecycle: typing.Optional[cdktf.TerraformResourceLifecycle] = None,
        provider: typing.Optional[cdktf.TerraformProvider] = None,
        name: builtins.str,
        resource_group_name: builtins.str,
        timeouts: typing.Optional["DataAzurermSnapshotTimeouts"] = None,
    ) -> None:
        """
        :param count: 
        :param depends_on: 
        :param lifecycle: 
        :param provider: 
        :param name: 
        :param resource_group_name: 
        :param timeouts: timeouts block.
        """
        if isinstance(lifecycle, dict):
            lifecycle = cdktf.TerraformResourceLifecycle(**lifecycle)
        if isinstance(timeouts, dict):
            timeouts = DataAzurermSnapshotTimeouts(**timeouts)
        self._values: typing.Dict[str, typing.Any] = {
            "name": name,
            "resource_group_name": resource_group_name,
        }
        if count is not None:
            self._values["count"] = count
        if depends_on is not None:
            self._values["depends_on"] = depends_on
        if lifecycle is not None:
            self._values["lifecycle"] = lifecycle
        if provider is not None:
            self._values["provider"] = provider
        if timeouts is not None:
            self._values["timeouts"] = timeouts

    @builtins.property
    def count(self) -> typing.Optional[jsii.Number]:
        """
        :stability: experimental
        """
        result = self._values.get("count")
        return result

    @builtins.property
    def depends_on(self) -> typing.Optional[typing.List[cdktf.TerraformResource]]:
        """
        :stability: experimental
        """
        result = self._values.get("depends_on")
        return result

    @builtins.property
    def lifecycle(self) -> typing.Optional[cdktf.TerraformResourceLifecycle]:
        """
        :stability: experimental
        """
        result = self._values.get("lifecycle")
        return result

    @builtins.property
    def provider(self) -> typing.Optional[cdktf.TerraformProvider]:
        """
        :stability: experimental
        """
        result = self._values.get("provider")
        return result

    @builtins.property
    def name(self) -> builtins.str:
        result = self._values.get("name")
        assert result is not None, "Required property 'name' is missing"
        return result

    @builtins.property
    def resource_group_name(self) -> builtins.str:
        result = self._values.get("resource_group_name")
        assert result is not None, "Required property 'resource_group_name' is missing"
        return result

    @builtins.property
    def timeouts(self) -> typing.Optional["DataAzurermSnapshotTimeouts"]:
        """timeouts block."""
        result = self._values.get("timeouts")
        return result

    def __eq__(self, rhs: typing.Any) -> builtins.bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs: typing.Any) -> builtins.bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return "DataAzurermSnapshotConfig(%s)" % ", ".join(
            k + "=" + repr(v) for k, v in self._values.items()
        )


class DataAzurermSnapshotEncryptionSettings(
    cdktf.ComplexComputedList,
    metaclass=jsii.JSIIMeta,
    jsii_type="@cdktf/provider-azurerm.DataAzurermSnapshotEncryptionSettings",
):
    def __init__(
        self,
        terraform_resource: cdktf.ITerraformResource,
        terraform_attribute: builtins.str,
        index: builtins.str,
    ) -> None:
        """
        :param terraform_resource: -
        :param terraform_attribute: -
        :param index: -

        :stability: experimental
        """
        jsii.create(DataAzurermSnapshotEncryptionSettings, self, [terraform_resource, terraform_attribute, index])

    @builtins.property # type: ignore
    @jsii.member(jsii_name="diskEncryptionKey")
    def disk_encryption_key(self) -> typing.Any:
        return jsii.get(self, "diskEncryptionKey")

    @builtins.property # type: ignore
    @jsii.member(jsii_name="enabled")
    def enabled(self) -> builtins.bool:
        return jsii.get(self, "enabled")

    @builtins.property # type: ignore
    @jsii.member(jsii_name="keyEncryptionKey")
    def key_encryption_key(self) -> typing.Any:
        return jsii.get(self, "keyEncryptionKey")


class DataAzurermSnapshotEncryptionSettingsDiskEncryptionKey(
    cdktf.ComplexComputedList,
    metaclass=jsii.JSIIMeta,
    jsii_type="@cdktf/provider-azurerm.DataAzurermSnapshotEncryptionSettingsDiskEncryptionKey",
):
    def __init__(
        self,
        terraform_resource: cdktf.ITerraformResource,
        terraform_attribute: builtins.str,
        index: builtins.str,
    ) -> None:
        """
        :param terraform_resource: -
        :param terraform_attribute: -
        :param index: -

        :stability: experimental
        """
        jsii.create(DataAzurermSnapshotEncryptionSettingsDiskEncryptionKey, self, [terraform_resource, terraform_attribute, index])

    @builtins.property # type: ignore
    @jsii.member(jsii_name="secretUrl")
    def secret_url(self) -> builtins.str:
        return jsii.get(self, "secretUrl")

    @builtins.property # type: ignore
    @jsii.member(jsii_name="sourceVaultId")
    def source_vault_id(self) -> builtins.str:
        return jsii.get(self, "sourceVaultId")


class DataAzurermSnapshotEncryptionSettingsKeyEncryptionKey(
    cdktf.ComplexComputedList,
    metaclass=jsii.JSIIMeta,
    jsii_type="@cdktf/provider-azurerm.DataAzurermSnapshotEncryptionSettingsKeyEncryptionKey",
):
    def __init__(
        self,
        terraform_resource: cdktf.ITerraformResource,
        terraform_attribute: builtins.str,
        index: builtins.str,
    ) -> None:
        """
        :param terraform_resource: -
        :param terraform_attribute: -
        :param index: -

        :stability: experimental
        """
        jsii.create(DataAzurermSnapshotEncryptionSettingsKeyEncryptionKey, self, [terraform_resource, terraform_attribute, index])

    @builtins.property # type: ignore
    @jsii.member(jsii_name="keyUrl")
    def key_url(self) -> builtins.str:
        return jsii.get(self, "keyUrl")

    @builtins.property # type: ignore
    @jsii.member(jsii_name="sourceVaultId")
    def source_vault_id(self) -> builtins.str:
        return jsii.get(self, "sourceVaultId")


@jsii.data_type(
    jsii_type="@cdktf/provider-azurerm.DataAzurermSnapshotTimeouts",
    jsii_struct_bases=[],
    name_mapping={"read": "read"},
)
class DataAzurermSnapshotTimeouts:
    def __init__(self, *, read: typing.Optional[builtins.str] = None) -> None:
        """
        :param read: 
        """
        self._values: typing.Dict[str, typing.Any] = {}
        if read is not None:
            self._values["read"] = read

    @builtins.property
    def read(self) -> typing.Optional[builtins.str]:
        result = self._values.get("read")
        return result

    def __eq__(self, rhs: typing.Any) -> builtins.bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs: typing.Any) -> builtins.bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return "DataAzurermSnapshotTimeouts(%s)" % ", ".join(
            k + "=" + repr(v) for k, v in self._values.items()
        )


class DataAzurermSqlDatabase(
    cdktf.TerraformDataSource,
    metaclass=jsii.JSIIMeta,
    jsii_type="@cdktf/provider-azurerm.DataAzurermSqlDatabase",
):
    def __init__(
        self,
        scope: constructs.Construct,
        id: builtins.str,
        *,
        name: builtins.str,
        resource_group_name: builtins.str,
        server_name: builtins.str,
        tags: typing.Optional[typing.Mapping[builtins.str, builtins.str]] = None,
        timeouts: typing.Optional["DataAzurermSqlDatabaseTimeouts"] = None,
        count: typing.Optional[jsii.Number] = None,
        depends_on: typing.Optional[typing.List[cdktf.TerraformResource]] = None,
        lifecycle: typing.Optional[cdktf.TerraformResourceLifecycle] = None,
        provider: typing.Optional[cdktf.TerraformProvider] = None,
    ) -> None:
        """
        :param scope: -
        :param id: -
        :param name: 
        :param resource_group_name: 
        :param server_name: 
        :param tags: 
        :param timeouts: timeouts block.
        :param count: 
        :param depends_on: 
        :param lifecycle: 
        :param provider: 
        """
        config = DataAzurermSqlDatabaseConfig(
            name=name,
            resource_group_name=resource_group_name,
            server_name=server_name,
            tags=tags,
            timeouts=timeouts,
            count=count,
            depends_on=depends_on,
            lifecycle=lifecycle,
            provider=provider,
        )

        jsii.create(DataAzurermSqlDatabase, self, [scope, id, config])

    @jsii.member(jsii_name="synthesizeAttributes")
    def _synthesize_attributes(self) -> typing.Mapping[builtins.str, typing.Any]:
        return jsii.invoke(self, "synthesizeAttributes", [])

    @builtins.property # type: ignore
    @jsii.member(jsii_name="collation")
    def collation(self) -> builtins.str:
        return jsii.get(self, "collation")

    @builtins.property # type: ignore
    @jsii.member(jsii_name="defaultSecondaryLocation")
    def default_secondary_location(self) -> builtins.str:
        return jsii.get(self, "defaultSecondaryLocation")

    @builtins.property # type: ignore
    @jsii.member(jsii_name="edition")
    def edition(self) -> builtins.str:
        return jsii.get(self, "edition")

    @builtins.property # type: ignore
    @jsii.member(jsii_name="elasticPoolName")
    def elastic_pool_name(self) -> builtins.str:
        return jsii.get(self, "elasticPoolName")

    @builtins.property # type: ignore
    @jsii.member(jsii_name="failoverGroupId")
    def failover_group_id(self) -> builtins.str:
        return jsii.get(self, "failoverGroupId")

    @builtins.property # type: ignore
    @jsii.member(jsii_name="location")
    def location(self) -> builtins.str:
        return jsii.get(self, "location")

    @builtins.property # type: ignore
    @jsii.member(jsii_name="readScale")
    def read_scale(self) -> builtins.bool:
        return jsii.get(self, "readScale")

    @builtins.property # type: ignore
    @jsii.member(jsii_name="name")
    def name(self) -> builtins.str:
        return jsii.get(self, "name")

    @name.setter # type: ignore
    def name(self, value: builtins.str) -> None:
        jsii.set(self, "name", value)

    @builtins.property # type: ignore
    @jsii.member(jsii_name="resourceGroupName")
    def resource_group_name(self) -> builtins.str:
        return jsii.get(self, "resourceGroupName")

    @resource_group_name.setter # type: ignore
    def resource_group_name(self, value: builtins.str) -> None:
        jsii.set(self, "resourceGroupName", value)

    @builtins.property # type: ignore
    @jsii.member(jsii_name="serverName")
    def server_name(self) -> builtins.str:
        return jsii.get(self, "serverName")

    @server_name.setter # type: ignore
    def server_name(self, value: builtins.str) -> None:
        jsii.set(self, "serverName", value)

    @builtins.property # type: ignore
    @jsii.member(jsii_name="id")
    def id(self) -> typing.Optional[builtins.str]:
        return jsii.get(self, "id")

    @id.setter # type: ignore
    def id(self, value: typing.Optional[builtins.str]) -> None:
        jsii.set(self, "id", value)

    @builtins.property # type: ignore
    @jsii.member(jsii_name="tags")
    def tags(self) -> typing.Optional[typing.Mapping[builtins.str, builtins.str]]:
        return jsii.get(self, "tags")

    @tags.setter # type: ignore
    def tags(
        self,
        value: typing.Optional[typing.Mapping[builtins.str, builtins.str]],
    ) -> None:
        jsii.set(self, "tags", value)

    @builtins.property # type: ignore
    @jsii.member(jsii_name="timeouts")
    def timeouts(self) -> typing.Optional["DataAzurermSqlDatabaseTimeouts"]:
        return jsii.get(self, "timeouts")

    @timeouts.setter # type: ignore
    def timeouts(
        self,
        value: typing.Optional["DataAzurermSqlDatabaseTimeouts"],
    ) -> None:
        jsii.set(self, "timeouts", value)


@jsii.data_type(
    jsii_type="@cdktf/provider-azurerm.DataAzurermSqlDatabaseConfig",
    jsii_struct_bases=[cdktf.TerraformMetaArguments],
    name_mapping={
        "count": "count",
        "depends_on": "dependsOn",
        "lifecycle": "lifecycle",
        "provider": "provider",
        "name": "name",
        "resource_group_name": "resourceGroupName",
        "server_name": "serverName",
        "tags": "tags",
        "timeouts": "timeouts",
    },
)
class DataAzurermSqlDatabaseConfig(cdktf.TerraformMetaArguments):
    def __init__(
        self,
        *,
        count: typing.Optional[jsii.Number] = None,
        depends_on: typing.Optional[typing.List[cdktf.TerraformResource]] = None,
        lifecycle: typing.Optional[cdktf.TerraformResourceLifecycle] = None,
        provider: typing.Optional[cdktf.TerraformProvider] = None,
        name: builtins.str,
        resource_group_name: builtins.str,
        server_name: builtins.str,
        tags: typing.Optional[typing.Mapping[builtins.str, builtins.str]] = None,
        timeouts: typing.Optional["DataAzurermSqlDatabaseTimeouts"] = None,
    ) -> None:
        """
        :param count: 
        :param depends_on: 
        :param lifecycle: 
        :param provider: 
        :param name: 
        :param resource_group_name: 
        :param server_name: 
        :param tags: 
        :param timeouts: timeouts block.
        """
        if isinstance(lifecycle, dict):
            lifecycle = cdktf.TerraformResourceLifecycle(**lifecycle)
        if isinstance(timeouts, dict):
            timeouts = DataAzurermSqlDatabaseTimeouts(**timeouts)
        self._values: typing.Dict[str, typing.Any] = {
            "name": name,
            "resource_group_name": resource_group_name,
            "server_name": server_name,
        }
        if count is not None:
            self._values["count"] = count
        if depends_on is not None:
            self._values["depends_on"] = depends_on
        if lifecycle is not None:
            self._values["lifecycle"] = lifecycle
        if provider is not None:
            self._values["provider"] = provider
        if tags is not None:
            self._values["tags"] = tags
        if timeouts is not None:
            self._values["timeouts"] = timeouts

    @builtins.property
    def count(self) -> typing.Optional[jsii.Number]:
        """
        :stability: experimental
        """
        result = self._values.get("count")
        return result

    @builtins.property
    def depends_on(self) -> typing.Optional[typing.List[cdktf.TerraformResource]]:
        """
        :stability: experimental
        """
        result = self._values.get("depends_on")
        return result

    @builtins.property
    def lifecycle(self) -> typing.Optional[cdktf.TerraformResourceLifecycle]:
        """
        :stability: experimental
        """
        result = self._values.get("lifecycle")
        return result

    @builtins.property
    def provider(self) -> typing.Optional[cdktf.TerraformProvider]:
        """
        :stability: experimental
        """
        result = self._values.get("provider")
        return result

    @builtins.property
    def name(self) -> builtins.str:
        result = self._values.get("name")
        assert result is not None, "Required property 'name' is missing"
        return result

    @builtins.property
    def resource_group_name(self) -> builtins.str:
        result = self._values.get("resource_group_name")
        assert result is not None, "Required property 'resource_group_name' is missing"
        return result

    @builtins.property
    def server_name(self) -> builtins.str:
        result = self._values.get("server_name")
        assert result is not None, "Required property 'server_name' is missing"
        return result

    @builtins.property
    def tags(self) -> typing.Optional[typing.Mapping[builtins.str, builtins.str]]:
        result = self._values.get("tags")
        return result

    @builtins.property
    def timeouts(self) -> typing.Optional["DataAzurermSqlDatabaseTimeouts"]:
        """timeouts block."""
        result = self._values.get("timeouts")
        return result

    def __eq__(self, rhs: typing.Any) -> builtins.bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs: typing.Any) -> builtins.bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return "DataAzurermSqlDatabaseConfig(%s)" % ", ".join(
            k + "=" + repr(v) for k, v in self._values.items()
        )


@jsii.data_type(
    jsii_type="@cdktf/provider-azurerm.DataAzurermSqlDatabaseTimeouts",
    jsii_struct_bases=[],
    name_mapping={"read": "read"},
)
class DataAzurermSqlDatabaseTimeouts:
    def __init__(self, *, read: typing.Optional[builtins.str] = None) -> None:
        """
        :param read: 
        """
        self._values: typing.Dict[str, typing.Any] = {}
        if read is not None:
            self._values["read"] = read

    @builtins.property
    def read(self) -> typing.Optional[builtins.str]:
        result = self._values.get("read")
        return result

    def __eq__(self, rhs: typing.Any) -> builtins.bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs: typing.Any) -> builtins.bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return "DataAzurermSqlDatabaseTimeouts(%s)" % ", ".join(
            k + "=" + repr(v) for k, v in self._values.items()
        )


class DataAzurermSqlServer(
    cdktf.TerraformDataSource,
    metaclass=jsii.JSIIMeta,
    jsii_type="@cdktf/provider-azurerm.DataAzurermSqlServer",
):
    def __init__(
        self,
        scope: constructs.Construct,
        id: builtins.str,
        *,
        name: builtins.str,
        resource_group_name: builtins.str,
        timeouts: typing.Optional["DataAzurermSqlServerTimeouts"] = None,
        count: typing.Optional[jsii.Number] = None,
        depends_on: typing.Optional[typing.List[cdktf.TerraformResource]] = None,
        lifecycle: typing.Optional[cdktf.TerraformResourceLifecycle] = None,
        provider: typing.Optional[cdktf.TerraformProvider] = None,
    ) -> None:
        """
        :param scope: -
        :param id: -
        :param name: 
        :param resource_group_name: 
        :param timeouts: timeouts block.
        :param count: 
        :param depends_on: 
        :param lifecycle: 
        :param provider: 
        """
        config = DataAzurermSqlServerConfig(
            name=name,
            resource_group_name=resource_group_name,
            timeouts=timeouts,
            count=count,
            depends_on=depends_on,
            lifecycle=lifecycle,
            provider=provider,
        )

        jsii.create(DataAzurermSqlServer, self, [scope, id, config])

    @jsii.member(jsii_name="identity")
    def identity(self, index: builtins.str) -> "DataAzurermSqlServerIdentity":
        """
        :param index: -
        """
        return jsii.invoke(self, "identity", [index])

    @jsii.member(jsii_name="synthesizeAttributes")
    def _synthesize_attributes(self) -> typing.Mapping[builtins.str, typing.Any]:
        return jsii.invoke(self, "synthesizeAttributes", [])

    @jsii.member(jsii_name="tags")
    def tags(self, key: builtins.str) -> builtins.str:
        """
        :param key: -
        """
        return jsii.invoke(self, "tags", [key])

    @builtins.property # type: ignore
    @jsii.member(jsii_name="administratorLogin")
    def administrator_login(self) -> builtins.str:
        return jsii.get(self, "administratorLogin")

    @builtins.property # type: ignore
    @jsii.member(jsii_name="fqdn")
    def fqdn(self) -> builtins.str:
        return jsii.get(self, "fqdn")

    @builtins.property # type: ignore
    @jsii.member(jsii_name="location")
    def location(self) -> builtins.str:
        return jsii.get(self, "location")

    @builtins.property # type: ignore
    @jsii.member(jsii_name="version")
    def version(self) -> builtins.str:
        return jsii.get(self, "version")

    @builtins.property # type: ignore
    @jsii.member(jsii_name="name")
    def name(self) -> builtins.str:
        return jsii.get(self, "name")

    @name.setter # type: ignore
    def name(self, value: builtins.str) -> None:
        jsii.set(self, "name", value)

    @builtins.property # type: ignore
    @jsii.member(jsii_name="resourceGroupName")
    def resource_group_name(self) -> builtins.str:
        return jsii.get(self, "resourceGroupName")

    @resource_group_name.setter # type: ignore
    def resource_group_name(self, value: builtins.str) -> None:
        jsii.set(self, "resourceGroupName", value)

    @builtins.property # type: ignore
    @jsii.member(jsii_name="id")
    def id(self) -> typing.Optional[builtins.str]:
        return jsii.get(self, "id")

    @id.setter # type: ignore
    def id(self, value: typing.Optional[builtins.str]) -> None:
        jsii.set(self, "id", value)

    @builtins.property # type: ignore
    @jsii.member(jsii_name="timeouts")
    def timeouts(self) -> typing.Optional["DataAzurermSqlServerTimeouts"]:
        return jsii.get(self, "timeouts")

    @timeouts.setter # type: ignore
    def timeouts(self, value: typing.Optional["DataAzurermSqlServerTimeouts"]) -> None:
        jsii.set(self, "timeouts", value)


@jsii.data_type(
    jsii_type="@cdktf/provider-azurerm.DataAzurermSqlServerConfig",
    jsii_struct_bases=[cdktf.TerraformMetaArguments],
    name_mapping={
        "count": "count",
        "depends_on": "dependsOn",
        "lifecycle": "lifecycle",
        "provider": "provider",
        "name": "name",
        "resource_group_name": "resourceGroupName",
        "timeouts": "timeouts",
    },
)
class DataAzurermSqlServerConfig(cdktf.TerraformMetaArguments):
    def __init__(
        self,
        *,
        count: typing.Optional[jsii.Number] = None,
        depends_on: typing.Optional[typing.List[cdktf.TerraformResource]] = None,
        lifecycle: typing.Optional[cdktf.TerraformResourceLifecycle] = None,
        provider: typing.Optional[cdktf.TerraformProvider] = None,
        name: builtins.str,
        resource_group_name: builtins.str,
        timeouts: typing.Optional["DataAzurermSqlServerTimeouts"] = None,
    ) -> None:
        """
        :param count: 
        :param depends_on: 
        :param lifecycle: 
        :param provider: 
        :param name: 
        :param resource_group_name: 
        :param timeouts: timeouts block.
        """
        if isinstance(lifecycle, dict):
            lifecycle = cdktf.TerraformResourceLifecycle(**lifecycle)
        if isinstance(timeouts, dict):
            timeouts = DataAzurermSqlServerTimeouts(**timeouts)
        self._values: typing.Dict[str, typing.Any] = {
            "name": name,
            "resource_group_name": resource_group_name,
        }
        if count is not None:
            self._values["count"] = count
        if depends_on is not None:
            self._values["depends_on"] = depends_on
        if lifecycle is not None:
            self._values["lifecycle"] = lifecycle
        if provider is not None:
            self._values["provider"] = provider
        if timeouts is not None:
            self._values["timeouts"] = timeouts

    @builtins.property
    def count(self) -> typing.Optional[jsii.Number]:
        """
        :stability: experimental
        """
        result = self._values.get("count")
        return result

    @builtins.property
    def depends_on(self) -> typing.Optional[typing.List[cdktf.TerraformResource]]:
        """
        :stability: experimental
        """
        result = self._values.get("depends_on")
        return result

    @builtins.property
    def lifecycle(self) -> typing.Optional[cdktf.TerraformResourceLifecycle]:
        """
        :stability: experimental
        """
        result = self._values.get("lifecycle")
        return result

    @builtins.property
    def provider(self) -> typing.Optional[cdktf.TerraformProvider]:
        """
        :stability: experimental
        """
        result = self._values.get("provider")
        return result

    @builtins.property
    def name(self) -> builtins.str:
        result = self._values.get("name")
        assert result is not None, "Required property 'name' is missing"
        return result

    @builtins.property
    def resource_group_name(self) -> builtins.str:
        result = self._values.get("resource_group_name")
        assert result is not None, "Required property 'resource_group_name' is missing"
        return result

    @builtins.property
    def timeouts(self) -> typing.Optional["DataAzurermSqlServerTimeouts"]:
        """timeouts block."""
        result = self._values.get("timeouts")
        return result

    def __eq__(self, rhs: typing.Any) -> builtins.bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs: typing.Any) -> builtins.bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return "DataAzurermSqlServerConfig(%s)" % ", ".join(
            k + "=" + repr(v) for k, v in self._values.items()
        )


class DataAzurermSqlServerIdentity(
    cdktf.ComplexComputedList,
    metaclass=jsii.JSIIMeta,
    jsii_type="@cdktf/provider-azurerm.DataAzurermSqlServerIdentity",
):
    def __init__(
        self,
        terraform_resource: cdktf.ITerraformResource,
        terraform_attribute: builtins.str,
        index: builtins.str,
    ) -> None:
        """
        :param terraform_resource: -
        :param terraform_attribute: -
        :param index: -

        :stability: experimental
        """
        jsii.create(DataAzurermSqlServerIdentity, self, [terraform_resource, terraform_attribute, index])

    @builtins.property # type: ignore
    @jsii.member(jsii_name="principalId")
    def principal_id(self) -> builtins.str:
        return jsii.get(self, "principalId")

    @builtins.property # type: ignore
    @jsii.member(jsii_name="tenantId")
    def tenant_id(self) -> builtins.str:
        return jsii.get(self, "tenantId")

    @builtins.property # type: ignore
    @jsii.member(jsii_name="type")
    def type(self) -> builtins.str:
        return jsii.get(self, "type")


@jsii.data_type(
    jsii_type="@cdktf/provider-azurerm.DataAzurermSqlServerTimeouts",
    jsii_struct_bases=[],
    name_mapping={"read": "read"},
)
class DataAzurermSqlServerTimeouts:
    def __init__(self, *, read: typing.Optional[builtins.str] = None) -> None:
        """
        :param read: 
        """
        self._values: typing.Dict[str, typing.Any] = {}
        if read is not None:
            self._values["read"] = read

    @builtins.property
    def read(self) -> typing.Optional[builtins.str]:
        result = self._values.get("read")
        return result

    def __eq__(self, rhs: typing.Any) -> builtins.bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs: typing.Any) -> builtins.bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return "DataAzurermSqlServerTimeouts(%s)" % ", ".join(
            k + "=" + repr(v) for k, v in self._values.items()
        )


class DataAzurermStorageAccount(
    cdktf.TerraformDataSource,
    metaclass=jsii.JSIIMeta,
    jsii_type="@cdktf/provider-azurerm.DataAzurermStorageAccount",
):
    def __init__(
        self,
        scope: constructs.Construct,
        id: builtins.str,
        *,
        name: builtins.str,
        resource_group_name: builtins.str,
        timeouts: typing.Optional["DataAzurermStorageAccountTimeouts"] = None,
        count: typing.Optional[jsii.Number] = None,
        depends_on: typing.Optional[typing.List[cdktf.TerraformResource]] = None,
        lifecycle: typing.Optional[cdktf.TerraformResourceLifecycle] = None,
        provider: typing.Optional[cdktf.TerraformProvider] = None,
    ) -> None:
        """
        :param scope: -
        :param id: -
        :param name: 
        :param resource_group_name: 
        :param timeouts: timeouts block.
        :param count: 
        :param depends_on: 
        :param lifecycle: 
        :param provider: 
        """
        config = DataAzurermStorageAccountConfig(
            name=name,
            resource_group_name=resource_group_name,
            timeouts=timeouts,
            count=count,
            depends_on=depends_on,
            lifecycle=lifecycle,
            provider=provider,
        )

        jsii.create(DataAzurermStorageAccount, self, [scope, id, config])

    @jsii.member(jsii_name="customDomain")
    def custom_domain(
        self,
        index: builtins.str,
    ) -> "DataAzurermStorageAccountCustomDomain":
        """
        :param index: -
        """
        return jsii.invoke(self, "customDomain", [index])

    @jsii.member(jsii_name="synthesizeAttributes")
    def _synthesize_attributes(self) -> typing.Mapping[builtins.str, typing.Any]:
        return jsii.invoke(self, "synthesizeAttributes", [])

    @jsii.member(jsii_name="tags")
    def tags(self, key: builtins.str) -> builtins.str:
        """
        :param key: -
        """
        return jsii.invoke(self, "tags", [key])

    @builtins.property # type: ignore
    @jsii.member(jsii_name="accessTier")
    def access_tier(self) -> builtins.str:
        return jsii.get(self, "accessTier")

    @builtins.property # type: ignore
    @jsii.member(jsii_name="accountKind")
    def account_kind(self) -> builtins.str:
        return jsii.get(self, "accountKind")

    @builtins.property # type: ignore
    @jsii.member(jsii_name="accountReplicationType")
    def account_replication_type(self) -> builtins.str:
        return jsii.get(self, "accountReplicationType")

    @builtins.property # type: ignore
    @jsii.member(jsii_name="accountTier")
    def account_tier(self) -> builtins.str:
        return jsii.get(self, "accountTier")

    @builtins.property # type: ignore
    @jsii.member(jsii_name="enableHttpsTrafficOnly")
    def enable_https_traffic_only(self) -> builtins.bool:
        return jsii.get(self, "enableHttpsTrafficOnly")

    @builtins.property # type: ignore
    @jsii.member(jsii_name="isHnsEnabled")
    def is_hns_enabled(self) -> builtins.bool:
        return jsii.get(self, "isHnsEnabled")

    @builtins.property # type: ignore
    @jsii.member(jsii_name="location")
    def location(self) -> builtins.str:
        return jsii.get(self, "location")

    @builtins.property # type: ignore
    @jsii.member(jsii_name="primaryAccessKey")
    def primary_access_key(self) -> builtins.str:
        return jsii.get(self, "primaryAccessKey")

    @builtins.property # type: ignore
    @jsii.member(jsii_name="primaryBlobConnectionString")
    def primary_blob_connection_string(self) -> builtins.str:
        return jsii.get(self, "primaryBlobConnectionString")

    @builtins.property # type: ignore
    @jsii.member(jsii_name="primaryBlobEndpoint")
    def primary_blob_endpoint(self) -> builtins.str:
        return jsii.get(self, "primaryBlobEndpoint")

    @builtins.property # type: ignore
    @jsii.member(jsii_name="primaryBlobHost")
    def primary_blob_host(self) -> builtins.str:
        return jsii.get(self, "primaryBlobHost")

    @builtins.property # type: ignore
    @jsii.member(jsii_name="primaryConnectionString")
    def primary_connection_string(self) -> builtins.str:
        return jsii.get(self, "primaryConnectionString")

    @builtins.property # type: ignore
    @jsii.member(jsii_name="primaryDfsEndpoint")
    def primary_dfs_endpoint(self) -> builtins.str:
        return jsii.get(self, "primaryDfsEndpoint")

    @builtins.property # type: ignore
    @jsii.member(jsii_name="primaryDfsHost")
    def primary_dfs_host(self) -> builtins.str:
        return jsii.get(self, "primaryDfsHost")

    @builtins.property # type: ignore
    @jsii.member(jsii_name="primaryFileEndpoint")
    def primary_file_endpoint(self) -> builtins.str:
        return jsii.get(self, "primaryFileEndpoint")

    @builtins.property # type: ignore
    @jsii.member(jsii_name="primaryFileHost")
    def primary_file_host(self) -> builtins.str:
        return jsii.get(self, "primaryFileHost")

    @builtins.property # type: ignore
    @jsii.member(jsii_name="primaryLocation")
    def primary_location(self) -> builtins.str:
        return jsii.get(self, "primaryLocation")

    @builtins.property # type: ignore
    @jsii.member(jsii_name="primaryQueueEndpoint")
    def primary_queue_endpoint(self) -> builtins.str:
        return jsii.get(self, "primaryQueueEndpoint")

    @builtins.property # type: ignore
    @jsii.member(jsii_name="primaryQueueHost")
    def primary_queue_host(self) -> builtins.str:
        return jsii.get(self, "primaryQueueHost")

    @builtins.property # type: ignore
    @jsii.member(jsii_name="primaryTableEndpoint")
    def primary_table_endpoint(self) -> builtins.str:
        return jsii.get(self, "primaryTableEndpoint")

    @builtins.property # type: ignore
    @jsii.member(jsii_name="primaryTableHost")
    def primary_table_host(self) -> builtins.str:
        return jsii.get(self, "primaryTableHost")

    @builtins.property # type: ignore
    @jsii.member(jsii_name="primaryWebEndpoint")
    def primary_web_endpoint(self) -> builtins.str:
        return jsii.get(self, "primaryWebEndpoint")

    @builtins.property # type: ignore
    @jsii.member(jsii_name="primaryWebHost")
    def primary_web_host(self) -> builtins.str:
        return jsii.get(self, "primaryWebHost")

    @builtins.property # type: ignore
    @jsii.member(jsii_name="secondaryAccessKey")
    def secondary_access_key(self) -> builtins.str:
        return jsii.get(self, "secondaryAccessKey")

    @builtins.property # type: ignore
    @jsii.member(jsii_name="secondaryBlobConnectionString")
    def secondary_blob_connection_string(self) -> builtins.str:
        return jsii.get(self, "secondaryBlobConnectionString")

    @builtins.property # type: ignore
    @jsii.member(jsii_name="secondaryBlobEndpoint")
    def secondary_blob_endpoint(self) -> builtins.str:
        return jsii.get(self, "secondaryBlobEndpoint")

    @builtins.property # type: ignore
    @jsii.member(jsii_name="secondaryBlobHost")
    def secondary_blob_host(self) -> builtins.str:
        return jsii.get(self, "secondaryBlobHost")

    @builtins.property # type: ignore
    @jsii.member(jsii_name="secondaryConnectionString")
    def secondary_connection_string(self) -> builtins.str:
        return jsii.get(self, "secondaryConnectionString")

    @builtins.property # type: ignore
    @jsii.member(jsii_name="secondaryDfsEndpoint")
    def secondary_dfs_endpoint(self) -> builtins.str:
        return jsii.get(self, "secondaryDfsEndpoint")

    @builtins.property # type: ignore
    @jsii.member(jsii_name="secondaryDfsHost")
    def secondary_dfs_host(self) -> builtins.str:
        return jsii.get(self, "secondaryDfsHost")

    @builtins.property # type: ignore
    @jsii.member(jsii_name="secondaryFileEndpoint")
    def secondary_file_endpoint(self) -> builtins.str:
        return jsii.get(self, "secondaryFileEndpoint")

    @builtins.property # type: ignore
    @jsii.member(jsii_name="secondaryFileHost")
    def secondary_file_host(self) -> builtins.str:
        return jsii.get(self, "secondaryFileHost")

    @builtins.property # type: ignore
    @jsii.member(jsii_name="secondaryLocation")
    def secondary_location(self) -> builtins.str:
        return jsii.get(self, "secondaryLocation")

    @builtins.property # type: ignore
    @jsii.member(jsii_name="secondaryQueueEndpoint")
    def secondary_queue_endpoint(self) -> builtins.str:
        return jsii.get(self, "secondaryQueueEndpoint")

    @builtins.property # type: ignore
    @jsii.member(jsii_name="secondaryQueueHost")
    def secondary_queue_host(self) -> builtins.str:
        return jsii.get(self, "secondaryQueueHost")

    @builtins.property # type: ignore
    @jsii.member(jsii_name="secondaryTableEndpoint")
    def secondary_table_endpoint(self) -> builtins.str:
        return jsii.get(self, "secondaryTableEndpoint")

    @builtins.property # type: ignore
    @jsii.member(jsii_name="secondaryTableHost")
    def secondary_table_host(self) -> builtins.str:
        return jsii.get(self, "secondaryTableHost")

    @builtins.property # type: ignore
    @jsii.member(jsii_name="secondaryWebEndpoint")
    def secondary_web_endpoint(self) -> builtins.str:
        return jsii.get(self, "secondaryWebEndpoint")

    @builtins.property # type: ignore
    @jsii.member(jsii_name="secondaryWebHost")
    def secondary_web_host(self) -> builtins.str:
        return jsii.get(self, "secondaryWebHost")

    @builtins.property # type: ignore
    @jsii.member(jsii_name="name")
    def name(self) -> builtins.str:
        return jsii.get(self, "name")

    @name.setter # type: ignore
    def name(self, value: builtins.str) -> None:
        jsii.set(self, "name", value)

    @builtins.property # type: ignore
    @jsii.member(jsii_name="resourceGroupName")
    def resource_group_name(self) -> builtins.str:
        return jsii.get(self, "resourceGroupName")

    @resource_group_name.setter # type: ignore
    def resource_group_name(self, value: builtins.str) -> None:
        jsii.set(self, "resourceGroupName", value)

    @builtins.property # type: ignore
    @jsii.member(jsii_name="id")
    def id(self) -> typing.Optional[builtins.str]:
        return jsii.get(self, "id")

    @id.setter # type: ignore
    def id(self, value: typing.Optional[builtins.str]) -> None:
        jsii.set(self, "id", value)

    @builtins.property # type: ignore
    @jsii.member(jsii_name="timeouts")
    def timeouts(self) -> typing.Optional["DataAzurermStorageAccountTimeouts"]:
        return jsii.get(self, "timeouts")

    @timeouts.setter # type: ignore
    def timeouts(
        self,
        value: typing.Optional["DataAzurermStorageAccountTimeouts"],
    ) -> None:
        jsii.set(self, "timeouts", value)


class DataAzurermStorageAccountBlobContainerSas(
    cdktf.TerraformDataSource,
    metaclass=jsii.JSIIMeta,
    jsii_type="@cdktf/provider-azurerm.DataAzurermStorageAccountBlobContainerSas",
):
    def __init__(
        self,
        scope: constructs.Construct,
        id: builtins.str,
        *,
        connection_string: builtins.str,
        container_name: builtins.str,
        expiry: builtins.str,
        permissions: typing.List["DataAzurermStorageAccountBlobContainerSasPermissions"],
        start: builtins.str,
        cache_control: typing.Optional[builtins.str] = None,
        content_disposition: typing.Optional[builtins.str] = None,
        content_encoding: typing.Optional[builtins.str] = None,
        content_language: typing.Optional[builtins.str] = None,
        content_type: typing.Optional[builtins.str] = None,
        https_only: typing.Optional[builtins.bool] = None,
        ip_address: typing.Optional[builtins.str] = None,
        timeouts: typing.Optional["DataAzurermStorageAccountBlobContainerSasTimeouts"] = None,
        count: typing.Optional[jsii.Number] = None,
        depends_on: typing.Optional[typing.List[cdktf.TerraformResource]] = None,
        lifecycle: typing.Optional[cdktf.TerraformResourceLifecycle] = None,
        provider: typing.Optional[cdktf.TerraformProvider] = None,
    ) -> None:
        """
        :param scope: -
        :param id: -
        :param connection_string: 
        :param container_name: 
        :param expiry: 
        :param permissions: permissions block.
        :param start: 
        :param cache_control: 
        :param content_disposition: 
        :param content_encoding: 
        :param content_language: 
        :param content_type: 
        :param https_only: 
        :param ip_address: 
        :param timeouts: timeouts block.
        :param count: 
        :param depends_on: 
        :param lifecycle: 
        :param provider: 
        """
        config = DataAzurermStorageAccountBlobContainerSasConfig(
            connection_string=connection_string,
            container_name=container_name,
            expiry=expiry,
            permissions=permissions,
            start=start,
            cache_control=cache_control,
            content_disposition=content_disposition,
            content_encoding=content_encoding,
            content_language=content_language,
            content_type=content_type,
            https_only=https_only,
            ip_address=ip_address,
            timeouts=timeouts,
            count=count,
            depends_on=depends_on,
            lifecycle=lifecycle,
            provider=provider,
        )

        jsii.create(DataAzurermStorageAccountBlobContainerSas, self, [scope, id, config])

    @jsii.member(jsii_name="synthesizeAttributes")
    def _synthesize_attributes(self) -> typing.Mapping[builtins.str, typing.Any]:
        return jsii.invoke(self, "synthesizeAttributes", [])

    @builtins.property # type: ignore
    @jsii.member(jsii_name="sas")
    def sas(self) -> builtins.str:
        return jsii.get(self, "sas")

    @builtins.property # type: ignore
    @jsii.member(jsii_name="connectionString")
    def connection_string(self) -> builtins.str:
        return jsii.get(self, "connectionString")

    @connection_string.setter # type: ignore
    def connection_string(self, value: builtins.str) -> None:
        jsii.set(self, "connectionString", value)

    @builtins.property # type: ignore
    @jsii.member(jsii_name="containerName")
    def container_name(self) -> builtins.str:
        return jsii.get(self, "containerName")

    @container_name.setter # type: ignore
    def container_name(self, value: builtins.str) -> None:
        jsii.set(self, "containerName", value)

    @builtins.property # type: ignore
    @jsii.member(jsii_name="expiry")
    def expiry(self) -> builtins.str:
        return jsii.get(self, "expiry")

    @expiry.setter # type: ignore
    def expiry(self, value: builtins.str) -> None:
        jsii.set(self, "expiry", value)

    @builtins.property # type: ignore
    @jsii.member(jsii_name="permissions")
    def permissions(
        self,
    ) -> typing.List["DataAzurermStorageAccountBlobContainerSasPermissions"]:
        return jsii.get(self, "permissions")

    @permissions.setter # type: ignore
    def permissions(
        self,
        value: typing.List["DataAzurermStorageAccountBlobContainerSasPermissions"],
    ) -> None:
        jsii.set(self, "permissions", value)

    @builtins.property # type: ignore
    @jsii.member(jsii_name="start")
    def start(self) -> builtins.str:
        return jsii.get(self, "start")

    @start.setter # type: ignore
    def start(self, value: builtins.str) -> None:
        jsii.set(self, "start", value)

    @builtins.property # type: ignore
    @jsii.member(jsii_name="cacheControl")
    def cache_control(self) -> typing.Optional[builtins.str]:
        return jsii.get(self, "cacheControl")

    @cache_control.setter # type: ignore
    def cache_control(self, value: typing.Optional[builtins.str]) -> None:
        jsii.set(self, "cacheControl", value)

    @builtins.property # type: ignore
    @jsii.member(jsii_name="contentDisposition")
    def content_disposition(self) -> typing.Optional[builtins.str]:
        return jsii.get(self, "contentDisposition")

    @content_disposition.setter # type: ignore
    def content_disposition(self, value: typing.Optional[builtins.str]) -> None:
        jsii.set(self, "contentDisposition", value)

    @builtins.property # type: ignore
    @jsii.member(jsii_name="contentEncoding")
    def content_encoding(self) -> typing.Optional[builtins.str]:
        return jsii.get(self, "contentEncoding")

    @content_encoding.setter # type: ignore
    def content_encoding(self, value: typing.Optional[builtins.str]) -> None:
        jsii.set(self, "contentEncoding", value)

    @builtins.property # type: ignore
    @jsii.member(jsii_name="contentLanguage")
    def content_language(self) -> typing.Optional[builtins.str]:
        return jsii.get(self, "contentLanguage")

    @content_language.setter # type: ignore
    def content_language(self, value: typing.Optional[builtins.str]) -> None:
        jsii.set(self, "contentLanguage", value)

    @builtins.property # type: ignore
    @jsii.member(jsii_name="contentType")
    def content_type(self) -> typing.Optional[builtins.str]:
        return jsii.get(self, "contentType")

    @content_type.setter # type: ignore
    def content_type(self, value: typing.Optional[builtins.str]) -> None:
        jsii.set(self, "contentType", value)

    @builtins.property # type: ignore
    @jsii.member(jsii_name="httpsOnly")
    def https_only(self) -> typing.Optional[builtins.bool]:
        return jsii.get(self, "httpsOnly")

    @https_only.setter # type: ignore
    def https_only(self, value: typing.Optional[builtins.bool]) -> None:
        jsii.set(self, "httpsOnly", value)

    @builtins.property # type: ignore
    @jsii.member(jsii_name="id")
    def id(self) -> typing.Optional[builtins.str]:
        return jsii.get(self, "id")

    @id.setter # type: ignore
    def id(self, value: typing.Optional[builtins.str]) -> None:
        jsii.set(self, "id", value)

    @builtins.property # type: ignore
    @jsii.member(jsii_name="ipAddress")
    def ip_address(self) -> typing.Optional[builtins.str]:
        return jsii.get(self, "ipAddress")

    @ip_address.setter # type: ignore
    def ip_address(self, value: typing.Optional[builtins.str]) -> None:
        jsii.set(self, "ipAddress", value)

    @builtins.property # type: ignore
    @jsii.member(jsii_name="timeouts")
    def timeouts(
        self,
    ) -> typing.Optional["DataAzurermStorageAccountBlobContainerSasTimeouts"]:
        return jsii.get(self, "timeouts")

    @timeouts.setter # type: ignore
    def timeouts(
        self,
        value: typing.Optional["DataAzurermStorageAccountBlobContainerSasTimeouts"],
    ) -> None:
        jsii.set(self, "timeouts", value)


@jsii.data_type(
    jsii_type="@cdktf/provider-azurerm.DataAzurermStorageAccountBlobContainerSasConfig",
    jsii_struct_bases=[cdktf.TerraformMetaArguments],
    name_mapping={
        "count": "count",
        "depends_on": "dependsOn",
        "lifecycle": "lifecycle",
        "provider": "provider",
        "connection_string": "connectionString",
        "container_name": "containerName",
        "expiry": "expiry",
        "permissions": "permissions",
        "start": "start",
        "cache_control": "cacheControl",
        "content_disposition": "contentDisposition",
        "content_encoding": "contentEncoding",
        "content_language": "contentLanguage",
        "content_type": "contentType",
        "https_only": "httpsOnly",
        "ip_address": "ipAddress",
        "timeouts": "timeouts",
    },
)
class DataAzurermStorageAccountBlobContainerSasConfig(cdktf.TerraformMetaArguments):
    def __init__(
        self,
        *,
        count: typing.Optional[jsii.Number] = None,
        depends_on: typing.Optional[typing.List[cdktf.TerraformResource]] = None,
        lifecycle: typing.Optional[cdktf.TerraformResourceLifecycle] = None,
        provider: typing.Optional[cdktf.TerraformProvider] = None,
        connection_string: builtins.str,
        container_name: builtins.str,
        expiry: builtins.str,
        permissions: typing.List["DataAzurermStorageAccountBlobContainerSasPermissions"],
        start: builtins.str,
        cache_control: typing.Optional[builtins.str] = None,
        content_disposition: typing.Optional[builtins.str] = None,
        content_encoding: typing.Optional[builtins.str] = None,
        content_language: typing.Optional[builtins.str] = None,
        content_type: typing.Optional[builtins.str] = None,
        https_only: typing.Optional[builtins.bool] = None,
        ip_address: typing.Optional[builtins.str] = None,
        timeouts: typing.Optional["DataAzurermStorageAccountBlobContainerSasTimeouts"] = None,
    ) -> None:
        """
        :param count: 
        :param depends_on: 
        :param lifecycle: 
        :param provider: 
        :param connection_string: 
        :param container_name: 
        :param expiry: 
        :param permissions: permissions block.
        :param start: 
        :param cache_control: 
        :param content_disposition: 
        :param content_encoding: 
        :param content_language: 
        :param content_type: 
        :param https_only: 
        :param ip_address: 
        :param timeouts: timeouts block.
        """
        if isinstance(lifecycle, dict):
            lifecycle = cdktf.TerraformResourceLifecycle(**lifecycle)
        if isinstance(timeouts, dict):
            timeouts = DataAzurermStorageAccountBlobContainerSasTimeouts(**timeouts)
        self._values: typing.Dict[str, typing.Any] = {
            "connection_string": connection_string,
            "container_name": container_name,
            "expiry": expiry,
            "permissions": permissions,
            "start": start,
        }
        if count is not None:
            self._values["count"] = count
        if depends_on is not None:
            self._values["depends_on"] = depends_on
        if lifecycle is not None:
            self._values["lifecycle"] = lifecycle
        if provider is not None:
            self._values["provider"] = provider
        if cache_control is not None:
            self._values["cache_control"] = cache_control
        if content_disposition is not None:
            self._values["content_disposition"] = content_disposition
        if content_encoding is not None:
            self._values["content_encoding"] = content_encoding
        if content_language is not None:
            self._values["content_language"] = content_language
        if content_type is not None:
            self._values["content_type"] = content_type
        if https_only is not None:
            self._values["https_only"] = https_only
        if ip_address is not None:
            self._values["ip_address"] = ip_address
        if timeouts is not None:
            self._values["timeouts"] = timeouts

    @builtins.property
    def count(self) -> typing.Optional[jsii.Number]:
        """
        :stability: experimental
        """
        result = self._values.get("count")
        return result

    @builtins.property
    def depends_on(self) -> typing.Optional[typing.List[cdktf.TerraformResource]]:
        """
        :stability: experimental
        """
        result = self._values.get("depends_on")
        return result

    @builtins.property
    def lifecycle(self) -> typing.Optional[cdktf.TerraformResourceLifecycle]:
        """
        :stability: experimental
        """
        result = self._values.get("lifecycle")
        return result

    @builtins.property
    def provider(self) -> typing.Optional[cdktf.TerraformProvider]:
        """
        :stability: experimental
        """
        result = self._values.get("provider")
        return result

    @builtins.property
    def connection_string(self) -> builtins.str:
        result = self._values.get("connection_string")
        assert result is not None, "Required property 'connection_string' is missing"
        return result

    @builtins.property
    def container_name(self) -> builtins.str:
        result = self._values.get("container_name")
        assert result is not None, "Required property 'container_name' is missing"
        return result

    @builtins.property
    def expiry(self) -> builtins.str:
        result = self._values.get("expiry")
        assert result is not None, "Required property 'expiry' is missing"
        return result

    @builtins.property
    def permissions(
        self,
    ) -> typing.List["DataAzurermStorageAccountBlobContainerSasPermissions"]:
        """permissions block."""
        result = self._values.get("permissions")
        assert result is not None, "Required property 'permissions' is missing"
        return result

    @builtins.property
    def start(self) -> builtins.str:
        result = self._values.get("start")
        assert result is not None, "Required property 'start' is missing"
        return result

    @builtins.property
    def cache_control(self) -> typing.Optional[builtins.str]:
        result = self._values.get("cache_control")
        return result

    @builtins.property
    def content_disposition(self) -> typing.Optional[builtins.str]:
        result = self._values.get("content_disposition")
        return result

    @builtins.property
    def content_encoding(self) -> typing.Optional[builtins.str]:
        result = self._values.get("content_encoding")
        return result

    @builtins.property
    def content_language(self) -> typing.Optional[builtins.str]:
        result = self._values.get("content_language")
        return result

    @builtins.property
    def content_type(self) -> typing.Optional[builtins.str]:
        result = self._values.get("content_type")
        return result

    @builtins.property
    def https_only(self) -> typing.Optional[builtins.bool]:
        result = self._values.get("https_only")
        return result

    @builtins.property
    def ip_address(self) -> typing.Optional[builtins.str]:
        result = self._values.get("ip_address")
        return result

    @builtins.property
    def timeouts(
        self,
    ) -> typing.Optional["DataAzurermStorageAccountBlobContainerSasTimeouts"]:
        """timeouts block."""
        result = self._values.get("timeouts")
        return result

    def __eq__(self, rhs: typing.Any) -> builtins.bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs: typing.Any) -> builtins.bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return "DataAzurermStorageAccountBlobContainerSasConfig(%s)" % ", ".join(
            k + "=" + repr(v) for k, v in self._values.items()
        )


@jsii.data_type(
    jsii_type="@cdktf/provider-azurerm.DataAzurermStorageAccountBlobContainerSasPermissions",
    jsii_struct_bases=[],
    name_mapping={
        "add": "add",
        "create": "create",
        "delete": "delete",
        "list": "list",
        "read": "read",
        "write": "write",
    },
)
class DataAzurermStorageAccountBlobContainerSasPermissions:
    def __init__(
        self,
        *,
        add: builtins.bool,
        create: builtins.bool,
        delete: builtins.bool,
        list: builtins.bool,
        read: builtins.bool,
        write: builtins.bool,
    ) -> None:
        """
        :param add: 
        :param create: 
        :param delete: 
        :param list: 
        :param read: 
        :param write: 
        """
        self._values: typing.Dict[str, typing.Any] = {
            "add": add,
            "create": create,
            "delete": delete,
            "list": list,
            "read": read,
            "write": write,
        }

    @builtins.property
    def add(self) -> builtins.bool:
        result = self._values.get("add")
        assert result is not None, "Required property 'add' is missing"
        return result

    @builtins.property
    def create(self) -> builtins.bool:
        result = self._values.get("create")
        assert result is not None, "Required property 'create' is missing"
        return result

    @builtins.property
    def delete(self) -> builtins.bool:
        result = self._values.get("delete")
        assert result is not None, "Required property 'delete' is missing"
        return result

    @builtins.property
    def list(self) -> builtins.bool:
        result = self._values.get("list")
        assert result is not None, "Required property 'list' is missing"
        return result

    @builtins.property
    def read(self) -> builtins.bool:
        result = self._values.get("read")
        assert result is not None, "Required property 'read' is missing"
        return result

    @builtins.property
    def write(self) -> builtins.bool:
        result = self._values.get("write")
        assert result is not None, "Required property 'write' is missing"
        return result

    def __eq__(self, rhs: typing.Any) -> builtins.bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs: typing.Any) -> builtins.bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return "DataAzurermStorageAccountBlobContainerSasPermissions(%s)" % ", ".join(
            k + "=" + repr(v) for k, v in self._values.items()
        )


@jsii.data_type(
    jsii_type="@cdktf/provider-azurerm.DataAzurermStorageAccountBlobContainerSasTimeouts",
    jsii_struct_bases=[],
    name_mapping={"read": "read"},
)
class DataAzurermStorageAccountBlobContainerSasTimeouts:
    def __init__(self, *, read: typing.Optional[builtins.str] = None) -> None:
        """
        :param read: 
        """
        self._values: typing.Dict[str, typing.Any] = {}
        if read is not None:
            self._values["read"] = read

    @builtins.property
    def read(self) -> typing.Optional[builtins.str]:
        result = self._values.get("read")
        return result

    def __eq__(self, rhs: typing.Any) -> builtins.bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs: typing.Any) -> builtins.bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return "DataAzurermStorageAccountBlobContainerSasTimeouts(%s)" % ", ".join(
            k + "=" + repr(v) for k, v in self._values.items()
        )


@jsii.data_type(
    jsii_type="@cdktf/provider-azurerm.DataAzurermStorageAccountConfig",
    jsii_struct_bases=[cdktf.TerraformMetaArguments],
    name_mapping={
        "count": "count",
        "depends_on": "dependsOn",
        "lifecycle": "lifecycle",
        "provider": "provider",
        "name": "name",
        "resource_group_name": "resourceGroupName",
        "timeouts": "timeouts",
    },
)
class DataAzurermStorageAccountConfig(cdktf.TerraformMetaArguments):
    def __init__(
        self,
        *,
        count: typing.Optional[jsii.Number] = None,
        depends_on: typing.Optional[typing.List[cdktf.TerraformResource]] = None,
        lifecycle: typing.Optional[cdktf.TerraformResourceLifecycle] = None,
        provider: typing.Optional[cdktf.TerraformProvider] = None,
        name: builtins.str,
        resource_group_name: builtins.str,
        timeouts: typing.Optional["DataAzurermStorageAccountTimeouts"] = None,
    ) -> None:
        """
        :param count: 
        :param depends_on: 
        :param lifecycle: 
        :param provider: 
        :param name: 
        :param resource_group_name: 
        :param timeouts: timeouts block.
        """
        if isinstance(lifecycle, dict):
            lifecycle = cdktf.TerraformResourceLifecycle(**lifecycle)
        if isinstance(timeouts, dict):
            timeouts = DataAzurermStorageAccountTimeouts(**timeouts)
        self._values: typing.Dict[str, typing.Any] = {
            "name": name,
            "resource_group_name": resource_group_name,
        }
        if count is not None:
            self._values["count"] = count
        if depends_on is not None:
            self._values["depends_on"] = depends_on
        if lifecycle is not None:
            self._values["lifecycle"] = lifecycle
        if provider is not None:
            self._values["provider"] = provider
        if timeouts is not None:
            self._values["timeouts"] = timeouts

    @builtins.property
    def count(self) -> typing.Optional[jsii.Number]:
        """
        :stability: experimental
        """
        result = self._values.get("count")
        return result

    @builtins.property
    def depends_on(self) -> typing.Optional[typing.List[cdktf.TerraformResource]]:
        """
        :stability: experimental
        """
        result = self._values.get("depends_on")
        return result

    @builtins.property
    def lifecycle(self) -> typing.Optional[cdktf.TerraformResourceLifecycle]:
        """
        :stability: experimental
        """
        result = self._values.get("lifecycle")
        return result

    @builtins.property
    def provider(self) -> typing.Optional[cdktf.TerraformProvider]:
        """
        :stability: experimental
        """
        result = self._values.get("provider")
        return result

    @builtins.property
    def name(self) -> builtins.str:
        result = self._values.get("name")
        assert result is not None, "Required property 'name' is missing"
        return result

    @builtins.property
    def resource_group_name(self) -> builtins.str:
        result = self._values.get("resource_group_name")
        assert result is not None, "Required property 'resource_group_name' is missing"
        return result

    @builtins.property
    def timeouts(self) -> typing.Optional["DataAzurermStorageAccountTimeouts"]:
        """timeouts block."""
        result = self._values.get("timeouts")
        return result

    def __eq__(self, rhs: typing.Any) -> builtins.bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs: typing.Any) -> builtins.bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return "DataAzurermStorageAccountConfig(%s)" % ", ".join(
            k + "=" + repr(v) for k, v in self._values.items()
        )


class DataAzurermStorageAccountCustomDomain(
    cdktf.ComplexComputedList,
    metaclass=jsii.JSIIMeta,
    jsii_type="@cdktf/provider-azurerm.DataAzurermStorageAccountCustomDomain",
):
    def __init__(
        self,
        terraform_resource: cdktf.ITerraformResource,
        terraform_attribute: builtins.str,
        index: builtins.str,
    ) -> None:
        """
        :param terraform_resource: -
        :param terraform_attribute: -
        :param index: -

        :stability: experimental
        """
        jsii.create(DataAzurermStorageAccountCustomDomain, self, [terraform_resource, terraform_attribute, index])

    @builtins.property # type: ignore
    @jsii.member(jsii_name="name")
    def name(self) -> builtins.str:
        return jsii.get(self, "name")


class DataAzurermStorageAccountSas(
    cdktf.TerraformDataSource,
    metaclass=jsii.JSIIMeta,
    jsii_type="@cdktf/provider-azurerm.DataAzurermStorageAccountSas",
):
    def __init__(
        self,
        scope: constructs.Construct,
        id: builtins.str,
        *,
        connection_string: builtins.str,
        expiry: builtins.str,
        permissions: typing.List["DataAzurermStorageAccountSasPermissions"],
        resource_types: typing.List["DataAzurermStorageAccountSasResourceTypes"],
        services: typing.List["DataAzurermStorageAccountSasServices"],
        start: builtins.str,
        https_only: typing.Optional[builtins.bool] = None,
        timeouts: typing.Optional["DataAzurermStorageAccountSasTimeouts"] = None,
        count: typing.Optional[jsii.Number] = None,
        depends_on: typing.Optional[typing.List[cdktf.TerraformResource]] = None,
        lifecycle: typing.Optional[cdktf.TerraformResourceLifecycle] = None,
        provider: typing.Optional[cdktf.TerraformProvider] = None,
    ) -> None:
        """
        :param scope: -
        :param id: -
        :param connection_string: 
        :param expiry: 
        :param permissions: permissions block.
        :param resource_types: resource_types block.
        :param services: services block.
        :param start: 
        :param https_only: 
        :param timeouts: timeouts block.
        :param count: 
        :param depends_on: 
        :param lifecycle: 
        :param provider: 
        """
        config = DataAzurermStorageAccountSasConfig(
            connection_string=connection_string,
            expiry=expiry,
            permissions=permissions,
            resource_types=resource_types,
            services=services,
            start=start,
            https_only=https_only,
            timeouts=timeouts,
            count=count,
            depends_on=depends_on,
            lifecycle=lifecycle,
            provider=provider,
        )

        jsii.create(DataAzurermStorageAccountSas, self, [scope, id, config])

    @jsii.member(jsii_name="synthesizeAttributes")
    def _synthesize_attributes(self) -> typing.Mapping[builtins.str, typing.Any]:
        return jsii.invoke(self, "synthesizeAttributes", [])

    @builtins.property # type: ignore
    @jsii.member(jsii_name="sas")
    def sas(self) -> builtins.str:
        return jsii.get(self, "sas")

    @builtins.property # type: ignore
    @jsii.member(jsii_name="connectionString")
    def connection_string(self) -> builtins.str:
        return jsii.get(self, "connectionString")

    @connection_string.setter # type: ignore
    def connection_string(self, value: builtins.str) -> None:
        jsii.set(self, "connectionString", value)

    @builtins.property # type: ignore
    @jsii.member(jsii_name="expiry")
    def expiry(self) -> builtins.str:
        return jsii.get(self, "expiry")

    @expiry.setter # type: ignore
    def expiry(self, value: builtins.str) -> None:
        jsii.set(self, "expiry", value)

    @builtins.property # type: ignore
    @jsii.member(jsii_name="permissions")
    def permissions(self) -> typing.List["DataAzurermStorageAccountSasPermissions"]:
        return jsii.get(self, "permissions")

    @permissions.setter # type: ignore
    def permissions(
        self,
        value: typing.List["DataAzurermStorageAccountSasPermissions"],
    ) -> None:
        jsii.set(self, "permissions", value)

    @builtins.property # type: ignore
    @jsii.member(jsii_name="resourceTypes")
    def resource_types(
        self,
    ) -> typing.List["DataAzurermStorageAccountSasResourceTypes"]:
        return jsii.get(self, "resourceTypes")

    @resource_types.setter # type: ignore
    def resource_types(
        self,
        value: typing.List["DataAzurermStorageAccountSasResourceTypes"],
    ) -> None:
        jsii.set(self, "resourceTypes", value)

    @builtins.property # type: ignore
    @jsii.member(jsii_name="services")
    def services(self) -> typing.List["DataAzurermStorageAccountSasServices"]:
        return jsii.get(self, "services")

    @services.setter # type: ignore
    def services(
        self,
        value: typing.List["DataAzurermStorageAccountSasServices"],
    ) -> None:
        jsii.set(self, "services", value)

    @builtins.property # type: ignore
    @jsii.member(jsii_name="start")
    def start(self) -> builtins.str:
        return jsii.get(self, "start")

    @start.setter # type: ignore
    def start(self, value: builtins.str) -> None:
        jsii.set(self, "start", value)

    @builtins.property # type: ignore
    @jsii.member(jsii_name="httpsOnly")
    def https_only(self) -> typing.Optional[builtins.bool]:
        return jsii.get(self, "httpsOnly")

    @https_only.setter # type: ignore
    def https_only(self, value: typing.Optional[builtins.bool]) -> None:
        jsii.set(self, "httpsOnly", value)

    @builtins.property # type: ignore
    @jsii.member(jsii_name="id")
    def id(self) -> typing.Optional[builtins.str]:
        return jsii.get(self, "id")

    @id.setter # type: ignore
    def id(self, value: typing.Optional[builtins.str]) -> None:
        jsii.set(self, "id", value)

    @builtins.property # type: ignore
    @jsii.member(jsii_name="timeouts")
    def timeouts(self) -> typing.Optional["DataAzurermStorageAccountSasTimeouts"]:
        return jsii.get(self, "timeouts")

    @timeouts.setter # type: ignore
    def timeouts(
        self,
        value: typing.Optional["DataAzurermStorageAccountSasTimeouts"],
    ) -> None:
        jsii.set(self, "timeouts", value)


@jsii.data_type(
    jsii_type="@cdktf/provider-azurerm.DataAzurermStorageAccountSasConfig",
    jsii_struct_bases=[cdktf.TerraformMetaArguments],
    name_mapping={
        "count": "count",
        "depends_on": "dependsOn",
        "lifecycle": "lifecycle",
        "provider": "provider",
        "connection_string": "connectionString",
        "expiry": "expiry",
        "permissions": "permissions",
        "resource_types": "resourceTypes",
        "services": "services",
        "start": "start",
        "https_only": "httpsOnly",
        "timeouts": "timeouts",
    },
)
class DataAzurermStorageAccountSasConfig(cdktf.TerraformMetaArguments):
    def __init__(
        self,
        *,
        count: typing.Optional[jsii.Number] = None,
        depends_on: typing.Optional[typing.List[cdktf.TerraformResource]] = None,
        lifecycle: typing.Optional[cdktf.TerraformResourceLifecycle] = None,
        provider: typing.Optional[cdktf.TerraformProvider] = None,
        connection_string: builtins.str,
        expiry: builtins.str,
        permissions: typing.List["DataAzurermStorageAccountSasPermissions"],
        resource_types: typing.List["DataAzurermStorageAccountSasResourceTypes"],
        services: typing.List["DataAzurermStorageAccountSasServices"],
        start: builtins.str,
        https_only: typing.Optional[builtins.bool] = None,
        timeouts: typing.Optional["DataAzurermStorageAccountSasTimeouts"] = None,
    ) -> None:
        """
        :param count: 
        :param depends_on: 
        :param lifecycle: 
        :param provider: 
        :param connection_string: 
        :param expiry: 
        :param permissions: permissions block.
        :param resource_types: resource_types block.
        :param services: services block.
        :param start: 
        :param https_only: 
        :param timeouts: timeouts block.
        """
        if isinstance(lifecycle, dict):
            lifecycle = cdktf.TerraformResourceLifecycle(**lifecycle)
        if isinstance(timeouts, dict):
            timeouts = DataAzurermStorageAccountSasTimeouts(**timeouts)
        self._values: typing.Dict[str, typing.Any] = {
            "connection_string": connection_string,
            "expiry": expiry,
            "permissions": permissions,
            "resource_types": resource_types,
            "services": services,
            "start": start,
        }
        if count is not None:
            self._values["count"] = count
        if depends_on is not None:
            self._values["depends_on"] = depends_on
        if lifecycle is not None:
            self._values["lifecycle"] = lifecycle
        if provider is not None:
            self._values["provider"] = provider
        if https_only is not None:
            self._values["https_only"] = https_only
        if timeouts is not None:
            self._values["timeouts"] = timeouts

    @builtins.property
    def count(self) -> typing.Optional[jsii.Number]:
        """
        :stability: experimental
        """
        result = self._values.get("count")
        return result

    @builtins.property
    def depends_on(self) -> typing.Optional[typing.List[cdktf.TerraformResource]]:
        """
        :stability: experimental
        """
        result = self._values.get("depends_on")
        return result

    @builtins.property
    def lifecycle(self) -> typing.Optional[cdktf.TerraformResourceLifecycle]:
        """
        :stability: experimental
        """
        result = self._values.get("lifecycle")
        return result

    @builtins.property
    def provider(self) -> typing.Optional[cdktf.TerraformProvider]:
        """
        :stability: experimental
        """
        result = self._values.get("provider")
        return result

    @builtins.property
    def connection_string(self) -> builtins.str:
        result = self._values.get("connection_string")
        assert result is not None, "Required property 'connection_string' is missing"
        return result

    @builtins.property
    def expiry(self) -> builtins.str:
        result = self._values.get("expiry")
        assert result is not None, "Required property 'expiry' is missing"
        return result

    @builtins.property
    def permissions(self) -> typing.List["DataAzurermStorageAccountSasPermissions"]:
        """permissions block."""
        result = self._values.get("permissions")
        assert result is not None, "Required property 'permissions' is missing"
        return result

    @builtins.property
    def resource_types(
        self,
    ) -> typing.List["DataAzurermStorageAccountSasResourceTypes"]:
        """resource_types block."""
        result = self._values.get("resource_types")
        assert result is not None, "Required property 'resource_types' is missing"
        return result

    @builtins.property
    def services(self) -> typing.List["DataAzurermStorageAccountSasServices"]:
        """services block."""
        result = self._values.get("services")
        assert result is not None, "Required property 'services' is missing"
        return result

    @builtins.property
    def start(self) -> builtins.str:
        result = self._values.get("start")
        assert result is not None, "Required property 'start' is missing"
        return result

    @builtins.property
    def https_only(self) -> typing.Optional[builtins.bool]:
        result = self._values.get("https_only")
        return result

    @builtins.property
    def timeouts(self) -> typing.Optional["DataAzurermStorageAccountSasTimeouts"]:
        """timeouts block."""
        result = self._values.get("timeouts")
        return result

    def __eq__(self, rhs: typing.Any) -> builtins.bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs: typing.Any) -> builtins.bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return "DataAzurermStorageAccountSasConfig(%s)" % ", ".join(
            k + "=" + repr(v) for k, v in self._values.items()
        )


@jsii.data_type(
    jsii_type="@cdktf/provider-azurerm.DataAzurermStorageAccountSasPermissions",
    jsii_struct_bases=[],
    name_mapping={
        "add": "add",
        "create": "create",
        "delete": "delete",
        "list": "list",
        "process": "process",
        "read": "read",
        "update": "update",
        "write": "write",
    },
)
class DataAzurermStorageAccountSasPermissions:
    def __init__(
        self,
        *,
        add: builtins.bool,
        create: builtins.bool,
        delete: builtins.bool,
        list: builtins.bool,
        process: builtins.bool,
        read: builtins.bool,
        update: builtins.bool,
        write: builtins.bool,
    ) -> None:
        """
        :param add: 
        :param create: 
        :param delete: 
        :param list: 
        :param process: 
        :param read: 
        :param update: 
        :param write: 
        """
        self._values: typing.Dict[str, typing.Any] = {
            "add": add,
            "create": create,
            "delete": delete,
            "list": list,
            "process": process,
            "read": read,
            "update": update,
            "write": write,
        }

    @builtins.property
    def add(self) -> builtins.bool:
        result = self._values.get("add")
        assert result is not None, "Required property 'add' is missing"
        return result

    @builtins.property
    def create(self) -> builtins.bool:
        result = self._values.get("create")
        assert result is not None, "Required property 'create' is missing"
        return result

    @builtins.property
    def delete(self) -> builtins.bool:
        result = self._values.get("delete")
        assert result is not None, "Required property 'delete' is missing"
        return result

    @builtins.property
    def list(self) -> builtins.bool:
        result = self._values.get("list")
        assert result is not None, "Required property 'list' is missing"
        return result

    @builtins.property
    def process(self) -> builtins.bool:
        result = self._values.get("process")
        assert result is not None, "Required property 'process' is missing"
        return result

    @builtins.property
    def read(self) -> builtins.bool:
        result = self._values.get("read")
        assert result is not None, "Required property 'read' is missing"
        return result

    @builtins.property
    def update(self) -> builtins.bool:
        result = self._values.get("update")
        assert result is not None, "Required property 'update' is missing"
        return result

    @builtins.property
    def write(self) -> builtins.bool:
        result = self._values.get("write")
        assert result is not None, "Required property 'write' is missing"
        return result

    def __eq__(self, rhs: typing.Any) -> builtins.bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs: typing.Any) -> builtins.bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return "DataAzurermStorageAccountSasPermissions(%s)" % ", ".join(
            k + "=" + repr(v) for k, v in self._values.items()
        )


@jsii.data_type(
    jsii_type="@cdktf/provider-azurerm.DataAzurermStorageAccountSasResourceTypes",
    jsii_struct_bases=[],
    name_mapping={"container": "container", "object": "object", "service": "service"},
)
class DataAzurermStorageAccountSasResourceTypes:
    def __init__(
        self,
        *,
        container: builtins.bool,
        object: builtins.bool,
        service: builtins.bool,
    ) -> None:
        """
        :param container: 
        :param object: 
        :param service: 
        """
        self._values: typing.Dict[str, typing.Any] = {
            "container": container,
            "object": object,
            "service": service,
        }

    @builtins.property
    def container(self) -> builtins.bool:
        result = self._values.get("container")
        assert result is not None, "Required property 'container' is missing"
        return result

    @builtins.property
    def object(self) -> builtins.bool:
        result = self._values.get("object")
        assert result is not None, "Required property 'object' is missing"
        return result

    @builtins.property
    def service(self) -> builtins.bool:
        result = self._values.get("service")
        assert result is not None, "Required property 'service' is missing"
        return result

    def __eq__(self, rhs: typing.Any) -> builtins.bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs: typing.Any) -> builtins.bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return "DataAzurermStorageAccountSasResourceTypes(%s)" % ", ".join(
            k + "=" + repr(v) for k, v in self._values.items()
        )


@jsii.data_type(
    jsii_type="@cdktf/provider-azurerm.DataAzurermStorageAccountSasServices",
    jsii_struct_bases=[],
    name_mapping={"blob": "blob", "file": "file", "queue": "queue", "table": "table"},
)
class DataAzurermStorageAccountSasServices:
    def __init__(
        self,
        *,
        blob: builtins.bool,
        file: builtins.bool,
        queue: builtins.bool,
        table: builtins.bool,
    ) -> None:
        """
        :param blob: 
        :param file: 
        :param queue: 
        :param table: 
        """
        self._values: typing.Dict[str, typing.Any] = {
            "blob": blob,
            "file": file,
            "queue": queue,
            "table": table,
        }

    @builtins.property
    def blob(self) -> builtins.bool:
        result = self._values.get("blob")
        assert result is not None, "Required property 'blob' is missing"
        return result

    @builtins.property
    def file(self) -> builtins.bool:
        result = self._values.get("file")
        assert result is not None, "Required property 'file' is missing"
        return result

    @builtins.property
    def queue(self) -> builtins.bool:
        result = self._values.get("queue")
        assert result is not None, "Required property 'queue' is missing"
        return result

    @builtins.property
    def table(self) -> builtins.bool:
        result = self._values.get("table")
        assert result is not None, "Required property 'table' is missing"
        return result

    def __eq__(self, rhs: typing.Any) -> builtins.bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs: typing.Any) -> builtins.bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return "DataAzurermStorageAccountSasServices(%s)" % ", ".join(
            k + "=" + repr(v) for k, v in self._values.items()
        )


@jsii.data_type(
    jsii_type="@cdktf/provider-azurerm.DataAzurermStorageAccountSasTimeouts",
    jsii_struct_bases=[],
    name_mapping={"read": "read"},
)
class DataAzurermStorageAccountSasTimeouts:
    def __init__(self, *, read: typing.Optional[builtins.str] = None) -> None:
        """
        :param read: 
        """
        self._values: typing.Dict[str, typing.Any] = {}
        if read is not None:
            self._values["read"] = read

    @builtins.property
    def read(self) -> typing.Optional[builtins.str]:
        result = self._values.get("read")
        return result

    def __eq__(self, rhs: typing.Any) -> builtins.bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs: typing.Any) -> builtins.bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return "DataAzurermStorageAccountSasTimeouts(%s)" % ", ".join(
            k + "=" + repr(v) for k, v in self._values.items()
        )


@jsii.data_type(
    jsii_type="@cdktf/provider-azurerm.DataAzurermStorageAccountTimeouts",
    jsii_struct_bases=[],
    name_mapping={"read": "read"},
)
class DataAzurermStorageAccountTimeouts:
    def __init__(self, *, read: typing.Optional[builtins.str] = None) -> None:
        """
        :param read: 
        """
        self._values: typing.Dict[str, typing.Any] = {}
        if read is not None:
            self._values["read"] = read

    @builtins.property
    def read(self) -> typing.Optional[builtins.str]:
        result = self._values.get("read")
        return result

    def __eq__(self, rhs: typing.Any) -> builtins.bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs: typing.Any) -> builtins.bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return "DataAzurermStorageAccountTimeouts(%s)" % ", ".join(
            k + "=" + repr(v) for k, v in self._values.items()
        )


class DataAzurermStorageContainer(
    cdktf.TerraformDataSource,
    metaclass=jsii.JSIIMeta,
    jsii_type="@cdktf/provider-azurerm.DataAzurermStorageContainer",
):
    def __init__(
        self,
        scope: constructs.Construct,
        id: builtins.str,
        *,
        name: builtins.str,
        storage_account_name: builtins.str,
        metadata: typing.Optional[typing.Mapping[builtins.str, builtins.str]] = None,
        timeouts: typing.Optional["DataAzurermStorageContainerTimeouts"] = None,
        count: typing.Optional[jsii.Number] = None,
        depends_on: typing.Optional[typing.List[cdktf.TerraformResource]] = None,
        lifecycle: typing.Optional[cdktf.TerraformResourceLifecycle] = None,
        provider: typing.Optional[cdktf.TerraformProvider] = None,
    ) -> None:
        """
        :param scope: -
        :param id: -
        :param name: 
        :param storage_account_name: 
        :param metadata: 
        :param timeouts: timeouts block.
        :param count: 
        :param depends_on: 
        :param lifecycle: 
        :param provider: 
        """
        config = DataAzurermStorageContainerConfig(
            name=name,
            storage_account_name=storage_account_name,
            metadata=metadata,
            timeouts=timeouts,
            count=count,
            depends_on=depends_on,
            lifecycle=lifecycle,
            provider=provider,
        )

        jsii.create(DataAzurermStorageContainer, self, [scope, id, config])

    @jsii.member(jsii_name="synthesizeAttributes")
    def _synthesize_attributes(self) -> typing.Mapping[builtins.str, typing.Any]:
        return jsii.invoke(self, "synthesizeAttributes", [])

    @builtins.property # type: ignore
    @jsii.member(jsii_name="containerAccessType")
    def container_access_type(self) -> builtins.str:
        return jsii.get(self, "containerAccessType")

    @builtins.property # type: ignore
    @jsii.member(jsii_name="hasImmutabilityPolicy")
    def has_immutability_policy(self) -> builtins.bool:
        return jsii.get(self, "hasImmutabilityPolicy")

    @builtins.property # type: ignore
    @jsii.member(jsii_name="hasLegalHold")
    def has_legal_hold(self) -> builtins.bool:
        return jsii.get(self, "hasLegalHold")

    @builtins.property # type: ignore
    @jsii.member(jsii_name="name")
    def name(self) -> builtins.str:
        return jsii.get(self, "name")

    @name.setter # type: ignore
    def name(self, value: builtins.str) -> None:
        jsii.set(self, "name", value)

    @builtins.property # type: ignore
    @jsii.member(jsii_name="storageAccountName")
    def storage_account_name(self) -> builtins.str:
        return jsii.get(self, "storageAccountName")

    @storage_account_name.setter # type: ignore
    def storage_account_name(self, value: builtins.str) -> None:
        jsii.set(self, "storageAccountName", value)

    @builtins.property # type: ignore
    @jsii.member(jsii_name="id")
    def id(self) -> typing.Optional[builtins.str]:
        return jsii.get(self, "id")

    @id.setter # type: ignore
    def id(self, value: typing.Optional[builtins.str]) -> None:
        jsii.set(self, "id", value)

    @builtins.property # type: ignore
    @jsii.member(jsii_name="metadata")
    def metadata(self) -> typing.Optional[typing.Mapping[builtins.str, builtins.str]]:
        return jsii.get(self, "metadata")

    @metadata.setter # type: ignore
    def metadata(
        self,
        value: typing.Optional[typing.Mapping[builtins.str, builtins.str]],
    ) -> None:
        jsii.set(self, "metadata", value)

    @builtins.property # type: ignore
    @jsii.member(jsii_name="timeouts")
    def timeouts(self) -> typing.Optional["DataAzurermStorageContainerTimeouts"]:
        return jsii.get(self, "timeouts")

    @timeouts.setter # type: ignore
    def timeouts(
        self,
        value: typing.Optional["DataAzurermStorageContainerTimeouts"],
    ) -> None:
        jsii.set(self, "timeouts", value)


@jsii.data_type(
    jsii_type="@cdktf/provider-azurerm.DataAzurermStorageContainerConfig",
    jsii_struct_bases=[cdktf.TerraformMetaArguments],
    name_mapping={
        "count": "count",
        "depends_on": "dependsOn",
        "lifecycle": "lifecycle",
        "provider": "provider",
        "name": "name",
        "storage_account_name": "storageAccountName",
        "metadata": "metadata",
        "timeouts": "timeouts",
    },
)
class DataAzurermStorageContainerConfig(cdktf.TerraformMetaArguments):
    def __init__(
        self,
        *,
        count: typing.Optional[jsii.Number] = None,
        depends_on: typing.Optional[typing.List[cdktf.TerraformResource]] = None,
        lifecycle: typing.Optional[cdktf.TerraformResourceLifecycle] = None,
        provider: typing.Optional[cdktf.TerraformProvider] = None,
        name: builtins.str,
        storage_account_name: builtins.str,
        metadata: typing.Optional[typing.Mapping[builtins.str, builtins.str]] = None,
        timeouts: typing.Optional["DataAzurermStorageContainerTimeouts"] = None,
    ) -> None:
        """
        :param count: 
        :param depends_on: 
        :param lifecycle: 
        :param provider: 
        :param name: 
        :param storage_account_name: 
        :param metadata: 
        :param timeouts: timeouts block.
        """
        if isinstance(lifecycle, dict):
            lifecycle = cdktf.TerraformResourceLifecycle(**lifecycle)
        if isinstance(timeouts, dict):
            timeouts = DataAzurermStorageContainerTimeouts(**timeouts)
        self._values: typing.Dict[str, typing.Any] = {
            "name": name,
            "storage_account_name": storage_account_name,
        }
        if count is not None:
            self._values["count"] = count
        if depends_on is not None:
            self._values["depends_on"] = depends_on
        if lifecycle is not None:
            self._values["lifecycle"] = lifecycle
        if provider is not None:
            self._values["provider"] = provider
        if metadata is not None:
            self._values["metadata"] = metadata
        if timeouts is not None:
            self._values["timeouts"] = timeouts

    @builtins.property
    def count(self) -> typing.Optional[jsii.Number]:
        """
        :stability: experimental
        """
        result = self._values.get("count")
        return result

    @builtins.property
    def depends_on(self) -> typing.Optional[typing.List[cdktf.TerraformResource]]:
        """
        :stability: experimental
        """
        result = self._values.get("depends_on")
        return result

    @builtins.property
    def lifecycle(self) -> typing.Optional[cdktf.TerraformResourceLifecycle]:
        """
        :stability: experimental
        """
        result = self._values.get("lifecycle")
        return result

    @builtins.property
    def provider(self) -> typing.Optional[cdktf.TerraformProvider]:
        """
        :stability: experimental
        """
        result = self._values.get("provider")
        return result

    @builtins.property
    def name(self) -> builtins.str:
        result = self._values.get("name")
        assert result is not None, "Required property 'name' is missing"
        return result

    @builtins.property
    def storage_account_name(self) -> builtins.str:
        result = self._values.get("storage_account_name")
        assert result is not None, "Required property 'storage_account_name' is missing"
        return result

    @builtins.property
    def metadata(self) -> typing.Optional[typing.Mapping[builtins.str, builtins.str]]:
        result = self._values.get("metadata")
        return result

    @builtins.property
    def timeouts(self) -> typing.Optional["DataAzurermStorageContainerTimeouts"]:
        """timeouts block."""
        result = self._values.get("timeouts")
        return result

    def __eq__(self, rhs: typing.Any) -> builtins.bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs: typing.Any) -> builtins.bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return "DataAzurermStorageContainerConfig(%s)" % ", ".join(
            k + "=" + repr(v) for k, v in self._values.items()
        )


@jsii.data_type(
    jsii_type="@cdktf/provider-azurerm.DataAzurermStorageContainerTimeouts",
    jsii_struct_bases=[],
    name_mapping={"read": "read"},
)
class DataAzurermStorageContainerTimeouts:
    def __init__(self, *, read: typing.Optional[builtins.str] = None) -> None:
        """
        :param read: 
        """
        self._values: typing.Dict[str, typing.Any] = {}
        if read is not None:
            self._values["read"] = read

    @builtins.property
    def read(self) -> typing.Optional[builtins.str]:
        result = self._values.get("read")
        return result

    def __eq__(self, rhs: typing.Any) -> builtins.bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs: typing.Any) -> builtins.bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return "DataAzurermStorageContainerTimeouts(%s)" % ", ".join(
            k + "=" + repr(v) for k, v in self._values.items()
        )


class DataAzurermStorageManagementPolicy(
    cdktf.TerraformDataSource,
    metaclass=jsii.JSIIMeta,
    jsii_type="@cdktf/provider-azurerm.DataAzurermStorageManagementPolicy",
):
    def __init__(
        self,
        scope: constructs.Construct,
        id: builtins.str,
        *,
        storage_account_id: builtins.str,
        timeouts: typing.Optional["DataAzurermStorageManagementPolicyTimeouts"] = None,
        count: typing.Optional[jsii.Number] = None,
        depends_on: typing.Optional[typing.List[cdktf.TerraformResource]] = None,
        lifecycle: typing.Optional[cdktf.TerraformResourceLifecycle] = None,
        provider: typing.Optional[cdktf.TerraformProvider] = None,
    ) -> None:
        """
        :param scope: -
        :param id: -
        :param storage_account_id: 
        :param timeouts: timeouts block.
        :param count: 
        :param depends_on: 
        :param lifecycle: 
        :param provider: 
        """
        config = DataAzurermStorageManagementPolicyConfig(
            storage_account_id=storage_account_id,
            timeouts=timeouts,
            count=count,
            depends_on=depends_on,
            lifecycle=lifecycle,
            provider=provider,
        )

        jsii.create(DataAzurermStorageManagementPolicy, self, [scope, id, config])

    @jsii.member(jsii_name="rule")
    def rule(self, index: builtins.str) -> "DataAzurermStorageManagementPolicyRule":
        """
        :param index: -
        """
        return jsii.invoke(self, "rule", [index])

    @jsii.member(jsii_name="synthesizeAttributes")
    def _synthesize_attributes(self) -> typing.Mapping[builtins.str, typing.Any]:
        return jsii.invoke(self, "synthesizeAttributes", [])

    @builtins.property # type: ignore
    @jsii.member(jsii_name="storageAccountId")
    def storage_account_id(self) -> builtins.str:
        return jsii.get(self, "storageAccountId")

    @storage_account_id.setter # type: ignore
    def storage_account_id(self, value: builtins.str) -> None:
        jsii.set(self, "storageAccountId", value)

    @builtins.property # type: ignore
    @jsii.member(jsii_name="id")
    def id(self) -> typing.Optional[builtins.str]:
        return jsii.get(self, "id")

    @id.setter # type: ignore
    def id(self, value: typing.Optional[builtins.str]) -> None:
        jsii.set(self, "id", value)

    @builtins.property # type: ignore
    @jsii.member(jsii_name="timeouts")
    def timeouts(self) -> typing.Optional["DataAzurermStorageManagementPolicyTimeouts"]:
        return jsii.get(self, "timeouts")

    @timeouts.setter # type: ignore
    def timeouts(
        self,
        value: typing.Optional["DataAzurermStorageManagementPolicyTimeouts"],
    ) -> None:
        jsii.set(self, "timeouts", value)


@jsii.data_type(
    jsii_type="@cdktf/provider-azurerm.DataAzurermStorageManagementPolicyConfig",
    jsii_struct_bases=[cdktf.TerraformMetaArguments],
    name_mapping={
        "count": "count",
        "depends_on": "dependsOn",
        "lifecycle": "lifecycle",
        "provider": "provider",
        "storage_account_id": "storageAccountId",
        "timeouts": "timeouts",
    },
)
class DataAzurermStorageManagementPolicyConfig(cdktf.TerraformMetaArguments):
    def __init__(
        self,
        *,
        count: typing.Optional[jsii.Number] = None,
        depends_on: typing.Optional[typing.List[cdktf.TerraformResource]] = None,
        lifecycle: typing.Optional[cdktf.TerraformResourceLifecycle] = None,
        provider: typing.Optional[cdktf.TerraformProvider] = None,
        storage_account_id: builtins.str,
        timeouts: typing.Optional["DataAzurermStorageManagementPolicyTimeouts"] = None,
    ) -> None:
        """
        :param count: 
        :param depends_on: 
        :param lifecycle: 
        :param provider: 
        :param storage_account_id: 
        :param timeouts: timeouts block.
        """
        if isinstance(lifecycle, dict):
            lifecycle = cdktf.TerraformResourceLifecycle(**lifecycle)
        if isinstance(timeouts, dict):
            timeouts = DataAzurermStorageManagementPolicyTimeouts(**timeouts)
        self._values: typing.Dict[str, typing.Any] = {
            "storage_account_id": storage_account_id,
        }
        if count is not None:
            self._values["count"] = count
        if depends_on is not None:
            self._values["depends_on"] = depends_on
        if lifecycle is not None:
            self._values["lifecycle"] = lifecycle
        if provider is not None:
            self._values["provider"] = provider
        if timeouts is not None:
            self._values["timeouts"] = timeouts

    @builtins.property
    def count(self) -> typing.Optional[jsii.Number]:
        """
        :stability: experimental
        """
        result = self._values.get("count")
        return result

    @builtins.property
    def depends_on(self) -> typing.Optional[typing.List[cdktf.TerraformResource]]:
        """
        :stability: experimental
        """
        result = self._values.get("depends_on")
        return result

    @builtins.property
    def lifecycle(self) -> typing.Optional[cdktf.TerraformResourceLifecycle]:
        """
        :stability: experimental
        """
        result = self._values.get("lifecycle")
        return result

    @builtins.property
    def provider(self) -> typing.Optional[cdktf.TerraformProvider]:
        """
        :stability: experimental
        """
        result = self._values.get("provider")
        return result

    @builtins.property
    def storage_account_id(self) -> builtins.str:
        result = self._values.get("storage_account_id")
        assert result is not None, "Required property 'storage_account_id' is missing"
        return result

    @builtins.property
    def timeouts(self) -> typing.Optional["DataAzurermStorageManagementPolicyTimeouts"]:
        """timeouts block."""
        result = self._values.get("timeouts")
        return result

    def __eq__(self, rhs: typing.Any) -> builtins.bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs: typing.Any) -> builtins.bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return "DataAzurermStorageManagementPolicyConfig(%s)" % ", ".join(
            k + "=" + repr(v) for k, v in self._values.items()
        )


class DataAzurermStorageManagementPolicyRule(
    cdktf.ComplexComputedList,
    metaclass=jsii.JSIIMeta,
    jsii_type="@cdktf/provider-azurerm.DataAzurermStorageManagementPolicyRule",
):
    def __init__(
        self,
        terraform_resource: cdktf.ITerraformResource,
        terraform_attribute: builtins.str,
        index: builtins.str,
    ) -> None:
        """
        :param terraform_resource: -
        :param terraform_attribute: -
        :param index: -

        :stability: experimental
        """
        jsii.create(DataAzurermStorageManagementPolicyRule, self, [terraform_resource, terraform_attribute, index])

    @builtins.property # type: ignore
    @jsii.member(jsii_name="actions")
    def actions(self) -> typing.Any:
        return jsii.get(self, "actions")

    @builtins.property # type: ignore
    @jsii.member(jsii_name="enabled")
    def enabled(self) -> builtins.bool:
        return jsii.get(self, "enabled")

    @builtins.property # type: ignore
    @jsii.member(jsii_name="filters")
    def filters(self) -> typing.Any:
        return jsii.get(self, "filters")

    @builtins.property # type: ignore
    @jsii.member(jsii_name="name")
    def name(self) -> builtins.str:
        return jsii.get(self, "name")


class DataAzurermStorageManagementPolicyRuleActions(
    cdktf.ComplexComputedList,
    metaclass=jsii.JSIIMeta,
    jsii_type="@cdktf/provider-azurerm.DataAzurermStorageManagementPolicyRuleActions",
):
    def __init__(
        self,
        terraform_resource: cdktf.ITerraformResource,
        terraform_attribute: builtins.str,
        index: builtins.str,
    ) -> None:
        """
        :param terraform_resource: -
        :param terraform_attribute: -
        :param index: -

        :stability: experimental
        """
        jsii.create(DataAzurermStorageManagementPolicyRuleActions, self, [terraform_resource, terraform_attribute, index])

    @builtins.property # type: ignore
    @jsii.member(jsii_name="baseBlob")
    def base_blob(self) -> typing.Any:
        return jsii.get(self, "baseBlob")

    @builtins.property # type: ignore
    @jsii.member(jsii_name="snapshot")
    def snapshot(self) -> typing.Any:
        return jsii.get(self, "snapshot")


class DataAzurermStorageManagementPolicyRuleActionsBaseBlob(
    cdktf.ComplexComputedList,
    metaclass=jsii.JSIIMeta,
    jsii_type="@cdktf/provider-azurerm.DataAzurermStorageManagementPolicyRuleActionsBaseBlob",
):
    def __init__(
        self,
        terraform_resource: cdktf.ITerraformResource,
        terraform_attribute: builtins.str,
        index: builtins.str,
    ) -> None:
        """
        :param terraform_resource: -
        :param terraform_attribute: -
        :param index: -

        :stability: experimental
        """
        jsii.create(DataAzurermStorageManagementPolicyRuleActionsBaseBlob, self, [terraform_resource, terraform_attribute, index])

    @builtins.property # type: ignore
    @jsii.member(jsii_name="deleteAfterDaysSinceModificationGreaterThan")
    def delete_after_days_since_modification_greater_than(self) -> jsii.Number:
        return jsii.get(self, "deleteAfterDaysSinceModificationGreaterThan")

    @builtins.property # type: ignore
    @jsii.member(jsii_name="tierToArchiveAfterDaysSinceModificationGreaterThan")
    def tier_to_archive_after_days_since_modification_greater_than(self) -> jsii.Number:
        return jsii.get(self, "tierToArchiveAfterDaysSinceModificationGreaterThan")

    @builtins.property # type: ignore
    @jsii.member(jsii_name="tierToCoolAfterDaysSinceModificationGreaterThan")
    def tier_to_cool_after_days_since_modification_greater_than(self) -> jsii.Number:
        return jsii.get(self, "tierToCoolAfterDaysSinceModificationGreaterThan")


class DataAzurermStorageManagementPolicyRuleActionsSnapshot(
    cdktf.ComplexComputedList,
    metaclass=jsii.JSIIMeta,
    jsii_type="@cdktf/provider-azurerm.DataAzurermStorageManagementPolicyRuleActionsSnapshot",
):
    def __init__(
        self,
        terraform_resource: cdktf.ITerraformResource,
        terraform_attribute: builtins.str,
        index: builtins.str,
    ) -> None:
        """
        :param terraform_resource: -
        :param terraform_attribute: -
        :param index: -

        :stability: experimental
        """
        jsii.create(DataAzurermStorageManagementPolicyRuleActionsSnapshot, self, [terraform_resource, terraform_attribute, index])

    @builtins.property # type: ignore
    @jsii.member(jsii_name="deleteAfterDaysSinceCreationGreaterThan")
    def delete_after_days_since_creation_greater_than(self) -> jsii.Number:
        return jsii.get(self, "deleteAfterDaysSinceCreationGreaterThan")


class DataAzurermStorageManagementPolicyRuleFilters(
    cdktf.ComplexComputedList,
    metaclass=jsii.JSIIMeta,
    jsii_type="@cdktf/provider-azurerm.DataAzurermStorageManagementPolicyRuleFilters",
):
    def __init__(
        self,
        terraform_resource: cdktf.ITerraformResource,
        terraform_attribute: builtins.str,
        index: builtins.str,
    ) -> None:
        """
        :param terraform_resource: -
        :param terraform_attribute: -
        :param index: -

        :stability: experimental
        """
        jsii.create(DataAzurermStorageManagementPolicyRuleFilters, self, [terraform_resource, terraform_attribute, index])

    @builtins.property # type: ignore
    @jsii.member(jsii_name="blobTypes")
    def blob_types(self) -> typing.List[builtins.str]:
        return jsii.get(self, "blobTypes")

    @builtins.property # type: ignore
    @jsii.member(jsii_name="prefixMatch")
    def prefix_match(self) -> typing.List[builtins.str]:
        return jsii.get(self, "prefixMatch")


@jsii.data_type(
    jsii_type="@cdktf/provider-azurerm.DataAzurermStorageManagementPolicyTimeouts",
    jsii_struct_bases=[],
    name_mapping={"read": "read"},
)
class DataAzurermStorageManagementPolicyTimeouts:
    def __init__(self, *, read: typing.Optional[builtins.str] = None) -> None:
        """
        :param read: 
        """
        self._values: typing.Dict[str, typing.Any] = {}
        if read is not None:
            self._values["read"] = read

    @builtins.property
    def read(self) -> typing.Optional[builtins.str]:
        result = self._values.get("read")
        return result

    def __eq__(self, rhs: typing.Any) -> builtins.bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs: typing.Any) -> builtins.bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return "DataAzurermStorageManagementPolicyTimeouts(%s)" % ", ".join(
            k + "=" + repr(v) for k, v in self._values.items()
        )


class DataAzurermStreamAnalyticsJob(
    cdktf.TerraformDataSource,
    metaclass=jsii.JSIIMeta,
    jsii_type="@cdktf/provider-azurerm.DataAzurermStreamAnalyticsJob",
):
    def __init__(
        self,
        scope: constructs.Construct,
        id: builtins.str,
        *,
        name: builtins.str,
        resource_group_name: builtins.str,
        timeouts: typing.Optional["DataAzurermStreamAnalyticsJobTimeouts"] = None,
        count: typing.Optional[jsii.Number] = None,
        depends_on: typing.Optional[typing.List[cdktf.TerraformResource]] = None,
        lifecycle: typing.Optional[cdktf.TerraformResourceLifecycle] = None,
        provider: typing.Optional[cdktf.TerraformProvider] = None,
    ) -> None:
        """
        :param scope: -
        :param id: -
        :param name: 
        :param resource_group_name: 
        :param timeouts: timeouts block.
        :param count: 
        :param depends_on: 
        :param lifecycle: 
        :param provider: 
        """
        config = DataAzurermStreamAnalyticsJobConfig(
            name=name,
            resource_group_name=resource_group_name,
            timeouts=timeouts,
            count=count,
            depends_on=depends_on,
            lifecycle=lifecycle,
            provider=provider,
        )

        jsii.create(DataAzurermStreamAnalyticsJob, self, [scope, id, config])

    @jsii.member(jsii_name="synthesizeAttributes")
    def _synthesize_attributes(self) -> typing.Mapping[builtins.str, typing.Any]:
        return jsii.invoke(self, "synthesizeAttributes", [])

    @builtins.property # type: ignore
    @jsii.member(jsii_name="compatibilityLevel")
    def compatibility_level(self) -> builtins.str:
        return jsii.get(self, "compatibilityLevel")

    @builtins.property # type: ignore
    @jsii.member(jsii_name="dataLocale")
    def data_locale(self) -> builtins.str:
        return jsii.get(self, "dataLocale")

    @builtins.property # type: ignore
    @jsii.member(jsii_name="eventsLateArrivalMaxDelayInSeconds")
    def events_late_arrival_max_delay_in_seconds(self) -> jsii.Number:
        return jsii.get(self, "eventsLateArrivalMaxDelayInSeconds")

    @builtins.property # type: ignore
    @jsii.member(jsii_name="eventsOutOfOrderMaxDelayInSeconds")
    def events_out_of_order_max_delay_in_seconds(self) -> jsii.Number:
        return jsii.get(self, "eventsOutOfOrderMaxDelayInSeconds")

    @builtins.property # type: ignore
    @jsii.member(jsii_name="eventsOutOfOrderPolicy")
    def events_out_of_order_policy(self) -> builtins.str:
        return jsii.get(self, "eventsOutOfOrderPolicy")

    @builtins.property # type: ignore
    @jsii.member(jsii_name="jobId")
    def job_id(self) -> builtins.str:
        return jsii.get(self, "jobId")

    @builtins.property # type: ignore
    @jsii.member(jsii_name="location")
    def location(self) -> builtins.str:
        return jsii.get(self, "location")

    @builtins.property # type: ignore
    @jsii.member(jsii_name="outputErrorPolicy")
    def output_error_policy(self) -> builtins.str:
        return jsii.get(self, "outputErrorPolicy")

    @builtins.property # type: ignore
    @jsii.member(jsii_name="streamingUnits")
    def streaming_units(self) -> jsii.Number:
        return jsii.get(self, "streamingUnits")

    @builtins.property # type: ignore
    @jsii.member(jsii_name="transformationQuery")
    def transformation_query(self) -> builtins.str:
        return jsii.get(self, "transformationQuery")

    @builtins.property # type: ignore
    @jsii.member(jsii_name="name")
    def name(self) -> builtins.str:
        return jsii.get(self, "name")

    @name.setter # type: ignore
    def name(self, value: builtins.str) -> None:
        jsii.set(self, "name", value)

    @builtins.property # type: ignore
    @jsii.member(jsii_name="resourceGroupName")
    def resource_group_name(self) -> builtins.str:
        return jsii.get(self, "resourceGroupName")

    @resource_group_name.setter # type: ignore
    def resource_group_name(self, value: builtins.str) -> None:
        jsii.set(self, "resourceGroupName", value)

    @builtins.property # type: ignore
    @jsii.member(jsii_name="id")
    def id(self) -> typing.Optional[builtins.str]:
        return jsii.get(self, "id")

    @id.setter # type: ignore
    def id(self, value: typing.Optional[builtins.str]) -> None:
        jsii.set(self, "id", value)

    @builtins.property # type: ignore
    @jsii.member(jsii_name="timeouts")
    def timeouts(self) -> typing.Optional["DataAzurermStreamAnalyticsJobTimeouts"]:
        return jsii.get(self, "timeouts")

    @timeouts.setter # type: ignore
    def timeouts(
        self,
        value: typing.Optional["DataAzurermStreamAnalyticsJobTimeouts"],
    ) -> None:
        jsii.set(self, "timeouts", value)


@jsii.data_type(
    jsii_type="@cdktf/provider-azurerm.DataAzurermStreamAnalyticsJobConfig",
    jsii_struct_bases=[cdktf.TerraformMetaArguments],
    name_mapping={
        "count": "count",
        "depends_on": "dependsOn",
        "lifecycle": "lifecycle",
        "provider": "provider",
        "name": "name",
        "resource_group_name": "resourceGroupName",
        "timeouts": "timeouts",
    },
)
class DataAzurermStreamAnalyticsJobConfig(cdktf.TerraformMetaArguments):
    def __init__(
        self,
        *,
        count: typing.Optional[jsii.Number] = None,
        depends_on: typing.Optional[typing.List[cdktf.TerraformResource]] = None,
        lifecycle: typing.Optional[cdktf.TerraformResourceLifecycle] = None,
        provider: typing.Optional[cdktf.TerraformProvider] = None,
        name: builtins.str,
        resource_group_name: builtins.str,
        timeouts: typing.Optional["DataAzurermStreamAnalyticsJobTimeouts"] = None,
    ) -> None:
        """
        :param count: 
        :param depends_on: 
        :param lifecycle: 
        :param provider: 
        :param name: 
        :param resource_group_name: 
        :param timeouts: timeouts block.
        """
        if isinstance(lifecycle, dict):
            lifecycle = cdktf.TerraformResourceLifecycle(**lifecycle)
        if isinstance(timeouts, dict):
            timeouts = DataAzurermStreamAnalyticsJobTimeouts(**timeouts)
        self._values: typing.Dict[str, typing.Any] = {
            "name": name,
            "resource_group_name": resource_group_name,
        }
        if count is not None:
            self._values["count"] = count
        if depends_on is not None:
            self._values["depends_on"] = depends_on
        if lifecycle is not None:
            self._values["lifecycle"] = lifecycle
        if provider is not None:
            self._values["provider"] = provider
        if timeouts is not None:
            self._values["timeouts"] = timeouts

    @builtins.property
    def count(self) -> typing.Optional[jsii.Number]:
        """
        :stability: experimental
        """
        result = self._values.get("count")
        return result

    @builtins.property
    def depends_on(self) -> typing.Optional[typing.List[cdktf.TerraformResource]]:
        """
        :stability: experimental
        """
        result = self._values.get("depends_on")
        return result

    @builtins.property
    def lifecycle(self) -> typing.Optional[cdktf.TerraformResourceLifecycle]:
        """
        :stability: experimental
        """
        result = self._values.get("lifecycle")
        return result

    @builtins.property
    def provider(self) -> typing.Optional[cdktf.TerraformProvider]:
        """
        :stability: experimental
        """
        result = self._values.get("provider")
        return result

    @builtins.property
    def name(self) -> builtins.str:
        result = self._values.get("name")
        assert result is not None, "Required property 'name' is missing"
        return result

    @builtins.property
    def resource_group_name(self) -> builtins.str:
        result = self._values.get("resource_group_name")
        assert result is not None, "Required property 'resource_group_name' is missing"
        return result

    @builtins.property
    def timeouts(self) -> typing.Optional["DataAzurermStreamAnalyticsJobTimeouts"]:
        """timeouts block."""
        result = self._values.get("timeouts")
        return result

    def __eq__(self, rhs: typing.Any) -> builtins.bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs: typing.Any) -> builtins.bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return "DataAzurermStreamAnalyticsJobConfig(%s)" % ", ".join(
            k + "=" + repr(v) for k, v in self._values.items()
        )


@jsii.data_type(
    jsii_type="@cdktf/provider-azurerm.DataAzurermStreamAnalyticsJobTimeouts",
    jsii_struct_bases=[],
    name_mapping={"read": "read"},
)
class DataAzurermStreamAnalyticsJobTimeouts:
    def __init__(self, *, read: typing.Optional[builtins.str] = None) -> None:
        """
        :param read: 
        """
        self._values: typing.Dict[str, typing.Any] = {}
        if read is not None:
            self._values["read"] = read

    @builtins.property
    def read(self) -> typing.Optional[builtins.str]:
        result = self._values.get("read")
        return result

    def __eq__(self, rhs: typing.Any) -> builtins.bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs: typing.Any) -> builtins.bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return "DataAzurermStreamAnalyticsJobTimeouts(%s)" % ", ".join(
            k + "=" + repr(v) for k, v in self._values.items()
        )


class DataAzurermSubnet(
    cdktf.TerraformDataSource,
    metaclass=jsii.JSIIMeta,
    jsii_type="@cdktf/provider-azurerm.DataAzurermSubnet",
):
    def __init__(
        self,
        scope: constructs.Construct,
        id: builtins.str,
        *,
        name: builtins.str,
        resource_group_name: builtins.str,
        virtual_network_name: builtins.str,
        timeouts: typing.Optional["DataAzurermSubnetTimeouts"] = None,
        count: typing.Optional[jsii.Number] = None,
        depends_on: typing.Optional[typing.List[cdktf.TerraformResource]] = None,
        lifecycle: typing.Optional[cdktf.TerraformResourceLifecycle] = None,
        provider: typing.Optional[cdktf.TerraformProvider] = None,
    ) -> None:
        """
        :param scope: -
        :param id: -
        :param name: 
        :param resource_group_name: 
        :param virtual_network_name: 
        :param timeouts: timeouts block.
        :param count: 
        :param depends_on: 
        :param lifecycle: 
        :param provider: 
        """
        config = DataAzurermSubnetConfig(
            name=name,
            resource_group_name=resource_group_name,
            virtual_network_name=virtual_network_name,
            timeouts=timeouts,
            count=count,
            depends_on=depends_on,
            lifecycle=lifecycle,
            provider=provider,
        )

        jsii.create(DataAzurermSubnet, self, [scope, id, config])

    @jsii.member(jsii_name="synthesizeAttributes")
    def _synthesize_attributes(self) -> typing.Mapping[builtins.str, typing.Any]:
        return jsii.invoke(self, "synthesizeAttributes", [])

    @builtins.property # type: ignore
    @jsii.member(jsii_name="addressPrefix")
    def address_prefix(self) -> builtins.str:
        return jsii.get(self, "addressPrefix")

    @builtins.property # type: ignore
    @jsii.member(jsii_name="enforcePrivateLinkEndpointNetworkPolicies")
    def enforce_private_link_endpoint_network_policies(self) -> builtins.bool:
        return jsii.get(self, "enforcePrivateLinkEndpointNetworkPolicies")

    @builtins.property # type: ignore
    @jsii.member(jsii_name="enforcePrivateLinkServiceNetworkPolicies")
    def enforce_private_link_service_network_policies(self) -> builtins.bool:
        return jsii.get(self, "enforcePrivateLinkServiceNetworkPolicies")

    @builtins.property # type: ignore
    @jsii.member(jsii_name="networkSecurityGroupId")
    def network_security_group_id(self) -> builtins.str:
        return jsii.get(self, "networkSecurityGroupId")

    @builtins.property # type: ignore
    @jsii.member(jsii_name="routeTableId")
    def route_table_id(self) -> builtins.str:
        return jsii.get(self, "routeTableId")

    @builtins.property # type: ignore
    @jsii.member(jsii_name="serviceEndpoints")
    def service_endpoints(self) -> typing.List[builtins.str]:
        return jsii.get(self, "serviceEndpoints")

    @builtins.property # type: ignore
    @jsii.member(jsii_name="name")
    def name(self) -> builtins.str:
        return jsii.get(self, "name")

    @name.setter # type: ignore
    def name(self, value: builtins.str) -> None:
        jsii.set(self, "name", value)

    @builtins.property # type: ignore
    @jsii.member(jsii_name="resourceGroupName")
    def resource_group_name(self) -> builtins.str:
        return jsii.get(self, "resourceGroupName")

    @resource_group_name.setter # type: ignore
    def resource_group_name(self, value: builtins.str) -> None:
        jsii.set(self, "resourceGroupName", value)

    @builtins.property # type: ignore
    @jsii.member(jsii_name="virtualNetworkName")
    def virtual_network_name(self) -> builtins.str:
        return jsii.get(self, "virtualNetworkName")

    @virtual_network_name.setter # type: ignore
    def virtual_network_name(self, value: builtins.str) -> None:
        jsii.set(self, "virtualNetworkName", value)

    @builtins.property # type: ignore
    @jsii.member(jsii_name="id")
    def id(self) -> typing.Optional[builtins.str]:
        return jsii.get(self, "id")

    @id.setter # type: ignore
    def id(self, value: typing.Optional[builtins.str]) -> None:
        jsii.set(self, "id", value)

    @builtins.property # type: ignore
    @jsii.member(jsii_name="timeouts")
    def timeouts(self) -> typing.Optional["DataAzurermSubnetTimeouts"]:
        return jsii.get(self, "timeouts")

    @timeouts.setter # type: ignore
    def timeouts(self, value: typing.Optional["DataAzurermSubnetTimeouts"]) -> None:
        jsii.set(self, "timeouts", value)


@jsii.data_type(
    jsii_type="@cdktf/provider-azurerm.DataAzurermSubnetConfig",
    jsii_struct_bases=[cdktf.TerraformMetaArguments],
    name_mapping={
        "count": "count",
        "depends_on": "dependsOn",
        "lifecycle": "lifecycle",
        "provider": "provider",
        "name": "name",
        "resource_group_name": "resourceGroupName",
        "virtual_network_name": "virtualNetworkName",
        "timeouts": "timeouts",
    },
)
class DataAzurermSubnetConfig(cdktf.TerraformMetaArguments):
    def __init__(
        self,
        *,
        count: typing.Optional[jsii.Number] = None,
        depends_on: typing.Optional[typing.List[cdktf.TerraformResource]] = None,
        lifecycle: typing.Optional[cdktf.TerraformResourceLifecycle] = None,
        provider: typing.Optional[cdktf.TerraformProvider] = None,
        name: builtins.str,
        resource_group_name: builtins.str,
        virtual_network_name: builtins.str,
        timeouts: typing.Optional["DataAzurermSubnetTimeouts"] = None,
    ) -> None:
        """
        :param count: 
        :param depends_on: 
        :param lifecycle: 
        :param provider: 
        :param name: 
        :param resource_group_name: 
        :param virtual_network_name: 
        :param timeouts: timeouts block.
        """
        if isinstance(lifecycle, dict):
            lifecycle = cdktf.TerraformResourceLifecycle(**lifecycle)
        if isinstance(timeouts, dict):
            timeouts = DataAzurermSubnetTimeouts(**timeouts)
        self._values: typing.Dict[str, typing.Any] = {
            "name": name,
            "resource_group_name": resource_group_name,
            "virtual_network_name": virtual_network_name,
        }
        if count is not None:
            self._values["count"] = count
        if depends_on is not None:
            self._values["depends_on"] = depends_on
        if lifecycle is not None:
            self._values["lifecycle"] = lifecycle
        if provider is not None:
            self._values["provider"] = provider
        if timeouts is not None:
            self._values["timeouts"] = timeouts

    @builtins.property
    def count(self) -> typing.Optional[jsii.Number]:
        """
        :stability: experimental
        """
        result = self._values.get("count")
        return result

    @builtins.property
    def depends_on(self) -> typing.Optional[typing.List[cdktf.TerraformResource]]:
        """
        :stability: experimental
        """
        result = self._values.get("depends_on")
        return result

    @builtins.property
    def lifecycle(self) -> typing.Optional[cdktf.TerraformResourceLifecycle]:
        """
        :stability: experimental
        """
        result = self._values.get("lifecycle")
        return result

    @builtins.property
    def provider(self) -> typing.Optional[cdktf.TerraformProvider]:
        """
        :stability: experimental
        """
        result = self._values.get("provider")
        return result

    @builtins.property
    def name(self) -> builtins.str:
        result = self._values.get("name")
        assert result is not None, "Required property 'name' is missing"
        return result

    @builtins.property
    def resource_group_name(self) -> builtins.str:
        result = self._values.get("resource_group_name")
        assert result is not None, "Required property 'resource_group_name' is missing"
        return result

    @builtins.property
    def virtual_network_name(self) -> builtins.str:
        result = self._values.get("virtual_network_name")
        assert result is not None, "Required property 'virtual_network_name' is missing"
        return result

    @builtins.property
    def timeouts(self) -> typing.Optional["DataAzurermSubnetTimeouts"]:
        """timeouts block."""
        result = self._values.get("timeouts")
        return result

    def __eq__(self, rhs: typing.Any) -> builtins.bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs: typing.Any) -> builtins.bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return "DataAzurermSubnetConfig(%s)" % ", ".join(
            k + "=" + repr(v) for k, v in self._values.items()
        )


@jsii.data_type(
    jsii_type="@cdktf/provider-azurerm.DataAzurermSubnetTimeouts",
    jsii_struct_bases=[],
    name_mapping={"read": "read"},
)
class DataAzurermSubnetTimeouts:
    def __init__(self, *, read: typing.Optional[builtins.str] = None) -> None:
        """
        :param read: 
        """
        self._values: typing.Dict[str, typing.Any] = {}
        if read is not None:
            self._values["read"] = read

    @builtins.property
    def read(self) -> typing.Optional[builtins.str]:
        result = self._values.get("read")
        return result

    def __eq__(self, rhs: typing.Any) -> builtins.bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs: typing.Any) -> builtins.bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return "DataAzurermSubnetTimeouts(%s)" % ", ".join(
            k + "=" + repr(v) for k, v in self._values.items()
        )


class DataAzurermSubscription(
    cdktf.TerraformDataSource,
    metaclass=jsii.JSIIMeta,
    jsii_type="@cdktf/provider-azurerm.DataAzurermSubscription",
):
    def __init__(
        self,
        scope: constructs.Construct,
        id: builtins.str,
        *,
        subscription_id: typing.Optional[builtins.str] = None,
        timeouts: typing.Optional["DataAzurermSubscriptionTimeouts"] = None,
        count: typing.Optional[jsii.Number] = None,
        depends_on: typing.Optional[typing.List[cdktf.TerraformResource]] = None,
        lifecycle: typing.Optional[cdktf.TerraformResourceLifecycle] = None,
        provider: typing.Optional[cdktf.TerraformProvider] = None,
    ) -> None:
        """
        :param scope: -
        :param id: -
        :param subscription_id: 
        :param timeouts: timeouts block.
        :param count: 
        :param depends_on: 
        :param lifecycle: 
        :param provider: 
        """
        config = DataAzurermSubscriptionConfig(
            subscription_id=subscription_id,
            timeouts=timeouts,
            count=count,
            depends_on=depends_on,
            lifecycle=lifecycle,
            provider=provider,
        )

        jsii.create(DataAzurermSubscription, self, [scope, id, config])

    @jsii.member(jsii_name="synthesizeAttributes")
    def _synthesize_attributes(self) -> typing.Mapping[builtins.str, typing.Any]:
        return jsii.invoke(self, "synthesizeAttributes", [])

    @builtins.property # type: ignore
    @jsii.member(jsii_name="displayName")
    def display_name(self) -> builtins.str:
        return jsii.get(self, "displayName")

    @builtins.property # type: ignore
    @jsii.member(jsii_name="locationPlacementId")
    def location_placement_id(self) -> builtins.str:
        return jsii.get(self, "locationPlacementId")

    @builtins.property # type: ignore
    @jsii.member(jsii_name="quotaId")
    def quota_id(self) -> builtins.str:
        return jsii.get(self, "quotaId")

    @builtins.property # type: ignore
    @jsii.member(jsii_name="spendingLimit")
    def spending_limit(self) -> builtins.str:
        return jsii.get(self, "spendingLimit")

    @builtins.property # type: ignore
    @jsii.member(jsii_name="state")
    def state(self) -> builtins.str:
        return jsii.get(self, "state")

    @builtins.property # type: ignore
    @jsii.member(jsii_name="tenantId")
    def tenant_id(self) -> builtins.str:
        return jsii.get(self, "tenantId")

    @builtins.property # type: ignore
    @jsii.member(jsii_name="id")
    def id(self) -> typing.Optional[builtins.str]:
        return jsii.get(self, "id")

    @id.setter # type: ignore
    def id(self, value: typing.Optional[builtins.str]) -> None:
        jsii.set(self, "id", value)

    @builtins.property # type: ignore
    @jsii.member(jsii_name="subscriptionId")
    def subscription_id(self) -> typing.Optional[builtins.str]:
        return jsii.get(self, "subscriptionId")

    @subscription_id.setter # type: ignore
    def subscription_id(self, value: typing.Optional[builtins.str]) -> None:
        jsii.set(self, "subscriptionId", value)

    @builtins.property # type: ignore
    @jsii.member(jsii_name="timeouts")
    def timeouts(self) -> typing.Optional["DataAzurermSubscriptionTimeouts"]:
        return jsii.get(self, "timeouts")

    @timeouts.setter # type: ignore
    def timeouts(
        self,
        value: typing.Optional["DataAzurermSubscriptionTimeouts"],
    ) -> None:
        jsii.set(self, "timeouts", value)


@jsii.data_type(
    jsii_type="@cdktf/provider-azurerm.DataAzurermSubscriptionConfig",
    jsii_struct_bases=[cdktf.TerraformMetaArguments],
    name_mapping={
        "count": "count",
        "depends_on": "dependsOn",
        "lifecycle": "lifecycle",
        "provider": "provider",
        "subscription_id": "subscriptionId",
        "timeouts": "timeouts",
    },
)
class DataAzurermSubscriptionConfig(cdktf.TerraformMetaArguments):
    def __init__(
        self,
        *,
        count: typing.Optional[jsii.Number] = None,
        depends_on: typing.Optional[typing.List[cdktf.TerraformResource]] = None,
        lifecycle: typing.Optional[cdktf.TerraformResourceLifecycle] = None,
        provider: typing.Optional[cdktf.TerraformProvider] = None,
        subscription_id: typing.Optional[builtins.str] = None,
        timeouts: typing.Optional["DataAzurermSubscriptionTimeouts"] = None,
    ) -> None:
        """
        :param count: 
        :param depends_on: 
        :param lifecycle: 
        :param provider: 
        :param subscription_id: 
        :param timeouts: timeouts block.
        """
        if isinstance(lifecycle, dict):
            lifecycle = cdktf.TerraformResourceLifecycle(**lifecycle)
        if isinstance(timeouts, dict):
            timeouts = DataAzurermSubscriptionTimeouts(**timeouts)
        self._values: typing.Dict[str, typing.Any] = {}
        if count is not None:
            self._values["count"] = count
        if depends_on is not None:
            self._values["depends_on"] = depends_on
        if lifecycle is not None:
            self._values["lifecycle"] = lifecycle
        if provider is not None:
            self._values["provider"] = provider
        if subscription_id is not None:
            self._values["subscription_id"] = subscription_id
        if timeouts is not None:
            self._values["timeouts"] = timeouts

    @builtins.property
    def count(self) -> typing.Optional[jsii.Number]:
        """
        :stability: experimental
        """
        result = self._values.get("count")
        return result

    @builtins.property
    def depends_on(self) -> typing.Optional[typing.List[cdktf.TerraformResource]]:
        """
        :stability: experimental
        """
        result = self._values.get("depends_on")
        return result

    @builtins.property
    def lifecycle(self) -> typing.Optional[cdktf.TerraformResourceLifecycle]:
        """
        :stability: experimental
        """
        result = self._values.get("lifecycle")
        return result

    @builtins.property
    def provider(self) -> typing.Optional[cdktf.TerraformProvider]:
        """
        :stability: experimental
        """
        result = self._values.get("provider")
        return result

    @builtins.property
    def subscription_id(self) -> typing.Optional[builtins.str]:
        result = self._values.get("subscription_id")
        return result

    @builtins.property
    def timeouts(self) -> typing.Optional["DataAzurermSubscriptionTimeouts"]:
        """timeouts block."""
        result = self._values.get("timeouts")
        return result

    def __eq__(self, rhs: typing.Any) -> builtins.bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs: typing.Any) -> builtins.bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return "DataAzurermSubscriptionConfig(%s)" % ", ".join(
            k + "=" + repr(v) for k, v in self._values.items()
        )


@jsii.data_type(
    jsii_type="@cdktf/provider-azurerm.DataAzurermSubscriptionTimeouts",
    jsii_struct_bases=[],
    name_mapping={"read": "read"},
)
class DataAzurermSubscriptionTimeouts:
    def __init__(self, *, read: typing.Optional[builtins.str] = None) -> None:
        """
        :param read: 
        """
        self._values: typing.Dict[str, typing.Any] = {}
        if read is not None:
            self._values["read"] = read

    @builtins.property
    def read(self) -> typing.Optional[builtins.str]:
        result = self._values.get("read")
        return result

    def __eq__(self, rhs: typing.Any) -> builtins.bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs: typing.Any) -> builtins.bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return "DataAzurermSubscriptionTimeouts(%s)" % ", ".join(
            k + "=" + repr(v) for k, v in self._values.items()
        )


class DataAzurermSubscriptions(
    cdktf.TerraformDataSource,
    metaclass=jsii.JSIIMeta,
    jsii_type="@cdktf/provider-azurerm.DataAzurermSubscriptions",
):
    def __init__(
        self,
        scope: constructs.Construct,
        id: builtins.str,
        *,
        display_name_contains: typing.Optional[builtins.str] = None,
        display_name_prefix: typing.Optional[builtins.str] = None,
        timeouts: typing.Optional["DataAzurermSubscriptionsTimeouts"] = None,
        count: typing.Optional[jsii.Number] = None,
        depends_on: typing.Optional[typing.List[cdktf.TerraformResource]] = None,
        lifecycle: typing.Optional[cdktf.TerraformResourceLifecycle] = None,
        provider: typing.Optional[cdktf.TerraformProvider] = None,
    ) -> None:
        """
        :param scope: -
        :param id: -
        :param display_name_contains: 
        :param display_name_prefix: 
        :param timeouts: timeouts block.
        :param count: 
        :param depends_on: 
        :param lifecycle: 
        :param provider: 
        """
        config = DataAzurermSubscriptionsConfig(
            display_name_contains=display_name_contains,
            display_name_prefix=display_name_prefix,
            timeouts=timeouts,
            count=count,
            depends_on=depends_on,
            lifecycle=lifecycle,
            provider=provider,
        )

        jsii.create(DataAzurermSubscriptions, self, [scope, id, config])

    @jsii.member(jsii_name="subscriptions")
    def subscriptions(
        self,
        index: builtins.str,
    ) -> "DataAzurermSubscriptionsSubscriptions":
        """
        :param index: -
        """
        return jsii.invoke(self, "subscriptions", [index])

    @jsii.member(jsii_name="synthesizeAttributes")
    def _synthesize_attributes(self) -> typing.Mapping[builtins.str, typing.Any]:
        return jsii.invoke(self, "synthesizeAttributes", [])

    @builtins.property # type: ignore
    @jsii.member(jsii_name="displayNameContains")
    def display_name_contains(self) -> typing.Optional[builtins.str]:
        return jsii.get(self, "displayNameContains")

    @display_name_contains.setter # type: ignore
    def display_name_contains(self, value: typing.Optional[builtins.str]) -> None:
        jsii.set(self, "displayNameContains", value)

    @builtins.property # type: ignore
    @jsii.member(jsii_name="displayNamePrefix")
    def display_name_prefix(self) -> typing.Optional[builtins.str]:
        return jsii.get(self, "displayNamePrefix")

    @display_name_prefix.setter # type: ignore
    def display_name_prefix(self, value: typing.Optional[builtins.str]) -> None:
        jsii.set(self, "displayNamePrefix", value)

    @builtins.property # type: ignore
    @jsii.member(jsii_name="id")
    def id(self) -> typing.Optional[builtins.str]:
        return jsii.get(self, "id")

    @id.setter # type: ignore
    def id(self, value: typing.Optional[builtins.str]) -> None:
        jsii.set(self, "id", value)

    @builtins.property # type: ignore
    @jsii.member(jsii_name="timeouts")
    def timeouts(self) -> typing.Optional["DataAzurermSubscriptionsTimeouts"]:
        return jsii.get(self, "timeouts")

    @timeouts.setter # type: ignore
    def timeouts(
        self,
        value: typing.Optional["DataAzurermSubscriptionsTimeouts"],
    ) -> None:
        jsii.set(self, "timeouts", value)


@jsii.data_type(
    jsii_type="@cdktf/provider-azurerm.DataAzurermSubscriptionsConfig",
    jsii_struct_bases=[cdktf.TerraformMetaArguments],
    name_mapping={
        "count": "count",
        "depends_on": "dependsOn",
        "lifecycle": "lifecycle",
        "provider": "provider",
        "display_name_contains": "displayNameContains",
        "display_name_prefix": "displayNamePrefix",
        "timeouts": "timeouts",
    },
)
class DataAzurermSubscriptionsConfig(cdktf.TerraformMetaArguments):
    def __init__(
        self,
        *,
        count: typing.Optional[jsii.Number] = None,
        depends_on: typing.Optional[typing.List[cdktf.TerraformResource]] = None,
        lifecycle: typing.Optional[cdktf.TerraformResourceLifecycle] = None,
        provider: typing.Optional[cdktf.TerraformProvider] = None,
        display_name_contains: typing.Optional[builtins.str] = None,
        display_name_prefix: typing.Optional[builtins.str] = None,
        timeouts: typing.Optional["DataAzurermSubscriptionsTimeouts"] = None,
    ) -> None:
        """
        :param count: 
        :param depends_on: 
        :param lifecycle: 
        :param provider: 
        :param display_name_contains: 
        :param display_name_prefix: 
        :param timeouts: timeouts block.
        """
        if isinstance(lifecycle, dict):
            lifecycle = cdktf.TerraformResourceLifecycle(**lifecycle)
        if isinstance(timeouts, dict):
            timeouts = DataAzurermSubscriptionsTimeouts(**timeouts)
        self._values: typing.Dict[str, typing.Any] = {}
        if count is not None:
            self._values["count"] = count
        if depends_on is not None:
            self._values["depends_on"] = depends_on
        if lifecycle is not None:
            self._values["lifecycle"] = lifecycle
        if provider is not None:
            self._values["provider"] = provider
        if display_name_contains is not None:
            self._values["display_name_contains"] = display_name_contains
        if display_name_prefix is not None:
            self._values["display_name_prefix"] = display_name_prefix
        if timeouts is not None:
            self._values["timeouts"] = timeouts

    @builtins.property
    def count(self) -> typing.Optional[jsii.Number]:
        """
        :stability: experimental
        """
        result = self._values.get("count")
        return result

    @builtins.property
    def depends_on(self) -> typing.Optional[typing.List[cdktf.TerraformResource]]:
        """
        :stability: experimental
        """
        result = self._values.get("depends_on")
        return result

    @builtins.property
    def lifecycle(self) -> typing.Optional[cdktf.TerraformResourceLifecycle]:
        """
        :stability: experimental
        """
        result = self._values.get("lifecycle")
        return result

    @builtins.property
    def provider(self) -> typing.Optional[cdktf.TerraformProvider]:
        """
        :stability: experimental
        """
        result = self._values.get("provider")
        return result

    @builtins.property
    def display_name_contains(self) -> typing.Optional[builtins.str]:
        result = self._values.get("display_name_contains")
        return result

    @builtins.property
    def display_name_prefix(self) -> typing.Optional[builtins.str]:
        result = self._values.get("display_name_prefix")
        return result

    @builtins.property
    def timeouts(self) -> typing.Optional["DataAzurermSubscriptionsTimeouts"]:
        """timeouts block."""
        result = self._values.get("timeouts")
        return result

    def __eq__(self, rhs: typing.Any) -> builtins.bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs: typing.Any) -> builtins.bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return "DataAzurermSubscriptionsConfig(%s)" % ", ".join(
            k + "=" + repr(v) for k, v in self._values.items()
        )


class DataAzurermSubscriptionsSubscriptions(
    cdktf.ComplexComputedList,
    metaclass=jsii.JSIIMeta,
    jsii_type="@cdktf/provider-azurerm.DataAzurermSubscriptionsSubscriptions",
):
    def __init__(
        self,
        terraform_resource: cdktf.ITerraformResource,
        terraform_attribute: builtins.str,
        index: builtins.str,
    ) -> None:
        """
        :param terraform_resource: -
        :param terraform_attribute: -
        :param index: -

        :stability: experimental
        """
        jsii.create(DataAzurermSubscriptionsSubscriptions, self, [terraform_resource, terraform_attribute, index])

    @builtins.property # type: ignore
    @jsii.member(jsii_name="displayName")
    def display_name(self) -> builtins.str:
        return jsii.get(self, "displayName")

    @builtins.property # type: ignore
    @jsii.member(jsii_name="locationPlacementId")
    def location_placement_id(self) -> builtins.str:
        return jsii.get(self, "locationPlacementId")

    @builtins.property # type: ignore
    @jsii.member(jsii_name="quotaId")
    def quota_id(self) -> builtins.str:
        return jsii.get(self, "quotaId")

    @builtins.property # type: ignore
    @jsii.member(jsii_name="spendingLimit")
    def spending_limit(self) -> builtins.str:
        return jsii.get(self, "spendingLimit")

    @builtins.property # type: ignore
    @jsii.member(jsii_name="state")
    def state(self) -> builtins.str:
        return jsii.get(self, "state")

    @builtins.property # type: ignore
    @jsii.member(jsii_name="subscriptionId")
    def subscription_id(self) -> builtins.str:
        return jsii.get(self, "subscriptionId")

    @builtins.property # type: ignore
    @jsii.member(jsii_name="tenantId")
    def tenant_id(self) -> builtins.str:
        return jsii.get(self, "tenantId")


@jsii.data_type(
    jsii_type="@cdktf/provider-azurerm.DataAzurermSubscriptionsTimeouts",
    jsii_struct_bases=[],
    name_mapping={"read": "read"},
)
class DataAzurermSubscriptionsTimeouts:
    def __init__(self, *, read: typing.Optional[builtins.str] = None) -> None:
        """
        :param read: 
        """
        self._values: typing.Dict[str, typing.Any] = {}
        if read is not None:
            self._values["read"] = read

    @builtins.property
    def read(self) -> typing.Optional[builtins.str]:
        result = self._values.get("read")
        return result

    def __eq__(self, rhs: typing.Any) -> builtins.bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs: typing.Any) -> builtins.bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return "DataAzurermSubscriptionsTimeouts(%s)" % ", ".join(
            k + "=" + repr(v) for k, v in self._values.items()
        )


class DataAzurermTrafficManagerGeographicalLocation(
    cdktf.TerraformDataSource,
    metaclass=jsii.JSIIMeta,
    jsii_type="@cdktf/provider-azurerm.DataAzurermTrafficManagerGeographicalLocation",
):
    def __init__(
        self,
        scope: constructs.Construct,
        id: builtins.str,
        *,
        name: builtins.str,
        timeouts: typing.Optional["DataAzurermTrafficManagerGeographicalLocationTimeouts"] = None,
        count: typing.Optional[jsii.Number] = None,
        depends_on: typing.Optional[typing.List[cdktf.TerraformResource]] = None,
        lifecycle: typing.Optional[cdktf.TerraformResourceLifecycle] = None,
        provider: typing.Optional[cdktf.TerraformProvider] = None,
    ) -> None:
        """
        :param scope: -
        :param id: -
        :param name: 
        :param timeouts: timeouts block.
        :param count: 
        :param depends_on: 
        :param lifecycle: 
        :param provider: 
        """
        config = DataAzurermTrafficManagerGeographicalLocationConfig(
            name=name,
            timeouts=timeouts,
            count=count,
            depends_on=depends_on,
            lifecycle=lifecycle,
            provider=provider,
        )

        jsii.create(DataAzurermTrafficManagerGeographicalLocation, self, [scope, id, config])

    @jsii.member(jsii_name="synthesizeAttributes")
    def _synthesize_attributes(self) -> typing.Mapping[builtins.str, typing.Any]:
        return jsii.invoke(self, "synthesizeAttributes", [])

    @builtins.property # type: ignore
    @jsii.member(jsii_name="name")
    def name(self) -> builtins.str:
        return jsii.get(self, "name")

    @name.setter # type: ignore
    def name(self, value: builtins.str) -> None:
        jsii.set(self, "name", value)

    @builtins.property # type: ignore
    @jsii.member(jsii_name="id")
    def id(self) -> typing.Optional[builtins.str]:
        return jsii.get(self, "id")

    @id.setter # type: ignore
    def id(self, value: typing.Optional[builtins.str]) -> None:
        jsii.set(self, "id", value)

    @builtins.property # type: ignore
    @jsii.member(jsii_name="timeouts")
    def timeouts(
        self,
    ) -> typing.Optional["DataAzurermTrafficManagerGeographicalLocationTimeouts"]:
        return jsii.get(self, "timeouts")

    @timeouts.setter # type: ignore
    def timeouts(
        self,
        value: typing.Optional["DataAzurermTrafficManagerGeographicalLocationTimeouts"],
    ) -> None:
        jsii.set(self, "timeouts", value)


@jsii.data_type(
    jsii_type="@cdktf/provider-azurerm.DataAzurermTrafficManagerGeographicalLocationConfig",
    jsii_struct_bases=[cdktf.TerraformMetaArguments],
    name_mapping={
        "count": "count",
        "depends_on": "dependsOn",
        "lifecycle": "lifecycle",
        "provider": "provider",
        "name": "name",
        "timeouts": "timeouts",
    },
)
class DataAzurermTrafficManagerGeographicalLocationConfig(cdktf.TerraformMetaArguments):
    def __init__(
        self,
        *,
        count: typing.Optional[jsii.Number] = None,
        depends_on: typing.Optional[typing.List[cdktf.TerraformResource]] = None,
        lifecycle: typing.Optional[cdktf.TerraformResourceLifecycle] = None,
        provider: typing.Optional[cdktf.TerraformProvider] = None,
        name: builtins.str,
        timeouts: typing.Optional["DataAzurermTrafficManagerGeographicalLocationTimeouts"] = None,
    ) -> None:
        """
        :param count: 
        :param depends_on: 
        :param lifecycle: 
        :param provider: 
        :param name: 
        :param timeouts: timeouts block.
        """
        if isinstance(lifecycle, dict):
            lifecycle = cdktf.TerraformResourceLifecycle(**lifecycle)
        if isinstance(timeouts, dict):
            timeouts = DataAzurermTrafficManagerGeographicalLocationTimeouts(**timeouts)
        self._values: typing.Dict[str, typing.Any] = {
            "name": name,
        }
        if count is not None:
            self._values["count"] = count
        if depends_on is not None:
            self._values["depends_on"] = depends_on
        if lifecycle is not None:
            self._values["lifecycle"] = lifecycle
        if provider is not None:
            self._values["provider"] = provider
        if timeouts is not None:
            self._values["timeouts"] = timeouts

    @builtins.property
    def count(self) -> typing.Optional[jsii.Number]:
        """
        :stability: experimental
        """
        result = self._values.get("count")
        return result

    @builtins.property
    def depends_on(self) -> typing.Optional[typing.List[cdktf.TerraformResource]]:
        """
        :stability: experimental
        """
        result = self._values.get("depends_on")
        return result

    @builtins.property
    def lifecycle(self) -> typing.Optional[cdktf.TerraformResourceLifecycle]:
        """
        :stability: experimental
        """
        result = self._values.get("lifecycle")
        return result

    @builtins.property
    def provider(self) -> typing.Optional[cdktf.TerraformProvider]:
        """
        :stability: experimental
        """
        result = self._values.get("provider")
        return result

    @builtins.property
    def name(self) -> builtins.str:
        result = self._values.get("name")
        assert result is not None, "Required property 'name' is missing"
        return result

    @builtins.property
    def timeouts(
        self,
    ) -> typing.Optional["DataAzurermTrafficManagerGeographicalLocationTimeouts"]:
        """timeouts block."""
        result = self._values.get("timeouts")
        return result

    def __eq__(self, rhs: typing.Any) -> builtins.bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs: typing.Any) -> builtins.bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return "DataAzurermTrafficManagerGeographicalLocationConfig(%s)" % ", ".join(
            k + "=" + repr(v) for k, v in self._values.items()
        )


@jsii.data_type(
    jsii_type="@cdktf/provider-azurerm.DataAzurermTrafficManagerGeographicalLocationTimeouts",
    jsii_struct_bases=[],
    name_mapping={"read": "read"},
)
class DataAzurermTrafficManagerGeographicalLocationTimeouts:
    def __init__(self, *, read: typing.Optional[builtins.str] = None) -> None:
        """
        :param read: 
        """
        self._values: typing.Dict[str, typing.Any] = {}
        if read is not None:
            self._values["read"] = read

    @builtins.property
    def read(self) -> typing.Optional[builtins.str]:
        result = self._values.get("read")
        return result

    def __eq__(self, rhs: typing.Any) -> builtins.bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs: typing.Any) -> builtins.bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return "DataAzurermTrafficManagerGeographicalLocationTimeouts(%s)" % ", ".join(
            k + "=" + repr(v) for k, v in self._values.items()
        )


class DataAzurermUserAssignedIdentity(
    cdktf.TerraformDataSource,
    metaclass=jsii.JSIIMeta,
    jsii_type="@cdktf/provider-azurerm.DataAzurermUserAssignedIdentity",
):
    def __init__(
        self,
        scope: constructs.Construct,
        id: builtins.str,
        *,
        name: builtins.str,
        resource_group_name: builtins.str,
        timeouts: typing.Optional["DataAzurermUserAssignedIdentityTimeouts"] = None,
        count: typing.Optional[jsii.Number] = None,
        depends_on: typing.Optional[typing.List[cdktf.TerraformResource]] = None,
        lifecycle: typing.Optional[cdktf.TerraformResourceLifecycle] = None,
        provider: typing.Optional[cdktf.TerraformProvider] = None,
    ) -> None:
        """
        :param scope: -
        :param id: -
        :param name: 
        :param resource_group_name: 
        :param timeouts: timeouts block.
        :param count: 
        :param depends_on: 
        :param lifecycle: 
        :param provider: 
        """
        config = DataAzurermUserAssignedIdentityConfig(
            name=name,
            resource_group_name=resource_group_name,
            timeouts=timeouts,
            count=count,
            depends_on=depends_on,
            lifecycle=lifecycle,
            provider=provider,
        )

        jsii.create(DataAzurermUserAssignedIdentity, self, [scope, id, config])

    @jsii.member(jsii_name="synthesizeAttributes")
    def _synthesize_attributes(self) -> typing.Mapping[builtins.str, typing.Any]:
        return jsii.invoke(self, "synthesizeAttributes", [])

    @jsii.member(jsii_name="tags")
    def tags(self, key: builtins.str) -> builtins.str:
        """
        :param key: -
        """
        return jsii.invoke(self, "tags", [key])

    @builtins.property # type: ignore
    @jsii.member(jsii_name="clientId")
    def client_id(self) -> builtins.str:
        return jsii.get(self, "clientId")

    @builtins.property # type: ignore
    @jsii.member(jsii_name="location")
    def location(self) -> builtins.str:
        return jsii.get(self, "location")

    @builtins.property # type: ignore
    @jsii.member(jsii_name="principalId")
    def principal_id(self) -> builtins.str:
        return jsii.get(self, "principalId")

    @builtins.property # type: ignore
    @jsii.member(jsii_name="name")
    def name(self) -> builtins.str:
        return jsii.get(self, "name")

    @name.setter # type: ignore
    def name(self, value: builtins.str) -> None:
        jsii.set(self, "name", value)

    @builtins.property # type: ignore
    @jsii.member(jsii_name="resourceGroupName")
    def resource_group_name(self) -> builtins.str:
        return jsii.get(self, "resourceGroupName")

    @resource_group_name.setter # type: ignore
    def resource_group_name(self, value: builtins.str) -> None:
        jsii.set(self, "resourceGroupName", value)

    @builtins.property # type: ignore
    @jsii.member(jsii_name="id")
    def id(self) -> typing.Optional[builtins.str]:
        return jsii.get(self, "id")

    @id.setter # type: ignore
    def id(self, value: typing.Optional[builtins.str]) -> None:
        jsii.set(self, "id", value)

    @builtins.property # type: ignore
    @jsii.member(jsii_name="timeouts")
    def timeouts(self) -> typing.Optional["DataAzurermUserAssignedIdentityTimeouts"]:
        return jsii.get(self, "timeouts")

    @timeouts.setter # type: ignore
    def timeouts(
        self,
        value: typing.Optional["DataAzurermUserAssignedIdentityTimeouts"],
    ) -> None:
        jsii.set(self, "timeouts", value)


@jsii.data_type(
    jsii_type="@cdktf/provider-azurerm.DataAzurermUserAssignedIdentityConfig",
    jsii_struct_bases=[cdktf.TerraformMetaArguments],
    name_mapping={
        "count": "count",
        "depends_on": "dependsOn",
        "lifecycle": "lifecycle",
        "provider": "provider",
        "name": "name",
        "resource_group_name": "resourceGroupName",
        "timeouts": "timeouts",
    },
)
class DataAzurermUserAssignedIdentityConfig(cdktf.TerraformMetaArguments):
    def __init__(
        self,
        *,
        count: typing.Optional[jsii.Number] = None,
        depends_on: typing.Optional[typing.List[cdktf.TerraformResource]] = None,
        lifecycle: typing.Optional[cdktf.TerraformResourceLifecycle] = None,
        provider: typing.Optional[cdktf.TerraformProvider] = None,
        name: builtins.str,
        resource_group_name: builtins.str,
        timeouts: typing.Optional["DataAzurermUserAssignedIdentityTimeouts"] = None,
    ) -> None:
        """
        :param count: 
        :param depends_on: 
        :param lifecycle: 
        :param provider: 
        :param name: 
        :param resource_group_name: 
        :param timeouts: timeouts block.
        """
        if isinstance(lifecycle, dict):
            lifecycle = cdktf.TerraformResourceLifecycle(**lifecycle)
        if isinstance(timeouts, dict):
            timeouts = DataAzurermUserAssignedIdentityTimeouts(**timeouts)
        self._values: typing.Dict[str, typing.Any] = {
            "name": name,
            "resource_group_name": resource_group_name,
        }
        if count is not None:
            self._values["count"] = count
        if depends_on is not None:
            self._values["depends_on"] = depends_on
        if lifecycle is not None:
            self._values["lifecycle"] = lifecycle
        if provider is not None:
            self._values["provider"] = provider
        if timeouts is not None:
            self._values["timeouts"] = timeouts

    @builtins.property
    def count(self) -> typing.Optional[jsii.Number]:
        """
        :stability: experimental
        """
        result = self._values.get("count")
        return result

    @builtins.property
    def depends_on(self) -> typing.Optional[typing.List[cdktf.TerraformResource]]:
        """
        :stability: experimental
        """
        result = self._values.get("depends_on")
        return result

    @builtins.property
    def lifecycle(self) -> typing.Optional[cdktf.TerraformResourceLifecycle]:
        """
        :stability: experimental
        """
        result = self._values.get("lifecycle")
        return result

    @builtins.property
    def provider(self) -> typing.Optional[cdktf.TerraformProvider]:
        """
        :stability: experimental
        """
        result = self._values.get("provider")
        return result

    @builtins.property
    def name(self) -> builtins.str:
        result = self._values.get("name")
        assert result is not None, "Required property 'name' is missing"
        return result

    @builtins.property
    def resource_group_name(self) -> builtins.str:
        result = self._values.get("resource_group_name")
        assert result is not None, "Required property 'resource_group_name' is missing"
        return result

    @builtins.property
    def timeouts(self) -> typing.Optional["DataAzurermUserAssignedIdentityTimeouts"]:
        """timeouts block."""
        result = self._values.get("timeouts")
        return result

    def __eq__(self, rhs: typing.Any) -> builtins.bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs: typing.Any) -> builtins.bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return "DataAzurermUserAssignedIdentityConfig(%s)" % ", ".join(
            k + "=" + repr(v) for k, v in self._values.items()
        )


@jsii.data_type(
    jsii_type="@cdktf/provider-azurerm.DataAzurermUserAssignedIdentityTimeouts",
    jsii_struct_bases=[],
    name_mapping={"read": "read"},
)
class DataAzurermUserAssignedIdentityTimeouts:
    def __init__(self, *, read: typing.Optional[builtins.str] = None) -> None:
        """
        :param read: 
        """
        self._values: typing.Dict[str, typing.Any] = {}
        if read is not None:
            self._values["read"] = read

    @builtins.property
    def read(self) -> typing.Optional[builtins.str]:
        result = self._values.get("read")
        return result

    def __eq__(self, rhs: typing.Any) -> builtins.bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs: typing.Any) -> builtins.bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return "DataAzurermUserAssignedIdentityTimeouts(%s)" % ", ".join(
            k + "=" + repr(v) for k, v in self._values.items()
        )


class DataAzurermVirtualHub(
    cdktf.TerraformDataSource,
    metaclass=jsii.JSIIMeta,
    jsii_type="@cdktf/provider-azurerm.DataAzurermVirtualHub",
):
    def __init__(
        self,
        scope: constructs.Construct,
        id: builtins.str,
        *,
        name: builtins.str,
        resource_group_name: builtins.str,
        timeouts: typing.Optional["DataAzurermVirtualHubTimeouts"] = None,
        count: typing.Optional[jsii.Number] = None,
        depends_on: typing.Optional[typing.List[cdktf.TerraformResource]] = None,
        lifecycle: typing.Optional[cdktf.TerraformResourceLifecycle] = None,
        provider: typing.Optional[cdktf.TerraformProvider] = None,
    ) -> None:
        """
        :param scope: -
        :param id: -
        :param name: 
        :param resource_group_name: 
        :param timeouts: timeouts block.
        :param count: 
        :param depends_on: 
        :param lifecycle: 
        :param provider: 
        """
        config = DataAzurermVirtualHubConfig(
            name=name,
            resource_group_name=resource_group_name,
            timeouts=timeouts,
            count=count,
            depends_on=depends_on,
            lifecycle=lifecycle,
            provider=provider,
        )

        jsii.create(DataAzurermVirtualHub, self, [scope, id, config])

    @jsii.member(jsii_name="synthesizeAttributes")
    def _synthesize_attributes(self) -> typing.Mapping[builtins.str, typing.Any]:
        return jsii.invoke(self, "synthesizeAttributes", [])

    @jsii.member(jsii_name="tags")
    def tags(self, key: builtins.str) -> builtins.str:
        """
        :param key: -
        """
        return jsii.invoke(self, "tags", [key])

    @builtins.property # type: ignore
    @jsii.member(jsii_name="addressPrefix")
    def address_prefix(self) -> builtins.str:
        return jsii.get(self, "addressPrefix")

    @builtins.property # type: ignore
    @jsii.member(jsii_name="location")
    def location(self) -> builtins.str:
        return jsii.get(self, "location")

    @builtins.property # type: ignore
    @jsii.member(jsii_name="virtualWanId")
    def virtual_wan_id(self) -> builtins.str:
        return jsii.get(self, "virtualWanId")

    @builtins.property # type: ignore
    @jsii.member(jsii_name="name")
    def name(self) -> builtins.str:
        return jsii.get(self, "name")

    @name.setter # type: ignore
    def name(self, value: builtins.str) -> None:
        jsii.set(self, "name", value)

    @builtins.property # type: ignore
    @jsii.member(jsii_name="resourceGroupName")
    def resource_group_name(self) -> builtins.str:
        return jsii.get(self, "resourceGroupName")

    @resource_group_name.setter # type: ignore
    def resource_group_name(self, value: builtins.str) -> None:
        jsii.set(self, "resourceGroupName", value)

    @builtins.property # type: ignore
    @jsii.member(jsii_name="id")
    def id(self) -> typing.Optional[builtins.str]:
        return jsii.get(self, "id")

    @id.setter # type: ignore
    def id(self, value: typing.Optional[builtins.str]) -> None:
        jsii.set(self, "id", value)

    @builtins.property # type: ignore
    @jsii.member(jsii_name="timeouts")
    def timeouts(self) -> typing.Optional["DataAzurermVirtualHubTimeouts"]:
        return jsii.get(self, "timeouts")

    @timeouts.setter # type: ignore
    def timeouts(self, value: typing.Optional["DataAzurermVirtualHubTimeouts"]) -> None:
        jsii.set(self, "timeouts", value)


@jsii.data_type(
    jsii_type="@cdktf/provider-azurerm.DataAzurermVirtualHubConfig",
    jsii_struct_bases=[cdktf.TerraformMetaArguments],
    name_mapping={
        "count": "count",
        "depends_on": "dependsOn",
        "lifecycle": "lifecycle",
        "provider": "provider",
        "name": "name",
        "resource_group_name": "resourceGroupName",
        "timeouts": "timeouts",
    },
)
class DataAzurermVirtualHubConfig(cdktf.TerraformMetaArguments):
    def __init__(
        self,
        *,
        count: typing.Optional[jsii.Number] = None,
        depends_on: typing.Optional[typing.List[cdktf.TerraformResource]] = None,
        lifecycle: typing.Optional[cdktf.TerraformResourceLifecycle] = None,
        provider: typing.Optional[cdktf.TerraformProvider] = None,
        name: builtins.str,
        resource_group_name: builtins.str,
        timeouts: typing.Optional["DataAzurermVirtualHubTimeouts"] = None,
    ) -> None:
        """
        :param count: 
        :param depends_on: 
        :param lifecycle: 
        :param provider: 
        :param name: 
        :param resource_group_name: 
        :param timeouts: timeouts block.
        """
        if isinstance(lifecycle, dict):
            lifecycle = cdktf.TerraformResourceLifecycle(**lifecycle)
        if isinstance(timeouts, dict):
            timeouts = DataAzurermVirtualHubTimeouts(**timeouts)
        self._values: typing.Dict[str, typing.Any] = {
            "name": name,
            "resource_group_name": resource_group_name,
        }
        if count is not None:
            self._values["count"] = count
        if depends_on is not None:
            self._values["depends_on"] = depends_on
        if lifecycle is not None:
            self._values["lifecycle"] = lifecycle
        if provider is not None:
            self._values["provider"] = provider
        if timeouts is not None:
            self._values["timeouts"] = timeouts

    @builtins.property
    def count(self) -> typing.Optional[jsii.Number]:
        """
        :stability: experimental
        """
        result = self._values.get("count")
        return result

    @builtins.property
    def depends_on(self) -> typing.Optional[typing.List[cdktf.TerraformResource]]:
        """
        :stability: experimental
        """
        result = self._values.get("depends_on")
        return result

    @builtins.property
    def lifecycle(self) -> typing.Optional[cdktf.TerraformResourceLifecycle]:
        """
        :stability: experimental
        """
        result = self._values.get("lifecycle")
        return result

    @builtins.property
    def provider(self) -> typing.Optional[cdktf.TerraformProvider]:
        """
        :stability: experimental
        """
        result = self._values.get("provider")
        return result

    @builtins.property
    def name(self) -> builtins.str:
        result = self._values.get("name")
        assert result is not None, "Required property 'name' is missing"
        return result

    @builtins.property
    def resource_group_name(self) -> builtins.str:
        result = self._values.get("resource_group_name")
        assert result is not None, "Required property 'resource_group_name' is missing"
        return result

    @builtins.property
    def timeouts(self) -> typing.Optional["DataAzurermVirtualHubTimeouts"]:
        """timeouts block."""
        result = self._values.get("timeouts")
        return result

    def __eq__(self, rhs: typing.Any) -> builtins.bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs: typing.Any) -> builtins.bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return "DataAzurermVirtualHubConfig(%s)" % ", ".join(
            k + "=" + repr(v) for k, v in self._values.items()
        )


@jsii.data_type(
    jsii_type="@cdktf/provider-azurerm.DataAzurermVirtualHubTimeouts",
    jsii_struct_bases=[],
    name_mapping={"read": "read"},
)
class DataAzurermVirtualHubTimeouts:
    def __init__(self, *, read: typing.Optional[builtins.str] = None) -> None:
        """
        :param read: 
        """
        self._values: typing.Dict[str, typing.Any] = {}
        if read is not None:
            self._values["read"] = read

    @builtins.property
    def read(self) -> typing.Optional[builtins.str]:
        result = self._values.get("read")
        return result

    def __eq__(self, rhs: typing.Any) -> builtins.bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs: typing.Any) -> builtins.bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return "DataAzurermVirtualHubTimeouts(%s)" % ", ".join(
            k + "=" + repr(v) for k, v in self._values.items()
        )


class DataAzurermVirtualMachine(
    cdktf.TerraformDataSource,
    metaclass=jsii.JSIIMeta,
    jsii_type="@cdktf/provider-azurerm.DataAzurermVirtualMachine",
):
    def __init__(
        self,
        scope: constructs.Construct,
        id: builtins.str,
        *,
        name: builtins.str,
        resource_group_name: builtins.str,
        timeouts: typing.Optional["DataAzurermVirtualMachineTimeouts"] = None,
        count: typing.Optional[jsii.Number] = None,
        depends_on: typing.Optional[typing.List[cdktf.TerraformResource]] = None,
        lifecycle: typing.Optional[cdktf.TerraformResourceLifecycle] = None,
        provider: typing.Optional[cdktf.TerraformProvider] = None,
    ) -> None:
        """
        :param scope: -
        :param id: -
        :param name: 
        :param resource_group_name: 
        :param timeouts: timeouts block.
        :param count: 
        :param depends_on: 
        :param lifecycle: 
        :param provider: 
        """
        config = DataAzurermVirtualMachineConfig(
            name=name,
            resource_group_name=resource_group_name,
            timeouts=timeouts,
            count=count,
            depends_on=depends_on,
            lifecycle=lifecycle,
            provider=provider,
        )

        jsii.create(DataAzurermVirtualMachine, self, [scope, id, config])

    @jsii.member(jsii_name="synthesizeAttributes")
    def _synthesize_attributes(self) -> typing.Mapping[builtins.str, typing.Any]:
        return jsii.invoke(self, "synthesizeAttributes", [])

    @builtins.property # type: ignore
    @jsii.member(jsii_name="name")
    def name(self) -> builtins.str:
        return jsii.get(self, "name")

    @name.setter # type: ignore
    def name(self, value: builtins.str) -> None:
        jsii.set(self, "name", value)

    @builtins.property # type: ignore
    @jsii.member(jsii_name="resourceGroupName")
    def resource_group_name(self) -> builtins.str:
        return jsii.get(self, "resourceGroupName")

    @resource_group_name.setter # type: ignore
    def resource_group_name(self, value: builtins.str) -> None:
        jsii.set(self, "resourceGroupName", value)

    @builtins.property # type: ignore
    @jsii.member(jsii_name="id")
    def id(self) -> typing.Optional[builtins.str]:
        return jsii.get(self, "id")

    @id.setter # type: ignore
    def id(self, value: typing.Optional[builtins.str]) -> None:
        jsii.set(self, "id", value)

    @builtins.property # type: ignore
    @jsii.member(jsii_name="timeouts")
    def timeouts(self) -> typing.Optional["DataAzurermVirtualMachineTimeouts"]:
        return jsii.get(self, "timeouts")

    @timeouts.setter # type: ignore
    def timeouts(
        self,
        value: typing.Optional["DataAzurermVirtualMachineTimeouts"],
    ) -> None:
        jsii.set(self, "timeouts", value)


@jsii.data_type(
    jsii_type="@cdktf/provider-azurerm.DataAzurermVirtualMachineConfig",
    jsii_struct_bases=[cdktf.TerraformMetaArguments],
    name_mapping={
        "count": "count",
        "depends_on": "dependsOn",
        "lifecycle": "lifecycle",
        "provider": "provider",
        "name": "name",
        "resource_group_name": "resourceGroupName",
        "timeouts": "timeouts",
    },
)
class DataAzurermVirtualMachineConfig(cdktf.TerraformMetaArguments):
    def __init__(
        self,
        *,
        count: typing.Optional[jsii.Number] = None,
        depends_on: typing.Optional[typing.List[cdktf.TerraformResource]] = None,
        lifecycle: typing.Optional[cdktf.TerraformResourceLifecycle] = None,
        provider: typing.Optional[cdktf.TerraformProvider] = None,
        name: builtins.str,
        resource_group_name: builtins.str,
        timeouts: typing.Optional["DataAzurermVirtualMachineTimeouts"] = None,
    ) -> None:
        """
        :param count: 
        :param depends_on: 
        :param lifecycle: 
        :param provider: 
        :param name: 
        :param resource_group_name: 
        :param timeouts: timeouts block.
        """
        if isinstance(lifecycle, dict):
            lifecycle = cdktf.TerraformResourceLifecycle(**lifecycle)
        if isinstance(timeouts, dict):
            timeouts = DataAzurermVirtualMachineTimeouts(**timeouts)
        self._values: typing.Dict[str, typing.Any] = {
            "name": name,
            "resource_group_name": resource_group_name,
        }
        if count is not None:
            self._values["count"] = count
        if depends_on is not None:
            self._values["depends_on"] = depends_on
        if lifecycle is not None:
            self._values["lifecycle"] = lifecycle
        if provider is not None:
            self._values["provider"] = provider
        if timeouts is not None:
            self._values["timeouts"] = timeouts

    @builtins.property
    def count(self) -> typing.Optional[jsii.Number]:
        """
        :stability: experimental
        """
        result = self._values.get("count")
        return result

    @builtins.property
    def depends_on(self) -> typing.Optional[typing.List[cdktf.TerraformResource]]:
        """
        :stability: experimental
        """
        result = self._values.get("depends_on")
        return result

    @builtins.property
    def lifecycle(self) -> typing.Optional[cdktf.TerraformResourceLifecycle]:
        """
        :stability: experimental
        """
        result = self._values.get("lifecycle")
        return result

    @builtins.property
    def provider(self) -> typing.Optional[cdktf.TerraformProvider]:
        """
        :stability: experimental
        """
        result = self._values.get("provider")
        return result

    @builtins.property
    def name(self) -> builtins.str:
        result = self._values.get("name")
        assert result is not None, "Required property 'name' is missing"
        return result

    @builtins.property
    def resource_group_name(self) -> builtins.str:
        result = self._values.get("resource_group_name")
        assert result is not None, "Required property 'resource_group_name' is missing"
        return result

    @builtins.property
    def timeouts(self) -> typing.Optional["DataAzurermVirtualMachineTimeouts"]:
        """timeouts block."""
        result = self._values.get("timeouts")
        return result

    def __eq__(self, rhs: typing.Any) -> builtins.bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs: typing.Any) -> builtins.bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return "DataAzurermVirtualMachineConfig(%s)" % ", ".join(
            k + "=" + repr(v) for k, v in self._values.items()
        )


@jsii.data_type(
    jsii_type="@cdktf/provider-azurerm.DataAzurermVirtualMachineTimeouts",
    jsii_struct_bases=[],
    name_mapping={"read": "read"},
)
class DataAzurermVirtualMachineTimeouts:
    def __init__(self, *, read: typing.Optional[builtins.str] = None) -> None:
        """
        :param read: 
        """
        self._values: typing.Dict[str, typing.Any] = {}
        if read is not None:
            self._values["read"] = read

    @builtins.property
    def read(self) -> typing.Optional[builtins.str]:
        result = self._values.get("read")
        return result

    def __eq__(self, rhs: typing.Any) -> builtins.bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs: typing.Any) -> builtins.bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return "DataAzurermVirtualMachineTimeouts(%s)" % ", ".join(
            k + "=" + repr(v) for k, v in self._values.items()
        )


class DataAzurermVirtualNetwork(
    cdktf.TerraformDataSource,
    metaclass=jsii.JSIIMeta,
    jsii_type="@cdktf/provider-azurerm.DataAzurermVirtualNetwork",
):
    def __init__(
        self,
        scope: constructs.Construct,
        id: builtins.str,
        *,
        name: builtins.str,
        resource_group_name: builtins.str,
        timeouts: typing.Optional["DataAzurermVirtualNetworkTimeouts"] = None,
        count: typing.Optional[jsii.Number] = None,
        depends_on: typing.Optional[typing.List[cdktf.TerraformResource]] = None,
        lifecycle: typing.Optional[cdktf.TerraformResourceLifecycle] = None,
        provider: typing.Optional[cdktf.TerraformProvider] = None,
    ) -> None:
        """
        :param scope: -
        :param id: -
        :param name: 
        :param resource_group_name: 
        :param timeouts: timeouts block.
        :param count: 
        :param depends_on: 
        :param lifecycle: 
        :param provider: 
        """
        config = DataAzurermVirtualNetworkConfig(
            name=name,
            resource_group_name=resource_group_name,
            timeouts=timeouts,
            count=count,
            depends_on=depends_on,
            lifecycle=lifecycle,
            provider=provider,
        )

        jsii.create(DataAzurermVirtualNetwork, self, [scope, id, config])

    @jsii.member(jsii_name="synthesizeAttributes")
    def _synthesize_attributes(self) -> typing.Mapping[builtins.str, typing.Any]:
        return jsii.invoke(self, "synthesizeAttributes", [])

    @jsii.member(jsii_name="vnetPeerings")
    def vnet_peerings(self, key: builtins.str) -> builtins.str:
        """
        :param key: -
        """
        return jsii.invoke(self, "vnetPeerings", [key])

    @builtins.property # type: ignore
    @jsii.member(jsii_name="addressSpace")
    def address_space(self) -> typing.List[builtins.str]:
        return jsii.get(self, "addressSpace")

    @builtins.property # type: ignore
    @jsii.member(jsii_name="dnsServers")
    def dns_servers(self) -> typing.List[builtins.str]:
        return jsii.get(self, "dnsServers")

    @builtins.property # type: ignore
    @jsii.member(jsii_name="location")
    def location(self) -> builtins.str:
        return jsii.get(self, "location")

    @builtins.property # type: ignore
    @jsii.member(jsii_name="subnets")
    def subnets(self) -> typing.List[builtins.str]:
        return jsii.get(self, "subnets")

    @builtins.property # type: ignore
    @jsii.member(jsii_name="name")
    def name(self) -> builtins.str:
        return jsii.get(self, "name")

    @name.setter # type: ignore
    def name(self, value: builtins.str) -> None:
        jsii.set(self, "name", value)

    @builtins.property # type: ignore
    @jsii.member(jsii_name="resourceGroupName")
    def resource_group_name(self) -> builtins.str:
        return jsii.get(self, "resourceGroupName")

    @resource_group_name.setter # type: ignore
    def resource_group_name(self, value: builtins.str) -> None:
        jsii.set(self, "resourceGroupName", value)

    @builtins.property # type: ignore
    @jsii.member(jsii_name="id")
    def id(self) -> typing.Optional[builtins.str]:
        return jsii.get(self, "id")

    @id.setter # type: ignore
    def id(self, value: typing.Optional[builtins.str]) -> None:
        jsii.set(self, "id", value)

    @builtins.property # type: ignore
    @jsii.member(jsii_name="timeouts")
    def timeouts(self) -> typing.Optional["DataAzurermVirtualNetworkTimeouts"]:
        return jsii.get(self, "timeouts")

    @timeouts.setter # type: ignore
    def timeouts(
        self,
        value: typing.Optional["DataAzurermVirtualNetworkTimeouts"],
    ) -> None:
        jsii.set(self, "timeouts", value)


@jsii.data_type(
    jsii_type="@cdktf/provider-azurerm.DataAzurermVirtualNetworkConfig",
    jsii_struct_bases=[cdktf.TerraformMetaArguments],
    name_mapping={
        "count": "count",
        "depends_on": "dependsOn",
        "lifecycle": "lifecycle",
        "provider": "provider",
        "name": "name",
        "resource_group_name": "resourceGroupName",
        "timeouts": "timeouts",
    },
)
class DataAzurermVirtualNetworkConfig(cdktf.TerraformMetaArguments):
    def __init__(
        self,
        *,
        count: typing.Optional[jsii.Number] = None,
        depends_on: typing.Optional[typing.List[cdktf.TerraformResource]] = None,
        lifecycle: typing.Optional[cdktf.TerraformResourceLifecycle] = None,
        provider: typing.Optional[cdktf.TerraformProvider] = None,
        name: builtins.str,
        resource_group_name: builtins.str,
        timeouts: typing.Optional["DataAzurermVirtualNetworkTimeouts"] = None,
    ) -> None:
        """
        :param count: 
        :param depends_on: 
        :param lifecycle: 
        :param provider: 
        :param name: 
        :param resource_group_name: 
        :param timeouts: timeouts block.
        """
        if isinstance(lifecycle, dict):
            lifecycle = cdktf.TerraformResourceLifecycle(**lifecycle)
        if isinstance(timeouts, dict):
            timeouts = DataAzurermVirtualNetworkTimeouts(**timeouts)
        self._values: typing.Dict[str, typing.Any] = {
            "name": name,
            "resource_group_name": resource_group_name,
        }
        if count is not None:
            self._values["count"] = count
        if depends_on is not None:
            self._values["depends_on"] = depends_on
        if lifecycle is not None:
            self._values["lifecycle"] = lifecycle
        if provider is not None:
            self._values["provider"] = provider
        if timeouts is not None:
            self._values["timeouts"] = timeouts

    @builtins.property
    def count(self) -> typing.Optional[jsii.Number]:
        """
        :stability: experimental
        """
        result = self._values.get("count")
        return result

    @builtins.property
    def depends_on(self) -> typing.Optional[typing.List[cdktf.TerraformResource]]:
        """
        :stability: experimental
        """
        result = self._values.get("depends_on")
        return result

    @builtins.property
    def lifecycle(self) -> typing.Optional[cdktf.TerraformResourceLifecycle]:
        """
        :stability: experimental
        """
        result = self._values.get("lifecycle")
        return result

    @builtins.property
    def provider(self) -> typing.Optional[cdktf.TerraformProvider]:
        """
        :stability: experimental
        """
        result = self._values.get("provider")
        return result

    @builtins.property
    def name(self) -> builtins.str:
        result = self._values.get("name")
        assert result is not None, "Required property 'name' is missing"
        return result

    @builtins.property
    def resource_group_name(self) -> builtins.str:
        result = self._values.get("resource_group_name")
        assert result is not None, "Required property 'resource_group_name' is missing"
        return result

    @builtins.property
    def timeouts(self) -> typing.Optional["DataAzurermVirtualNetworkTimeouts"]:
        """timeouts block."""
        result = self._values.get("timeouts")
        return result

    def __eq__(self, rhs: typing.Any) -> builtins.bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs: typing.Any) -> builtins.bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return "DataAzurermVirtualNetworkConfig(%s)" % ", ".join(
            k + "=" + repr(v) for k, v in self._values.items()
        )


class DataAzurermVirtualNetworkGateway(
    cdktf.TerraformDataSource,
    metaclass=jsii.JSIIMeta,
    jsii_type="@cdktf/provider-azurerm.DataAzurermVirtualNetworkGateway",
):
    def __init__(
        self,
        scope: constructs.Construct,
        id: builtins.str,
        *,
        name: builtins.str,
        resource_group_name: builtins.str,
        timeouts: typing.Optional["DataAzurermVirtualNetworkGatewayTimeouts"] = None,
        count: typing.Optional[jsii.Number] = None,
        depends_on: typing.Optional[typing.List[cdktf.TerraformResource]] = None,
        lifecycle: typing.Optional[cdktf.TerraformResourceLifecycle] = None,
        provider: typing.Optional[cdktf.TerraformProvider] = None,
    ) -> None:
        """
        :param scope: -
        :param id: -
        :param name: 
        :param resource_group_name: 
        :param timeouts: timeouts block.
        :param count: 
        :param depends_on: 
        :param lifecycle: 
        :param provider: 
        """
        config = DataAzurermVirtualNetworkGatewayConfig(
            name=name,
            resource_group_name=resource_group_name,
            timeouts=timeouts,
            count=count,
            depends_on=depends_on,
            lifecycle=lifecycle,
            provider=provider,
        )

        jsii.create(DataAzurermVirtualNetworkGateway, self, [scope, id, config])

    @jsii.member(jsii_name="bgpSettings")
    def bgp_settings(
        self,
        index: builtins.str,
    ) -> "DataAzurermVirtualNetworkGatewayBgpSettings":
        """
        :param index: -
        """
        return jsii.invoke(self, "bgpSettings", [index])

    @jsii.member(jsii_name="ipConfiguration")
    def ip_configuration(
        self,
        index: builtins.str,
    ) -> "DataAzurermVirtualNetworkGatewayIpConfiguration":
        """
        :param index: -
        """
        return jsii.invoke(self, "ipConfiguration", [index])

    @jsii.member(jsii_name="synthesizeAttributes")
    def _synthesize_attributes(self) -> typing.Mapping[builtins.str, typing.Any]:
        return jsii.invoke(self, "synthesizeAttributes", [])

    @jsii.member(jsii_name="tags")
    def tags(self, key: builtins.str) -> builtins.str:
        """
        :param key: -
        """
        return jsii.invoke(self, "tags", [key])

    @jsii.member(jsii_name="vpnClientConfiguration")
    def vpn_client_configuration(
        self,
        index: builtins.str,
    ) -> "DataAzurermVirtualNetworkGatewayVpnClientConfiguration":
        """
        :param index: -
        """
        return jsii.invoke(self, "vpnClientConfiguration", [index])

    @builtins.property # type: ignore
    @jsii.member(jsii_name="activeActive")
    def active_active(self) -> builtins.bool:
        return jsii.get(self, "activeActive")

    @builtins.property # type: ignore
    @jsii.member(jsii_name="defaultLocalNetworkGatewayId")
    def default_local_network_gateway_id(self) -> builtins.str:
        return jsii.get(self, "defaultLocalNetworkGatewayId")

    @builtins.property # type: ignore
    @jsii.member(jsii_name="enableBgp")
    def enable_bgp(self) -> builtins.bool:
        return jsii.get(self, "enableBgp")

    @builtins.property # type: ignore
    @jsii.member(jsii_name="generation")
    def generation(self) -> builtins.str:
        return jsii.get(self, "generation")

    @builtins.property # type: ignore
    @jsii.member(jsii_name="location")
    def location(self) -> builtins.str:
        return jsii.get(self, "location")

    @builtins.property # type: ignore
    @jsii.member(jsii_name="sku")
    def sku(self) -> builtins.str:
        return jsii.get(self, "sku")

    @builtins.property # type: ignore
    @jsii.member(jsii_name="type")
    def type(self) -> builtins.str:
        return jsii.get(self, "type")

    @builtins.property # type: ignore
    @jsii.member(jsii_name="vpnType")
    def vpn_type(self) -> builtins.str:
        return jsii.get(self, "vpnType")

    @builtins.property # type: ignore
    @jsii.member(jsii_name="name")
    def name(self) -> builtins.str:
        return jsii.get(self, "name")

    @name.setter # type: ignore
    def name(self, value: builtins.str) -> None:
        jsii.set(self, "name", value)

    @builtins.property # type: ignore
    @jsii.member(jsii_name="resourceGroupName")
    def resource_group_name(self) -> builtins.str:
        return jsii.get(self, "resourceGroupName")

    @resource_group_name.setter # type: ignore
    def resource_group_name(self, value: builtins.str) -> None:
        jsii.set(self, "resourceGroupName", value)

    @builtins.property # type: ignore
    @jsii.member(jsii_name="id")
    def id(self) -> typing.Optional[builtins.str]:
        return jsii.get(self, "id")

    @id.setter # type: ignore
    def id(self, value: typing.Optional[builtins.str]) -> None:
        jsii.set(self, "id", value)

    @builtins.property # type: ignore
    @jsii.member(jsii_name="timeouts")
    def timeouts(self) -> typing.Optional["DataAzurermVirtualNetworkGatewayTimeouts"]:
        return jsii.get(self, "timeouts")

    @timeouts.setter # type: ignore
    def timeouts(
        self,
        value: typing.Optional["DataAzurermVirtualNetworkGatewayTimeouts"],
    ) -> None:
        jsii.set(self, "timeouts", value)


class DataAzurermVirtualNetworkGatewayBgpSettings(
    cdktf.ComplexComputedList,
    metaclass=jsii.JSIIMeta,
    jsii_type="@cdktf/provider-azurerm.DataAzurermVirtualNetworkGatewayBgpSettings",
):
    def __init__(
        self,
        terraform_resource: cdktf.ITerraformResource,
        terraform_attribute: builtins.str,
        index: builtins.str,
    ) -> None:
        """
        :param terraform_resource: -
        :param terraform_attribute: -
        :param index: -

        :stability: experimental
        """
        jsii.create(DataAzurermVirtualNetworkGatewayBgpSettings, self, [terraform_resource, terraform_attribute, index])

    @builtins.property # type: ignore
    @jsii.member(jsii_name="asn")
    def asn(self) -> jsii.Number:
        return jsii.get(self, "asn")

    @builtins.property # type: ignore
    @jsii.member(jsii_name="peeringAddress")
    def peering_address(self) -> builtins.str:
        return jsii.get(self, "peeringAddress")

    @builtins.property # type: ignore
    @jsii.member(jsii_name="peerWeight")
    def peer_weight(self) -> jsii.Number:
        return jsii.get(self, "peerWeight")


@jsii.data_type(
    jsii_type="@cdktf/provider-azurerm.DataAzurermVirtualNetworkGatewayConfig",
    jsii_struct_bases=[cdktf.TerraformMetaArguments],
    name_mapping={
        "count": "count",
        "depends_on": "dependsOn",
        "lifecycle": "lifecycle",
        "provider": "provider",
        "name": "name",
        "resource_group_name": "resourceGroupName",
        "timeouts": "timeouts",
    },
)
class DataAzurermVirtualNetworkGatewayConfig(cdktf.TerraformMetaArguments):
    def __init__(
        self,
        *,
        count: typing.Optional[jsii.Number] = None,
        depends_on: typing.Optional[typing.List[cdktf.TerraformResource]] = None,
        lifecycle: typing.Optional[cdktf.TerraformResourceLifecycle] = None,
        provider: typing.Optional[cdktf.TerraformProvider] = None,
        name: builtins.str,
        resource_group_name: builtins.str,
        timeouts: typing.Optional["DataAzurermVirtualNetworkGatewayTimeouts"] = None,
    ) -> None:
        """
        :param count: 
        :param depends_on: 
        :param lifecycle: 
        :param provider: 
        :param name: 
        :param resource_group_name: 
        :param timeouts: timeouts block.
        """
        if isinstance(lifecycle, dict):
            lifecycle = cdktf.TerraformResourceLifecycle(**lifecycle)
        if isinstance(timeouts, dict):
            timeouts = DataAzurermVirtualNetworkGatewayTimeouts(**timeouts)
        self._values: typing.Dict[str, typing.Any] = {
            "name": name,
            "resource_group_name": resource_group_name,
        }
        if count is not None:
            self._values["count"] = count
        if depends_on is not None:
            self._values["depends_on"] = depends_on
        if lifecycle is not None:
            self._values["lifecycle"] = lifecycle
        if provider is not None:
            self._values["provider"] = provider
        if timeouts is not None:
            self._values["timeouts"] = timeouts

    @builtins.property
    def count(self) -> typing.Optional[jsii.Number]:
        """
        :stability: experimental
        """
        result = self._values.get("count")
        return result

    @builtins.property
    def depends_on(self) -> typing.Optional[typing.List[cdktf.TerraformResource]]:
        """
        :stability: experimental
        """
        result = self._values.get("depends_on")
        return result

    @builtins.property
    def lifecycle(self) -> typing.Optional[cdktf.TerraformResourceLifecycle]:
        """
        :stability: experimental
        """
        result = self._values.get("lifecycle")
        return result

    @builtins.property
    def provider(self) -> typing.Optional[cdktf.TerraformProvider]:
        """
        :stability: experimental
        """
        result = self._values.get("provider")
        return result

    @builtins.property
    def name(self) -> builtins.str:
        result = self._values.get("name")
        assert result is not None, "Required property 'name' is missing"
        return result

    @builtins.property
    def resource_group_name(self) -> builtins.str:
        result = self._values.get("resource_group_name")
        assert result is not None, "Required property 'resource_group_name' is missing"
        return result

    @builtins.property
    def timeouts(self) -> typing.Optional["DataAzurermVirtualNetworkGatewayTimeouts"]:
        """timeouts block."""
        result = self._values.get("timeouts")
        return result

    def __eq__(self, rhs: typing.Any) -> builtins.bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs: typing.Any) -> builtins.bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return "DataAzurermVirtualNetworkGatewayConfig(%s)" % ", ".join(
            k + "=" + repr(v) for k, v in self._values.items()
        )


class DataAzurermVirtualNetworkGatewayConnection(
    cdktf.TerraformDataSource,
    metaclass=jsii.JSIIMeta,
    jsii_type="@cdktf/provider-azurerm.DataAzurermVirtualNetworkGatewayConnection",
):
    def __init__(
        self,
        scope: constructs.Construct,
        id: builtins.str,
        *,
        name: builtins.str,
        resource_group_name: builtins.str,
        timeouts: typing.Optional["DataAzurermVirtualNetworkGatewayConnectionTimeouts"] = None,
        count: typing.Optional[jsii.Number] = None,
        depends_on: typing.Optional[typing.List[cdktf.TerraformResource]] = None,
        lifecycle: typing.Optional[cdktf.TerraformResourceLifecycle] = None,
        provider: typing.Optional[cdktf.TerraformProvider] = None,
    ) -> None:
        """
        :param scope: -
        :param id: -
        :param name: 
        :param resource_group_name: 
        :param timeouts: timeouts block.
        :param count: 
        :param depends_on: 
        :param lifecycle: 
        :param provider: 
        """
        config = DataAzurermVirtualNetworkGatewayConnectionConfig(
            name=name,
            resource_group_name=resource_group_name,
            timeouts=timeouts,
            count=count,
            depends_on=depends_on,
            lifecycle=lifecycle,
            provider=provider,
        )

        jsii.create(DataAzurermVirtualNetworkGatewayConnection, self, [scope, id, config])

    @jsii.member(jsii_name="ipsecPolicy")
    def ipsec_policy(
        self,
        index: builtins.str,
    ) -> "DataAzurermVirtualNetworkGatewayConnectionIpsecPolicy":
        """
        :param index: -
        """
        return jsii.invoke(self, "ipsecPolicy", [index])

    @jsii.member(jsii_name="synthesizeAttributes")
    def _synthesize_attributes(self) -> typing.Mapping[builtins.str, typing.Any]:
        return jsii.invoke(self, "synthesizeAttributes", [])

    @jsii.member(jsii_name="tags")
    def tags(self, key: builtins.str) -> builtins.str:
        """
        :param key: -
        """
        return jsii.invoke(self, "tags", [key])

    @builtins.property # type: ignore
    @jsii.member(jsii_name="authorizationKey")
    def authorization_key(self) -> builtins.str:
        return jsii.get(self, "authorizationKey")

    @builtins.property # type: ignore
    @jsii.member(jsii_name="connectionProtocol")
    def connection_protocol(self) -> builtins.str:
        return jsii.get(self, "connectionProtocol")

    @builtins.property # type: ignore
    @jsii.member(jsii_name="egressBytesTransferred")
    def egress_bytes_transferred(self) -> jsii.Number:
        return jsii.get(self, "egressBytesTransferred")

    @builtins.property # type: ignore
    @jsii.member(jsii_name="enableBgp")
    def enable_bgp(self) -> builtins.bool:
        return jsii.get(self, "enableBgp")

    @builtins.property # type: ignore
    @jsii.member(jsii_name="expressRouteCircuitId")
    def express_route_circuit_id(self) -> builtins.str:
        return jsii.get(self, "expressRouteCircuitId")

    @builtins.property # type: ignore
    @jsii.member(jsii_name="expressRouteGatewayBypass")
    def express_route_gateway_bypass(self) -> builtins.bool:
        return jsii.get(self, "expressRouteGatewayBypass")

    @builtins.property # type: ignore
    @jsii.member(jsii_name="ingressBytesTransferred")
    def ingress_bytes_transferred(self) -> jsii.Number:
        return jsii.get(self, "ingressBytesTransferred")

    @builtins.property # type: ignore
    @jsii.member(jsii_name="localNetworkGatewayId")
    def local_network_gateway_id(self) -> builtins.str:
        return jsii.get(self, "localNetworkGatewayId")

    @builtins.property # type: ignore
    @jsii.member(jsii_name="location")
    def location(self) -> builtins.str:
        return jsii.get(self, "location")

    @builtins.property # type: ignore
    @jsii.member(jsii_name="peerVirtualNetworkGatewayId")
    def peer_virtual_network_gateway_id(self) -> builtins.str:
        return jsii.get(self, "peerVirtualNetworkGatewayId")

    @builtins.property # type: ignore
    @jsii.member(jsii_name="resourceGuid")
    def resource_guid(self) -> builtins.str:
        return jsii.get(self, "resourceGuid")

    @builtins.property # type: ignore
    @jsii.member(jsii_name="routingWeight")
    def routing_weight(self) -> jsii.Number:
        return jsii.get(self, "routingWeight")

    @builtins.property # type: ignore
    @jsii.member(jsii_name="sharedKey")
    def shared_key(self) -> builtins.str:
        return jsii.get(self, "sharedKey")

    @builtins.property # type: ignore
    @jsii.member(jsii_name="type")
    def type(self) -> builtins.str:
        return jsii.get(self, "type")

    @builtins.property # type: ignore
    @jsii.member(jsii_name="usePolicyBasedTrafficSelectors")
    def use_policy_based_traffic_selectors(self) -> builtins.bool:
        return jsii.get(self, "usePolicyBasedTrafficSelectors")

    @builtins.property # type: ignore
    @jsii.member(jsii_name="virtualNetworkGatewayId")
    def virtual_network_gateway_id(self) -> builtins.str:
        return jsii.get(self, "virtualNetworkGatewayId")

    @builtins.property # type: ignore
    @jsii.member(jsii_name="name")
    def name(self) -> builtins.str:
        return jsii.get(self, "name")

    @name.setter # type: ignore
    def name(self, value: builtins.str) -> None:
        jsii.set(self, "name", value)

    @builtins.property # type: ignore
    @jsii.member(jsii_name="resourceGroupName")
    def resource_group_name(self) -> builtins.str:
        return jsii.get(self, "resourceGroupName")

    @resource_group_name.setter # type: ignore
    def resource_group_name(self, value: builtins.str) -> None:
        jsii.set(self, "resourceGroupName", value)

    @builtins.property # type: ignore
    @jsii.member(jsii_name="id")
    def id(self) -> typing.Optional[builtins.str]:
        return jsii.get(self, "id")

    @id.setter # type: ignore
    def id(self, value: typing.Optional[builtins.str]) -> None:
        jsii.set(self, "id", value)

    @builtins.property # type: ignore
    @jsii.member(jsii_name="timeouts")
    def timeouts(
        self,
    ) -> typing.Optional["DataAzurermVirtualNetworkGatewayConnectionTimeouts"]:
        return jsii.get(self, "timeouts")

    @timeouts.setter # type: ignore
    def timeouts(
        self,
        value: typing.Optional["DataAzurermVirtualNetworkGatewayConnectionTimeouts"],
    ) -> None:
        jsii.set(self, "timeouts", value)


@jsii.data_type(
    jsii_type="@cdktf/provider-azurerm.DataAzurermVirtualNetworkGatewayConnectionConfig",
    jsii_struct_bases=[cdktf.TerraformMetaArguments],
    name_mapping={
        "count": "count",
        "depends_on": "dependsOn",
        "lifecycle": "lifecycle",
        "provider": "provider",
        "name": "name",
        "resource_group_name": "resourceGroupName",
        "timeouts": "timeouts",
    },
)
class DataAzurermVirtualNetworkGatewayConnectionConfig(cdktf.TerraformMetaArguments):
    def __init__(
        self,
        *,
        count: typing.Optional[jsii.Number] = None,
        depends_on: typing.Optional[typing.List[cdktf.TerraformResource]] = None,
        lifecycle: typing.Optional[cdktf.TerraformResourceLifecycle] = None,
        provider: typing.Optional[cdktf.TerraformProvider] = None,
        name: builtins.str,
        resource_group_name: builtins.str,
        timeouts: typing.Optional["DataAzurermVirtualNetworkGatewayConnectionTimeouts"] = None,
    ) -> None:
        """
        :param count: 
        :param depends_on: 
        :param lifecycle: 
        :param provider: 
        :param name: 
        :param resource_group_name: 
        :param timeouts: timeouts block.
        """
        if isinstance(lifecycle, dict):
            lifecycle = cdktf.TerraformResourceLifecycle(**lifecycle)
        if isinstance(timeouts, dict):
            timeouts = DataAzurermVirtualNetworkGatewayConnectionTimeouts(**timeouts)
        self._values: typing.Dict[str, typing.Any] = {
            "name": name,
            "resource_group_name": resource_group_name,
        }
        if count is not None:
            self._values["count"] = count
        if depends_on is not None:
            self._values["depends_on"] = depends_on
        if lifecycle is not None:
            self._values["lifecycle"] = lifecycle
        if provider is not None:
            self._values["provider"] = provider
        if timeouts is not None:
            self._values["timeouts"] = timeouts

    @builtins.property
    def count(self) -> typing.Optional[jsii.Number]:
        """
        :stability: experimental
        """
        result = self._values.get("count")
        return result

    @builtins.property
    def depends_on(self) -> typing.Optional[typing.List[cdktf.TerraformResource]]:
        """
        :stability: experimental
        """
        result = self._values.get("depends_on")
        return result

    @builtins.property
    def lifecycle(self) -> typing.Optional[cdktf.TerraformResourceLifecycle]:
        """
        :stability: experimental
        """
        result = self._values.get("lifecycle")
        return result

    @builtins.property
    def provider(self) -> typing.Optional[cdktf.TerraformProvider]:
        """
        :stability: experimental
        """
        result = self._values.get("provider")
        return result

    @builtins.property
    def name(self) -> builtins.str:
        result = self._values.get("name")
        assert result is not None, "Required property 'name' is missing"
        return result

    @builtins.property
    def resource_group_name(self) -> builtins.str:
        result = self._values.get("resource_group_name")
        assert result is not None, "Required property 'resource_group_name' is missing"
        return result

    @builtins.property
    def timeouts(
        self,
    ) -> typing.Optional["DataAzurermVirtualNetworkGatewayConnectionTimeouts"]:
        """timeouts block."""
        result = self._values.get("timeouts")
        return result

    def __eq__(self, rhs: typing.Any) -> builtins.bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs: typing.Any) -> builtins.bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return "DataAzurermVirtualNetworkGatewayConnectionConfig(%s)" % ", ".join(
            k + "=" + repr(v) for k, v in self._values.items()
        )


class DataAzurermVirtualNetworkGatewayConnectionIpsecPolicy(
    cdktf.ComplexComputedList,
    metaclass=jsii.JSIIMeta,
    jsii_type="@cdktf/provider-azurerm.DataAzurermVirtualNetworkGatewayConnectionIpsecPolicy",
):
    def __init__(
        self,
        terraform_resource: cdktf.ITerraformResource,
        terraform_attribute: builtins.str,
        index: builtins.str,
    ) -> None:
        """
        :param terraform_resource: -
        :param terraform_attribute: -
        :param index: -

        :stability: experimental
        """
        jsii.create(DataAzurermVirtualNetworkGatewayConnectionIpsecPolicy, self, [terraform_resource, terraform_attribute, index])

    @builtins.property # type: ignore
    @jsii.member(jsii_name="dhGroup")
    def dh_group(self) -> builtins.str:
        return jsii.get(self, "dhGroup")

    @builtins.property # type: ignore
    @jsii.member(jsii_name="ikeEncryption")
    def ike_encryption(self) -> builtins.str:
        return jsii.get(self, "ikeEncryption")

    @builtins.property # type: ignore
    @jsii.member(jsii_name="ikeIntegrity")
    def ike_integrity(self) -> builtins.str:
        return jsii.get(self, "ikeIntegrity")

    @builtins.property # type: ignore
    @jsii.member(jsii_name="ipsecEncryption")
    def ipsec_encryption(self) -> builtins.str:
        return jsii.get(self, "ipsecEncryption")

    @builtins.property # type: ignore
    @jsii.member(jsii_name="ipsecIntegrity")
    def ipsec_integrity(self) -> builtins.str:
        return jsii.get(self, "ipsecIntegrity")

    @builtins.property # type: ignore
    @jsii.member(jsii_name="pfsGroup")
    def pfs_group(self) -> builtins.str:
        return jsii.get(self, "pfsGroup")

    @builtins.property # type: ignore
    @jsii.member(jsii_name="saDatasize")
    def sa_datasize(self) -> jsii.Number:
        return jsii.get(self, "saDatasize")

    @builtins.property # type: ignore
    @jsii.member(jsii_name="saLifetime")
    def sa_lifetime(self) -> jsii.Number:
        return jsii.get(self, "saLifetime")


@jsii.data_type(
    jsii_type="@cdktf/provider-azurerm.DataAzurermVirtualNetworkGatewayConnectionTimeouts",
    jsii_struct_bases=[],
    name_mapping={"read": "read"},
)
class DataAzurermVirtualNetworkGatewayConnectionTimeouts:
    def __init__(self, *, read: typing.Optional[builtins.str] = None) -> None:
        """
        :param read: 
        """
        self._values: typing.Dict[str, typing.Any] = {}
        if read is not None:
            self._values["read"] = read

    @builtins.property
    def read(self) -> typing.Optional[builtins.str]:
        result = self._values.get("read")
        return result

    def __eq__(self, rhs: typing.Any) -> builtins.bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs: typing.Any) -> builtins.bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return "DataAzurermVirtualNetworkGatewayConnectionTimeouts(%s)" % ", ".join(
            k + "=" + repr(v) for k, v in self._values.items()
        )


class DataAzurermVirtualNetworkGatewayIpConfiguration(
    cdktf.ComplexComputedList,
    metaclass=jsii.JSIIMeta,
    jsii_type="@cdktf/provider-azurerm.DataAzurermVirtualNetworkGatewayIpConfiguration",
):
    def __init__(
        self,
        terraform_resource: cdktf.ITerraformResource,
        terraform_attribute: builtins.str,
        index: builtins.str,
    ) -> None:
        """
        :param terraform_resource: -
        :param terraform_attribute: -
        :param index: -

        :stability: experimental
        """
        jsii.create(DataAzurermVirtualNetworkGatewayIpConfiguration, self, [terraform_resource, terraform_attribute, index])

    @builtins.property # type: ignore
    @jsii.member(jsii_name="name")
    def name(self) -> builtins.str:
        return jsii.get(self, "name")

    @builtins.property # type: ignore
    @jsii.member(jsii_name="privateIpAddressAllocation")
    def private_ip_address_allocation(self) -> builtins.str:
        return jsii.get(self, "privateIpAddressAllocation")

    @builtins.property # type: ignore
    @jsii.member(jsii_name="publicIpAddressId")
    def public_ip_address_id(self) -> builtins.str:
        return jsii.get(self, "publicIpAddressId")

    @builtins.property # type: ignore
    @jsii.member(jsii_name="subnetId")
    def subnet_id(self) -> builtins.str:
        return jsii.get(self, "subnetId")


@jsii.data_type(
    jsii_type="@cdktf/provider-azurerm.DataAzurermVirtualNetworkGatewayTimeouts",
    jsii_struct_bases=[],
    name_mapping={"read": "read"},
)
class DataAzurermVirtualNetworkGatewayTimeouts:
    def __init__(self, *, read: typing.Optional[builtins.str] = None) -> None:
        """
        :param read: 
        """
        self._values: typing.Dict[str, typing.Any] = {}
        if read is not None:
            self._values["read"] = read

    @builtins.property
    def read(self) -> typing.Optional[builtins.str]:
        result = self._values.get("read")
        return result

    def __eq__(self, rhs: typing.Any) -> builtins.bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs: typing.Any) -> builtins.bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return "DataAzurermVirtualNetworkGatewayTimeouts(%s)" % ", ".join(
            k + "=" + repr(v) for k, v in self._values.items()
        )


class DataAzurermVirtualNetworkGatewayVpnClientConfiguration(
    cdktf.ComplexComputedList,
    metaclass=jsii.JSIIMeta,
    jsii_type="@cdktf/provider-azurerm.DataAzurermVirtualNetworkGatewayVpnClientConfiguration",
):
    def __init__(
        self,
        terraform_resource: cdktf.ITerraformResource,
        terraform_attribute: builtins.str,
        index: builtins.str,
    ) -> None:
        """
        :param terraform_resource: -
        :param terraform_attribute: -
        :param index: -

        :stability: experimental
        """
        jsii.create(DataAzurermVirtualNetworkGatewayVpnClientConfiguration, self, [terraform_resource, terraform_attribute, index])

    @builtins.property # type: ignore
    @jsii.member(jsii_name="addressSpace")
    def address_space(self) -> typing.List[builtins.str]:
        return jsii.get(self, "addressSpace")

    @builtins.property # type: ignore
    @jsii.member(jsii_name="radiusServerAddress")
    def radius_server_address(self) -> builtins.str:
        return jsii.get(self, "radiusServerAddress")

    @builtins.property # type: ignore
    @jsii.member(jsii_name="radiusServerSecret")
    def radius_server_secret(self) -> builtins.str:
        return jsii.get(self, "radiusServerSecret")

    @builtins.property # type: ignore
    @jsii.member(jsii_name="revokedCertificate")
    def revoked_certificate(self) -> typing.Any:
        return jsii.get(self, "revokedCertificate")

    @builtins.property # type: ignore
    @jsii.member(jsii_name="rootCertificate")
    def root_certificate(self) -> typing.Any:
        return jsii.get(self, "rootCertificate")

    @builtins.property # type: ignore
    @jsii.member(jsii_name="vpnClientProtocols")
    def vpn_client_protocols(self) -> typing.List[builtins.str]:
        return jsii.get(self, "vpnClientProtocols")


class DataAzurermVirtualNetworkGatewayVpnClientConfigurationRevokedCertificate(
    cdktf.ComplexComputedList,
    metaclass=jsii.JSIIMeta,
    jsii_type="@cdktf/provider-azurerm.DataAzurermVirtualNetworkGatewayVpnClientConfigurationRevokedCertificate",
):
    def __init__(
        self,
        terraform_resource: cdktf.ITerraformResource,
        terraform_attribute: builtins.str,
        index: builtins.str,
    ) -> None:
        """
        :param terraform_resource: -
        :param terraform_attribute: -
        :param index: -

        :stability: experimental
        """
        jsii.create(DataAzurermVirtualNetworkGatewayVpnClientConfigurationRevokedCertificate, self, [terraform_resource, terraform_attribute, index])

    @builtins.property # type: ignore
    @jsii.member(jsii_name="name")
    def name(self) -> builtins.str:
        return jsii.get(self, "name")

    @builtins.property # type: ignore
    @jsii.member(jsii_name="thumbprint")
    def thumbprint(self) -> builtins.str:
        return jsii.get(self, "thumbprint")


class DataAzurermVirtualNetworkGatewayVpnClientConfigurationRootCertificate(
    cdktf.ComplexComputedList,
    metaclass=jsii.JSIIMeta,
    jsii_type="@cdktf/provider-azurerm.DataAzurermVirtualNetworkGatewayVpnClientConfigurationRootCertificate",
):
    def __init__(
        self,
        terraform_resource: cdktf.ITerraformResource,
        terraform_attribute: builtins.str,
        index: builtins.str,
    ) -> None:
        """
        :param terraform_resource: -
        :param terraform_attribute: -
        :param index: -

        :stability: experimental
        """
        jsii.create(DataAzurermVirtualNetworkGatewayVpnClientConfigurationRootCertificate, self, [terraform_resource, terraform_attribute, index])

    @builtins.property # type: ignore
    @jsii.member(jsii_name="name")
    def name(self) -> builtins.str:
        return jsii.get(self, "name")

    @builtins.property # type: ignore
    @jsii.member(jsii_name="publicCertData")
    def public_cert_data(self) -> builtins.str:
        return jsii.get(self, "publicCertData")


@jsii.data_type(
    jsii_type="@cdktf/provider-azurerm.DataAzurermVirtualNetworkTimeouts",
    jsii_struct_bases=[],
    name_mapping={"read": "read"},
)
class DataAzurermVirtualNetworkTimeouts:
    def __init__(self, *, read: typing.Optional[builtins.str] = None) -> None:
        """
        :param read: 
        """
        self._values: typing.Dict[str, typing.Any] = {}
        if read is not None:
            self._values["read"] = read

    @builtins.property
    def read(self) -> typing.Optional[builtins.str]:
        result = self._values.get("read")
        return result

    def __eq__(self, rhs: typing.Any) -> builtins.bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs: typing.Any) -> builtins.bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return "DataAzurermVirtualNetworkTimeouts(%s)" % ", ".join(
            k + "=" + repr(v) for k, v in self._values.items()
        )


class DataFactory(
    cdktf.TerraformResource,
    metaclass=jsii.JSIIMeta,
    jsii_type="@cdktf/provider-azurerm.DataFactory",
):
    def __init__(
        self,
        scope: constructs.Construct,
        id: builtins.str,
        *,
        location: builtins.str,
        name: builtins.str,
        resource_group_name: builtins.str,
        github_configuration: typing.Optional[typing.List["DataFactoryGithubConfiguration"]] = None,
        identity: typing.Optional[typing.List["DataFactoryIdentity"]] = None,
        tags: typing.Optional[typing.Mapping[builtins.str, builtins.str]] = None,
        timeouts: typing.Optional["DataFactoryTimeouts"] = None,
        vsts_configuration: typing.Optional[typing.List["DataFactoryVstsConfiguration"]] = None,
        count: typing.Optional[jsii.Number] = None,
        depends_on: typing.Optional[typing.List[cdktf.TerraformResource]] = None,
        lifecycle: typing.Optional[cdktf.TerraformResourceLifecycle] = None,
        provider: typing.Optional[cdktf.TerraformProvider] = None,
    ) -> None:
        """
        :param scope: -
        :param id: -
        :param location: 
        :param name: 
        :param resource_group_name: 
        :param github_configuration: github_configuration block.
        :param identity: identity block.
        :param tags: 
        :param timeouts: timeouts block.
        :param vsts_configuration: vsts_configuration block.
        :param count: 
        :param depends_on: 
        :param lifecycle: 
        :param provider: 
        """
        config = DataFactoryConfig(
            location=location,
            name=name,
            resource_group_name=resource_group_name,
            github_configuration=github_configuration,
            identity=identity,
            tags=tags,
            timeouts=timeouts,
            vsts_configuration=vsts_configuration,
            count=count,
            depends_on=depends_on,
            lifecycle=lifecycle,
            provider=provider,
        )

        jsii.create(DataFactory, self, [scope, id, config])

    @jsii.member(jsii_name="synthesizeAttributes")
    def _synthesize_attributes(self) -> typing.Mapping[builtins.str, typing.Any]:
        return jsii.invoke(self, "synthesizeAttributes", [])

    @builtins.property # type: ignore
    @jsii.member(jsii_name="location")
    def location(self) -> builtins.str:
        return jsii.get(self, "location")

    @location.setter # type: ignore
    def location(self, value: builtins.str) -> None:
        jsii.set(self, "location", value)

    @builtins.property # type: ignore
    @jsii.member(jsii_name="name")
    def name(self) -> builtins.str:
        return jsii.get(self, "name")

    @name.setter # type: ignore
    def name(self, value: builtins.str) -> None:
        jsii.set(self, "name", value)

    @builtins.property # type: ignore
    @jsii.member(jsii_name="resourceGroupName")
    def resource_group_name(self) -> builtins.str:
        return jsii.get(self, "resourceGroupName")

    @resource_group_name.setter # type: ignore
    def resource_group_name(self, value: builtins.str) -> None:
        jsii.set(self, "resourceGroupName", value)

    @builtins.property # type: ignore
    @jsii.member(jsii_name="githubConfiguration")
    def github_configuration(
        self,
    ) -> typing.Optional[typing.List["DataFactoryGithubConfiguration"]]:
        return jsii.get(self, "githubConfiguration")

    @github_configuration.setter # type: ignore
    def github_configuration(
        self,
        value: typing.Optional[typing.List["DataFactoryGithubConfiguration"]],
    ) -> None:
        jsii.set(self, "githubConfiguration", value)

    @builtins.property # type: ignore
    @jsii.member(jsii_name="id")
    def id(self) -> typing.Optional[builtins.str]:
        return jsii.get(self, "id")

    @id.setter # type: ignore
    def id(self, value: typing.Optional[builtins.str]) -> None:
        jsii.set(self, "id", value)

    @builtins.property # type: ignore
    @jsii.member(jsii_name="identity")
    def identity(self) -> typing.Optional[typing.List["DataFactoryIdentity"]]:
        return jsii.get(self, "identity")

    @identity.setter # type: ignore
    def identity(
        self,
        value: typing.Optional[typing.List["DataFactoryIdentity"]],
    ) -> None:
        jsii.set(self, "identity", value)

    @builtins.property # type: ignore
    @jsii.member(jsii_name="tags")
    def tags(self) -> typing.Optional[typing.Mapping[builtins.str, builtins.str]]:
        return jsii.get(self, "tags")

    @tags.setter # type: ignore
    def tags(
        self,
        value: typing.Optional[typing.Mapping[builtins.str, builtins.str]],
    ) -> None:
        jsii.set(self, "tags", value)

    @builtins.property # type: ignore
    @jsii.member(jsii_name="timeouts")
    def timeouts(self) -> typing.Optional["DataFactoryTimeouts"]:
        return jsii.get(self, "timeouts")

    @timeouts.setter # type: ignore
    def timeouts(self, value: typing.Optional["DataFactoryTimeouts"]) -> None:
        jsii.set(self, "timeouts", value)

    @builtins.property # type: ignore
    @jsii.member(jsii_name="vstsConfiguration")
    def vsts_configuration(
        self,
    ) -> typing.Optional[typing.List["DataFactoryVstsConfiguration"]]:
        return jsii.get(self, "vstsConfiguration")

    @vsts_configuration.setter # type: ignore
    def vsts_configuration(
        self,
        value: typing.Optional[typing.List["DataFactoryVstsConfiguration"]],
    ) -> None:
        jsii.set(self, "vstsConfiguration", value)


@jsii.data_type(
    jsii_type="@cdktf/provider-azurerm.DataFactoryConfig",
    jsii_struct_bases=[cdktf.TerraformMetaArguments],
    name_mapping={
        "count": "count",
        "depends_on": "dependsOn",
        "lifecycle": "lifecycle",
        "provider": "provider",
        "location": "location",
        "name": "name",
        "resource_group_name": "resourceGroupName",
        "github_configuration": "githubConfiguration",
        "identity": "identity",
        "tags": "tags",
        "timeouts": "timeouts",
        "vsts_configuration": "vstsConfiguration",
    },
)
class DataFactoryConfig(cdktf.TerraformMetaArguments):
    def __init__(
        self,
        *,
        count: typing.Optional[jsii.Number] = None,
        depends_on: typing.Optional[typing.List[cdktf.TerraformResource]] = None,
        lifecycle: typing.Optional[cdktf.TerraformResourceLifecycle] = None,
        provider: typing.Optional[cdktf.TerraformProvider] = None,
        location: builtins.str,
        name: builtins.str,
        resource_group_name: builtins.str,
        github_configuration: typing.Optional[typing.List["DataFactoryGithubConfiguration"]] = None,
        identity: typing.Optional[typing.List["DataFactoryIdentity"]] = None,
        tags: typing.Optional[typing.Mapping[builtins.str, builtins.str]] = None,
        timeouts: typing.Optional["DataFactoryTimeouts"] = None,
        vsts_configuration: typing.Optional[typing.List["DataFactoryVstsConfiguration"]] = None,
    ) -> None:
        """
        :param count: 
        :param depends_on: 
        :param lifecycle: 
        :param provider: 
        :param location: 
        :param name: 
        :param resource_group_name: 
        :param github_configuration: github_configuration block.
        :param identity: identity block.
        :param tags: 
        :param timeouts: timeouts block.
        :param vsts_configuration: vsts_configuration block.
        """
        if isinstance(lifecycle, dict):
            lifecycle = cdktf.TerraformResourceLifecycle(**lifecycle)
        if isinstance(timeouts, dict):
            timeouts = DataFactoryTimeouts(**timeouts)
        self._values: typing.Dict[str, typing.Any] = {
            "location": location,
            "name": name,
            "resource_group_name": resource_group_name,
        }
        if count is not None:
            self._values["count"] = count
        if depends_on is not None:
            self._values["depends_on"] = depends_on
        if lifecycle is not None:
            self._values["lifecycle"] = lifecycle
        if provider is not None:
            self._values["provider"] = provider
        if github_configuration is not None:
            self._values["github_configuration"] = github_configuration
        if identity is not None:
            self._values["identity"] = identity
        if tags is not None:
            self._values["tags"] = tags
        if timeouts is not None:
            self._values["timeouts"] = timeouts
        if vsts_configuration is not None:
            self._values["vsts_configuration"] = vsts_configuration

    @builtins.property
    def count(self) -> typing.Optional[jsii.Number]:
        """
        :stability: experimental
        """
        result = self._values.get("count")
        return result

    @builtins.property
    def depends_on(self) -> typing.Optional[typing.List[cdktf.TerraformResource]]:
        """
        :stability: experimental
        """
        result = self._values.get("depends_on")
        return result

    @builtins.property
    def lifecycle(self) -> typing.Optional[cdktf.TerraformResourceLifecycle]:
        """
        :stability: experimental
        """
        result = self._values.get("lifecycle")
        return result

    @builtins.property
    def provider(self) -> typing.Optional[cdktf.TerraformProvider]:
        """
        :stability: experimental
        """
        result = self._values.get("provider")
        return result

    @builtins.property
    def location(self) -> builtins.str:
        result = self._values.get("location")
        assert result is not None, "Required property 'location' is missing"
        return result

    @builtins.property
    def name(self) -> builtins.str:
        result = self._values.get("name")
        assert result is not None, "Required property 'name' is missing"
        return result

    @builtins.property
    def resource_group_name(self) -> builtins.str:
        result = self._values.get("resource_group_name")
        assert result is not None, "Required property 'resource_group_name' is missing"
        return result

    @builtins.property
    def github_configuration(
        self,
    ) -> typing.Optional[typing.List["DataFactoryGithubConfiguration"]]:
        """github_configuration block."""
        result = self._values.get("github_configuration")
        return result

    @builtins.property
    def identity(self) -> typing.Optional[typing.List["DataFactoryIdentity"]]:
        """identity block."""
        result = self._values.get("identity")
        return result

    @builtins.property
    def tags(self) -> typing.Optional[typing.Mapping[builtins.str, builtins.str]]:
        result = self._values.get("tags")
        return result

    @builtins.property
    def timeouts(self) -> typing.Optional["DataFactoryTimeouts"]:
        """timeouts block."""
        result = self._values.get("timeouts")
        return result

    @builtins.property
    def vsts_configuration(
        self,
    ) -> typing.Optional[typing.List["DataFactoryVstsConfiguration"]]:
        """vsts_configuration block."""
        result = self._values.get("vsts_configuration")
        return result

    def __eq__(self, rhs: typing.Any) -> builtins.bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs: typing.Any) -> builtins.bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return "DataFactoryConfig(%s)" % ", ".join(
            k + "=" + repr(v) for k, v in self._values.items()
        )


class DataFactoryDatasetMysql(
    cdktf.TerraformResource,
    metaclass=jsii.JSIIMeta,
    jsii_type="@cdktf/provider-azurerm.DataFactoryDatasetMysql",
):
    def __init__(
        self,
        scope: constructs.Construct,
        id: builtins.str,
        *,
        data_factory_name: builtins.str,
        linked_service_name: builtins.str,
        name: builtins.str,
        resource_group_name: builtins.str,
        additional_properties: typing.Optional[typing.Mapping[builtins.str, builtins.str]] = None,
        annotations: typing.Optional[typing.List[builtins.str]] = None,
        description: typing.Optional[builtins.str] = None,
        folder: typing.Optional[builtins.str] = None,
        parameters: typing.Optional[typing.Mapping[builtins.str, builtins.str]] = None,
        schema_column: typing.Optional[typing.List["DataFactoryDatasetMysqlSchemaColumn"]] = None,
        table_name: typing.Optional[builtins.str] = None,
        timeouts: typing.Optional["DataFactoryDatasetMysqlTimeouts"] = None,
        count: typing.Optional[jsii.Number] = None,
        depends_on: typing.Optional[typing.List[cdktf.TerraformResource]] = None,
        lifecycle: typing.Optional[cdktf.TerraformResourceLifecycle] = None,
        provider: typing.Optional[cdktf.TerraformProvider] = None,
    ) -> None:
        """
        :param scope: -
        :param id: -
        :param data_factory_name: 
        :param linked_service_name: 
        :param name: 
        :param resource_group_name: 
        :param additional_properties: 
        :param annotations: 
        :param description: 
        :param folder: 
        :param parameters: 
        :param schema_column: schema_column block.
        :param table_name: 
        :param timeouts: timeouts block.
        :param count: 
        :param depends_on: 
        :param lifecycle: 
        :param provider: 
        """
        config = DataFactoryDatasetMysqlConfig(
            data_factory_name=data_factory_name,
            linked_service_name=linked_service_name,
            name=name,
            resource_group_name=resource_group_name,
            additional_properties=additional_properties,
            annotations=annotations,
            description=description,
            folder=folder,
            parameters=parameters,
            schema_column=schema_column,
            table_name=table_name,
            timeouts=timeouts,
            count=count,
            depends_on=depends_on,
            lifecycle=lifecycle,
            provider=provider,
        )

        jsii.create(DataFactoryDatasetMysql, self, [scope, id, config])

    @jsii.member(jsii_name="synthesizeAttributes")
    def _synthesize_attributes(self) -> typing.Mapping[builtins.str, typing.Any]:
        return jsii.invoke(self, "synthesizeAttributes", [])

    @builtins.property # type: ignore
    @jsii.member(jsii_name="dataFactoryName")
    def data_factory_name(self) -> builtins.str:
        return jsii.get(self, "dataFactoryName")

    @data_factory_name.setter # type: ignore
    def data_factory_name(self, value: builtins.str) -> None:
        jsii.set(self, "dataFactoryName", value)

    @builtins.property # type: ignore
    @jsii.member(jsii_name="linkedServiceName")
    def linked_service_name(self) -> builtins.str:
        return jsii.get(self, "linkedServiceName")

    @linked_service_name.setter # type: ignore
    def linked_service_name(self, value: builtins.str) -> None:
        jsii.set(self, "linkedServiceName", value)

    @builtins.property # type: ignore
    @jsii.member(jsii_name="name")
    def name(self) -> builtins.str:
        return jsii.get(self, "name")

    @name.setter # type: ignore
    def name(self, value: builtins.str) -> None:
        jsii.set(self, "name", value)

    @builtins.property # type: ignore
    @jsii.member(jsii_name="resourceGroupName")
    def resource_group_name(self) -> builtins.str:
        return jsii.get(self, "resourceGroupName")

    @resource_group_name.setter # type: ignore
    def resource_group_name(self, value: builtins.str) -> None:
        jsii.set(self, "resourceGroupName", value)

    @builtins.property # type: ignore
    @jsii.member(jsii_name="additionalProperties")
    def additional_properties(
        self,
    ) -> typing.Optional[typing.Mapping[builtins.str, builtins.str]]:
        return jsii.get(self, "additionalProperties")

    @additional_properties.setter # type: ignore
    def additional_properties(
        self,
        value: typing.Optional[typing.Mapping[builtins.str, builtins.str]],
    ) -> None:
        jsii.set(self, "additionalProperties", value)

    @builtins.property # type: ignore
    @jsii.member(jsii_name="annotations")
    def annotations(self) -> typing.Optional[typing.List[builtins.str]]:
        return jsii.get(self, "annotations")

    @annotations.setter # type: ignore
    def annotations(self, value: typing.Optional[typing.List[builtins.str]]) -> None:
        jsii.set(self, "annotations", value)

    @builtins.property # type: ignore
    @jsii.member(jsii_name="description")
    def description(self) -> typing.Optional[builtins.str]:
        return jsii.get(self, "description")

    @description.setter # type: ignore
    def description(self, value: typing.Optional[builtins.str]) -> None:
        jsii.set(self, "description", value)

    @builtins.property # type: ignore
    @jsii.member(jsii_name="folder")
    def folder(self) -> typing.Optional[builtins.str]:
        return jsii.get(self, "folder")

    @folder.setter # type: ignore
    def folder(self, value: typing.Optional[builtins.str]) -> None:
        jsii.set(self, "folder", value)

    @builtins.property # type: ignore
    @jsii.member(jsii_name="id")
    def id(self) -> typing.Optional[builtins.str]:
        return jsii.get(self, "id")

    @id.setter # type: ignore
    def id(self, value: typing.Optional[builtins.str]) -> None:
        jsii.set(self, "id", value)

    @builtins.property # type: ignore
    @jsii.member(jsii_name="parameters")
    def parameters(self) -> typing.Optional[typing.Mapping[builtins.str, builtins.str]]:
        return jsii.get(self, "parameters")

    @parameters.setter # type: ignore
    def parameters(
        self,
        value: typing.Optional[typing.Mapping[builtins.str, builtins.str]],
    ) -> None:
        jsii.set(self, "parameters", value)

    @builtins.property # type: ignore
    @jsii.member(jsii_name="schemaColumn")
    def schema_column(
        self,
    ) -> typing.Optional[typing.List["DataFactoryDatasetMysqlSchemaColumn"]]:
        return jsii.get(self, "schemaColumn")

    @schema_column.setter # type: ignore
    def schema_column(
        self,
        value: typing.Optional[typing.List["DataFactoryDatasetMysqlSchemaColumn"]],
    ) -> None:
        jsii.set(self, "schemaColumn", value)

    @builtins.property # type: ignore
    @jsii.member(jsii_name="tableName")
    def table_name(self) -> typing.Optional[builtins.str]:
        return jsii.get(self, "tableName")

    @table_name.setter # type: ignore
    def table_name(self, value: typing.Optional[builtins.str]) -> None:
        jsii.set(self, "tableName", value)

    @builtins.property # type: ignore
    @jsii.member(jsii_name="timeouts")
    def timeouts(self) -> typing.Optional["DataFactoryDatasetMysqlTimeouts"]:
        return jsii.get(self, "timeouts")

    @timeouts.setter # type: ignore
    def timeouts(
        self,
        value: typing.Optional["DataFactoryDatasetMysqlTimeouts"],
    ) -> None:
        jsii.set(self, "timeouts", value)


@jsii.data_type(
    jsii_type="@cdktf/provider-azurerm.DataFactoryDatasetMysqlConfig",
    jsii_struct_bases=[cdktf.TerraformMetaArguments],
    name_mapping={
        "count": "count",
        "depends_on": "dependsOn",
        "lifecycle": "lifecycle",
        "provider": "provider",
        "data_factory_name": "dataFactoryName",
        "linked_service_name": "linkedServiceName",
        "name": "name",
        "resource_group_name": "resourceGroupName",
        "additional_properties": "additionalProperties",
        "annotations": "annotations",
        "description": "description",
        "folder": "folder",
        "parameters": "parameters",
        "schema_column": "schemaColumn",
        "table_name": "tableName",
        "timeouts": "timeouts",
    },
)
class DataFactoryDatasetMysqlConfig(cdktf.TerraformMetaArguments):
    def __init__(
        self,
        *,
        count: typing.Optional[jsii.Number] = None,
        depends_on: typing.Optional[typing.List[cdktf.TerraformResource]] = None,
        lifecycle: typing.Optional[cdktf.TerraformResourceLifecycle] = None,
        provider: typing.Optional[cdktf.TerraformProvider] = None,
        data_factory_name: builtins.str,
        linked_service_name: builtins.str,
        name: builtins.str,
        resource_group_name: builtins.str,
        additional_properties: typing.Optional[typing.Mapping[builtins.str, builtins.str]] = None,
        annotations: typing.Optional[typing.List[builtins.str]] = None,
        description: typing.Optional[builtins.str] = None,
        folder: typing.Optional[builtins.str] = None,
        parameters: typing.Optional[typing.Mapping[builtins.str, builtins.str]] = None,
        schema_column: typing.Optional[typing.List["DataFactoryDatasetMysqlSchemaColumn"]] = None,
        table_name: typing.Optional[builtins.str] = None,
        timeouts: typing.Optional["DataFactoryDatasetMysqlTimeouts"] = None,
    ) -> None:
        """
        :param count: 
        :param depends_on: 
        :param lifecycle: 
        :param provider: 
        :param data_factory_name: 
        :param linked_service_name: 
        :param name: 
        :param resource_group_name: 
        :param additional_properties: 
        :param annotations: 
        :param description: 
        :param folder: 
        :param parameters: 
        :param schema_column: schema_column block.
        :param table_name: 
        :param timeouts: timeouts block.
        """
        if isinstance(lifecycle, dict):
            lifecycle = cdktf.TerraformResourceLifecycle(**lifecycle)
        if isinstance(timeouts, dict):
            timeouts = DataFactoryDatasetMysqlTimeouts(**timeouts)
        self._values: typing.Dict[str, typing.Any] = {
            "data_factory_name": data_factory_name,
            "linked_service_name": linked_service_name,
            "name": name,
            "resource_group_name": resource_group_name,
        }
        if count is not None:
            self._values["count"] = count
        if depends_on is not None:
            self._values["depends_on"] = depends_on
        if lifecycle is not None:
            self._values["lifecycle"] = lifecycle
        if provider is not None:
            self._values["provider"] = provider
        if additional_properties is not None:
            self._values["additional_properties"] = additional_properties
        if annotations is not None:
            self._values["annotations"] = annotations
        if description is not None:
            self._values["description"] = description
        if folder is not None:
            self._values["folder"] = folder
        if parameters is not None:
            self._values["parameters"] = parameters
        if schema_column is not None:
            self._values["schema_column"] = schema_column
        if table_name is not None:
            self._values["table_name"] = table_name
        if timeouts is not None:
            self._values["timeouts"] = timeouts

    @builtins.property
    def count(self) -> typing.Optional[jsii.Number]:
        """
        :stability: experimental
        """
        result = self._values.get("count")
        return result

    @builtins.property
    def depends_on(self) -> typing.Optional[typing.List[cdktf.TerraformResource]]:
        """
        :stability: experimental
        """
        result = self._values.get("depends_on")
        return result

    @builtins.property
    def lifecycle(self) -> typing.Optional[cdktf.TerraformResourceLifecycle]:
        """
        :stability: experimental
        """
        result = self._values.get("lifecycle")
        return result

    @builtins.property
    def provider(self) -> typing.Optional[cdktf.TerraformProvider]:
        """
        :stability: experimental
        """
        result = self._values.get("provider")
        return result

    @builtins.property
    def data_factory_name(self) -> builtins.str:
        result = self._values.get("data_factory_name")
        assert result is not None, "Required property 'data_factory_name' is missing"
        return result

    @builtins.property
    def linked_service_name(self) -> builtins.str:
        result = self._values.get("linked_service_name")
        assert result is not None, "Required property 'linked_service_name' is missing"
        return result

    @builtins.property
    def name(self) -> builtins.str:
        result = self._values.get("name")
        assert result is not None, "Required property 'name' is missing"
        return result

    @builtins.property
    def resource_group_name(self) -> builtins.str:
        result = self._values.get("resource_group_name")
        assert result is not None, "Required property 'resource_group_name' is missing"
        return result

    @builtins.property
    def additional_properties(
        self,
    ) -> typing.Optional[typing.Mapping[builtins.str, builtins.str]]:
        result = self._values.get("additional_properties")
        return result

    @builtins.property
    def annotations(self) -> typing.Optional[typing.List[builtins.str]]:
        result = self._values.get("annotations")
        return result

    @builtins.property
    def description(self) -> typing.Optional[builtins.str]:
        result = self._values.get("description")
        return result

    @builtins.property
    def folder(self) -> typing.Optional[builtins.str]:
        result = self._values.get("folder")
        return result

    @builtins.property
    def parameters(self) -> typing.Optional[typing.Mapping[builtins.str, builtins.str]]:
        result = self._values.get("parameters")
        return result

    @builtins.property
    def schema_column(
        self,
    ) -> typing.Optional[typing.List["DataFactoryDatasetMysqlSchemaColumn"]]:
        """schema_column block."""
        result = self._values.get("schema_column")
        return result

    @builtins.property
    def table_name(self) -> typing.Optional[builtins.str]:
        result = self._values.get("table_name")
        return result

    @builtins.property
    def timeouts(self) -> typing.Optional["DataFactoryDatasetMysqlTimeouts"]:
        """timeouts block."""
        result = self._values.get("timeouts")
        return result

    def __eq__(self, rhs: typing.Any) -> builtins.bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs: typing.Any) -> builtins.bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return "DataFactoryDatasetMysqlConfig(%s)" % ", ".join(
            k + "=" + repr(v) for k, v in self._values.items()
        )


@jsii.data_type(
    jsii_type="@cdktf/provider-azurerm.DataFactoryDatasetMysqlSchemaColumn",
    jsii_struct_bases=[],
    name_mapping={"name": "name", "description": "description", "type": "type"},
)
class DataFactoryDatasetMysqlSchemaColumn:
    def __init__(
        self,
        *,
        name: builtins.str,
        description: typing.Optional[builtins.str] = None,
        type: typing.Optional[builtins.str] = None,
    ) -> None:
        """
        :param name: 
        :param description: 
        :param type: 
        """
        self._values: typing.Dict[str, typing.Any] = {
            "name": name,
        }
        if description is not None:
            self._values["description"] = description
        if type is not None:
            self._values["type"] = type

    @builtins.property
    def name(self) -> builtins.str:
        result = self._values.get("name")
        assert result is not None, "Required property 'name' is missing"
        return result

    @builtins.property
    def description(self) -> typing.Optional[builtins.str]:
        result = self._values.get("description")
        return result

    @builtins.property
    def type(self) -> typing.Optional[builtins.str]:
        result = self._values.get("type")
        return result

    def __eq__(self, rhs: typing.Any) -> builtins.bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs: typing.Any) -> builtins.bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return "DataFactoryDatasetMysqlSchemaColumn(%s)" % ", ".join(
            k + "=" + repr(v) for k, v in self._values.items()
        )


@jsii.data_type(
    jsii_type="@cdktf/provider-azurerm.DataFactoryDatasetMysqlTimeouts",
    jsii_struct_bases=[],
    name_mapping={
        "create": "create",
        "delete": "delete",
        "read": "read",
        "update": "update",
    },
)
class DataFactoryDatasetMysqlTimeouts:
    def __init__(
        self,
        *,
        create: typing.Optional[builtins.str] = None,
        delete: typing.Optional[builtins.str] = None,
        read: typing.Optional[builtins.str] = None,
        update: typing.Optional[builtins.str] = None,
    ) -> None:
        """
        :param create: 
        :param delete: 
        :param read: 
        :param update: 
        """
        self._values: typing.Dict[str, typing.Any] = {}
        if create is not None:
            self._values["create"] = create
        if delete is not None:
            self._values["delete"] = delete
        if read is not None:
            self._values["read"] = read
        if update is not None:
            self._values["update"] = update

    @builtins.property
    def create(self) -> typing.Optional[builtins.str]:
        result = self._values.get("create")
        return result

    @builtins.property
    def delete(self) -> typing.Optional[builtins.str]:
        result = self._values.get("delete")
        return result

    @builtins.property
    def read(self) -> typing.Optional[builtins.str]:
        result = self._values.get("read")
        return result

    @builtins.property
    def update(self) -> typing.Optional[builtins.str]:
        result = self._values.get("update")
        return result

    def __eq__(self, rhs: typing.Any) -> builtins.bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs: typing.Any) -> builtins.bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return "DataFactoryDatasetMysqlTimeouts(%s)" % ", ".join(
            k + "=" + repr(v) for k, v in self._values.items()
        )


class DataFactoryDatasetPostgresql(
    cdktf.TerraformResource,
    metaclass=jsii.JSIIMeta,
    jsii_type="@cdktf/provider-azurerm.DataFactoryDatasetPostgresql",
):
    def __init__(
        self,
        scope: constructs.Construct,
        id: builtins.str,
        *,
        data_factory_name: builtins.str,
        linked_service_name: builtins.str,
        name: builtins.str,
        resource_group_name: builtins.str,
        additional_properties: typing.Optional[typing.Mapping[builtins.str, builtins.str]] = None,
        annotations: typing.Optional[typing.List[builtins.str]] = None,
        description: typing.Optional[builtins.str] = None,
        folder: typing.Optional[builtins.str] = None,
        parameters: typing.Optional[typing.Mapping[builtins.str, builtins.str]] = None,
        schema_column: typing.Optional[typing.List["DataFactoryDatasetPostgresqlSchemaColumn"]] = None,
        table_name: typing.Optional[builtins.str] = None,
        timeouts: typing.Optional["DataFactoryDatasetPostgresqlTimeouts"] = None,
        count: typing.Optional[jsii.Number] = None,
        depends_on: typing.Optional[typing.List[cdktf.TerraformResource]] = None,
        lifecycle: typing.Optional[cdktf.TerraformResourceLifecycle] = None,
        provider: typing.Optional[cdktf.TerraformProvider] = None,
    ) -> None:
        """
        :param scope: -
        :param id: -
        :param data_factory_name: 
        :param linked_service_name: 
        :param name: 
        :param resource_group_name: 
        :param additional_properties: 
        :param annotations: 
        :param description: 
        :param folder: 
        :param parameters: 
        :param schema_column: schema_column block.
        :param table_name: 
        :param timeouts: timeouts block.
        :param count: 
        :param depends_on: 
        :param lifecycle: 
        :param provider: 
        """
        config = DataFactoryDatasetPostgresqlConfig(
            data_factory_name=data_factory_name,
            linked_service_name=linked_service_name,
            name=name,
            resource_group_name=resource_group_name,
            additional_properties=additional_properties,
            annotations=annotations,
            description=description,
            folder=folder,
            parameters=parameters,
            schema_column=schema_column,
            table_name=table_name,
            timeouts=timeouts,
            count=count,
            depends_on=depends_on,
            lifecycle=lifecycle,
            provider=provider,
        )

        jsii.create(DataFactoryDatasetPostgresql, self, [scope, id, config])

    @jsii.member(jsii_name="synthesizeAttributes")
    def _synthesize_attributes(self) -> typing.Mapping[builtins.str, typing.Any]:
        return jsii.invoke(self, "synthesizeAttributes", [])

    @builtins.property # type: ignore
    @jsii.member(jsii_name="dataFactoryName")
    def data_factory_name(self) -> builtins.str:
        return jsii.get(self, "dataFactoryName")

    @data_factory_name.setter # type: ignore
    def data_factory_name(self, value: builtins.str) -> None:
        jsii.set(self, "dataFactoryName", value)

    @builtins.property # type: ignore
    @jsii.member(jsii_name="linkedServiceName")
    def linked_service_name(self) -> builtins.str:
        return jsii.get(self, "linkedServiceName")

    @linked_service_name.setter # type: ignore
    def linked_service_name(self, value: builtins.str) -> None:
        jsii.set(self, "linkedServiceName", value)

    @builtins.property # type: ignore
    @jsii.member(jsii_name="name")
    def name(self) -> builtins.str:
        return jsii.get(self, "name")

    @name.setter # type: ignore
    def name(self, value: builtins.str) -> None:
        jsii.set(self, "name", value)

    @builtins.property # type: ignore
    @jsii.member(jsii_name="resourceGroupName")
    def resource_group_name(self) -> builtins.str:
        return jsii.get(self, "resourceGroupName")

    @resource_group_name.setter # type: ignore
    def resource_group_name(self, value: builtins.str) -> None:
        jsii.set(self, "resourceGroupName", value)

    @builtins.property # type: ignore
    @jsii.member(jsii_name="additionalProperties")
    def additional_properties(
        self,
    ) -> typing.Optional[typing.Mapping[builtins.str, builtins.str]]:
        return jsii.get(self, "additionalProperties")

    @additional_properties.setter # type: ignore
    def additional_properties(
        self,
        value: typing.Optional[typing.Mapping[builtins.str, builtins.str]],
    ) -> None:
        jsii.set(self, "additionalProperties", value)

    @builtins.property # type: ignore
    @jsii.member(jsii_name="annotations")
    def annotations(self) -> typing.Optional[typing.List[builtins.str]]:
        return jsii.get(self, "annotations")

    @annotations.setter # type: ignore
    def annotations(self, value: typing.Optional[typing.List[builtins.str]]) -> None:
        jsii.set(self, "annotations", value)

    @builtins.property # type: ignore
    @jsii.member(jsii_name="description")
    def description(self) -> typing.Optional[builtins.str]:
        return jsii.get(self, "description")

    @description.setter # type: ignore
    def description(self, value: typing.Optional[builtins.str]) -> None:
        jsii.set(self, "description", value)

    @builtins.property # type: ignore
    @jsii.member(jsii_name="folder")
    def folder(self) -> typing.Optional[builtins.str]:
        return jsii.get(self, "folder")

    @folder.setter # type: ignore
    def folder(self, value: typing.Optional[builtins.str]) -> None:
        jsii.set(self, "folder", value)

    @builtins.property # type: ignore
    @jsii.member(jsii_name="id")
    def id(self) -> typing.Optional[builtins.str]:
        return jsii.get(self, "id")

    @id.setter # type: ignore
    def id(self, value: typing.Optional[builtins.str]) -> None:
        jsii.set(self, "id", value)

    @builtins.property # type: ignore
    @jsii.member(jsii_name="parameters")
    def parameters(self) -> typing.Optional[typing.Mapping[builtins.str, builtins.str]]:
        return jsii.get(self, "parameters")

    @parameters.setter # type: ignore
    def parameters(
        self,
        value: typing.Optional[typing.Mapping[builtins.str, builtins.str]],
    ) -> None:
        jsii.set(self, "parameters", value)

    @builtins.property # type: ignore
    @jsii.member(jsii_name="schemaColumn")
    def schema_column(
        self,
    ) -> typing.Optional[typing.List["DataFactoryDatasetPostgresqlSchemaColumn"]]:
        return jsii.get(self, "schemaColumn")

    @schema_column.setter # type: ignore
    def schema_column(
        self,
        value: typing.Optional[typing.List["DataFactoryDatasetPostgresqlSchemaColumn"]],
    ) -> None:
        jsii.set(self, "schemaColumn", value)

    @builtins.property # type: ignore
    @jsii.member(jsii_name="tableName")
    def table_name(self) -> typing.Optional[builtins.str]:
        return jsii.get(self, "tableName")

    @table_name.setter # type: ignore
    def table_name(self, value: typing.Optional[builtins.str]) -> None:
        jsii.set(self, "tableName", value)

    @builtins.property # type: ignore
    @jsii.member(jsii_name="timeouts")
    def timeouts(self) -> typing.Optional["DataFactoryDatasetPostgresqlTimeouts"]:
        return jsii.get(self, "timeouts")

    @timeouts.setter # type: ignore
    def timeouts(
        self,
        value: typing.Optional["DataFactoryDatasetPostgresqlTimeouts"],
    ) -> None:
        jsii.set(self, "timeouts", value)


@jsii.data_type(
    jsii_type="@cdktf/provider-azurerm.DataFactoryDatasetPostgresqlConfig",
    jsii_struct_bases=[cdktf.TerraformMetaArguments],
    name_mapping={
        "count": "count",
        "depends_on": "dependsOn",
        "lifecycle": "lifecycle",
        "provider": "provider",
        "data_factory_name": "dataFactoryName",
        "linked_service_name": "linkedServiceName",
        "name": "name",
        "resource_group_name": "resourceGroupName",
        "additional_properties": "additionalProperties",
        "annotations": "annotations",
        "description": "description",
        "folder": "folder",
        "parameters": "parameters",
        "schema_column": "schemaColumn",
        "table_name": "tableName",
        "timeouts": "timeouts",
    },
)
class DataFactoryDatasetPostgresqlConfig(cdktf.TerraformMetaArguments):
    def __init__(
        self,
        *,
        count: typing.Optional[jsii.Number] = None,
        depends_on: typing.Optional[typing.List[cdktf.TerraformResource]] = None,
        lifecycle: typing.Optional[cdktf.TerraformResourceLifecycle] = None,
        provider: typing.Optional[cdktf.TerraformProvider] = None,
        data_factory_name: builtins.str,
        linked_service_name: builtins.str,
        name: builtins.str,
        resource_group_name: builtins.str,
        additional_properties: typing.Optional[typing.Mapping[builtins.str, builtins.str]] = None,
        annotations: typing.Optional[typing.List[builtins.str]] = None,
        description: typing.Optional[builtins.str] = None,
        folder: typing.Optional[builtins.str] = None,
        parameters: typing.Optional[typing.Mapping[builtins.str, builtins.str]] = None,
        schema_column: typing.Optional[typing.List["DataFactoryDatasetPostgresqlSchemaColumn"]] = None,
        table_name: typing.Optional[builtins.str] = None,
        timeouts: typing.Optional["DataFactoryDatasetPostgresqlTimeouts"] = None,
    ) -> None:
        """
        :param count: 
        :param depends_on: 
        :param lifecycle: 
        :param provider: 
        :param data_factory_name: 
        :param linked_service_name: 
        :param name: 
        :param resource_group_name: 
        :param additional_properties: 
        :param annotations: 
        :param description: 
        :param folder: 
        :param parameters: 
        :param schema_column: schema_column block.
        :param table_name: 
        :param timeouts: timeouts block.
        """
        if isinstance(lifecycle, dict):
            lifecycle = cdktf.TerraformResourceLifecycle(**lifecycle)
        if isinstance(timeouts, dict):
            timeouts = DataFactoryDatasetPostgresqlTimeouts(**timeouts)
        self._values: typing.Dict[str, typing.Any] = {
            "data_factory_name": data_factory_name,
            "linked_service_name": linked_service_name,
            "name": name,
            "resource_group_name": resource_group_name,
        }
        if count is not None:
            self._values["count"] = count
        if depends_on is not None:
            self._values["depends_on"] = depends_on
        if lifecycle is not None:
            self._values["lifecycle"] = lifecycle
        if provider is not None:
            self._values["provider"] = provider
        if additional_properties is not None:
            self._values["additional_properties"] = additional_properties
        if annotations is not None:
            self._values["annotations"] = annotations
        if description is not None:
            self._values["description"] = description
        if folder is not None:
            self._values["folder"] = folder
        if parameters is not None:
            self._values["parameters"] = parameters
        if schema_column is not None:
            self._values["schema_column"] = schema_column
        if table_name is not None:
            self._values["table_name"] = table_name
        if timeouts is not None:
            self._values["timeouts"] = timeouts

    @builtins.property
    def count(self) -> typing.Optional[jsii.Number]:
        """
        :stability: experimental
        """
        result = self._values.get("count")
        return result

    @builtins.property
    def depends_on(self) -> typing.Optional[typing.List[cdktf.TerraformResource]]:
        """
        :stability: experimental
        """
        result = self._values.get("depends_on")
        return result

    @builtins.property
    def lifecycle(self) -> typing.Optional[cdktf.TerraformResourceLifecycle]:
        """
        :stability: experimental
        """
        result = self._values.get("lifecycle")
        return result

    @builtins.property
    def provider(self) -> typing.Optional[cdktf.TerraformProvider]:
        """
        :stability: experimental
        """
        result = self._values.get("provider")
        return result

    @builtins.property
    def data_factory_name(self) -> builtins.str:
        result = self._values.get("data_factory_name")
        assert result is not None, "Required property 'data_factory_name' is missing"
        return result

    @builtins.property
    def linked_service_name(self) -> builtins.str:
        result = self._values.get("linked_service_name")
        assert result is not None, "Required property 'linked_service_name' is missing"
        return result

    @builtins.property
    def name(self) -> builtins.str:
        result = self._values.get("name")
        assert result is not None, "Required property 'name' is missing"
        return result

    @builtins.property
    def resource_group_name(self) -> builtins.str:
        result = self._values.get("resource_group_name")
        assert result is not None, "Required property 'resource_group_name' is missing"
        return result

    @builtins.property
    def additional_properties(
        self,
    ) -> typing.Optional[typing.Mapping[builtins.str, builtins.str]]:
        result = self._values.get("additional_properties")
        return result

    @builtins.property
    def annotations(self) -> typing.Optional[typing.List[builtins.str]]:
        result = self._values.get("annotations")
        return result

    @builtins.property
    def description(self) -> typing.Optional[builtins.str]:
        result = self._values.get("description")
        return result

    @builtins.property
    def folder(self) -> typing.Optional[builtins.str]:
        result = self._values.get("folder")
        return result

    @builtins.property
    def parameters(self) -> typing.Optional[typing.Mapping[builtins.str, builtins.str]]:
        result = self._values.get("parameters")
        return result

    @builtins.property
    def schema_column(
        self,
    ) -> typing.Optional[typing.List["DataFactoryDatasetPostgresqlSchemaColumn"]]:
        """schema_column block."""
        result = self._values.get("schema_column")
        return result

    @builtins.property
    def table_name(self) -> typing.Optional[builtins.str]:
        result = self._values.get("table_name")
        return result

    @builtins.property
    def timeouts(self) -> typing.Optional["DataFactoryDatasetPostgresqlTimeouts"]:
        """timeouts block."""
        result = self._values.get("timeouts")
        return result

    def __eq__(self, rhs: typing.Any) -> builtins.bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs: typing.Any) -> builtins.bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return "DataFactoryDatasetPostgresqlConfig(%s)" % ", ".join(
            k + "=" + repr(v) for k, v in self._values.items()
        )


@jsii.data_type(
    jsii_type="@cdktf/provider-azurerm.DataFactoryDatasetPostgresqlSchemaColumn",
    jsii_struct_bases=[],
    name_mapping={"name": "name", "description": "description", "type": "type"},
)
class DataFactoryDatasetPostgresqlSchemaColumn:
    def __init__(
        self,
        *,
        name: builtins.str,
        description: typing.Optional[builtins.str] = None,
        type: typing.Optional[builtins.str] = None,
    ) -> None:
        """
        :param name: 
        :param description: 
        :param type: 
        """
        self._values: typing.Dict[str, typing.Any] = {
            "name": name,
        }
        if description is not None:
            self._values["description"] = description
        if type is not None:
            self._values["type"] = type

    @builtins.property
    def name(self) -> builtins.str:
        result = self._values.get("name")
        assert result is not None, "Required property 'name' is missing"
        return result

    @builtins.property
    def description(self) -> typing.Optional[builtins.str]:
        result = self._values.get("description")
        return result

    @builtins.property
    def type(self) -> typing.Optional[builtins.str]:
        result = self._values.get("type")
        return result

    def __eq__(self, rhs: typing.Any) -> builtins.bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs: typing.Any) -> builtins.bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return "DataFactoryDatasetPostgresqlSchemaColumn(%s)" % ", ".join(
            k + "=" + repr(v) for k, v in self._values.items()
        )


@jsii.data_type(
    jsii_type="@cdktf/provider-azurerm.DataFactoryDatasetPostgresqlTimeouts",
    jsii_struct_bases=[],
    name_mapping={
        "create": "create",
        "delete": "delete",
        "read": "read",
        "update": "update",
    },
)
class DataFactoryDatasetPostgresqlTimeouts:
    def __init__(
        self,
        *,
        create: typing.Optional[builtins.str] = None,
        delete: typing.Optional[builtins.str] = None,
        read: typing.Optional[builtins.str] = None,
        update: typing.Optional[builtins.str] = None,
    ) -> None:
        """
        :param create: 
        :param delete: 
        :param read: 
        :param update: 
        """
        self._values: typing.Dict[str, typing.Any] = {}
        if create is not None:
            self._values["create"] = create
        if delete is not None:
            self._values["delete"] = delete
        if read is not None:
            self._values["read"] = read
        if update is not None:
            self._values["update"] = update

    @builtins.property
    def create(self) -> typing.Optional[builtins.str]:
        result = self._values.get("create")
        return result

    @builtins.property
    def delete(self) -> typing.Optional[builtins.str]:
        result = self._values.get("delete")
        return result

    @builtins.property
    def read(self) -> typing.Optional[builtins.str]:
        result = self._values.get("read")
        return result

    @builtins.property
    def update(self) -> typing.Optional[builtins.str]:
        result = self._values.get("update")
        return result

    def __eq__(self, rhs: typing.Any) -> builtins.bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs: typing.Any) -> builtins.bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return "DataFactoryDatasetPostgresqlTimeouts(%s)" % ", ".join(
            k + "=" + repr(v) for k, v in self._values.items()
        )


class DataFactoryDatasetSqlServerTable(
    cdktf.TerraformResource,
    metaclass=jsii.JSIIMeta,
    jsii_type="@cdktf/provider-azurerm.DataFactoryDatasetSqlServerTable",
):
    def __init__(
        self,
        scope: constructs.Construct,
        id: builtins.str,
        *,
        data_factory_name: builtins.str,
        linked_service_name: builtins.str,
        name: builtins.str,
        resource_group_name: builtins.str,
        additional_properties: typing.Optional[typing.Mapping[builtins.str, builtins.str]] = None,
        annotations: typing.Optional[typing.List[builtins.str]] = None,
        description: typing.Optional[builtins.str] = None,
        folder: typing.Optional[builtins.str] = None,
        parameters: typing.Optional[typing.Mapping[builtins.str, builtins.str]] = None,
        schema_column: typing.Optional[typing.List["DataFactoryDatasetSqlServerTableSchemaColumn"]] = None,
        table_name: typing.Optional[builtins.str] = None,
        timeouts: typing.Optional["DataFactoryDatasetSqlServerTableTimeouts"] = None,
        count: typing.Optional[jsii.Number] = None,
        depends_on: typing.Optional[typing.List[cdktf.TerraformResource]] = None,
        lifecycle: typing.Optional[cdktf.TerraformResourceLifecycle] = None,
        provider: typing.Optional[cdktf.TerraformProvider] = None,
    ) -> None:
        """
        :param scope: -
        :param id: -
        :param data_factory_name: 
        :param linked_service_name: 
        :param name: 
        :param resource_group_name: 
        :param additional_properties: 
        :param annotations: 
        :param description: 
        :param folder: 
        :param parameters: 
        :param schema_column: schema_column block.
        :param table_name: 
        :param timeouts: timeouts block.
        :param count: 
        :param depends_on: 
        :param lifecycle: 
        :param provider: 
        """
        config = DataFactoryDatasetSqlServerTableConfig(
            data_factory_name=data_factory_name,
            linked_service_name=linked_service_name,
            name=name,
            resource_group_name=resource_group_name,
            additional_properties=additional_properties,
            annotations=annotations,
            description=description,
            folder=folder,
            parameters=parameters,
            schema_column=schema_column,
            table_name=table_name,
            timeouts=timeouts,
            count=count,
            depends_on=depends_on,
            lifecycle=lifecycle,
            provider=provider,
        )

        jsii.create(DataFactoryDatasetSqlServerTable, self, [scope, id, config])

    @jsii.member(jsii_name="synthesizeAttributes")
    def _synthesize_attributes(self) -> typing.Mapping[builtins.str, typing.Any]:
        return jsii.invoke(self, "synthesizeAttributes", [])

    @builtins.property # type: ignore
    @jsii.member(jsii_name="dataFactoryName")
    def data_factory_name(self) -> builtins.str:
        return jsii.get(self, "dataFactoryName")

    @data_factory_name.setter # type: ignore
    def data_factory_name(self, value: builtins.str) -> None:
        jsii.set(self, "dataFactoryName", value)

    @builtins.property # type: ignore
    @jsii.member(jsii_name="linkedServiceName")
    def linked_service_name(self) -> builtins.str:
        return jsii.get(self, "linkedServiceName")

    @linked_service_name.setter # type: ignore
    def linked_service_name(self, value: builtins.str) -> None:
        jsii.set(self, "linkedServiceName", value)

    @builtins.property # type: ignore
    @jsii.member(jsii_name="name")
    def name(self) -> builtins.str:
        return jsii.get(self, "name")

    @name.setter # type: ignore
    def name(self, value: builtins.str) -> None:
        jsii.set(self, "name", value)

    @builtins.property # type: ignore
    @jsii.member(jsii_name="resourceGroupName")
    def resource_group_name(self) -> builtins.str:
        return jsii.get(self, "resourceGroupName")

    @resource_group_name.setter # type: ignore
    def resource_group_name(self, value: builtins.str) -> None:
        jsii.set(self, "resourceGroupName", value)

    @builtins.property # type: ignore
    @jsii.member(jsii_name="additionalProperties")
    def additional_properties(
        self,
    ) -> typing.Optional[typing.Mapping[builtins.str, builtins.str]]:
        return jsii.get(self, "additionalProperties")

    @additional_properties.setter # type: ignore
    def additional_properties(
        self,
        value: typing.Optional[typing.Mapping[builtins.str, builtins.str]],
    ) -> None:
        jsii.set(self, "additionalProperties", value)

    @builtins.property # type: ignore
    @jsii.member(jsii_name="annotations")
    def annotations(self) -> typing.Optional[typing.List[builtins.str]]:
        return jsii.get(self, "annotations")

    @annotations.setter # type: ignore
    def annotations(self, value: typing.Optional[typing.List[builtins.str]]) -> None:
        jsii.set(self, "annotations", value)

    @builtins.property # type: ignore
    @jsii.member(jsii_name="description")
    def description(self) -> typing.Optional[builtins.str]:
        return jsii.get(self, "description")

    @description.setter # type: ignore
    def description(self, value: typing.Optional[builtins.str]) -> None:
        jsii.set(self, "description", value)

    @builtins.property # type: ignore
    @jsii.member(jsii_name="folder")
    def folder(self) -> typing.Optional[builtins.str]:
        return jsii.get(self, "folder")

    @folder.setter # type: ignore
    def folder(self, value: typing.Optional[builtins.str]) -> None:
        jsii.set(self, "folder", value)

    @builtins.property # type: ignore
    @jsii.member(jsii_name="id")
    def id(self) -> typing.Optional[builtins.str]:
        return jsii.get(self, "id")

    @id.setter # type: ignore
    def id(self, value: typing.Optional[builtins.str]) -> None:
        jsii.set(self, "id", value)

    @builtins.property # type: ignore
    @jsii.member(jsii_name="parameters")
    def parameters(self) -> typing.Optional[typing.Mapping[builtins.str, builtins.str]]:
        return jsii.get(self, "parameters")

    @parameters.setter # type: ignore
    def parameters(
        self,
        value: typing.Optional[typing.Mapping[builtins.str, builtins.str]],
    ) -> None:
        jsii.set(self, "parameters", value)

    @builtins.property # type: ignore
    @jsii.member(jsii_name="schemaColumn")
    def schema_column(
        self,
    ) -> typing.Optional[typing.List["DataFactoryDatasetSqlServerTableSchemaColumn"]]:
        return jsii.get(self, "schemaColumn")

    @schema_column.setter # type: ignore
    def schema_column(
        self,
        value: typing.Optional[typing.List["DataFactoryDatasetSqlServerTableSchemaColumn"]],
    ) -> None:
        jsii.set(self, "schemaColumn", value)

    @builtins.property # type: ignore
    @jsii.member(jsii_name="tableName")
    def table_name(self) -> typing.Optional[builtins.str]:
        return jsii.get(self, "tableName")

    @table_name.setter # type: ignore
    def table_name(self, value: typing.Optional[builtins.str]) -> None:
        jsii.set(self, "tableName", value)

    @builtins.property # type: ignore
    @jsii.member(jsii_name="timeouts")
    def timeouts(self) -> typing.Optional["DataFactoryDatasetSqlServerTableTimeouts"]:
        return jsii.get(self, "timeouts")

    @timeouts.setter # type: ignore
    def timeouts(
        self,
        value: typing.Optional["DataFactoryDatasetSqlServerTableTimeouts"],
    ) -> None:
        jsii.set(self, "timeouts", value)


@jsii.data_type(
    jsii_type="@cdktf/provider-azurerm.DataFactoryDatasetSqlServerTableConfig",
    jsii_struct_bases=[cdktf.TerraformMetaArguments],
    name_mapping={
        "count": "count",
        "depends_on": "dependsOn",
        "lifecycle": "lifecycle",
        "provider": "provider",
        "data_factory_name": "dataFactoryName",
        "linked_service_name": "linkedServiceName",
        "name": "name",
        "resource_group_name": "resourceGroupName",
        "additional_properties": "additionalProperties",
        "annotations": "annotations",
        "description": "description",
        "folder": "folder",
        "parameters": "parameters",
        "schema_column": "schemaColumn",
        "table_name": "tableName",
        "timeouts": "timeouts",
    },
)
class DataFactoryDatasetSqlServerTableConfig(cdktf.TerraformMetaArguments):
    def __init__(
        self,
        *,
        count: typing.Optional[jsii.Number] = None,
        depends_on: typing.Optional[typing.List[cdktf.TerraformResource]] = None,
        lifecycle: typing.Optional[cdktf.TerraformResourceLifecycle] = None,
        provider: typing.Optional[cdktf.TerraformProvider] = None,
        data_factory_name: builtins.str,
        linked_service_name: builtins.str,
        name: builtins.str,
        resource_group_name: builtins.str,
        additional_properties: typing.Optional[typing.Mapping[builtins.str, builtins.str]] = None,
        annotations: typing.Optional[typing.List[builtins.str]] = None,
        description: typing.Optional[builtins.str] = None,
        folder: typing.Optional[builtins.str] = None,
        parameters: typing.Optional[typing.Mapping[builtins.str, builtins.str]] = None,
        schema_column: typing.Optional[typing.List["DataFactoryDatasetSqlServerTableSchemaColumn"]] = None,
        table_name: typing.Optional[builtins.str] = None,
        timeouts: typing.Optional["DataFactoryDatasetSqlServerTableTimeouts"] = None,
    ) -> None:
        """
        :param count: 
        :param depends_on: 
        :param lifecycle: 
        :param provider: 
        :param data_factory_name: 
        :param linked_service_name: 
        :param name: 
        :param resource_group_name: 
        :param additional_properties: 
        :param annotations: 
        :param description: 
        :param folder: 
        :param parameters: 
        :param schema_column: schema_column block.
        :param table_name: 
        :param timeouts: timeouts block.
        """
        if isinstance(lifecycle, dict):
            lifecycle = cdktf.TerraformResourceLifecycle(**lifecycle)
        if isinstance(timeouts, dict):
            timeouts = DataFactoryDatasetSqlServerTableTimeouts(**timeouts)
        self._values: typing.Dict[str, typing.Any] = {
            "data_factory_name": data_factory_name,
            "linked_service_name": linked_service_name,
            "name": name,
            "resource_group_name": resource_group_name,
        }
        if count is not None:
            self._values["count"] = count
        if depends_on is not None:
            self._values["depends_on"] = depends_on
        if lifecycle is not None:
            self._values["lifecycle"] = lifecycle
        if provider is not None:
            self._values["provider"] = provider
        if additional_properties is not None:
            self._values["additional_properties"] = additional_properties
        if annotations is not None:
            self._values["annotations"] = annotations
        if description is not None:
            self._values["description"] = description
        if folder is not None:
            self._values["folder"] = folder
        if parameters is not None:
            self._values["parameters"] = parameters
        if schema_column is not None:
            self._values["schema_column"] = schema_column
        if table_name is not None:
            self._values["table_name"] = table_name
        if timeouts is not None:
            self._values["timeouts"] = timeouts

    @builtins.property
    def count(self) -> typing.Optional[jsii.Number]:
        """
        :stability: experimental
        """
        result = self._values.get("count")
        return result

    @builtins.property
    def depends_on(self) -> typing.Optional[typing.List[cdktf.TerraformResource]]:
        """
        :stability: experimental
        """
        result = self._values.get("depends_on")
        return result

    @builtins.property
    def lifecycle(self) -> typing.Optional[cdktf.TerraformResourceLifecycle]:
        """
        :stability: experimental
        """
        result = self._values.get("lifecycle")
        return result

    @builtins.property
    def provider(self) -> typing.Optional[cdktf.TerraformProvider]:
        """
        :stability: experimental
        """
        result = self._values.get("provider")
        return result

    @builtins.property
    def data_factory_name(self) -> builtins.str:
        result = self._values.get("data_factory_name")
        assert result is not None, "Required property 'data_factory_name' is missing"
        return result

    @builtins.property
    def linked_service_name(self) -> builtins.str:
        result = self._values.get("linked_service_name")
        assert result is not None, "Required property 'linked_service_name' is missing"
        return result

    @builtins.property
    def name(self) -> builtins.str:
        result = self._values.get("name")
        assert result is not None, "Required property 'name' is missing"
        return result

    @builtins.property
    def resource_group_name(self) -> builtins.str:
        result = self._values.get("resource_group_name")
        assert result is not None, "Required property 'resource_group_name' is missing"
        return result

    @builtins.property
    def additional_properties(
        self,
    ) -> typing.Optional[typing.Mapping[builtins.str, builtins.str]]:
        result = self._values.get("additional_properties")
        return result

    @builtins.property
    def annotations(self) -> typing.Optional[typing.List[builtins.str]]:
        result = self._values.get("annotations")
        return result

    @builtins.property
    def description(self) -> typing.Optional[builtins.str]:
        result = self._values.get("description")
        return result

    @builtins.property
    def folder(self) -> typing.Optional[builtins.str]:
        result = self._values.get("folder")
        return result

    @builtins.property
    def parameters(self) -> typing.Optional[typing.Mapping[builtins.str, builtins.str]]:
        result = self._values.get("parameters")
        return result

    @builtins.property
    def schema_column(
        self,
    ) -> typing.Optional[typing.List["DataFactoryDatasetSqlServerTableSchemaColumn"]]:
        """schema_column block."""
        result = self._values.get("schema_column")
        return result

    @builtins.property
    def table_name(self) -> typing.Optional[builtins.str]:
        result = self._values.get("table_name")
        return result

    @builtins.property
    def timeouts(self) -> typing.Optional["DataFactoryDatasetSqlServerTableTimeouts"]:
        """timeouts block."""
        result = self._values.get("timeouts")
        return result

    def __eq__(self, rhs: typing.Any) -> builtins.bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs: typing.Any) -> builtins.bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return "DataFactoryDatasetSqlServerTableConfig(%s)" % ", ".join(
            k + "=" + repr(v) for k, v in self._values.items()
        )


@jsii.data_type(
    jsii_type="@cdktf/provider-azurerm.DataFactoryDatasetSqlServerTableSchemaColumn",
    jsii_struct_bases=[],
    name_mapping={"name": "name", "description": "description", "type": "type"},
)
class DataFactoryDatasetSqlServerTableSchemaColumn:
    def __init__(
        self,
        *,
        name: builtins.str,
        description: typing.Optional[builtins.str] = None,
        type: typing.Optional[builtins.str] = None,
    ) -> None:
        """
        :param name: 
        :param description: 
        :param type: 
        """
        self._values: typing.Dict[str, typing.Any] = {
            "name": name,
        }
        if description is not None:
            self._values["description"] = description
        if type is not None:
            self._values["type"] = type

    @builtins.property
    def name(self) -> builtins.str:
        result = self._values.get("name")
        assert result is not None, "Required property 'name' is missing"
        return result

    @builtins.property
    def description(self) -> typing.Optional[builtins.str]:
        result = self._values.get("description")
        return result

    @builtins.property
    def type(self) -> typing.Optional[builtins.str]:
        result = self._values.get("type")
        return result

    def __eq__(self, rhs: typing.Any) -> builtins.bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs: typing.Any) -> builtins.bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return "DataFactoryDatasetSqlServerTableSchemaColumn(%s)" % ", ".join(
            k + "=" + repr(v) for k, v in self._values.items()
        )


@jsii.data_type(
    jsii_type="@cdktf/provider-azurerm.DataFactoryDatasetSqlServerTableTimeouts",
    jsii_struct_bases=[],
    name_mapping={
        "create": "create",
        "delete": "delete",
        "read": "read",
        "update": "update",
    },
)
class DataFactoryDatasetSqlServerTableTimeouts:
    def __init__(
        self,
        *,
        create: typing.Optional[builtins.str] = None,
        delete: typing.Optional[builtins.str] = None,
        read: typing.Optional[builtins.str] = None,
        update: typing.Optional[builtins.str] = None,
    ) -> None:
        """
        :param create: 
        :param delete: 
        :param read: 
        :param update: 
        """
        self._values: typing.Dict[str, typing.Any] = {}
        if create is not None:
            self._values["create"] = create
        if delete is not None:
            self._values["delete"] = delete
        if read is not None:
            self._values["read"] = read
        if update is not None:
            self._values["update"] = update

    @builtins.property
    def create(self) -> typing.Optional[builtins.str]:
        result = self._values.get("create")
        return result

    @builtins.property
    def delete(self) -> typing.Optional[builtins.str]:
        result = self._values.get("delete")
        return result

    @builtins.property
    def read(self) -> typing.Optional[builtins.str]:
        result = self._values.get("read")
        return result

    @builtins.property
    def update(self) -> typing.Optional[builtins.str]:
        result = self._values.get("update")
        return result

    def __eq__(self, rhs: typing.Any) -> builtins.bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs: typing.Any) -> builtins.bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return "DataFactoryDatasetSqlServerTableTimeouts(%s)" % ", ".join(
            k + "=" + repr(v) for k, v in self._values.items()
        )


@jsii.data_type(
    jsii_type="@cdktf/provider-azurerm.DataFactoryGithubConfiguration",
    jsii_struct_bases=[],
    name_mapping={
        "account_name": "accountName",
        "branch_name": "branchName",
        "git_url": "gitUrl",
        "repository_name": "repositoryName",
        "root_folder": "rootFolder",
    },
)
class DataFactoryGithubConfiguration:
    def __init__(
        self,
        *,
        account_name: builtins.str,
        branch_name: builtins.str,
        git_url: builtins.str,
        repository_name: builtins.str,
        root_folder: builtins.str,
    ) -> None:
        """
        :param account_name: 
        :param branch_name: 
        :param git_url: 
        :param repository_name: 
        :param root_folder: 
        """
        self._values: typing.Dict[str, typing.Any] = {
            "account_name": account_name,
            "branch_name": branch_name,
            "git_url": git_url,
            "repository_name": repository_name,
            "root_folder": root_folder,
        }

    @builtins.property
    def account_name(self) -> builtins.str:
        result = self._values.get("account_name")
        assert result is not None, "Required property 'account_name' is missing"
        return result

    @builtins.property
    def branch_name(self) -> builtins.str:
        result = self._values.get("branch_name")
        assert result is not None, "Required property 'branch_name' is missing"
        return result

    @builtins.property
    def git_url(self) -> builtins.str:
        result = self._values.get("git_url")
        assert result is not None, "Required property 'git_url' is missing"
        return result

    @builtins.property
    def repository_name(self) -> builtins.str:
        result = self._values.get("repository_name")
        assert result is not None, "Required property 'repository_name' is missing"
        return result

    @builtins.property
    def root_folder(self) -> builtins.str:
        result = self._values.get("root_folder")
        assert result is not None, "Required property 'root_folder' is missing"
        return result

    def __eq__(self, rhs: typing.Any) -> builtins.bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs: typing.Any) -> builtins.bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return "DataFactoryGithubConfiguration(%s)" % ", ".join(
            k + "=" + repr(v) for k, v in self._values.items()
        )


@jsii.data_type(
    jsii_type="@cdktf/provider-azurerm.DataFactoryIdentity",
    jsii_struct_bases=[],
    name_mapping={"type": "type"},
)
class DataFactoryIdentity:
    def __init__(self, *, type: builtins.str) -> None:
        """
        :param type: 
        """
        self._values: typing.Dict[str, typing.Any] = {
            "type": type,
        }

    @builtins.property
    def type(self) -> builtins.str:
        result = self._values.get("type")
        assert result is not None, "Required property 'type' is missing"
        return result

    def __eq__(self, rhs: typing.Any) -> builtins.bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs: typing.Any) -> builtins.bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return "DataFactoryIdentity(%s)" % ", ".join(
            k + "=" + repr(v) for k, v in self._values.items()
        )


class DataFactoryIntegrationRuntimeManaged(
    cdktf.TerraformResource,
    metaclass=jsii.JSIIMeta,
    jsii_type="@cdktf/provider-azurerm.DataFactoryIntegrationRuntimeManaged",
):
    def __init__(
        self,
        scope: constructs.Construct,
        id: builtins.str,
        *,
        data_factory_name: builtins.str,
        location: builtins.str,
        name: builtins.str,
        node_size: builtins.str,
        resource_group_name: builtins.str,
        catalog_info: typing.Optional[typing.List["DataFactoryIntegrationRuntimeManagedCatalogInfo"]] = None,
        custom_setup_script: typing.Optional[typing.List["DataFactoryIntegrationRuntimeManagedCustomSetupScript"]] = None,
        description: typing.Optional[builtins.str] = None,
        edition: typing.Optional[builtins.str] = None,
        license_type: typing.Optional[builtins.str] = None,
        max_parallel_executions_per_node: typing.Optional[jsii.Number] = None,
        number_of_nodes: typing.Optional[jsii.Number] = None,
        timeouts: typing.Optional["DataFactoryIntegrationRuntimeManagedTimeouts"] = None,
        vnet_integration: typing.Optional[typing.List["DataFactoryIntegrationRuntimeManagedVnetIntegration"]] = None,
        count: typing.Optional[jsii.Number] = None,
        depends_on: typing.Optional[typing.List[cdktf.TerraformResource]] = None,
        lifecycle: typing.Optional[cdktf.TerraformResourceLifecycle] = None,
        provider: typing.Optional[cdktf.TerraformProvider] = None,
    ) -> None:
        """
        :param scope: -
        :param id: -
        :param data_factory_name: 
        :param location: 
        :param name: 
        :param node_size: 
        :param resource_group_name: 
        :param catalog_info: catalog_info block.
        :param custom_setup_script: custom_setup_script block.
        :param description: 
        :param edition: 
        :param license_type: 
        :param max_parallel_executions_per_node: 
        :param number_of_nodes: 
        :param timeouts: timeouts block.
        :param vnet_integration: vnet_integration block.
        :param count: 
        :param depends_on: 
        :param lifecycle: 
        :param provider: 
        """
        config = DataFactoryIntegrationRuntimeManagedConfig(
            data_factory_name=data_factory_name,
            location=location,
            name=name,
            node_size=node_size,
            resource_group_name=resource_group_name,
            catalog_info=catalog_info,
            custom_setup_script=custom_setup_script,
            description=description,
            edition=edition,
            license_type=license_type,
            max_parallel_executions_per_node=max_parallel_executions_per_node,
            number_of_nodes=number_of_nodes,
            timeouts=timeouts,
            vnet_integration=vnet_integration,
            count=count,
            depends_on=depends_on,
            lifecycle=lifecycle,
            provider=provider,
        )

        jsii.create(DataFactoryIntegrationRuntimeManaged, self, [scope, id, config])

    @jsii.member(jsii_name="synthesizeAttributes")
    def _synthesize_attributes(self) -> typing.Mapping[builtins.str, typing.Any]:
        return jsii.invoke(self, "synthesizeAttributes", [])

    @builtins.property # type: ignore
    @jsii.member(jsii_name="dataFactoryName")
    def data_factory_name(self) -> builtins.str:
        return jsii.get(self, "dataFactoryName")

    @data_factory_name.setter # type: ignore
    def data_factory_name(self, value: builtins.str) -> None:
        jsii.set(self, "dataFactoryName", value)

    @builtins.property # type: ignore
    @jsii.member(jsii_name="location")
    def location(self) -> builtins.str:
        return jsii.get(self, "location")

    @location.setter # type: ignore
    def location(self, value: builtins.str) -> None:
        jsii.set(self, "location", value)

    @builtins.property # type: ignore
    @jsii.member(jsii_name="name")
    def name(self) -> builtins.str:
        return jsii.get(self, "name")

    @name.setter # type: ignore
    def name(self, value: builtins.str) -> None:
        jsii.set(self, "name", value)

    @builtins.property # type: ignore
    @jsii.member(jsii_name="nodeSize")
    def node_size(self) -> builtins.str:
        return jsii.get(self, "nodeSize")

    @node_size.setter # type: ignore
    def node_size(self, value: builtins.str) -> None:
        jsii.set(self, "nodeSize", value)

    @builtins.property # type: ignore
    @jsii.member(jsii_name="resourceGroupName")
    def resource_group_name(self) -> builtins.str:
        return jsii.get(self, "resourceGroupName")

    @resource_group_name.setter # type: ignore
    def resource_group_name(self, value: builtins.str) -> None:
        jsii.set(self, "resourceGroupName", value)

    @builtins.property # type: ignore
    @jsii.member(jsii_name="catalogInfo")
    def catalog_info(
        self,
    ) -> typing.Optional[typing.List["DataFactoryIntegrationRuntimeManagedCatalogInfo"]]:
        return jsii.get(self, "catalogInfo")

    @catalog_info.setter # type: ignore
    def catalog_info(
        self,
        value: typing.Optional[typing.List["DataFactoryIntegrationRuntimeManagedCatalogInfo"]],
    ) -> None:
        jsii.set(self, "catalogInfo", value)

    @builtins.property # type: ignore
    @jsii.member(jsii_name="customSetupScript")
    def custom_setup_script(
        self,
    ) -> typing.Optional[typing.List["DataFactoryIntegrationRuntimeManagedCustomSetupScript"]]:
        return jsii.get(self, "customSetupScript")

    @custom_setup_script.setter # type: ignore
    def custom_setup_script(
        self,
        value: typing.Optional[typing.List["DataFactoryIntegrationRuntimeManagedCustomSetupScript"]],
    ) -> None:
        jsii.set(self, "customSetupScript", value)

    @builtins.property # type: ignore
    @jsii.member(jsii_name="description")
    def description(self) -> typing.Optional[builtins.str]:
        return jsii.get(self, "description")

    @description.setter # type: ignore
    def description(self, value: typing.Optional[builtins.str]) -> None:
        jsii.set(self, "description", value)

    @builtins.property # type: ignore
    @jsii.member(jsii_name="edition")
    def edition(self) -> typing.Optional[builtins.str]:
        return jsii.get(self, "edition")

    @edition.setter # type: ignore
    def edition(self, value: typing.Optional[builtins.str]) -> None:
        jsii.set(self, "edition", value)

    @builtins.property # type: ignore
    @jsii.member(jsii_name="id")
    def id(self) -> typing.Optional[builtins.str]:
        return jsii.get(self, "id")

    @id.setter # type: ignore
    def id(self, value: typing.Optional[builtins.str]) -> None:
        jsii.set(self, "id", value)

    @builtins.property # type: ignore
    @jsii.member(jsii_name="licenseType")
    def license_type(self) -> typing.Optional[builtins.str]:
        return jsii.get(self, "licenseType")

    @license_type.setter # type: ignore
    def license_type(self, value: typing.Optional[builtins.str]) -> None:
        jsii.set(self, "licenseType", value)

    @builtins.property # type: ignore
    @jsii.member(jsii_name="maxParallelExecutionsPerNode")
    def max_parallel_executions_per_node(self) -> typing.Optional[jsii.Number]:
        return jsii.get(self, "maxParallelExecutionsPerNode")

    @max_parallel_executions_per_node.setter # type: ignore
    def max_parallel_executions_per_node(
        self,
        value: typing.Optional[jsii.Number],
    ) -> None:
        jsii.set(self, "maxParallelExecutionsPerNode", value)

    @builtins.property # type: ignore
    @jsii.member(jsii_name="numberOfNodes")
    def number_of_nodes(self) -> typing.Optional[jsii.Number]:
        return jsii.get(self, "numberOfNodes")

    @number_of_nodes.setter # type: ignore
    def number_of_nodes(self, value: typing.Optional[jsii.Number]) -> None:
        jsii.set(self, "numberOfNodes", value)

    @builtins.property # type: ignore
    @jsii.member(jsii_name="timeouts")
    def timeouts(
        self,
    ) -> typing.Optional["DataFactoryIntegrationRuntimeManagedTimeouts"]:
        return jsii.get(self, "timeouts")

    @timeouts.setter # type: ignore
    def timeouts(
        self,
        value: typing.Optional["DataFactoryIntegrationRuntimeManagedTimeouts"],
    ) -> None:
        jsii.set(self, "timeouts", value)

    @builtins.property # type: ignore
    @jsii.member(jsii_name="vnetIntegration")
    def vnet_integration(
        self,
    ) -> typing.Optional[typing.List["DataFactoryIntegrationRuntimeManagedVnetIntegration"]]:
        return jsii.get(self, "vnetIntegration")

    @vnet_integration.setter # type: ignore
    def vnet_integration(
        self,
        value: typing.Optional[typing.List["DataFactoryIntegrationRuntimeManagedVnetIntegration"]],
    ) -> None:
        jsii.set(self, "vnetIntegration", value)


@jsii.data_type(
    jsii_type="@cdktf/provider-azurerm.DataFactoryIntegrationRuntimeManagedCatalogInfo",
    jsii_struct_bases=[],
    name_mapping={
        "administrator_login": "administratorLogin",
        "administrator_password": "administratorPassword",
        "server_endpoint": "serverEndpoint",
        "pricing_tier": "pricingTier",
    },
)
class DataFactoryIntegrationRuntimeManagedCatalogInfo:
    def __init__(
        self,
        *,
        administrator_login: builtins.str,
        administrator_password: builtins.str,
        server_endpoint: builtins.str,
        pricing_tier: typing.Optional[builtins.str] = None,
    ) -> None:
        """
        :param administrator_login: 
        :param administrator_password: 
        :param server_endpoint: 
        :param pricing_tier: 
        """
        self._values: typing.Dict[str, typing.Any] = {
            "administrator_login": administrator_login,
            "administrator_password": administrator_password,
            "server_endpoint": server_endpoint,
        }
        if pricing_tier is not None:
            self._values["pricing_tier"] = pricing_tier

    @builtins.property
    def administrator_login(self) -> builtins.str:
        result = self._values.get("administrator_login")
        assert result is not None, "Required property 'administrator_login' is missing"
        return result

    @builtins.property
    def administrator_password(self) -> builtins.str:
        result = self._values.get("administrator_password")
        assert result is not None, "Required property 'administrator_password' is missing"
        return result

    @builtins.property
    def server_endpoint(self) -> builtins.str:
        result = self._values.get("server_endpoint")
        assert result is not None, "Required property 'server_endpoint' is missing"
        return result

    @builtins.property
    def pricing_tier(self) -> typing.Optional[builtins.str]:
        result = self._values.get("pricing_tier")
        return result

    def __eq__(self, rhs: typing.Any) -> builtins.bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs: typing.Any) -> builtins.bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return "DataFactoryIntegrationRuntimeManagedCatalogInfo(%s)" % ", ".join(
            k + "=" + repr(v) for k, v in self._values.items()
        )


@jsii.data_type(
    jsii_type="@cdktf/provider-azurerm.DataFactoryIntegrationRuntimeManagedConfig",
    jsii_struct_bases=[cdktf.TerraformMetaArguments],
    name_mapping={
        "count": "count",
        "depends_on": "dependsOn",
        "lifecycle": "lifecycle",
        "provider": "provider",
        "data_factory_name": "dataFactoryName",
        "location": "location",
        "name": "name",
        "node_size": "nodeSize",
        "resource_group_name": "resourceGroupName",
        "catalog_info": "catalogInfo",
        "custom_setup_script": "customSetupScript",
        "description": "description",
        "edition": "edition",
        "license_type": "licenseType",
        "max_parallel_executions_per_node": "maxParallelExecutionsPerNode",
        "number_of_nodes": "numberOfNodes",
        "timeouts": "timeouts",
        "vnet_integration": "vnetIntegration",
    },
)
class DataFactoryIntegrationRuntimeManagedConfig(cdktf.TerraformMetaArguments):
    def __init__(
        self,
        *,
        count: typing.Optional[jsii.Number] = None,
        depends_on: typing.Optional[typing.List[cdktf.TerraformResource]] = None,
        lifecycle: typing.Optional[cdktf.TerraformResourceLifecycle] = None,
        provider: typing.Optional[cdktf.TerraformProvider] = None,
        data_factory_name: builtins.str,
        location: builtins.str,
        name: builtins.str,
        node_size: builtins.str,
        resource_group_name: builtins.str,
        catalog_info: typing.Optional[typing.List[DataFactoryIntegrationRuntimeManagedCatalogInfo]] = None,
        custom_setup_script: typing.Optional[typing.List["DataFactoryIntegrationRuntimeManagedCustomSetupScript"]] = None,
        description: typing.Optional[builtins.str] = None,
        edition: typing.Optional[builtins.str] = None,
        license_type: typing.Optional[builtins.str] = None,
        max_parallel_executions_per_node: typing.Optional[jsii.Number] = None,
        number_of_nodes: typing.Optional[jsii.Number] = None,
        timeouts: typing.Optional["DataFactoryIntegrationRuntimeManagedTimeouts"] = None,
        vnet_integration: typing.Optional[typing.List["DataFactoryIntegrationRuntimeManagedVnetIntegration"]] = None,
    ) -> None:
        """
        :param count: 
        :param depends_on: 
        :param lifecycle: 
        :param provider: 
        :param data_factory_name: 
        :param location: 
        :param name: 
        :param node_size: 
        :param resource_group_name: 
        :param catalog_info: catalog_info block.
        :param custom_setup_script: custom_setup_script block.
        :param description: 
        :param edition: 
        :param license_type: 
        :param max_parallel_executions_per_node: 
        :param number_of_nodes: 
        :param timeouts: timeouts block.
        :param vnet_integration: vnet_integration block.
        """
        if isinstance(lifecycle, dict):
            lifecycle = cdktf.TerraformResourceLifecycle(**lifecycle)
        if isinstance(timeouts, dict):
            timeouts = DataFactoryIntegrationRuntimeManagedTimeouts(**timeouts)
        self._values: typing.Dict[str, typing.Any] = {
            "data_factory_name": data_factory_name,
            "location": location,
            "name": name,
            "node_size": node_size,
            "resource_group_name": resource_group_name,
        }
        if count is not None:
            self._values["count"] = count
        if depends_on is not None:
            self._values["depends_on"] = depends_on
        if lifecycle is not None:
            self._values["lifecycle"] = lifecycle
        if provider is not None:
            self._values["provider"] = provider
        if catalog_info is not None:
            self._values["catalog_info"] = catalog_info
        if custom_setup_script is not None:
            self._values["custom_setup_script"] = custom_setup_script
        if description is not None:
            self._values["description"] = description
        if edition is not None:
            self._values["edition"] = edition
        if license_type is not None:
            self._values["license_type"] = license_type
        if max_parallel_executions_per_node is not None:
            self._values["max_parallel_executions_per_node"] = max_parallel_executions_per_node
        if number_of_nodes is not None:
            self._values["number_of_nodes"] = number_of_nodes
        if timeouts is not None:
            self._values["timeouts"] = timeouts
        if vnet_integration is not None:
            self._values["vnet_integration"] = vnet_integration

    @builtins.property
    def count(self) -> typing.Optional[jsii.Number]:
        """
        :stability: experimental
        """
        result = self._values.get("count")
        return result

    @builtins.property
    def depends_on(self) -> typing.Optional[typing.List[cdktf.TerraformResource]]:
        """
        :stability: experimental
        """
        result = self._values.get("depends_on")
        return result

    @builtins.property
    def lifecycle(self) -> typing.Optional[cdktf.TerraformResourceLifecycle]:
        """
        :stability: experimental
        """
        result = self._values.get("lifecycle")
        return result

    @builtins.property
    def provider(self) -> typing.Optional[cdktf.TerraformProvider]:
        """
        :stability: experimental
        """
        result = self._values.get("provider")
        return result

    @builtins.property
    def data_factory_name(self) -> builtins.str:
        result = self._values.get("data_factory_name")
        assert result is not None, "Required property 'data_factory_name' is missing"
        return result

    @builtins.property
    def location(self) -> builtins.str:
        result = self._values.get("location")
        assert result is not None, "Required property 'location' is missing"
        return result

    @builtins.property
    def name(self) -> builtins.str:
        result = self._values.get("name")
        assert result is not None, "Required property 'name' is missing"
        return result

    @builtins.property
    def node_size(self) -> builtins.str:
        result = self._values.get("node_size")
        assert result is not None, "Required property 'node_size' is missing"
        return result

    @builtins.property
    def resource_group_name(self) -> builtins.str:
        result = self._values.get("resource_group_name")
        assert result is not None, "Required property 'resource_group_name' is missing"
        return result

    @builtins.property
    def catalog_info(
        self,
    ) -> typing.Optional[typing.List[DataFactoryIntegrationRuntimeManagedCatalogInfo]]:
        """catalog_info block."""
        result = self._values.get("catalog_info")
        return result

    @builtins.property
    def custom_setup_script(
        self,
    ) -> typing.Optional[typing.List["DataFactoryIntegrationRuntimeManagedCustomSetupScript"]]:
        """custom_setup_script block."""
        result = self._values.get("custom_setup_script")
        return result

    @builtins.property
    def description(self) -> typing.Optional[builtins.str]:
        result = self._values.get("description")
        return result

    @builtins.property
    def edition(self) -> typing.Optional[builtins.str]:
        result = self._values.get("edition")
        return result

    @builtins.property
    def license_type(self) -> typing.Optional[builtins.str]:
        result = self._values.get("license_type")
        return result

    @builtins.property
    def max_parallel_executions_per_node(self) -> typing.Optional[jsii.Number]:
        result = self._values.get("max_parallel_executions_per_node")
        return result

    @builtins.property
    def number_of_nodes(self) -> typing.Optional[jsii.Number]:
        result = self._values.get("number_of_nodes")
        return result

    @builtins.property
    def timeouts(
        self,
    ) -> typing.Optional["DataFactoryIntegrationRuntimeManagedTimeouts"]:
        """timeouts block."""
        result = self._values.get("timeouts")
        return result

    @builtins.property
    def vnet_integration(
        self,
    ) -> typing.Optional[typing.List["DataFactoryIntegrationRuntimeManagedVnetIntegration"]]:
        """vnet_integration block."""
        result = self._values.get("vnet_integration")
        return result

    def __eq__(self, rhs: typing.Any) -> builtins.bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs: typing.Any) -> builtins.bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return "DataFactoryIntegrationRuntimeManagedConfig(%s)" % ", ".join(
            k + "=" + repr(v) for k, v in self._values.items()
        )


@jsii.data_type(
    jsii_type="@cdktf/provider-azurerm.DataFactoryIntegrationRuntimeManagedCustomSetupScript",
    jsii_struct_bases=[],
    name_mapping={"blob_container_uri": "blobContainerUri", "sas_token": "sasToken"},
)
class DataFactoryIntegrationRuntimeManagedCustomSetupScript:
    def __init__(
        self,
        *,
        blob_container_uri: builtins.str,
        sas_token: builtins.str,
    ) -> None:
        """
        :param blob_container_uri: 
        :param sas_token: 
        """
        self._values: typing.Dict[str, typing.Any] = {
            "blob_container_uri": blob_container_uri,
            "sas_token": sas_token,
        }

    @builtins.property
    def blob_container_uri(self) -> builtins.str:
        result = self._values.get("blob_container_uri")
        assert result is not None, "Required property 'blob_container_uri' is missing"
        return result

    @builtins.property
    def sas_token(self) -> builtins.str:
        result = self._values.get("sas_token")
        assert result is not None, "Required property 'sas_token' is missing"
        return result

    def __eq__(self, rhs: typing.Any) -> builtins.bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs: typing.Any) -> builtins.bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return "DataFactoryIntegrationRuntimeManagedCustomSetupScript(%s)" % ", ".join(
            k + "=" + repr(v) for k, v in self._values.items()
        )


@jsii.data_type(
    jsii_type="@cdktf/provider-azurerm.DataFactoryIntegrationRuntimeManagedTimeouts",
    jsii_struct_bases=[],
    name_mapping={
        "create": "create",
        "delete": "delete",
        "read": "read",
        "update": "update",
    },
)
class DataFactoryIntegrationRuntimeManagedTimeouts:
    def __init__(
        self,
        *,
        create: typing.Optional[builtins.str] = None,
        delete: typing.Optional[builtins.str] = None,
        read: typing.Optional[builtins.str] = None,
        update: typing.Optional[builtins.str] = None,
    ) -> None:
        """
        :param create: 
        :param delete: 
        :param read: 
        :param update: 
        """
        self._values: typing.Dict[str, typing.Any] = {}
        if create is not None:
            self._values["create"] = create
        if delete is not None:
            self._values["delete"] = delete
        if read is not None:
            self._values["read"] = read
        if update is not None:
            self._values["update"] = update

    @builtins.property
    def create(self) -> typing.Optional[builtins.str]:
        result = self._values.get("create")
        return result

    @builtins.property
    def delete(self) -> typing.Optional[builtins.str]:
        result = self._values.get("delete")
        return result

    @builtins.property
    def read(self) -> typing.Optional[builtins.str]:
        result = self._values.get("read")
        return result

    @builtins.property
    def update(self) -> typing.Optional[builtins.str]:
        result = self._values.get("update")
        return result

    def __eq__(self, rhs: typing.Any) -> builtins.bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs: typing.Any) -> builtins.bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return "DataFactoryIntegrationRuntimeManagedTimeouts(%s)" % ", ".join(
            k + "=" + repr(v) for k, v in self._values.items()
        )


@jsii.data_type(
    jsii_type="@cdktf/provider-azurerm.DataFactoryIntegrationRuntimeManagedVnetIntegration",
    jsii_struct_bases=[],
    name_mapping={"subnet_name": "subnetName", "vnet_id": "vnetId"},
)
class DataFactoryIntegrationRuntimeManagedVnetIntegration:
    def __init__(self, *, subnet_name: builtins.str, vnet_id: builtins.str) -> None:
        """
        :param subnet_name: 
        :param vnet_id: 
        """
        self._values: typing.Dict[str, typing.Any] = {
            "subnet_name": subnet_name,
            "vnet_id": vnet_id,
        }

    @builtins.property
    def subnet_name(self) -> builtins.str:
        result = self._values.get("subnet_name")
        assert result is not None, "Required property 'subnet_name' is missing"
        return result

    @builtins.property
    def vnet_id(self) -> builtins.str:
        result = self._values.get("vnet_id")
        assert result is not None, "Required property 'vnet_id' is missing"
        return result

    def __eq__(self, rhs: typing.Any) -> builtins.bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs: typing.Any) -> builtins.bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return "DataFactoryIntegrationRuntimeManagedVnetIntegration(%s)" % ", ".join(
            k + "=" + repr(v) for k, v in self._values.items()
        )


class DataFactoryLinkedServiceDataLakeStorageGen2(
    cdktf.TerraformResource,
    metaclass=jsii.JSIIMeta,
    jsii_type="@cdktf/provider-azurerm.DataFactoryLinkedServiceDataLakeStorageGen2",
):
    def __init__(
        self,
        scope: constructs.Construct,
        id: builtins.str,
        *,
        data_factory_name: builtins.str,
        name: builtins.str,
        resource_group_name: builtins.str,
        service_principal_id: builtins.str,
        service_principal_key: builtins.str,
        tenant: builtins.str,
        url: builtins.str,
        additional_properties: typing.Optional[typing.Mapping[builtins.str, builtins.str]] = None,
        annotations: typing.Optional[typing.List[builtins.str]] = None,
        description: typing.Optional[builtins.str] = None,
        integration_runtime_name: typing.Optional[builtins.str] = None,
        parameters: typing.Optional[typing.Mapping[builtins.str, builtins.str]] = None,
        timeouts: typing.Optional["DataFactoryLinkedServiceDataLakeStorageGen2Timeouts"] = None,
        count: typing.Optional[jsii.Number] = None,
        depends_on: typing.Optional[typing.List[cdktf.TerraformResource]] = None,
        lifecycle: typing.Optional[cdktf.TerraformResourceLifecycle] = None,
        provider: typing.Optional[cdktf.TerraformProvider] = None,
    ) -> None:
        """
        :param scope: -
        :param id: -
        :param data_factory_name: 
        :param name: 
        :param resource_group_name: 
        :param service_principal_id: 
        :param service_principal_key: 
        :param tenant: 
        :param url: 
        :param additional_properties: 
        :param annotations: 
        :param description: 
        :param integration_runtime_name: 
        :param parameters: 
        :param timeouts: timeouts block.
        :param count: 
        :param depends_on: 
        :param lifecycle: 
        :param provider: 
        """
        config = DataFactoryLinkedServiceDataLakeStorageGen2Config(
            data_factory_name=data_factory_name,
            name=name,
            resource_group_name=resource_group_name,
            service_principal_id=service_principal_id,
            service_principal_key=service_principal_key,
            tenant=tenant,
            url=url,
            additional_properties=additional_properties,
            annotations=annotations,
            description=description,
            integration_runtime_name=integration_runtime_name,
            parameters=parameters,
            timeouts=timeouts,
            count=count,
            depends_on=depends_on,
            lifecycle=lifecycle,
            provider=provider,
        )

        jsii.create(DataFactoryLinkedServiceDataLakeStorageGen2, self, [scope, id, config])

    @jsii.member(jsii_name="synthesizeAttributes")
    def _synthesize_attributes(self) -> typing.Mapping[builtins.str, typing.Any]:
        return jsii.invoke(self, "synthesizeAttributes", [])

    @builtins.property # type: ignore
    @jsii.member(jsii_name="dataFactoryName")
    def data_factory_name(self) -> builtins.str:
        return jsii.get(self, "dataFactoryName")

    @data_factory_name.setter # type: ignore
    def data_factory_name(self, value: builtins.str) -> None:
        jsii.set(self, "dataFactoryName", value)

    @builtins.property # type: ignore
    @jsii.member(jsii_name="name")
    def name(self) -> builtins.str:
        return jsii.get(self, "name")

    @name.setter # type: ignore
    def name(self, value: builtins.str) -> None:
        jsii.set(self, "name", value)

    @builtins.property # type: ignore
    @jsii.member(jsii_name="resourceGroupName")
    def resource_group_name(self) -> builtins.str:
        return jsii.get(self, "resourceGroupName")

    @resource_group_name.setter # type: ignore
    def resource_group_name(self, value: builtins.str) -> None:
        jsii.set(self, "resourceGroupName", value)

    @builtins.property # type: ignore
    @jsii.member(jsii_name="servicePrincipalId")
    def service_principal_id(self) -> builtins.str:
        return jsii.get(self, "servicePrincipalId")

    @service_principal_id.setter # type: ignore
    def service_principal_id(self, value: builtins.str) -> None:
        jsii.set(self, "servicePrincipalId", value)

    @builtins.property # type: ignore
    @jsii.member(jsii_name="servicePrincipalKey")
    def service_principal_key(self) -> builtins.str:
        return jsii.get(self, "servicePrincipalKey")

    @service_principal_key.setter # type: ignore
    def service_principal_key(self, value: builtins.str) -> None:
        jsii.set(self, "servicePrincipalKey", value)

    @builtins.property # type: ignore
    @jsii.member(jsii_name="tenant")
    def tenant(self) -> builtins.str:
        return jsii.get(self, "tenant")

    @tenant.setter # type: ignore
    def tenant(self, value: builtins.str) -> None:
        jsii.set(self, "tenant", value)

    @builtins.property # type: ignore
    @jsii.member(jsii_name="url")
    def url(self) -> builtins.str:
        return jsii.get(self, "url")

    @url.setter # type: ignore
    def url(self, value: builtins.str) -> None:
        jsii.set(self, "url", value)

    @builtins.property # type: ignore
    @jsii.member(jsii_name="additionalProperties")
    def additional_properties(
        self,
    ) -> typing.Optional[typing.Mapping[builtins.str, builtins.str]]:
        return jsii.get(self, "additionalProperties")

    @additional_properties.setter # type: ignore
    def additional_properties(
        self,
        value: typing.Optional[typing.Mapping[builtins.str, builtins.str]],
    ) -> None:
        jsii.set(self, "additionalProperties", value)

    @builtins.property # type: ignore
    @jsii.member(jsii_name="annotations")
    def annotations(self) -> typing.Optional[typing.List[builtins.str]]:
        return jsii.get(self, "annotations")

    @annotations.setter # type: ignore
    def annotations(self, value: typing.Optional[typing.List[builtins.str]]) -> None:
        jsii.set(self, "annotations", value)

    @builtins.property # type: ignore
    @jsii.member(jsii_name="description")
    def description(self) -> typing.Optional[builtins.str]:
        return jsii.get(self, "description")

    @description.setter # type: ignore
    def description(self, value: typing.Optional[builtins.str]) -> None:
        jsii.set(self, "description", value)

    @builtins.property # type: ignore
    @jsii.member(jsii_name="id")
    def id(self) -> typing.Optional[builtins.str]:
        return jsii.get(self, "id")

    @id.setter # type: ignore
    def id(self, value: typing.Optional[builtins.str]) -> None:
        jsii.set(self, "id", value)

    @builtins.property # type: ignore
    @jsii.member(jsii_name="integrationRuntimeName")
    def integration_runtime_name(self) -> typing.Optional[builtins.str]:
        return jsii.get(self, "integrationRuntimeName")

    @integration_runtime_name.setter # type: ignore
    def integration_runtime_name(self, value: typing.Optional[builtins.str]) -> None:
        jsii.set(self, "integrationRuntimeName", value)

    @builtins.property # type: ignore
    @jsii.member(jsii_name="parameters")
    def parameters(self) -> typing.Optional[typing.Mapping[builtins.str, builtins.str]]:
        return jsii.get(self, "parameters")

    @parameters.setter # type: ignore
    def parameters(
        self,
        value: typing.Optional[typing.Mapping[builtins.str, builtins.str]],
    ) -> None:
        jsii.set(self, "parameters", value)

    @builtins.property # type: ignore
    @jsii.member(jsii_name="timeouts")
    def timeouts(
        self,
    ) -> typing.Optional["DataFactoryLinkedServiceDataLakeStorageGen2Timeouts"]:
        return jsii.get(self, "timeouts")

    @timeouts.setter # type: ignore
    def timeouts(
        self,
        value: typing.Optional["DataFactoryLinkedServiceDataLakeStorageGen2Timeouts"],
    ) -> None:
        jsii.set(self, "timeouts", value)


@jsii.data_type(
    jsii_type="@cdktf/provider-azurerm.DataFactoryLinkedServiceDataLakeStorageGen2Config",
    jsii_struct_bases=[cdktf.TerraformMetaArguments],
    name_mapping={
        "count": "count",
        "depends_on": "dependsOn",
        "lifecycle": "lifecycle",
        "provider": "provider",
        "data_factory_name": "dataFactoryName",
        "name": "name",
        "resource_group_name": "resourceGroupName",
        "service_principal_id": "servicePrincipalId",
        "service_principal_key": "servicePrincipalKey",
        "tenant": "tenant",
        "url": "url",
        "additional_properties": "additionalProperties",
        "annotations": "annotations",
        "description": "description",
        "integration_runtime_name": "integrationRuntimeName",
        "parameters": "parameters",
        "timeouts": "timeouts",
    },
)
class DataFactoryLinkedServiceDataLakeStorageGen2Config(cdktf.TerraformMetaArguments):
    def __init__(
        self,
        *,
        count: typing.Optional[jsii.Number] = None,
        depends_on: typing.Optional[typing.List[cdktf.TerraformResource]] = None,
        lifecycle: typing.Optional[cdktf.TerraformResourceLifecycle] = None,
        provider: typing.Optional[cdktf.TerraformProvider] = None,
        data_factory_name: builtins.str,
        name: builtins.str,
        resource_group_name: builtins.str,
        service_principal_id: builtins.str,
        service_principal_key: builtins.str,
        tenant: builtins.str,
        url: builtins.str,
        additional_properties: typing.Optional[typing.Mapping[builtins.str, builtins.str]] = None,
        annotations: typing.Optional[typing.List[builtins.str]] = None,
        description: typing.Optional[builtins.str] = None,
        integration_runtime_name: typing.Optional[builtins.str] = None,
        parameters: typing.Optional[typing.Mapping[builtins.str, builtins.str]] = None,
        timeouts: typing.Optional["DataFactoryLinkedServiceDataLakeStorageGen2Timeouts"] = None,
    ) -> None:
        """
        :param count: 
        :param depends_on: 
        :param lifecycle: 
        :param provider: 
        :param data_factory_name: 
        :param name: 
        :param resource_group_name: 
        :param service_principal_id: 
        :param service_principal_key: 
        :param tenant: 
        :param url: 
        :param additional_properties: 
        :param annotations: 
        :param description: 
        :param integration_runtime_name: 
        :param parameters: 
        :param timeouts: timeouts block.
        """
        if isinstance(lifecycle, dict):
            lifecycle = cdktf.TerraformResourceLifecycle(**lifecycle)
        if isinstance(timeouts, dict):
            timeouts = DataFactoryLinkedServiceDataLakeStorageGen2Timeouts(**timeouts)
        self._values: typing.Dict[str, typing.Any] = {
            "data_factory_name": data_factory_name,
            "name": name,
            "resource_group_name": resource_group_name,
            "service_principal_id": service_principal_id,
            "service_principal_key": service_principal_key,
            "tenant": tenant,
            "url": url,
        }
        if count is not None:
            self._values["count"] = count
        if depends_on is not None:
            self._values["depends_on"] = depends_on
        if lifecycle is not None:
            self._values["lifecycle"] = lifecycle
        if provider is not None:
            self._values["provider"] = provider
        if additional_properties is not None:
            self._values["additional_properties"] = additional_properties
        if annotations is not None:
            self._values["annotations"] = annotations
        if description is not None:
            self._values["description"] = description
        if integration_runtime_name is not None:
            self._values["integration_runtime_name"] = integration_runtime_name
        if parameters is not None:
            self._values["parameters"] = parameters
        if timeouts is not None:
            self._values["timeouts"] = timeouts

    @builtins.property
    def count(self) -> typing.Optional[jsii.Number]:
        """
        :stability: experimental
        """
        result = self._values.get("count")
        return result

    @builtins.property
    def depends_on(self) -> typing.Optional[typing.List[cdktf.TerraformResource]]:
        """
        :stability: experimental
        """
        result = self._values.get("depends_on")
        return result

    @builtins.property
    def lifecycle(self) -> typing.Optional[cdktf.TerraformResourceLifecycle]:
        """
        :stability: experimental
        """
        result = self._values.get("lifecycle")
        return result

    @builtins.property
    def provider(self) -> typing.Optional[cdktf.TerraformProvider]:
        """
        :stability: experimental
        """
        result = self._values.get("provider")
        return result

    @builtins.property
    def data_factory_name(self) -> builtins.str:
        result = self._values.get("data_factory_name")
        assert result is not None, "Required property 'data_factory_name' is missing"
        return result

    @builtins.property
    def name(self) -> builtins.str:
        result = self._values.get("name")
        assert result is not None, "Required property 'name' is missing"
        return result

    @builtins.property
    def resource_group_name(self) -> builtins.str:
        result = self._values.get("resource_group_name")
        assert result is not None, "Required property 'resource_group_name' is missing"
        return result

    @builtins.property
    def service_principal_id(self) -> builtins.str:
        result = self._values.get("service_principal_id")
        assert result is not None, "Required property 'service_principal_id' is missing"
        return result

    @builtins.property
    def service_principal_key(self) -> builtins.str:
        result = self._values.get("service_principal_key")
        assert result is not None, "Required property 'service_principal_key' is missing"
        return result

    @builtins.property
    def tenant(self) -> builtins.str:
        result = self._values.get("tenant")
        assert result is not None, "Required property 'tenant' is missing"
        return result

    @builtins.property
    def url(self) -> builtins.str:
        result = self._values.get("url")
        assert result is not None, "Required property 'url' is missing"
        return result

    @builtins.property
    def additional_properties(
        self,
    ) -> typing.Optional[typing.Mapping[builtins.str, builtins.str]]:
        result = self._values.get("additional_properties")
        return result

    @builtins.property
    def annotations(self) -> typing.Optional[typing.List[builtins.str]]:
        result = self._values.get("annotations")
        return result

    @builtins.property
    def description(self) -> typing.Optional[builtins.str]:
        result = self._values.get("description")
        return result

    @builtins.property
    def integration_runtime_name(self) -> typing.Optional[builtins.str]:
        result = self._values.get("integration_runtime_name")
        return result

    @builtins.property
    def parameters(self) -> typing.Optional[typing.Mapping[builtins.str, builtins.str]]:
        result = self._values.get("parameters")
        return result

    @builtins.property
    def timeouts(
        self,
    ) -> typing.Optional["DataFactoryLinkedServiceDataLakeStorageGen2Timeouts"]:
        """timeouts block."""
        result = self._values.get("timeouts")
        return result

    def __eq__(self, rhs: typing.Any) -> builtins.bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs: typing.Any) -> builtins.bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return "DataFactoryLinkedServiceDataLakeStorageGen2Config(%s)" % ", ".join(
            k + "=" + repr(v) for k, v in self._values.items()
        )


@jsii.data_type(
    jsii_type="@cdktf/provider-azurerm.DataFactoryLinkedServiceDataLakeStorageGen2Timeouts",
    jsii_struct_bases=[],
    name_mapping={
        "create": "create",
        "delete": "delete",
        "read": "read",
        "update": "update",
    },
)
class DataFactoryLinkedServiceDataLakeStorageGen2Timeouts:
    def __init__(
        self,
        *,
        create: typing.Optional[builtins.str] = None,
        delete: typing.Optional[builtins.str] = None,
        read: typing.Optional[builtins.str] = None,
        update: typing.Optional[builtins.str] = None,
    ) -> None:
        """
        :param create: 
        :param delete: 
        :param read: 
        :param update: 
        """
        self._values: typing.Dict[str, typing.Any] = {}
        if create is not None:
            self._values["create"] = create
        if delete is not None:
            self._values["delete"] = delete
        if read is not None:
            self._values["read"] = read
        if update is not None:
            self._values["update"] = update

    @builtins.property
    def create(self) -> typing.Optional[builtins.str]:
        result = self._values.get("create")
        return result

    @builtins.property
    def delete(self) -> typing.Optional[builtins.str]:
        result = self._values.get("delete")
        return result

    @builtins.property
    def read(self) -> typing.Optional[builtins.str]:
        result = self._values.get("read")
        return result

    @builtins.property
    def update(self) -> typing.Optional[builtins.str]:
        result = self._values.get("update")
        return result

    def __eq__(self, rhs: typing.Any) -> builtins.bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs: typing.Any) -> builtins.bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return "DataFactoryLinkedServiceDataLakeStorageGen2Timeouts(%s)" % ", ".join(
            k + "=" + repr(v) for k, v in self._values.items()
        )


class DataFactoryLinkedServiceMysql(
    cdktf.TerraformResource,
    metaclass=jsii.JSIIMeta,
    jsii_type="@cdktf/provider-azurerm.DataFactoryLinkedServiceMysql",
):
    def __init__(
        self,
        scope: constructs.Construct,
        id: builtins.str,
        *,
        connection_string: builtins.str,
        data_factory_name: builtins.str,
        name: builtins.str,
        resource_group_name: builtins.str,
        additional_properties: typing.Optional[typing.Mapping[builtins.str, builtins.str]] = None,
        annotations: typing.Optional[typing.List[builtins.str]] = None,
        description: typing.Optional[builtins.str] = None,
        integration_runtime_name: typing.Optional[builtins.str] = None,
        parameters: typing.Optional[typing.Mapping[builtins.str, builtins.str]] = None,
        timeouts: typing.Optional["DataFactoryLinkedServiceMysqlTimeouts"] = None,
        count: typing.Optional[jsii.Number] = None,
        depends_on: typing.Optional[typing.List[cdktf.TerraformResource]] = None,
        lifecycle: typing.Optional[cdktf.TerraformResourceLifecycle] = None,
        provider: typing.Optional[cdktf.TerraformProvider] = None,
    ) -> None:
        """
        :param scope: -
        :param id: -
        :param connection_string: 
        :param data_factory_name: 
        :param name: 
        :param resource_group_name: 
        :param additional_properties: 
        :param annotations: 
        :param description: 
        :param integration_runtime_name: 
        :param parameters: 
        :param timeouts: timeouts block.
        :param count: 
        :param depends_on: 
        :param lifecycle: 
        :param provider: 
        """
        config = DataFactoryLinkedServiceMysqlConfig(
            connection_string=connection_string,
            data_factory_name=data_factory_name,
            name=name,
            resource_group_name=resource_group_name,
            additional_properties=additional_properties,
            annotations=annotations,
            description=description,
            integration_runtime_name=integration_runtime_name,
            parameters=parameters,
            timeouts=timeouts,
            count=count,
            depends_on=depends_on,
            lifecycle=lifecycle,
            provider=provider,
        )

        jsii.create(DataFactoryLinkedServiceMysql, self, [scope, id, config])

    @jsii.member(jsii_name="synthesizeAttributes")
    def _synthesize_attributes(self) -> typing.Mapping[builtins.str, typing.Any]:
        return jsii.invoke(self, "synthesizeAttributes", [])

    @builtins.property # type: ignore
    @jsii.member(jsii_name="connectionString")
    def connection_string(self) -> builtins.str:
        return jsii.get(self, "connectionString")

    @connection_string.setter # type: ignore
    def connection_string(self, value: builtins.str) -> None:
        jsii.set(self, "connectionString", value)

    @builtins.property # type: ignore
    @jsii.member(jsii_name="dataFactoryName")
    def data_factory_name(self) -> builtins.str:
        return jsii.get(self, "dataFactoryName")

    @data_factory_name.setter # type: ignore
    def data_factory_name(self, value: builtins.str) -> None:
        jsii.set(self, "dataFactoryName", value)

    @builtins.property # type: ignore
    @jsii.member(jsii_name="name")
    def name(self) -> builtins.str:
        return jsii.get(self, "name")

    @name.setter # type: ignore
    def name(self, value: builtins.str) -> None:
        jsii.set(self, "name", value)

    @builtins.property # type: ignore
    @jsii.member(jsii_name="resourceGroupName")
    def resource_group_name(self) -> builtins.str:
        return jsii.get(self, "resourceGroupName")

    @resource_group_name.setter # type: ignore
    def resource_group_name(self, value: builtins.str) -> None:
        jsii.set(self, "resourceGroupName", value)

    @builtins.property # type: ignore
    @jsii.member(jsii_name="additionalProperties")
    def additional_properties(
        self,
    ) -> typing.Optional[typing.Mapping[builtins.str, builtins.str]]:
        return jsii.get(self, "additionalProperties")

    @additional_properties.setter # type: ignore
    def additional_properties(
        self,
        value: typing.Optional[typing.Mapping[builtins.str, builtins.str]],
    ) -> None:
        jsii.set(self, "additionalProperties", value)

    @builtins.property # type: ignore
    @jsii.member(jsii_name="annotations")
    def annotations(self) -> typing.Optional[typing.List[builtins.str]]:
        return jsii.get(self, "annotations")

    @annotations.setter # type: ignore
    def annotations(self, value: typing.Optional[typing.List[builtins.str]]) -> None:
        jsii.set(self, "annotations", value)

    @builtins.property # type: ignore
    @jsii.member(jsii_name="description")
    def description(self) -> typing.Optional[builtins.str]:
        return jsii.get(self, "description")

    @description.setter # type: ignore
    def description(self, value: typing.Optional[builtins.str]) -> None:
        jsii.set(self, "description", value)

    @builtins.property # type: ignore
    @jsii.member(jsii_name="id")
    def id(self) -> typing.Optional[builtins.str]:
        return jsii.get(self, "id")

    @id.setter # type: ignore
    def id(self, value: typing.Optional[builtins.str]) -> None:
        jsii.set(self, "id", value)

    @builtins.property # type: ignore
    @jsii.member(jsii_name="integrationRuntimeName")
    def integration_runtime_name(self) -> typing.Optional[builtins.str]:
        return jsii.get(self, "integrationRuntimeName")

    @integration_runtime_name.setter # type: ignore
    def integration_runtime_name(self, value: typing.Optional[builtins.str]) -> None:
        jsii.set(self, "integrationRuntimeName", value)

    @builtins.property # type: ignore
    @jsii.member(jsii_name="parameters")
    def parameters(self) -> typing.Optional[typing.Mapping[builtins.str, builtins.str]]:
        return jsii.get(self, "parameters")

    @parameters.setter # type: ignore
    def parameters(
        self,
        value: typing.Optional[typing.Mapping[builtins.str, builtins.str]],
    ) -> None:
        jsii.set(self, "parameters", value)

    @builtins.property # type: ignore
    @jsii.member(jsii_name="timeouts")
    def timeouts(self) -> typing.Optional["DataFactoryLinkedServiceMysqlTimeouts"]:
        return jsii.get(self, "timeouts")

    @timeouts.setter # type: ignore
    def timeouts(
        self,
        value: typing.Optional["DataFactoryLinkedServiceMysqlTimeouts"],
    ) -> None:
        jsii.set(self, "timeouts", value)


@jsii.data_type(
    jsii_type="@cdktf/provider-azurerm.DataFactoryLinkedServiceMysqlConfig",
    jsii_struct_bases=[cdktf.TerraformMetaArguments],
    name_mapping={
        "count": "count",
        "depends_on": "dependsOn",
        "lifecycle": "lifecycle",
        "provider": "provider",
        "connection_string": "connectionString",
        "data_factory_name": "dataFactoryName",
        "name": "name",
        "resource_group_name": "resourceGroupName",
        "additional_properties": "additionalProperties",
        "annotations": "annotations",
        "description": "description",
        "integration_runtime_name": "integrationRuntimeName",
        "parameters": "parameters",
        "timeouts": "timeouts",
    },
)
class DataFactoryLinkedServiceMysqlConfig(cdktf.TerraformMetaArguments):
    def __init__(
        self,
        *,
        count: typing.Optional[jsii.Number] = None,
        depends_on: typing.Optional[typing.List[cdktf.TerraformResource]] = None,
        lifecycle: typing.Optional[cdktf.TerraformResourceLifecycle] = None,
        provider: typing.Optional[cdktf.TerraformProvider] = None,
        connection_string: builtins.str,
        data_factory_name: builtins.str,
        name: builtins.str,
        resource_group_name: builtins.str,
        additional_properties: typing.Optional[typing.Mapping[builtins.str, builtins.str]] = None,
        annotations: typing.Optional[typing.List[builtins.str]] = None,
        description: typing.Optional[builtins.str] = None,
        integration_runtime_name: typing.Optional[builtins.str] = None,
        parameters: typing.Optional[typing.Mapping[builtins.str, builtins.str]] = None,
        timeouts: typing.Optional["DataFactoryLinkedServiceMysqlTimeouts"] = None,
    ) -> None:
        """
        :param count: 
        :param depends_on: 
        :param lifecycle: 
        :param provider: 
        :param connection_string: 
        :param data_factory_name: 
        :param name: 
        :param resource_group_name: 
        :param additional_properties: 
        :param annotations: 
        :param description: 
        :param integration_runtime_name: 
        :param parameters: 
        :param timeouts: timeouts block.
        """
        if isinstance(lifecycle, dict):
            lifecycle = cdktf.TerraformResourceLifecycle(**lifecycle)
        if isinstance(timeouts, dict):
            timeouts = DataFactoryLinkedServiceMysqlTimeouts(**timeouts)
        self._values: typing.Dict[str, typing.Any] = {
            "connection_string": connection_string,
            "data_factory_name": data_factory_name,
            "name": name,
            "resource_group_name": resource_group_name,
        }
        if count is not None:
            self._values["count"] = count
        if depends_on is not None:
            self._values["depends_on"] = depends_on
        if lifecycle is not None:
            self._values["lifecycle"] = lifecycle
        if provider is not None:
            self._values["provider"] = provider
        if additional_properties is not None:
            self._values["additional_properties"] = additional_properties
        if annotations is not None:
            self._values["annotations"] = annotations
        if description is not None:
            self._values["description"] = description
        if integration_runtime_name is not None:
            self._values["integration_runtime_name"] = integration_runtime_name
        if parameters is not None:
            self._values["parameters"] = parameters
        if timeouts is not None:
            self._values["timeouts"] = timeouts

    @builtins.property
    def count(self) -> typing.Optional[jsii.Number]:
        """
        :stability: experimental
        """
        result = self._values.get("count")
        return result

    @builtins.property
    def depends_on(self) -> typing.Optional[typing.List[cdktf.TerraformResource]]:
        """
        :stability: experimental
        """
        result = self._values.get("depends_on")
        return result

    @builtins.property
    def lifecycle(self) -> typing.Optional[cdktf.TerraformResourceLifecycle]:
        """
        :stability: experimental
        """
        result = self._values.get("lifecycle")
        return result

    @builtins.property
    def provider(self) -> typing.Optional[cdktf.TerraformProvider]:
        """
        :stability: experimental
        """
        result = self._values.get("provider")
        return result

    @builtins.property
    def connection_string(self) -> builtins.str:
        result = self._values.get("connection_string")
        assert result is not None, "Required property 'connection_string' is missing"
        return result

    @builtins.property
    def data_factory_name(self) -> builtins.str:
        result = self._values.get("data_factory_name")
        assert result is not None, "Required property 'data_factory_name' is missing"
        return result

    @builtins.property
    def name(self) -> builtins.str:
        result = self._values.get("name")
        assert result is not None, "Required property 'name' is missing"
        return result

    @builtins.property
    def resource_group_name(self) -> builtins.str:
        result = self._values.get("resource_group_name")
        assert result is not None, "Required property 'resource_group_name' is missing"
        return result

    @builtins.property
    def additional_properties(
        self,
    ) -> typing.Optional[typing.Mapping[builtins.str, builtins.str]]:
        result = self._values.get("additional_properties")
        return result

    @builtins.property
    def annotations(self) -> typing.Optional[typing.List[builtins.str]]:
        result = self._values.get("annotations")
        return result

    @builtins.property
    def description(self) -> typing.Optional[builtins.str]:
        result = self._values.get("description")
        return result

    @builtins.property
    def integration_runtime_name(self) -> typing.Optional[builtins.str]:
        result = self._values.get("integration_runtime_name")
        return result

    @builtins.property
    def parameters(self) -> typing.Optional[typing.Mapping[builtins.str, builtins.str]]:
        result = self._values.get("parameters")
        return result

    @builtins.property
    def timeouts(self) -> typing.Optional["DataFactoryLinkedServiceMysqlTimeouts"]:
        """timeouts block."""
        result = self._values.get("timeouts")
        return result

    def __eq__(self, rhs: typing.Any) -> builtins.bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs: typing.Any) -> builtins.bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return "DataFactoryLinkedServiceMysqlConfig(%s)" % ", ".join(
            k + "=" + repr(v) for k, v in self._values.items()
        )


@jsii.data_type(
    jsii_type="@cdktf/provider-azurerm.DataFactoryLinkedServiceMysqlTimeouts",
    jsii_struct_bases=[],
    name_mapping={
        "create": "create",
        "delete": "delete",
        "read": "read",
        "update": "update",
    },
)
class DataFactoryLinkedServiceMysqlTimeouts:
    def __init__(
        self,
        *,
        create: typing.Optional[builtins.str] = None,
        delete: typing.Optional[builtins.str] = None,
        read: typing.Optional[builtins.str] = None,
        update: typing.Optional[builtins.str] = None,
    ) -> None:
        """
        :param create: 
        :param delete: 
        :param read: 
        :param update: 
        """
        self._values: typing.Dict[str, typing.Any] = {}
        if create is not None:
            self._values["create"] = create
        if delete is not None:
            self._values["delete"] = delete
        if read is not None:
            self._values["read"] = read
        if update is not None:
            self._values["update"] = update

    @builtins.property
    def create(self) -> typing.Optional[builtins.str]:
        result = self._values.get("create")
        return result

    @builtins.property
    def delete(self) -> typing.Optional[builtins.str]:
        result = self._values.get("delete")
        return result

    @builtins.property
    def read(self) -> typing.Optional[builtins.str]:
        result = self._values.get("read")
        return result

    @builtins.property
    def update(self) -> typing.Optional[builtins.str]:
        result = self._values.get("update")
        return result

    def __eq__(self, rhs: typing.Any) -> builtins.bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs: typing.Any) -> builtins.bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return "DataFactoryLinkedServiceMysqlTimeouts(%s)" % ", ".join(
            k + "=" + repr(v) for k, v in self._values.items()
        )


class DataFactoryLinkedServicePostgresql(
    cdktf.TerraformResource,
    metaclass=jsii.JSIIMeta,
    jsii_type="@cdktf/provider-azurerm.DataFactoryLinkedServicePostgresql",
):
    def __init__(
        self,
        scope: constructs.Construct,
        id: builtins.str,
        *,
        connection_string: builtins.str,
        data_factory_name: builtins.str,
        name: builtins.str,
        resource_group_name: builtins.str,
        additional_properties: typing.Optional[typing.Mapping[builtins.str, builtins.str]] = None,
        annotations: typing.Optional[typing.List[builtins.str]] = None,
        description: typing.Optional[builtins.str] = None,
        integration_runtime_name: typing.Optional[builtins.str] = None,
        parameters: typing.Optional[typing.Mapping[builtins.str, builtins.str]] = None,
        timeouts: typing.Optional["DataFactoryLinkedServicePostgresqlTimeouts"] = None,
        count: typing.Optional[jsii.Number] = None,
        depends_on: typing.Optional[typing.List[cdktf.TerraformResource]] = None,
        lifecycle: typing.Optional[cdktf.TerraformResourceLifecycle] = None,
        provider: typing.Optional[cdktf.TerraformProvider] = None,
    ) -> None:
        """
        :param scope: -
        :param id: -
        :param connection_string: 
        :param data_factory_name: 
        :param name: 
        :param resource_group_name: 
        :param additional_properties: 
        :param annotations: 
        :param description: 
        :param integration_runtime_name: 
        :param parameters: 
        :param timeouts: timeouts block.
        :param count: 
        :param depends_on: 
        :param lifecycle: 
        :param provider: 
        """
        config = DataFactoryLinkedServicePostgresqlConfig(
            connection_string=connection_string,
            data_factory_name=data_factory_name,
            name=name,
            resource_group_name=resource_group_name,
            additional_properties=additional_properties,
            annotations=annotations,
            description=description,
            integration_runtime_name=integration_runtime_name,
            parameters=parameters,
            timeouts=timeouts,
            count=count,
            depends_on=depends_on,
            lifecycle=lifecycle,
            provider=provider,
        )

        jsii.create(DataFactoryLinkedServicePostgresql, self, [scope, id, config])

    @jsii.member(jsii_name="synthesizeAttributes")
    def _synthesize_attributes(self) -> typing.Mapping[builtins.str, typing.Any]:
        return jsii.invoke(self, "synthesizeAttributes", [])

    @builtins.property # type: ignore
    @jsii.member(jsii_name="connectionString")
    def connection_string(self) -> builtins.str:
        return jsii.get(self, "connectionString")

    @connection_string.setter # type: ignore
    def connection_string(self, value: builtins.str) -> None:
        jsii.set(self, "connectionString", value)

    @builtins.property # type: ignore
    @jsii.member(jsii_name="dataFactoryName")
    def data_factory_name(self) -> builtins.str:
        return jsii.get(self, "dataFactoryName")

    @data_factory_name.setter # type: ignore
    def data_factory_name(self, value: builtins.str) -> None:
        jsii.set(self, "dataFactoryName", value)

    @builtins.property # type: ignore
    @jsii.member(jsii_name="name")
    def name(self) -> builtins.str:
        return jsii.get(self, "name")

    @name.setter # type: ignore
    def name(self, value: builtins.str) -> None:
        jsii.set(self, "name", value)

    @builtins.property # type: ignore
    @jsii.member(jsii_name="resourceGroupName")
    def resource_group_name(self) -> builtins.str:
        return jsii.get(self, "resourceGroupName")

    @resource_group_name.setter # type: ignore
    def resource_group_name(self, value: builtins.str) -> None:
        jsii.set(self, "resourceGroupName", value)

    @builtins.property # type: ignore
    @jsii.member(jsii_name="additionalProperties")
    def additional_properties(
        self,
    ) -> typing.Optional[typing.Mapping[builtins.str, builtins.str]]:
        return jsii.get(self, "additionalProperties")

    @additional_properties.setter # type: ignore
    def additional_properties(
        self,
        value: typing.Optional[typing.Mapping[builtins.str, builtins.str]],
    ) -> None:
        jsii.set(self, "additionalProperties", value)

    @builtins.property # type: ignore
    @jsii.member(jsii_name="annotations")
    def annotations(self) -> typing.Optional[typing.List[builtins.str]]:
        return jsii.get(self, "annotations")

    @annotations.setter # type: ignore
    def annotations(self, value: typing.Optional[typing.List[builtins.str]]) -> None:
        jsii.set(self, "annotations", value)

    @builtins.property # type: ignore
    @jsii.member(jsii_name="description")
    def description(self) -> typing.Optional[builtins.str]:
        return jsii.get(self, "description")

    @description.setter # type: ignore
    def description(self, value: typing.Optional[builtins.str]) -> None:
        jsii.set(self, "description", value)

    @builtins.property # type: ignore
    @jsii.member(jsii_name="id")
    def id(self) -> typing.Optional[builtins.str]:
        return jsii.get(self, "id")

    @id.setter # type: ignore
    def id(self, value: typing.Optional[builtins.str]) -> None:
        jsii.set(self, "id", value)

    @builtins.property # type: ignore
    @jsii.member(jsii_name="integrationRuntimeName")
    def integration_runtime_name(self) -> typing.Optional[builtins.str]:
        return jsii.get(self, "integrationRuntimeName")

    @integration_runtime_name.setter # type: ignore
    def integration_runtime_name(self, value: typing.Optional[builtins.str]) -> None:
        jsii.set(self, "integrationRuntimeName", value)

    @builtins.property # type: ignore
    @jsii.member(jsii_name="parameters")
    def parameters(self) -> typing.Optional[typing.Mapping[builtins.str, builtins.str]]:
        return jsii.get(self, "parameters")

    @parameters.setter # type: ignore
    def parameters(
        self,
        value: typing.Optional[typing.Mapping[builtins.str, builtins.str]],
    ) -> None:
        jsii.set(self, "parameters", value)

    @builtins.property # type: ignore
    @jsii.member(jsii_name="timeouts")
    def timeouts(self) -> typing.Optional["DataFactoryLinkedServicePostgresqlTimeouts"]:
        return jsii.get(self, "timeouts")

    @timeouts.setter # type: ignore
    def timeouts(
        self,
        value: typing.Optional["DataFactoryLinkedServicePostgresqlTimeouts"],
    ) -> None:
        jsii.set(self, "timeouts", value)


@jsii.data_type(
    jsii_type="@cdktf/provider-azurerm.DataFactoryLinkedServicePostgresqlConfig",
    jsii_struct_bases=[cdktf.TerraformMetaArguments],
    name_mapping={
        "count": "count",
        "depends_on": "dependsOn",
        "lifecycle": "lifecycle",
        "provider": "provider",
        "connection_string": "connectionString",
        "data_factory_name": "dataFactoryName",
        "name": "name",
        "resource_group_name": "resourceGroupName",
        "additional_properties": "additionalProperties",
        "annotations": "annotations",
        "description": "description",
        "integration_runtime_name": "integrationRuntimeName",
        "parameters": "parameters",
        "timeouts": "timeouts",
    },
)
class DataFactoryLinkedServicePostgresqlConfig(cdktf.TerraformMetaArguments):
    def __init__(
        self,
        *,
        count: typing.Optional[jsii.Number] = None,
        depends_on: typing.Optional[typing.List[cdktf.TerraformResource]] = None,
        lifecycle: typing.Optional[cdktf.TerraformResourceLifecycle] = None,
        provider: typing.Optional[cdktf.TerraformProvider] = None,
        connection_string: builtins.str,
        data_factory_name: builtins.str,
        name: builtins.str,
        resource_group_name: builtins.str,
        additional_properties: typing.Optional[typing.Mapping[builtins.str, builtins.str]] = None,
        annotations: typing.Optional[typing.List[builtins.str]] = None,
        description: typing.Optional[builtins.str] = None,
        integration_runtime_name: typing.Optional[builtins.str] = None,
        parameters: typing.Optional[typing.Mapping[builtins.str, builtins.str]] = None,
        timeouts: typing.Optional["DataFactoryLinkedServicePostgresqlTimeouts"] = None,
    ) -> None:
        """
        :param count: 
        :param depends_on: 
        :param lifecycle: 
        :param provider: 
        :param connection_string: 
        :param data_factory_name: 
        :param name: 
        :param resource_group_name: 
        :param additional_properties: 
        :param annotations: 
        :param description: 
        :param integration_runtime_name: 
        :param parameters: 
        :param timeouts: timeouts block.
        """
        if isinstance(lifecycle, dict):
            lifecycle = cdktf.TerraformResourceLifecycle(**lifecycle)
        if isinstance(timeouts, dict):
            timeouts = DataFactoryLinkedServicePostgresqlTimeouts(**timeouts)
        self._values: typing.Dict[str, typing.Any] = {
            "connection_string": connection_string,
            "data_factory_name": data_factory_name,
            "name": name,
            "resource_group_name": resource_group_name,
        }
        if count is not None:
            self._values["count"] = count
        if depends_on is not None:
            self._values["depends_on"] = depends_on
        if lifecycle is not None:
            self._values["lifecycle"] = lifecycle
        if provider is not None:
            self._values["provider"] = provider
        if additional_properties is not None:
            self._values["additional_properties"] = additional_properties
        if annotations is not None:
            self._values["annotations"] = annotations
        if description is not None:
            self._values["description"] = description
        if integration_runtime_name is not None:
            self._values["integration_runtime_name"] = integration_runtime_name
        if parameters is not None:
            self._values["parameters"] = parameters
        if timeouts is not None:
            self._values["timeouts"] = timeouts

    @builtins.property
    def count(self) -> typing.Optional[jsii.Number]:
        """
        :stability: experimental
        """
        result = self._values.get("count")
        return result

    @builtins.property
    def depends_on(self) -> typing.Optional[typing.List[cdktf.TerraformResource]]:
        """
        :stability: experimental
        """
        result = self._values.get("depends_on")
        return result

    @builtins.property
    def lifecycle(self) -> typing.Optional[cdktf.TerraformResourceLifecycle]:
        """
        :stability: experimental
        """
        result = self._values.get("lifecycle")
        return result

    @builtins.property
    def provider(self) -> typing.Optional[cdktf.TerraformProvider]:
        """
        :stability: experimental
        """
        result = self._values.get("provider")
        return result

    @builtins.property
    def connection_string(self) -> builtins.str:
        result = self._values.get("connection_string")
        assert result is not None, "Required property 'connection_string' is missing"
        return result

    @builtins.property
    def data_factory_name(self) -> builtins.str:
        result = self._values.get("data_factory_name")
        assert result is not None, "Required property 'data_factory_name' is missing"
        return result

    @builtins.property
    def name(self) -> builtins.str:
        result = self._values.get("name")
        assert result is not None, "Required property 'name' is missing"
        return result

    @builtins.property
    def resource_group_name(self) -> builtins.str:
        result = self._values.get("resource_group_name")
        assert result is not None, "Required property 'resource_group_name' is missing"
        return result

    @builtins.property
    def additional_properties(
        self,
    ) -> typing.Optional[typing.Mapping[builtins.str, builtins.str]]:
        result = self._values.get("additional_properties")
        return result

    @builtins.property
    def annotations(self) -> typing.Optional[typing.List[builtins.str]]:
        result = self._values.get("annotations")
        return result

    @builtins.property
    def description(self) -> typing.Optional[builtins.str]:
        result = self._values.get("description")
        return result

    @builtins.property
    def integration_runtime_name(self) -> typing.Optional[builtins.str]:
        result = self._values.get("integration_runtime_name")
        return result

    @builtins.property
    def parameters(self) -> typing.Optional[typing.Mapping[builtins.str, builtins.str]]:
        result = self._values.get("parameters")
        return result

    @builtins.property
    def timeouts(self) -> typing.Optional["DataFactoryLinkedServicePostgresqlTimeouts"]:
        """timeouts block."""
        result = self._values.get("timeouts")
        return result

    def __eq__(self, rhs: typing.Any) -> builtins.bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs: typing.Any) -> builtins.bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return "DataFactoryLinkedServicePostgresqlConfig(%s)" % ", ".join(
            k + "=" + repr(v) for k, v in self._values.items()
        )


@jsii.data_type(
    jsii_type="@cdktf/provider-azurerm.DataFactoryLinkedServicePostgresqlTimeouts",
    jsii_struct_bases=[],
    name_mapping={
        "create": "create",
        "delete": "delete",
        "read": "read",
        "update": "update",
    },
)
class DataFactoryLinkedServicePostgresqlTimeouts:
    def __init__(
        self,
        *,
        create: typing.Optional[builtins.str] = None,
        delete: typing.Optional[builtins.str] = None,
        read: typing.Optional[builtins.str] = None,
        update: typing.Optional[builtins.str] = None,
    ) -> None:
        """
        :param create: 
        :param delete: 
        :param read: 
        :param update: 
        """
        self._values: typing.Dict[str, typing.Any] = {}
        if create is not None:
            self._values["create"] = create
        if delete is not None:
            self._values["delete"] = delete
        if read is not None:
            self._values["read"] = read
        if update is not None:
            self._values["update"] = update

    @builtins.property
    def create(self) -> typing.Optional[builtins.str]:
        result = self._values.get("create")
        return result

    @builtins.property
    def delete(self) -> typing.Optional[builtins.str]:
        result = self._values.get("delete")
        return result

    @builtins.property
    def read(self) -> typing.Optional[builtins.str]:
        result = self._values.get("read")
        return result

    @builtins.property
    def update(self) -> typing.Optional[builtins.str]:
        result = self._values.get("update")
        return result

    def __eq__(self, rhs: typing.Any) -> builtins.bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs: typing.Any) -> builtins.bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return "DataFactoryLinkedServicePostgresqlTimeouts(%s)" % ", ".join(
            k + "=" + repr(v) for k, v in self._values.items()
        )


class DataFactoryLinkedServiceSqlServer(
    cdktf.TerraformResource,
    metaclass=jsii.JSIIMeta,
    jsii_type="@cdktf/provider-azurerm.DataFactoryLinkedServiceSqlServer",
):
    def __init__(
        self,
        scope: constructs.Construct,
        id: builtins.str,
        *,
        connection_string: builtins.str,
        data_factory_name: builtins.str,
        name: builtins.str,
        resource_group_name: builtins.str,
        additional_properties: typing.Optional[typing.Mapping[builtins.str, builtins.str]] = None,
        annotations: typing.Optional[typing.List[builtins.str]] = None,
        description: typing.Optional[builtins.str] = None,
        integration_runtime_name: typing.Optional[builtins.str] = None,
        parameters: typing.Optional[typing.Mapping[builtins.str, builtins.str]] = None,
        timeouts: typing.Optional["DataFactoryLinkedServiceSqlServerTimeouts"] = None,
        count: typing.Optional[jsii.Number] = None,
        depends_on: typing.Optional[typing.List[cdktf.TerraformResource]] = None,
        lifecycle: typing.Optional[cdktf.TerraformResourceLifecycle] = None,
        provider: typing.Optional[cdktf.TerraformProvider] = None,
    ) -> None:
        """
        :param scope: -
        :param id: -
        :param connection_string: 
        :param data_factory_name: 
        :param name: 
        :param resource_group_name: 
        :param additional_properties: 
        :param annotations: 
        :param description: 
        :param integration_runtime_name: 
        :param parameters: 
        :param timeouts: timeouts block.
        :param count: 
        :param depends_on: 
        :param lifecycle: 
        :param provider: 
        """
        config = DataFactoryLinkedServiceSqlServerConfig(
            connection_string=connection_string,
            data_factory_name=data_factory_name,
            name=name,
            resource_group_name=resource_group_name,
            additional_properties=additional_properties,
            annotations=annotations,
            description=description,
            integration_runtime_name=integration_runtime_name,
            parameters=parameters,
            timeouts=timeouts,
            count=count,
            depends_on=depends_on,
            lifecycle=lifecycle,
            provider=provider,
        )

        jsii.create(DataFactoryLinkedServiceSqlServer, self, [scope, id, config])

    @jsii.member(jsii_name="synthesizeAttributes")
    def _synthesize_attributes(self) -> typing.Mapping[builtins.str, typing.Any]:
        return jsii.invoke(self, "synthesizeAttributes", [])

    @builtins.property # type: ignore
    @jsii.member(jsii_name="connectionString")
    def connection_string(self) -> builtins.str:
        return jsii.get(self, "connectionString")

    @connection_string.setter # type: ignore
    def connection_string(self, value: builtins.str) -> None:
        jsii.set(self, "connectionString", value)

    @builtins.property # type: ignore
    @jsii.member(jsii_name="dataFactoryName")
    def data_factory_name(self) -> builtins.str:
        return jsii.get(self, "dataFactoryName")

    @data_factory_name.setter # type: ignore
    def data_factory_name(self, value: builtins.str) -> None:
        jsii.set(self, "dataFactoryName", value)

    @builtins.property # type: ignore
    @jsii.member(jsii_name="name")
    def name(self) -> builtins.str:
        return jsii.get(self, "name")

    @name.setter # type: ignore
    def name(self, value: builtins.str) -> None:
        jsii.set(self, "name", value)

    @builtins.property # type: ignore
    @jsii.member(jsii_name="resourceGroupName")
    def resource_group_name(self) -> builtins.str:
        return jsii.get(self, "resourceGroupName")

    @resource_group_name.setter # type: ignore
    def resource_group_name(self, value: builtins.str) -> None:
        jsii.set(self, "resourceGroupName", value)

    @builtins.property # type: ignore
    @jsii.member(jsii_name="additionalProperties")
    def additional_properties(
        self,
    ) -> typing.Optional[typing.Mapping[builtins.str, builtins.str]]:
        return jsii.get(self, "additionalProperties")

    @additional_properties.setter # type: ignore
    def additional_properties(
        self,
        value: typing.Optional[typing.Mapping[builtins.str, builtins.str]],
    ) -> None:
        jsii.set(self, "additionalProperties", value)

    @builtins.property # type: ignore
    @jsii.member(jsii_name="annotations")
    def annotations(self) -> typing.Optional[typing.List[builtins.str]]:
        return jsii.get(self, "annotations")

    @annotations.setter # type: ignore
    def annotations(self, value: typing.Optional[typing.List[builtins.str]]) -> None:
        jsii.set(self, "annotations", value)

    @builtins.property # type: ignore
    @jsii.member(jsii_name="description")
    def description(self) -> typing.Optional[builtins.str]:
        return jsii.get(self, "description")

    @description.setter # type: ignore
    def description(self, value: typing.Optional[builtins.str]) -> None:
        jsii.set(self, "description", value)

    @builtins.property # type: ignore
    @jsii.member(jsii_name="id")
    def id(self) -> typing.Optional[builtins.str]:
        return jsii.get(self, "id")

    @id.setter # type: ignore
    def id(self, value: typing.Optional[builtins.str]) -> None:
        jsii.set(self, "id", value)

    @builtins.property # type: ignore
    @jsii.member(jsii_name="integrationRuntimeName")
    def integration_runtime_name(self) -> typing.Optional[builtins.str]:
        return jsii.get(self, "integrationRuntimeName")

    @integration_runtime_name.setter # type: ignore
    def integration_runtime_name(self, value: typing.Optional[builtins.str]) -> None:
        jsii.set(self, "integrationRuntimeName", value)

    @builtins.property # type: ignore
    @jsii.member(jsii_name="parameters")
    def parameters(self) -> typing.Optional[typing.Mapping[builtins.str, builtins.str]]:
        return jsii.get(self, "parameters")

    @parameters.setter # type: ignore
    def parameters(
        self,
        value: typing.Optional[typing.Mapping[builtins.str, builtins.str]],
    ) -> None:
        jsii.set(self, "parameters", value)

    @builtins.property # type: ignore
    @jsii.member(jsii_name="timeouts")
    def timeouts(self) -> typing.Optional["DataFactoryLinkedServiceSqlServerTimeouts"]:
        return jsii.get(self, "timeouts")

    @timeouts.setter # type: ignore
    def timeouts(
        self,
        value: typing.Optional["DataFactoryLinkedServiceSqlServerTimeouts"],
    ) -> None:
        jsii.set(self, "timeouts", value)


@jsii.data_type(
    jsii_type="@cdktf/provider-azurerm.DataFactoryLinkedServiceSqlServerConfig",
    jsii_struct_bases=[cdktf.TerraformMetaArguments],
    name_mapping={
        "count": "count",
        "depends_on": "dependsOn",
        "lifecycle": "lifecycle",
        "provider": "provider",
        "connection_string": "connectionString",
        "data_factory_name": "dataFactoryName",
        "name": "name",
        "resource_group_name": "resourceGroupName",
        "additional_properties": "additionalProperties",
        "annotations": "annotations",
        "description": "description",
        "integration_runtime_name": "integrationRuntimeName",
        "parameters": "parameters",
        "timeouts": "timeouts",
    },
)
class DataFactoryLinkedServiceSqlServerConfig(cdktf.TerraformMetaArguments):
    def __init__(
        self,
        *,
        count: typing.Optional[jsii.Number] = None,
        depends_on: typing.Optional[typing.List[cdktf.TerraformResource]] = None,
        lifecycle: typing.Optional[cdktf.TerraformResourceLifecycle] = None,
        provider: typing.Optional[cdktf.TerraformProvider] = None,
        connection_string: builtins.str,
        data_factory_name: builtins.str,
        name: builtins.str,
        resource_group_name: builtins.str,
        additional_properties: typing.Optional[typing.Mapping[builtins.str, builtins.str]] = None,
        annotations: typing.Optional[typing.List[builtins.str]] = None,
        description: typing.Optional[builtins.str] = None,
        integration_runtime_name: typing.Optional[builtins.str] = None,
        parameters: typing.Optional[typing.Mapping[builtins.str, builtins.str]] = None,
        timeouts: typing.Optional["DataFactoryLinkedServiceSqlServerTimeouts"] = None,
    ) -> None:
        """
        :param count: 
        :param depends_on: 
        :param lifecycle: 
        :param provider: 
        :param connection_string: 
        :param data_factory_name: 
        :param name: 
        :param resource_group_name: 
        :param additional_properties: 
        :param annotations: 
        :param description: 
        :param integration_runtime_name: 
        :param parameters: 
        :param timeouts: timeouts block.
        """
        if isinstance(lifecycle, dict):
            lifecycle = cdktf.TerraformResourceLifecycle(**lifecycle)
        if isinstance(timeouts, dict):
            timeouts = DataFactoryLinkedServiceSqlServerTimeouts(**timeouts)
        self._values: typing.Dict[str, typing.Any] = {
            "connection_string": connection_string,
            "data_factory_name": data_factory_name,
            "name": name,
            "resource_group_name": resource_group_name,
        }
        if count is not None:
            self._values["count"] = count
        if depends_on is not None:
            self._values["depends_on"] = depends_on
        if lifecycle is not None:
            self._values["lifecycle"] = lifecycle
        if provider is not None:
            self._values["provider"] = provider
        if additional_properties is not None:
            self._values["additional_properties"] = additional_properties
        if annotations is not None:
            self._values["annotations"] = annotations
        if description is not None:
            self._values["description"] = description
        if integration_runtime_name is not None:
            self._values["integration_runtime_name"] = integration_runtime_name
        if parameters is not None:
            self._values["parameters"] = parameters
        if timeouts is not None:
            self._values["timeouts"] = timeouts

    @builtins.property
    def count(self) -> typing.Optional[jsii.Number]:
        """
        :stability: experimental
        """
        result = self._values.get("count")
        return result

    @builtins.property
    def depends_on(self) -> typing.Optional[typing.List[cdktf.TerraformResource]]:
        """
        :stability: experimental
        """
        result = self._values.get("depends_on")
        return result

    @builtins.property
    def lifecycle(self) -> typing.Optional[cdktf.TerraformResourceLifecycle]:
        """
        :stability: experimental
        """
        result = self._values.get("lifecycle")
        return result

    @builtins.property
    def provider(self) -> typing.Optional[cdktf.TerraformProvider]:
        """
        :stability: experimental
        """
        result = self._values.get("provider")
        return result

    @builtins.property
    def connection_string(self) -> builtins.str:
        result = self._values.get("connection_string")
        assert result is not None, "Required property 'connection_string' is missing"
        return result

    @builtins.property
    def data_factory_name(self) -> builtins.str:
        result = self._values.get("data_factory_name")
        assert result is not None, "Required property 'data_factory_name' is missing"
        return result

    @builtins.property
    def name(self) -> builtins.str:
        result = self._values.get("name")
        assert result is not None, "Required property 'name' is missing"
        return result

    @builtins.property
    def resource_group_name(self) -> builtins.str:
        result = self._values.get("resource_group_name")
        assert result is not None, "Required property 'resource_group_name' is missing"
        return result

    @builtins.property
    def additional_properties(
        self,
    ) -> typing.Optional[typing.Mapping[builtins.str, builtins.str]]:
        result = self._values.get("additional_properties")
        return result

    @builtins.property
    def annotations(self) -> typing.Optional[typing.List[builtins.str]]:
        result = self._values.get("annotations")
        return result

    @builtins.property
    def description(self) -> typing.Optional[builtins.str]:
        result = self._values.get("description")
        return result

    @builtins.property
    def integration_runtime_name(self) -> typing.Optional[builtins.str]:
        result = self._values.get("integration_runtime_name")
        return result

    @builtins.property
    def parameters(self) -> typing.Optional[typing.Mapping[builtins.str, builtins.str]]:
        result = self._values.get("parameters")
        return result

    @builtins.property
    def timeouts(self) -> typing.Optional["DataFactoryLinkedServiceSqlServerTimeouts"]:
        """timeouts block."""
        result = self._values.get("timeouts")
        return result

    def __eq__(self, rhs: typing.Any) -> builtins.bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs: typing.Any) -> builtins.bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return "DataFactoryLinkedServiceSqlServerConfig(%s)" % ", ".join(
            k + "=" + repr(v) for k, v in self._values.items()
        )


@jsii.data_type(
    jsii_type="@cdktf/provider-azurerm.DataFactoryLinkedServiceSqlServerTimeouts",
    jsii_struct_bases=[],
    name_mapping={
        "create": "create",
        "delete": "delete",
        "read": "read",
        "update": "update",
    },
)
class DataFactoryLinkedServiceSqlServerTimeouts:
    def __init__(
        self,
        *,
        create: typing.Optional[builtins.str] = None,
        delete: typing.Optional[builtins.str] = None,
        read: typing.Optional[builtins.str] = None,
        update: typing.Optional[builtins.str] = None,
    ) -> None:
        """
        :param create: 
        :param delete: 
        :param read: 
        :param update: 
        """
        self._values: typing.Dict[str, typing.Any] = {}
        if create is not None:
            self._values["create"] = create
        if delete is not None:
            self._values["delete"] = delete
        if read is not None:
            self._values["read"] = read
        if update is not None:
            self._values["update"] = update

    @builtins.property
    def create(self) -> typing.Optional[builtins.str]:
        result = self._values.get("create")
        return result

    @builtins.property
    def delete(self) -> typing.Optional[builtins.str]:
        result = self._values.get("delete")
        return result

    @builtins.property
    def read(self) -> typing.Optional[builtins.str]:
        result = self._values.get("read")
        return result

    @builtins.property
    def update(self) -> typing.Optional[builtins.str]:
        result = self._values.get("update")
        return result

    def __eq__(self, rhs: typing.Any) -> builtins.bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs: typing.Any) -> builtins.bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return "DataFactoryLinkedServiceSqlServerTimeouts(%s)" % ", ".join(
            k + "=" + repr(v) for k, v in self._values.items()
        )


class DataFactoryPipeline(
    cdktf.TerraformResource,
    metaclass=jsii.JSIIMeta,
    jsii_type="@cdktf/provider-azurerm.DataFactoryPipeline",
):
    def __init__(
        self,
        scope: constructs.Construct,
        id: builtins.str,
        *,
        data_factory_name: builtins.str,
        name: builtins.str,
        resource_group_name: builtins.str,
        annotations: typing.Optional[typing.List[builtins.str]] = None,
        description: typing.Optional[builtins.str] = None,
        parameters: typing.Optional[typing.Mapping[builtins.str, builtins.str]] = None,
        timeouts: typing.Optional["DataFactoryPipelineTimeouts"] = None,
        variables: typing.Optional[typing.Mapping[builtins.str, builtins.str]] = None,
        count: typing.Optional[jsii.Number] = None,
        depends_on: typing.Optional[typing.List[cdktf.TerraformResource]] = None,
        lifecycle: typing.Optional[cdktf.TerraformResourceLifecycle] = None,
        provider: typing.Optional[cdktf.TerraformProvider] = None,
    ) -> None:
        """
        :param scope: -
        :param id: -
        :param data_factory_name: 
        :param name: 
        :param resource_group_name: 
        :param annotations: 
        :param description: 
        :param parameters: 
        :param timeouts: timeouts block.
        :param variables: 
        :param count: 
        :param depends_on: 
        :param lifecycle: 
        :param provider: 
        """
        config = DataFactoryPipelineConfig(
            data_factory_name=data_factory_name,
            name=name,
            resource_group_name=resource_group_name,
            annotations=annotations,
            description=description,
            parameters=parameters,
            timeouts=timeouts,
            variables=variables,
            count=count,
            depends_on=depends_on,
            lifecycle=lifecycle,
            provider=provider,
        )

        jsii.create(DataFactoryPipeline, self, [scope, id, config])

    @jsii.member(jsii_name="synthesizeAttributes")
    def _synthesize_attributes(self) -> typing.Mapping[builtins.str, typing.Any]:
        return jsii.invoke(self, "synthesizeAttributes", [])

    @builtins.property # type: ignore
    @jsii.member(jsii_name="dataFactoryName")
    def data_factory_name(self) -> builtins.str:
        return jsii.get(self, "dataFactoryName")

    @data_factory_name.setter # type: ignore
    def data_factory_name(self, value: builtins.str) -> None:
        jsii.set(self, "dataFactoryName", value)

    @builtins.property # type: ignore
    @jsii.member(jsii_name="name")
    def name(self) -> builtins.str:
        return jsii.get(self, "name")

    @name.setter # type: ignore
    def name(self, value: builtins.str) -> None:
        jsii.set(self, "name", value)

    @builtins.property # type: ignore
    @jsii.member(jsii_name="resourceGroupName")
    def resource_group_name(self) -> builtins.str:
        return jsii.get(self, "resourceGroupName")

    @resource_group_name.setter # type: ignore
    def resource_group_name(self, value: builtins.str) -> None:
        jsii.set(self, "resourceGroupName", value)

    @builtins.property # type: ignore
    @jsii.member(jsii_name="annotations")
    def annotations(self) -> typing.Optional[typing.List[builtins.str]]:
        return jsii.get(self, "annotations")

    @annotations.setter # type: ignore
    def annotations(self, value: typing.Optional[typing.List[builtins.str]]) -> None:
        jsii.set(self, "annotations", value)

    @builtins.property # type: ignore
    @jsii.member(jsii_name="description")
    def description(self) -> typing.Optional[builtins.str]:
        return jsii.get(self, "description")

    @description.setter # type: ignore
    def description(self, value: typing.Optional[builtins.str]) -> None:
        jsii.set(self, "description", value)

    @builtins.property # type: ignore
    @jsii.member(jsii_name="id")
    def id(self) -> typing.Optional[builtins.str]:
        return jsii.get(self, "id")

    @id.setter # type: ignore
    def id(self, value: typing.Optional[builtins.str]) -> None:
        jsii.set(self, "id", value)

    @builtins.property # type: ignore
    @jsii.member(jsii_name="parameters")
    def parameters(self) -> typing.Optional[typing.Mapping[builtins.str, builtins.str]]:
        return jsii.get(self, "parameters")

    @parameters.setter # type: ignore
    def parameters(
        self,
        value: typing.Optional[typing.Mapping[builtins.str, builtins.str]],
    ) -> None:
        jsii.set(self, "parameters", value)

    @builtins.property # type: ignore
    @jsii.member(jsii_name="timeouts")
    def timeouts(self) -> typing.Optional["DataFactoryPipelineTimeouts"]:
        return jsii.get(self, "timeouts")

    @timeouts.setter # type: ignore
    def timeouts(self, value: typing.Optional["DataFactoryPipelineTimeouts"]) -> None:
        jsii.set(self, "timeouts", value)

    @builtins.property # type: ignore
    @jsii.member(jsii_name="variables")
    def variables(self) -> typing.Optional[typing.Mapping[builtins.str, builtins.str]]:
        return jsii.get(self, "variables")

    @variables.setter # type: ignore
    def variables(
        self,
        value: typing.Optional[typing.Mapping[builtins.str, builtins.str]],
    ) -> None:
        jsii.set(self, "variables", value)


@jsii.data_type(
    jsii_type="@cdktf/provider-azurerm.DataFactoryPipelineConfig",
    jsii_struct_bases=[cdktf.TerraformMetaArguments],
    name_mapping={
        "count": "count",
        "depends_on": "dependsOn",
        "lifecycle": "lifecycle",
        "provider": "provider",
        "data_factory_name": "dataFactoryName",
        "name": "name",
        "resource_group_name": "resourceGroupName",
        "annotations": "annotations",
        "description": "description",
        "parameters": "parameters",
        "timeouts": "timeouts",
        "variables": "variables",
    },
)
class DataFactoryPipelineConfig(cdktf.TerraformMetaArguments):
    def __init__(
        self,
        *,
        count: typing.Optional[jsii.Number] = None,
        depends_on: typing.Optional[typing.List[cdktf.TerraformResource]] = None,
        lifecycle: typing.Optional[cdktf.TerraformResourceLifecycle] = None,
        provider: typing.Optional[cdktf.TerraformProvider] = None,
        data_factory_name: builtins.str,
        name: builtins.str,
        resource_group_name: builtins.str,
        annotations: typing.Optional[typing.List[builtins.str]] = None,
        description: typing.Optional[builtins.str] = None,
        parameters: typing.Optional[typing.Mapping[builtins.str, builtins.str]] = None,
        timeouts: typing.Optional["DataFactoryPipelineTimeouts"] = None,
        variables: typing.Optional[typing.Mapping[builtins.str, builtins.str]] = None,
    ) -> None:
        """
        :param count: 
        :param depends_on: 
        :param lifecycle: 
        :param provider: 
        :param data_factory_name: 
        :param name: 
        :param resource_group_name: 
        :param annotations: 
        :param description: 
        :param parameters: 
        :param timeouts: timeouts block.
        :param variables: 
        """
        if isinstance(lifecycle, dict):
            lifecycle = cdktf.TerraformResourceLifecycle(**lifecycle)
        if isinstance(timeouts, dict):
            timeouts = DataFactoryPipelineTimeouts(**timeouts)
        self._values: typing.Dict[str, typing.Any] = {
            "data_factory_name": data_factory_name,
            "name": name,
            "resource_group_name": resource_group_name,
        }
        if count is not None:
            self._values["count"] = count
        if depends_on is not None:
            self._values["depends_on"] = depends_on
        if lifecycle is not None:
            self._values["lifecycle"] = lifecycle
        if provider is not None:
            self._values["provider"] = provider
        if annotations is not None:
            self._values["annotations"] = annotations
        if description is not None:
            self._values["description"] = description
        if parameters is not None:
            self._values["parameters"] = parameters
        if timeouts is not None:
            self._values["timeouts"] = timeouts
        if variables is not None:
            self._values["variables"] = variables

    @builtins.property
    def count(self) -> typing.Optional[jsii.Number]:
        """
        :stability: experimental
        """
        result = self._values.get("count")
        return result

    @builtins.property
    def depends_on(self) -> typing.Optional[typing.List[cdktf.TerraformResource]]:
        """
        :stability: experimental
        """
        result = self._values.get("depends_on")
        return result

    @builtins.property
    def lifecycle(self) -> typing.Optional[cdktf.TerraformResourceLifecycle]:
        """
        :stability: experimental
        """
        result = self._values.get("lifecycle")
        return result

    @builtins.property
    def provider(self) -> typing.Optional[cdktf.TerraformProvider]:
        """
        :stability: experimental
        """
        result = self._values.get("provider")
        return result

    @builtins.property
    def data_factory_name(self) -> builtins.str:
        result = self._values.get("data_factory_name")
        assert result is not None, "Required property 'data_factory_name' is missing"
        return result

    @builtins.property
    def name(self) -> builtins.str:
        result = self._values.get("name")
        assert result is not None, "Required property 'name' is missing"
        return result

    @builtins.property
    def resource_group_name(self) -> builtins.str:
        result = self._values.get("resource_group_name")
        assert result is not None, "Required property 'resource_group_name' is missing"
        return result

    @builtins.property
    def annotations(self) -> typing.Optional[typing.List[builtins.str]]:
        result = self._values.get("annotations")
        return result

    @builtins.property
    def description(self) -> typing.Optional[builtins.str]:
        result = self._values.get("description")
        return result

    @builtins.property
    def parameters(self) -> typing.Optional[typing.Mapping[builtins.str, builtins.str]]:
        result = self._values.get("parameters")
        return result

    @builtins.property
    def timeouts(self) -> typing.Optional["DataFactoryPipelineTimeouts"]:
        """timeouts block."""
        result = self._values.get("timeouts")
        return result

    @builtins.property
    def variables(self) -> typing.Optional[typing.Mapping[builtins.str, builtins.str]]:
        result = self._values.get("variables")
        return result

    def __eq__(self, rhs: typing.Any) -> builtins.bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs: typing.Any) -> builtins.bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return "DataFactoryPipelineConfig(%s)" % ", ".join(
            k + "=" + repr(v) for k, v in self._values.items()
        )


@jsii.data_type(
    jsii_type="@cdktf/provider-azurerm.DataFactoryPipelineTimeouts",
    jsii_struct_bases=[],
    name_mapping={
        "create": "create",
        "delete": "delete",
        "read": "read",
        "update": "update",
    },
)
class DataFactoryPipelineTimeouts:
    def __init__(
        self,
        *,
        create: typing.Optional[builtins.str] = None,
        delete: typing.Optional[builtins.str] = None,
        read: typing.Optional[builtins.str] = None,
        update: typing.Optional[builtins.str] = None,
    ) -> None:
        """
        :param create: 
        :param delete: 
        :param read: 
        :param update: 
        """
        self._values: typing.Dict[str, typing.Any] = {}
        if create is not None:
            self._values["create"] = create
        if delete is not None:
            self._values["delete"] = delete
        if read is not None:
            self._values["read"] = read
        if update is not None:
            self._values["update"] = update

    @builtins.property
    def create(self) -> typing.Optional[builtins.str]:
        result = self._values.get("create")
        return result

    @builtins.property
    def delete(self) -> typing.Optional[builtins.str]:
        result = self._values.get("delete")
        return result

    @builtins.property
    def read(self) -> typing.Optional[builtins.str]:
        result = self._values.get("read")
        return result

    @builtins.property
    def update(self) -> typing.Optional[builtins.str]:
        result = self._values.get("update")
        return result

    def __eq__(self, rhs: typing.Any) -> builtins.bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs: typing.Any) -> builtins.bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return "DataFactoryPipelineTimeouts(%s)" % ", ".join(
            k + "=" + repr(v) for k, v in self._values.items()
        )


@jsii.data_type(
    jsii_type="@cdktf/provider-azurerm.DataFactoryTimeouts",
    jsii_struct_bases=[],
    name_mapping={
        "create": "create",
        "delete": "delete",
        "read": "read",
        "update": "update",
    },
)
class DataFactoryTimeouts:
    def __init__(
        self,
        *,
        create: typing.Optional[builtins.str] = None,
        delete: typing.Optional[builtins.str] = None,
        read: typing.Optional[builtins.str] = None,
        update: typing.Optional[builtins.str] = None,
    ) -> None:
        """
        :param create: 
        :param delete: 
        :param read: 
        :param update: 
        """
        self._values: typing.Dict[str, typing.Any] = {}
        if create is not None:
            self._values["create"] = create
        if delete is not None:
            self._values["delete"] = delete
        if read is not None:
            self._values["read"] = read
        if update is not None:
            self._values["update"] = update

    @builtins.property
    def create(self) -> typing.Optional[builtins.str]:
        result = self._values.get("create")
        return result

    @builtins.property
    def delete(self) -> typing.Optional[builtins.str]:
        result = self._values.get("delete")
        return result

    @builtins.property
    def read(self) -> typing.Optional[builtins.str]:
        result = self._values.get("read")
        return result

    @builtins.property
    def update(self) -> typing.Optional[builtins.str]:
        result = self._values.get("update")
        return result

    def __eq__(self, rhs: typing.Any) -> builtins.bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs: typing.Any) -> builtins.bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return "DataFactoryTimeouts(%s)" % ", ".join(
            k + "=" + repr(v) for k, v in self._values.items()
        )


class DataFactoryTriggerSchedule(
    cdktf.TerraformResource,
    metaclass=jsii.JSIIMeta,
    jsii_type="@cdktf/provider-azurerm.DataFactoryTriggerSchedule",
):
    def __init__(
        self,
        scope: constructs.Construct,
        id: builtins.str,
        *,
        data_factory_name: builtins.str,
        name: builtins.str,
        pipeline_name: builtins.str,
        resource_group_name: builtins.str,
        annotations: typing.Optional[typing.List[builtins.str]] = None,
        end_time: typing.Optional[builtins.str] = None,
        frequency: typing.Optional[builtins.str] = None,
        interval: typing.Optional[jsii.Number] = None,
        pipeline_parameters: typing.Optional[typing.Mapping[builtins.str, builtins.str]] = None,
        start_time: typing.Optional[builtins.str] = None,
        timeouts: typing.Optional["DataFactoryTriggerScheduleTimeouts"] = None,
        count: typing.Optional[jsii.Number] = None,
        depends_on: typing.Optional[typing.List[cdktf.TerraformResource]] = None,
        lifecycle: typing.Optional[cdktf.TerraformResourceLifecycle] = None,
        provider: typing.Optional[cdktf.TerraformProvider] = None,
    ) -> None:
        """
        :param scope: -
        :param id: -
        :param data_factory_name: 
        :param name: 
        :param pipeline_name: 
        :param resource_group_name: 
        :param annotations: 
        :param end_time: 
        :param frequency: 
        :param interval: 
        :param pipeline_parameters: 
        :param start_time: 
        :param timeouts: timeouts block.
        :param count: 
        :param depends_on: 
        :param lifecycle: 
        :param provider: 
        """
        config = DataFactoryTriggerScheduleConfig(
            data_factory_name=data_factory_name,
            name=name,
            pipeline_name=pipeline_name,
            resource_group_name=resource_group_name,
            annotations=annotations,
            end_time=end_time,
            frequency=frequency,
            interval=interval,
            pipeline_parameters=pipeline_parameters,
            start_time=start_time,
            timeouts=timeouts,
            count=count,
            depends_on=depends_on,
            lifecycle=lifecycle,
            provider=provider,
        )

        jsii.create(DataFactoryTriggerSchedule, self, [scope, id, config])

    @jsii.member(jsii_name="synthesizeAttributes")
    def _synthesize_attributes(self) -> typing.Mapping[builtins.str, typing.Any]:
        return jsii.invoke(self, "synthesizeAttributes", [])

    @builtins.property # type: ignore
    @jsii.member(jsii_name="dataFactoryName")
    def data_factory_name(self) -> builtins.str:
        return jsii.get(self, "dataFactoryName")

    @data_factory_name.setter # type: ignore
    def data_factory_name(self, value: builtins.str) -> None:
        jsii.set(self, "dataFactoryName", value)

    @builtins.property # type: ignore
    @jsii.member(jsii_name="name")
    def name(self) -> builtins.str:
        return jsii.get(self, "name")

    @name.setter # type: ignore
    def name(self, value: builtins.str) -> None:
        jsii.set(self, "name", value)

    @builtins.property # type: ignore
    @jsii.member(jsii_name="pipelineName")
    def pipeline_name(self) -> builtins.str:
        return jsii.get(self, "pipelineName")

    @pipeline_name.setter # type: ignore
    def pipeline_name(self, value: builtins.str) -> None:
        jsii.set(self, "pipelineName", value)

    @builtins.property # type: ignore
    @jsii.member(jsii_name="resourceGroupName")
    def resource_group_name(self) -> builtins.str:
        return jsii.get(self, "resourceGroupName")

    @resource_group_name.setter # type: ignore
    def resource_group_name(self, value: builtins.str) -> None:
        jsii.set(self, "resourceGroupName", value)

    @builtins.property # type: ignore
    @jsii.member(jsii_name="annotations")
    def annotations(self) -> typing.Optional[typing.List[builtins.str]]:
        return jsii.get(self, "annotations")

    @annotations.setter # type: ignore
    def annotations(self, value: typing.Optional[typing.List[builtins.str]]) -> None:
        jsii.set(self, "annotations", value)

    @builtins.property # type: ignore
    @jsii.member(jsii_name="endTime")
    def end_time(self) -> typing.Optional[builtins.str]:
        return jsii.get(self, "endTime")

    @end_time.setter # type: ignore
    def end_time(self, value: typing.Optional[builtins.str]) -> None:
        jsii.set(self, "endTime", value)

    @builtins.property # type: ignore
    @jsii.member(jsii_name="frequency")
    def frequency(self) -> typing.Optional[builtins.str]:
        return jsii.get(self, "frequency")

    @frequency.setter # type: ignore
    def frequency(self, value: typing.Optional[builtins.str]) -> None:
        jsii.set(self, "frequency", value)

    @builtins.property # type: ignore
    @jsii.member(jsii_name="id")
    def id(self) -> typing.Optional[builtins.str]:
        return jsii.get(self, "id")

    @id.setter # type: ignore
    def id(self, value: typing.Optional[builtins.str]) -> None:
        jsii.set(self, "id", value)

    @builtins.property # type: ignore
    @jsii.member(jsii_name="interval")
    def interval(self) -> typing.Optional[jsii.Number]:
        return jsii.get(self, "interval")

    @interval.setter # type: ignore
    def interval(self, value: typing.Optional[jsii.Number]) -> None:
        jsii.set(self, "interval", value)

    @builtins.property # type: ignore
    @jsii.member(jsii_name="pipelineParameters")
    def pipeline_parameters(
        self,
    ) -> typing.Optional[typing.Mapping[builtins.str, builtins.str]]:
        return jsii.get(self, "pipelineParameters")

    @pipeline_parameters.setter # type: ignore
    def pipeline_parameters(
        self,
        value: typing.Optional[typing.Mapping[builtins.str, builtins.str]],
    ) -> None:
        jsii.set(self, "pipelineParameters", value)

    @builtins.property # type: ignore
    @jsii.member(jsii_name="startTime")
    def start_time(self) -> typing.Optional[builtins.str]:
        return jsii.get(self, "startTime")

    @start_time.setter # type: ignore
    def start_time(self, value: typing.Optional[builtins.str]) -> None:
        jsii.set(self, "startTime", value)

    @builtins.property # type: ignore
    @jsii.member(jsii_name="timeouts")
    def timeouts(self) -> typing.Optional["DataFactoryTriggerScheduleTimeouts"]:
        return jsii.get(self, "timeouts")

    @timeouts.setter # type: ignore
    def timeouts(
        self,
        value: typing.Optional["DataFactoryTriggerScheduleTimeouts"],
    ) -> None:
        jsii.set(self, "timeouts", value)


@jsii.data_type(
    jsii_type="@cdktf/provider-azurerm.DataFactoryTriggerScheduleConfig",
    jsii_struct_bases=[cdktf.TerraformMetaArguments],
    name_mapping={
        "count": "count",
        "depends_on": "dependsOn",
        "lifecycle": "lifecycle",
        "provider": "provider",
        "data_factory_name": "dataFactoryName",
        "name": "name",
        "pipeline_name": "pipelineName",
        "resource_group_name": "resourceGroupName",
        "annotations": "annotations",
        "end_time": "endTime",
        "frequency": "frequency",
        "interval": "interval",
        "pipeline_parameters": "pipelineParameters",
        "start_time": "startTime",
        "timeouts": "timeouts",
    },
)
class DataFactoryTriggerScheduleConfig(cdktf.TerraformMetaArguments):
    def __init__(
        self,
        *,
        count: typing.Optional[jsii.Number] = None,
        depends_on: typing.Optional[typing.List[cdktf.TerraformResource]] = None,
        lifecycle: typing.Optional[cdktf.TerraformResourceLifecycle] = None,
        provider: typing.Optional[cdktf.TerraformProvider] = None,
        data_factory_name: builtins.str,
        name: builtins.str,
        pipeline_name: builtins.str,
        resource_group_name: builtins.str,
        annotations: typing.Optional[typing.List[builtins.str]] = None,
        end_time: typing.Optional[builtins.str] = None,
        frequency: typing.Optional[builtins.str] = None,
        interval: typing.Optional[jsii.Number] = None,
        pipeline_parameters: typing.Optional[typing.Mapping[builtins.str, builtins.str]] = None,
        start_time: typing.Optional[builtins.str] = None,
        timeouts: typing.Optional["DataFactoryTriggerScheduleTimeouts"] = None,
    ) -> None:
        """
        :param count: 
        :param depends_on: 
        :param lifecycle: 
        :param provider: 
        :param data_factory_name: 
        :param name: 
        :param pipeline_name: 
        :param resource_group_name: 
        :param annotations: 
        :param end_time: 
        :param frequency: 
        :param interval: 
        :param pipeline_parameters: 
        :param start_time: 
        :param timeouts: timeouts block.
        """
        if isinstance(lifecycle, dict):
            lifecycle = cdktf.TerraformResourceLifecycle(**lifecycle)
        if isinstance(timeouts, dict):
            timeouts = DataFactoryTriggerScheduleTimeouts(**timeouts)
        self._values: typing.Dict[str, typing.Any] = {
            "data_factory_name": data_factory_name,
            "name": name,
            "pipeline_name": pipeline_name,
            "resource_group_name": resource_group_name,
        }
        if count is not None:
            self._values["count"] = count
        if depends_on is not None:
            self._values["depends_on"] = depends_on
        if lifecycle is not None:
            self._values["lifecycle"] = lifecycle
        if provider is not None:
            self._values["provider"] = provider
        if annotations is not None:
            self._values["annotations"] = annotations
        if end_time is not None:
            self._values["end_time"] = end_time
        if frequency is not None:
            self._values["frequency"] = frequency
        if interval is not None:
            self._values["interval"] = interval
        if pipeline_parameters is not None:
            self._values["pipeline_parameters"] = pipeline_parameters
        if start_time is not None:
            self._values["start_time"] = start_time
        if timeouts is not None:
            self._values["timeouts"] = timeouts

    @builtins.property
    def count(self) -> typing.Optional[jsii.Number]:
        """
        :stability: experimental
        """
        result = self._values.get("count")
        return result

    @builtins.property
    def depends_on(self) -> typing.Optional[typing.List[cdktf.TerraformResource]]:
        """
        :stability: experimental
        """
        result = self._values.get("depends_on")
        return result

    @builtins.property
    def lifecycle(self) -> typing.Optional[cdktf.TerraformResourceLifecycle]:
        """
        :stability: experimental
        """
        result = self._values.get("lifecycle")
        return result

    @builtins.property
    def provider(self) -> typing.Optional[cdktf.TerraformProvider]:
        """
        :stability: experimental
        """
        result = self._values.get("provider")
        return result

    @builtins.property
    def data_factory_name(self) -> builtins.str:
        result = self._values.get("data_factory_name")
        assert result is not None, "Required property 'data_factory_name' is missing"
        return result

    @builtins.property
    def name(self) -> builtins.str:
        result = self._values.get("name")
        assert result is not None, "Required property 'name' is missing"
        return result

    @builtins.property
    def pipeline_name(self) -> builtins.str:
        result = self._values.get("pipeline_name")
        assert result is not None, "Required property 'pipeline_name' is missing"
        return result

    @builtins.property
    def resource_group_name(self) -> builtins.str:
        result = self._values.get("resource_group_name")
        assert result is not None, "Required property 'resource_group_name' is missing"
        return result

    @builtins.property
    def annotations(self) -> typing.Optional[typing.List[builtins.str]]:
        result = self._values.get("annotations")
        return result

    @builtins.property
    def end_time(self) -> typing.Optional[builtins.str]:
        result = self._values.get("end_time")
        return result

    @builtins.property
    def frequency(self) -> typing.Optional[builtins.str]:
        result = self._values.get("frequency")
        return result

    @builtins.property
    def interval(self) -> typing.Optional[jsii.Number]:
        result = self._values.get("interval")
        return result

    @builtins.property
    def pipeline_parameters(
        self,
    ) -> typing.Optional[typing.Mapping[builtins.str, builtins.str]]:
        result = self._values.get("pipeline_parameters")
        return result

    @builtins.property
    def start_time(self) -> typing.Optional[builtins.str]:
        result = self._values.get("start_time")
        return result

    @builtins.property
    def timeouts(self) -> typing.Optional["DataFactoryTriggerScheduleTimeouts"]:
        """timeouts block."""
        result = self._values.get("timeouts")
        return result

    def __eq__(self, rhs: typing.Any) -> builtins.bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs: typing.Any) -> builtins.bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return "DataFactoryTriggerScheduleConfig(%s)" % ", ".join(
            k + "=" + repr(v) for k, v in self._values.items()
        )


@jsii.data_type(
    jsii_type="@cdktf/provider-azurerm.DataFactoryTriggerScheduleTimeouts",
    jsii_struct_bases=[],
    name_mapping={
        "create": "create",
        "delete": "delete",
        "read": "read",
        "update": "update",
    },
)
class DataFactoryTriggerScheduleTimeouts:
    def __init__(
        self,
        *,
        create: typing.Optional[builtins.str] = None,
        delete: typing.Optional[builtins.str] = None,
        read: typing.Optional[builtins.str] = None,
        update: typing.Optional[builtins.str] = None,
    ) -> None:
        """
        :param create: 
        :param delete: 
        :param read: 
        :param update: 
        """
        self._values: typing.Dict[str, typing.Any] = {}
        if create is not None:
            self._values["create"] = create
        if delete is not None:
            self._values["delete"] = delete
        if read is not None:
            self._values["read"] = read
        if update is not None:
            self._values["update"] = update

    @builtins.property
    def create(self) -> typing.Optional[builtins.str]:
        result = self._values.get("create")
        return result

    @builtins.property
    def delete(self) -> typing.Optional[builtins.str]:
        result = self._values.get("delete")
        return result

    @builtins.property
    def read(self) -> typing.Optional[builtins.str]:
        result = self._values.get("read")
        return result

    @builtins.property
    def update(self) -> typing.Optional[builtins.str]:
        result = self._values.get("update")
        return result

    def __eq__(self, rhs: typing.Any) -> builtins.bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs: typing.Any) -> builtins.bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return "DataFactoryTriggerScheduleTimeouts(%s)" % ", ".join(
            k + "=" + repr(v) for k, v in self._values.items()
        )


@jsii.data_type(
    jsii_type="@cdktf/provider-azurerm.DataFactoryVstsConfiguration",
    jsii_struct_bases=[],
    name_mapping={
        "account_name": "accountName",
        "branch_name": "branchName",
        "project_name": "projectName",
        "repository_name": "repositoryName",
        "root_folder": "rootFolder",
        "tenant_id": "tenantId",
    },
)
class DataFactoryVstsConfiguration:
    def __init__(
        self,
        *,
        account_name: builtins.str,
        branch_name: builtins.str,
        project_name: builtins.str,
        repository_name: builtins.str,
        root_folder: builtins.str,
        tenant_id: builtins.str,
    ) -> None:
        """
        :param account_name: 
        :param branch_name: 
        :param project_name: 
        :param repository_name: 
        :param root_folder: 
        :param tenant_id: 
        """
        self._values: typing.Dict[str, typing.Any] = {
            "account_name": account_name,
            "branch_name": branch_name,
            "project_name": project_name,
            "repository_name": repository_name,
            "root_folder": root_folder,
            "tenant_id": tenant_id,
        }

    @builtins.property
    def account_name(self) -> builtins.str:
        result = self._values.get("account_name")
        assert result is not None, "Required property 'account_name' is missing"
        return result

    @builtins.property
    def branch_name(self) -> builtins.str:
        result = self._values.get("branch_name")
        assert result is not None, "Required property 'branch_name' is missing"
        return result

    @builtins.property
    def project_name(self) -> builtins.str:
        result = self._values.get("project_name")
        assert result is not None, "Required property 'project_name' is missing"
        return result

    @builtins.property
    def repository_name(self) -> builtins.str:
        result = self._values.get("repository_name")
        assert result is not None, "Required property 'repository_name' is missing"
        return result

    @builtins.property
    def root_folder(self) -> builtins.str:
        result = self._values.get("root_folder")
        assert result is not None, "Required property 'root_folder' is missing"
        return result

    @builtins.property
    def tenant_id(self) -> builtins.str:
        result = self._values.get("tenant_id")
        assert result is not None, "Required property 'tenant_id' is missing"
        return result

    def __eq__(self, rhs: typing.Any) -> builtins.bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs: typing.Any) -> builtins.bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return "DataFactoryVstsConfiguration(%s)" % ", ".join(
            k + "=" + repr(v) for k, v in self._values.items()
        )


class DataLakeAnalyticsAccount(
    cdktf.TerraformResource,
    metaclass=jsii.JSIIMeta,
    jsii_type="@cdktf/provider-azurerm.DataLakeAnalyticsAccount",
):
    def __init__(
        self,
        scope: constructs.Construct,
        id: builtins.str,
        *,
        default_store_account_name: builtins.str,
        location: builtins.str,
        name: builtins.str,
        resource_group_name: builtins.str,
        tags: typing.Optional[typing.Mapping[builtins.str, builtins.str]] = None,
        tier: typing.Optional[builtins.str] = None,
        timeouts: typing.Optional["DataLakeAnalyticsAccountTimeouts"] = None,
        count: typing.Optional[jsii.Number] = None,
        depends_on: typing.Optional[typing.List[cdktf.TerraformResource]] = None,
        lifecycle: typing.Optional[cdktf.TerraformResourceLifecycle] = None,
        provider: typing.Optional[cdktf.TerraformProvider] = None,
    ) -> None:
        """
        :param scope: -
        :param id: -
        :param default_store_account_name: 
        :param location: 
        :param name: 
        :param resource_group_name: 
        :param tags: 
        :param tier: 
        :param timeouts: timeouts block.
        :param count: 
        :param depends_on: 
        :param lifecycle: 
        :param provider: 
        """
        config = DataLakeAnalyticsAccountConfig(
            default_store_account_name=default_store_account_name,
            location=location,
            name=name,
            resource_group_name=resource_group_name,
            tags=tags,
            tier=tier,
            timeouts=timeouts,
            count=count,
            depends_on=depends_on,
            lifecycle=lifecycle,
            provider=provider,
        )

        jsii.create(DataLakeAnalyticsAccount, self, [scope, id, config])

    @jsii.member(jsii_name="synthesizeAttributes")
    def _synthesize_attributes(self) -> typing.Mapping[builtins.str, typing.Any]:
        return jsii.invoke(self, "synthesizeAttributes", [])

    @builtins.property # type: ignore
    @jsii.member(jsii_name="defaultStoreAccountName")
    def default_store_account_name(self) -> builtins.str:
        return jsii.get(self, "defaultStoreAccountName")

    @default_store_account_name.setter # type: ignore
    def default_store_account_name(self, value: builtins.str) -> None:
        jsii.set(self, "defaultStoreAccountName", value)

    @builtins.property # type: ignore
    @jsii.member(jsii_name="location")
    def location(self) -> builtins.str:
        return jsii.get(self, "location")

    @location.setter # type: ignore
    def location(self, value: builtins.str) -> None:
        jsii.set(self, "location", value)

    @builtins.property # type: ignore
    @jsii.member(jsii_name="name")
    def name(self) -> builtins.str:
        return jsii.get(self, "name")

    @name.setter # type: ignore
    def name(self, value: builtins.str) -> None:
        jsii.set(self, "name", value)

    @builtins.property # type: ignore
    @jsii.member(jsii_name="resourceGroupName")
    def resource_group_name(self) -> builtins.str:
        return jsii.get(self, "resourceGroupName")

    @resource_group_name.setter # type: ignore
    def resource_group_name(self, value: builtins.str) -> None:
        jsii.set(self, "resourceGroupName", value)

    @builtins.property # type: ignore
    @jsii.member(jsii_name="id")
    def id(self) -> typing.Optional[builtins.str]:
        return jsii.get(self, "id")

    @id.setter # type: ignore
    def id(self, value: typing.Optional[builtins.str]) -> None:
        jsii.set(self, "id", value)

    @builtins.property # type: ignore
    @jsii.member(jsii_name="tags")
    def tags(self) -> typing.Optional[typing.Mapping[builtins.str, builtins.str]]:
        return jsii.get(self, "tags")

    @tags.setter # type: ignore
    def tags(
        self,
        value: typing.Optional[typing.Mapping[builtins.str, builtins.str]],
    ) -> None:
        jsii.set(self, "tags", value)

    @builtins.property # type: ignore
    @jsii.member(jsii_name="tier")
    def tier(self) -> typing.Optional[builtins.str]:
        return jsii.get(self, "tier")

    @tier.setter # type: ignore
    def tier(self, value: typing.Optional[builtins.str]) -> None:
        jsii.set(self, "tier", value)

    @builtins.property # type: ignore
    @jsii.member(jsii_name="timeouts")
    def timeouts(self) -> typing.Optional["DataLakeAnalyticsAccountTimeouts"]:
        return jsii.get(self, "timeouts")

    @timeouts.setter # type: ignore
    def timeouts(
        self,
        value: typing.Optional["DataLakeAnalyticsAccountTimeouts"],
    ) -> None:
        jsii.set(self, "timeouts", value)


@jsii.data_type(
    jsii_type="@cdktf/provider-azurerm.DataLakeAnalyticsAccountConfig",
    jsii_struct_bases=[cdktf.TerraformMetaArguments],
    name_mapping={
        "count": "count",
        "depends_on": "dependsOn",
        "lifecycle": "lifecycle",
        "provider": "provider",
        "default_store_account_name": "defaultStoreAccountName",
        "location": "location",
        "name": "name",
        "resource_group_name": "resourceGroupName",
        "tags": "tags",
        "tier": "tier",
        "timeouts": "timeouts",
    },
)
class DataLakeAnalyticsAccountConfig(cdktf.TerraformMetaArguments):
    def __init__(
        self,
        *,
        count: typing.Optional[jsii.Number] = None,
        depends_on: typing.Optional[typing.List[cdktf.TerraformResource]] = None,
        lifecycle: typing.Optional[cdktf.TerraformResourceLifecycle] = None,
        provider: typing.Optional[cdktf.TerraformProvider] = None,
        default_store_account_name: builtins.str,
        location: builtins.str,
        name: builtins.str,
        resource_group_name: builtins.str,
        tags: typing.Optional[typing.Mapping[builtins.str, builtins.str]] = None,
        tier: typing.Optional[builtins.str] = None,
        timeouts: typing.Optional["DataLakeAnalyticsAccountTimeouts"] = None,
    ) -> None:
        """
        :param count: 
        :param depends_on: 
        :param lifecycle: 
        :param provider: 
        :param default_store_account_name: 
        :param location: 
        :param name: 
        :param resource_group_name: 
        :param tags: 
        :param tier: 
        :param timeouts: timeouts block.
        """
        if isinstance(lifecycle, dict):
            lifecycle = cdktf.TerraformResourceLifecycle(**lifecycle)
        if isinstance(timeouts, dict):
            timeouts = DataLakeAnalyticsAccountTimeouts(**timeouts)
        self._values: typing.Dict[str, typing.Any] = {
            "default_store_account_name": default_store_account_name,
            "location": location,
            "name": name,
            "resource_group_name": resource_group_name,
        }
        if count is not None:
            self._values["count"] = count
        if depends_on is not None:
            self._values["depends_on"] = depends_on
        if lifecycle is not None:
            self._values["lifecycle"] = lifecycle
        if provider is not None:
            self._values["provider"] = provider
        if tags is not None:
            self._values["tags"] = tags
        if tier is not None:
            self._values["tier"] = tier
        if timeouts is not None:
            self._values["timeouts"] = timeouts

    @builtins.property
    def count(self) -> typing.Optional[jsii.Number]:
        """
        :stability: experimental
        """
        result = self._values.get("count")
        return result

    @builtins.property
    def depends_on(self) -> typing.Optional[typing.List[cdktf.TerraformResource]]:
        """
        :stability: experimental
        """
        result = self._values.get("depends_on")
        return result

    @builtins.property
    def lifecycle(self) -> typing.Optional[cdktf.TerraformResourceLifecycle]:
        """
        :stability: experimental
        """
        result = self._values.get("lifecycle")
        return result

    @builtins.property
    def provider(self) -> typing.Optional[cdktf.TerraformProvider]:
        """
        :stability: experimental
        """
        result = self._values.get("provider")
        return result

    @builtins.property
    def default_store_account_name(self) -> builtins.str:
        result = self._values.get("default_store_account_name")
        assert result is not None, "Required property 'default_store_account_name' is missing"
        return result

    @builtins.property
    def location(self) -> builtins.str:
        result = self._values.get("location")
        assert result is not None, "Required property 'location' is missing"
        return result

    @builtins.property
    def name(self) -> builtins.str:
        result = self._values.get("name")
        assert result is not None, "Required property 'name' is missing"
        return result

    @builtins.property
    def resource_group_name(self) -> builtins.str:
        result = self._values.get("resource_group_name")
        assert result is not None, "Required property 'resource_group_name' is missing"
        return result

    @builtins.property
    def tags(self) -> typing.Optional[typing.Mapping[builtins.str, builtins.str]]:
        result = self._values.get("tags")
        return result

    @builtins.property
    def tier(self) -> typing.Optional[builtins.str]:
        result = self._values.get("tier")
        return result

    @builtins.property
    def timeouts(self) -> typing.Optional["DataLakeAnalyticsAccountTimeouts"]:
        """timeouts block."""
        result = self._values.get("timeouts")
        return result

    def __eq__(self, rhs: typing.Any) -> builtins.bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs: typing.Any) -> builtins.bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return "DataLakeAnalyticsAccountConfig(%s)" % ", ".join(
            k + "=" + repr(v) for k, v in self._values.items()
        )


@jsii.data_type(
    jsii_type="@cdktf/provider-azurerm.DataLakeAnalyticsAccountTimeouts",
    jsii_struct_bases=[],
    name_mapping={
        "create": "create",
        "delete": "delete",
        "read": "read",
        "update": "update",
    },
)
class DataLakeAnalyticsAccountTimeouts:
    def __init__(
        self,
        *,
        create: typing.Optional[builtins.str] = None,
        delete: typing.Optional[builtins.str] = None,
        read: typing.Optional[builtins.str] = None,
        update: typing.Optional[builtins.str] = None,
    ) -> None:
        """
        :param create: 
        :param delete: 
        :param read: 
        :param update: 
        """
        self._values: typing.Dict[str, typing.Any] = {}
        if create is not None:
            self._values["create"] = create
        if delete is not None:
            self._values["delete"] = delete
        if read is not None:
            self._values["read"] = read
        if update is not None:
            self._values["update"] = update

    @builtins.property
    def create(self) -> typing.Optional[builtins.str]:
        result = self._values.get("create")
        return result

    @builtins.property
    def delete(self) -> typing.Optional[builtins.str]:
        result = self._values.get("delete")
        return result

    @builtins.property
    def read(self) -> typing.Optional[builtins.str]:
        result = self._values.get("read")
        return result

    @builtins.property
    def update(self) -> typing.Optional[builtins.str]:
        result = self._values.get("update")
        return result

    def __eq__(self, rhs: typing.Any) -> builtins.bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs: typing.Any) -> builtins.bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return "DataLakeAnalyticsAccountTimeouts(%s)" % ", ".join(
            k + "=" + repr(v) for k, v in self._values.items()
        )


class DataLakeAnalyticsFirewallRule(
    cdktf.TerraformResource,
    metaclass=jsii.JSIIMeta,
    jsii_type="@cdktf/provider-azurerm.DataLakeAnalyticsFirewallRule",
):
    def __init__(
        self,
        scope: constructs.Construct,
        id: builtins.str,
        *,
        account_name: builtins.str,
        end_ip_address: builtins.str,
        name: builtins.str,
        resource_group_name: builtins.str,
        start_ip_address: builtins.str,
        timeouts: typing.Optional["DataLakeAnalyticsFirewallRuleTimeouts"] = None,
        count: typing.Optional[jsii.Number] = None,
        depends_on: typing.Optional[typing.List[cdktf.TerraformResource]] = None,
        lifecycle: typing.Optional[cdktf.TerraformResourceLifecycle] = None,
        provider: typing.Optional[cdktf.TerraformProvider] = None,
    ) -> None:
        """
        :param scope: -
        :param id: -
        :param account_name: 
        :param end_ip_address: 
        :param name: 
        :param resource_group_name: 
        :param start_ip_address: 
        :param timeouts: timeouts block.
        :param count: 
        :param depends_on: 
        :param lifecycle: 
        :param provider: 
        """
        config = DataLakeAnalyticsFirewallRuleConfig(
            account_name=account_name,
            end_ip_address=end_ip_address,
            name=name,
            resource_group_name=resource_group_name,
            start_ip_address=start_ip_address,
            timeouts=timeouts,
            count=count,
            depends_on=depends_on,
            lifecycle=lifecycle,
            provider=provider,
        )

        jsii.create(DataLakeAnalyticsFirewallRule, self, [scope, id, config])

    @jsii.member(jsii_name="synthesizeAttributes")
    def _synthesize_attributes(self) -> typing.Mapping[builtins.str, typing.Any]:
        return jsii.invoke(self, "synthesizeAttributes", [])

    @builtins.property # type: ignore
    @jsii.member(jsii_name="accountName")
    def account_name(self) -> builtins.str:
        return jsii.get(self, "accountName")

    @account_name.setter # type: ignore
    def account_name(self, value: builtins.str) -> None:
        jsii.set(self, "accountName", value)

    @builtins.property # type: ignore
    @jsii.member(jsii_name="endIpAddress")
    def end_ip_address(self) -> builtins.str:
        return jsii.get(self, "endIpAddress")

    @end_ip_address.setter # type: ignore
    def end_ip_address(self, value: builtins.str) -> None:
        jsii.set(self, "endIpAddress", value)

    @builtins.property # type: ignore
    @jsii.member(jsii_name="name")
    def name(self) -> builtins.str:
        return jsii.get(self, "name")

    @name.setter # type: ignore
    def name(self, value: builtins.str) -> None:
        jsii.set(self, "name", value)

    @builtins.property # type: ignore
    @jsii.member(jsii_name="resourceGroupName")
    def resource_group_name(self) -> builtins.str:
        return jsii.get(self, "resourceGroupName")

    @resource_group_name.setter # type: ignore
    def resource_group_name(self, value: builtins.str) -> None:
        jsii.set(self, "resourceGroupName", value)

    @builtins.property # type: ignore
    @jsii.member(jsii_name="startIpAddress")
    def start_ip_address(self) -> builtins.str:
        return jsii.get(self, "startIpAddress")

    @start_ip_address.setter # type: ignore
    def start_ip_address(self, value: builtins.str) -> None:
        jsii.set(self, "startIpAddress", value)

    @builtins.property # type: ignore
    @jsii.member(jsii_name="id")
    def id(self) -> typing.Optional[builtins.str]:
        return jsii.get(self, "id")

    @id.setter # type: ignore
    def id(self, value: typing.Optional[builtins.str]) -> None:
        jsii.set(self, "id", value)

    @builtins.property # type: ignore
    @jsii.member(jsii_name="timeouts")
    def timeouts(self) -> typing.Optional["DataLakeAnalyticsFirewallRuleTimeouts"]:
        return jsii.get(self, "timeouts")

    @timeouts.setter # type: ignore
    def timeouts(
        self,
        value: typing.Optional["DataLakeAnalyticsFirewallRuleTimeouts"],
    ) -> None:
        jsii.set(self, "timeouts", value)


@jsii.data_type(
    jsii_type="@cdktf/provider-azurerm.DataLakeAnalyticsFirewallRuleConfig",
    jsii_struct_bases=[cdktf.TerraformMetaArguments],
    name_mapping={
        "count": "count",
        "depends_on": "dependsOn",
        "lifecycle": "lifecycle",
        "provider": "provider",
        "account_name": "accountName",
        "end_ip_address": "endIpAddress",
        "name": "name",
        "resource_group_name": "resourceGroupName",
        "start_ip_address": "startIpAddress",
        "timeouts": "timeouts",
    },
)
class DataLakeAnalyticsFirewallRuleConfig(cdktf.TerraformMetaArguments):
    def __init__(
        self,
        *,
        count: typing.Optional[jsii.Number] = None,
        depends_on: typing.Optional[typing.List[cdktf.TerraformResource]] = None,
        lifecycle: typing.Optional[cdktf.TerraformResourceLifecycle] = None,
        provider: typing.Optional[cdktf.TerraformProvider] = None,
        account_name: builtins.str,
        end_ip_address: builtins.str,
        name: builtins.str,
        resource_group_name: builtins.str,
        start_ip_address: builtins.str,
        timeouts: typing.Optional["DataLakeAnalyticsFirewallRuleTimeouts"] = None,
    ) -> None:
        """
        :param count: 
        :param depends_on: 
        :param lifecycle: 
        :param provider: 
        :param account_name: 
        :param end_ip_address: 
        :param name: 
        :param resource_group_name: 
        :param start_ip_address: 
        :param timeouts: timeouts block.
        """
        if isinstance(lifecycle, dict):
            lifecycle = cdktf.TerraformResourceLifecycle(**lifecycle)
        if isinstance(timeouts, dict):
            timeouts = DataLakeAnalyticsFirewallRuleTimeouts(**timeouts)
        self._values: typing.Dict[str, typing.Any] = {
            "account_name": account_name,
            "end_ip_address": end_ip_address,
            "name": name,
            "resource_group_name": resource_group_name,
            "start_ip_address": start_ip_address,
        }
        if count is not None:
            self._values["count"] = count
        if depends_on is not None:
            self._values["depends_on"] = depends_on
        if lifecycle is not None:
            self._values["lifecycle"] = lifecycle
        if provider is not None:
            self._values["provider"] = provider
        if timeouts is not None:
            self._values["timeouts"] = timeouts

    @builtins.property
    def count(self) -> typing.Optional[jsii.Number]:
        """
        :stability: experimental
        """
        result = self._values.get("count")
        return result

    @builtins.property
    def depends_on(self) -> typing.Optional[typing.List[cdktf.TerraformResource]]:
        """
        :stability: experimental
        """
        result = self._values.get("depends_on")
        return result

    @builtins.property
    def lifecycle(self) -> typing.Optional[cdktf.TerraformResourceLifecycle]:
        """
        :stability: experimental
        """
        result = self._values.get("lifecycle")
        return result

    @builtins.property
    def provider(self) -> typing.Optional[cdktf.TerraformProvider]:
        """
        :stability: experimental
        """
        result = self._values.get("provider")
        return result

    @builtins.property
    def account_name(self) -> builtins.str:
        result = self._values.get("account_name")
        assert result is not None, "Required property 'account_name' is missing"
        return result

    @builtins.property
    def end_ip_address(self) -> builtins.str:
        result = self._values.get("end_ip_address")
        assert result is not None, "Required property 'end_ip_address' is missing"
        return result

    @builtins.property
    def name(self) -> builtins.str:
        result = self._values.get("name")
        assert result is not None, "Required property 'name' is missing"
        return result

    @builtins.property
    def resource_group_name(self) -> builtins.str:
        result = self._values.get("resource_group_name")
        assert result is not None, "Required property 'resource_group_name' is missing"
        return result

    @builtins.property
    def start_ip_address(self) -> builtins.str:
        result = self._values.get("start_ip_address")
        assert result is not None, "Required property 'start_ip_address' is missing"
        return result

    @builtins.property
    def timeouts(self) -> typing.Optional["DataLakeAnalyticsFirewallRuleTimeouts"]:
        """timeouts block."""
        result = self._values.get("timeouts")
        return result

    def __eq__(self, rhs: typing.Any) -> builtins.bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs: typing.Any) -> builtins.bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return "DataLakeAnalyticsFirewallRuleConfig(%s)" % ", ".join(
            k + "=" + repr(v) for k, v in self._values.items()
        )


@jsii.data_type(
    jsii_type="@cdktf/provider-azurerm.DataLakeAnalyticsFirewallRuleTimeouts",
    jsii_struct_bases=[],
    name_mapping={
        "create": "create",
        "delete": "delete",
        "read": "read",
        "update": "update",
    },
)
class DataLakeAnalyticsFirewallRuleTimeouts:
    def __init__(
        self,
        *,
        create: typing.Optional[builtins.str] = None,
        delete: typing.Optional[builtins.str] = None,
        read: typing.Optional[builtins.str] = None,
        update: typing.Optional[builtins.str] = None,
    ) -> None:
        """
        :param create: 
        :param delete: 
        :param read: 
        :param update: 
        """
        self._values: typing.Dict[str, typing.Any] = {}
        if create is not None:
            self._values["create"] = create
        if delete is not None:
            self._values["delete"] = delete
        if read is not None:
            self._values["read"] = read
        if update is not None:
            self._values["update"] = update

    @builtins.property
    def create(self) -> typing.Optional[builtins.str]:
        result = self._values.get("create")
        return result

    @builtins.property
    def delete(self) -> typing.Optional[builtins.str]:
        result = self._values.get("delete")
        return result

    @builtins.property
    def read(self) -> typing.Optional[builtins.str]:
        result = self._values.get("read")
        return result

    @builtins.property
    def update(self) -> typing.Optional[builtins.str]:
        result = self._values.get("update")
        return result

    def __eq__(self, rhs: typing.Any) -> builtins.bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs: typing.Any) -> builtins.bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return "DataLakeAnalyticsFirewallRuleTimeouts(%s)" % ", ".join(
            k + "=" + repr(v) for k, v in self._values.items()
        )


class DataLakeStore(
    cdktf.TerraformResource,
    metaclass=jsii.JSIIMeta,
    jsii_type="@cdktf/provider-azurerm.DataLakeStore",
):
    def __init__(
        self,
        scope: constructs.Construct,
        id: builtins.str,
        *,
        location: builtins.str,
        name: builtins.str,
        resource_group_name: builtins.str,
        encryption_state: typing.Optional[builtins.str] = None,
        encryption_type: typing.Optional[builtins.str] = None,
        firewall_allow_azure_ips: typing.Optional[builtins.str] = None,
        firewall_state: typing.Optional[builtins.str] = None,
        tags: typing.Optional[typing.Mapping[builtins.str, builtins.str]] = None,
        tier: typing.Optional[builtins.str] = None,
        timeouts: typing.Optional["DataLakeStoreTimeouts"] = None,
        count: typing.Optional[jsii.Number] = None,
        depends_on: typing.Optional[typing.List[cdktf.TerraformResource]] = None,
        lifecycle: typing.Optional[cdktf.TerraformResourceLifecycle] = None,
        provider: typing.Optional[cdktf.TerraformProvider] = None,
    ) -> None:
        """
        :param scope: -
        :param id: -
        :param location: 
        :param name: 
        :param resource_group_name: 
        :param encryption_state: 
        :param encryption_type: 
        :param firewall_allow_azure_ips: 
        :param firewall_state: 
        :param tags: 
        :param tier: 
        :param timeouts: timeouts block.
        :param count: 
        :param depends_on: 
        :param lifecycle: 
        :param provider: 
        """
        config = DataLakeStoreConfig(
            location=location,
            name=name,
            resource_group_name=resource_group_name,
            encryption_state=encryption_state,
            encryption_type=encryption_type,
            firewall_allow_azure_ips=firewall_allow_azure_ips,
            firewall_state=firewall_state,
            tags=tags,
            tier=tier,
            timeouts=timeouts,
            count=count,
            depends_on=depends_on,
            lifecycle=lifecycle,
            provider=provider,
        )

        jsii.create(DataLakeStore, self, [scope, id, config])

    @jsii.member(jsii_name="synthesizeAttributes")
    def _synthesize_attributes(self) -> typing.Mapping[builtins.str, typing.Any]:
        return jsii.invoke(self, "synthesizeAttributes", [])

    @builtins.property # type: ignore
    @jsii.member(jsii_name="endpoint")
    def endpoint(self) -> builtins.str:
        return jsii.get(self, "endpoint")

    @builtins.property # type: ignore
    @jsii.member(jsii_name="location")
    def location(self) -> builtins.str:
        return jsii.get(self, "location")

    @location.setter # type: ignore
    def location(self, value: builtins.str) -> None:
        jsii.set(self, "location", value)

    @builtins.property # type: ignore
    @jsii.member(jsii_name="name")
    def name(self) -> builtins.str:
        return jsii.get(self, "name")

    @name.setter # type: ignore
    def name(self, value: builtins.str) -> None:
        jsii.set(self, "name", value)

    @builtins.property # type: ignore
    @jsii.member(jsii_name="resourceGroupName")
    def resource_group_name(self) -> builtins.str:
        return jsii.get(self, "resourceGroupName")

    @resource_group_name.setter # type: ignore
    def resource_group_name(self, value: builtins.str) -> None:
        jsii.set(self, "resourceGroupName", value)

    @builtins.property # type: ignore
    @jsii.member(jsii_name="encryptionState")
    def encryption_state(self) -> typing.Optional[builtins.str]:
        return jsii.get(self, "encryptionState")

    @encryption_state.setter # type: ignore
    def encryption_state(self, value: typing.Optional[builtins.str]) -> None:
        jsii.set(self, "encryptionState", value)

    @builtins.property # type: ignore
    @jsii.member(jsii_name="encryptionType")
    def encryption_type(self) -> typing.Optional[builtins.str]:
        return jsii.get(self, "encryptionType")

    @encryption_type.setter # type: ignore
    def encryption_type(self, value: typing.Optional[builtins.str]) -> None:
        jsii.set(self, "encryptionType", value)

    @builtins.property # type: ignore
    @jsii.member(jsii_name="firewallAllowAzureIps")
    def firewall_allow_azure_ips(self) -> typing.Optional[builtins.str]:
        return jsii.get(self, "firewallAllowAzureIps")

    @firewall_allow_azure_ips.setter # type: ignore
    def firewall_allow_azure_ips(self, value: typing.Optional[builtins.str]) -> None:
        jsii.set(self, "firewallAllowAzureIps", value)

    @builtins.property # type: ignore
    @jsii.member(jsii_name="firewallState")
    def firewall_state(self) -> typing.Optional[builtins.str]:
        return jsii.get(self, "firewallState")

    @firewall_state.setter # type: ignore
    def firewall_state(self, value: typing.Optional[builtins.str]) -> None:
        jsii.set(self, "firewallState", value)

    @builtins.property # type: ignore
    @jsii.member(jsii_name="id")
    def id(self) -> typing.Optional[builtins.str]:
        return jsii.get(self, "id")

    @id.setter # type: ignore
    def id(self, value: typing.Optional[builtins.str]) -> None:
        jsii.set(self, "id", value)

    @builtins.property # type: ignore
    @jsii.member(jsii_name="tags")
    def tags(self) -> typing.Optional[typing.Mapping[builtins.str, builtins.str]]:
        return jsii.get(self, "tags")

    @tags.setter # type: ignore
    def tags(
        self,
        value: typing.Optional[typing.Mapping[builtins.str, builtins.str]],
    ) -> None:
        jsii.set(self, "tags", value)

    @builtins.property # type: ignore
    @jsii.member(jsii_name="tier")
    def tier(self) -> typing.Optional[builtins.str]:
        return jsii.get(self, "tier")

    @tier.setter # type: ignore
    def tier(self, value: typing.Optional[builtins.str]) -> None:
        jsii.set(self, "tier", value)

    @builtins.property # type: ignore
    @jsii.member(jsii_name="timeouts")
    def timeouts(self) -> typing.Optional["DataLakeStoreTimeouts"]:
        return jsii.get(self, "timeouts")

    @timeouts.setter # type: ignore
    def timeouts(self, value: typing.Optional["DataLakeStoreTimeouts"]) -> None:
        jsii.set(self, "timeouts", value)


@jsii.data_type(
    jsii_type="@cdktf/provider-azurerm.DataLakeStoreConfig",
    jsii_struct_bases=[cdktf.TerraformMetaArguments],
    name_mapping={
        "count": "count",
        "depends_on": "dependsOn",
        "lifecycle": "lifecycle",
        "provider": "provider",
        "location": "location",
        "name": "name",
        "resource_group_name": "resourceGroupName",
        "encryption_state": "encryptionState",
        "encryption_type": "encryptionType",
        "firewall_allow_azure_ips": "firewallAllowAzureIps",
        "firewall_state": "firewallState",
        "tags": "tags",
        "tier": "tier",
        "timeouts": "timeouts",
    },
)
class DataLakeStoreConfig(cdktf.TerraformMetaArguments):
    def __init__(
        self,
        *,
        count: typing.Optional[jsii.Number] = None,
        depends_on: typing.Optional[typing.List[cdktf.TerraformResource]] = None,
        lifecycle: typing.Optional[cdktf.TerraformResourceLifecycle] = None,
        provider: typing.Optional[cdktf.TerraformProvider] = None,
        location: builtins.str,
        name: builtins.str,
        resource_group_name: builtins.str,
        encryption_state: typing.Optional[builtins.str] = None,
        encryption_type: typing.Optional[builtins.str] = None,
        firewall_allow_azure_ips: typing.Optional[builtins.str] = None,
        firewall_state: typing.Optional[builtins.str] = None,
        tags: typing.Optional[typing.Mapping[builtins.str, builtins.str]] = None,
        tier: typing.Optional[builtins.str] = None,
        timeouts: typing.Optional["DataLakeStoreTimeouts"] = None,
    ) -> None:
        """
        :param count: 
        :param depends_on: 
        :param lifecycle: 
        :param provider: 
        :param location: 
        :param name: 
        :param resource_group_name: 
        :param encryption_state: 
        :param encryption_type: 
        :param firewall_allow_azure_ips: 
        :param firewall_state: 
        :param tags: 
        :param tier: 
        :param timeouts: timeouts block.
        """
        if isinstance(lifecycle, dict):
            lifecycle = cdktf.TerraformResourceLifecycle(**lifecycle)
        if isinstance(timeouts, dict):
            timeouts = DataLakeStoreTimeouts(**timeouts)
        self._values: typing.Dict[str, typing.Any] = {
            "location": location,
            "name": name,
            "resource_group_name": resource_group_name,
        }
        if count is not None:
            self._values["count"] = count
        if depends_on is not None:
            self._values["depends_on"] = depends_on
        if lifecycle is not None:
            self._values["lifecycle"] = lifecycle
        if provider is not None:
            self._values["provider"] = provider
        if encryption_state is not None:
            self._values["encryption_state"] = encryption_state
        if encryption_type is not None:
            self._values["encryption_type"] = encryption_type
        if firewall_allow_azure_ips is not None:
            self._values["firewall_allow_azure_ips"] = firewall_allow_azure_ips
        if firewall_state is not None:
            self._values["firewall_state"] = firewall_state
        if tags is not None:
            self._values["tags"] = tags
        if tier is not None:
            self._values["tier"] = tier
        if timeouts is not None:
            self._values["timeouts"] = timeouts

    @builtins.property
    def count(self) -> typing.Optional[jsii.Number]:
        """
        :stability: experimental
        """
        result = self._values.get("count")
        return result

    @builtins.property
    def depends_on(self) -> typing.Optional[typing.List[cdktf.TerraformResource]]:
        """
        :stability: experimental
        """
        result = self._values.get("depends_on")
        return result

    @builtins.property
    def lifecycle(self) -> typing.Optional[cdktf.TerraformResourceLifecycle]:
        """
        :stability: experimental
        """
        result = self._values.get("lifecycle")
        return result

    @builtins.property
    def provider(self) -> typing.Optional[cdktf.TerraformProvider]:
        """
        :stability: experimental
        """
        result = self._values.get("provider")
        return result

    @builtins.property
    def location(self) -> builtins.str:
        result = self._values.get("location")
        assert result is not None, "Required property 'location' is missing"
        return result

    @builtins.property
    def name(self) -> builtins.str:
        result = self._values.get("name")
        assert result is not None, "Required property 'name' is missing"
        return result

    @builtins.property
    def resource_group_name(self) -> builtins.str:
        result = self._values.get("resource_group_name")
        assert result is not None, "Required property 'resource_group_name' is missing"
        return result

    @builtins.property
    def encryption_state(self) -> typing.Optional[builtins.str]:
        result = self._values.get("encryption_state")
        return result

    @builtins.property
    def encryption_type(self) -> typing.Optional[builtins.str]:
        result = self._values.get("encryption_type")
        return result

    @builtins.property
    def firewall_allow_azure_ips(self) -> typing.Optional[builtins.str]:
        result = self._values.get("firewall_allow_azure_ips")
        return result

    @builtins.property
    def firewall_state(self) -> typing.Optional[builtins.str]:
        result = self._values.get("firewall_state")
        return result

    @builtins.property
    def tags(self) -> typing.Optional[typing.Mapping[builtins.str, builtins.str]]:
        result = self._values.get("tags")
        return result

    @builtins.property
    def tier(self) -> typing.Optional[builtins.str]:
        result = self._values.get("tier")
        return result

    @builtins.property
    def timeouts(self) -> typing.Optional["DataLakeStoreTimeouts"]:
        """timeouts block."""
        result = self._values.get("timeouts")
        return result

    def __eq__(self, rhs: typing.Any) -> builtins.bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs: typing.Any) -> builtins.bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return "DataLakeStoreConfig(%s)" % ", ".join(
            k + "=" + repr(v) for k, v in self._values.items()
        )


class DataLakeStoreFile(
    cdktf.TerraformResource,
    metaclass=jsii.JSIIMeta,
    jsii_type="@cdktf/provider-azurerm.DataLakeStoreFile",
):
    def __init__(
        self,
        scope: constructs.Construct,
        id: builtins.str,
        *,
        account_name: builtins.str,
        local_file_path: builtins.str,
        remote_file_path: builtins.str,
        timeouts: typing.Optional["DataLakeStoreFileTimeouts"] = None,
        count: typing.Optional[jsii.Number] = None,
        depends_on: typing.Optional[typing.List[cdktf.TerraformResource]] = None,
        lifecycle: typing.Optional[cdktf.TerraformResourceLifecycle] = None,
        provider: typing.Optional[cdktf.TerraformProvider] = None,
    ) -> None:
        """
        :param scope: -
        :param id: -
        :param account_name: 
        :param local_file_path: 
        :param remote_file_path: 
        :param timeouts: timeouts block.
        :param count: 
        :param depends_on: 
        :param lifecycle: 
        :param provider: 
        """
        config = DataLakeStoreFileConfig(
            account_name=account_name,
            local_file_path=local_file_path,
            remote_file_path=remote_file_path,
            timeouts=timeouts,
            count=count,
            depends_on=depends_on,
            lifecycle=lifecycle,
            provider=provider,
        )

        jsii.create(DataLakeStoreFile, self, [scope, id, config])

    @jsii.member(jsii_name="synthesizeAttributes")
    def _synthesize_attributes(self) -> typing.Mapping[builtins.str, typing.Any]:
        return jsii.invoke(self, "synthesizeAttributes", [])

    @builtins.property # type: ignore
    @jsii.member(jsii_name="accountName")
    def account_name(self) -> builtins.str:
        return jsii.get(self, "accountName")

    @account_name.setter # type: ignore
    def account_name(self, value: builtins.str) -> None:
        jsii.set(self, "accountName", value)

    @builtins.property # type: ignore
    @jsii.member(jsii_name="localFilePath")
    def local_file_path(self) -> builtins.str:
        return jsii.get(self, "localFilePath")

    @local_file_path.setter # type: ignore
    def local_file_path(self, value: builtins.str) -> None:
        jsii.set(self, "localFilePath", value)

    @builtins.property # type: ignore
    @jsii.member(jsii_name="remoteFilePath")
    def remote_file_path(self) -> builtins.str:
        return jsii.get(self, "remoteFilePath")

    @remote_file_path.setter # type: ignore
    def remote_file_path(self, value: builtins.str) -> None:
        jsii.set(self, "remoteFilePath", value)

    @builtins.property # type: ignore
    @jsii.member(jsii_name="id")
    def id(self) -> typing.Optional[builtins.str]:
        return jsii.get(self, "id")

    @id.setter # type: ignore
    def id(self, value: typing.Optional[builtins.str]) -> None:
        jsii.set(self, "id", value)

    @builtins.property # type: ignore
    @jsii.member(jsii_name="timeouts")
    def timeouts(self) -> typing.Optional["DataLakeStoreFileTimeouts"]:
        return jsii.get(self, "timeouts")

    @timeouts.setter # type: ignore
    def timeouts(self, value: typing.Optional["DataLakeStoreFileTimeouts"]) -> None:
        jsii.set(self, "timeouts", value)


@jsii.data_type(
    jsii_type="@cdktf/provider-azurerm.DataLakeStoreFileConfig",
    jsii_struct_bases=[cdktf.TerraformMetaArguments],
    name_mapping={
        "count": "count",
        "depends_on": "dependsOn",
        "lifecycle": "lifecycle",
        "provider": "provider",
        "account_name": "accountName",
        "local_file_path": "localFilePath",
        "remote_file_path": "remoteFilePath",
        "timeouts": "timeouts",
    },
)
class DataLakeStoreFileConfig(cdktf.TerraformMetaArguments):
    def __init__(
        self,
        *,
        count: typing.Optional[jsii.Number] = None,
        depends_on: typing.Optional[typing.List[cdktf.TerraformResource]] = None,
        lifecycle: typing.Optional[cdktf.TerraformResourceLifecycle] = None,
        provider: typing.Optional[cdktf.TerraformProvider] = None,
        account_name: builtins.str,
        local_file_path: builtins.str,
        remote_file_path: builtins.str,
        timeouts: typing.Optional["DataLakeStoreFileTimeouts"] = None,
    ) -> None:
        """
        :param count: 
        :param depends_on: 
        :param lifecycle: 
        :param provider: 
        :param account_name: 
        :param local_file_path: 
        :param remote_file_path: 
        :param timeouts: timeouts block.
        """
        if isinstance(lifecycle, dict):
            lifecycle = cdktf.TerraformResourceLifecycle(**lifecycle)
        if isinstance(timeouts, dict):
            timeouts = DataLakeStoreFileTimeouts(**timeouts)
        self._values: typing.Dict[str, typing.Any] = {
            "account_name": account_name,
            "local_file_path": local_file_path,
            "remote_file_path": remote_file_path,
        }
        if count is not None:
            self._values["count"] = count
        if depends_on is not None:
            self._values["depends_on"] = depends_on
        if lifecycle is not None:
            self._values["lifecycle"] = lifecycle
        if provider is not None:
            self._values["provider"] = provider
        if timeouts is not None:
            self._values["timeouts"] = timeouts

    @builtins.property
    def count(self) -> typing.Optional[jsii.Number]:
        """
        :stability: experimental
        """
        result = self._values.get("count")
        return result

    @builtins.property
    def depends_on(self) -> typing.Optional[typing.List[cdktf.TerraformResource]]:
        """
        :stability: experimental
        """
        result = self._values.get("depends_on")
        return result

    @builtins.property
    def lifecycle(self) -> typing.Optional[cdktf.TerraformResourceLifecycle]:
        """
        :stability: experimental
        """
        result = self._values.get("lifecycle")
        return result

    @builtins.property
    def provider(self) -> typing.Optional[cdktf.TerraformProvider]:
        """
        :stability: experimental
        """
        result = self._values.get("provider")
        return result

    @builtins.property
    def account_name(self) -> builtins.str:
        result = self._values.get("account_name")
        assert result is not None, "Required property 'account_name' is missing"
        return result

    @builtins.property
    def local_file_path(self) -> builtins.str:
        result = self._values.get("local_file_path")
        assert result is not None, "Required property 'local_file_path' is missing"
        return result

    @builtins.property
    def remote_file_path(self) -> builtins.str:
        result = self._values.get("remote_file_path")
        assert result is not None, "Required property 'remote_file_path' is missing"
        return result

    @builtins.property
    def timeouts(self) -> typing.Optional["DataLakeStoreFileTimeouts"]:
        """timeouts block."""
        result = self._values.get("timeouts")
        return result

    def __eq__(self, rhs: typing.Any) -> builtins.bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs: typing.Any) -> builtins.bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return "DataLakeStoreFileConfig(%s)" % ", ".join(
            k + "=" + repr(v) for k, v in self._values.items()
        )


@jsii.data_type(
    jsii_type="@cdktf/provider-azurerm.DataLakeStoreFileTimeouts",
    jsii_struct_bases=[],
    name_mapping={
        "create": "create",
        "delete": "delete",
        "read": "read",
        "update": "update",
    },
)
class DataLakeStoreFileTimeouts:
    def __init__(
        self,
        *,
        create: typing.Optional[builtins.str] = None,
        delete: typing.Optional[builtins.str] = None,
        read: typing.Optional[builtins.str] = None,
        update: typing.Optional[builtins.str] = None,
    ) -> None:
        """
        :param create: 
        :param delete: 
        :param read: 
        :param update: 
        """
        self._values: typing.Dict[str, typing.Any] = {}
        if create is not None:
            self._values["create"] = create
        if delete is not None:
            self._values["delete"] = delete
        if read is not None:
            self._values["read"] = read
        if update is not None:
            self._values["update"] = update

    @builtins.property
    def create(self) -> typing.Optional[builtins.str]:
        result = self._values.get("create")
        return result

    @builtins.property
    def delete(self) -> typing.Optional[builtins.str]:
        result = self._values.get("delete")
        return result

    @builtins.property
    def read(self) -> typing.Optional[builtins.str]:
        result = self._values.get("read")
        return result

    @builtins.property
    def update(self) -> typing.Optional[builtins.str]:
        result = self._values.get("update")
        return result

    def __eq__(self, rhs: typing.Any) -> builtins.bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs: typing.Any) -> builtins.bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return "DataLakeStoreFileTimeouts(%s)" % ", ".join(
            k + "=" + repr(v) for k, v in self._values.items()
        )


class DataLakeStoreFirewallRule(
    cdktf.TerraformResource,
    metaclass=jsii.JSIIMeta,
    jsii_type="@cdktf/provider-azurerm.DataLakeStoreFirewallRule",
):
    def __init__(
        self,
        scope: constructs.Construct,
        id: builtins.str,
        *,
        account_name: builtins.str,
        end_ip_address: builtins.str,
        name: builtins.str,
        resource_group_name: builtins.str,
        start_ip_address: builtins.str,
        timeouts: typing.Optional["DataLakeStoreFirewallRuleTimeouts"] = None,
        count: typing.Optional[jsii.Number] = None,
        depends_on: typing.Optional[typing.List[cdktf.TerraformResource]] = None,
        lifecycle: typing.Optional[cdktf.TerraformResourceLifecycle] = None,
        provider: typing.Optional[cdktf.TerraformProvider] = None,
    ) -> None:
        """
        :param scope: -
        :param id: -
        :param account_name: 
        :param end_ip_address: 
        :param name: 
        :param resource_group_name: 
        :param start_ip_address: 
        :param timeouts: timeouts block.
        :param count: 
        :param depends_on: 
        :param lifecycle: 
        :param provider: 
        """
        config = DataLakeStoreFirewallRuleConfig(
            account_name=account_name,
            end_ip_address=end_ip_address,
            name=name,
            resource_group_name=resource_group_name,
            start_ip_address=start_ip_address,
            timeouts=timeouts,
            count=count,
            depends_on=depends_on,
            lifecycle=lifecycle,
            provider=provider,
        )

        jsii.create(DataLakeStoreFirewallRule, self, [scope, id, config])

    @jsii.member(jsii_name="synthesizeAttributes")
    def _synthesize_attributes(self) -> typing.Mapping[builtins.str, typing.Any]:
        return jsii.invoke(self, "synthesizeAttributes", [])

    @builtins.property # type: ignore
    @jsii.member(jsii_name="accountName")
    def account_name(self) -> builtins.str:
        return jsii.get(self, "accountName")

    @account_name.setter # type: ignore
    def account_name(self, value: builtins.str) -> None:
        jsii.set(self, "accountName", value)

    @builtins.property # type: ignore
    @jsii.member(jsii_name="endIpAddress")
    def end_ip_address(self) -> builtins.str:
        return jsii.get(self, "endIpAddress")

    @end_ip_address.setter # type: ignore
    def end_ip_address(self, value: builtins.str) -> None:
        jsii.set(self, "endIpAddress", value)

    @builtins.property # type: ignore
    @jsii.member(jsii_name="name")
    def name(self) -> builtins.str:
        return jsii.get(self, "name")

    @name.setter # type: ignore
    def name(self, value: builtins.str) -> None:
        jsii.set(self, "name", value)

    @builtins.property # type: ignore
    @jsii.member(jsii_name="resourceGroupName")
    def resource_group_name(self) -> builtins.str:
        return jsii.get(self, "resourceGroupName")

    @resource_group_name.setter # type: ignore
    def resource_group_name(self, value: builtins.str) -> None:
        jsii.set(self, "resourceGroupName", value)

    @builtins.property # type: ignore
    @jsii.member(jsii_name="startIpAddress")
    def start_ip_address(self) -> builtins.str:
        return jsii.get(self, "startIpAddress")

    @start_ip_address.setter # type: ignore
    def start_ip_address(self, value: builtins.str) -> None:
        jsii.set(self, "startIpAddress", value)

    @builtins.property # type: ignore
    @jsii.member(jsii_name="id")
    def id(self) -> typing.Optional[builtins.str]:
        return jsii.get(self, "id")

    @id.setter # type: ignore
    def id(self, value: typing.Optional[builtins.str]) -> None:
        jsii.set(self, "id", value)

    @builtins.property # type: ignore
    @jsii.member(jsii_name="timeouts")
    def timeouts(self) -> typing.Optional["DataLakeStoreFirewallRuleTimeouts"]:
        return jsii.get(self, "timeouts")

    @timeouts.setter # type: ignore
    def timeouts(
        self,
        value: typing.Optional["DataLakeStoreFirewallRuleTimeouts"],
    ) -> None:
        jsii.set(self, "timeouts", value)


@jsii.data_type(
    jsii_type="@cdktf/provider-azurerm.DataLakeStoreFirewallRuleConfig",
    jsii_struct_bases=[cdktf.TerraformMetaArguments],
    name_mapping={
        "count": "count",
        "depends_on": "dependsOn",
        "lifecycle": "lifecycle",
        "provider": "provider",
        "account_name": "accountName",
        "end_ip_address": "endIpAddress",
        "name": "name",
        "resource_group_name": "resourceGroupName",
        "start_ip_address": "startIpAddress",
        "timeouts": "timeouts",
    },
)
class DataLakeStoreFirewallRuleConfig(cdktf.TerraformMetaArguments):
    def __init__(
        self,
        *,
        count: typing.Optional[jsii.Number] = None,
        depends_on: typing.Optional[typing.List[cdktf.TerraformResource]] = None,
        lifecycle: typing.Optional[cdktf.TerraformResourceLifecycle] = None,
        provider: typing.Optional[cdktf.TerraformProvider] = None,
        account_name: builtins.str,
        end_ip_address: builtins.str,
        name: builtins.str,
        resource_group_name: builtins.str,
        start_ip_address: builtins.str,
        timeouts: typing.Optional["DataLakeStoreFirewallRuleTimeouts"] = None,
    ) -> None:
        """
        :param count: 
        :param depends_on: 
        :param lifecycle: 
        :param provider: 
        :param account_name: 
        :param end_ip_address: 
        :param name: 
        :param resource_group_name: 
        :param start_ip_address: 
        :param timeouts: timeouts block.
        """
        if isinstance(lifecycle, dict):
            lifecycle = cdktf.TerraformResourceLifecycle(**lifecycle)
        if isinstance(timeouts, dict):
            timeouts = DataLakeStoreFirewallRuleTimeouts(**timeouts)
        self._values: typing.Dict[str, typing.Any] = {
            "account_name": account_name,
            "end_ip_address": end_ip_address,
            "name": name,
            "resource_group_name": resource_group_name,
            "start_ip_address": start_ip_address,
        }
        if count is not None:
            self._values["count"] = count
        if depends_on is not None:
            self._values["depends_on"] = depends_on
        if lifecycle is not None:
            self._values["lifecycle"] = lifecycle
        if provider is not None:
            self._values["provider"] = provider
        if timeouts is not None:
            self._values["timeouts"] = timeouts

    @builtins.property
    def count(self) -> typing.Optional[jsii.Number]:
        """
        :stability: experimental
        """
        result = self._values.get("count")
        return result

    @builtins.property
    def depends_on(self) -> typing.Optional[typing.List[cdktf.TerraformResource]]:
        """
        :stability: experimental
        """
        result = self._values.get("depends_on")
        return result

    @builtins.property
    def lifecycle(self) -> typing.Optional[cdktf.TerraformResourceLifecycle]:
        """
        :stability: experimental
        """
        result = self._values.get("lifecycle")
        return result

    @builtins.property
    def provider(self) -> typing.Optional[cdktf.TerraformProvider]:
        """
        :stability: experimental
        """
        result = self._values.get("provider")
        return result

    @builtins.property
    def account_name(self) -> builtins.str:
        result = self._values.get("account_name")
        assert result is not None, "Required property 'account_name' is missing"
        return result

    @builtins.property
    def end_ip_address(self) -> builtins.str:
        result = self._values.get("end_ip_address")
        assert result is not None, "Required property 'end_ip_address' is missing"
        return result

    @builtins.property
    def name(self) -> builtins.str:
        result = self._values.get("name")
        assert result is not None, "Required property 'name' is missing"
        return result

    @builtins.property
    def resource_group_name(self) -> builtins.str:
        result = self._values.get("resource_group_name")
        assert result is not None, "Required property 'resource_group_name' is missing"
        return result

    @builtins.property
    def start_ip_address(self) -> builtins.str:
        result = self._values.get("start_ip_address")
        assert result is not None, "Required property 'start_ip_address' is missing"
        return result

    @builtins.property
    def timeouts(self) -> typing.Optional["DataLakeStoreFirewallRuleTimeouts"]:
        """timeouts block."""
        result = self._values.get("timeouts")
        return result

    def __eq__(self, rhs: typing.Any) -> builtins.bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs: typing.Any) -> builtins.bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return "DataLakeStoreFirewallRuleConfig(%s)" % ", ".join(
            k + "=" + repr(v) for k, v in self._values.items()
        )


@jsii.data_type(
    jsii_type="@cdktf/provider-azurerm.DataLakeStoreFirewallRuleTimeouts",
    jsii_struct_bases=[],
    name_mapping={
        "create": "create",
        "delete": "delete",
        "read": "read",
        "update": "update",
    },
)
class DataLakeStoreFirewallRuleTimeouts:
    def __init__(
        self,
        *,
        create: typing.Optional[builtins.str] = None,
        delete: typing.Optional[builtins.str] = None,
        read: typing.Optional[builtins.str] = None,
        update: typing.Optional[builtins.str] = None,
    ) -> None:
        """
        :param create: 
        :param delete: 
        :param read: 
        :param update: 
        """
        self._values: typing.Dict[str, typing.Any] = {}
        if create is not None:
            self._values["create"] = create
        if delete is not None:
            self._values["delete"] = delete
        if read is not None:
            self._values["read"] = read
        if update is not None:
            self._values["update"] = update

    @builtins.property
    def create(self) -> typing.Optional[builtins.str]:
        result = self._values.get("create")
        return result

    @builtins.property
    def delete(self) -> typing.Optional[builtins.str]:
        result = self._values.get("delete")
        return result

    @builtins.property
    def read(self) -> typing.Optional[builtins.str]:
        result = self._values.get("read")
        return result

    @builtins.property
    def update(self) -> typing.Optional[builtins.str]:
        result = self._values.get("update")
        return result

    def __eq__(self, rhs: typing.Any) -> builtins.bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs: typing.Any) -> builtins.bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return "DataLakeStoreFirewallRuleTimeouts(%s)" % ", ".join(
            k + "=" + repr(v) for k, v in self._values.items()
        )


@jsii.data_type(
    jsii_type="@cdktf/provider-azurerm.DataLakeStoreTimeouts",
    jsii_struct_bases=[],
    name_mapping={
        "create": "create",
        "delete": "delete",
        "read": "read",
        "update": "update",
    },
)
class DataLakeStoreTimeouts:
    def __init__(
        self,
        *,
        create: typing.Optional[builtins.str] = None,
        delete: typing.Optional[builtins.str] = None,
        read: typing.Optional[builtins.str] = None,
        update: typing.Optional[builtins.str] = None,
    ) -> None:
        """
        :param create: 
        :param delete: 
        :param read: 
        :param update: 
        """
        self._values: typing.Dict[str, typing.Any] = {}
        if create is not None:
            self._values["create"] = create
        if delete is not None:
            self._values["delete"] = delete
        if read is not None:
            self._values["read"] = read
        if update is not None:
            self._values["update"] = update

    @builtins.property
    def create(self) -> typing.Optional[builtins.str]:
        result = self._values.get("create")
        return result

    @builtins.property
    def delete(self) -> typing.Optional[builtins.str]:
        result = self._values.get("delete")
        return result

    @builtins.property
    def read(self) -> typing.Optional[builtins.str]:
        result = self._values.get("read")
        return result

    @builtins.property
    def update(self) -> typing.Optional[builtins.str]:
        result = self._values.get("update")
        return result

    def __eq__(self, rhs: typing.Any) -> builtins.bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs: typing.Any) -> builtins.bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return "DataLakeStoreTimeouts(%s)" % ", ".join(
            k + "=" + repr(v) for k, v in self._values.items()
        )


class DatabricksWorkspace(
    cdktf.TerraformResource,
    metaclass=jsii.JSIIMeta,
    jsii_type="@cdktf/provider-azurerm.DatabricksWorkspace",
):
    def __init__(
        self,
        scope: constructs.Construct,
        id: builtins.str,
        *,
        location: builtins.str,
        name: builtins.str,
        resource_group_name: builtins.str,
        sku: builtins.str,
        custom_parameters: typing.Optional[typing.List["DatabricksWorkspaceCustomParameters"]] = None,
        managed_resource_group_name: typing.Optional[builtins.str] = None,
        tags: typing.Optional[typing.Mapping[builtins.str, builtins.str]] = None,
        timeouts: typing.Optional["DatabricksWorkspaceTimeouts"] = None,
        count: typing.Optional[jsii.Number] = None,
        depends_on: typing.Optional[typing.List[cdktf.TerraformResource]] = None,
        lifecycle: typing.Optional[cdktf.TerraformResourceLifecycle] = None,
        provider: typing.Optional[cdktf.TerraformProvider] = None,
    ) -> None:
        """
        :param scope: -
        :param id: -
        :param location: 
        :param name: 
        :param resource_group_name: 
        :param sku: 
        :param custom_parameters: custom_parameters block.
        :param managed_resource_group_name: 
        :param tags: 
        :param timeouts: timeouts block.
        :param count: 
        :param depends_on: 
        :param lifecycle: 
        :param provider: 
        """
        config = DatabricksWorkspaceConfig(
            location=location,
            name=name,
            resource_group_name=resource_group_name,
            sku=sku,
            custom_parameters=custom_parameters,
            managed_resource_group_name=managed_resource_group_name,
            tags=tags,
            timeouts=timeouts,
            count=count,
            depends_on=depends_on,
            lifecycle=lifecycle,
            provider=provider,
        )

        jsii.create(DatabricksWorkspace, self, [scope, id, config])

    @jsii.member(jsii_name="synthesizeAttributes")
    def _synthesize_attributes(self) -> typing.Mapping[builtins.str, typing.Any]:
        return jsii.invoke(self, "synthesizeAttributes", [])

    @builtins.property # type: ignore
    @jsii.member(jsii_name="managedResourceGroupId")
    def managed_resource_group_id(self) -> builtins.str:
        return jsii.get(self, "managedResourceGroupId")

    @builtins.property # type: ignore
    @jsii.member(jsii_name="location")
    def location(self) -> builtins.str:
        return jsii.get(self, "location")

    @location.setter # type: ignore
    def location(self, value: builtins.str) -> None:
        jsii.set(self, "location", value)

    @builtins.property # type: ignore
    @jsii.member(jsii_name="name")
    def name(self) -> builtins.str:
        return jsii.get(self, "name")

    @name.setter # type: ignore
    def name(self, value: builtins.str) -> None:
        jsii.set(self, "name", value)

    @builtins.property # type: ignore
    @jsii.member(jsii_name="resourceGroupName")
    def resource_group_name(self) -> builtins.str:
        return jsii.get(self, "resourceGroupName")

    @resource_group_name.setter # type: ignore
    def resource_group_name(self, value: builtins.str) -> None:
        jsii.set(self, "resourceGroupName", value)

    @builtins.property # type: ignore
    @jsii.member(jsii_name="sku")
    def sku(self) -> builtins.str:
        return jsii.get(self, "sku")

    @sku.setter # type: ignore
    def sku(self, value: builtins.str) -> None:
        jsii.set(self, "sku", value)

    @builtins.property # type: ignore
    @jsii.member(jsii_name="customParameters")
    def custom_parameters(
        self,
    ) -> typing.Optional[typing.List["DatabricksWorkspaceCustomParameters"]]:
        return jsii.get(self, "customParameters")

    @custom_parameters.setter # type: ignore
    def custom_parameters(
        self,
        value: typing.Optional[typing.List["DatabricksWorkspaceCustomParameters"]],
    ) -> None:
        jsii.set(self, "customParameters", value)

    @builtins.property # type: ignore
    @jsii.member(jsii_name="id")
    def id(self) -> typing.Optional[builtins.str]:
        return jsii.get(self, "id")

    @id.setter # type: ignore
    def id(self, value: typing.Optional[builtins.str]) -> None:
        jsii.set(self, "id", value)

    @builtins.property # type: ignore
    @jsii.member(jsii_name="managedResourceGroupName")
    def managed_resource_group_name(self) -> typing.Optional[builtins.str]:
        return jsii.get(self, "managedResourceGroupName")

    @managed_resource_group_name.setter # type: ignore
    def managed_resource_group_name(self, value: typing.Optional[builtins.str]) -> None:
        jsii.set(self, "managedResourceGroupName", value)

    @builtins.property # type: ignore
    @jsii.member(jsii_name="tags")
    def tags(self) -> typing.Optional[typing.Mapping[builtins.str, builtins.str]]:
        return jsii.get(self, "tags")

    @tags.setter # type: ignore
    def tags(
        self,
        value: typing.Optional[typing.Mapping[builtins.str, builtins.str]],
    ) -> None:
        jsii.set(self, "tags", value)

    @builtins.property # type: ignore
    @jsii.member(jsii_name="timeouts")
    def timeouts(self) -> typing.Optional["DatabricksWorkspaceTimeouts"]:
        return jsii.get(self, "timeouts")

    @timeouts.setter # type: ignore
    def timeouts(self, value: typing.Optional["DatabricksWorkspaceTimeouts"]) -> None:
        jsii.set(self, "timeouts", value)


@jsii.data_type(
    jsii_type="@cdktf/provider-azurerm.DatabricksWorkspaceConfig",
    jsii_struct_bases=[cdktf.TerraformMetaArguments],
    name_mapping={
        "count": "count",
        "depends_on": "dependsOn",
        "lifecycle": "lifecycle",
        "provider": "provider",
        "location": "location",
        "name": "name",
        "resource_group_name": "resourceGroupName",
        "sku": "sku",
        "custom_parameters": "customParameters",
        "managed_resource_group_name": "managedResourceGroupName",
        "tags": "tags",
        "timeouts": "timeouts",
    },
)
class DatabricksWorkspaceConfig(cdktf.TerraformMetaArguments):
    def __init__(
        self,
        *,
        count: typing.Optional[jsii.Number] = None,
        depends_on: typing.Optional[typing.List[cdktf.TerraformResource]] = None,
        lifecycle: typing.Optional[cdktf.TerraformResourceLifecycle] = None,
        provider: typing.Optional[cdktf.TerraformProvider] = None,
        location: builtins.str,
        name: builtins.str,
        resource_group_name: builtins.str,
        sku: builtins.str,
        custom_parameters: typing.Optional[typing.List["DatabricksWorkspaceCustomParameters"]] = None,
        managed_resource_group_name: typing.Optional[builtins.str] = None,
        tags: typing.Optional[typing.Mapping[builtins.str, builtins.str]] = None,
        timeouts: typing.Optional["DatabricksWorkspaceTimeouts"] = None,
    ) -> None:
        """
        :param count: 
        :param depends_on: 
        :param lifecycle: 
        :param provider: 
        :param location: 
        :param name: 
        :param resource_group_name: 
        :param sku: 
        :param custom_parameters: custom_parameters block.
        :param managed_resource_group_name: 
        :param tags: 
        :param timeouts: timeouts block.
        """
        if isinstance(lifecycle, dict):
            lifecycle = cdktf.TerraformResourceLifecycle(**lifecycle)
        if isinstance(timeouts, dict):
            timeouts = DatabricksWorkspaceTimeouts(**timeouts)
        self._values: typing.Dict[str, typing.Any] = {
            "location": location,
            "name": name,
            "resource_group_name": resource_group_name,
            "sku": sku,
        }
        if count is not None:
            self._values["count"] = count
        if depends_on is not None:
            self._values["depends_on"] = depends_on
        if lifecycle is not None:
            self._values["lifecycle"] = lifecycle
        if provider is not None:
            self._values["provider"] = provider
        if custom_parameters is not None:
            self._values["custom_parameters"] = custom_parameters
        if managed_resource_group_name is not None:
            self._values["managed_resource_group_name"] = managed_resource_group_name
        if tags is not None:
            self._values["tags"] = tags
        if timeouts is not None:
            self._values["timeouts"] = timeouts

    @builtins.property
    def count(self) -> typing.Optional[jsii.Number]:
        """
        :stability: experimental
        """
        result = self._values.get("count")
        return result

    @builtins.property
    def depends_on(self) -> typing.Optional[typing.List[cdktf.TerraformResource]]:
        """
        :stability: experimental
        """
        result = self._values.get("depends_on")
        return result

    @builtins.property
    def lifecycle(self) -> typing.Optional[cdktf.TerraformResourceLifecycle]:
        """
        :stability: experimental
        """
        result = self._values.get("lifecycle")
        return result

    @builtins.property
    def provider(self) -> typing.Optional[cdktf.TerraformProvider]:
        """
        :stability: experimental
        """
        result = self._values.get("provider")
        return result

    @builtins.property
    def location(self) -> builtins.str:
        result = self._values.get("location")
        assert result is not None, "Required property 'location' is missing"
        return result

    @builtins.property
    def name(self) -> builtins.str:
        result = self._values.get("name")
        assert result is not None, "Required property 'name' is missing"
        return result

    @builtins.property
    def resource_group_name(self) -> builtins.str:
        result = self._values.get("resource_group_name")
        assert result is not None, "Required property 'resource_group_name' is missing"
        return result

    @builtins.property
    def sku(self) -> builtins.str:
        result = self._values.get("sku")
        assert result is not None, "Required property 'sku' is missing"
        return result

    @builtins.property
    def custom_parameters(
        self,
    ) -> typing.Optional[typing.List["DatabricksWorkspaceCustomParameters"]]:
        """custom_parameters block."""
        result = self._values.get("custom_parameters")
        return result

    @builtins.property
    def managed_resource_group_name(self) -> typing.Optional[builtins.str]:
        result = self._values.get("managed_resource_group_name")
        return result

    @builtins.property
    def tags(self) -> typing.Optional[typing.Mapping[builtins.str, builtins.str]]:
        result = self._values.get("tags")
        return result

    @builtins.property
    def timeouts(self) -> typing.Optional["DatabricksWorkspaceTimeouts"]:
        """timeouts block."""
        result = self._values.get("timeouts")
        return result

    def __eq__(self, rhs: typing.Any) -> builtins.bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs: typing.Any) -> builtins.bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return "DatabricksWorkspaceConfig(%s)" % ", ".join(
            k + "=" + repr(v) for k, v in self._values.items()
        )


@jsii.data_type(
    jsii_type="@cdktf/provider-azurerm.DatabricksWorkspaceCustomParameters",
    jsii_struct_bases=[],
    name_mapping={
        "no_public_ip": "noPublicIp",
        "private_subnet_name": "privateSubnetName",
        "public_subnet_name": "publicSubnetName",
        "virtual_network_id": "virtualNetworkId",
    },
)
class DatabricksWorkspaceCustomParameters:
    def __init__(
        self,
        *,
        no_public_ip: typing.Optional[builtins.bool] = None,
        private_subnet_name: typing.Optional[builtins.str] = None,
        public_subnet_name: typing.Optional[builtins.str] = None,
        virtual_network_id: typing.Optional[builtins.str] = None,
    ) -> None:
        """
        :param no_public_ip: 
        :param private_subnet_name: 
        :param public_subnet_name: 
        :param virtual_network_id: 
        """
        self._values: typing.Dict[str, typing.Any] = {}
        if no_public_ip is not None:
            self._values["no_public_ip"] = no_public_ip
        if private_subnet_name is not None:
            self._values["private_subnet_name"] = private_subnet_name
        if public_subnet_name is not None:
            self._values["public_subnet_name"] = public_subnet_name
        if virtual_network_id is not None:
            self._values["virtual_network_id"] = virtual_network_id

    @builtins.property
    def no_public_ip(self) -> typing.Optional[builtins.bool]:
        result = self._values.get("no_public_ip")
        return result

    @builtins.property
    def private_subnet_name(self) -> typing.Optional[builtins.str]:
        result = self._values.get("private_subnet_name")
        return result

    @builtins.property
    def public_subnet_name(self) -> typing.Optional[builtins.str]:
        result = self._values.get("public_subnet_name")
        return result

    @builtins.property
    def virtual_network_id(self) -> typing.Optional[builtins.str]:
        result = self._values.get("virtual_network_id")
        return result

    def __eq__(self, rhs: typing.Any) -> builtins.bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs: typing.Any) -> builtins.bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return "DatabricksWorkspaceCustomParameters(%s)" % ", ".join(
            k + "=" + repr(v) for k, v in self._values.items()
        )


@jsii.data_type(
    jsii_type="@cdktf/provider-azurerm.DatabricksWorkspaceTimeouts",
    jsii_struct_bases=[],
    name_mapping={
        "create": "create",
        "delete": "delete",
        "read": "read",
        "update": "update",
    },
)
class DatabricksWorkspaceTimeouts:
    def __init__(
        self,
        *,
        create: typing.Optional[builtins.str] = None,
        delete: typing.Optional[builtins.str] = None,
        read: typing.Optional[builtins.str] = None,
        update: typing.Optional[builtins.str] = None,
    ) -> None:
        """
        :param create: 
        :param delete: 
        :param read: 
        :param update: 
        """
        self._values: typing.Dict[str, typing.Any] = {}
        if create is not None:
            self._values["create"] = create
        if delete is not None:
            self._values["delete"] = delete
        if read is not None:
            self._values["read"] = read
        if update is not None:
            self._values["update"] = update

    @builtins.property
    def create(self) -> typing.Optional[builtins.str]:
        result = self._values.get("create")
        return result

    @builtins.property
    def delete(self) -> typing.Optional[builtins.str]:
        result = self._values.get("delete")
        return result

    @builtins.property
    def read(self) -> typing.Optional[builtins.str]:
        result = self._values.get("read")
        return result

    @builtins.property
    def update(self) -> typing.Optional[builtins.str]:
        result = self._values.get("update")
        return result

    def __eq__(self, rhs: typing.Any) -> builtins.bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs: typing.Any) -> builtins.bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return "DatabricksWorkspaceTimeouts(%s)" % ", ".join(
            k + "=" + repr(v) for k, v in self._values.items()
        )


class DedicatedHost(
    cdktf.TerraformResource,
    metaclass=jsii.JSIIMeta,
    jsii_type="@cdktf/provider-azurerm.DedicatedHost",
):
    def __init__(
        self,
        scope: constructs.Construct,
        id: builtins.str,
        *,
        dedicated_host_group_id: builtins.str,
        location: builtins.str,
        name: builtins.str,
        platform_fault_domain: jsii.Number,
        sku_name: builtins.str,
        auto_replace_on_failure: typing.Optional[builtins.bool] = None,
        license_type: typing.Optional[builtins.str] = None,
        tags: typing.Optional[typing.Mapping[builtins.str, builtins.str]] = None,
        timeouts: typing.Optional["DedicatedHostTimeouts"] = None,
        count: typing.Optional[jsii.Number] = None,
        depends_on: typing.Optional[typing.List[cdktf.TerraformResource]] = None,
        lifecycle: typing.Optional[cdktf.TerraformResourceLifecycle] = None,
        provider: typing.Optional[cdktf.TerraformProvider] = None,
    ) -> None:
        """
        :param scope: -
        :param id: -
        :param dedicated_host_group_id: 
        :param location: 
        :param name: 
        :param platform_fault_domain: 
        :param sku_name: 
        :param auto_replace_on_failure: 
        :param license_type: 
        :param tags: 
        :param timeouts: timeouts block.
        :param count: 
        :param depends_on: 
        :param lifecycle: 
        :param provider: 
        """
        config = DedicatedHostConfig(
            dedicated_host_group_id=dedicated_host_group_id,
            location=location,
            name=name,
            platform_fault_domain=platform_fault_domain,
            sku_name=sku_name,
            auto_replace_on_failure=auto_replace_on_failure,
            license_type=license_type,
            tags=tags,
            timeouts=timeouts,
            count=count,
            depends_on=depends_on,
            lifecycle=lifecycle,
            provider=provider,
        )

        jsii.create(DedicatedHost, self, [scope, id, config])

    @jsii.member(jsii_name="synthesizeAttributes")
    def _synthesize_attributes(self) -> typing.Mapping[builtins.str, typing.Any]:
        return jsii.invoke(self, "synthesizeAttributes", [])

    @builtins.property # type: ignore
    @jsii.member(jsii_name="dedicatedHostGroupId")
    def dedicated_host_group_id(self) -> builtins.str:
        return jsii.get(self, "dedicatedHostGroupId")

    @dedicated_host_group_id.setter # type: ignore
    def dedicated_host_group_id(self, value: builtins.str) -> None:
        jsii.set(self, "dedicatedHostGroupId", value)

    @builtins.property # type: ignore
    @jsii.member(jsii_name="location")
    def location(self) -> builtins.str:
        return jsii.get(self, "location")

    @location.setter # type: ignore
    def location(self, value: builtins.str) -> None:
        jsii.set(self, "location", value)

    @builtins.property # type: ignore
    @jsii.member(jsii_name="name")
    def name(self) -> builtins.str:
        return jsii.get(self, "name")

    @name.setter # type: ignore
    def name(self, value: builtins.str) -> None:
        jsii.set(self, "name", value)

    @builtins.property # type: ignore
    @jsii.member(jsii_name="platformFaultDomain")
    def platform_fault_domain(self) -> jsii.Number:
        return jsii.get(self, "platformFaultDomain")

    @platform_fault_domain.setter # type: ignore
    def platform_fault_domain(self, value: jsii.Number) -> None:
        jsii.set(self, "platformFaultDomain", value)

    @builtins.property # type: ignore
    @jsii.member(jsii_name="skuName")
    def sku_name(self) -> builtins.str:
        return jsii.get(self, "skuName")

    @sku_name.setter # type: ignore
    def sku_name(self, value: builtins.str) -> None:
        jsii.set(self, "skuName", value)

    @builtins.property # type: ignore
    @jsii.member(jsii_name="autoReplaceOnFailure")
    def auto_replace_on_failure(self) -> typing.Optional[builtins.bool]:
        return jsii.get(self, "autoReplaceOnFailure")

    @auto_replace_on_failure.setter # type: ignore
    def auto_replace_on_failure(self, value: typing.Optional[builtins.bool]) -> None:
        jsii.set(self, "autoReplaceOnFailure", value)

    @builtins.property # type: ignore
    @jsii.member(jsii_name="id")
    def id(self) -> typing.Optional[builtins.str]:
        return jsii.get(self, "id")

    @id.setter # type: ignore
    def id(self, value: typing.Optional[builtins.str]) -> None:
        jsii.set(self, "id", value)

    @builtins.property # type: ignore
    @jsii.member(jsii_name="licenseType")
    def license_type(self) -> typing.Optional[builtins.str]:
        return jsii.get(self, "licenseType")

    @license_type.setter # type: ignore
    def license_type(self, value: typing.Optional[builtins.str]) -> None:
        jsii.set(self, "licenseType", value)

    @builtins.property # type: ignore
    @jsii.member(jsii_name="tags")
    def tags(self) -> typing.Optional[typing.Mapping[builtins.str, builtins.str]]:
        return jsii.get(self, "tags")

    @tags.setter # type: ignore
    def tags(
        self,
        value: typing.Optional[typing.Mapping[builtins.str, builtins.str]],
    ) -> None:
        jsii.set(self, "tags", value)

    @builtins.property # type: ignore
    @jsii.member(jsii_name="timeouts")
    def timeouts(self) -> typing.Optional["DedicatedHostTimeouts"]:
        return jsii.get(self, "timeouts")

    @timeouts.setter # type: ignore
    def timeouts(self, value: typing.Optional["DedicatedHostTimeouts"]) -> None:
        jsii.set(self, "timeouts", value)


@jsii.data_type(
    jsii_type="@cdktf/provider-azurerm.DedicatedHostConfig",
    jsii_struct_bases=[cdktf.TerraformMetaArguments],
    name_mapping={
        "count": "count",
        "depends_on": "dependsOn",
        "lifecycle": "lifecycle",
        "provider": "provider",
        "dedicated_host_group_id": "dedicatedHostGroupId",
        "location": "location",
        "name": "name",
        "platform_fault_domain": "platformFaultDomain",
        "sku_name": "skuName",
        "auto_replace_on_failure": "autoReplaceOnFailure",
        "license_type": "licenseType",
        "tags": "tags",
        "timeouts": "timeouts",
    },
)
class DedicatedHostConfig(cdktf.TerraformMetaArguments):
    def __init__(
        self,
        *,
        count: typing.Optional[jsii.Number] = None,
        depends_on: typing.Optional[typing.List[cdktf.TerraformResource]] = None,
        lifecycle: typing.Optional[cdktf.TerraformResourceLifecycle] = None,
        provider: typing.Optional[cdktf.TerraformProvider] = None,
        dedicated_host_group_id: builtins.str,
        location: builtins.str,
        name: builtins.str,
        platform_fault_domain: jsii.Number,
        sku_name: builtins.str,
        auto_replace_on_failure: typing.Optional[builtins.bool] = None,
        license_type: typing.Optional[builtins.str] = None,
        tags: typing.Optional[typing.Mapping[builtins.str, builtins.str]] = None,
        timeouts: typing.Optional["DedicatedHostTimeouts"] = None,
    ) -> None:
        """
        :param count: 
        :param depends_on: 
        :param lifecycle: 
        :param provider: 
        :param dedicated_host_group_id: 
        :param location: 
        :param name: 
        :param platform_fault_domain: 
        :param sku_name: 
        :param auto_replace_on_failure: 
        :param license_type: 
        :param tags: 
        :param timeouts: timeouts block.
        """
        if isinstance(lifecycle, dict):
            lifecycle = cdktf.TerraformResourceLifecycle(**lifecycle)
        if isinstance(timeouts, dict):
            timeouts = DedicatedHostTimeouts(**timeouts)
        self._values: typing.Dict[str, typing.Any] = {
            "dedicated_host_group_id": dedicated_host_group_id,
            "location": location,
            "name": name,
            "platform_fault_domain": platform_fault_domain,
            "sku_name": sku_name,
        }
        if count is not None:
            self._values["count"] = count
        if depends_on is not None:
            self._values["depends_on"] = depends_on
        if lifecycle is not None:
            self._values["lifecycle"] = lifecycle
        if provider is not None:
            self._values["provider"] = provider
        if auto_replace_on_failure is not None:
            self._values["auto_replace_on_failure"] = auto_replace_on_failure
        if license_type is not None:
            self._values["license_type"] = license_type
        if tags is not None:
            self._values["tags"] = tags
        if timeouts is not None:
            self._values["timeouts"] = timeouts

    @builtins.property
    def count(self) -> typing.Optional[jsii.Number]:
        """
        :stability: experimental
        """
        result = self._values.get("count")
        return result

    @builtins.property
    def depends_on(self) -> typing.Optional[typing.List[cdktf.TerraformResource]]:
        """
        :stability: experimental
        """
        result = self._values.get("depends_on")
        return result

    @builtins.property
    def lifecycle(self) -> typing.Optional[cdktf.TerraformResourceLifecycle]:
        """
        :stability: experimental
        """
        result = self._values.get("lifecycle")
        return result

    @builtins.property
    def provider(self) -> typing.Optional[cdktf.TerraformProvider]:
        """
        :stability: experimental
        """
        result = self._values.get("provider")
        return result

    @builtins.property
    def dedicated_host_group_id(self) -> builtins.str:
        result = self._values.get("dedicated_host_group_id")
        assert result is not None, "Required property 'dedicated_host_group_id' is missing"
        return result

    @builtins.property
    def location(self) -> builtins.str:
        result = self._values.get("location")
        assert result is not None, "Required property 'location' is missing"
        return result

    @builtins.property
    def name(self) -> builtins.str:
        result = self._values.get("name")
        assert result is not None, "Required property 'name' is missing"
        return result

    @builtins.property
    def platform_fault_domain(self) -> jsii.Number:
        result = self._values.get("platform_fault_domain")
        assert result is not None, "Required property 'platform_fault_domain' is missing"
        return result

    @builtins.property
    def sku_name(self) -> builtins.str:
        result = self._values.get("sku_name")
        assert result is not None, "Required property 'sku_name' is missing"
        return result

    @builtins.property
    def auto_replace_on_failure(self) -> typing.Optional[builtins.bool]:
        result = self._values.get("auto_replace_on_failure")
        return result

    @builtins.property
    def license_type(self) -> typing.Optional[builtins.str]:
        result = self._values.get("license_type")
        return result

    @builtins.property
    def tags(self) -> typing.Optional[typing.Mapping[builtins.str, builtins.str]]:
        result = self._values.get("tags")
        return result

    @builtins.property
    def timeouts(self) -> typing.Optional["DedicatedHostTimeouts"]:
        """timeouts block."""
        result = self._values.get("timeouts")
        return result

    def __eq__(self, rhs: typing.Any) -> builtins.bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs: typing.Any) -> builtins.bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return "DedicatedHostConfig(%s)" % ", ".join(
            k + "=" + repr(v) for k, v in self._values.items()
        )


class DedicatedHostGroup(
    cdktf.TerraformResource,
    metaclass=jsii.JSIIMeta,
    jsii_type="@cdktf/provider-azurerm.DedicatedHostGroup",
):
    def __init__(
        self,
        scope: constructs.Construct,
        id: builtins.str,
        *,
        location: builtins.str,
        name: builtins.str,
        platform_fault_domain_count: jsii.Number,
        resource_group_name: builtins.str,
        tags: typing.Optional[typing.Mapping[builtins.str, builtins.str]] = None,
        timeouts: typing.Optional["DedicatedHostGroupTimeouts"] = None,
        zones: typing.Optional[typing.List[builtins.str]] = None,
        count: typing.Optional[jsii.Number] = None,
        depends_on: typing.Optional[typing.List[cdktf.TerraformResource]] = None,
        lifecycle: typing.Optional[cdktf.TerraformResourceLifecycle] = None,
        provider: typing.Optional[cdktf.TerraformProvider] = None,
    ) -> None:
        """
        :param scope: -
        :param id: -
        :param location: 
        :param name: 
        :param platform_fault_domain_count: 
        :param resource_group_name: 
        :param tags: 
        :param timeouts: timeouts block.
        :param zones: 
        :param count: 
        :param depends_on: 
        :param lifecycle: 
        :param provider: 
        """
        config = DedicatedHostGroupConfig(
            location=location,
            name=name,
            platform_fault_domain_count=platform_fault_domain_count,
            resource_group_name=resource_group_name,
            tags=tags,
            timeouts=timeouts,
            zones=zones,
            count=count,
            depends_on=depends_on,
            lifecycle=lifecycle,
            provider=provider,
        )

        jsii.create(DedicatedHostGroup, self, [scope, id, config])

    @jsii.member(jsii_name="synthesizeAttributes")
    def _synthesize_attributes(self) -> typing.Mapping[builtins.str, typing.Any]:
        return jsii.invoke(self, "synthesizeAttributes", [])

    @builtins.property # type: ignore
    @jsii.member(jsii_name="location")
    def location(self) -> builtins.str:
        return jsii.get(self, "location")

    @location.setter # type: ignore
    def location(self, value: builtins.str) -> None:
        jsii.set(self, "location", value)

    @builtins.property # type: ignore
    @jsii.member(jsii_name="name")
    def name(self) -> builtins.str:
        return jsii.get(self, "name")

    @name.setter # type: ignore
    def name(self, value: builtins.str) -> None:
        jsii.set(self, "name", value)

    @builtins.property # type: ignore
    @jsii.member(jsii_name="platformFaultDomainCount")
    def platform_fault_domain_count(self) -> jsii.Number:
        return jsii.get(self, "platformFaultDomainCount")

    @platform_fault_domain_count.setter # type: ignore
    def platform_fault_domain_count(self, value: jsii.Number) -> None:
        jsii.set(self, "platformFaultDomainCount", value)

    @builtins.property # type: ignore
    @jsii.member(jsii_name="resourceGroupName")
    def resource_group_name(self) -> builtins.str:
        return jsii.get(self, "resourceGroupName")

    @resource_group_name.setter # type: ignore
    def resource_group_name(self, value: builtins.str) -> None:
        jsii.set(self, "resourceGroupName", value)

    @builtins.property # type: ignore
    @jsii.member(jsii_name="id")
    def id(self) -> typing.Optional[builtins.str]:
        return jsii.get(self, "id")

    @id.setter # type: ignore
    def id(self, value: typing.Optional[builtins.str]) -> None:
        jsii.set(self, "id", value)

    @builtins.property # type: ignore
    @jsii.member(jsii_name="tags")
    def tags(self) -> typing.Optional[typing.Mapping[builtins.str, builtins.str]]:
        return jsii.get(self, "tags")

    @tags.setter # type: ignore
    def tags(
        self,
        value: typing.Optional[typing.Mapping[builtins.str, builtins.str]],
    ) -> None:
        jsii.set(self, "tags", value)

    @builtins.property # type: ignore
    @jsii.member(jsii_name="timeouts")
    def timeouts(self) -> typing.Optional["DedicatedHostGroupTimeouts"]:
        return jsii.get(self, "timeouts")

    @timeouts.setter # type: ignore
    def timeouts(self, value: typing.Optional["DedicatedHostGroupTimeouts"]) -> None:
        jsii.set(self, "timeouts", value)

    @builtins.property # type: ignore
    @jsii.member(jsii_name="zones")
    def zones(self) -> typing.Optional[typing.List[builtins.str]]:
        return jsii.get(self, "zones")

    @zones.setter # type: ignore
    def zones(self, value: typing.Optional[typing.List[builtins.str]]) -> None:
        jsii.set(self, "zones", value)


@jsii.data_type(
    jsii_type="@cdktf/provider-azurerm.DedicatedHostGroupConfig",
    jsii_struct_bases=[cdktf.TerraformMetaArguments],
    name_mapping={
        "count": "count",
        "depends_on": "dependsOn",
        "lifecycle": "lifecycle",
        "provider": "provider",
        "location": "location",
        "name": "name",
        "platform_fault_domain_count": "platformFaultDomainCount",
        "resource_group_name": "resourceGroupName",
        "tags": "tags",
        "timeouts": "timeouts",
        "zones": "zones",
    },
)
class DedicatedHostGroupConfig(cdktf.TerraformMetaArguments):
    def __init__(
        self,
        *,
        count: typing.Optional[jsii.Number] = None,
        depends_on: typing.Optional[typing.List[cdktf.TerraformResource]] = None,
        lifecycle: typing.Optional[cdktf.TerraformResourceLifecycle] = None,
        provider: typing.Optional[cdktf.TerraformProvider] = None,
        location: builtins.str,
        name: builtins.str,
        platform_fault_domain_count: jsii.Number,
        resource_group_name: builtins.str,
        tags: typing.Optional[typing.Mapping[builtins.str, builtins.str]] = None,
        timeouts: typing.Optional["DedicatedHostGroupTimeouts"] = None,
        zones: typing.Optional[typing.List[builtins.str]] = None,
    ) -> None:
        """
        :param count: 
        :param depends_on: 
        :param lifecycle: 
        :param provider: 
        :param location: 
        :param name: 
        :param platform_fault_domain_count: 
        :param resource_group_name: 
        :param tags: 
        :param timeouts: timeouts block.
        :param zones: 
        """
        if isinstance(lifecycle, dict):
            lifecycle = cdktf.TerraformResourceLifecycle(**lifecycle)
        if isinstance(timeouts, dict):
            timeouts = DedicatedHostGroupTimeouts(**timeouts)
        self._values: typing.Dict[str, typing.Any] = {
            "location": location,
            "name": name,
            "platform_fault_domain_count": platform_fault_domain_count,
            "resource_group_name": resource_group_name,
        }
        if count is not None:
            self._values["count"] = count
        if depends_on is not None:
            self._values["depends_on"] = depends_on
        if lifecycle is not None:
            self._values["lifecycle"] = lifecycle
        if provider is not None:
            self._values["provider"] = provider
        if tags is not None:
            self._values["tags"] = tags
        if timeouts is not None:
            self._values["timeouts"] = timeouts
        if zones is not None:
            self._values["zones"] = zones

    @builtins.property
    def count(self) -> typing.Optional[jsii.Number]:
        """
        :stability: experimental
        """
        result = self._values.get("count")
        return result

    @builtins.property
    def depends_on(self) -> typing.Optional[typing.List[cdktf.TerraformResource]]:
        """
        :stability: experimental
        """
        result = self._values.get("depends_on")
        return result

    @builtins.property
    def lifecycle(self) -> typing.Optional[cdktf.TerraformResourceLifecycle]:
        """
        :stability: experimental
        """
        result = self._values.get("lifecycle")
        return result

    @builtins.property
    def provider(self) -> typing.Optional[cdktf.TerraformProvider]:
        """
        :stability: experimental
        """
        result = self._values.get("provider")
        return result

    @builtins.property
    def location(self) -> builtins.str:
        result = self._values.get("location")
        assert result is not None, "Required property 'location' is missing"
        return result

    @builtins.property
    def name(self) -> builtins.str:
        result = self._values.get("name")
        assert result is not None, "Required property 'name' is missing"
        return result

    @builtins.property
    def platform_fault_domain_count(self) -> jsii.Number:
        result = self._values.get("platform_fault_domain_count")
        assert result is not None, "Required property 'platform_fault_domain_count' is missing"
        return result

    @builtins.property
    def resource_group_name(self) -> builtins.str:
        result = self._values.get("resource_group_name")
        assert result is not None, "Required property 'resource_group_name' is missing"
        return result

    @builtins.property
    def tags(self) -> typing.Optional[typing.Mapping[builtins.str, builtins.str]]:
        result = self._values.get("tags")
        return result

    @builtins.property
    def timeouts(self) -> typing.Optional["DedicatedHostGroupTimeouts"]:
        """timeouts block."""
        result = self._values.get("timeouts")
        return result

    @builtins.property
    def zones(self) -> typing.Optional[typing.List[builtins.str]]:
        result = self._values.get("zones")
        return result

    def __eq__(self, rhs: typing.Any) -> builtins.bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs: typing.Any) -> builtins.bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return "DedicatedHostGroupConfig(%s)" % ", ".join(
            k + "=" + repr(v) for k, v in self._values.items()
        )


@jsii.data_type(
    jsii_type="@cdktf/provider-azurerm.DedicatedHostGroupTimeouts",
    jsii_struct_bases=[],
    name_mapping={
        "create": "create",
        "delete": "delete",
        "read": "read",
        "update": "update",
    },
)
class DedicatedHostGroupTimeouts:
    def __init__(
        self,
        *,
        create: typing.Optional[builtins.str] = None,
        delete: typing.Optional[builtins.str] = None,
        read: typing.Optional[builtins.str] = None,
        update: typing.Optional[builtins.str] = None,
    ) -> None:
        """
        :param create: 
        :param delete: 
        :param read: 
        :param update: 
        """
        self._values: typing.Dict[str, typing.Any] = {}
        if create is not None:
            self._values["create"] = create
        if delete is not None:
            self._values["delete"] = delete
        if read is not None:
            self._values["read"] = read
        if update is not None:
            self._values["update"] = update

    @builtins.property
    def create(self) -> typing.Optional[builtins.str]:
        result = self._values.get("create")
        return result

    @builtins.property
    def delete(self) -> typing.Optional[builtins.str]:
        result = self._values.get("delete")
        return result

    @builtins.property
    def read(self) -> typing.Optional[builtins.str]:
        result = self._values.get("read")
        return result

    @builtins.property
    def update(self) -> typing.Optional[builtins.str]:
        result = self._values.get("update")
        return result

    def __eq__(self, rhs: typing.Any) -> builtins.bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs: typing.Any) -> builtins.bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return "DedicatedHostGroupTimeouts(%s)" % ", ".join(
            k + "=" + repr(v) for k, v in self._values.items()
        )


@jsii.data_type(
    jsii_type="@cdktf/provider-azurerm.DedicatedHostTimeouts",
    jsii_struct_bases=[],
    name_mapping={
        "create": "create",
        "delete": "delete",
        "read": "read",
        "update": "update",
    },
)
class DedicatedHostTimeouts:
    def __init__(
        self,
        *,
        create: typing.Optional[builtins.str] = None,
        delete: typing.Optional[builtins.str] = None,
        read: typing.Optional[builtins.str] = None,
        update: typing.Optional[builtins.str] = None,
    ) -> None:
        """
        :param create: 
        :param delete: 
        :param read: 
        :param update: 
        """
        self._values: typing.Dict[str, typing.Any] = {}
        if create is not None:
            self._values["create"] = create
        if delete is not None:
            self._values["delete"] = delete
        if read is not None:
            self._values["read"] = read
        if update is not None:
            self._values["update"] = update

    @builtins.property
    def create(self) -> typing.Optional[builtins.str]:
        result = self._values.get("create")
        return result

    @builtins.property
    def delete(self) -> typing.Optional[builtins.str]:
        result = self._values.get("delete")
        return result

    @builtins.property
    def read(self) -> typing.Optional[builtins.str]:
        result = self._values.get("read")
        return result

    @builtins.property
    def update(self) -> typing.Optional[builtins.str]:
        result = self._values.get("update")
        return result

    def __eq__(self, rhs: typing.Any) -> builtins.bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs: typing.Any) -> builtins.bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return "DedicatedHostTimeouts(%s)" % ", ".join(
            k + "=" + repr(v) for k, v in self._values.items()
        )


class DevTestLab(
    cdktf.TerraformResource,
    metaclass=jsii.JSIIMeta,
    jsii_type="@cdktf/provider-azurerm.DevTestLab",
):
    def __init__(
        self,
        scope: constructs.Construct,
        id: builtins.str,
        *,
        location: builtins.str,
        name: builtins.str,
        resource_group_name: builtins.str,
        storage_type: typing.Optional[builtins.str] = None,
        tags: typing.Optional[typing.Mapping[builtins.str, builtins.str]] = None,
        timeouts: typing.Optional["DevTestLabTimeouts"] = None,
        count: typing.Optional[jsii.Number] = None,
        depends_on: typing.Optional[typing.List[cdktf.TerraformResource]] = None,
        lifecycle: typing.Optional[cdktf.TerraformResourceLifecycle] = None,
        provider: typing.Optional[cdktf.TerraformProvider] = None,
    ) -> None:
        """
        :param scope: -
        :param id: -
        :param location: 
        :param name: 
        :param resource_group_name: 
        :param storage_type: 
        :param tags: 
        :param timeouts: timeouts block.
        :param count: 
        :param depends_on: 
        :param lifecycle: 
        :param provider: 
        """
        config = DevTestLabConfig(
            location=location,
            name=name,
            resource_group_name=resource_group_name,
            storage_type=storage_type,
            tags=tags,
            timeouts=timeouts,
            count=count,
            depends_on=depends_on,
            lifecycle=lifecycle,
            provider=provider,
        )

        jsii.create(DevTestLab, self, [scope, id, config])

    @jsii.member(jsii_name="synthesizeAttributes")
    def _synthesize_attributes(self) -> typing.Mapping[builtins.str, typing.Any]:
        return jsii.invoke(self, "synthesizeAttributes", [])

    @builtins.property # type: ignore
    @jsii.member(jsii_name="artifactsStorageAccountId")
    def artifacts_storage_account_id(self) -> builtins.str:
        return jsii.get(self, "artifactsStorageAccountId")

    @builtins.property # type: ignore
    @jsii.member(jsii_name="defaultPremiumStorageAccountId")
    def default_premium_storage_account_id(self) -> builtins.str:
        return jsii.get(self, "defaultPremiumStorageAccountId")

    @builtins.property # type: ignore
    @jsii.member(jsii_name="defaultStorageAccountId")
    def default_storage_account_id(self) -> builtins.str:
        return jsii.get(self, "defaultStorageAccountId")

    @builtins.property # type: ignore
    @jsii.member(jsii_name="keyVaultId")
    def key_vault_id(self) -> builtins.str:
        return jsii.get(self, "keyVaultId")

    @builtins.property # type: ignore
    @jsii.member(jsii_name="premiumDataDiskStorageAccountId")
    def premium_data_disk_storage_account_id(self) -> builtins.str:
        return jsii.get(self, "premiumDataDiskStorageAccountId")

    @builtins.property # type: ignore
    @jsii.member(jsii_name="uniqueIdentifier")
    def unique_identifier(self) -> builtins.str:
        return jsii.get(self, "uniqueIdentifier")

    @builtins.property # type: ignore
    @jsii.member(jsii_name="location")
    def location(self) -> builtins.str:
        return jsii.get(self, "location")

    @location.setter # type: ignore
    def location(self, value: builtins.str) -> None:
        jsii.set(self, "location", value)

    @builtins.property # type: ignore
    @jsii.member(jsii_name="name")
    def name(self) -> builtins.str:
        return jsii.get(self, "name")

    @name.setter # type: ignore
    def name(self, value: builtins.str) -> None:
        jsii.set(self, "name", value)

    @builtins.property # type: ignore
    @jsii.member(jsii_name="resourceGroupName")
    def resource_group_name(self) -> builtins.str:
        return jsii.get(self, "resourceGroupName")

    @resource_group_name.setter # type: ignore
    def resource_group_name(self, value: builtins.str) -> None:
        jsii.set(self, "resourceGroupName", value)

    @builtins.property # type: ignore
    @jsii.member(jsii_name="id")
    def id(self) -> typing.Optional[builtins.str]:
        return jsii.get(self, "id")

    @id.setter # type: ignore
    def id(self, value: typing.Optional[builtins.str]) -> None:
        jsii.set(self, "id", value)

    @builtins.property # type: ignore
    @jsii.member(jsii_name="storageType")
    def storage_type(self) -> typing.Optional[builtins.str]:
        return jsii.get(self, "storageType")

    @storage_type.setter # type: ignore
    def storage_type(self, value: typing.Optional[builtins.str]) -> None:
        jsii.set(self, "storageType", value)

    @builtins.property # type: ignore
    @jsii.member(jsii_name="tags")
    def tags(self) -> typing.Optional[typing.Mapping[builtins.str, builtins.str]]:
        return jsii.get(self, "tags")

    @tags.setter # type: ignore
    def tags(
        self,
        value: typing.Optional[typing.Mapping[builtins.str, builtins.str]],
    ) -> None:
        jsii.set(self, "tags", value)

    @builtins.property # type: ignore
    @jsii.member(jsii_name="timeouts")
    def timeouts(self) -> typing.Optional["DevTestLabTimeouts"]:
        return jsii.get(self, "timeouts")

    @timeouts.setter # type: ignore
    def timeouts(self, value: typing.Optional["DevTestLabTimeouts"]) -> None:
        jsii.set(self, "timeouts", value)


@jsii.data_type(
    jsii_type="@cdktf/provider-azurerm.DevTestLabConfig",
    jsii_struct_bases=[cdktf.TerraformMetaArguments],
    name_mapping={
        "count": "count",
        "depends_on": "dependsOn",
        "lifecycle": "lifecycle",
        "provider": "provider",
        "location": "location",
        "name": "name",
        "resource_group_name": "resourceGroupName",
        "storage_type": "storageType",
        "tags": "tags",
        "timeouts": "timeouts",
    },
)
class DevTestLabConfig(cdktf.TerraformMetaArguments):
    def __init__(
        self,
        *,
        count: typing.Optional[jsii.Number] = None,
        depends_on: typing.Optional[typing.List[cdktf.TerraformResource]] = None,
        lifecycle: typing.Optional[cdktf.TerraformResourceLifecycle] = None,
        provider: typing.Optional[cdktf.TerraformProvider] = None,
        location: builtins.str,
        name: builtins.str,
        resource_group_name: builtins.str,
        storage_type: typing.Optional[builtins.str] = None,
        tags: typing.Optional[typing.Mapping[builtins.str, builtins.str]] = None,
        timeouts: typing.Optional["DevTestLabTimeouts"] = None,
    ) -> None:
        """
        :param count: 
        :param depends_on: 
        :param lifecycle: 
        :param provider: 
        :param location: 
        :param name: 
        :param resource_group_name: 
        :param storage_type: 
        :param tags: 
        :param timeouts: timeouts block.
        """
        if isinstance(lifecycle, dict):
            lifecycle = cdktf.TerraformResourceLifecycle(**lifecycle)
        if isinstance(timeouts, dict):
            timeouts = DevTestLabTimeouts(**timeouts)
        self._values: typing.Dict[str, typing.Any] = {
            "location": location,
            "name": name,
            "resource_group_name": resource_group_name,
        }
        if count is not None:
            self._values["count"] = count
        if depends_on is not None:
            self._values["depends_on"] = depends_on
        if lifecycle is not None:
            self._values["lifecycle"] = lifecycle
        if provider is not None:
            self._values["provider"] = provider
        if storage_type is not None:
            self._values["storage_type"] = storage_type
        if tags is not None:
            self._values["tags"] = tags
        if timeouts is not None:
            self._values["timeouts"] = timeouts

    @builtins.property
    def count(self) -> typing.Optional[jsii.Number]:
        """
        :stability: experimental
        """
        result = self._values.get("count")
        return result

    @builtins.property
    def depends_on(self) -> typing.Optional[typing.List[cdktf.TerraformResource]]:
        """
        :stability: experimental
        """
        result = self._values.get("depends_on")
        return result

    @builtins.property
    def lifecycle(self) -> typing.Optional[cdktf.TerraformResourceLifecycle]:
        """
        :stability: experimental
        """
        result = self._values.get("lifecycle")
        return result

    @builtins.property
    def provider(self) -> typing.Optional[cdktf.TerraformProvider]:
        """
        :stability: experimental
        """
        result = self._values.get("provider")
        return result

    @builtins.property
    def location(self) -> builtins.str:
        result = self._values.get("location")
        assert result is not None, "Required property 'location' is missing"
        return result

    @builtins.property
    def name(self) -> builtins.str:
        result = self._values.get("name")
        assert result is not None, "Required property 'name' is missing"
        return result

    @builtins.property
    def resource_group_name(self) -> builtins.str:
        result = self._values.get("resource_group_name")
        assert result is not None, "Required property 'resource_group_name' is missing"
        return result

    @builtins.property
    def storage_type(self) -> typing.Optional[builtins.str]:
        result = self._values.get("storage_type")
        return result

    @builtins.property
    def tags(self) -> typing.Optional[typing.Mapping[builtins.str, builtins.str]]:
        result = self._values.get("tags")
        return result

    @builtins.property
    def timeouts(self) -> typing.Optional["DevTestLabTimeouts"]:
        """timeouts block."""
        result = self._values.get("timeouts")
        return result

    def __eq__(self, rhs: typing.Any) -> builtins.bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs: typing.Any) -> builtins.bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return "DevTestLabConfig(%s)" % ", ".join(
            k + "=" + repr(v) for k, v in self._values.items()
        )


@jsii.data_type(
    jsii_type="@cdktf/provider-azurerm.DevTestLabTimeouts",
    jsii_struct_bases=[],
    name_mapping={
        "create": "create",
        "delete": "delete",
        "read": "read",
        "update": "update",
    },
)
class DevTestLabTimeouts:
    def __init__(
        self,
        *,
        create: typing.Optional[builtins.str] = None,
        delete: typing.Optional[builtins.str] = None,
        read: typing.Optional[builtins.str] = None,
        update: typing.Optional[builtins.str] = None,
    ) -> None:
        """
        :param create: 
        :param delete: 
        :param read: 
        :param update: 
        """
        self._values: typing.Dict[str, typing.Any] = {}
        if create is not None:
            self._values["create"] = create
        if delete is not None:
            self._values["delete"] = delete
        if read is not None:
            self._values["read"] = read
        if update is not None:
            self._values["update"] = update

    @builtins.property
    def create(self) -> typing.Optional[builtins.str]:
        result = self._values.get("create")
        return result

    @builtins.property
    def delete(self) -> typing.Optional[builtins.str]:
        result = self._values.get("delete")
        return result

    @builtins.property
    def read(self) -> typing.Optional[builtins.str]:
        result = self._values.get("read")
        return result

    @builtins.property
    def update(self) -> typing.Optional[builtins.str]:
        result = self._values.get("update")
        return result

    def __eq__(self, rhs: typing.Any) -> builtins.bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs: typing.Any) -> builtins.bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return "DevTestLabTimeouts(%s)" % ", ".join(
            k + "=" + repr(v) for k, v in self._values.items()
        )


class DevTestLinuxVirtualMachine(
    cdktf.TerraformResource,
    metaclass=jsii.JSIIMeta,
    jsii_type="@cdktf/provider-azurerm.DevTestLinuxVirtualMachine",
):
    def __init__(
        self,
        scope: constructs.Construct,
        id: builtins.str,
        *,
        gallery_image_reference: typing.List["DevTestLinuxVirtualMachineGalleryImageReference"],
        lab_name: builtins.str,
        lab_subnet_name: builtins.str,
        lab_virtual_network_id: builtins.str,
        location: builtins.str,
        name: builtins.str,
        resource_group_name: builtins.str,
        size: builtins.str,
        storage_type: builtins.str,
        username: builtins.str,
        allow_claim: typing.Optional[builtins.bool] = None,
        disallow_public_ip_address: typing.Optional[builtins.bool] = None,
        inbound_nat_rule: typing.Optional[typing.List["DevTestLinuxVirtualMachineInboundNatRule"]] = None,
        notes: typing.Optional[builtins.str] = None,
        password: typing.Optional[builtins.str] = None,
        ssh_key: typing.Optional[builtins.str] = None,
        tags: typing.Optional[typing.Mapping[builtins.str, builtins.str]] = None,
        timeouts: typing.Optional["DevTestLinuxVirtualMachineTimeouts"] = None,
        count: typing.Optional[jsii.Number] = None,
        depends_on: typing.Optional[typing.List[cdktf.TerraformResource]] = None,
        lifecycle: typing.Optional[cdktf.TerraformResourceLifecycle] = None,
        provider: typing.Optional[cdktf.TerraformProvider] = None,
    ) -> None:
        """
        :param scope: -
        :param id: -
        :param gallery_image_reference: gallery_image_reference block.
        :param lab_name: 
        :param lab_subnet_name: 
        :param lab_virtual_network_id: 
        :param location: 
        :param name: 
        :param resource_group_name: 
        :param size: 
        :param storage_type: 
        :param username: 
        :param allow_claim: 
        :param disallow_public_ip_address: 
        :param inbound_nat_rule: inbound_nat_rule block.
        :param notes: 
        :param password: 
        :param ssh_key: 
        :param tags: 
        :param timeouts: timeouts block.
        :param count: 
        :param depends_on: 
        :param lifecycle: 
        :param provider: 
        """
        config = DevTestLinuxVirtualMachineConfig(
            gallery_image_reference=gallery_image_reference,
            lab_name=lab_name,
            lab_subnet_name=lab_subnet_name,
            lab_virtual_network_id=lab_virtual_network_id,
            location=location,
            name=name,
            resource_group_name=resource_group_name,
            size=size,
            storage_type=storage_type,
            username=username,
            allow_claim=allow_claim,
            disallow_public_ip_address=disallow_public_ip_address,
            inbound_nat_rule=inbound_nat_rule,
            notes=notes,
            password=password,
            ssh_key=ssh_key,
            tags=tags,
            timeouts=timeouts,
            count=count,
            depends_on=depends_on,
            lifecycle=lifecycle,
            provider=provider,
        )

        jsii.create(DevTestLinuxVirtualMachine, self, [scope, id, config])

    @jsii.member(jsii_name="synthesizeAttributes")
    def _synthesize_attributes(self) -> typing.Mapping[builtins.str, typing.Any]:
        return jsii.invoke(self, "synthesizeAttributes", [])

    @builtins.property # type: ignore
    @jsii.member(jsii_name="fqdn")
    def fqdn(self) -> builtins.str:
        return jsii.get(self, "fqdn")

    @builtins.property # type: ignore
    @jsii.member(jsii_name="uniqueIdentifier")
    def unique_identifier(self) -> builtins.str:
        return jsii.get(self, "uniqueIdentifier")

    @builtins.property # type: ignore
    @jsii.member(jsii_name="galleryImageReference")
    def gallery_image_reference(
        self,
    ) -> typing.List["DevTestLinuxVirtualMachineGalleryImageReference"]:
        return jsii.get(self, "galleryImageReference")

    @gallery_image_reference.setter # type: ignore
    def gallery_image_reference(
        self,
        value: typing.List["DevTestLinuxVirtualMachineGalleryImageReference"],
    ) -> None:
        jsii.set(self, "galleryImageReference", value)

    @builtins.property # type: ignore
    @jsii.member(jsii_name="labName")
    def lab_name(self) -> builtins.str:
        return jsii.get(self, "labName")

    @lab_name.setter # type: ignore
    def lab_name(self, value: builtins.str) -> None:
        jsii.set(self, "labName", value)

    @builtins.property # type: ignore
    @jsii.member(jsii_name="labSubnetName")
    def lab_subnet_name(self) -> builtins.str:
        return jsii.get(self, "labSubnetName")

    @lab_subnet_name.setter # type: ignore
    def lab_subnet_name(self, value: builtins.str) -> None:
        jsii.set(self, "labSubnetName", value)

    @builtins.property # type: ignore
    @jsii.member(jsii_name="labVirtualNetworkId")
    def lab_virtual_network_id(self) -> builtins.str:
        return jsii.get(self, "labVirtualNetworkId")

    @lab_virtual_network_id.setter # type: ignore
    def lab_virtual_network_id(self, value: builtins.str) -> None:
        jsii.set(self, "labVirtualNetworkId", value)

    @builtins.property # type: ignore
    @jsii.member(jsii_name="location")
    def location(self) -> builtins.str:
        return jsii.get(self, "location")

    @location.setter # type: ignore
    def location(self, value: builtins.str) -> None:
        jsii.set(self, "location", value)

    @builtins.property # type: ignore
    @jsii.member(jsii_name="name")
    def name(self) -> builtins.str:
        return jsii.get(self, "name")

    @name.setter # type: ignore
    def name(self, value: builtins.str) -> None:
        jsii.set(self, "name", value)

    @builtins.property # type: ignore
    @jsii.member(jsii_name="resourceGroupName")
    def resource_group_name(self) -> builtins.str:
        return jsii.get(self, "resourceGroupName")

    @resource_group_name.setter # type: ignore
    def resource_group_name(self, value: builtins.str) -> None:
        jsii.set(self, "resourceGroupName", value)

    @builtins.property # type: ignore
    @jsii.member(jsii_name="size")
    def size(self) -> builtins.str:
        return jsii.get(self, "size")

    @size.setter # type: ignore
    def size(self, value: builtins.str) -> None:
        jsii.set(self, "size", value)

    @builtins.property # type: ignore
    @jsii.member(jsii_name="storageType")
    def storage_type(self) -> builtins.str:
        return jsii.get(self, "storageType")

    @storage_type.setter # type: ignore
    def storage_type(self, value: builtins.str) -> None:
        jsii.set(self, "storageType", value)

    @builtins.property # type: ignore
    @jsii.member(jsii_name="username")
    def username(self) -> builtins.str:
        return jsii.get(self, "username")

    @username.setter # type: ignore
    def username(self, value: builtins.str) -> None:
        jsii.set(self, "username", value)

    @builtins.property # type: ignore
    @jsii.member(jsii_name="allowClaim")
    def allow_claim(self) -> typing.Optional[builtins.bool]:
        return jsii.get(self, "allowClaim")

    @allow_claim.setter # type: ignore
    def allow_claim(self, value: typing.Optional[builtins.bool]) -> None:
        jsii.set(self, "allowClaim", value)

    @builtins.property # type: ignore
    @jsii.member(jsii_name="disallowPublicIpAddress")
    def disallow_public_ip_address(self) -> typing.Optional[builtins.bool]:
        return jsii.get(self, "disallowPublicIpAddress")

    @disallow_public_ip_address.setter # type: ignore
    def disallow_public_ip_address(self, value: typing.Optional[builtins.bool]) -> None:
        jsii.set(self, "disallowPublicIpAddress", value)

    @builtins.property # type: ignore
    @jsii.member(jsii_name="id")
    def id(self) -> typing.Optional[builtins.str]:
        return jsii.get(self, "id")

    @id.setter # type: ignore
    def id(self, value: typing.Optional[builtins.str]) -> None:
        jsii.set(self, "id", value)

    @builtins.property # type: ignore
    @jsii.member(jsii_name="inboundNatRule")
    def inbound_nat_rule(
        self,
    ) -> typing.Optional[typing.List["DevTestLinuxVirtualMachineInboundNatRule"]]:
        return jsii.get(self, "inboundNatRule")

    @inbound_nat_rule.setter # type: ignore
    def inbound_nat_rule(
        self,
        value: typing.Optional[typing.List["DevTestLinuxVirtualMachineInboundNatRule"]],
    ) -> None:
        jsii.set(self, "inboundNatRule", value)

    @builtins.property # type: ignore
    @jsii.member(jsii_name="notes")
    def notes(self) -> typing.Optional[builtins.str]:
        return jsii.get(self, "notes")

    @notes.setter # type: ignore
    def notes(self, value: typing.Optional[builtins.str]) -> None:
        jsii.set(self, "notes", value)

    @builtins.property # type: ignore
    @jsii.member(jsii_name="password")
    def password(self) -> typing.Optional[builtins.str]:
        return jsii.get(self, "password")

    @password.setter # type: ignore
    def password(self, value: typing.Optional[builtins.str]) -> None:
        jsii.set(self, "password", value)

    @builtins.property # type: ignore
    @jsii.member(jsii_name="sshKey")
    def ssh_key(self) -> typing.Optional[builtins.str]:
        return jsii.get(self, "sshKey")

    @ssh_key.setter # type: ignore
    def ssh_key(self, value: typing.Optional[builtins.str]) -> None:
        jsii.set(self, "sshKey", value)

    @builtins.property # type: ignore
    @jsii.member(jsii_name="tags")
    def tags(self) -> typing.Optional[typing.Mapping[builtins.str, builtins.str]]:
        return jsii.get(self, "tags")

    @tags.setter # type: ignore
    def tags(
        self,
        value: typing.Optional[typing.Mapping[builtins.str, builtins.str]],
    ) -> None:
        jsii.set(self, "tags", value)

    @builtins.property # type: ignore
    @jsii.member(jsii_name="timeouts")
    def timeouts(self) -> typing.Optional["DevTestLinuxVirtualMachineTimeouts"]:
        return jsii.get(self, "timeouts")

    @timeouts.setter # type: ignore
    def timeouts(
        self,
        value: typing.Optional["DevTestLinuxVirtualMachineTimeouts"],
    ) -> None:
        jsii.set(self, "timeouts", value)


@jsii.data_type(
    jsii_type="@cdktf/provider-azurerm.DevTestLinuxVirtualMachineConfig",
    jsii_struct_bases=[cdktf.TerraformMetaArguments],
    name_mapping={
        "count": "count",
        "depends_on": "dependsOn",
        "lifecycle": "lifecycle",
        "provider": "provider",
        "gallery_image_reference": "galleryImageReference",
        "lab_name": "labName",
        "lab_subnet_name": "labSubnetName",
        "lab_virtual_network_id": "labVirtualNetworkId",
        "location": "location",
        "name": "name",
        "resource_group_name": "resourceGroupName",
        "size": "size",
        "storage_type": "storageType",
        "username": "username",
        "allow_claim": "allowClaim",
        "disallow_public_ip_address": "disallowPublicIpAddress",
        "inbound_nat_rule": "inboundNatRule",
        "notes": "notes",
        "password": "password",
        "ssh_key": "sshKey",
        "tags": "tags",
        "timeouts": "timeouts",
    },
)
class DevTestLinuxVirtualMachineConfig(cdktf.TerraformMetaArguments):
    def __init__(
        self,
        *,
        count: typing.Optional[jsii.Number] = None,
        depends_on: typing.Optional[typing.List[cdktf.TerraformResource]] = None,
        lifecycle: typing.Optional[cdktf.TerraformResourceLifecycle] = None,
        provider: typing.Optional[cdktf.TerraformProvider] = None,
        gallery_image_reference: typing.List["DevTestLinuxVirtualMachineGalleryImageReference"],
        lab_name: builtins.str,
        lab_subnet_name: builtins.str,
        lab_virtual_network_id: builtins.str,
        location: builtins.str,
        name: builtins.str,
        resource_group_name: builtins.str,
        size: builtins.str,
        storage_type: builtins.str,
        username: builtins.str,
        allow_claim: typing.Optional[builtins.bool] = None,
        disallow_public_ip_address: typing.Optional[builtins.bool] = None,
        inbound_nat_rule: typing.Optional[typing.List["DevTestLinuxVirtualMachineInboundNatRule"]] = None,
        notes: typing.Optional[builtins.str] = None,
        password: typing.Optional[builtins.str] = None,
        ssh_key: typing.Optional[builtins.str] = None,
        tags: typing.Optional[typing.Mapping[builtins.str, builtins.str]] = None,
        timeouts: typing.Optional["DevTestLinuxVirtualMachineTimeouts"] = None,
    ) -> None:
        """
        :param count: 
        :param depends_on: 
        :param lifecycle: 
        :param provider: 
        :param gallery_image_reference: gallery_image_reference block.
        :param lab_name: 
        :param lab_subnet_name: 
        :param lab_virtual_network_id: 
        :param location: 
        :param name: 
        :param resource_group_name: 
        :param size: 
        :param storage_type: 
        :param username: 
        :param allow_claim: 
        :param disallow_public_ip_address: 
        :param inbound_nat_rule: inbound_nat_rule block.
        :param notes: 
        :param password: 
        :param ssh_key: 
        :param tags: 
        :param timeouts: timeouts block.
        """
        if isinstance(lifecycle, dict):
            lifecycle = cdktf.TerraformResourceLifecycle(**lifecycle)
        if isinstance(timeouts, dict):
            timeouts = DevTestLinuxVirtualMachineTimeouts(**timeouts)
        self._values: typing.Dict[str, typing.Any] = {
            "gallery_image_reference": gallery_image_reference,
            "lab_name": lab_name,
            "lab_subnet_name": lab_subnet_name,
            "lab_virtual_network_id": lab_virtual_network_id,
            "location": location,
            "name": name,
            "resource_group_name": resource_group_name,
            "size": size,
            "storage_type": storage_type,
            "username": username,
        }
        if count is not None:
            self._values["count"] = count
        if depends_on is not None:
            self._values["depends_on"] = depends_on
        if lifecycle is not None:
            self._values["lifecycle"] = lifecycle
        if provider is not None:
            self._values["provider"] = provider
        if allow_claim is not None:
            self._values["allow_claim"] = allow_claim
        if disallow_public_ip_address is not None:
            self._values["disallow_public_ip_address"] = disallow_public_ip_address
        if inbound_nat_rule is not None:
            self._values["inbound_nat_rule"] = inbound_nat_rule
        if notes is not None:
            self._values["notes"] = notes
        if password is not None:
            self._values["password"] = password
        if ssh_key is not None:
            self._values["ssh_key"] = ssh_key
        if tags is not None:
            self._values["tags"] = tags
        if timeouts is not None:
            self._values["timeouts"] = timeouts

    @builtins.property
    def count(self) -> typing.Optional[jsii.Number]:
        """
        :stability: experimental
        """
        result = self._values.get("count")
        return result

    @builtins.property
    def depends_on(self) -> typing.Optional[typing.List[cdktf.TerraformResource]]:
        """
        :stability: experimental
        """
        result = self._values.get("depends_on")
        return result

    @builtins.property
    def lifecycle(self) -> typing.Optional[cdktf.TerraformResourceLifecycle]:
        """
        :stability: experimental
        """
        result = self._values.get("lifecycle")
        return result

    @builtins.property
    def provider(self) -> typing.Optional[cdktf.TerraformProvider]:
        """
        :stability: experimental
        """
        result = self._values.get("provider")
        return result

    @builtins.property
    def gallery_image_reference(
        self,
    ) -> typing.List["DevTestLinuxVirtualMachineGalleryImageReference"]:
        """gallery_image_reference block."""
        result = self._values.get("gallery_image_reference")
        assert result is not None, "Required property 'gallery_image_reference' is missing"
        return result

    @builtins.property
    def lab_name(self) -> builtins.str:
        result = self._values.get("lab_name")
        assert result is not None, "Required property 'lab_name' is missing"
        return result

    @builtins.property
    def lab_subnet_name(self) -> builtins.str:
        result = self._values.get("lab_subnet_name")
        assert result is not None, "Required property 'lab_subnet_name' is missing"
        return result

    @builtins.property
    def lab_virtual_network_id(self) -> builtins.str:
        result = self._values.get("lab_virtual_network_id")
        assert result is not None, "Required property 'lab_virtual_network_id' is missing"
        return result

    @builtins.property
    def location(self) -> builtins.str:
        result = self._values.get("location")
        assert result is not None, "Required property 'location' is missing"
        return result

    @builtins.property
    def name(self) -> builtins.str:
        result = self._values.get("name")
        assert result is not None, "Required property 'name' is missing"
        return result

    @builtins.property
    def resource_group_name(self) -> builtins.str:
        result = self._values.get("resource_group_name")
        assert result is not None, "Required property 'resource_group_name' is missing"
        return result

    @builtins.property
    def size(self) -> builtins.str:
        result = self._values.get("size")
        assert result is not None, "Required property 'size' is missing"
        return result

    @builtins.property
    def storage_type(self) -> builtins.str:
        result = self._values.get("storage_type")
        assert result is not None, "Required property 'storage_type' is missing"
        return result

    @builtins.property
    def username(self) -> builtins.str:
        result = self._values.get("username")
        assert result is not None, "Required property 'username' is missing"
        return result

    @builtins.property
    def allow_claim(self) -> typing.Optional[builtins.bool]:
        result = self._values.get("allow_claim")
        return result

    @builtins.property
    def disallow_public_ip_address(self) -> typing.Optional[builtins.bool]:
        result = self._values.get("disallow_public_ip_address")
        return result

    @builtins.property
    def inbound_nat_rule(
        self,
    ) -> typing.Optional[typing.List["DevTestLinuxVirtualMachineInboundNatRule"]]:
        """inbound_nat_rule block."""
        result = self._values.get("inbound_nat_rule")
        return result

    @builtins.property
    def notes(self) -> typing.Optional[builtins.str]:
        result = self._values.get("notes")
        return result

    @builtins.property
    def password(self) -> typing.Optional[builtins.str]:
        result = self._values.get("password")
        return result

    @builtins.property
    def ssh_key(self) -> typing.Optional[builtins.str]:
        result = self._values.get("ssh_key")
        return result

    @builtins.property
    def tags(self) -> typing.Optional[typing.Mapping[builtins.str, builtins.str]]:
        result = self._values.get("tags")
        return result

    @builtins.property
    def timeouts(self) -> typing.Optional["DevTestLinuxVirtualMachineTimeouts"]:
        """timeouts block."""
        result = self._values.get("timeouts")
        return result

    def __eq__(self, rhs: typing.Any) -> builtins.bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs: typing.Any) -> builtins.bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return "DevTestLinuxVirtualMachineConfig(%s)" % ", ".join(
            k + "=" + repr(v) for k, v in self._values.items()
        )


@jsii.data_type(
    jsii_type="@cdktf/provider-azurerm.DevTestLinuxVirtualMachineGalleryImageReference",
    jsii_struct_bases=[],
    name_mapping={
        "offer": "offer",
        "publisher": "publisher",
        "sku": "sku",
        "version": "version",
    },
)
class DevTestLinuxVirtualMachineGalleryImageReference:
    def __init__(
        self,
        *,
        offer: builtins.str,
        publisher: builtins.str,
        sku: builtins.str,
        version: builtins.str,
    ) -> None:
        """
        :param offer: 
        :param publisher: 
        :param sku: 
        :param version: 
        """
        self._values: typing.Dict[str, typing.Any] = {
            "offer": offer,
            "publisher": publisher,
            "sku": sku,
            "version": version,
        }

    @builtins.property
    def offer(self) -> builtins.str:
        result = self._values.get("offer")
        assert result is not None, "Required property 'offer' is missing"
        return result

    @builtins.property
    def publisher(self) -> builtins.str:
        result = self._values.get("publisher")
        assert result is not None, "Required property 'publisher' is missing"
        return result

    @builtins.property
    def sku(self) -> builtins.str:
        result = self._values.get("sku")
        assert result is not None, "Required property 'sku' is missing"
        return result

    @builtins.property
    def version(self) -> builtins.str:
        result = self._values.get("version")
        assert result is not None, "Required property 'version' is missing"
        return result

    def __eq__(self, rhs: typing.Any) -> builtins.bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs: typing.Any) -> builtins.bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return "DevTestLinuxVirtualMachineGalleryImageReference(%s)" % ", ".join(
            k + "=" + repr(v) for k, v in self._values.items()
        )


@jsii.data_type(
    jsii_type="@cdktf/provider-azurerm.DevTestLinuxVirtualMachineInboundNatRule",
    jsii_struct_bases=[],
    name_mapping={"backend_port": "backendPort", "protocol": "protocol"},
)
class DevTestLinuxVirtualMachineInboundNatRule:
    def __init__(self, *, backend_port: jsii.Number, protocol: builtins.str) -> None:
        """
        :param backend_port: 
        :param protocol: 
        """
        self._values: typing.Dict[str, typing.Any] = {
            "backend_port": backend_port,
            "protocol": protocol,
        }

    @builtins.property
    def backend_port(self) -> jsii.Number:
        result = self._values.get("backend_port")
        assert result is not None, "Required property 'backend_port' is missing"
        return result

    @builtins.property
    def protocol(self) -> builtins.str:
        result = self._values.get("protocol")
        assert result is not None, "Required property 'protocol' is missing"
        return result

    def __eq__(self, rhs: typing.Any) -> builtins.bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs: typing.Any) -> builtins.bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return "DevTestLinuxVirtualMachineInboundNatRule(%s)" % ", ".join(
            k + "=" + repr(v) for k, v in self._values.items()
        )


@jsii.data_type(
    jsii_type="@cdktf/provider-azurerm.DevTestLinuxVirtualMachineTimeouts",
    jsii_struct_bases=[],
    name_mapping={
        "create": "create",
        "delete": "delete",
        "read": "read",
        "update": "update",
    },
)
class DevTestLinuxVirtualMachineTimeouts:
    def __init__(
        self,
        *,
        create: typing.Optional[builtins.str] = None,
        delete: typing.Optional[builtins.str] = None,
        read: typing.Optional[builtins.str] = None,
        update: typing.Optional[builtins.str] = None,
    ) -> None:
        """
        :param create: 
        :param delete: 
        :param read: 
        :param update: 
        """
        self._values: typing.Dict[str, typing.Any] = {}
        if create is not None:
            self._values["create"] = create
        if delete is not None:
            self._values["delete"] = delete
        if read is not None:
            self._values["read"] = read
        if update is not None:
            self._values["update"] = update

    @builtins.property
    def create(self) -> typing.Optional[builtins.str]:
        result = self._values.get("create")
        return result

    @builtins.property
    def delete(self) -> typing.Optional[builtins.str]:
        result = self._values.get("delete")
        return result

    @builtins.property
    def read(self) -> typing.Optional[builtins.str]:
        result = self._values.get("read")
        return result

    @builtins.property
    def update(self) -> typing.Optional[builtins.str]:
        result = self._values.get("update")
        return result

    def __eq__(self, rhs: typing.Any) -> builtins.bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs: typing.Any) -> builtins.bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return "DevTestLinuxVirtualMachineTimeouts(%s)" % ", ".join(
            k + "=" + repr(v) for k, v in self._values.items()
        )


class DevTestPolicy(
    cdktf.TerraformResource,
    metaclass=jsii.JSIIMeta,
    jsii_type="@cdktf/provider-azurerm.DevTestPolicy",
):
    def __init__(
        self,
        scope: constructs.Construct,
        id: builtins.str,
        *,
        evaluator_type: builtins.str,
        lab_name: builtins.str,
        name: builtins.str,
        policy_set_name: builtins.str,
        resource_group_name: builtins.str,
        threshold: builtins.str,
        description: typing.Optional[builtins.str] = None,
        fact_data: typing.Optional[builtins.str] = None,
        tags: typing.Optional[typing.Mapping[builtins.str, builtins.str]] = None,
        timeouts: typing.Optional["DevTestPolicyTimeouts"] = None,
        count: typing.Optional[jsii.Number] = None,
        depends_on: typing.Optional[typing.List[cdktf.TerraformResource]] = None,
        lifecycle: typing.Optional[cdktf.TerraformResourceLifecycle] = None,
        provider: typing.Optional[cdktf.TerraformProvider] = None,
    ) -> None:
        """
        :param scope: -
        :param id: -
        :param evaluator_type: 
        :param lab_name: 
        :param name: 
        :param policy_set_name: 
        :param resource_group_name: 
        :param threshold: 
        :param description: 
        :param fact_data: 
        :param tags: 
        :param timeouts: timeouts block.
        :param count: 
        :param depends_on: 
        :param lifecycle: 
        :param provider: 
        """
        config = DevTestPolicyConfig(
            evaluator_type=evaluator_type,
            lab_name=lab_name,
            name=name,
            policy_set_name=policy_set_name,
            resource_group_name=resource_group_name,
            threshold=threshold,
            description=description,
            fact_data=fact_data,
            tags=tags,
            timeouts=timeouts,
            count=count,
            depends_on=depends_on,
            lifecycle=lifecycle,
            provider=provider,
        )

        jsii.create(DevTestPolicy, self, [scope, id, config])

    @jsii.member(jsii_name="synthesizeAttributes")
    def _synthesize_attributes(self) -> typing.Mapping[builtins.str, typing.Any]:
        return jsii.invoke(self, "synthesizeAttributes", [])

    @builtins.property # type: ignore
    @jsii.member(jsii_name="evaluatorType")
    def evaluator_type(self) -> builtins.str:
        return jsii.get(self, "evaluatorType")

    @evaluator_type.setter # type: ignore
    def evaluator_type(self, value: builtins.str) -> None:
        jsii.set(self, "evaluatorType", value)

    @builtins.property # type: ignore
    @jsii.member(jsii_name="labName")
    def lab_name(self) -> builtins.str:
        return jsii.get(self, "labName")

    @lab_name.setter # type: ignore
    def lab_name(self, value: builtins.str) -> None:
        jsii.set(self, "labName", value)

    @builtins.property # type: ignore
    @jsii.member(jsii_name="name")
    def name(self) -> builtins.str:
        return jsii.get(self, "name")

    @name.setter # type: ignore
    def name(self, value: builtins.str) -> None:
        jsii.set(self, "name", value)

    @builtins.property # type: ignore
    @jsii.member(jsii_name="policySetName")
    def policy_set_name(self) -> builtins.str:
        return jsii.get(self, "policySetName")

    @policy_set_name.setter # type: ignore
    def policy_set_name(self, value: builtins.str) -> None:
        jsii.set(self, "policySetName", value)

    @builtins.property # type: ignore
    @jsii.member(jsii_name="resourceGroupName")
    def resource_group_name(self) -> builtins.str:
        return jsii.get(self, "resourceGroupName")

    @resource_group_name.setter # type: ignore
    def resource_group_name(self, value: builtins.str) -> None:
        jsii.set(self, "resourceGroupName", value)

    @builtins.property # type: ignore
    @jsii.member(jsii_name="threshold")
    def threshold(self) -> builtins.str:
        return jsii.get(self, "threshold")

    @threshold.setter # type: ignore
    def threshold(self, value: builtins.str) -> None:
        jsii.set(self, "threshold", value)

    @builtins.property # type: ignore
    @jsii.member(jsii_name="description")
    def description(self) -> typing.Optional[builtins.str]:
        return jsii.get(self, "description")

    @description.setter # type: ignore
    def description(self, value: typing.Optional[builtins.str]) -> None:
        jsii.set(self, "description", value)

    @builtins.property # type: ignore
    @jsii.member(jsii_name="factData")
    def fact_data(self) -> typing.Optional[builtins.str]:
        return jsii.get(self, "factData")

    @fact_data.setter # type: ignore
    def fact_data(self, value: typing.Optional[builtins.str]) -> None:
        jsii.set(self, "factData", value)

    @builtins.property # type: ignore
    @jsii.member(jsii_name="id")
    def id(self) -> typing.Optional[builtins.str]:
        return jsii.get(self, "id")

    @id.setter # type: ignore
    def id(self, value: typing.Optional[builtins.str]) -> None:
        jsii.set(self, "id", value)

    @builtins.property # type: ignore
    @jsii.member(jsii_name="tags")
    def tags(self) -> typing.Optional[typing.Mapping[builtins.str, builtins.str]]:
        return jsii.get(self, "tags")

    @tags.setter # type: ignore
    def tags(
        self,
        value: typing.Optional[typing.Mapping[builtins.str, builtins.str]],
    ) -> None:
        jsii.set(self, "tags", value)

    @builtins.property # type: ignore
    @jsii.member(jsii_name="timeouts")
    def timeouts(self) -> typing.Optional["DevTestPolicyTimeouts"]:
        return jsii.get(self, "timeouts")

    @timeouts.setter # type: ignore
    def timeouts(self, value: typing.Optional["DevTestPolicyTimeouts"]) -> None:
        jsii.set(self, "timeouts", value)


@jsii.data_type(
    jsii_type="@cdktf/provider-azurerm.DevTestPolicyConfig",
    jsii_struct_bases=[cdktf.TerraformMetaArguments],
    name_mapping={
        "count": "count",
        "depends_on": "dependsOn",
        "lifecycle": "lifecycle",
        "provider": "provider",
        "evaluator_type": "evaluatorType",
        "lab_name": "labName",
        "name": "name",
        "policy_set_name": "policySetName",
        "resource_group_name": "resourceGroupName",
        "threshold": "threshold",
        "description": "description",
        "fact_data": "factData",
        "tags": "tags",
        "timeouts": "timeouts",
    },
)
class DevTestPolicyConfig(cdktf.TerraformMetaArguments):
    def __init__(
        self,
        *,
        count: typing.Optional[jsii.Number] = None,
        depends_on: typing.Optional[typing.List[cdktf.TerraformResource]] = None,
        lifecycle: typing.Optional[cdktf.TerraformResourceLifecycle] = None,
        provider: typing.Optional[cdktf.TerraformProvider] = None,
        evaluator_type: builtins.str,
        lab_name: builtins.str,
        name: builtins.str,
        policy_set_name: builtins.str,
        resource_group_name: builtins.str,
        threshold: builtins.str,
        description: typing.Optional[builtins.str] = None,
        fact_data: typing.Optional[builtins.str] = None,
        tags: typing.Optional[typing.Mapping[builtins.str, builtins.str]] = None,
        timeouts: typing.Optional["DevTestPolicyTimeouts"] = None,
    ) -> None:
        """
        :param count: 
        :param depends_on: 
        :param lifecycle: 
        :param provider: 
        :param evaluator_type: 
        :param lab_name: 
        :param name: 
        :param policy_set_name: 
        :param resource_group_name: 
        :param threshold: 
        :param description: 
        :param fact_data: 
        :param tags: 
        :param timeouts: timeouts block.
        """
        if isinstance(lifecycle, dict):
            lifecycle = cdktf.TerraformResourceLifecycle(**lifecycle)
        if isinstance(timeouts, dict):
            timeouts = DevTestPolicyTimeouts(**timeouts)
        self._values: typing.Dict[str, typing.Any] = {
            "evaluator_type": evaluator_type,
            "lab_name": lab_name,
            "name": name,
            "policy_set_name": policy_set_name,
            "resource_group_name": resource_group_name,
            "threshold": threshold,
        }
        if count is not None:
            self._values["count"] = count
        if depends_on is not None:
            self._values["depends_on"] = depends_on
        if lifecycle is not None:
            self._values["lifecycle"] = lifecycle
        if provider is not None:
            self._values["provider"] = provider
        if description is not None:
            self._values["description"] = description
        if fact_data is not None:
            self._values["fact_data"] = fact_data
        if tags is not None:
            self._values["tags"] = tags
        if timeouts is not None:
            self._values["timeouts"] = timeouts

    @builtins.property
    def count(self) -> typing.Optional[jsii.Number]:
        """
        :stability: experimental
        """
        result = self._values.get("count")
        return result

    @builtins.property
    def depends_on(self) -> typing.Optional[typing.List[cdktf.TerraformResource]]:
        """
        :stability: experimental
        """
        result = self._values.get("depends_on")
        return result

    @builtins.property
    def lifecycle(self) -> typing.Optional[cdktf.TerraformResourceLifecycle]:
        """
        :stability: experimental
        """
        result = self._values.get("lifecycle")
        return result

    @builtins.property
    def provider(self) -> typing.Optional[cdktf.TerraformProvider]:
        """
        :stability: experimental
        """
        result = self._values.get("provider")
        return result

    @builtins.property
    def evaluator_type(self) -> builtins.str:
        result = self._values.get("evaluator_type")
        assert result is not None, "Required property 'evaluator_type' is missing"
        return result

    @builtins.property
    def lab_name(self) -> builtins.str:
        result = self._values.get("lab_name")
        assert result is not None, "Required property 'lab_name' is missing"
        return result

    @builtins.property
    def name(self) -> builtins.str:
        result = self._values.get("name")
        assert result is not None, "Required property 'name' is missing"
        return result

    @builtins.property
    def policy_set_name(self) -> builtins.str:
        result = self._values.get("policy_set_name")
        assert result is not None, "Required property 'policy_set_name' is missing"
        return result

    @builtins.property
    def resource_group_name(self) -> builtins.str:
        result = self._values.get("resource_group_name")
        assert result is not None, "Required property 'resource_group_name' is missing"
        return result

    @builtins.property
    def threshold(self) -> builtins.str:
        result = self._values.get("threshold")
        assert result is not None, "Required property 'threshold' is missing"
        return result

    @builtins.property
    def description(self) -> typing.Optional[builtins.str]:
        result = self._values.get("description")
        return result

    @builtins.property
    def fact_data(self) -> typing.Optional[builtins.str]:
        result = self._values.get("fact_data")
        return result

    @builtins.property
    def tags(self) -> typing.Optional[typing.Mapping[builtins.str, builtins.str]]:
        result = self._values.get("tags")
        return result

    @builtins.property
    def timeouts(self) -> typing.Optional["DevTestPolicyTimeouts"]:
        """timeouts block."""
        result = self._values.get("timeouts")
        return result

    def __eq__(self, rhs: typing.Any) -> builtins.bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs: typing.Any) -> builtins.bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return "DevTestPolicyConfig(%s)" % ", ".join(
            k + "=" + repr(v) for k, v in self._values.items()
        )


@jsii.data_type(
    jsii_type="@cdktf/provider-azurerm.DevTestPolicyTimeouts",
    jsii_struct_bases=[],
    name_mapping={
        "create": "create",
        "delete": "delete",
        "read": "read",
        "update": "update",
    },
)
class DevTestPolicyTimeouts:
    def __init__(
        self,
        *,
        create: typing.Optional[builtins.str] = None,
        delete: typing.Optional[builtins.str] = None,
        read: typing.Optional[builtins.str] = None,
        update: typing.Optional[builtins.str] = None,
    ) -> None:
        """
        :param create: 
        :param delete: 
        :param read: 
        :param update: 
        """
        self._values: typing.Dict[str, typing.Any] = {}
        if create is not None:
            self._values["create"] = create
        if delete is not None:
            self._values["delete"] = delete
        if read is not None:
            self._values["read"] = read
        if update is not None:
            self._values["update"] = update

    @builtins.property
    def create(self) -> typing.Optional[builtins.str]:
        result = self._values.get("create")
        return result

    @builtins.property
    def delete(self) -> typing.Optional[builtins.str]:
        result = self._values.get("delete")
        return result

    @builtins.property
    def read(self) -> typing.Optional[builtins.str]:
        result = self._values.get("read")
        return result

    @builtins.property
    def update(self) -> typing.Optional[builtins.str]:
        result = self._values.get("update")
        return result

    def __eq__(self, rhs: typing.Any) -> builtins.bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs: typing.Any) -> builtins.bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return "DevTestPolicyTimeouts(%s)" % ", ".join(
            k + "=" + repr(v) for k, v in self._values.items()
        )


class DevTestSchedule(
    cdktf.TerraformResource,
    metaclass=jsii.JSIIMeta,
    jsii_type="@cdktf/provider-azurerm.DevTestSchedule",
):
    def __init__(
        self,
        scope: constructs.Construct,
        id: builtins.str,
        *,
        lab_name: builtins.str,
        location: builtins.str,
        name: builtins.str,
        notification_settings: typing.List["DevTestScheduleNotificationSettings"],
        resource_group_name: builtins.str,
        task_type: builtins.str,
        time_zone_id: builtins.str,
        daily_recurrence: typing.Optional[typing.List["DevTestScheduleDailyRecurrence"]] = None,
        hourly_recurrence: typing.Optional[typing.List["DevTestScheduleHourlyRecurrence"]] = None,
        status: typing.Optional[builtins.str] = None,
        tags: typing.Optional[typing.Mapping[builtins.str, builtins.str]] = None,
        timeouts: typing.Optional["DevTestScheduleTimeouts"] = None,
        weekly_recurrence: typing.Optional[typing.List["DevTestScheduleWeeklyRecurrence"]] = None,
        count: typing.Optional[jsii.Number] = None,
        depends_on: typing.Optional[typing.List[cdktf.TerraformResource]] = None,
        lifecycle: typing.Optional[cdktf.TerraformResourceLifecycle] = None,
        provider: typing.Optional[cdktf.TerraformProvider] = None,
    ) -> None:
        """
        :param scope: -
        :param id: -
        :param lab_name: 
        :param location: 
        :param name: 
        :param notification_settings: notification_settings block.
        :param resource_group_name: 
        :param task_type: 
        :param time_zone_id: 
        :param daily_recurrence: daily_recurrence block.
        :param hourly_recurrence: hourly_recurrence block.
        :param status: 
        :param tags: 
        :param timeouts: timeouts block.
        :param weekly_recurrence: weekly_recurrence block.
        :param count: 
        :param depends_on: 
        :param lifecycle: 
        :param provider: 
        """
        config = DevTestScheduleConfig(
            lab_name=lab_name,
            location=location,
            name=name,
            notification_settings=notification_settings,
            resource_group_name=resource_group_name,
            task_type=task_type,
            time_zone_id=time_zone_id,
            daily_recurrence=daily_recurrence,
            hourly_recurrence=hourly_recurrence,
            status=status,
            tags=tags,
            timeouts=timeouts,
            weekly_recurrence=weekly_recurrence,
            count=count,
            depends_on=depends_on,
            lifecycle=lifecycle,
            provider=provider,
        )

        jsii.create(DevTestSchedule, self, [scope, id, config])

    @jsii.member(jsii_name="synthesizeAttributes")
    def _synthesize_attributes(self) -> typing.Mapping[builtins.str, typing.Any]:
        return jsii.invoke(self, "synthesizeAttributes", [])

    @builtins.property # type: ignore
    @jsii.member(jsii_name="labName")
    def lab_name(self) -> builtins.str:
        return jsii.get(self, "labName")

    @lab_name.setter # type: ignore
    def lab_name(self, value: builtins.str) -> None:
        jsii.set(self, "labName", value)

    @builtins.property # type: ignore
    @jsii.member(jsii_name="location")
    def location(self) -> builtins.str:
        return jsii.get(self, "location")

    @location.setter # type: ignore
    def location(self, value: builtins.str) -> None:
        jsii.set(self, "location", value)

    @builtins.property # type: ignore
    @jsii.member(jsii_name="name")
    def name(self) -> builtins.str:
        return jsii.get(self, "name")

    @name.setter # type: ignore
    def name(self, value: builtins.str) -> None:
        jsii.set(self, "name", value)

    @builtins.property # type: ignore
    @jsii.member(jsii_name="notificationSettings")
    def notification_settings(
        self,
    ) -> typing.List["DevTestScheduleNotificationSettings"]:
        return jsii.get(self, "notificationSettings")

    @notification_settings.setter # type: ignore
    def notification_settings(
        self,
        value: typing.List["DevTestScheduleNotificationSettings"],
    ) -> None:
        jsii.set(self, "notificationSettings", value)

    @builtins.property # type: ignore
    @jsii.member(jsii_name="resourceGroupName")
    def resource_group_name(self) -> builtins.str:
        return jsii.get(self, "resourceGroupName")

    @resource_group_name.setter # type: ignore
    def resource_group_name(self, value: builtins.str) -> None:
        jsii.set(self, "resourceGroupName", value)

    @builtins.property # type: ignore
    @jsii.member(jsii_name="taskType")
    def task_type(self) -> builtins.str:
        return jsii.get(self, "taskType")

    @task_type.setter # type: ignore
    def task_type(self, value: builtins.str) -> None:
        jsii.set(self, "taskType", value)

    @builtins.property # type: ignore
    @jsii.member(jsii_name="timeZoneId")
    def time_zone_id(self) -> builtins.str:
        return jsii.get(self, "timeZoneId")

    @time_zone_id.setter # type: ignore
    def time_zone_id(self, value: builtins.str) -> None:
        jsii.set(self, "timeZoneId", value)

    @builtins.property # type: ignore
    @jsii.member(jsii_name="dailyRecurrence")
    def daily_recurrence(
        self,
    ) -> typing.Optional[typing.List["DevTestScheduleDailyRecurrence"]]:
        return jsii.get(self, "dailyRecurrence")

    @daily_recurrence.setter # type: ignore
    def daily_recurrence(
        self,
        value: typing.Optional[typing.List["DevTestScheduleDailyRecurrence"]],
    ) -> None:
        jsii.set(self, "dailyRecurrence", value)

    @builtins.property # type: ignore
    @jsii.member(jsii_name="hourlyRecurrence")
    def hourly_recurrence(
        self,
    ) -> typing.Optional[typing.List["DevTestScheduleHourlyRecurrence"]]:
        return jsii.get(self, "hourlyRecurrence")

    @hourly_recurrence.setter # type: ignore
    def hourly_recurrence(
        self,
        value: typing.Optional[typing.List["DevTestScheduleHourlyRecurrence"]],
    ) -> None:
        jsii.set(self, "hourlyRecurrence", value)

    @builtins.property # type: ignore
    @jsii.member(jsii_name="id")
    def id(self) -> typing.Optional[builtins.str]:
        return jsii.get(self, "id")

    @id.setter # type: ignore
    def id(self, value: typing.Optional[builtins.str]) -> None:
        jsii.set(self, "id", value)

    @builtins.property # type: ignore
    @jsii.member(jsii_name="status")
    def status(self) -> typing.Optional[builtins.str]:
        return jsii.get(self, "status")

    @status.setter # type: ignore
    def status(self, value: typing.Optional[builtins.str]) -> None:
        jsii.set(self, "status", value)

    @builtins.property # type: ignore
    @jsii.member(jsii_name="tags")
    def tags(self) -> typing.Optional[typing.Mapping[builtins.str, builtins.str]]:
        return jsii.get(self, "tags")

    @tags.setter # type: ignore
    def tags(
        self,
        value: typing.Optional[typing.Mapping[builtins.str, builtins.str]],
    ) -> None:
        jsii.set(self, "tags", value)

    @builtins.property # type: ignore
    @jsii.member(jsii_name="timeouts")
    def timeouts(self) -> typing.Optional["DevTestScheduleTimeouts"]:
        return jsii.get(self, "timeouts")

    @timeouts.setter # type: ignore
    def timeouts(self, value: typing.Optional["DevTestScheduleTimeouts"]) -> None:
        jsii.set(self, "timeouts", value)

    @builtins.property # type: ignore
    @jsii.member(jsii_name="weeklyRecurrence")
    def weekly_recurrence(
        self,
    ) -> typing.Optional[typing.List["DevTestScheduleWeeklyRecurrence"]]:
        return jsii.get(self, "weeklyRecurrence")

    @weekly_recurrence.setter # type: ignore
    def weekly_recurrence(
        self,
        value: typing.Optional[typing.List["DevTestScheduleWeeklyRecurrence"]],
    ) -> None:
        jsii.set(self, "weeklyRecurrence", value)


@jsii.data_type(
    jsii_type="@cdktf/provider-azurerm.DevTestScheduleConfig",
    jsii_struct_bases=[cdktf.TerraformMetaArguments],
    name_mapping={
        "count": "count",
        "depends_on": "dependsOn",
        "lifecycle": "lifecycle",
        "provider": "provider",
        "lab_name": "labName",
        "location": "location",
        "name": "name",
        "notification_settings": "notificationSettings",
        "resource_group_name": "resourceGroupName",
        "task_type": "taskType",
        "time_zone_id": "timeZoneId",
        "daily_recurrence": "dailyRecurrence",
        "hourly_recurrence": "hourlyRecurrence",
        "status": "status",
        "tags": "tags",
        "timeouts": "timeouts",
        "weekly_recurrence": "weeklyRecurrence",
    },
)
class DevTestScheduleConfig(cdktf.TerraformMetaArguments):
    def __init__(
        self,
        *,
        count: typing.Optional[jsii.Number] = None,
        depends_on: typing.Optional[typing.List[cdktf.TerraformResource]] = None,
        lifecycle: typing.Optional[cdktf.TerraformResourceLifecycle] = None,
        provider: typing.Optional[cdktf.TerraformProvider] = None,
        lab_name: builtins.str,
        location: builtins.str,
        name: builtins.str,
        notification_settings: typing.List["DevTestScheduleNotificationSettings"],
        resource_group_name: builtins.str,
        task_type: builtins.str,
        time_zone_id: builtins.str,
        daily_recurrence: typing.Optional[typing.List["DevTestScheduleDailyRecurrence"]] = None,
        hourly_recurrence: typing.Optional[typing.List["DevTestScheduleHourlyRecurrence"]] = None,
        status: typing.Optional[builtins.str] = None,
        tags: typing.Optional[typing.Mapping[builtins.str, builtins.str]] = None,
        timeouts: typing.Optional["DevTestScheduleTimeouts"] = None,
        weekly_recurrence: typing.Optional[typing.List["DevTestScheduleWeeklyRecurrence"]] = None,
    ) -> None:
        """
        :param count: 
        :param depends_on: 
        :param lifecycle: 
        :param provider: 
        :param lab_name: 
        :param location: 
        :param name: 
        :param notification_settings: notification_settings block.
        :param resource_group_name: 
        :param task_type: 
        :param time_zone_id: 
        :param daily_recurrence: daily_recurrence block.
        :param hourly_recurrence: hourly_recurrence block.
        :param status: 
        :param tags: 
        :param timeouts: timeouts block.
        :param weekly_recurrence: weekly_recurrence block.
        """
        if isinstance(lifecycle, dict):
            lifecycle = cdktf.TerraformResourceLifecycle(**lifecycle)
        if isinstance(timeouts, dict):
            timeouts = DevTestScheduleTimeouts(**timeouts)
        self._values: typing.Dict[str, typing.Any] = {
            "lab_name": lab_name,
            "location": location,
            "name": name,
            "notification_settings": notification_settings,
            "resource_group_name": resource_group_name,
            "task_type": task_type,
            "time_zone_id": time_zone_id,
        }
        if count is not None:
            self._values["count"] = count
        if depends_on is not None:
            self._values["depends_on"] = depends_on
        if lifecycle is not None:
            self._values["lifecycle"] = lifecycle
        if provider is not None:
            self._values["provider"] = provider
        if daily_recurrence is not None:
            self._values["daily_recurrence"] = daily_recurrence
        if hourly_recurrence is not None:
            self._values["hourly_recurrence"] = hourly_recurrence
        if status is not None:
            self._values["status"] = status
        if tags is not None:
            self._values["tags"] = tags
        if timeouts is not None:
            self._values["timeouts"] = timeouts
        if weekly_recurrence is not None:
            self._values["weekly_recurrence"] = weekly_recurrence

    @builtins.property
    def count(self) -> typing.Optional[jsii.Number]:
        """
        :stability: experimental
        """
        result = self._values.get("count")
        return result

    @builtins.property
    def depends_on(self) -> typing.Optional[typing.List[cdktf.TerraformResource]]:
        """
        :stability: experimental
        """
        result = self._values.get("depends_on")
        return result

    @builtins.property
    def lifecycle(self) -> typing.Optional[cdktf.TerraformResourceLifecycle]:
        """
        :stability: experimental
        """
        result = self._values.get("lifecycle")
        return result

    @builtins.property
    def provider(self) -> typing.Optional[cdktf.TerraformProvider]:
        """
        :stability: experimental
        """
        result = self._values.get("provider")
        return result

    @builtins.property
    def lab_name(self) -> builtins.str:
        result = self._values.get("lab_name")
        assert result is not None, "Required property 'lab_name' is missing"
        return result

    @builtins.property
    def location(self) -> builtins.str:
        result = self._values.get("location")
        assert result is not None, "Required property 'location' is missing"
        return result

    @builtins.property
    def name(self) -> builtins.str:
        result = self._values.get("name")
        assert result is not None, "Required property 'name' is missing"
        return result

    @builtins.property
    def notification_settings(
        self,
    ) -> typing.List["DevTestScheduleNotificationSettings"]:
        """notification_settings block."""
        result = self._values.get("notification_settings")
        assert result is not None, "Required property 'notification_settings' is missing"
        return result

    @builtins.property
    def resource_group_name(self) -> builtins.str:
        result = self._values.get("resource_group_name")
        assert result is not None, "Required property 'resource_group_name' is missing"
        return result

    @builtins.property
    def task_type(self) -> builtins.str:
        result = self._values.get("task_type")
        assert result is not None, "Required property 'task_type' is missing"
        return result

    @builtins.property
    def time_zone_id(self) -> builtins.str:
        result = self._values.get("time_zone_id")
        assert result is not None, "Required property 'time_zone_id' is missing"
        return result

    @builtins.property
    def daily_recurrence(
        self,
    ) -> typing.Optional[typing.List["DevTestScheduleDailyRecurrence"]]:
        """daily_recurrence block."""
        result = self._values.get("daily_recurrence")
        return result

    @builtins.property
    def hourly_recurrence(
        self,
    ) -> typing.Optional[typing.List["DevTestScheduleHourlyRecurrence"]]:
        """hourly_recurrence block."""
        result = self._values.get("hourly_recurrence")
        return result

    @builtins.property
    def status(self) -> typing.Optional[builtins.str]:
        result = self._values.get("status")
        return result

    @builtins.property
    def tags(self) -> typing.Optional[typing.Mapping[builtins.str, builtins.str]]:
        result = self._values.get("tags")
        return result

    @builtins.property
    def timeouts(self) -> typing.Optional["DevTestScheduleTimeouts"]:
        """timeouts block."""
        result = self._values.get("timeouts")
        return result

    @builtins.property
    def weekly_recurrence(
        self,
    ) -> typing.Optional[typing.List["DevTestScheduleWeeklyRecurrence"]]:
        """weekly_recurrence block."""
        result = self._values.get("weekly_recurrence")
        return result

    def __eq__(self, rhs: typing.Any) -> builtins.bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs: typing.Any) -> builtins.bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return "DevTestScheduleConfig(%s)" % ", ".join(
            k + "=" + repr(v) for k, v in self._values.items()
        )


@jsii.data_type(
    jsii_type="@cdktf/provider-azurerm.DevTestScheduleDailyRecurrence",
    jsii_struct_bases=[],
    name_mapping={"time": "time"},
)
class DevTestScheduleDailyRecurrence:
    def __init__(self, *, time: builtins.str) -> None:
        """
        :param time: 
        """
        self._values: typing.Dict[str, typing.Any] = {
            "time": time,
        }

    @builtins.property
    def time(self) -> builtins.str:
        result = self._values.get("time")
        assert result is not None, "Required property 'time' is missing"
        return result

    def __eq__(self, rhs: typing.Any) -> builtins.bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs: typing.Any) -> builtins.bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return "DevTestScheduleDailyRecurrence(%s)" % ", ".join(
            k + "=" + repr(v) for k, v in self._values.items()
        )


@jsii.data_type(
    jsii_type="@cdktf/provider-azurerm.DevTestScheduleHourlyRecurrence",
    jsii_struct_bases=[],
    name_mapping={"minute": "minute"},
)
class DevTestScheduleHourlyRecurrence:
    def __init__(self, *, minute: jsii.Number) -> None:
        """
        :param minute: 
        """
        self._values: typing.Dict[str, typing.Any] = {
            "minute": minute,
        }

    @builtins.property
    def minute(self) -> jsii.Number:
        result = self._values.get("minute")
        assert result is not None, "Required property 'minute' is missing"
        return result

    def __eq__(self, rhs: typing.Any) -> builtins.bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs: typing.Any) -> builtins.bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return "DevTestScheduleHourlyRecurrence(%s)" % ", ".join(
            k + "=" + repr(v) for k, v in self._values.items()
        )


@jsii.data_type(
    jsii_type="@cdktf/provider-azurerm.DevTestScheduleNotificationSettings",
    jsii_struct_bases=[],
    name_mapping={
        "status": "status",
        "time_in_minutes": "timeInMinutes",
        "webhook_url": "webhookUrl",
    },
)
class DevTestScheduleNotificationSettings:
    def __init__(
        self,
        *,
        status: typing.Optional[builtins.str] = None,
        time_in_minutes: typing.Optional[jsii.Number] = None,
        webhook_url: typing.Optional[builtins.str] = None,
    ) -> None:
        """
        :param status: 
        :param time_in_minutes: 
        :param webhook_url: 
        """
        self._values: typing.Dict[str, typing.Any] = {}
        if status is not None:
            self._values["status"] = status
        if time_in_minutes is not None:
            self._values["time_in_minutes"] = time_in_minutes
        if webhook_url is not None:
            self._values["webhook_url"] = webhook_url

    @builtins.property
    def status(self) -> typing.Optional[builtins.str]:
        result = self._values.get("status")
        return result

    @builtins.property
    def time_in_minutes(self) -> typing.Optional[jsii.Number]:
        result = self._values.get("time_in_minutes")
        return result

    @builtins.property
    def webhook_url(self) -> typing.Optional[builtins.str]:
        result = self._values.get("webhook_url")
        return result

    def __eq__(self, rhs: typing.Any) -> builtins.bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs: typing.Any) -> builtins.bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return "DevTestScheduleNotificationSettings(%s)" % ", ".join(
            k + "=" + repr(v) for k, v in self._values.items()
        )


@jsii.data_type(
    jsii_type="@cdktf/provider-azurerm.DevTestScheduleTimeouts",
    jsii_struct_bases=[],
    name_mapping={
        "create": "create",
        "delete": "delete",
        "read": "read",
        "update": "update",
    },
)
class DevTestScheduleTimeouts:
    def __init__(
        self,
        *,
        create: typing.Optional[builtins.str] = None,
        delete: typing.Optional[builtins.str] = None,
        read: typing.Optional[builtins.str] = None,
        update: typing.Optional[builtins.str] = None,
    ) -> None:
        """
        :param create: 
        :param delete: 
        :param read: 
        :param update: 
        """
        self._values: typing.Dict[str, typing.Any] = {}
        if create is not None:
            self._values["create"] = create
        if delete is not None:
            self._values["delete"] = delete
        if read is not None:
            self._values["read"] = read
        if update is not None:
            self._values["update"] = update

    @builtins.property
    def create(self) -> typing.Optional[builtins.str]:
        result = self._values.get("create")
        return result

    @builtins.property
    def delete(self) -> typing.Optional[builtins.str]:
        result = self._values.get("delete")
        return result

    @builtins.property
    def read(self) -> typing.Optional[builtins.str]:
        result = self._values.get("read")
        return result

    @builtins.property
    def update(self) -> typing.Optional[builtins.str]:
        result = self._values.get("update")
        return result

    def __eq__(self, rhs: typing.Any) -> builtins.bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs: typing.Any) -> builtins.bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return "DevTestScheduleTimeouts(%s)" % ", ".join(
            k + "=" + repr(v) for k, v in self._values.items()
        )


@jsii.data_type(
    jsii_type="@cdktf/provider-azurerm.DevTestScheduleWeeklyRecurrence",
    jsii_struct_bases=[],
    name_mapping={"time": "time", "week_days": "weekDays"},
)
class DevTestScheduleWeeklyRecurrence:
    def __init__(
        self,
        *,
        time: builtins.str,
        week_days: typing.Optional[typing.List[builtins.str]] = None,
    ) -> None:
        """
        :param time: 
        :param week_days: 
        """
        self._values: typing.Dict[str, typing.Any] = {
            "time": time,
        }
        if week_days is not None:
            self._values["week_days"] = week_days

    @builtins.property
    def time(self) -> builtins.str:
        result = self._values.get("time")
        assert result is not None, "Required property 'time' is missing"
        return result

    @builtins.property
    def week_days(self) -> typing.Optional[typing.List[builtins.str]]:
        result = self._values.get("week_days")
        return result

    def __eq__(self, rhs: typing.Any) -> builtins.bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs: typing.Any) -> builtins.bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return "DevTestScheduleWeeklyRecurrence(%s)" % ", ".join(
            k + "=" + repr(v) for k, v in self._values.items()
        )


class DevTestVirtualNetwork(
    cdktf.TerraformResource,
    metaclass=jsii.JSIIMeta,
    jsii_type="@cdktf/provider-azurerm.DevTestVirtualNetwork",
):
    def __init__(
        self,
        scope: constructs.Construct,
        id: builtins.str,
        *,
        lab_name: builtins.str,
        name: builtins.str,
        resource_group_name: builtins.str,
        description: typing.Optional[builtins.str] = None,
        subnet: typing.Optional[typing.List["DevTestVirtualNetworkSubnet"]] = None,
        tags: typing.Optional[typing.Mapping[builtins.str, builtins.str]] = None,
        timeouts: typing.Optional["DevTestVirtualNetworkTimeouts"] = None,
        count: typing.Optional[jsii.Number] = None,
        depends_on: typing.Optional[typing.List[cdktf.TerraformResource]] = None,
        lifecycle: typing.Optional[cdktf.TerraformResourceLifecycle] = None,
        provider: typing.Optional[cdktf.TerraformProvider] = None,
    ) -> None:
        """
        :param scope: -
        :param id: -
        :param lab_name: 
        :param name: 
        :param resource_group_name: 
        :param description: 
        :param subnet: subnet block.
        :param tags: 
        :param timeouts: timeouts block.
        :param count: 
        :param depends_on: 
        :param lifecycle: 
        :param provider: 
        """
        config = DevTestVirtualNetworkConfig(
            lab_name=lab_name,
            name=name,
            resource_group_name=resource_group_name,
            description=description,
            subnet=subnet,
            tags=tags,
            timeouts=timeouts,
            count=count,
            depends_on=depends_on,
            lifecycle=lifecycle,
            provider=provider,
        )

        jsii.create(DevTestVirtualNetwork, self, [scope, id, config])

    @jsii.member(jsii_name="synthesizeAttributes")
    def _synthesize_attributes(self) -> typing.Mapping[builtins.str, typing.Any]:
        return jsii.invoke(self, "synthesizeAttributes", [])

    @builtins.property # type: ignore
    @jsii.member(jsii_name="uniqueIdentifier")
    def unique_identifier(self) -> builtins.str:
        return jsii.get(self, "uniqueIdentifier")

    @builtins.property # type: ignore
    @jsii.member(jsii_name="labName")
    def lab_name(self) -> builtins.str:
        return jsii.get(self, "labName")

    @lab_name.setter # type: ignore
    def lab_name(self, value: builtins.str) -> None:
        jsii.set(self, "labName", value)

    @builtins.property # type: ignore
    @jsii.member(jsii_name="name")
    def name(self) -> builtins.str:
        return jsii.get(self, "name")

    @name.setter # type: ignore
    def name(self, value: builtins.str) -> None:
        jsii.set(self, "name", value)

    @builtins.property # type: ignore
    @jsii.member(jsii_name="resourceGroupName")
    def resource_group_name(self) -> builtins.str:
        return jsii.get(self, "resourceGroupName")

    @resource_group_name.setter # type: ignore
    def resource_group_name(self, value: builtins.str) -> None:
        jsii.set(self, "resourceGroupName", value)

    @builtins.property # type: ignore
    @jsii.member(jsii_name="description")
    def description(self) -> typing.Optional[builtins.str]:
        return jsii.get(self, "description")

    @description.setter # type: ignore
    def description(self, value: typing.Optional[builtins.str]) -> None:
        jsii.set(self, "description", value)

    @builtins.property # type: ignore
    @jsii.member(jsii_name="id")
    def id(self) -> typing.Optional[builtins.str]:
        return jsii.get(self, "id")

    @id.setter # type: ignore
    def id(self, value: typing.Optional[builtins.str]) -> None:
        jsii.set(self, "id", value)

    @builtins.property # type: ignore
    @jsii.member(jsii_name="subnet")
    def subnet(self) -> typing.Optional[typing.List["DevTestVirtualNetworkSubnet"]]:
        return jsii.get(self, "subnet")

    @subnet.setter # type: ignore
    def subnet(
        self,
        value: typing.Optional[typing.List["DevTestVirtualNetworkSubnet"]],
    ) -> None:
        jsii.set(self, "subnet", value)

    @builtins.property # type: ignore
    @jsii.member(jsii_name="tags")
    def tags(self) -> typing.Optional[typing.Mapping[builtins.str, builtins.str]]:
        return jsii.get(self, "tags")

    @tags.setter # type: ignore
    def tags(
        self,
        value: typing.Optional[typing.Mapping[builtins.str, builtins.str]],
    ) -> None:
        jsii.set(self, "tags", value)

    @builtins.property # type: ignore
    @jsii.member(jsii_name="timeouts")
    def timeouts(self) -> typing.Optional["DevTestVirtualNetworkTimeouts"]:
        return jsii.get(self, "timeouts")

    @timeouts.setter # type: ignore
    def timeouts(self, value: typing.Optional["DevTestVirtualNetworkTimeouts"]) -> None:
        jsii.set(self, "timeouts", value)


@jsii.data_type(
    jsii_type="@cdktf/provider-azurerm.DevTestVirtualNetworkConfig",
    jsii_struct_bases=[cdktf.TerraformMetaArguments],
    name_mapping={
        "count": "count",
        "depends_on": "dependsOn",
        "lifecycle": "lifecycle",
        "provider": "provider",
        "lab_name": "labName",
        "name": "name",
        "resource_group_name": "resourceGroupName",
        "description": "description",
        "subnet": "subnet",
        "tags": "tags",
        "timeouts": "timeouts",
    },
)
class DevTestVirtualNetworkConfig(cdktf.TerraformMetaArguments):
    def __init__(
        self,
        *,
        count: typing.Optional[jsii.Number] = None,
        depends_on: typing.Optional[typing.List[cdktf.TerraformResource]] = None,
        lifecycle: typing.Optional[cdktf.TerraformResourceLifecycle] = None,
        provider: typing.Optional[cdktf.TerraformProvider] = None,
        lab_name: builtins.str,
        name: builtins.str,
        resource_group_name: builtins.str,
        description: typing.Optional[builtins.str] = None,
        subnet: typing.Optional[typing.List["DevTestVirtualNetworkSubnet"]] = None,
        tags: typing.Optional[typing.Mapping[builtins.str, builtins.str]] = None,
        timeouts: typing.Optional["DevTestVirtualNetworkTimeouts"] = None,
    ) -> None:
        """
        :param count: 
        :param depends_on: 
        :param lifecycle: 
        :param provider: 
        :param lab_name: 
        :param name: 
        :param resource_group_name: 
        :param description: 
        :param subnet: subnet block.
        :param tags: 
        :param timeouts: timeouts block.
        """
        if isinstance(lifecycle, dict):
            lifecycle = cdktf.TerraformResourceLifecycle(**lifecycle)
        if isinstance(timeouts, dict):
            timeouts = DevTestVirtualNetworkTimeouts(**timeouts)
        self._values: typing.Dict[str, typing.Any] = {
            "lab_name": lab_name,
            "name": name,
            "resource_group_name": resource_group_name,
        }
        if count is not None:
            self._values["count"] = count
        if depends_on is not None:
            self._values["depends_on"] = depends_on
        if lifecycle is not None:
            self._values["lifecycle"] = lifecycle
        if provider is not None:
            self._values["provider"] = provider
        if description is not None:
            self._values["description"] = description
        if subnet is not None:
            self._values["subnet"] = subnet
        if tags is not None:
            self._values["tags"] = tags
        if timeouts is not None:
            self._values["timeouts"] = timeouts

    @builtins.property
    def count(self) -> typing.Optional[jsii.Number]:
        """
        :stability: experimental
        """
        result = self._values.get("count")
        return result

    @builtins.property
    def depends_on(self) -> typing.Optional[typing.List[cdktf.TerraformResource]]:
        """
        :stability: experimental
        """
        result = self._values.get("depends_on")
        return result

    @builtins.property
    def lifecycle(self) -> typing.Optional[cdktf.TerraformResourceLifecycle]:
        """
        :stability: experimental
        """
        result = self._values.get("lifecycle")
        return result

    @builtins.property
    def provider(self) -> typing.Optional[cdktf.TerraformProvider]:
        """
        :stability: experimental
        """
        result = self._values.get("provider")
        return result

    @builtins.property
    def lab_name(self) -> builtins.str:
        result = self._values.get("lab_name")
        assert result is not None, "Required property 'lab_name' is missing"
        return result

    @builtins.property
    def name(self) -> builtins.str:
        result = self._values.get("name")
        assert result is not None, "Required property 'name' is missing"
        return result

    @builtins.property
    def resource_group_name(self) -> builtins.str:
        result = self._values.get("resource_group_name")
        assert result is not None, "Required property 'resource_group_name' is missing"
        return result

    @builtins.property
    def description(self) -> typing.Optional[builtins.str]:
        result = self._values.get("description")
        return result

    @builtins.property
    def subnet(self) -> typing.Optional[typing.List["DevTestVirtualNetworkSubnet"]]:
        """subnet block."""
        result = self._values.get("subnet")
        return result

    @builtins.property
    def tags(self) -> typing.Optional[typing.Mapping[builtins.str, builtins.str]]:
        result = self._values.get("tags")
        return result

    @builtins.property
    def timeouts(self) -> typing.Optional["DevTestVirtualNetworkTimeouts"]:
        """timeouts block."""
        result = self._values.get("timeouts")
        return result

    def __eq__(self, rhs: typing.Any) -> builtins.bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs: typing.Any) -> builtins.bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return "DevTestVirtualNetworkConfig(%s)" % ", ".join(
            k + "=" + repr(v) for k, v in self._values.items()
        )


@jsii.data_type(
    jsii_type="@cdktf/provider-azurerm.DevTestVirtualNetworkSubnet",
    jsii_struct_bases=[],
    name_mapping={
        "use_in_virtual_machine_creation": "useInVirtualMachineCreation",
        "use_public_ip_address": "usePublicIpAddress",
    },
)
class DevTestVirtualNetworkSubnet:
    def __init__(
        self,
        *,
        use_in_virtual_machine_creation: typing.Optional[builtins.str] = None,
        use_public_ip_address: typing.Optional[builtins.str] = None,
    ) -> None:
        """
        :param use_in_virtual_machine_creation: 
        :param use_public_ip_address: 
        """
        self._values: typing.Dict[str, typing.Any] = {}
        if use_in_virtual_machine_creation is not None:
            self._values["use_in_virtual_machine_creation"] = use_in_virtual_machine_creation
        if use_public_ip_address is not None:
            self._values["use_public_ip_address"] = use_public_ip_address

    @builtins.property
    def use_in_virtual_machine_creation(self) -> typing.Optional[builtins.str]:
        result = self._values.get("use_in_virtual_machine_creation")
        return result

    @builtins.property
    def use_public_ip_address(self) -> typing.Optional[builtins.str]:
        result = self._values.get("use_public_ip_address")
        return result

    def __eq__(self, rhs: typing.Any) -> builtins.bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs: typing.Any) -> builtins.bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return "DevTestVirtualNetworkSubnet(%s)" % ", ".join(
            k + "=" + repr(v) for k, v in self._values.items()
        )


@jsii.data_type(
    jsii_type="@cdktf/provider-azurerm.DevTestVirtualNetworkTimeouts",
    jsii_struct_bases=[],
    name_mapping={
        "create": "create",
        "delete": "delete",
        "read": "read",
        "update": "update",
    },
)
class DevTestVirtualNetworkTimeouts:
    def __init__(
        self,
        *,
        create: typing.Optional[builtins.str] = None,
        delete: typing.Optional[builtins.str] = None,
        read: typing.Optional[builtins.str] = None,
        update: typing.Optional[builtins.str] = None,
    ) -> None:
        """
        :param create: 
        :param delete: 
        :param read: 
        :param update: 
        """
        self._values: typing.Dict[str, typing.Any] = {}
        if create is not None:
            self._values["create"] = create
        if delete is not None:
            self._values["delete"] = delete
        if read is not None:
            self._values["read"] = read
        if update is not None:
            self._values["update"] = update

    @builtins.property
    def create(self) -> typing.Optional[builtins.str]:
        result = self._values.get("create")
        return result

    @builtins.property
    def delete(self) -> typing.Optional[builtins.str]:
        result = self._values.get("delete")
        return result

    @builtins.property
    def read(self) -> typing.Optional[builtins.str]:
        result = self._values.get("read")
        return result

    @builtins.property
    def update(self) -> typing.Optional[builtins.str]:
        result = self._values.get("update")
        return result

    def __eq__(self, rhs: typing.Any) -> builtins.bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs: typing.Any) -> builtins.bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return "DevTestVirtualNetworkTimeouts(%s)" % ", ".join(
            k + "=" + repr(v) for k, v in self._values.items()
        )


class DevTestWindowsVirtualMachine(
    cdktf.TerraformResource,
    metaclass=jsii.JSIIMeta,
    jsii_type="@cdktf/provider-azurerm.DevTestWindowsVirtualMachine",
):
    def __init__(
        self,
        scope: constructs.Construct,
        id: builtins.str,
        *,
        gallery_image_reference: typing.List["DevTestWindowsVirtualMachineGalleryImageReference"],
        lab_name: builtins.str,
        lab_subnet_name: builtins.str,
        lab_virtual_network_id: builtins.str,
        location: builtins.str,
        name: builtins.str,
        password: builtins.str,
        resource_group_name: builtins.str,
        size: builtins.str,
        storage_type: builtins.str,
        username: builtins.str,
        allow_claim: typing.Optional[builtins.bool] = None,
        disallow_public_ip_address: typing.Optional[builtins.bool] = None,
        inbound_nat_rule: typing.Optional[typing.List["DevTestWindowsVirtualMachineInboundNatRule"]] = None,
        notes: typing.Optional[builtins.str] = None,
        tags: typing.Optional[typing.Mapping[builtins.str, builtins.str]] = None,
        timeouts: typing.Optional["DevTestWindowsVirtualMachineTimeouts"] = None,
        count: typing.Optional[jsii.Number] = None,
        depends_on: typing.Optional[typing.List[cdktf.TerraformResource]] = None,
        lifecycle: typing.Optional[cdktf.TerraformResourceLifecycle] = None,
        provider: typing.Optional[cdktf.TerraformProvider] = None,
    ) -> None:
        """
        :param scope: -
        :param id: -
        :param gallery_image_reference: gallery_image_reference block.
        :param lab_name: 
        :param lab_subnet_name: 
        :param lab_virtual_network_id: 
        :param location: 
        :param name: 
        :param password: 
        :param resource_group_name: 
        :param size: 
        :param storage_type: 
        :param username: 
        :param allow_claim: 
        :param disallow_public_ip_address: 
        :param inbound_nat_rule: inbound_nat_rule block.
        :param notes: 
        :param tags: 
        :param timeouts: timeouts block.
        :param count: 
        :param depends_on: 
        :param lifecycle: 
        :param provider: 
        """
        config = DevTestWindowsVirtualMachineConfig(
            gallery_image_reference=gallery_image_reference,
            lab_name=lab_name,
            lab_subnet_name=lab_subnet_name,
            lab_virtual_network_id=lab_virtual_network_id,
            location=location,
            name=name,
            password=password,
            resource_group_name=resource_group_name,
            size=size,
            storage_type=storage_type,
            username=username,
            allow_claim=allow_claim,
            disallow_public_ip_address=disallow_public_ip_address,
            inbound_nat_rule=inbound_nat_rule,
            notes=notes,
            tags=tags,
            timeouts=timeouts,
            count=count,
            depends_on=depends_on,
            lifecycle=lifecycle,
            provider=provider,
        )

        jsii.create(DevTestWindowsVirtualMachine, self, [scope, id, config])

    @jsii.member(jsii_name="synthesizeAttributes")
    def _synthesize_attributes(self) -> typing.Mapping[builtins.str, typing.Any]:
        return jsii.invoke(self, "synthesizeAttributes", [])

    @builtins.property # type: ignore
    @jsii.member(jsii_name="fqdn")
    def fqdn(self) -> builtins.str:
        return jsii.get(self, "fqdn")

    @builtins.property # type: ignore
    @jsii.member(jsii_name="uniqueIdentifier")
    def unique_identifier(self) -> builtins.str:
        return jsii.get(self, "uniqueIdentifier")

    @builtins.property # type: ignore
    @jsii.member(jsii_name="galleryImageReference")
    def gallery_image_reference(
        self,
    ) -> typing.List["DevTestWindowsVirtualMachineGalleryImageReference"]:
        return jsii.get(self, "galleryImageReference")

    @gallery_image_reference.setter # type: ignore
    def gallery_image_reference(
        self,
        value: typing.List["DevTestWindowsVirtualMachineGalleryImageReference"],
    ) -> None:
        jsii.set(self, "galleryImageReference", value)

    @builtins.property # type: ignore
    @jsii.member(jsii_name="labName")
    def lab_name(self) -> builtins.str:
        return jsii.get(self, "labName")

    @lab_name.setter # type: ignore
    def lab_name(self, value: builtins.str) -> None:
        jsii.set(self, "labName", value)

    @builtins.property # type: ignore
    @jsii.member(jsii_name="labSubnetName")
    def lab_subnet_name(self) -> builtins.str:
        return jsii.get(self, "labSubnetName")

    @lab_subnet_name.setter # type: ignore
    def lab_subnet_name(self, value: builtins.str) -> None:
        jsii.set(self, "labSubnetName", value)

    @builtins.property # type: ignore
    @jsii.member(jsii_name="labVirtualNetworkId")
    def lab_virtual_network_id(self) -> builtins.str:
        return jsii.get(self, "labVirtualNetworkId")

    @lab_virtual_network_id.setter # type: ignore
    def lab_virtual_network_id(self, value: builtins.str) -> None:
        jsii.set(self, "labVirtualNetworkId", value)

    @builtins.property # type: ignore
    @jsii.member(jsii_name="location")
    def location(self) -> builtins.str:
        return jsii.get(self, "location")

    @location.setter # type: ignore
    def location(self, value: builtins.str) -> None:
        jsii.set(self, "location", value)

    @builtins.property # type: ignore
    @jsii.member(jsii_name="name")
    def name(self) -> builtins.str:
        return jsii.get(self, "name")

    @name.setter # type: ignore
    def name(self, value: builtins.str) -> None:
        jsii.set(self, "name", value)

    @builtins.property # type: ignore
    @jsii.member(jsii_name="password")
    def password(self) -> builtins.str:
        return jsii.get(self, "password")

    @password.setter # type: ignore
    def password(self, value: builtins.str) -> None:
        jsii.set(self, "password", value)

    @builtins.property # type: ignore
    @jsii.member(jsii_name="resourceGroupName")
    def resource_group_name(self) -> builtins.str:
        return jsii.get(self, "resourceGroupName")

    @resource_group_name.setter # type: ignore
    def resource_group_name(self, value: builtins.str) -> None:
        jsii.set(self, "resourceGroupName", value)

    @builtins.property # type: ignore
    @jsii.member(jsii_name="size")
    def size(self) -> builtins.str:
        return jsii.get(self, "size")

    @size.setter # type: ignore
    def size(self, value: builtins.str) -> None:
        jsii.set(self, "size", value)

    @builtins.property # type: ignore
    @jsii.member(jsii_name="storageType")
    def storage_type(self) -> builtins.str:
        return jsii.get(self, "storageType")

    @storage_type.setter # type: ignore
    def storage_type(self, value: builtins.str) -> None:
        jsii.set(self, "storageType", value)

    @builtins.property # type: ignore
    @jsii.member(jsii_name="username")
    def username(self) -> builtins.str:
        return jsii.get(self, "username")

    @username.setter # type: ignore
    def username(self, value: builtins.str) -> None:
        jsii.set(self, "username", value)

    @builtins.property # type: ignore
    @jsii.member(jsii_name="allowClaim")
    def allow_claim(self) -> typing.Optional[builtins.bool]:
        return jsii.get(self, "allowClaim")

    @allow_claim.setter # type: ignore
    def allow_claim(self, value: typing.Optional[builtins.bool]) -> None:
        jsii.set(self, "allowClaim", value)

    @builtins.property # type: ignore
    @jsii.member(jsii_name="disallowPublicIpAddress")
    def disallow_public_ip_address(self) -> typing.Optional[builtins.bool]:
        return jsii.get(self, "disallowPublicIpAddress")

    @disallow_public_ip_address.setter # type: ignore
    def disallow_public_ip_address(self, value: typing.Optional[builtins.bool]) -> None:
        jsii.set(self, "disallowPublicIpAddress", value)

    @builtins.property # type: ignore
    @jsii.member(jsii_name="id")
    def id(self) -> typing.Optional[builtins.str]:
        return jsii.get(self, "id")

    @id.setter # type: ignore
    def id(self, value: typing.Optional[builtins.str]) -> None:
        jsii.set(self, "id", value)

    @builtins.property # type: ignore
    @jsii.member(jsii_name="inboundNatRule")
    def inbound_nat_rule(
        self,
    ) -> typing.Optional[typing.List["DevTestWindowsVirtualMachineInboundNatRule"]]:
        return jsii.get(self, "inboundNatRule")

    @inbound_nat_rule.setter # type: ignore
    def inbound_nat_rule(
        self,
        value: typing.Optional[typing.List["DevTestWindowsVirtualMachineInboundNatRule"]],
    ) -> None:
        jsii.set(self, "inboundNatRule", value)

    @builtins.property # type: ignore
    @jsii.member(jsii_name="notes")
    def notes(self) -> typing.Optional[builtins.str]:
        return jsii.get(self, "notes")

    @notes.setter # type: ignore
    def notes(self, value: typing.Optional[builtins.str]) -> None:
        jsii.set(self, "notes", value)

    @builtins.property # type: ignore
    @jsii.member(jsii_name="tags")
    def tags(self) -> typing.Optional[typing.Mapping[builtins.str, builtins.str]]:
        return jsii.get(self, "tags")

    @tags.setter # type: ignore
    def tags(
        self,
        value: typing.Optional[typing.Mapping[builtins.str, builtins.str]],
    ) -> None:
        jsii.set(self, "tags", value)

    @builtins.property # type: ignore
    @jsii.member(jsii_name="timeouts")
    def timeouts(self) -> typing.Optional["DevTestWindowsVirtualMachineTimeouts"]:
        return jsii.get(self, "timeouts")

    @timeouts.setter # type: ignore
    def timeouts(
        self,
        value: typing.Optional["DevTestWindowsVirtualMachineTimeouts"],
    ) -> None:
        jsii.set(self, "timeouts", value)


@jsii.data_type(
    jsii_type="@cdktf/provider-azurerm.DevTestWindowsVirtualMachineConfig",
    jsii_struct_bases=[cdktf.TerraformMetaArguments],
    name_mapping={
        "count": "count",
        "depends_on": "dependsOn",
        "lifecycle": "lifecycle",
        "provider": "provider",
        "gallery_image_reference": "galleryImageReference",
        "lab_name": "labName",
        "lab_subnet_name": "labSubnetName",
        "lab_virtual_network_id": "labVirtualNetworkId",
        "location": "location",
        "name": "name",
        "password": "password",
        "resource_group_name": "resourceGroupName",
        "size": "size",
        "storage_type": "storageType",
        "username": "username",
        "allow_claim": "allowClaim",
        "disallow_public_ip_address": "disallowPublicIpAddress",
        "inbound_nat_rule": "inboundNatRule",
        "notes": "notes",
        "tags": "tags",
        "timeouts": "timeouts",
    },
)
class DevTestWindowsVirtualMachineConfig(cdktf.TerraformMetaArguments):
    def __init__(
        self,
        *,
        count: typing.Optional[jsii.Number] = None,
        depends_on: typing.Optional[typing.List[cdktf.TerraformResource]] = None,
        lifecycle: typing.Optional[cdktf.TerraformResourceLifecycle] = None,
        provider: typing.Optional[cdktf.TerraformProvider] = None,
        gallery_image_reference: typing.List["DevTestWindowsVirtualMachineGalleryImageReference"],
        lab_name: builtins.str,
        lab_subnet_name: builtins.str,
        lab_virtual_network_id: builtins.str,
        location: builtins.str,
        name: builtins.str,
        password: builtins.str,
        resource_group_name: builtins.str,
        size: builtins.str,
        storage_type: builtins.str,
        username: builtins.str,
        allow_claim: typing.Optional[builtins.bool] = None,
        disallow_public_ip_address: typing.Optional[builtins.bool] = None,
        inbound_nat_rule: typing.Optional[typing.List["DevTestWindowsVirtualMachineInboundNatRule"]] = None,
        notes: typing.Optional[builtins.str] = None,
        tags: typing.Optional[typing.Mapping[builtins.str, builtins.str]] = None,
        timeouts: typing.Optional["DevTestWindowsVirtualMachineTimeouts"] = None,
    ) -> None:
        """
        :param count: 
        :param depends_on: 
        :param lifecycle: 
        :param provider: 
        :param gallery_image_reference: gallery_image_reference block.
        :param lab_name: 
        :param lab_subnet_name: 
        :param lab_virtual_network_id: 
        :param location: 
        :param name: 
        :param password: 
        :param resource_group_name: 
        :param size: 
        :param storage_type: 
        :param username: 
        :param allow_claim: 
        :param disallow_public_ip_address: 
        :param inbound_nat_rule: inbound_nat_rule block.
        :param notes: 
        :param tags: 
        :param timeouts: timeouts block.
        """
        if isinstance(lifecycle, dict):
            lifecycle = cdktf.TerraformResourceLifecycle(**lifecycle)
        if isinstance(timeouts, dict):
            timeouts = DevTestWindowsVirtualMachineTimeouts(**timeouts)
        self._values: typing.Dict[str, typing.Any] = {
            "gallery_image_reference": gallery_image_reference,
            "lab_name": lab_name,
            "lab_subnet_name": lab_subnet_name,
            "lab_virtual_network_id": lab_virtual_network_id,
            "location": location,
            "name": name,
            "password": password,
            "resource_group_name": resource_group_name,
            "size": size,
            "storage_type": storage_type,
            "username": username,
        }
        if count is not None:
            self._values["count"] = count
        if depends_on is not None:
            self._values["depends_on"] = depends_on
        if lifecycle is not None:
            self._values["lifecycle"] = lifecycle
        if provider is not None:
            self._values["provider"] = provider
        if allow_claim is not None:
            self._values["allow_claim"] = allow_claim
        if disallow_public_ip_address is not None:
            self._values["disallow_public_ip_address"] = disallow_public_ip_address
        if inbound_nat_rule is not None:
            self._values["inbound_nat_rule"] = inbound_nat_rule
        if notes is not None:
            self._values["notes"] = notes
        if tags is not None:
            self._values["tags"] = tags
        if timeouts is not None:
            self._values["timeouts"] = timeouts

    @builtins.property
    def count(self) -> typing.Optional[jsii.Number]:
        """
        :stability: experimental
        """
        result = self._values.get("count")
        return result

    @builtins.property
    def depends_on(self) -> typing.Optional[typing.List[cdktf.TerraformResource]]:
        """
        :stability: experimental
        """
        result = self._values.get("depends_on")
        return result

    @builtins.property
    def lifecycle(self) -> typing.Optional[cdktf.TerraformResourceLifecycle]:
        """
        :stability: experimental
        """
        result = self._values.get("lifecycle")
        return result

    @builtins.property
    def provider(self) -> typing.Optional[cdktf.TerraformProvider]:
        """
        :stability: experimental
        """
        result = self._values.get("provider")
        return result

    @builtins.property
    def gallery_image_reference(
        self,
    ) -> typing.List["DevTestWindowsVirtualMachineGalleryImageReference"]:
        """gallery_image_reference block."""
        result = self._values.get("gallery_image_reference")
        assert result is not None, "Required property 'gallery_image_reference' is missing"
        return result

    @builtins.property
    def lab_name(self) -> builtins.str:
        result = self._values.get("lab_name")
        assert result is not None, "Required property 'lab_name' is missing"
        return result

    @builtins.property
    def lab_subnet_name(self) -> builtins.str:
        result = self._values.get("lab_subnet_name")
        assert result is not None, "Required property 'lab_subnet_name' is missing"
        return result

    @builtins.property
    def lab_virtual_network_id(self) -> builtins.str:
        result = self._values.get("lab_virtual_network_id")
        assert result is not None, "Required property 'lab_virtual_network_id' is missing"
        return result

    @builtins.property
    def location(self) -> builtins.str:
        result = self._values.get("location")
        assert result is not None, "Required property 'location' is missing"
        return result

    @builtins.property
    def name(self) -> builtins.str:
        result = self._values.get("name")
        assert result is not None, "Required property 'name' is missing"
        return result

    @builtins.property
    def password(self) -> builtins.str:
        result = self._values.get("password")
        assert result is not None, "Required property 'password' is missing"
        return result

    @builtins.property
    def resource_group_name(self) -> builtins.str:
        result = self._values.get("resource_group_name")
        assert result is not None, "Required property 'resource_group_name' is missing"
        return result

    @builtins.property
    def size(self) -> builtins.str:
        result = self._values.get("size")
        assert result is not None, "Required property 'size' is missing"
        return result

    @builtins.property
    def storage_type(self) -> builtins.str:
        result = self._values.get("storage_type")
        assert result is not None, "Required property 'storage_type' is missing"
        return result

    @builtins.property
    def username(self) -> builtins.str:
        result = self._values.get("username")
        assert result is not None, "Required property 'username' is missing"
        return result

    @builtins.property
    def allow_claim(self) -> typing.Optional[builtins.bool]:
        result = self._values.get("allow_claim")
        return result

    @builtins.property
    def disallow_public_ip_address(self) -> typing.Optional[builtins.bool]:
        result = self._values.get("disallow_public_ip_address")
        return result

    @builtins.property
    def inbound_nat_rule(
        self,
    ) -> typing.Optional[typing.List["DevTestWindowsVirtualMachineInboundNatRule"]]:
        """inbound_nat_rule block."""
        result = self._values.get("inbound_nat_rule")
        return result

    @builtins.property
    def notes(self) -> typing.Optional[builtins.str]:
        result = self._values.get("notes")
        return result

    @builtins.property
    def tags(self) -> typing.Optional[typing.Mapping[builtins.str, builtins.str]]:
        result = self._values.get("tags")
        return result

    @builtins.property
    def timeouts(self) -> typing.Optional["DevTestWindowsVirtualMachineTimeouts"]:
        """timeouts block."""
        result = self._values.get("timeouts")
        return result

    def __eq__(self, rhs: typing.Any) -> builtins.bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs: typing.Any) -> builtins.bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return "DevTestWindowsVirtualMachineConfig(%s)" % ", ".join(
            k + "=" + repr(v) for k, v in self._values.items()
        )


@jsii.data_type(
    jsii_type="@cdktf/provider-azurerm.DevTestWindowsVirtualMachineGalleryImageReference",
    jsii_struct_bases=[],
    name_mapping={
        "offer": "offer",
        "publisher": "publisher",
        "sku": "sku",
        "version": "version",
    },
)
class DevTestWindowsVirtualMachineGalleryImageReference:
    def __init__(
        self,
        *,
        offer: builtins.str,
        publisher: builtins.str,
        sku: builtins.str,
        version: builtins.str,
    ) -> None:
        """
        :param offer: 
        :param publisher: 
        :param sku: 
        :param version: 
        """
        self._values: typing.Dict[str, typing.Any] = {
            "offer": offer,
            "publisher": publisher,
            "sku": sku,
            "version": version,
        }

    @builtins.property
    def offer(self) -> builtins.str:
        result = self._values.get("offer")
        assert result is not None, "Required property 'offer' is missing"
        return result

    @builtins.property
    def publisher(self) -> builtins.str:
        result = self._values.get("publisher")
        assert result is not None, "Required property 'publisher' is missing"
        return result

    @builtins.property
    def sku(self) -> builtins.str:
        result = self._values.get("sku")
        assert result is not None, "Required property 'sku' is missing"
        return result

    @builtins.property
    def version(self) -> builtins.str:
        result = self._values.get("version")
        assert result is not None, "Required property 'version' is missing"
        return result

    def __eq__(self, rhs: typing.Any) -> builtins.bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs: typing.Any) -> builtins.bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return "DevTestWindowsVirtualMachineGalleryImageReference(%s)" % ", ".join(
            k + "=" + repr(v) for k, v in self._values.items()
        )


@jsii.data_type(
    jsii_type="@cdktf/provider-azurerm.DevTestWindowsVirtualMachineInboundNatRule",
    jsii_struct_bases=[],
    name_mapping={"backend_port": "backendPort", "protocol": "protocol"},
)
class DevTestWindowsVirtualMachineInboundNatRule:
    def __init__(self, *, backend_port: jsii.Number, protocol: builtins.str) -> None:
        """
        :param backend_port: 
        :param protocol: 
        """
        self._values: typing.Dict[str, typing.Any] = {
            "backend_port": backend_port,
            "protocol": protocol,
        }

    @builtins.property
    def backend_port(self) -> jsii.Number:
        result = self._values.get("backend_port")
        assert result is not None, "Required property 'backend_port' is missing"
        return result

    @builtins.property
    def protocol(self) -> builtins.str:
        result = self._values.get("protocol")
        assert result is not None, "Required property 'protocol' is missing"
        return result

    def __eq__(self, rhs: typing.Any) -> builtins.bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs: typing.Any) -> builtins.bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return "DevTestWindowsVirtualMachineInboundNatRule(%s)" % ", ".join(
            k + "=" + repr(v) for k, v in self._values.items()
        )


@jsii.data_type(
    jsii_type="@cdktf/provider-azurerm.DevTestWindowsVirtualMachineTimeouts",
    jsii_struct_bases=[],
    name_mapping={
        "create": "create",
        "delete": "delete",
        "read": "read",
        "update": "update",
    },
)
class DevTestWindowsVirtualMachineTimeouts:
    def __init__(
        self,
        *,
        create: typing.Optional[builtins.str] = None,
        delete: typing.Optional[builtins.str] = None,
        read: typing.Optional[builtins.str] = None,
        update: typing.Optional[builtins.str] = None,
    ) -> None:
        """
        :param create: 
        :param delete: 
        :param read: 
        :param update: 
        """
        self._values: typing.Dict[str, typing.Any] = {}
        if create is not None:
            self._values["create"] = create
        if delete is not None:
            self._values["delete"] = delete
        if read is not None:
            self._values["read"] = read
        if update is not None:
            self._values["update"] = update

    @builtins.property
    def create(self) -> typing.Optional[builtins.str]:
        result = self._values.get("create")
        return result

    @builtins.property
    def delete(self) -> typing.Optional[builtins.str]:
        result = self._values.get("delete")
        return result

    @builtins.property
    def read(self) -> typing.Optional[builtins.str]:
        result = self._values.get("read")
        return result

    @builtins.property
    def update(self) -> typing.Optional[builtins.str]:
        result = self._values.get("update")
        return result

    def __eq__(self, rhs: typing.Any) -> builtins.bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs: typing.Any) -> builtins.bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return "DevTestWindowsVirtualMachineTimeouts(%s)" % ", ".join(
            k + "=" + repr(v) for k, v in self._values.items()
        )


class DevspaceController(
    cdktf.TerraformResource,
    metaclass=jsii.JSIIMeta,
    jsii_type="@cdktf/provider-azurerm.DevspaceController",
):
    def __init__(
        self,
        scope: constructs.Construct,
        id: builtins.str,
        *,
        location: builtins.str,
        name: builtins.str,
        resource_group_name: builtins.str,
        sku_name: builtins.str,
        target_container_host_credentials_base64: builtins.str,
        target_container_host_resource_id: builtins.str,
        tags: typing.Optional[typing.Mapping[builtins.str, builtins.str]] = None,
        timeouts: typing.Optional["DevspaceControllerTimeouts"] = None,
        count: typing.Optional[jsii.Number] = None,
        depends_on: typing.Optional[typing.List[cdktf.TerraformResource]] = None,
        lifecycle: typing.Optional[cdktf.TerraformResourceLifecycle] = None,
        provider: typing.Optional[cdktf.TerraformProvider] = None,
    ) -> None:
        """
        :param scope: -
        :param id: -
        :param location: 
        :param name: 
        :param resource_group_name: 
        :param sku_name: 
        :param target_container_host_credentials_base64: 
        :param target_container_host_resource_id: 
        :param tags: 
        :param timeouts: timeouts block.
        :param count: 
        :param depends_on: 
        :param lifecycle: 
        :param provider: 
        """
        config = DevspaceControllerConfig(
            location=location,
            name=name,
            resource_group_name=resource_group_name,
            sku_name=sku_name,
            target_container_host_credentials_base64=target_container_host_credentials_base64,
            target_container_host_resource_id=target_container_host_resource_id,
            tags=tags,
            timeouts=timeouts,
            count=count,
            depends_on=depends_on,
            lifecycle=lifecycle,
            provider=provider,
        )

        jsii.create(DevspaceController, self, [scope, id, config])

    @jsii.member(jsii_name="synthesizeAttributes")
    def _synthesize_attributes(self) -> typing.Mapping[builtins.str, typing.Any]:
        return jsii.invoke(self, "synthesizeAttributes", [])

    @builtins.property # type: ignore
    @jsii.member(jsii_name="dataPlaneFqdn")
    def data_plane_fqdn(self) -> builtins.str:
        return jsii.get(self, "dataPlaneFqdn")

    @builtins.property # type: ignore
    @jsii.member(jsii_name="hostSuffix")
    def host_suffix(self) -> builtins.str:
        return jsii.get(self, "hostSuffix")

    @builtins.property # type: ignore
    @jsii.member(jsii_name="location")
    def location(self) -> builtins.str:
        return jsii.get(self, "location")

    @location.setter # type: ignore
    def location(self, value: builtins.str) -> None:
        jsii.set(self, "location", value)

    @builtins.property # type: ignore
    @jsii.member(jsii_name="name")
    def name(self) -> builtins.str:
        return jsii.get(self, "name")

    @name.setter # type: ignore
    def name(self, value: builtins.str) -> None:
        jsii.set(self, "name", value)

    @builtins.property # type: ignore
    @jsii.member(jsii_name="resourceGroupName")
    def resource_group_name(self) -> builtins.str:
        return jsii.get(self, "resourceGroupName")

    @resource_group_name.setter # type: ignore
    def resource_group_name(self, value: builtins.str) -> None:
        jsii.set(self, "resourceGroupName", value)

    @builtins.property # type: ignore
    @jsii.member(jsii_name="skuName")
    def sku_name(self) -> builtins.str:
        return jsii.get(self, "skuName")

    @sku_name.setter # type: ignore
    def sku_name(self, value: builtins.str) -> None:
        jsii.set(self, "skuName", value)

    @builtins.property # type: ignore
    @jsii.member(jsii_name="targetContainerHostCredentialsBase64")
    def target_container_host_credentials_base64(self) -> builtins.str:
        return jsii.get(self, "targetContainerHostCredentialsBase64")

    @target_container_host_credentials_base64.setter # type: ignore
    def target_container_host_credentials_base64(self, value: builtins.str) -> None:
        jsii.set(self, "targetContainerHostCredentialsBase64", value)

    @builtins.property # type: ignore
    @jsii.member(jsii_name="targetContainerHostResourceId")
    def target_container_host_resource_id(self) -> builtins.str:
        return jsii.get(self, "targetContainerHostResourceId")

    @target_container_host_resource_id.setter # type: ignore
    def target_container_host_resource_id(self, value: builtins.str) -> None:
        jsii.set(self, "targetContainerHostResourceId", value)

    @builtins.property # type: ignore
    @jsii.member(jsii_name="id")
    def id(self) -> typing.Optional[builtins.str]:
        return jsii.get(self, "id")

    @id.setter # type: ignore
    def id(self, value: typing.Optional[builtins.str]) -> None:
        jsii.set(self, "id", value)

    @builtins.property # type: ignore
    @jsii.member(jsii_name="tags")
    def tags(self) -> typing.Optional[typing.Mapping[builtins.str, builtins.str]]:
        return jsii.get(self, "tags")

    @tags.setter # type: ignore
    def tags(
        self,
        value: typing.Optional[typing.Mapping[builtins.str, builtins.str]],
    ) -> None:
        jsii.set(self, "tags", value)

    @builtins.property # type: ignore
    @jsii.member(jsii_name="timeouts")
    def timeouts(self) -> typing.Optional["DevspaceControllerTimeouts"]:
        return jsii.get(self, "timeouts")

    @timeouts.setter # type: ignore
    def timeouts(self, value: typing.Optional["DevspaceControllerTimeouts"]) -> None:
        jsii.set(self, "timeouts", value)


@jsii.data_type(
    jsii_type="@cdktf/provider-azurerm.DevspaceControllerConfig",
    jsii_struct_bases=[cdktf.TerraformMetaArguments],
    name_mapping={
        "count": "count",
        "depends_on": "dependsOn",
        "lifecycle": "lifecycle",
        "provider": "provider",
        "location": "location",
        "name": "name",
        "resource_group_name": "resourceGroupName",
        "sku_name": "skuName",
        "target_container_host_credentials_base64": "targetContainerHostCredentialsBase64",
        "target_container_host_resource_id": "targetContainerHostResourceId",
        "tags": "tags",
        "timeouts": "timeouts",
    },
)
class DevspaceControllerConfig(cdktf.TerraformMetaArguments):
    def __init__(
        self,
        *,
        count: typing.Optional[jsii.Number] = None,
        depends_on: typing.Optional[typing.List[cdktf.TerraformResource]] = None,
        lifecycle: typing.Optional[cdktf.TerraformResourceLifecycle] = None,
        provider: typing.Optional[cdktf.TerraformProvider] = None,
        location: builtins.str,
        name: builtins.str,
        resource_group_name: builtins.str,
        sku_name: builtins.str,
        target_container_host_credentials_base64: builtins.str,
        target_container_host_resource_id: builtins.str,
        tags: typing.Optional[typing.Mapping[builtins.str, builtins.str]] = None,
        timeouts: typing.Optional["DevspaceControllerTimeouts"] = None,
    ) -> None:
        """
        :param count: 
        :param depends_on: 
        :param lifecycle: 
        :param provider: 
        :param location: 
        :param name: 
        :param resource_group_name: 
        :param sku_name: 
        :param target_container_host_credentials_base64: 
        :param target_container_host_resource_id: 
        :param tags: 
        :param timeouts: timeouts block.
        """
        if isinstance(lifecycle, dict):
            lifecycle = cdktf.TerraformResourceLifecycle(**lifecycle)
        if isinstance(timeouts, dict):
            timeouts = DevspaceControllerTimeouts(**timeouts)
        self._values: typing.Dict[str, typing.Any] = {
            "location": location,
            "name": name,
            "resource_group_name": resource_group_name,
            "sku_name": sku_name,
            "target_container_host_credentials_base64": target_container_host_credentials_base64,
            "target_container_host_resource_id": target_container_host_resource_id,
        }
        if count is not None:
            self._values["count"] = count
        if depends_on is not None:
            self._values["depends_on"] = depends_on
        if lifecycle is not None:
            self._values["lifecycle"] = lifecycle
        if provider is not None:
            self._values["provider"] = provider
        if tags is not None:
            self._values["tags"] = tags
        if timeouts is not None:
            self._values["timeouts"] = timeouts

    @builtins.property
    def count(self) -> typing.Optional[jsii.Number]:
        """
        :stability: experimental
        """
        result = self._values.get("count")
        return result

    @builtins.property
    def depends_on(self) -> typing.Optional[typing.List[cdktf.TerraformResource]]:
        """
        :stability: experimental
        """
        result = self._values.get("depends_on")
        return result

    @builtins.property
    def lifecycle(self) -> typing.Optional[cdktf.TerraformResourceLifecycle]:
        """
        :stability: experimental
        """
        result = self._values.get("lifecycle")
        return result

    @builtins.property
    def provider(self) -> typing.Optional[cdktf.TerraformProvider]:
        """
        :stability: experimental
        """
        result = self._values.get("provider")
        return result

    @builtins.property
    def location(self) -> builtins.str:
        result = self._values.get("location")
        assert result is not None, "Required property 'location' is missing"
        return result

    @builtins.property
    def name(self) -> builtins.str:
        result = self._values.get("name")
        assert result is not None, "Required property 'name' is missing"
        return result

    @builtins.property
    def resource_group_name(self) -> builtins.str:
        result = self._values.get("resource_group_name")
        assert result is not None, "Required property 'resource_group_name' is missing"
        return result

    @builtins.property
    def sku_name(self) -> builtins.str:
        result = self._values.get("sku_name")
        assert result is not None, "Required property 'sku_name' is missing"
        return result

    @builtins.property
    def target_container_host_credentials_base64(self) -> builtins.str:
        result = self._values.get("target_container_host_credentials_base64")
        assert result is not None, "Required property 'target_container_host_credentials_base64' is missing"
        return result

    @builtins.property
    def target_container_host_resource_id(self) -> builtins.str:
        result = self._values.get("target_container_host_resource_id")
        assert result is not None, "Required property 'target_container_host_resource_id' is missing"
        return result

    @builtins.property
    def tags(self) -> typing.Optional[typing.Mapping[builtins.str, builtins.str]]:
        result = self._values.get("tags")
        return result

    @builtins.property
    def timeouts(self) -> typing.Optional["DevspaceControllerTimeouts"]:
        """timeouts block."""
        result = self._values.get("timeouts")
        return result

    def __eq__(self, rhs: typing.Any) -> builtins.bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs: typing.Any) -> builtins.bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return "DevspaceControllerConfig(%s)" % ", ".join(
            k + "=" + repr(v) for k, v in self._values.items()
        )


@jsii.data_type(
    jsii_type="@cdktf/provider-azurerm.DevspaceControllerTimeouts",
    jsii_struct_bases=[],
    name_mapping={
        "create": "create",
        "delete": "delete",
        "read": "read",
        "update": "update",
    },
)
class DevspaceControllerTimeouts:
    def __init__(
        self,
        *,
        create: typing.Optional[builtins.str] = None,
        delete: typing.Optional[builtins.str] = None,
        read: typing.Optional[builtins.str] = None,
        update: typing.Optional[builtins.str] = None,
    ) -> None:
        """
        :param create: 
        :param delete: 
        :param read: 
        :param update: 
        """
        self._values: typing.Dict[str, typing.Any] = {}
        if create is not None:
            self._values["create"] = create
        if delete is not None:
            self._values["delete"] = delete
        if read is not None:
            self._values["read"] = read
        if update is not None:
            self._values["update"] = update

    @builtins.property
    def create(self) -> typing.Optional[builtins.str]:
        result = self._values.get("create")
        return result

    @builtins.property
    def delete(self) -> typing.Optional[builtins.str]:
        result = self._values.get("delete")
        return result

    @builtins.property
    def read(self) -> typing.Optional[builtins.str]:
        result = self._values.get("read")
        return result

    @builtins.property
    def update(self) -> typing.Optional[builtins.str]:
        result = self._values.get("update")
        return result

    def __eq__(self, rhs: typing.Any) -> builtins.bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs: typing.Any) -> builtins.bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return "DevspaceControllerTimeouts(%s)" % ", ".join(
            k + "=" + repr(v) for k, v in self._values.items()
        )


class DiskEncryptionSet(
    cdktf.TerraformResource,
    metaclass=jsii.JSIIMeta,
    jsii_type="@cdktf/provider-azurerm.DiskEncryptionSet",
):
    def __init__(
        self,
        scope: constructs.Construct,
        id: builtins.str,
        *,
        identity: typing.List["DiskEncryptionSetIdentity"],
        key_vault_key_id: builtins.str,
        location: builtins.str,
        name: builtins.str,
        resource_group_name: builtins.str,
        tags: typing.Optional[typing.Mapping[builtins.str, builtins.str]] = None,
        timeouts: typing.Optional["DiskEncryptionSetTimeouts"] = None,
        count: typing.Optional[jsii.Number] = None,
        depends_on: typing.Optional[typing.List[cdktf.TerraformResource]] = None,
        lifecycle: typing.Optional[cdktf.TerraformResourceLifecycle] = None,
        provider: typing.Optional[cdktf.TerraformProvider] = None,
    ) -> None:
        """
        :param scope: -
        :param id: -
        :param identity: identity block.
        :param key_vault_key_id: 
        :param location: 
        :param name: 
        :param resource_group_name: 
        :param tags: 
        :param timeouts: timeouts block.
        :param count: 
        :param depends_on: 
        :param lifecycle: 
        :param provider: 
        """
        config = DiskEncryptionSetConfig(
            identity=identity,
            key_vault_key_id=key_vault_key_id,
            location=location,
            name=name,
            resource_group_name=resource_group_name,
            tags=tags,
            timeouts=timeouts,
            count=count,
            depends_on=depends_on,
            lifecycle=lifecycle,
            provider=provider,
        )

        jsii.create(DiskEncryptionSet, self, [scope, id, config])

    @jsii.member(jsii_name="synthesizeAttributes")
    def _synthesize_attributes(self) -> typing.Mapping[builtins.str, typing.Any]:
        return jsii.invoke(self, "synthesizeAttributes", [])

    @builtins.property # type: ignore
    @jsii.member(jsii_name="identity")
    def identity(self) -> typing.List["DiskEncryptionSetIdentity"]:
        return jsii.get(self, "identity")

    @identity.setter # type: ignore
    def identity(self, value: typing.List["DiskEncryptionSetIdentity"]) -> None:
        jsii.set(self, "identity", value)

    @builtins.property # type: ignore
    @jsii.member(jsii_name="keyVaultKeyId")
    def key_vault_key_id(self) -> builtins.str:
        return jsii.get(self, "keyVaultKeyId")

    @key_vault_key_id.setter # type: ignore
    def key_vault_key_id(self, value: builtins.str) -> None:
        jsii.set(self, "keyVaultKeyId", value)

    @builtins.property # type: ignore
    @jsii.member(jsii_name="location")
    def location(self) -> builtins.str:
        return jsii.get(self, "location")

    @location.setter # type: ignore
    def location(self, value: builtins.str) -> None:
        jsii.set(self, "location", value)

    @builtins.property # type: ignore
    @jsii.member(jsii_name="name")
    def name(self) -> builtins.str:
        return jsii.get(self, "name")

    @name.setter # type: ignore
    def name(self, value: builtins.str) -> None:
        jsii.set(self, "name", value)

    @builtins.property # type: ignore
    @jsii.member(jsii_name="resourceGroupName")
    def resource_group_name(self) -> builtins.str:
        return jsii.get(self, "resourceGroupName")

    @resource_group_name.setter # type: ignore
    def resource_group_name(self, value: builtins.str) -> None:
        jsii.set(self, "resourceGroupName", value)

    @builtins.property # type: ignore
    @jsii.member(jsii_name="id")
    def id(self) -> typing.Optional[builtins.str]:
        return jsii.get(self, "id")

    @id.setter # type: ignore
    def id(self, value: typing.Optional[builtins.str]) -> None:
        jsii.set(self, "id", value)

    @builtins.property # type: ignore
    @jsii.member(jsii_name="tags")
    def tags(self) -> typing.Optional[typing.Mapping[builtins.str, builtins.str]]:
        return jsii.get(self, "tags")

    @tags.setter # type: ignore
    def tags(
        self,
        value: typing.Optional[typing.Mapping[builtins.str, builtins.str]],
    ) -> None:
        jsii.set(self, "tags", value)

    @builtins.property # type: ignore
    @jsii.member(jsii_name="timeouts")
    def timeouts(self) -> typing.Optional["DiskEncryptionSetTimeouts"]:
        return jsii.get(self, "timeouts")

    @timeouts.setter # type: ignore
    def timeouts(self, value: typing.Optional["DiskEncryptionSetTimeouts"]) -> None:
        jsii.set(self, "timeouts", value)


@jsii.data_type(
    jsii_type="@cdktf/provider-azurerm.DiskEncryptionSetConfig",
    jsii_struct_bases=[cdktf.TerraformMetaArguments],
    name_mapping={
        "count": "count",
        "depends_on": "dependsOn",
        "lifecycle": "lifecycle",
        "provider": "provider",
        "identity": "identity",
        "key_vault_key_id": "keyVaultKeyId",
        "location": "location",
        "name": "name",
        "resource_group_name": "resourceGroupName",
        "tags": "tags",
        "timeouts": "timeouts",
    },
)
class DiskEncryptionSetConfig(cdktf.TerraformMetaArguments):
    def __init__(
        self,
        *,
        count: typing.Optional[jsii.Number] = None,
        depends_on: typing.Optional[typing.List[cdktf.TerraformResource]] = None,
        lifecycle: typing.Optional[cdktf.TerraformResourceLifecycle] = None,
        provider: typing.Optional[cdktf.TerraformProvider] = None,
        identity: typing.List["DiskEncryptionSetIdentity"],
        key_vault_key_id: builtins.str,
        location: builtins.str,
        name: builtins.str,
        resource_group_name: builtins.str,
        tags: typing.Optional[typing.Mapping[builtins.str, builtins.str]] = None,
        timeouts: typing.Optional["DiskEncryptionSetTimeouts"] = None,
    ) -> None:
        """
        :param count: 
        :param depends_on: 
        :param lifecycle: 
        :param provider: 
        :param identity: identity block.
        :param key_vault_key_id: 
        :param location: 
        :param name: 
        :param resource_group_name: 
        :param tags: 
        :param timeouts: timeouts block.
        """
        if isinstance(lifecycle, dict):
            lifecycle = cdktf.TerraformResourceLifecycle(**lifecycle)
        if isinstance(timeouts, dict):
            timeouts = DiskEncryptionSetTimeouts(**timeouts)
        self._values: typing.Dict[str, typing.Any] = {
            "identity": identity,
            "key_vault_key_id": key_vault_key_id,
            "location": location,
            "name": name,
            "resource_group_name": resource_group_name,
        }
        if count is not None:
            self._values["count"] = count
        if depends_on is not None:
            self._values["depends_on"] = depends_on
        if lifecycle is not None:
            self._values["lifecycle"] = lifecycle
        if provider is not None:
            self._values["provider"] = provider
        if tags is not None:
            self._values["tags"] = tags
        if timeouts is not None:
            self._values["timeouts"] = timeouts

    @builtins.property
    def count(self) -> typing.Optional[jsii.Number]:
        """
        :stability: experimental
        """
        result = self._values.get("count")
        return result

    @builtins.property
    def depends_on(self) -> typing.Optional[typing.List[cdktf.TerraformResource]]:
        """
        :stability: experimental
        """
        result = self._values.get("depends_on")
        return result

    @builtins.property
    def lifecycle(self) -> typing.Optional[cdktf.TerraformResourceLifecycle]:
        """
        :stability: experimental
        """
        result = self._values.get("lifecycle")
        return result

    @builtins.property
    def provider(self) -> typing.Optional[cdktf.TerraformProvider]:
        """
        :stability: experimental
        """
        result = self._values.get("provider")
        return result

    @builtins.property
    def identity(self) -> typing.List["DiskEncryptionSetIdentity"]:
        """identity block."""
        result = self._values.get("identity")
        assert result is not None, "Required property 'identity' is missing"
        return result

    @builtins.property
    def key_vault_key_id(self) -> builtins.str:
        result = self._values.get("key_vault_key_id")
        assert result is not None, "Required property 'key_vault_key_id' is missing"
        return result

    @builtins.property
    def location(self) -> builtins.str:
        result = self._values.get("location")
        assert result is not None, "Required property 'location' is missing"
        return result

    @builtins.property
    def name(self) -> builtins.str:
        result = self._values.get("name")
        assert result is not None, "Required property 'name' is missing"
        return result

    @builtins.property
    def resource_group_name(self) -> builtins.str:
        result = self._values.get("resource_group_name")
        assert result is not None, "Required property 'resource_group_name' is missing"
        return result

    @builtins.property
    def tags(self) -> typing.Optional[typing.Mapping[builtins.str, builtins.str]]:
        result = self._values.get("tags")
        return result

    @builtins.property
    def timeouts(self) -> typing.Optional["DiskEncryptionSetTimeouts"]:
        """timeouts block."""
        result = self._values.get("timeouts")
        return result

    def __eq__(self, rhs: typing.Any) -> builtins.bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs: typing.Any) -> builtins.bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return "DiskEncryptionSetConfig(%s)" % ", ".join(
            k + "=" + repr(v) for k, v in self._values.items()
        )


@jsii.data_type(
    jsii_type="@cdktf/provider-azurerm.DiskEncryptionSetIdentity",
    jsii_struct_bases=[],
    name_mapping={"type": "type"},
)
class DiskEncryptionSetIdentity:
    def __init__(self, *, type: builtins.str) -> None:
        """
        :param type: 
        """
        self._values: typing.Dict[str, typing.Any] = {
            "type": type,
        }

    @builtins.property
    def type(self) -> builtins.str:
        result = self._values.get("type")
        assert result is not None, "Required property 'type' is missing"
        return result

    def __eq__(self, rhs: typing.Any) -> builtins.bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs: typing.Any) -> builtins.bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return "DiskEncryptionSetIdentity(%s)" % ", ".join(
            k + "=" + repr(v) for k, v in self._values.items()
        )


@jsii.data_type(
    jsii_type="@cdktf/provider-azurerm.DiskEncryptionSetTimeouts",
    jsii_struct_bases=[],
    name_mapping={
        "create": "create",
        "delete": "delete",
        "read": "read",
        "update": "update",
    },
)
class DiskEncryptionSetTimeouts:
    def __init__(
        self,
        *,
        create: typing.Optional[builtins.str] = None,
        delete: typing.Optional[builtins.str] = None,
        read: typing.Optional[builtins.str] = None,
        update: typing.Optional[builtins.str] = None,
    ) -> None:
        """
        :param create: 
        :param delete: 
        :param read: 
        :param update: 
        """
        self._values: typing.Dict[str, typing.Any] = {}
        if create is not None:
            self._values["create"] = create
        if delete is not None:
            self._values["delete"] = delete
        if read is not None:
            self._values["read"] = read
        if update is not None:
            self._values["update"] = update

    @builtins.property
    def create(self) -> typing.Optional[builtins.str]:
        result = self._values.get("create")
        return result

    @builtins.property
    def delete(self) -> typing.Optional[builtins.str]:
        result = self._values.get("delete")
        return result

    @builtins.property
    def read(self) -> typing.Optional[builtins.str]:
        result = self._values.get("read")
        return result

    @builtins.property
    def update(self) -> typing.Optional[builtins.str]:
        result = self._values.get("update")
        return result

    def __eq__(self, rhs: typing.Any) -> builtins.bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs: typing.Any) -> builtins.bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return "DiskEncryptionSetTimeouts(%s)" % ", ".join(
            k + "=" + repr(v) for k, v in self._values.items()
        )


class DnsARecord(
    cdktf.TerraformResource,
    metaclass=jsii.JSIIMeta,
    jsii_type="@cdktf/provider-azurerm.DnsARecord",
):
    def __init__(
        self,
        scope: constructs.Construct,
        id: builtins.str,
        *,
        name: builtins.str,
        resource_group_name: builtins.str,
        ttl: jsii.Number,
        zone_name: builtins.str,
        records: typing.Optional[typing.List[builtins.str]] = None,
        tags: typing.Optional[typing.Mapping[builtins.str, builtins.str]] = None,
        target_resource_id: typing.Optional[builtins.str] = None,
        timeouts: typing.Optional["DnsARecordTimeouts"] = None,
        count: typing.Optional[jsii.Number] = None,
        depends_on: typing.Optional[typing.List[cdktf.TerraformResource]] = None,
        lifecycle: typing.Optional[cdktf.TerraformResourceLifecycle] = None,
        provider: typing.Optional[cdktf.TerraformProvider] = None,
    ) -> None:
        """
        :param scope: -
        :param id: -
        :param name: 
        :param resource_group_name: 
        :param ttl: 
        :param zone_name: 
        :param records: 
        :param tags: 
        :param target_resource_id: 
        :param timeouts: timeouts block.
        :param count: 
        :param depends_on: 
        :param lifecycle: 
        :param provider: 
        """
        config = DnsARecordConfig(
            name=name,
            resource_group_name=resource_group_name,
            ttl=ttl,
            zone_name=zone_name,
            records=records,
            tags=tags,
            target_resource_id=target_resource_id,
            timeouts=timeouts,
            count=count,
            depends_on=depends_on,
            lifecycle=lifecycle,
            provider=provider,
        )

        jsii.create(DnsARecord, self, [scope, id, config])

    @jsii.member(jsii_name="synthesizeAttributes")
    def _synthesize_attributes(self) -> typing.Mapping[builtins.str, typing.Any]:
        return jsii.invoke(self, "synthesizeAttributes", [])

    @builtins.property # type: ignore
    @jsii.member(jsii_name="fqdn")
    def fqdn(self) -> builtins.str:
        return jsii.get(self, "fqdn")

    @builtins.property # type: ignore
    @jsii.member(jsii_name="name")
    def name(self) -> builtins.str:
        return jsii.get(self, "name")

    @name.setter # type: ignore
    def name(self, value: builtins.str) -> None:
        jsii.set(self, "name", value)

    @builtins.property # type: ignore
    @jsii.member(jsii_name="resourceGroupName")
    def resource_group_name(self) -> builtins.str:
        return jsii.get(self, "resourceGroupName")

    @resource_group_name.setter # type: ignore
    def resource_group_name(self, value: builtins.str) -> None:
        jsii.set(self, "resourceGroupName", value)

    @builtins.property # type: ignore
    @jsii.member(jsii_name="ttl")
    def ttl(self) -> jsii.Number:
        return jsii.get(self, "ttl")

    @ttl.setter # type: ignore
    def ttl(self, value: jsii.Number) -> None:
        jsii.set(self, "ttl", value)

    @builtins.property # type: ignore
    @jsii.member(jsii_name="zoneName")
    def zone_name(self) -> builtins.str:
        return jsii.get(self, "zoneName")

    @zone_name.setter # type: ignore
    def zone_name(self, value: builtins.str) -> None:
        jsii.set(self, "zoneName", value)

    @builtins.property # type: ignore
    @jsii.member(jsii_name="id")
    def id(self) -> typing.Optional[builtins.str]:
        return jsii.get(self, "id")

    @id.setter # type: ignore
    def id(self, value: typing.Optional[builtins.str]) -> None:
        jsii.set(self, "id", value)

    @builtins.property # type: ignore
    @jsii.member(jsii_name="records")
    def records(self) -> typing.Optional[typing.List[builtins.str]]:
        return jsii.get(self, "records")

    @records.setter # type: ignore
    def records(self, value: typing.Optional[typing.List[builtins.str]]) -> None:
        jsii.set(self, "records", value)

    @builtins.property # type: ignore
    @jsii.member(jsii_name="tags")
    def tags(self) -> typing.Optional[typing.Mapping[builtins.str, builtins.str]]:
        return jsii.get(self, "tags")

    @tags.setter # type: ignore
    def tags(
        self,
        value: typing.Optional[typing.Mapping[builtins.str, builtins.str]],
    ) -> None:
        jsii.set(self, "tags", value)

    @builtins.property # type: ignore
    @jsii.member(jsii_name="targetResourceId")
    def target_resource_id(self) -> typing.Optional[builtins.str]:
        return jsii.get(self, "targetResourceId")

    @target_resource_id.setter # type: ignore
    def target_resource_id(self, value: typing.Optional[builtins.str]) -> None:
        jsii.set(self, "targetResourceId", value)

    @builtins.property # type: ignore
    @jsii.member(jsii_name="timeouts")
    def timeouts(self) -> typing.Optional["DnsARecordTimeouts"]:
        return jsii.get(self, "timeouts")

    @timeouts.setter # type: ignore
    def timeouts(self, value: typing.Optional["DnsARecordTimeouts"]) -> None:
        jsii.set(self, "timeouts", value)


@jsii.data_type(
    jsii_type="@cdktf/provider-azurerm.DnsARecordConfig",
    jsii_struct_bases=[cdktf.TerraformMetaArguments],
    name_mapping={
        "count": "count",
        "depends_on": "dependsOn",
        "lifecycle": "lifecycle",
        "provider": "provider",
        "name": "name",
        "resource_group_name": "resourceGroupName",
        "ttl": "ttl",
        "zone_name": "zoneName",
        "records": "records",
        "tags": "tags",
        "target_resource_id": "targetResourceId",
        "timeouts": "timeouts",
    },
)
class DnsARecordConfig(cdktf.TerraformMetaArguments):
    def __init__(
        self,
        *,
        count: typing.Optional[jsii.Number] = None,
        depends_on: typing.Optional[typing.List[cdktf.TerraformResource]] = None,
        lifecycle: typing.Optional[cdktf.TerraformResourceLifecycle] = None,
        provider: typing.Optional[cdktf.TerraformProvider] = None,
        name: builtins.str,
        resource_group_name: builtins.str,
        ttl: jsii.Number,
        zone_name: builtins.str,
        records: typing.Optional[typing.List[builtins.str]] = None,
        tags: typing.Optional[typing.Mapping[builtins.str, builtins.str]] = None,
        target_resource_id: typing.Optional[builtins.str] = None,
        timeouts: typing.Optional["DnsARecordTimeouts"] = None,
    ) -> None:
        """
        :param count: 
        :param depends_on: 
        :param lifecycle: 
        :param provider: 
        :param name: 
        :param resource_group_name: 
        :param ttl: 
        :param zone_name: 
        :param records: 
        :param tags: 
        :param target_resource_id: 
        :param timeouts: timeouts block.
        """
        if isinstance(lifecycle, dict):
            lifecycle = cdktf.TerraformResourceLifecycle(**lifecycle)
        if isinstance(timeouts, dict):
            timeouts = DnsARecordTimeouts(**timeouts)
        self._values: typing.Dict[str, typing.Any] = {
            "name": name,
            "resource_group_name": resource_group_name,
            "ttl": ttl,
            "zone_name": zone_name,
        }
        if count is not None:
            self._values["count"] = count
        if depends_on is not None:
            self._values["depends_on"] = depends_on
        if lifecycle is not None:
            self._values["lifecycle"] = lifecycle
        if provider is not None:
            self._values["provider"] = provider
        if records is not None:
            self._values["records"] = records
        if tags is not None:
            self._values["tags"] = tags
        if target_resource_id is not None:
            self._values["target_resource_id"] = target_resource_id
        if timeouts is not None:
            self._values["timeouts"] = timeouts

    @builtins.property
    def count(self) -> typing.Optional[jsii.Number]:
        """
        :stability: experimental
        """
        result = self._values.get("count")
        return result

    @builtins.property
    def depends_on(self) -> typing.Optional[typing.List[cdktf.TerraformResource]]:
        """
        :stability: experimental
        """
        result = self._values.get("depends_on")
        return result

    @builtins.property
    def lifecycle(self) -> typing.Optional[cdktf.TerraformResourceLifecycle]:
        """
        :stability: experimental
        """
        result = self._values.get("lifecycle")
        return result

    @builtins.property
    def provider(self) -> typing.Optional[cdktf.TerraformProvider]:
        """
        :stability: experimental
        """
        result = self._values.get("provider")
        return result

    @builtins.property
    def name(self) -> builtins.str:
        result = self._values.get("name")
        assert result is not None, "Required property 'name' is missing"
        return result

    @builtins.property
    def resource_group_name(self) -> builtins.str:
        result = self._values.get("resource_group_name")
        assert result is not None, "Required property 'resource_group_name' is missing"
        return result

    @builtins.property
    def ttl(self) -> jsii.Number:
        result = self._values.get("ttl")
        assert result is not None, "Required property 'ttl' is missing"
        return result

    @builtins.property
    def zone_name(self) -> builtins.str:
        result = self._values.get("zone_name")
        assert result is not None, "Required property 'zone_name' is missing"
        return result

    @builtins.property
    def records(self) -> typing.Optional[typing.List[builtins.str]]:
        result = self._values.get("records")
        return result

    @builtins.property
    def tags(self) -> typing.Optional[typing.Mapping[builtins.str, builtins.str]]:
        result = self._values.get("tags")
        return result

    @builtins.property
    def target_resource_id(self) -> typing.Optional[builtins.str]:
        result = self._values.get("target_resource_id")
        return result

    @builtins.property
    def timeouts(self) -> typing.Optional["DnsARecordTimeouts"]:
        """timeouts block."""
        result = self._values.get("timeouts")
        return result

    def __eq__(self, rhs: typing.Any) -> builtins.bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs: typing.Any) -> builtins.bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return "DnsARecordConfig(%s)" % ", ".join(
            k + "=" + repr(v) for k, v in self._values.items()
        )


@jsii.data_type(
    jsii_type="@cdktf/provider-azurerm.DnsARecordTimeouts",
    jsii_struct_bases=[],
    name_mapping={
        "create": "create",
        "delete": "delete",
        "read": "read",
        "update": "update",
    },
)
class DnsARecordTimeouts:
    def __init__(
        self,
        *,
        create: typing.Optional[builtins.str] = None,
        delete: typing.Optional[builtins.str] = None,
        read: typing.Optional[builtins.str] = None,
        update: typing.Optional[builtins.str] = None,
    ) -> None:
        """
        :param create: 
        :param delete: 
        :param read: 
        :param update: 
        """
        self._values: typing.Dict[str, typing.Any] = {}
        if create is not None:
            self._values["create"] = create
        if delete is not None:
            self._values["delete"] = delete
        if read is not None:
            self._values["read"] = read
        if update is not None:
            self._values["update"] = update

    @builtins.property
    def create(self) -> typing.Optional[builtins.str]:
        result = self._values.get("create")
        return result

    @builtins.property
    def delete(self) -> typing.Optional[builtins.str]:
        result = self._values.get("delete")
        return result

    @builtins.property
    def read(self) -> typing.Optional[builtins.str]:
        result = self._values.get("read")
        return result

    @builtins.property
    def update(self) -> typing.Optional[builtins.str]:
        result = self._values.get("update")
        return result

    def __eq__(self, rhs: typing.Any) -> builtins.bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs: typing.Any) -> builtins.bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return "DnsARecordTimeouts(%s)" % ", ".join(
            k + "=" + repr(v) for k, v in self._values.items()
        )


class DnsAaaaRecord(
    cdktf.TerraformResource,
    metaclass=jsii.JSIIMeta,
    jsii_type="@cdktf/provider-azurerm.DnsAaaaRecord",
):
    def __init__(
        self,
        scope: constructs.Construct,
        id: builtins.str,
        *,
        name: builtins.str,
        resource_group_name: builtins.str,
        ttl: jsii.Number,
        zone_name: builtins.str,
        records: typing.Optional[typing.List[builtins.str]] = None,
        tags: typing.Optional[typing.Mapping[builtins.str, builtins.str]] = None,
        target_resource_id: typing.Optional[builtins.str] = None,
        timeouts: typing.Optional["DnsAaaaRecordTimeouts"] = None,
        count: typing.Optional[jsii.Number] = None,
        depends_on: typing.Optional[typing.List[cdktf.TerraformResource]] = None,
        lifecycle: typing.Optional[cdktf.TerraformResourceLifecycle] = None,
        provider: typing.Optional[cdktf.TerraformProvider] = None,
    ) -> None:
        """
        :param scope: -
        :param id: -
        :param name: 
        :param resource_group_name: 
        :param ttl: 
        :param zone_name: 
        :param records: 
        :param tags: 
        :param target_resource_id: 
        :param timeouts: timeouts block.
        :param count: 
        :param depends_on: 
        :param lifecycle: 
        :param provider: 
        """
        config = DnsAaaaRecordConfig(
            name=name,
            resource_group_name=resource_group_name,
            ttl=ttl,
            zone_name=zone_name,
            records=records,
            tags=tags,
            target_resource_id=target_resource_id,
            timeouts=timeouts,
            count=count,
            depends_on=depends_on,
            lifecycle=lifecycle,
            provider=provider,
        )

        jsii.create(DnsAaaaRecord, self, [scope, id, config])

    @jsii.member(jsii_name="synthesizeAttributes")
    def _synthesize_attributes(self) -> typing.Mapping[builtins.str, typing.Any]:
        return jsii.invoke(self, "synthesizeAttributes", [])

    @builtins.property # type: ignore
    @jsii.member(jsii_name="fqdn")
    def fqdn(self) -> builtins.str:
        return jsii.get(self, "fqdn")

    @builtins.property # type: ignore
    @jsii.member(jsii_name="name")
    def name(self) -> builtins.str:
        return jsii.get(self, "name")

    @name.setter # type: ignore
    def name(self, value: builtins.str) -> None:
        jsii.set(self, "name", value)

    @builtins.property # type: ignore
    @jsii.member(jsii_name="resourceGroupName")
    def resource_group_name(self) -> builtins.str:
        return jsii.get(self, "resourceGroupName")

    @resource_group_name.setter # type: ignore
    def resource_group_name(self, value: builtins.str) -> None:
        jsii.set(self, "resourceGroupName", value)

    @builtins.property # type: ignore
    @jsii.member(jsii_name="ttl")
    def ttl(self) -> jsii.Number:
        return jsii.get(self, "ttl")

    @ttl.setter # type: ignore
    def ttl(self, value: jsii.Number) -> None:
        jsii.set(self, "ttl", value)

    @builtins.property # type: ignore
    @jsii.member(jsii_name="zoneName")
    def zone_name(self) -> builtins.str:
        return jsii.get(self, "zoneName")

    @zone_name.setter # type: ignore
    def zone_name(self, value: builtins.str) -> None:
        jsii.set(self, "zoneName", value)

    @builtins.property # type: ignore
    @jsii.member(jsii_name="id")
    def id(self) -> typing.Optional[builtins.str]:
        return jsii.get(self, "id")

    @id.setter # type: ignore
    def id(self, value: typing.Optional[builtins.str]) -> None:
        jsii.set(self, "id", value)

    @builtins.property # type: ignore
    @jsii.member(jsii_name="records")
    def records(self) -> typing.Optional[typing.List[builtins.str]]:
        return jsii.get(self, "records")

    @records.setter # type: ignore
    def records(self, value: typing.Optional[typing.List[builtins.str]]) -> None:
        jsii.set(self, "records", value)

    @builtins.property # type: ignore
    @jsii.member(jsii_name="tags")
    def tags(self) -> typing.Optional[typing.Mapping[builtins.str, builtins.str]]:
        return jsii.get(self, "tags")

    @tags.setter # type: ignore
    def tags(
        self,
        value: typing.Optional[typing.Mapping[builtins.str, builtins.str]],
    ) -> None:
        jsii.set(self, "tags", value)

    @builtins.property # type: ignore
    @jsii.member(jsii_name="targetResourceId")
    def target_resource_id(self) -> typing.Optional[builtins.str]:
        return jsii.get(self, "targetResourceId")

    @target_resource_id.setter # type: ignore
    def target_resource_id(self, value: typing.Optional[builtins.str]) -> None:
        jsii.set(self, "targetResourceId", value)

    @builtins.property # type: ignore
    @jsii.member(jsii_name="timeouts")
    def timeouts(self) -> typing.Optional["DnsAaaaRecordTimeouts"]:
        return jsii.get(self, "timeouts")

    @timeouts.setter # type: ignore
    def timeouts(self, value: typing.Optional["DnsAaaaRecordTimeouts"]) -> None:
        jsii.set(self, "timeouts", value)


@jsii.data_type(
    jsii_type="@cdktf/provider-azurerm.DnsAaaaRecordConfig",
    jsii_struct_bases=[cdktf.TerraformMetaArguments],
    name_mapping={
        "count": "count",
        "depends_on": "dependsOn",
        "lifecycle": "lifecycle",
        "provider": "provider",
        "name": "name",
        "resource_group_name": "resourceGroupName",
        "ttl": "ttl",
        "zone_name": "zoneName",
        "records": "records",
        "tags": "tags",
        "target_resource_id": "targetResourceId",
        "timeouts": "timeouts",
    },
)
class DnsAaaaRecordConfig(cdktf.TerraformMetaArguments):
    def __init__(
        self,
        *,
        count: typing.Optional[jsii.Number] = None,
        depends_on: typing.Optional[typing.List[cdktf.TerraformResource]] = None,
        lifecycle: typing.Optional[cdktf.TerraformResourceLifecycle] = None,
        provider: typing.Optional[cdktf.TerraformProvider] = None,
        name: builtins.str,
        resource_group_name: builtins.str,
        ttl: jsii.Number,
        zone_name: builtins.str,
        records: typing.Optional[typing.List[builtins.str]] = None,
        tags: typing.Optional[typing.Mapping[builtins.str, builtins.str]] = None,
        target_resource_id: typing.Optional[builtins.str] = None,
        timeouts: typing.Optional["DnsAaaaRecordTimeouts"] = None,
    ) -> None:
        """
        :param count: 
        :param depends_on: 
        :param lifecycle: 
        :param provider: 
        :param name: 
        :param resource_group_name: 
        :param ttl: 
        :param zone_name: 
        :param records: 
        :param tags: 
        :param target_resource_id: 
        :param timeouts: timeouts block.
        """
        if isinstance(lifecycle, dict):
            lifecycle = cdktf.TerraformResourceLifecycle(**lifecycle)
        if isinstance(timeouts, dict):
            timeouts = DnsAaaaRecordTimeouts(**timeouts)
        self._values: typing.Dict[str, typing.Any] = {
            "name": name,
            "resource_group_name": resource_group_name,
            "ttl": ttl,
            "zone_name": zone_name,
        }
        if count is not None:
            self._values["count"] = count
        if depends_on is not None:
            self._values["depends_on"] = depends_on
        if lifecycle is not None:
            self._values["lifecycle"] = lifecycle
        if provider is not None:
            self._values["provider"] = provider
        if records is not None:
            self._values["records"] = records
        if tags is not None:
            self._values["tags"] = tags
        if target_resource_id is not None:
            self._values["target_resource_id"] = target_resource_id
        if timeouts is not None:
            self._values["timeouts"] = timeouts

    @builtins.property
    def count(self) -> typing.Optional[jsii.Number]:
        """
        :stability: experimental
        """
        result = self._values.get("count")
        return result

    @builtins.property
    def depends_on(self) -> typing.Optional[typing.List[cdktf.TerraformResource]]:
        """
        :stability: experimental
        """
        result = self._values.get("depends_on")
        return result

    @builtins.property
    def lifecycle(self) -> typing.Optional[cdktf.TerraformResourceLifecycle]:
        """
        :stability: experimental
        """
        result = self._values.get("lifecycle")
        return result

    @builtins.property
    def provider(self) -> typing.Optional[cdktf.TerraformProvider]:
        """
        :stability: experimental
        """
        result = self._values.get("provider")
        return result

    @builtins.property
    def name(self) -> builtins.str:
        result = self._values.get("name")
        assert result is not None, "Required property 'name' is missing"
        return result

    @builtins.property
    def resource_group_name(self) -> builtins.str:
        result = self._values.get("resource_group_name")
        assert result is not None, "Required property 'resource_group_name' is missing"
        return result

    @builtins.property
    def ttl(self) -> jsii.Number:
        result = self._values.get("ttl")
        assert result is not None, "Required property 'ttl' is missing"
        return result

    @builtins.property
    def zone_name(self) -> builtins.str:
        result = self._values.get("zone_name")
        assert result is not None, "Required property 'zone_name' is missing"
        return result

    @builtins.property
    def records(self) -> typing.Optional[typing.List[builtins.str]]:
        result = self._values.get("records")
        return result

    @builtins.property
    def tags(self) -> typing.Optional[typing.Mapping[builtins.str, builtins.str]]:
        result = self._values.get("tags")
        return result

    @builtins.property
    def target_resource_id(self) -> typing.Optional[builtins.str]:
        result = self._values.get("target_resource_id")
        return result

    @builtins.property
    def timeouts(self) -> typing.Optional["DnsAaaaRecordTimeouts"]:
        """timeouts block."""
        result = self._values.get("timeouts")
        return result

    def __eq__(self, rhs: typing.Any) -> builtins.bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs: typing.Any) -> builtins.bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return "DnsAaaaRecordConfig(%s)" % ", ".join(
            k + "=" + repr(v) for k, v in self._values.items()
        )


@jsii.data_type(
    jsii_type="@cdktf/provider-azurerm.DnsAaaaRecordTimeouts",
    jsii_struct_bases=[],
    name_mapping={
        "create": "create",
        "delete": "delete",
        "read": "read",
        "update": "update",
    },
)
class DnsAaaaRecordTimeouts:
    def __init__(
        self,
        *,
        create: typing.Optional[builtins.str] = None,
        delete: typing.Optional[builtins.str] = None,
        read: typing.Optional[builtins.str] = None,
        update: typing.Optional[builtins.str] = None,
    ) -> None:
        """
        :param create: 
        :param delete: 
        :param read: 
        :param update: 
        """
        self._values: typing.Dict[str, typing.Any] = {}
        if create is not None:
            self._values["create"] = create
        if delete is not None:
            self._values["delete"] = delete
        if read is not None:
            self._values["read"] = read
        if update is not None:
            self._values["update"] = update

    @builtins.property
    def create(self) -> typing.Optional[builtins.str]:
        result = self._values.get("create")
        return result

    @builtins.property
    def delete(self) -> typing.Optional[builtins.str]:
        result = self._values.get("delete")
        return result

    @builtins.property
    def read(self) -> typing.Optional[builtins.str]:
        result = self._values.get("read")
        return result

    @builtins.property
    def update(self) -> typing.Optional[builtins.str]:
        result = self._values.get("update")
        return result

    def __eq__(self, rhs: typing.Any) -> builtins.bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs: typing.Any) -> builtins.bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return "DnsAaaaRecordTimeouts(%s)" % ", ".join(
            k + "=" + repr(v) for k, v in self._values.items()
        )


class DnsCaaRecord(
    cdktf.TerraformResource,
    metaclass=jsii.JSIIMeta,
    jsii_type="@cdktf/provider-azurerm.DnsCaaRecord",
):
    def __init__(
        self,
        scope: constructs.Construct,
        id: builtins.str,
        *,
        name: builtins.str,
        record: typing.List["DnsCaaRecordRecord"],
        resource_group_name: builtins.str,
        ttl: jsii.Number,
        zone_name: builtins.str,
        tags: typing.Optional[typing.Mapping[builtins.str, builtins.str]] = None,
        timeouts: typing.Optional["DnsCaaRecordTimeouts"] = None,
        count: typing.Optional[jsii.Number] = None,
        depends_on: typing.Optional[typing.List[cdktf.TerraformResource]] = None,
        lifecycle: typing.Optional[cdktf.TerraformResourceLifecycle] = None,
        provider: typing.Optional[cdktf.TerraformProvider] = None,
    ) -> None:
        """
        :param scope: -
        :param id: -
        :param name: 
        :param record: record block.
        :param resource_group_name: 
        :param ttl: 
        :param zone_name: 
        :param tags: 
        :param timeouts: timeouts block.
        :param count: 
        :param depends_on: 
        :param lifecycle: 
        :param provider: 
        """
        config = DnsCaaRecordConfig(
            name=name,
            record=record,
            resource_group_name=resource_group_name,
            ttl=ttl,
            zone_name=zone_name,
            tags=tags,
            timeouts=timeouts,
            count=count,
            depends_on=depends_on,
            lifecycle=lifecycle,
            provider=provider,
        )

        jsii.create(DnsCaaRecord, self, [scope, id, config])

    @jsii.member(jsii_name="synthesizeAttributes")
    def _synthesize_attributes(self) -> typing.Mapping[builtins.str, typing.Any]:
        return jsii.invoke(self, "synthesizeAttributes", [])

    @builtins.property # type: ignore
    @jsii.member(jsii_name="fqdn")
    def fqdn(self) -> builtins.str:
        return jsii.get(self, "fqdn")

    @builtins.property # type: ignore
    @jsii.member(jsii_name="name")
    def name(self) -> builtins.str:
        return jsii.get(self, "name")

    @name.setter # type: ignore
    def name(self, value: builtins.str) -> None:
        jsii.set(self, "name", value)

    @builtins.property # type: ignore
    @jsii.member(jsii_name="record")
    def record(self) -> typing.List["DnsCaaRecordRecord"]:
        return jsii.get(self, "record")

    @record.setter # type: ignore
    def record(self, value: typing.List["DnsCaaRecordRecord"]) -> None:
        jsii.set(self, "record", value)

    @builtins.property # type: ignore
    @jsii.member(jsii_name="resourceGroupName")
    def resource_group_name(self) -> builtins.str:
        return jsii.get(self, "resourceGroupName")

    @resource_group_name.setter # type: ignore
    def resource_group_name(self, value: builtins.str) -> None:
        jsii.set(self, "resourceGroupName", value)

    @builtins.property # type: ignore
    @jsii.member(jsii_name="ttl")
    def ttl(self) -> jsii.Number:
        return jsii.get(self, "ttl")

    @ttl.setter # type: ignore
    def ttl(self, value: jsii.Number) -> None:
        jsii.set(self, "ttl", value)

    @builtins.property # type: ignore
    @jsii.member(jsii_name="zoneName")
    def zone_name(self) -> builtins.str:
        return jsii.get(self, "zoneName")

    @zone_name.setter # type: ignore
    def zone_name(self, value: builtins.str) -> None:
        jsii.set(self, "zoneName", value)

    @builtins.property # type: ignore
    @jsii.member(jsii_name="id")
    def id(self) -> typing.Optional[builtins.str]:
        return jsii.get(self, "id")

    @id.setter # type: ignore
    def id(self, value: typing.Optional[builtins.str]) -> None:
        jsii.set(self, "id", value)

    @builtins.property # type: ignore
    @jsii.member(jsii_name="tags")
    def tags(self) -> typing.Optional[typing.Mapping[builtins.str, builtins.str]]:
        return jsii.get(self, "tags")

    @tags.setter # type: ignore
    def tags(
        self,
        value: typing.Optional[typing.Mapping[builtins.str, builtins.str]],
    ) -> None:
        jsii.set(self, "tags", value)

    @builtins.property # type: ignore
    @jsii.member(jsii_name="timeouts")
    def timeouts(self) -> typing.Optional["DnsCaaRecordTimeouts"]:
        return jsii.get(self, "timeouts")

    @timeouts.setter # type: ignore
    def timeouts(self, value: typing.Optional["DnsCaaRecordTimeouts"]) -> None:
        jsii.set(self, "timeouts", value)


@jsii.data_type(
    jsii_type="@cdktf/provider-azurerm.DnsCaaRecordConfig",
    jsii_struct_bases=[cdktf.TerraformMetaArguments],
    name_mapping={
        "count": "count",
        "depends_on": "dependsOn",
        "lifecycle": "lifecycle",
        "provider": "provider",
        "name": "name",
        "record": "record",
        "resource_group_name": "resourceGroupName",
        "ttl": "ttl",
        "zone_name": "zoneName",
        "tags": "tags",
        "timeouts": "timeouts",
    },
)
class DnsCaaRecordConfig(cdktf.TerraformMetaArguments):
    def __init__(
        self,
        *,
        count: typing.Optional[jsii.Number] = None,
        depends_on: typing.Optional[typing.List[cdktf.TerraformResource]] = None,
        lifecycle: typing.Optional[cdktf.TerraformResourceLifecycle] = None,
        provider: typing.Optional[cdktf.TerraformProvider] = None,
        name: builtins.str,
        record: typing.List["DnsCaaRecordRecord"],
        resource_group_name: builtins.str,
        ttl: jsii.Number,
        zone_name: builtins.str,
        tags: typing.Optional[typing.Mapping[builtins.str, builtins.str]] = None,
        timeouts: typing.Optional["DnsCaaRecordTimeouts"] = None,
    ) -> None:
        """
        :param count: 
        :param depends_on: 
        :param lifecycle: 
        :param provider: 
        :param name: 
        :param record: record block.
        :param resource_group_name: 
        :param ttl: 
        :param zone_name: 
        :param tags: 
        :param timeouts: timeouts block.
        """
        if isinstance(lifecycle, dict):
            lifecycle = cdktf.TerraformResourceLifecycle(**lifecycle)
        if isinstance(timeouts, dict):
            timeouts = DnsCaaRecordTimeouts(**timeouts)
        self._values: typing.Dict[str, typing.Any] = {
            "name": name,
            "record": record,
            "resource_group_name": resource_group_name,
            "ttl": ttl,
            "zone_name": zone_name,
        }
        if count is not None:
            self._values["count"] = count
        if depends_on is not None:
            self._values["depends_on"] = depends_on
        if lifecycle is not None:
            self._values["lifecycle"] = lifecycle
        if provider is not None:
            self._values["provider"] = provider
        if tags is not None:
            self._values["tags"] = tags
        if timeouts is not None:
            self._values["timeouts"] = timeouts

    @builtins.property
    def count(self) -> typing.Optional[jsii.Number]:
        """
        :stability: experimental
        """
        result = self._values.get("count")
        return result

    @builtins.property
    def depends_on(self) -> typing.Optional[typing.List[cdktf.TerraformResource]]:
        """
        :stability: experimental
        """
        result = self._values.get("depends_on")
        return result

    @builtins.property
    def lifecycle(self) -> typing.Optional[cdktf.TerraformResourceLifecycle]:
        """
        :stability: experimental
        """
        result = self._values.get("lifecycle")
        return result

    @builtins.property
    def provider(self) -> typing.Optional[cdktf.TerraformProvider]:
        """
        :stability: experimental
        """
        result = self._values.get("provider")
        return result

    @builtins.property
    def name(self) -> builtins.str:
        result = self._values.get("name")
        assert result is not None, "Required property 'name' is missing"
        return result

    @builtins.property
    def record(self) -> typing.List["DnsCaaRecordRecord"]:
        """record block."""
        result = self._values.get("record")
        assert result is not None, "Required property 'record' is missing"
        return result

    @builtins.property
    def resource_group_name(self) -> builtins.str:
        result = self._values.get("resource_group_name")
        assert result is not None, "Required property 'resource_group_name' is missing"
        return result

    @builtins.property
    def ttl(self) -> jsii.Number:
        result = self._values.get("ttl")
        assert result is not None, "Required property 'ttl' is missing"
        return result

    @builtins.property
    def zone_name(self) -> builtins.str:
        result = self._values.get("zone_name")
        assert result is not None, "Required property 'zone_name' is missing"
        return result

    @builtins.property
    def tags(self) -> typing.Optional[typing.Mapping[builtins.str, builtins.str]]:
        result = self._values.get("tags")
        return result

    @builtins.property
    def timeouts(self) -> typing.Optional["DnsCaaRecordTimeouts"]:
        """timeouts block."""
        result = self._values.get("timeouts")
        return result

    def __eq__(self, rhs: typing.Any) -> builtins.bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs: typing.Any) -> builtins.bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return "DnsCaaRecordConfig(%s)" % ", ".join(
            k + "=" + repr(v) for k, v in self._values.items()
        )


@jsii.data_type(
    jsii_type="@cdktf/provider-azurerm.DnsCaaRecordRecord",
    jsii_struct_bases=[],
    name_mapping={"flags": "flags", "tag": "tag", "value": "value"},
)
class DnsCaaRecordRecord:
    def __init__(
        self,
        *,
        flags: jsii.Number,
        tag: builtins.str,
        value: builtins.str,
    ) -> None:
        """
        :param flags: 
        :param tag: 
        :param value: 
        """
        self._values: typing.Dict[str, typing.Any] = {
            "flags": flags,
            "tag": tag,
            "value": value,
        }

    @builtins.property
    def flags(self) -> jsii.Number:
        result = self._values.get("flags")
        assert result is not None, "Required property 'flags' is missing"
        return result

    @builtins.property
    def tag(self) -> builtins.str:
        result = self._values.get("tag")
        assert result is not None, "Required property 'tag' is missing"
        return result

    @builtins.property
    def value(self) -> builtins.str:
        result = self._values.get("value")
        assert result is not None, "Required property 'value' is missing"
        return result

    def __eq__(self, rhs: typing.Any) -> builtins.bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs: typing.Any) -> builtins.bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return "DnsCaaRecordRecord(%s)" % ", ".join(
            k + "=" + repr(v) for k, v in self._values.items()
        )


@jsii.data_type(
    jsii_type="@cdktf/provider-azurerm.DnsCaaRecordTimeouts",
    jsii_struct_bases=[],
    name_mapping={
        "create": "create",
        "delete": "delete",
        "read": "read",
        "update": "update",
    },
)
class DnsCaaRecordTimeouts:
    def __init__(
        self,
        *,
        create: typing.Optional[builtins.str] = None,
        delete: typing.Optional[builtins.str] = None,
        read: typing.Optional[builtins.str] = None,
        update: typing.Optional[builtins.str] = None,
    ) -> None:
        """
        :param create: 
        :param delete: 
        :param read: 
        :param update: 
        """
        self._values: typing.Dict[str, typing.Any] = {}
        if create is not None:
            self._values["create"] = create
        if delete is not None:
            self._values["delete"] = delete
        if read is not None:
            self._values["read"] = read
        if update is not None:
            self._values["update"] = update

    @builtins.property
    def create(self) -> typing.Optional[builtins.str]:
        result = self._values.get("create")
        return result

    @builtins.property
    def delete(self) -> typing.Optional[builtins.str]:
        result = self._values.get("delete")
        return result

    @builtins.property
    def read(self) -> typing.Optional[builtins.str]:
        result = self._values.get("read")
        return result

    @builtins.property
    def update(self) -> typing.Optional[builtins.str]:
        result = self._values.get("update")
        return result

    def __eq__(self, rhs: typing.Any) -> builtins.bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs: typing.Any) -> builtins.bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return "DnsCaaRecordTimeouts(%s)" % ", ".join(
            k + "=" + repr(v) for k, v in self._values.items()
        )


class DnsCnameRecord(
    cdktf.TerraformResource,
    metaclass=jsii.JSIIMeta,
    jsii_type="@cdktf/provider-azurerm.DnsCnameRecord",
):
    def __init__(
        self,
        scope: constructs.Construct,
        id: builtins.str,
        *,
        name: builtins.str,
        resource_group_name: builtins.str,
        ttl: jsii.Number,
        zone_name: builtins.str,
        record: typing.Optional[builtins.str] = None,
        tags: typing.Optional[typing.Mapping[builtins.str, builtins.str]] = None,
        target_resource_id: typing.Optional[builtins.str] = None,
        timeouts: typing.Optional["DnsCnameRecordTimeouts"] = None,
        count: typing.Optional[jsii.Number] = None,
        depends_on: typing.Optional[typing.List[cdktf.TerraformResource]] = None,
        lifecycle: typing.Optional[cdktf.TerraformResourceLifecycle] = None,
        provider: typing.Optional[cdktf.TerraformProvider] = None,
    ) -> None:
        """
        :param scope: -
        :param id: -
        :param name: 
        :param resource_group_name: 
        :param ttl: 
        :param zone_name: 
        :param record: 
        :param tags: 
        :param target_resource_id: 
        :param timeouts: timeouts block.
        :param count: 
        :param depends_on: 
        :param lifecycle: 
        :param provider: 
        """
        config = DnsCnameRecordConfig(
            name=name,
            resource_group_name=resource_group_name,
            ttl=ttl,
            zone_name=zone_name,
            record=record,
            tags=tags,
            target_resource_id=target_resource_id,
            timeouts=timeouts,
            count=count,
            depends_on=depends_on,
            lifecycle=lifecycle,
            provider=provider,
        )

        jsii.create(DnsCnameRecord, self, [scope, id, config])

    @jsii.member(jsii_name="synthesizeAttributes")
    def _synthesize_attributes(self) -> typing.Mapping[builtins.str, typing.Any]:
        return jsii.invoke(self, "synthesizeAttributes", [])

    @builtins.property # type: ignore
    @jsii.member(jsii_name="fqdn")
    def fqdn(self) -> builtins.str:
        return jsii.get(self, "fqdn")

    @builtins.property # type: ignore
    @jsii.member(jsii_name="name")
    def name(self) -> builtins.str:
        return jsii.get(self, "name")

    @name.setter # type: ignore
    def name(self, value: builtins.str) -> None:
        jsii.set(self, "name", value)

    @builtins.property # type: ignore
    @jsii.member(jsii_name="resourceGroupName")
    def resource_group_name(self) -> builtins.str:
        return jsii.get(self, "resourceGroupName")

    @resource_group_name.setter # type: ignore
    def resource_group_name(self, value: builtins.str) -> None:
        jsii.set(self, "resourceGroupName", value)

    @builtins.property # type: ignore
    @jsii.member(jsii_name="ttl")
    def ttl(self) -> jsii.Number:
        return jsii.get(self, "ttl")

    @ttl.setter # type: ignore
    def ttl(self, value: jsii.Number) -> None:
        jsii.set(self, "ttl", value)

    @builtins.property # type: ignore
    @jsii.member(jsii_name="zoneName")
    def zone_name(self) -> builtins.str:
        return jsii.get(self, "zoneName")

    @zone_name.setter # type: ignore
    def zone_name(self, value: builtins.str) -> None:
        jsii.set(self, "zoneName", value)

    @builtins.property # type: ignore
    @jsii.member(jsii_name="id")
    def id(self) -> typing.Optional[builtins.str]:
        return jsii.get(self, "id")

    @id.setter # type: ignore
    def id(self, value: typing.Optional[builtins.str]) -> None:
        jsii.set(self, "id", value)

    @builtins.property # type: ignore
    @jsii.member(jsii_name="record")
    def record(self) -> typing.Optional[builtins.str]:
        return jsii.get(self, "record")

    @record.setter # type: ignore
    def record(self, value: typing.Optional[builtins.str]) -> None:
        jsii.set(self, "record", value)

    @builtins.property # type: ignore
    @jsii.member(jsii_name="tags")
    def tags(self) -> typing.Optional[typing.Mapping[builtins.str, builtins.str]]:
        return jsii.get(self, "tags")

    @tags.setter # type: ignore
    def tags(
        self,
        value: typing.Optional[typing.Mapping[builtins.str, builtins.str]],
    ) -> None:
        jsii.set(self, "tags", value)

    @builtins.property # type: ignore
    @jsii.member(jsii_name="targetResourceId")
    def target_resource_id(self) -> typing.Optional[builtins.str]:
        return jsii.get(self, "targetResourceId")

    @target_resource_id.setter # type: ignore
    def target_resource_id(self, value: typing.Optional[builtins.str]) -> None:
        jsii.set(self, "targetResourceId", value)

    @builtins.property # type: ignore
    @jsii.member(jsii_name="timeouts")
    def timeouts(self) -> typing.Optional["DnsCnameRecordTimeouts"]:
        return jsii.get(self, "timeouts")

    @timeouts.setter # type: ignore
    def timeouts(self, value: typing.Optional["DnsCnameRecordTimeouts"]) -> None:
        jsii.set(self, "timeouts", value)


@jsii.data_type(
    jsii_type="@cdktf/provider-azurerm.DnsCnameRecordConfig",
    jsii_struct_bases=[cdktf.TerraformMetaArguments],
    name_mapping={
        "count": "count",
        "depends_on": "dependsOn",
        "lifecycle": "lifecycle",
        "provider": "provider",
        "name": "name",
        "resource_group_name": "resourceGroupName",
        "ttl": "ttl",
        "zone_name": "zoneName",
        "record": "record",
        "tags": "tags",
        "target_resource_id": "targetResourceId",
        "timeouts": "timeouts",
    },
)
class DnsCnameRecordConfig(cdktf.TerraformMetaArguments):
    def __init__(
        self,
        *,
        count: typing.Optional[jsii.Number] = None,
        depends_on: typing.Optional[typing.List[cdktf.TerraformResource]] = None,
        lifecycle: typing.Optional[cdktf.TerraformResourceLifecycle] = None,
        provider: typing.Optional[cdktf.TerraformProvider] = None,
        name: builtins.str,
        resource_group_name: builtins.str,
        ttl: jsii.Number,
        zone_name: builtins.str,
        record: typing.Optional[builtins.str] = None,
        tags: typing.Optional[typing.Mapping[builtins.str, builtins.str]] = None,
        target_resource_id: typing.Optional[builtins.str] = None,
        timeouts: typing.Optional["DnsCnameRecordTimeouts"] = None,
    ) -> None:
        """
        :param count: 
        :param depends_on: 
        :param lifecycle: 
        :param provider: 
        :param name: 
        :param resource_group_name: 
        :param ttl: 
        :param zone_name: 
        :param record: 
        :param tags: 
        :param target_resource_id: 
        :param timeouts: timeouts block.
        """
        if isinstance(lifecycle, dict):
            lifecycle = cdktf.TerraformResourceLifecycle(**lifecycle)
        if isinstance(timeouts, dict):
            timeouts = DnsCnameRecordTimeouts(**timeouts)
        self._values: typing.Dict[str, typing.Any] = {
            "name": name,
            "resource_group_name": resource_group_name,
            "ttl": ttl,
            "zone_name": zone_name,
        }
        if count is not None:
            self._values["count"] = count
        if depends_on is not None:
            self._values["depends_on"] = depends_on
        if lifecycle is not None:
            self._values["lifecycle"] = lifecycle
        if provider is not None:
            self._values["provider"] = provider
        if record is not None:
            self._values["record"] = record
        if tags is not None:
            self._values["tags"] = tags
        if target_resource_id is not None:
            self._values["target_resource_id"] = target_resource_id
        if timeouts is not None:
            self._values["timeouts"] = timeouts

    @builtins.property
    def count(self) -> typing.Optional[jsii.Number]:
        """
        :stability: experimental
        """
        result = self._values.get("count")
        return result

    @builtins.property
    def depends_on(self) -> typing.Optional[typing.List[cdktf.TerraformResource]]:
        """
        :stability: experimental
        """
        result = self._values.get("depends_on")
        return result

    @builtins.property
    def lifecycle(self) -> typing.Optional[cdktf.TerraformResourceLifecycle]:
        """
        :stability: experimental
        """
        result = self._values.get("lifecycle")
        return result

    @builtins.property
    def provider(self) -> typing.Optional[cdktf.TerraformProvider]:
        """
        :stability: experimental
        """
        result = self._values.get("provider")
        return result

    @builtins.property
    def name(self) -> builtins.str:
        result = self._values.get("name")
        assert result is not None, "Required property 'name' is missing"
        return result

    @builtins.property
    def resource_group_name(self) -> builtins.str:
        result = self._values.get("resource_group_name")
        assert result is not None, "Required property 'resource_group_name' is missing"
        return result

    @builtins.property
    def ttl(self) -> jsii.Number:
        result = self._values.get("ttl")
        assert result is not None, "Required property 'ttl' is missing"
        return result

    @builtins.property
    def zone_name(self) -> builtins.str:
        result = self._values.get("zone_name")
        assert result is not None, "Required property 'zone_name' is missing"
        return result

    @builtins.property
    def record(self) -> typing.Optional[builtins.str]:
        result = self._values.get("record")
        return result

    @builtins.property
    def tags(self) -> typing.Optional[typing.Mapping[builtins.str, builtins.str]]:
        result = self._values.get("tags")
        return result

    @builtins.property
    def target_resource_id(self) -> typing.Optional[builtins.str]:
        result = self._values.get("target_resource_id")
        return result

    @builtins.property
    def timeouts(self) -> typing.Optional["DnsCnameRecordTimeouts"]:
        """timeouts block."""
        result = self._values.get("timeouts")
        return result

    def __eq__(self, rhs: typing.Any) -> builtins.bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs: typing.Any) -> builtins.bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return "DnsCnameRecordConfig(%s)" % ", ".join(
            k + "=" + repr(v) for k, v in self._values.items()
        )


@jsii.data_type(
    jsii_type="@cdktf/provider-azurerm.DnsCnameRecordTimeouts",
    jsii_struct_bases=[],
    name_mapping={
        "create": "create",
        "delete": "delete",
        "read": "read",
        "update": "update",
    },
)
class DnsCnameRecordTimeouts:
    def __init__(
        self,
        *,
        create: typing.Optional[builtins.str] = None,
        delete: typing.Optional[builtins.str] = None,
        read: typing.Optional[builtins.str] = None,
        update: typing.Optional[builtins.str] = None,
    ) -> None:
        """
        :param create: 
        :param delete: 
        :param read: 
        :param update: 
        """
        self._values: typing.Dict[str, typing.Any] = {}
        if create is not None:
            self._values["create"] = create
        if delete is not None:
            self._values["delete"] = delete
        if read is not None:
            self._values["read"] = read
        if update is not None:
            self._values["update"] = update

    @builtins.property
    def create(self) -> typing.Optional[builtins.str]:
        result = self._values.get("create")
        return result

    @builtins.property
    def delete(self) -> typing.Optional[builtins.str]:
        result = self._values.get("delete")
        return result

    @builtins.property
    def read(self) -> typing.Optional[builtins.str]:
        result = self._values.get("read")
        return result

    @builtins.property
    def update(self) -> typing.Optional[builtins.str]:
        result = self._values.get("update")
        return result

    def __eq__(self, rhs: typing.Any) -> builtins.bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs: typing.Any) -> builtins.bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return "DnsCnameRecordTimeouts(%s)" % ", ".join(
            k + "=" + repr(v) for k, v in self._values.items()
        )


class DnsMxRecord(
    cdktf.TerraformResource,
    metaclass=jsii.JSIIMeta,
    jsii_type="@cdktf/provider-azurerm.DnsMxRecord",
):
    def __init__(
        self,
        scope: constructs.Construct,
        id: builtins.str,
        *,
        record: typing.List["DnsMxRecordRecord"],
        resource_group_name: builtins.str,
        ttl: jsii.Number,
        zone_name: builtins.str,
        name: typing.Optional[builtins.str] = None,
        tags: typing.Optional[typing.Mapping[builtins.str, builtins.str]] = None,
        timeouts: typing.Optional["DnsMxRecordTimeouts"] = None,
        count: typing.Optional[jsii.Number] = None,
        depends_on: typing.Optional[typing.List[cdktf.TerraformResource]] = None,
        lifecycle: typing.Optional[cdktf.TerraformResourceLifecycle] = None,
        provider: typing.Optional[cdktf.TerraformProvider] = None,
    ) -> None:
        """
        :param scope: -
        :param id: -
        :param record: record block.
        :param resource_group_name: 
        :param ttl: 
        :param zone_name: 
        :param name: 
        :param tags: 
        :param timeouts: timeouts block.
        :param count: 
        :param depends_on: 
        :param lifecycle: 
        :param provider: 
        """
        config = DnsMxRecordConfig(
            record=record,
            resource_group_name=resource_group_name,
            ttl=ttl,
            zone_name=zone_name,
            name=name,
            tags=tags,
            timeouts=timeouts,
            count=count,
            depends_on=depends_on,
            lifecycle=lifecycle,
            provider=provider,
        )

        jsii.create(DnsMxRecord, self, [scope, id, config])

    @jsii.member(jsii_name="synthesizeAttributes")
    def _synthesize_attributes(self) -> typing.Mapping[builtins.str, typing.Any]:
        return jsii.invoke(self, "synthesizeAttributes", [])

    @builtins.property # type: ignore
    @jsii.member(jsii_name="fqdn")
    def fqdn(self) -> builtins.str:
        return jsii.get(self, "fqdn")

    @builtins.property # type: ignore
    @jsii.member(jsii_name="record")
    def record(self) -> typing.List["DnsMxRecordRecord"]:
        return jsii.get(self, "record")

    @record.setter # type: ignore
    def record(self, value: typing.List["DnsMxRecordRecord"]) -> None:
        jsii.set(self, "record", value)

    @builtins.property # type: ignore
    @jsii.member(jsii_name="resourceGroupName")
    def resource_group_name(self) -> builtins.str:
        return jsii.get(self, "resourceGroupName")

    @resource_group_name.setter # type: ignore
    def resource_group_name(self, value: builtins.str) -> None:
        jsii.set(self, "resourceGroupName", value)

    @builtins.property # type: ignore
    @jsii.member(jsii_name="ttl")
    def ttl(self) -> jsii.Number:
        return jsii.get(self, "ttl")

    @ttl.setter # type: ignore
    def ttl(self, value: jsii.Number) -> None:
        jsii.set(self, "ttl", value)

    @builtins.property # type: ignore
    @jsii.member(jsii_name="zoneName")
    def zone_name(self) -> builtins.str:
        return jsii.get(self, "zoneName")

    @zone_name.setter # type: ignore
    def zone_name(self, value: builtins.str) -> None:
        jsii.set(self, "zoneName", value)

    @builtins.property # type: ignore
    @jsii.member(jsii_name="id")
    def id(self) -> typing.Optional[builtins.str]:
        return jsii.get(self, "id")

    @id.setter # type: ignore
    def id(self, value: typing.Optional[builtins.str]) -> None:
        jsii.set(self, "id", value)

    @builtins.property # type: ignore
    @jsii.member(jsii_name="name")
    def name(self) -> typing.Optional[builtins.str]:
        return jsii.get(self, "name")

    @name.setter # type: ignore
    def name(self, value: typing.Optional[builtins.str]) -> None:
        jsii.set(self, "name", value)

    @builtins.property # type: ignore
    @jsii.member(jsii_name="tags")
    def tags(self) -> typing.Optional[typing.Mapping[builtins.str, builtins.str]]:
        return jsii.get(self, "tags")

    @tags.setter # type: ignore
    def tags(
        self,
        value: typing.Optional[typing.Mapping[builtins.str, builtins.str]],
    ) -> None:
        jsii.set(self, "tags", value)

    @builtins.property # type: ignore
    @jsii.member(jsii_name="timeouts")
    def timeouts(self) -> typing.Optional["DnsMxRecordTimeouts"]:
        return jsii.get(self, "timeouts")

    @timeouts.setter # type: ignore
    def timeouts(self, value: typing.Optional["DnsMxRecordTimeouts"]) -> None:
        jsii.set(self, "timeouts", value)


@jsii.data_type(
    jsii_type="@cdktf/provider-azurerm.DnsMxRecordConfig",
    jsii_struct_bases=[cdktf.TerraformMetaArguments],
    name_mapping={
        "count": "count",
        "depends_on": "dependsOn",
        "lifecycle": "lifecycle",
        "provider": "provider",
        "record": "record",
        "resource_group_name": "resourceGroupName",
        "ttl": "ttl",
        "zone_name": "zoneName",
        "name": "name",
        "tags": "tags",
        "timeouts": "timeouts",
    },
)
class DnsMxRecordConfig(cdktf.TerraformMetaArguments):
    def __init__(
        self,
        *,
        count: typing.Optional[jsii.Number] = None,
        depends_on: typing.Optional[typing.List[cdktf.TerraformResource]] = None,
        lifecycle: typing.Optional[cdktf.TerraformResourceLifecycle] = None,
        provider: typing.Optional[cdktf.TerraformProvider] = None,
        record: typing.List["DnsMxRecordRecord"],
        resource_group_name: builtins.str,
        ttl: jsii.Number,
        zone_name: builtins.str,
        name: typing.Optional[builtins.str] = None,
        tags: typing.Optional[typing.Mapping[builtins.str, builtins.str]] = None,
        timeouts: typing.Optional["DnsMxRecordTimeouts"] = None,
    ) -> None:
        """
        :param count: 
        :param depends_on: 
        :param lifecycle: 
        :param provider: 
        :param record: record block.
        :param resource_group_name: 
        :param ttl: 
        :param zone_name: 
        :param name: 
        :param tags: 
        :param timeouts: timeouts block.
        """
        if isinstance(lifecycle, dict):
            lifecycle = cdktf.TerraformResourceLifecycle(**lifecycle)
        if isinstance(timeouts, dict):
            timeouts = DnsMxRecordTimeouts(**timeouts)
        self._values: typing.Dict[str, typing.Any] = {
            "record": record,
            "resource_group_name": resource_group_name,
            "ttl": ttl,
            "zone_name": zone_name,
        }
        if count is not None:
            self._values["count"] = count
        if depends_on is not None:
            self._values["depends_on"] = depends_on
        if lifecycle is not None:
            self._values["lifecycle"] = lifecycle
        if provider is not None:
            self._values["provider"] = provider
        if name is not None:
            self._values["name"] = name
        if tags is not None:
            self._values["tags"] = tags
        if timeouts is not None:
            self._values["timeouts"] = timeouts

    @builtins.property
    def count(self) -> typing.Optional[jsii.Number]:
        """
        :stability: experimental
        """
        result = self._values.get("count")
        return result

    @builtins.property
    def depends_on(self) -> typing.Optional[typing.List[cdktf.TerraformResource]]:
        """
        :stability: experimental
        """
        result = self._values.get("depends_on")
        return result

    @builtins.property
    def lifecycle(self) -> typing.Optional[cdktf.TerraformResourceLifecycle]:
        """
        :stability: experimental
        """
        result = self._values.get("lifecycle")
        return result

    @builtins.property
    def provider(self) -> typing.Optional[cdktf.TerraformProvider]:
        """
        :stability: experimental
        """
        result = self._values.get("provider")
        return result

    @builtins.property
    def record(self) -> typing.List["DnsMxRecordRecord"]:
        """record block."""
        result = self._values.get("record")
        assert result is not None, "Required property 'record' is missing"
        return result

    @builtins.property
    def resource_group_name(self) -> builtins.str:
        result = self._values.get("resource_group_name")
        assert result is not None, "Required property 'resource_group_name' is missing"
        return result

    @builtins.property
    def ttl(self) -> jsii.Number:
        result = self._values.get("ttl")
        assert result is not None, "Required property 'ttl' is missing"
        return result

    @builtins.property
    def zone_name(self) -> builtins.str:
        result = self._values.get("zone_name")
        assert result is not None, "Required property 'zone_name' is missing"
        return result

    @builtins.property
    def name(self) -> typing.Optional[builtins.str]:
        result = self._values.get("name")
        return result

    @builtins.property
    def tags(self) -> typing.Optional[typing.Mapping[builtins.str, builtins.str]]:
        result = self._values.get("tags")
        return result

    @builtins.property
    def timeouts(self) -> typing.Optional["DnsMxRecordTimeouts"]:
        """timeouts block."""
        result = self._values.get("timeouts")
        return result

    def __eq__(self, rhs: typing.Any) -> builtins.bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs: typing.Any) -> builtins.bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return "DnsMxRecordConfig(%s)" % ", ".join(
            k + "=" + repr(v) for k, v in self._values.items()
        )


@jsii.data_type(
    jsii_type="@cdktf/provider-azurerm.DnsMxRecordRecord",
    jsii_struct_bases=[],
    name_mapping={"exchange": "exchange", "preference": "preference"},
)
class DnsMxRecordRecord:
    def __init__(self, *, exchange: builtins.str, preference: builtins.str) -> None:
        """
        :param exchange: 
        :param preference: 
        """
        self._values: typing.Dict[str, typing.Any] = {
            "exchange": exchange,
            "preference": preference,
        }

    @builtins.property
    def exchange(self) -> builtins.str:
        result = self._values.get("exchange")
        assert result is not None, "Required property 'exchange' is missing"
        return result

    @builtins.property
    def preference(self) -> builtins.str:
        result = self._values.get("preference")
        assert result is not None, "Required property 'preference' is missing"
        return result

    def __eq__(self, rhs: typing.Any) -> builtins.bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs: typing.Any) -> builtins.bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return "DnsMxRecordRecord(%s)" % ", ".join(
            k + "=" + repr(v) for k, v in self._values.items()
        )


@jsii.data_type(
    jsii_type="@cdktf/provider-azurerm.DnsMxRecordTimeouts",
    jsii_struct_bases=[],
    name_mapping={
        "create": "create",
        "delete": "delete",
        "read": "read",
        "update": "update",
    },
)
class DnsMxRecordTimeouts:
    def __init__(
        self,
        *,
        create: typing.Optional[builtins.str] = None,
        delete: typing.Optional[builtins.str] = None,
        read: typing.Optional[builtins.str] = None,
        update: typing.Optional[builtins.str] = None,
    ) -> None:
        """
        :param create: 
        :param delete: 
        :param read: 
        :param update: 
        """
        self._values: typing.Dict[str, typing.Any] = {}
        if create is not None:
            self._values["create"] = create
        if delete is not None:
            self._values["delete"] = delete
        if read is not None:
            self._values["read"] = read
        if update is not None:
            self._values["update"] = update

    @builtins.property
    def create(self) -> typing.Optional[builtins.str]:
        result = self._values.get("create")
        return result

    @builtins.property
    def delete(self) -> typing.Optional[builtins.str]:
        result = self._values.get("delete")
        return result

    @builtins.property
    def read(self) -> typing.Optional[builtins.str]:
        result = self._values.get("read")
        return result

    @builtins.property
    def update(self) -> typing.Optional[builtins.str]:
        result = self._values.get("update")
        return result

    def __eq__(self, rhs: typing.Any) -> builtins.bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs: typing.Any) -> builtins.bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return "DnsMxRecordTimeouts(%s)" % ", ".join(
            k + "=" + repr(v) for k, v in self._values.items()
        )


class DnsNsRecord(
    cdktf.TerraformResource,
    metaclass=jsii.JSIIMeta,
    jsii_type="@cdktf/provider-azurerm.DnsNsRecord",
):
    def __init__(
        self,
        scope: constructs.Construct,
        id: builtins.str,
        *,
        name: builtins.str,
        records: typing.List[builtins.str],
        resource_group_name: builtins.str,
        ttl: jsii.Number,
        zone_name: builtins.str,
        tags: typing.Optional[typing.Mapping[builtins.str, builtins.str]] = None,
        timeouts: typing.Optional["DnsNsRecordTimeouts"] = None,
        count: typing.Optional[jsii.Number] = None,
        depends_on: typing.Optional[typing.List[cdktf.TerraformResource]] = None,
        lifecycle: typing.Optional[cdktf.TerraformResourceLifecycle] = None,
        provider: typing.Optional[cdktf.TerraformProvider] = None,
    ) -> None:
        """
        :param scope: -
        :param id: -
        :param name: 
        :param records: 
        :param resource_group_name: 
        :param ttl: 
        :param zone_name: 
        :param tags: 
        :param timeouts: timeouts block.
        :param count: 
        :param depends_on: 
        :param lifecycle: 
        :param provider: 
        """
        config = DnsNsRecordConfig(
            name=name,
            records=records,
            resource_group_name=resource_group_name,
            ttl=ttl,
            zone_name=zone_name,
            tags=tags,
            timeouts=timeouts,
            count=count,
            depends_on=depends_on,
            lifecycle=lifecycle,
            provider=provider,
        )

        jsii.create(DnsNsRecord, self, [scope, id, config])

    @jsii.member(jsii_name="synthesizeAttributes")
    def _synthesize_attributes(self) -> typing.Mapping[builtins.str, typing.Any]:
        return jsii.invoke(self, "synthesizeAttributes", [])

    @builtins.property # type: ignore
    @jsii.member(jsii_name="fqdn")
    def fqdn(self) -> builtins.str:
        return jsii.get(self, "fqdn")

    @builtins.property # type: ignore
    @jsii.member(jsii_name="name")
    def name(self) -> builtins.str:
        return jsii.get(self, "name")

    @name.setter # type: ignore
    def name(self, value: builtins.str) -> None:
        jsii.set(self, "name", value)

    @builtins.property # type: ignore
    @jsii.member(jsii_name="records")
    def records(self) -> typing.List[builtins.str]:
        return jsii.get(self, "records")

    @records.setter # type: ignore
    def records(self, value: typing.List[builtins.str]) -> None:
        jsii.set(self, "records", value)

    @builtins.property # type: ignore
    @jsii.member(jsii_name="resourceGroupName")
    def resource_group_name(self) -> builtins.str:
        return jsii.get(self, "resourceGroupName")

    @resource_group_name.setter # type: ignore
    def resource_group_name(self, value: builtins.str) -> None:
        jsii.set(self, "resourceGroupName", value)

    @builtins.property # type: ignore
    @jsii.member(jsii_name="ttl")
    def ttl(self) -> jsii.Number:
        return jsii.get(self, "ttl")

    @ttl.setter # type: ignore
    def ttl(self, value: jsii.Number) -> None:
        jsii.set(self, "ttl", value)

    @builtins.property # type: ignore
    @jsii.member(jsii_name="zoneName")
    def zone_name(self) -> builtins.str:
        return jsii.get(self, "zoneName")

    @zone_name.setter # type: ignore
    def zone_name(self, value: builtins.str) -> None:
        jsii.set(self, "zoneName", value)

    @builtins.property # type: ignore
    @jsii.member(jsii_name="id")
    def id(self) -> typing.Optional[builtins.str]:
        return jsii.get(self, "id")

    @id.setter # type: ignore
    def id(self, value: typing.Optional[builtins.str]) -> None:
        jsii.set(self, "id", value)

    @builtins.property # type: ignore
    @jsii.member(jsii_name="tags")
    def tags(self) -> typing.Optional[typing.Mapping[builtins.str, builtins.str]]:
        return jsii.get(self, "tags")

    @tags.setter # type: ignore
    def tags(
        self,
        value: typing.Optional[typing.Mapping[builtins.str, builtins.str]],
    ) -> None:
        jsii.set(self, "tags", value)

    @builtins.property # type: ignore
    @jsii.member(jsii_name="timeouts")
    def timeouts(self) -> typing.Optional["DnsNsRecordTimeouts"]:
        return jsii.get(self, "timeouts")

    @timeouts.setter # type: ignore
    def timeouts(self, value: typing.Optional["DnsNsRecordTimeouts"]) -> None:
        jsii.set(self, "timeouts", value)


@jsii.data_type(
    jsii_type="@cdktf/provider-azurerm.DnsNsRecordConfig",
    jsii_struct_bases=[cdktf.TerraformMetaArguments],
    name_mapping={
        "count": "count",
        "depends_on": "dependsOn",
        "lifecycle": "lifecycle",
        "provider": "provider",
        "name": "name",
        "records": "records",
        "resource_group_name": "resourceGroupName",
        "ttl": "ttl",
        "zone_name": "zoneName",
        "tags": "tags",
        "timeouts": "timeouts",
    },
)
class DnsNsRecordConfig(cdktf.TerraformMetaArguments):
    def __init__(
        self,
        *,
        count: typing.Optional[jsii.Number] = None,
        depends_on: typing.Optional[typing.List[cdktf.TerraformResource]] = None,
        lifecycle: typing.Optional[cdktf.TerraformResourceLifecycle] = None,
        provider: typing.Optional[cdktf.TerraformProvider] = None,
        name: builtins.str,
        records: typing.List[builtins.str],
        resource_group_name: builtins.str,
        ttl: jsii.Number,
        zone_name: builtins.str,
        tags: typing.Optional[typing.Mapping[builtins.str, builtins.str]] = None,
        timeouts: typing.Optional["DnsNsRecordTimeouts"] = None,
    ) -> None:
        """
        :param count: 
        :param depends_on: 
        :param lifecycle: 
        :param provider: 
        :param name: 
        :param records: 
        :param resource_group_name: 
        :param ttl: 
        :param zone_name: 
        :param tags: 
        :param timeouts: timeouts block.
        """
        if isinstance(lifecycle, dict):
            lifecycle = cdktf.TerraformResourceLifecycle(**lifecycle)
        if isinstance(timeouts, dict):
            timeouts = DnsNsRecordTimeouts(**timeouts)
        self._values: typing.Dict[str, typing.Any] = {
            "name": name,
            "records": records,
            "resource_group_name": resource_group_name,
            "ttl": ttl,
            "zone_name": zone_name,
        }
        if count is not None:
            self._values["count"] = count
        if depends_on is not None:
            self._values["depends_on"] = depends_on
        if lifecycle is not None:
            self._values["lifecycle"] = lifecycle
        if provider is not None:
            self._values["provider"] = provider
        if tags is not None:
            self._values["tags"] = tags
        if timeouts is not None:
            self._values["timeouts"] = timeouts

    @builtins.property
    def count(self) -> typing.Optional[jsii.Number]:
        """
        :stability: experimental
        """
        result = self._values.get("count")
        return result

    @builtins.property
    def depends_on(self) -> typing.Optional[typing.List[cdktf.TerraformResource]]:
        """
        :stability: experimental
        """
        result = self._values.get("depends_on")
        return result

    @builtins.property
    def lifecycle(self) -> typing.Optional[cdktf.TerraformResourceLifecycle]:
        """
        :stability: experimental
        """
        result = self._values.get("lifecycle")
        return result

    @builtins.property
    def provider(self) -> typing.Optional[cdktf.TerraformProvider]:
        """
        :stability: experimental
        """
        result = self._values.get("provider")
        return result

    @builtins.property
    def name(self) -> builtins.str:
        result = self._values.get("name")
        assert result is not None, "Required property 'name' is missing"
        return result

    @builtins.property
    def records(self) -> typing.List[builtins.str]:
        result = self._values.get("records")
        assert result is not None, "Required property 'records' is missing"
        return result

    @builtins.property
    def resource_group_name(self) -> builtins.str:
        result = self._values.get("resource_group_name")
        assert result is not None, "Required property 'resource_group_name' is missing"
        return result

    @builtins.property
    def ttl(self) -> jsii.Number:
        result = self._values.get("ttl")
        assert result is not None, "Required property 'ttl' is missing"
        return result

    @builtins.property
    def zone_name(self) -> builtins.str:
        result = self._values.get("zone_name")
        assert result is not None, "Required property 'zone_name' is missing"
        return result

    @builtins.property
    def tags(self) -> typing.Optional[typing.Mapping[builtins.str, builtins.str]]:
        result = self._values.get("tags")
        return result

    @builtins.property
    def timeouts(self) -> typing.Optional["DnsNsRecordTimeouts"]:
        """timeouts block."""
        result = self._values.get("timeouts")
        return result

    def __eq__(self, rhs: typing.Any) -> builtins.bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs: typing.Any) -> builtins.bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return "DnsNsRecordConfig(%s)" % ", ".join(
            k + "=" + repr(v) for k, v in self._values.items()
        )


@jsii.data_type(
    jsii_type="@cdktf/provider-azurerm.DnsNsRecordTimeouts",
    jsii_struct_bases=[],
    name_mapping={
        "create": "create",
        "delete": "delete",
        "read": "read",
        "update": "update",
    },
)
class DnsNsRecordTimeouts:
    def __init__(
        self,
        *,
        create: typing.Optional[builtins.str] = None,
        delete: typing.Optional[builtins.str] = None,
        read: typing.Optional[builtins.str] = None,
        update: typing.Optional[builtins.str] = None,
    ) -> None:
        """
        :param create: 
        :param delete: 
        :param read: 
        :param update: 
        """
        self._values: typing.Dict[str, typing.Any] = {}
        if create is not None:
            self._values["create"] = create
        if delete is not None:
            self._values["delete"] = delete
        if read is not None:
            self._values["read"] = read
        if update is not None:
            self._values["update"] = update

    @builtins.property
    def create(self) -> typing.Optional[builtins.str]:
        result = self._values.get("create")
        return result

    @builtins.property
    def delete(self) -> typing.Optional[builtins.str]:
        result = self._values.get("delete")
        return result

    @builtins.property
    def read(self) -> typing.Optional[builtins.str]:
        result = self._values.get("read")
        return result

    @builtins.property
    def update(self) -> typing.Optional[builtins.str]:
        result = self._values.get("update")
        return result

    def __eq__(self, rhs: typing.Any) -> builtins.bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs: typing.Any) -> builtins.bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return "DnsNsRecordTimeouts(%s)" % ", ".join(
            k + "=" + repr(v) for k, v in self._values.items()
        )


class DnsPtrRecord(
    cdktf.TerraformResource,
    metaclass=jsii.JSIIMeta,
    jsii_type="@cdktf/provider-azurerm.DnsPtrRecord",
):
    def __init__(
        self,
        scope: constructs.Construct,
        id: builtins.str,
        *,
        name: builtins.str,
        records: typing.List[builtins.str],
        resource_group_name: builtins.str,
        ttl: jsii.Number,
        zone_name: builtins.str,
        tags: typing.Optional[typing.Mapping[builtins.str, builtins.str]] = None,
        timeouts: typing.Optional["DnsPtrRecordTimeouts"] = None,
        count: typing.Optional[jsii.Number] = None,
        depends_on: typing.Optional[typing.List[cdktf.TerraformResource]] = None,
        lifecycle: typing.Optional[cdktf.TerraformResourceLifecycle] = None,
        provider: typing.Optional[cdktf.TerraformProvider] = None,
    ) -> None:
        """
        :param scope: -
        :param id: -
        :param name: 
        :param records: 
        :param resource_group_name: 
        :param ttl: 
        :param zone_name: 
        :param tags: 
        :param timeouts: timeouts block.
        :param count: 
        :param depends_on: 
        :param lifecycle: 
        :param provider: 
        """
        config = DnsPtrRecordConfig(
            name=name,
            records=records,
            resource_group_name=resource_group_name,
            ttl=ttl,
            zone_name=zone_name,
            tags=tags,
            timeouts=timeouts,
            count=count,
            depends_on=depends_on,
            lifecycle=lifecycle,
            provider=provider,
        )

        jsii.create(DnsPtrRecord, self, [scope, id, config])

    @jsii.member(jsii_name="synthesizeAttributes")
    def _synthesize_attributes(self) -> typing.Mapping[builtins.str, typing.Any]:
        return jsii.invoke(self, "synthesizeAttributes", [])

    @builtins.property # type: ignore
    @jsii.member(jsii_name="fqdn")
    def fqdn(self) -> builtins.str:
        return jsii.get(self, "fqdn")

    @builtins.property # type: ignore
    @jsii.member(jsii_name="name")
    def name(self) -> builtins.str:
        return jsii.get(self, "name")

    @name.setter # type: ignore
    def name(self, value: builtins.str) -> None:
        jsii.set(self, "name", value)

    @builtins.property # type: ignore
    @jsii.member(jsii_name="records")
    def records(self) -> typing.List[builtins.str]:
        return jsii.get(self, "records")

    @records.setter # type: ignore
    def records(self, value: typing.List[builtins.str]) -> None:
        jsii.set(self, "records", value)

    @builtins.property # type: ignore
    @jsii.member(jsii_name="resourceGroupName")
    def resource_group_name(self) -> builtins.str:
        return jsii.get(self, "resourceGroupName")

    @resource_group_name.setter # type: ignore
    def resource_group_name(self, value: builtins.str) -> None:
        jsii.set(self, "resourceGroupName", value)

    @builtins.property # type: ignore
    @jsii.member(jsii_name="ttl")
    def ttl(self) -> jsii.Number:
        return jsii.get(self, "ttl")

    @ttl.setter # type: ignore
    def ttl(self, value: jsii.Number) -> None:
        jsii.set(self, "ttl", value)

    @builtins.property # type: ignore
    @jsii.member(jsii_name="zoneName")
    def zone_name(self) -> builtins.str:
        return jsii.get(self, "zoneName")

    @zone_name.setter # type: ignore
    def zone_name(self, value: builtins.str) -> None:
        jsii.set(self, "zoneName", value)

    @builtins.property # type: ignore
    @jsii.member(jsii_name="id")
    def id(self) -> typing.Optional[builtins.str]:
        return jsii.get(self, "id")

    @id.setter # type: ignore
    def id(self, value: typing.Optional[builtins.str]) -> None:
        jsii.set(self, "id", value)

    @builtins.property # type: ignore
    @jsii.member(jsii_name="tags")
    def tags(self) -> typing.Optional[typing.Mapping[builtins.str, builtins.str]]:
        return jsii.get(self, "tags")

    @tags.setter # type: ignore
    def tags(
        self,
        value: typing.Optional[typing.Mapping[builtins.str, builtins.str]],
    ) -> None:
        jsii.set(self, "tags", value)

    @builtins.property # type: ignore
    @jsii.member(jsii_name="timeouts")
    def timeouts(self) -> typing.Optional["DnsPtrRecordTimeouts"]:
        return jsii.get(self, "timeouts")

    @timeouts.setter # type: ignore
    def timeouts(self, value: typing.Optional["DnsPtrRecordTimeouts"]) -> None:
        jsii.set(self, "timeouts", value)


@jsii.data_type(
    jsii_type="@cdktf/provider-azurerm.DnsPtrRecordConfig",
    jsii_struct_bases=[cdktf.TerraformMetaArguments],
    name_mapping={
        "count": "count",
        "depends_on": "dependsOn",
        "lifecycle": "lifecycle",
        "provider": "provider",
        "name": "name",
        "records": "records",
        "resource_group_name": "resourceGroupName",
        "ttl": "ttl",
        "zone_name": "zoneName",
        "tags": "tags",
        "timeouts": "timeouts",
    },
)
class DnsPtrRecordConfig(cdktf.TerraformMetaArguments):
    def __init__(
        self,
        *,
        count: typing.Optional[jsii.Number] = None,
        depends_on: typing.Optional[typing.List[cdktf.TerraformResource]] = None,
        lifecycle: typing.Optional[cdktf.TerraformResourceLifecycle] = None,
        provider: typing.Optional[cdktf.TerraformProvider] = None,
        name: builtins.str,
        records: typing.List[builtins.str],
        resource_group_name: builtins.str,
        ttl: jsii.Number,
        zone_name: builtins.str,
        tags: typing.Optional[typing.Mapping[builtins.str, builtins.str]] = None,
        timeouts: typing.Optional["DnsPtrRecordTimeouts"] = None,
    ) -> None:
        """
        :param count: 
        :param depends_on: 
        :param lifecycle: 
        :param provider: 
        :param name: 
        :param records: 
        :param resource_group_name: 
        :param ttl: 
        :param zone_name: 
        :param tags: 
        :param timeouts: timeouts block.
        """
        if isinstance(lifecycle, dict):
            lifecycle = cdktf.TerraformResourceLifecycle(**lifecycle)
        if isinstance(timeouts, dict):
            timeouts = DnsPtrRecordTimeouts(**timeouts)
        self._values: typing.Dict[str, typing.Any] = {
            "name": name,
            "records": records,
            "resource_group_name": resource_group_name,
            "ttl": ttl,
            "zone_name": zone_name,
        }
        if count is not None:
            self._values["count"] = count
        if depends_on is not None:
            self._values["depends_on"] = depends_on
        if lifecycle is not None:
            self._values["lifecycle"] = lifecycle
        if provider is not None:
            self._values["provider"] = provider
        if tags is not None:
            self._values["tags"] = tags
        if timeouts is not None:
            self._values["timeouts"] = timeouts

    @builtins.property
    def count(self) -> typing.Optional[jsii.Number]:
        """
        :stability: experimental
        """
        result = self._values.get("count")
        return result

    @builtins.property
    def depends_on(self) -> typing.Optional[typing.List[cdktf.TerraformResource]]:
        """
        :stability: experimental
        """
        result = self._values.get("depends_on")
        return result

    @builtins.property
    def lifecycle(self) -> typing.Optional[cdktf.TerraformResourceLifecycle]:
        """
        :stability: experimental
        """
        result = self._values.get("lifecycle")
        return result

    @builtins.property
    def provider(self) -> typing.Optional[cdktf.TerraformProvider]:
        """
        :stability: experimental
        """
        result = self._values.get("provider")
        return result

    @builtins.property
    def name(self) -> builtins.str:
        result = self._values.get("name")
        assert result is not None, "Required property 'name' is missing"
        return result

    @builtins.property
    def records(self) -> typing.List[builtins.str]:
        result = self._values.get("records")
        assert result is not None, "Required property 'records' is missing"
        return result

    @builtins.property
    def resource_group_name(self) -> builtins.str:
        result = self._values.get("resource_group_name")
        assert result is not None, "Required property 'resource_group_name' is missing"
        return result

    @builtins.property
    def ttl(self) -> jsii.Number:
        result = self._values.get("ttl")
        assert result is not None, "Required property 'ttl' is missing"
        return result

    @builtins.property
    def zone_name(self) -> builtins.str:
        result = self._values.get("zone_name")
        assert result is not None, "Required property 'zone_name' is missing"
        return result

    @builtins.property
    def tags(self) -> typing.Optional[typing.Mapping[builtins.str, builtins.str]]:
        result = self._values.get("tags")
        return result

    @builtins.property
    def timeouts(self) -> typing.Optional["DnsPtrRecordTimeouts"]:
        """timeouts block."""
        result = self._values.get("timeouts")
        return result

    def __eq__(self, rhs: typing.Any) -> builtins.bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs: typing.Any) -> builtins.bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return "DnsPtrRecordConfig(%s)" % ", ".join(
            k + "=" + repr(v) for k, v in self._values.items()
        )


@jsii.data_type(
    jsii_type="@cdktf/provider-azurerm.DnsPtrRecordTimeouts",
    jsii_struct_bases=[],
    name_mapping={
        "create": "create",
        "delete": "delete",
        "read": "read",
        "update": "update",
    },
)
class DnsPtrRecordTimeouts:
    def __init__(
        self,
        *,
        create: typing.Optional[builtins.str] = None,
        delete: typing.Optional[builtins.str] = None,
        read: typing.Optional[builtins.str] = None,
        update: typing.Optional[builtins.str] = None,
    ) -> None:
        """
        :param create: 
        :param delete: 
        :param read: 
        :param update: 
        """
        self._values: typing.Dict[str, typing.Any] = {}
        if create is not None:
            self._values["create"] = create
        if delete is not None:
            self._values["delete"] = delete
        if read is not None:
            self._values["read"] = read
        if update is not None:
            self._values["update"] = update

    @builtins.property
    def create(self) -> typing.Optional[builtins.str]:
        result = self._values.get("create")
        return result

    @builtins.property
    def delete(self) -> typing.Optional[builtins.str]:
        result = self._values.get("delete")
        return result

    @builtins.property
    def read(self) -> typing.Optional[builtins.str]:
        result = self._values.get("read")
        return result

    @builtins.property
    def update(self) -> typing.Optional[builtins.str]:
        result = self._values.get("update")
        return result

    def __eq__(self, rhs: typing.Any) -> builtins.bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs: typing.Any) -> builtins.bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return "DnsPtrRecordTimeouts(%s)" % ", ".join(
            k + "=" + repr(v) for k, v in self._values.items()
        )


class DnsSrvRecord(
    cdktf.TerraformResource,
    metaclass=jsii.JSIIMeta,
    jsii_type="@cdktf/provider-azurerm.DnsSrvRecord",
):
    def __init__(
        self,
        scope: constructs.Construct,
        id: builtins.str,
        *,
        name: builtins.str,
        record: typing.List["DnsSrvRecordRecord"],
        resource_group_name: builtins.str,
        ttl: jsii.Number,
        zone_name: builtins.str,
        tags: typing.Optional[typing.Mapping[builtins.str, builtins.str]] = None,
        timeouts: typing.Optional["DnsSrvRecordTimeouts"] = None,
        count: typing.Optional[jsii.Number] = None,
        depends_on: typing.Optional[typing.List[cdktf.TerraformResource]] = None,
        lifecycle: typing.Optional[cdktf.TerraformResourceLifecycle] = None,
        provider: typing.Optional[cdktf.TerraformProvider] = None,
    ) -> None:
        """
        :param scope: -
        :param id: -
        :param name: 
        :param record: record block.
        :param resource_group_name: 
        :param ttl: 
        :param zone_name: 
        :param tags: 
        :param timeouts: timeouts block.
        :param count: 
        :param depends_on: 
        :param lifecycle: 
        :param provider: 
        """
        config = DnsSrvRecordConfig(
            name=name,
            record=record,
            resource_group_name=resource_group_name,
            ttl=ttl,
            zone_name=zone_name,
            tags=tags,
            timeouts=timeouts,
            count=count,
            depends_on=depends_on,
            lifecycle=lifecycle,
            provider=provider,
        )

        jsii.create(DnsSrvRecord, self, [scope, id, config])

    @jsii.member(jsii_name="synthesizeAttributes")
    def _synthesize_attributes(self) -> typing.Mapping[builtins.str, typing.Any]:
        return jsii.invoke(self, "synthesizeAttributes", [])

    @builtins.property # type: ignore
    @jsii.member(jsii_name="fqdn")
    def fqdn(self) -> builtins.str:
        return jsii.get(self, "fqdn")

    @builtins.property # type: ignore
    @jsii.member(jsii_name="name")
    def name(self) -> builtins.str:
        return jsii.get(self, "name")

    @name.setter # type: ignore
    def name(self, value: builtins.str) -> None:
        jsii.set(self, "name", value)

    @builtins.property # type: ignore
    @jsii.member(jsii_name="record")
    def record(self) -> typing.List["DnsSrvRecordRecord"]:
        return jsii.get(self, "record")

    @record.setter # type: ignore
    def record(self, value: typing.List["DnsSrvRecordRecord"]) -> None:
        jsii.set(self, "record", value)

    @builtins.property # type: ignore
    @jsii.member(jsii_name="resourceGroupName")
    def resource_group_name(self) -> builtins.str:
        return jsii.get(self, "resourceGroupName")

    @resource_group_name.setter # type: ignore
    def resource_group_name(self, value: builtins.str) -> None:
        jsii.set(self, "resourceGroupName", value)

    @builtins.property # type: ignore
    @jsii.member(jsii_name="ttl")
    def ttl(self) -> jsii.Number:
        return jsii.get(self, "ttl")

    @ttl.setter # type: ignore
    def ttl(self, value: jsii.Number) -> None:
        jsii.set(self, "ttl", value)

    @builtins.property # type: ignore
    @jsii.member(jsii_name="zoneName")
    def zone_name(self) -> builtins.str:
        return jsii.get(self, "zoneName")

    @zone_name.setter # type: ignore
    def zone_name(self, value: builtins.str) -> None:
        jsii.set(self, "zoneName", value)

    @builtins.property # type: ignore
    @jsii.member(jsii_name="id")
    def id(self) -> typing.Optional[builtins.str]:
        return jsii.get(self, "id")

    @id.setter # type: ignore
    def id(self, value: typing.Optional[builtins.str]) -> None:
        jsii.set(self, "id", value)

    @builtins.property # type: ignore
    @jsii.member(jsii_name="tags")
    def tags(self) -> typing.Optional[typing.Mapping[builtins.str, builtins.str]]:
        return jsii.get(self, "tags")

    @tags.setter # type: ignore
    def tags(
        self,
        value: typing.Optional[typing.Mapping[builtins.str, builtins.str]],
    ) -> None:
        jsii.set(self, "tags", value)

    @builtins.property # type: ignore
    @jsii.member(jsii_name="timeouts")
    def timeouts(self) -> typing.Optional["DnsSrvRecordTimeouts"]:
        return jsii.get(self, "timeouts")

    @timeouts.setter # type: ignore
    def timeouts(self, value: typing.Optional["DnsSrvRecordTimeouts"]) -> None:
        jsii.set(self, "timeouts", value)


@jsii.data_type(
    jsii_type="@cdktf/provider-azurerm.DnsSrvRecordConfig",
    jsii_struct_bases=[cdktf.TerraformMetaArguments],
    name_mapping={
        "count": "count",
        "depends_on": "dependsOn",
        "lifecycle": "lifecycle",
        "provider": "provider",
        "name": "name",
        "record": "record",
        "resource_group_name": "resourceGroupName",
        "ttl": "ttl",
        "zone_name": "zoneName",
        "tags": "tags",
        "timeouts": "timeouts",
    },
)
class DnsSrvRecordConfig(cdktf.TerraformMetaArguments):
    def __init__(
        self,
        *,
        count: typing.Optional[jsii.Number] = None,
        depends_on: typing.Optional[typing.List[cdktf.TerraformResource]] = None,
        lifecycle: typing.Optional[cdktf.TerraformResourceLifecycle] = None,
        provider: typing.Optional[cdktf.TerraformProvider] = None,
        name: builtins.str,
        record: typing.List["DnsSrvRecordRecord"],
        resource_group_name: builtins.str,
        ttl: jsii.Number,
        zone_name: builtins.str,
        tags: typing.Optional[typing.Mapping[builtins.str, builtins.str]] = None,
        timeouts: typing.Optional["DnsSrvRecordTimeouts"] = None,
    ) -> None:
        """
        :param count: 
        :param depends_on: 
        :param lifecycle: 
        :param provider: 
        :param name: 
        :param record: record block.
        :param resource_group_name: 
        :param ttl: 
        :param zone_name: 
        :param tags: 
        :param timeouts: timeouts block.
        """
        if isinstance(lifecycle, dict):
            lifecycle = cdktf.TerraformResourceLifecycle(**lifecycle)
        if isinstance(timeouts, dict):
            timeouts = DnsSrvRecordTimeouts(**timeouts)
        self._values: typing.Dict[str, typing.Any] = {
            "name": name,
            "record": record,
            "resource_group_name": resource_group_name,
            "ttl": ttl,
            "zone_name": zone_name,
        }
        if count is not None:
            self._values["count"] = count
        if depends_on is not None:
            self._values["depends_on"] = depends_on
        if lifecycle is not None:
            self._values["lifecycle"] = lifecycle
        if provider is not None:
            self._values["provider"] = provider
        if tags is not None:
            self._values["tags"] = tags
        if timeouts is not None:
            self._values["timeouts"] = timeouts

    @builtins.property
    def count(self) -> typing.Optional[jsii.Number]:
        """
        :stability: experimental
        """
        result = self._values.get("count")
        return result

    @builtins.property
    def depends_on(self) -> typing.Optional[typing.List[cdktf.TerraformResource]]:
        """
        :stability: experimental
        """
        result = self._values.get("depends_on")
        return result

    @builtins.property
    def lifecycle(self) -> typing.Optional[cdktf.TerraformResourceLifecycle]:
        """
        :stability: experimental
        """
        result = self._values.get("lifecycle")
        return result

    @builtins.property
    def provider(self) -> typing.Optional[cdktf.TerraformProvider]:
        """
        :stability: experimental
        """
        result = self._values.get("provider")
        return result

    @builtins.property
    def name(self) -> builtins.str:
        result = self._values.get("name")
        assert result is not None, "Required property 'name' is missing"
        return result

    @builtins.property
    def record(self) -> typing.List["DnsSrvRecordRecord"]:
        """record block."""
        result = self._values.get("record")
        assert result is not None, "Required property 'record' is missing"
        return result

    @builtins.property
    def resource_group_name(self) -> builtins.str:
        result = self._values.get("resource_group_name")
        assert result is not None, "Required property 'resource_group_name' is missing"
        return result

    @builtins.property
    def ttl(self) -> jsii.Number:
        result = self._values.get("ttl")
        assert result is not None, "Required property 'ttl' is missing"
        return result

    @builtins.property
    def zone_name(self) -> builtins.str:
        result = self._values.get("zone_name")
        assert result is not None, "Required property 'zone_name' is missing"
        return result

    @builtins.property
    def tags(self) -> typing.Optional[typing.Mapping[builtins.str, builtins.str]]:
        result = self._values.get("tags")
        return result

    @builtins.property
    def timeouts(self) -> typing.Optional["DnsSrvRecordTimeouts"]:
        """timeouts block."""
        result = self._values.get("timeouts")
        return result

    def __eq__(self, rhs: typing.Any) -> builtins.bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs: typing.Any) -> builtins.bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return "DnsSrvRecordConfig(%s)" % ", ".join(
            k + "=" + repr(v) for k, v in self._values.items()
        )


@jsii.data_type(
    jsii_type="@cdktf/provider-azurerm.DnsSrvRecordRecord",
    jsii_struct_bases=[],
    name_mapping={
        "port": "port",
        "priority": "priority",
        "target": "target",
        "weight": "weight",
    },
)
class DnsSrvRecordRecord:
    def __init__(
        self,
        *,
        port: jsii.Number,
        priority: jsii.Number,
        target: builtins.str,
        weight: jsii.Number,
    ) -> None:
        """
        :param port: 
        :param priority: 
        :param target: 
        :param weight: 
        """
        self._values: typing.Dict[str, typing.Any] = {
            "port": port,
            "priority": priority,
            "target": target,
            "weight": weight,
        }

    @builtins.property
    def port(self) -> jsii.Number:
        result = self._values.get("port")
        assert result is not None, "Required property 'port' is missing"
        return result

    @builtins.property
    def priority(self) -> jsii.Number:
        result = self._values.get("priority")
        assert result is not None, "Required property 'priority' is missing"
        return result

    @builtins.property
    def target(self) -> builtins.str:
        result = self._values.get("target")
        assert result is not None, "Required property 'target' is missing"
        return result

    @builtins.property
    def weight(self) -> jsii.Number:
        result = self._values.get("weight")
        assert result is not None, "Required property 'weight' is missing"
        return result

    def __eq__(self, rhs: typing.Any) -> builtins.bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs: typing.Any) -> builtins.bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return "DnsSrvRecordRecord(%s)" % ", ".join(
            k + "=" + repr(v) for k, v in self._values.items()
        )


@jsii.data_type(
    jsii_type="@cdktf/provider-azurerm.DnsSrvRecordTimeouts",
    jsii_struct_bases=[],
    name_mapping={
        "create": "create",
        "delete": "delete",
        "read": "read",
        "update": "update",
    },
)
class DnsSrvRecordTimeouts:
    def __init__(
        self,
        *,
        create: typing.Optional[builtins.str] = None,
        delete: typing.Optional[builtins.str] = None,
        read: typing.Optional[builtins.str] = None,
        update: typing.Optional[builtins.str] = None,
    ) -> None:
        """
        :param create: 
        :param delete: 
        :param read: 
        :param update: 
        """
        self._values: typing.Dict[str, typing.Any] = {}
        if create is not None:
            self._values["create"] = create
        if delete is not None:
            self._values["delete"] = delete
        if read is not None:
            self._values["read"] = read
        if update is not None:
            self._values["update"] = update

    @builtins.property
    def create(self) -> typing.Optional[builtins.str]:
        result = self._values.get("create")
        return result

    @builtins.property
    def delete(self) -> typing.Optional[builtins.str]:
        result = self._values.get("delete")
        return result

    @builtins.property
    def read(self) -> typing.Optional[builtins.str]:
        result = self._values.get("read")
        return result

    @builtins.property
    def update(self) -> typing.Optional[builtins.str]:
        result = self._values.get("update")
        return result

    def __eq__(self, rhs: typing.Any) -> builtins.bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs: typing.Any) -> builtins.bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return "DnsSrvRecordTimeouts(%s)" % ", ".join(
            k + "=" + repr(v) for k, v in self._values.items()
        )


class DnsTxtRecord(
    cdktf.TerraformResource,
    metaclass=jsii.JSIIMeta,
    jsii_type="@cdktf/provider-azurerm.DnsTxtRecord",
):
    def __init__(
        self,
        scope: constructs.Construct,
        id: builtins.str,
        *,
        name: builtins.str,
        record: typing.List["DnsTxtRecordRecord"],
        resource_group_name: builtins.str,
        ttl: jsii.Number,
        zone_name: builtins.str,
        tags: typing.Optional[typing.Mapping[builtins.str, builtins.str]] = None,
        timeouts: typing.Optional["DnsTxtRecordTimeouts"] = None,
        count: typing.Optional[jsii.Number] = None,
        depends_on: typing.Optional[typing.List[cdktf.TerraformResource]] = None,
        lifecycle: typing.Optional[cdktf.TerraformResourceLifecycle] = None,
        provider: typing.Optional[cdktf.TerraformProvider] = None,
    ) -> None:
        """
        :param scope: -
        :param id: -
        :param name: 
        :param record: record block.
        :param resource_group_name: 
        :param ttl: 
        :param zone_name: 
        :param tags: 
        :param timeouts: timeouts block.
        :param count: 
        :param depends_on: 
        :param lifecycle: 
        :param provider: 
        """
        config = DnsTxtRecordConfig(
            name=name,
            record=record,
            resource_group_name=resource_group_name,
            ttl=ttl,
            zone_name=zone_name,
            tags=tags,
            timeouts=timeouts,
            count=count,
            depends_on=depends_on,
            lifecycle=lifecycle,
            provider=provider,
        )

        jsii.create(DnsTxtRecord, self, [scope, id, config])

    @jsii.member(jsii_name="synthesizeAttributes")
    def _synthesize_attributes(self) -> typing.Mapping[builtins.str, typing.Any]:
        return jsii.invoke(self, "synthesizeAttributes", [])

    @builtins.property # type: ignore
    @jsii.member(jsii_name="fqdn")
    def fqdn(self) -> builtins.str:
        return jsii.get(self, "fqdn")

    @builtins.property # type: ignore
    @jsii.member(jsii_name="name")
    def name(self) -> builtins.str:
        return jsii.get(self, "name")

    @name.setter # type: ignore
    def name(self, value: builtins.str) -> None:
        jsii.set(self, "name", value)

    @builtins.property # type: ignore
    @jsii.member(jsii_name="record")
    def record(self) -> typing.List["DnsTxtRecordRecord"]:
        return jsii.get(self, "record")

    @record.setter # type: ignore
    def record(self, value: typing.List["DnsTxtRecordRecord"]) -> None:
        jsii.set(self, "record", value)

    @builtins.property # type: ignore
    @jsii.member(jsii_name="resourceGroupName")
    def resource_group_name(self) -> builtins.str:
        return jsii.get(self, "resourceGroupName")

    @resource_group_name.setter # type: ignore
    def resource_group_name(self, value: builtins.str) -> None:
        jsii.set(self, "resourceGroupName", value)

    @builtins.property # type: ignore
    @jsii.member(jsii_name="ttl")
    def ttl(self) -> jsii.Number:
        return jsii.get(self, "ttl")

    @ttl.setter # type: ignore
    def ttl(self, value: jsii.Number) -> None:
        jsii.set(self, "ttl", value)

    @builtins.property # type: ignore
    @jsii.member(jsii_name="zoneName")
    def zone_name(self) -> builtins.str:
        return jsii.get(self, "zoneName")

    @zone_name.setter # type: ignore
    def zone_name(self, value: builtins.str) -> None:
        jsii.set(self, "zoneName", value)

    @builtins.property # type: ignore
    @jsii.member(jsii_name="id")
    def id(self) -> typing.Optional[builtins.str]:
        return jsii.get(self, "id")

    @id.setter # type: ignore
    def id(self, value: typing.Optional[builtins.str]) -> None:
        jsii.set(self, "id", value)

    @builtins.property # type: ignore
    @jsii.member(jsii_name="tags")
    def tags(self) -> typing.Optional[typing.Mapping[builtins.str, builtins.str]]:
        return jsii.get(self, "tags")

    @tags.setter # type: ignore
    def tags(
        self,
        value: typing.Optional[typing.Mapping[builtins.str, builtins.str]],
    ) -> None:
        jsii.set(self, "tags", value)

    @builtins.property # type: ignore
    @jsii.member(jsii_name="timeouts")
    def timeouts(self) -> typing.Optional["DnsTxtRecordTimeouts"]:
        return jsii.get(self, "timeouts")

    @timeouts.setter # type: ignore
    def timeouts(self, value: typing.Optional["DnsTxtRecordTimeouts"]) -> None:
        jsii.set(self, "timeouts", value)


@jsii.data_type(
    jsii_type="@cdktf/provider-azurerm.DnsTxtRecordConfig",
    jsii_struct_bases=[cdktf.TerraformMetaArguments],
    name_mapping={
        "count": "count",
        "depends_on": "dependsOn",
        "lifecycle": "lifecycle",
        "provider": "provider",
        "name": "name",
        "record": "record",
        "resource_group_name": "resourceGroupName",
        "ttl": "ttl",
        "zone_name": "zoneName",
        "tags": "tags",
        "timeouts": "timeouts",
    },
)
class DnsTxtRecordConfig(cdktf.TerraformMetaArguments):
    def __init__(
        self,
        *,
        count: typing.Optional[jsii.Number] = None,
        depends_on: typing.Optional[typing.List[cdktf.TerraformResource]] = None,
        lifecycle: typing.Optional[cdktf.TerraformResourceLifecycle] = None,
        provider: typing.Optional[cdktf.TerraformProvider] = None,
        name: builtins.str,
        record: typing.List["DnsTxtRecordRecord"],
        resource_group_name: builtins.str,
        ttl: jsii.Number,
        zone_name: builtins.str,
        tags: typing.Optional[typing.Mapping[builtins.str, builtins.str]] = None,
        timeouts: typing.Optional["DnsTxtRecordTimeouts"] = None,
    ) -> None:
        """
        :param count: 
        :param depends_on: 
        :param lifecycle: 
        :param provider: 
        :param name: 
        :param record: record block.
        :param resource_group_name: 
        :param ttl: 
        :param zone_name: 
        :param tags: 
        :param timeouts: timeouts block.
        """
        if isinstance(lifecycle, dict):
            lifecycle = cdktf.TerraformResourceLifecycle(**lifecycle)
        if isinstance(timeouts, dict):
            timeouts = DnsTxtRecordTimeouts(**timeouts)
        self._values: typing.Dict[str, typing.Any] = {
            "name": name,
            "record": record,
            "resource_group_name": resource_group_name,
            "ttl": ttl,
            "zone_name": zone_name,
        }
        if count is not None:
            self._values["count"] = count
        if depends_on is not None:
            self._values["depends_on"] = depends_on
        if lifecycle is not None:
            self._values["lifecycle"] = lifecycle
        if provider is not None:
            self._values["provider"] = provider
        if tags is not None:
            self._values["tags"] = tags
        if timeouts is not None:
            self._values["timeouts"] = timeouts

    @builtins.property
    def count(self) -> typing.Optional[jsii.Number]:
        """
        :stability: experimental
        """
        result = self._values.get("count")
        return result

    @builtins.property
    def depends_on(self) -> typing.Optional[typing.List[cdktf.TerraformResource]]:
        """
        :stability: experimental
        """
        result = self._values.get("depends_on")
        return result

    @builtins.property
    def lifecycle(self) -> typing.Optional[cdktf.TerraformResourceLifecycle]:
        """
        :stability: experimental
        """
        result = self._values.get("lifecycle")
        return result

    @builtins.property
    def provider(self) -> typing.Optional[cdktf.TerraformProvider]:
        """
        :stability: experimental
        """
        result = self._values.get("provider")
        return result

    @builtins.property
    def name(self) -> builtins.str:
        result = self._values.get("name")
        assert result is not None, "Required property 'name' is missing"
        return result

    @builtins.property
    def record(self) -> typing.List["DnsTxtRecordRecord"]:
        """record block."""
        result = self._values.get("record")
        assert result is not None, "Required property 'record' is missing"
        return result

    @builtins.property
    def resource_group_name(self) -> builtins.str:
        result = self._values.get("resource_group_name")
        assert result is not None, "Required property 'resource_group_name' is missing"
        return result

    @builtins.property
    def ttl(self) -> jsii.Number:
        result = self._values.get("ttl")
        assert result is not None, "Required property 'ttl' is missing"
        return result

    @builtins.property
    def zone_name(self) -> builtins.str:
        result = self._values.get("zone_name")
        assert result is not None, "Required property 'zone_name' is missing"
        return result

    @builtins.property
    def tags(self) -> typing.Optional[typing.Mapping[builtins.str, builtins.str]]:
        result = self._values.get("tags")
        return result

    @builtins.property
    def timeouts(self) -> typing.Optional["DnsTxtRecordTimeouts"]:
        """timeouts block."""
        result = self._values.get("timeouts")
        return result

    def __eq__(self, rhs: typing.Any) -> builtins.bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs: typing.Any) -> builtins.bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return "DnsTxtRecordConfig(%s)" % ", ".join(
            k + "=" + repr(v) for k, v in self._values.items()
        )


@jsii.data_type(
    jsii_type="@cdktf/provider-azurerm.DnsTxtRecordRecord",
    jsii_struct_bases=[],
    name_mapping={"value": "value"},
)
class DnsTxtRecordRecord:
    def __init__(self, *, value: builtins.str) -> None:
        """
        :param value: 
        """
        self._values: typing.Dict[str, typing.Any] = {
            "value": value,
        }

    @builtins.property
    def value(self) -> builtins.str:
        result = self._values.get("value")
        assert result is not None, "Required property 'value' is missing"
        return result

    def __eq__(self, rhs: typing.Any) -> builtins.bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs: typing.Any) -> builtins.bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return "DnsTxtRecordRecord(%s)" % ", ".join(
            k + "=" + repr(v) for k, v in self._values.items()
        )


@jsii.data_type(
    jsii_type="@cdktf/provider-azurerm.DnsTxtRecordTimeouts",
    jsii_struct_bases=[],
    name_mapping={
        "create": "create",
        "delete": "delete",
        "read": "read",
        "update": "update",
    },
)
class DnsTxtRecordTimeouts:
    def __init__(
        self,
        *,
        create: typing.Optional[builtins.str] = None,
        delete: typing.Optional[builtins.str] = None,
        read: typing.Optional[builtins.str] = None,
        update: typing.Optional[builtins.str] = None,
    ) -> None:
        """
        :param create: 
        :param delete: 
        :param read: 
        :param update: 
        """
        self._values: typing.Dict[str, typing.Any] = {}
        if create is not None:
            self._values["create"] = create
        if delete is not None:
            self._values["delete"] = delete
        if read is not None:
            self._values["read"] = read
        if update is not None:
            self._values["update"] = update

    @builtins.property
    def create(self) -> typing.Optional[builtins.str]:
        result = self._values.get("create")
        return result

    @builtins.property
    def delete(self) -> typing.Optional[builtins.str]:
        result = self._values.get("delete")
        return result

    @builtins.property
    def read(self) -> typing.Optional[builtins.str]:
        result = self._values.get("read")
        return result

    @builtins.property
    def update(self) -> typing.Optional[builtins.str]:
        result = self._values.get("update")
        return result

    def __eq__(self, rhs: typing.Any) -> builtins.bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs: typing.Any) -> builtins.bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return "DnsTxtRecordTimeouts(%s)" % ", ".join(
            k + "=" + repr(v) for k, v in self._values.items()
        )


class DnsZone(
    cdktf.TerraformResource,
    metaclass=jsii.JSIIMeta,
    jsii_type="@cdktf/provider-azurerm.DnsZone",
):
    def __init__(
        self,
        scope: constructs.Construct,
        id: builtins.str,
        *,
        name: builtins.str,
        resource_group_name: builtins.str,
        tags: typing.Optional[typing.Mapping[builtins.str, builtins.str]] = None,
        timeouts: typing.Optional["DnsZoneTimeouts"] = None,
        count: typing.Optional[jsii.Number] = None,
        depends_on: typing.Optional[typing.List[cdktf.TerraformResource]] = None,
        lifecycle: typing.Optional[cdktf.TerraformResourceLifecycle] = None,
        provider: typing.Optional[cdktf.TerraformProvider] = None,
    ) -> None:
        """
        :param scope: -
        :param id: -
        :param name: 
        :param resource_group_name: 
        :param tags: 
        :param timeouts: timeouts block.
        :param count: 
        :param depends_on: 
        :param lifecycle: 
        :param provider: 
        """
        config = DnsZoneConfig(
            name=name,
            resource_group_name=resource_group_name,
            tags=tags,
            timeouts=timeouts,
            count=count,
            depends_on=depends_on,
            lifecycle=lifecycle,
            provider=provider,
        )

        jsii.create(DnsZone, self, [scope, id, config])

    @jsii.member(jsii_name="synthesizeAttributes")
    def _synthesize_attributes(self) -> typing.Mapping[builtins.str, typing.Any]:
        return jsii.invoke(self, "synthesizeAttributes", [])

    @builtins.property # type: ignore
    @jsii.member(jsii_name="maxNumberOfRecordSets")
    def max_number_of_record_sets(self) -> jsii.Number:
        return jsii.get(self, "maxNumberOfRecordSets")

    @builtins.property # type: ignore
    @jsii.member(jsii_name="nameServers")
    def name_servers(self) -> typing.List[builtins.str]:
        return jsii.get(self, "nameServers")

    @builtins.property # type: ignore
    @jsii.member(jsii_name="numberOfRecordSets")
    def number_of_record_sets(self) -> jsii.Number:
        return jsii.get(self, "numberOfRecordSets")

    @builtins.property # type: ignore
    @jsii.member(jsii_name="name")
    def name(self) -> builtins.str:
        return jsii.get(self, "name")

    @name.setter # type: ignore
    def name(self, value: builtins.str) -> None:
        jsii.set(self, "name", value)

    @builtins.property # type: ignore
    @jsii.member(jsii_name="resourceGroupName")
    def resource_group_name(self) -> builtins.str:
        return jsii.get(self, "resourceGroupName")

    @resource_group_name.setter # type: ignore
    def resource_group_name(self, value: builtins.str) -> None:
        jsii.set(self, "resourceGroupName", value)

    @builtins.property # type: ignore
    @jsii.member(jsii_name="id")
    def id(self) -> typing.Optional[builtins.str]:
        return jsii.get(self, "id")

    @id.setter # type: ignore
    def id(self, value: typing.Optional[builtins.str]) -> None:
        jsii.set(self, "id", value)

    @builtins.property # type: ignore
    @jsii.member(jsii_name="tags")
    def tags(self) -> typing.Optional[typing.Mapping[builtins.str, builtins.str]]:
        return jsii.get(self, "tags")

    @tags.setter # type: ignore
    def tags(
        self,
        value: typing.Optional[typing.Mapping[builtins.str, builtins.str]],
    ) -> None:
        jsii.set(self, "tags", value)

    @builtins.property # type: ignore
    @jsii.member(jsii_name="timeouts")
    def timeouts(self) -> typing.Optional["DnsZoneTimeouts"]:
        return jsii.get(self, "timeouts")

    @timeouts.setter # type: ignore
    def timeouts(self, value: typing.Optional["DnsZoneTimeouts"]) -> None:
        jsii.set(self, "timeouts", value)


@jsii.data_type(
    jsii_type="@cdktf/provider-azurerm.DnsZoneConfig",
    jsii_struct_bases=[cdktf.TerraformMetaArguments],
    name_mapping={
        "count": "count",
        "depends_on": "dependsOn",
        "lifecycle": "lifecycle",
        "provider": "provider",
        "name": "name",
        "resource_group_name": "resourceGroupName",
        "tags": "tags",
        "timeouts": "timeouts",
    },
)
class DnsZoneConfig(cdktf.TerraformMetaArguments):
    def __init__(
        self,
        *,
        count: typing.Optional[jsii.Number] = None,
        depends_on: typing.Optional[typing.List[cdktf.TerraformResource]] = None,
        lifecycle: typing.Optional[cdktf.TerraformResourceLifecycle] = None,
        provider: typing.Optional[cdktf.TerraformProvider] = None,
        name: builtins.str,
        resource_group_name: builtins.str,
        tags: typing.Optional[typing.Mapping[builtins.str, builtins.str]] = None,
        timeouts: typing.Optional["DnsZoneTimeouts"] = None,
    ) -> None:
        """
        :param count: 
        :param depends_on: 
        :param lifecycle: 
        :param provider: 
        :param name: 
        :param resource_group_name: 
        :param tags: 
        :param timeouts: timeouts block.
        """
        if isinstance(lifecycle, dict):
            lifecycle = cdktf.TerraformResourceLifecycle(**lifecycle)
        if isinstance(timeouts, dict):
            timeouts = DnsZoneTimeouts(**timeouts)
        self._values: typing.Dict[str, typing.Any] = {
            "name": name,
            "resource_group_name": resource_group_name,
        }
        if count is not None:
            self._values["count"] = count
        if depends_on is not None:
            self._values["depends_on"] = depends_on
        if lifecycle is not None:
            self._values["lifecycle"] = lifecycle
        if provider is not None:
            self._values["provider"] = provider
        if tags is not None:
            self._values["tags"] = tags
        if timeouts is not None:
            self._values["timeouts"] = timeouts

    @builtins.property
    def count(self) -> typing.Optional[jsii.Number]:
        """
        :stability: experimental
        """
        result = self._values.get("count")
        return result

    @builtins.property
    def depends_on(self) -> typing.Optional[typing.List[cdktf.TerraformResource]]:
        """
        :stability: experimental
        """
        result = self._values.get("depends_on")
        return result

    @builtins.property
    def lifecycle(self) -> typing.Optional[cdktf.TerraformResourceLifecycle]:
        """
        :stability: experimental
        """
        result = self._values.get("lifecycle")
        return result

    @builtins.property
    def provider(self) -> typing.Optional[cdktf.TerraformProvider]:
        """
        :stability: experimental
        """
        result = self._values.get("provider")
        return result

    @builtins.property
    def name(self) -> builtins.str:
        result = self._values.get("name")
        assert result is not None, "Required property 'name' is missing"
        return result

    @builtins.property
    def resource_group_name(self) -> builtins.str:
        result = self._values.get("resource_group_name")
        assert result is not None, "Required property 'resource_group_name' is missing"
        return result

    @builtins.property
    def tags(self) -> typing.Optional[typing.Mapping[builtins.str, builtins.str]]:
        result = self._values.get("tags")
        return result

    @builtins.property
    def timeouts(self) -> typing.Optional["DnsZoneTimeouts"]:
        """timeouts block."""
        result = self._values.get("timeouts")
        return result

    def __eq__(self, rhs: typing.Any) -> builtins.bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs: typing.Any) -> builtins.bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return "DnsZoneConfig(%s)" % ", ".join(
            k + "=" + repr(v) for k, v in self._values.items()
        )


@jsii.data_type(
    jsii_type="@cdktf/provider-azurerm.DnsZoneTimeouts",
    jsii_struct_bases=[],
    name_mapping={
        "create": "create",
        "delete": "delete",
        "read": "read",
        "update": "update",
    },
)
class DnsZoneTimeouts:
    def __init__(
        self,
        *,
        create: typing.Optional[builtins.str] = None,
        delete: typing.Optional[builtins.str] = None,
        read: typing.Optional[builtins.str] = None,
        update: typing.Optional[builtins.str] = None,
    ) -> None:
        """
        :param create: 
        :param delete: 
        :param read: 
        :param update: 
        """
        self._values: typing.Dict[str, typing.Any] = {}
        if create is not None:
            self._values["create"] = create
        if delete is not None:
            self._values["delete"] = delete
        if read is not None:
            self._values["read"] = read
        if update is not None:
            self._values["update"] = update

    @builtins.property
    def create(self) -> typing.Optional[builtins.str]:
        result = self._values.get("create")
        return result

    @builtins.property
    def delete(self) -> typing.Optional[builtins.str]:
        result = self._values.get("delete")
        return result

    @builtins.property
    def read(self) -> typing.Optional[builtins.str]:
        result = self._values.get("read")
        return result

    @builtins.property
    def update(self) -> typing.Optional[builtins.str]:
        result = self._values.get("update")
        return result

    def __eq__(self, rhs: typing.Any) -> builtins.bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs: typing.Any) -> builtins.bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return "DnsZoneTimeouts(%s)" % ", ".join(
            k + "=" + repr(v) for k, v in self._values.items()
        )


class EventgridDomain(
    cdktf.TerraformResource,
    metaclass=jsii.JSIIMeta,
    jsii_type="@cdktf/provider-azurerm.EventgridDomain",
):
    def __init__(
        self,
        scope: constructs.Construct,
        id: builtins.str,
        *,
        location: builtins.str,
        name: builtins.str,
        resource_group_name: builtins.str,
        input_mapping_default_values: typing.Optional[typing.List["EventgridDomainInputMappingDefaultValues"]] = None,
        input_mapping_fields: typing.Optional[typing.List["EventgridDomainInputMappingFields"]] = None,
        input_schema: typing.Optional[builtins.str] = None,
        tags: typing.Optional[typing.Mapping[builtins.str, builtins.str]] = None,
        timeouts: typing.Optional["EventgridDomainTimeouts"] = None,
        count: typing.Optional[jsii.Number] = None,
        depends_on: typing.Optional[typing.List[cdktf.TerraformResource]] = None,
        lifecycle: typing.Optional[cdktf.TerraformResourceLifecycle] = None,
        provider: typing.Optional[cdktf.TerraformProvider] = None,
    ) -> None:
        """
        :param scope: -
        :param id: -
        :param location: 
        :param name: 
        :param resource_group_name: 
        :param input_mapping_default_values: input_mapping_default_values block.
        :param input_mapping_fields: input_mapping_fields block.
        :param input_schema: 
        :param tags: 
        :param timeouts: timeouts block.
        :param count: 
        :param depends_on: 
        :param lifecycle: 
        :param provider: 
        """
        config = EventgridDomainConfig(
            location=location,
            name=name,
            resource_group_name=resource_group_name,
            input_mapping_default_values=input_mapping_default_values,
            input_mapping_fields=input_mapping_fields,
            input_schema=input_schema,
            tags=tags,
            timeouts=timeouts,
            count=count,
            depends_on=depends_on,
            lifecycle=lifecycle,
            provider=provider,
        )

        jsii.create(EventgridDomain, self, [scope, id, config])

    @jsii.member(jsii_name="synthesizeAttributes")
    def _synthesize_attributes(self) -> typing.Mapping[builtins.str, typing.Any]:
        return jsii.invoke(self, "synthesizeAttributes", [])

    @builtins.property # type: ignore
    @jsii.member(jsii_name="endpoint")
    def endpoint(self) -> builtins.str:
        return jsii.get(self, "endpoint")

    @builtins.property # type: ignore
    @jsii.member(jsii_name="primaryAccessKey")
    def primary_access_key(self) -> builtins.str:
        return jsii.get(self, "primaryAccessKey")

    @builtins.property # type: ignore
    @jsii.member(jsii_name="secondaryAccessKey")
    def secondary_access_key(self) -> builtins.str:
        return jsii.get(self, "secondaryAccessKey")

    @builtins.property # type: ignore
    @jsii.member(jsii_name="location")
    def location(self) -> builtins.str:
        return jsii.get(self, "location")

    @location.setter # type: ignore
    def location(self, value: builtins.str) -> None:
        jsii.set(self, "location", value)

    @builtins.property # type: ignore
    @jsii.member(jsii_name="name")
    def name(self) -> builtins.str:
        return jsii.get(self, "name")

    @name.setter # type: ignore
    def name(self, value: builtins.str) -> None:
        jsii.set(self, "name", value)

    @builtins.property # type: ignore
    @jsii.member(jsii_name="resourceGroupName")
    def resource_group_name(self) -> builtins.str:
        return jsii.get(self, "resourceGroupName")

    @resource_group_name.setter # type: ignore
    def resource_group_name(self, value: builtins.str) -> None:
        jsii.set(self, "resourceGroupName", value)

    @builtins.property # type: ignore
    @jsii.member(jsii_name="id")
    def id(self) -> typing.Optional[builtins.str]:
        return jsii.get(self, "id")

    @id.setter # type: ignore
    def id(self, value: typing.Optional[builtins.str]) -> None:
        jsii.set(self, "id", value)

    @builtins.property # type: ignore
    @jsii.member(jsii_name="inputMappingDefaultValues")
    def input_mapping_default_values(
        self,
    ) -> typing.Optional[typing.List["EventgridDomainInputMappingDefaultValues"]]:
        return jsii.get(self, "inputMappingDefaultValues")

    @input_mapping_default_values.setter # type: ignore
    def input_mapping_default_values(
        self,
        value: typing.Optional[typing.List["EventgridDomainInputMappingDefaultValues"]],
    ) -> None:
        jsii.set(self, "inputMappingDefaultValues", value)

    @builtins.property # type: ignore
    @jsii.member(jsii_name="inputMappingFields")
    def input_mapping_fields(
        self,
    ) -> typing.Optional[typing.List["EventgridDomainInputMappingFields"]]:
        return jsii.get(self, "inputMappingFields")

    @input_mapping_fields.setter # type: ignore
    def input_mapping_fields(
        self,
        value: typing.Optional[typing.List["EventgridDomainInputMappingFields"]],
    ) -> None:
        jsii.set(self, "inputMappingFields", value)

    @builtins.property # type: ignore
    @jsii.member(jsii_name="inputSchema")
    def input_schema(self) -> typing.Optional[builtins.str]:
        return jsii.get(self, "inputSchema")

    @input_schema.setter # type: ignore
    def input_schema(self, value: typing.Optional[builtins.str]) -> None:
        jsii.set(self, "inputSchema", value)

    @builtins.property # type: ignore
    @jsii.member(jsii_name="tags")
    def tags(self) -> typing.Optional[typing.Mapping[builtins.str, builtins.str]]:
        return jsii.get(self, "tags")

    @tags.setter # type: ignore
    def tags(
        self,
        value: typing.Optional[typing.Mapping[builtins.str, builtins.str]],
    ) -> None:
        jsii.set(self, "tags", value)

    @builtins.property # type: ignore
    @jsii.member(jsii_name="timeouts")
    def timeouts(self) -> typing.Optional["EventgridDomainTimeouts"]:
        return jsii.get(self, "timeouts")

    @timeouts.setter # type: ignore
    def timeouts(self, value: typing.Optional["EventgridDomainTimeouts"]) -> None:
        jsii.set(self, "timeouts", value)


@jsii.data_type(
    jsii_type="@cdktf/provider-azurerm.EventgridDomainConfig",
    jsii_struct_bases=[cdktf.TerraformMetaArguments],
    name_mapping={
        "count": "count",
        "depends_on": "dependsOn",
        "lifecycle": "lifecycle",
        "provider": "provider",
        "location": "location",
        "name": "name",
        "resource_group_name": "resourceGroupName",
        "input_mapping_default_values": "inputMappingDefaultValues",
        "input_mapping_fields": "inputMappingFields",
        "input_schema": "inputSchema",
        "tags": "tags",
        "timeouts": "timeouts",
    },
)
class EventgridDomainConfig(cdktf.TerraformMetaArguments):
    def __init__(
        self,
        *,
        count: typing.Optional[jsii.Number] = None,
        depends_on: typing.Optional[typing.List[cdktf.TerraformResource]] = None,
        lifecycle: typing.Optional[cdktf.TerraformResourceLifecycle] = None,
        provider: typing.Optional[cdktf.TerraformProvider] = None,
        location: builtins.str,
        name: builtins.str,
        resource_group_name: builtins.str,
        input_mapping_default_values: typing.Optional[typing.List["EventgridDomainInputMappingDefaultValues"]] = None,
        input_mapping_fields: typing.Optional[typing.List["EventgridDomainInputMappingFields"]] = None,
        input_schema: typing.Optional[builtins.str] = None,
        tags: typing.Optional[typing.Mapping[builtins.str, builtins.str]] = None,
        timeouts: typing.Optional["EventgridDomainTimeouts"] = None,
    ) -> None:
        """
        :param count: 
        :param depends_on: 
        :param lifecycle: 
        :param provider: 
        :param location: 
        :param name: 
        :param resource_group_name: 
        :param input_mapping_default_values: input_mapping_default_values block.
        :param input_mapping_fields: input_mapping_fields block.
        :param input_schema: 
        :param tags: 
        :param timeouts: timeouts block.
        """
        if isinstance(lifecycle, dict):
            lifecycle = cdktf.TerraformResourceLifecycle(**lifecycle)
        if isinstance(timeouts, dict):
            timeouts = EventgridDomainTimeouts(**timeouts)
        self._values: typing.Dict[str, typing.Any] = {
            "location": location,
            "name": name,
            "resource_group_name": resource_group_name,
        }
        if count is not None:
            self._values["count"] = count
        if depends_on is not None:
            self._values["depends_on"] = depends_on
        if lifecycle is not None:
            self._values["lifecycle"] = lifecycle
        if provider is not None:
            self._values["provider"] = provider
        if input_mapping_default_values is not None:
            self._values["input_mapping_default_values"] = input_mapping_default_values
        if input_mapping_fields is not None:
            self._values["input_mapping_fields"] = input_mapping_fields
        if input_schema is not None:
            self._values["input_schema"] = input_schema
        if tags is not None:
            self._values["tags"] = tags
        if timeouts is not None:
            self._values["timeouts"] = timeouts

    @builtins.property
    def count(self) -> typing.Optional[jsii.Number]:
        """
        :stability: experimental
        """
        result = self._values.get("count")
        return result

    @builtins.property
    def depends_on(self) -> typing.Optional[typing.List[cdktf.TerraformResource]]:
        """
        :stability: experimental
        """
        result = self._values.get("depends_on")
        return result

    @builtins.property
    def lifecycle(self) -> typing.Optional[cdktf.TerraformResourceLifecycle]:
        """
        :stability: experimental
        """
        result = self._values.get("lifecycle")
        return result

    @builtins.property
    def provider(self) -> typing.Optional[cdktf.TerraformProvider]:
        """
        :stability: experimental
        """
        result = self._values.get("provider")
        return result

    @builtins.property
    def location(self) -> builtins.str:
        result = self._values.get("location")
        assert result is not None, "Required property 'location' is missing"
        return result

    @builtins.property
    def name(self) -> builtins.str:
        result = self._values.get("name")
        assert result is not None, "Required property 'name' is missing"
        return result

    @builtins.property
    def resource_group_name(self) -> builtins.str:
        result = self._values.get("resource_group_name")
        assert result is not None, "Required property 'resource_group_name' is missing"
        return result

    @builtins.property
    def input_mapping_default_values(
        self,
    ) -> typing.Optional[typing.List["EventgridDomainInputMappingDefaultValues"]]:
        """input_mapping_default_values block."""
        result = self._values.get("input_mapping_default_values")
        return result

    @builtins.property
    def input_mapping_fields(
        self,
    ) -> typing.Optional[typing.List["EventgridDomainInputMappingFields"]]:
        """input_mapping_fields block."""
        result = self._values.get("input_mapping_fields")
        return result

    @builtins.property
    def input_schema(self) -> typing.Optional[builtins.str]:
        result = self._values.get("input_schema")
        return result

    @builtins.property
    def tags(self) -> typing.Optional[typing.Mapping[builtins.str, builtins.str]]:
        result = self._values.get("tags")
        return result

    @builtins.property
    def timeouts(self) -> typing.Optional["EventgridDomainTimeouts"]:
        """timeouts block."""
        result = self._values.get("timeouts")
        return result

    def __eq__(self, rhs: typing.Any) -> builtins.bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs: typing.Any) -> builtins.bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return "EventgridDomainConfig(%s)" % ", ".join(
            k + "=" + repr(v) for k, v in self._values.items()
        )


@jsii.data_type(
    jsii_type="@cdktf/provider-azurerm.EventgridDomainInputMappingDefaultValues",
    jsii_struct_bases=[],
    name_mapping={
        "data_version": "dataVersion",
        "event_type": "eventType",
        "subject": "subject",
    },
)
class EventgridDomainInputMappingDefaultValues:
    def __init__(
        self,
        *,
        data_version: typing.Optional[builtins.str] = None,
        event_type: typing.Optional[builtins.str] = None,
        subject: typing.Optional[builtins.str] = None,
    ) -> None:
        """
        :param data_version: 
        :param event_type: 
        :param subject: 
        """
        self._values: typing.Dict[str, typing.Any] = {}
        if data_version is not None:
            self._values["data_version"] = data_version
        if event_type is not None:
            self._values["event_type"] = event_type
        if subject is not None:
            self._values["subject"] = subject

    @builtins.property
    def data_version(self) -> typing.Optional[builtins.str]:
        result = self._values.get("data_version")
        return result

    @builtins.property
    def event_type(self) -> typing.Optional[builtins.str]:
        result = self._values.get("event_type")
        return result

    @builtins.property
    def subject(self) -> typing.Optional[builtins.str]:
        result = self._values.get("subject")
        return result

    def __eq__(self, rhs: typing.Any) -> builtins.bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs: typing.Any) -> builtins.bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return "EventgridDomainInputMappingDefaultValues(%s)" % ", ".join(
            k + "=" + repr(v) for k, v in self._values.items()
        )


@jsii.data_type(
    jsii_type="@cdktf/provider-azurerm.EventgridDomainInputMappingFields",
    jsii_struct_bases=[],
    name_mapping={
        "data_version": "dataVersion",
        "event_time": "eventTime",
        "event_type": "eventType",
        "id": "id",
        "subject": "subject",
        "topic": "topic",
    },
)
class EventgridDomainInputMappingFields:
    def __init__(
        self,
        *,
        data_version: typing.Optional[builtins.str] = None,
        event_time: typing.Optional[builtins.str] = None,
        event_type: typing.Optional[builtins.str] = None,
        id: typing.Optional[builtins.str] = None,
        subject: typing.Optional[builtins.str] = None,
        topic: typing.Optional[builtins.str] = None,
    ) -> None:
        """
        :param data_version: 
        :param event_time: 
        :param event_type: 
        :param id: 
        :param subject: 
        :param topic: 
        """
        self._values: typing.Dict[str, typing.Any] = {}
        if data_version is not None:
            self._values["data_version"] = data_version
        if event_time is not None:
            self._values["event_time"] = event_time
        if event_type is not None:
            self._values["event_type"] = event_type
        if id is not None:
            self._values["id"] = id
        if subject is not None:
            self._values["subject"] = subject
        if topic is not None:
            self._values["topic"] = topic

    @builtins.property
    def data_version(self) -> typing.Optional[builtins.str]:
        result = self._values.get("data_version")
        return result

    @builtins.property
    def event_time(self) -> typing.Optional[builtins.str]:
        result = self._values.get("event_time")
        return result

    @builtins.property
    def event_type(self) -> typing.Optional[builtins.str]:
        result = self._values.get("event_type")
        return result

    @builtins.property
    def id(self) -> typing.Optional[builtins.str]:
        result = self._values.get("id")
        return result

    @builtins.property
    def subject(self) -> typing.Optional[builtins.str]:
        result = self._values.get("subject")
        return result

    @builtins.property
    def topic(self) -> typing.Optional[builtins.str]:
        result = self._values.get("topic")
        return result

    def __eq__(self, rhs: typing.Any) -> builtins.bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs: typing.Any) -> builtins.bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return "EventgridDomainInputMappingFields(%s)" % ", ".join(
            k + "=" + repr(v) for k, v in self._values.items()
        )


@jsii.data_type(
    jsii_type="@cdktf/provider-azurerm.EventgridDomainTimeouts",
    jsii_struct_bases=[],
    name_mapping={
        "create": "create",
        "delete": "delete",
        "read": "read",
        "update": "update",
    },
)
class EventgridDomainTimeouts:
    def __init__(
        self,
        *,
        create: typing.Optional[builtins.str] = None,
        delete: typing.Optional[builtins.str] = None,
        read: typing.Optional[builtins.str] = None,
        update: typing.Optional[builtins.str] = None,
    ) -> None:
        """
        :param create: 
        :param delete: 
        :param read: 
        :param update: 
        """
        self._values: typing.Dict[str, typing.Any] = {}
        if create is not None:
            self._values["create"] = create
        if delete is not None:
            self._values["delete"] = delete
        if read is not None:
            self._values["read"] = read
        if update is not None:
            self._values["update"] = update

    @builtins.property
    def create(self) -> typing.Optional[builtins.str]:
        result = self._values.get("create")
        return result

    @builtins.property
    def delete(self) -> typing.Optional[builtins.str]:
        result = self._values.get("delete")
        return result

    @builtins.property
    def read(self) -> typing.Optional[builtins.str]:
        result = self._values.get("read")
        return result

    @builtins.property
    def update(self) -> typing.Optional[builtins.str]:
        result = self._values.get("update")
        return result

    def __eq__(self, rhs: typing.Any) -> builtins.bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs: typing.Any) -> builtins.bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return "EventgridDomainTimeouts(%s)" % ", ".join(
            k + "=" + repr(v) for k, v in self._values.items()
        )


class EventgridEventSubscription(
    cdktf.TerraformResource,
    metaclass=jsii.JSIIMeta,
    jsii_type="@cdktf/provider-azurerm.EventgridEventSubscription",
):
    def __init__(
        self,
        scope_: constructs.Construct,
        id: builtins.str,
        *,
        name: builtins.str,
        scope: builtins.str,
        event_delivery_schema: typing.Optional[builtins.str] = None,
        eventhub_endpoint: typing.Optional[typing.List["EventgridEventSubscriptionEventhubEndpoint"]] = None,
        hybrid_connection_endpoint: typing.Optional[typing.List["EventgridEventSubscriptionHybridConnectionEndpoint"]] = None,
        included_event_types: typing.Optional[typing.List[builtins.str]] = None,
        labels: typing.Optional[typing.List[builtins.str]] = None,
        retry_policy: typing.Optional[typing.List["EventgridEventSubscriptionRetryPolicy"]] = None,
        storage_blob_dead_letter_destination: typing.Optional[typing.List["EventgridEventSubscriptionStorageBlobDeadLetterDestination"]] = None,
        storage_queue_endpoint: typing.Optional[typing.List["EventgridEventSubscriptionStorageQueueEndpoint"]] = None,
        subject_filter: typing.Optional[typing.List["EventgridEventSubscriptionSubjectFilter"]] = None,
        timeouts: typing.Optional["EventgridEventSubscriptionTimeouts"] = None,
        topic_name: typing.Optional[builtins.str] = None,
        webhook_endpoint: typing.Optional[typing.List["EventgridEventSubscriptionWebhookEndpoint"]] = None,
        count: typing.Optional[jsii.Number] = None,
        depends_on: typing.Optional[typing.List[cdktf.TerraformResource]] = None,
        lifecycle: typing.Optional[cdktf.TerraformResourceLifecycle] = None,
        provider: typing.Optional[cdktf.TerraformProvider] = None,
    ) -> None:
        """
        :param scope_: -
        :param id: -
        :param name: 
        :param scope: 
        :param event_delivery_schema: 
        :param eventhub_endpoint: eventhub_endpoint block.
        :param hybrid_connection_endpoint: hybrid_connection_endpoint block.
        :param included_event_types: 
        :param labels: 
        :param retry_policy: retry_policy block.
        :param storage_blob_dead_letter_destination: storage_blob_dead_letter_destination block.
        :param storage_queue_endpoint: storage_queue_endpoint block.
        :param subject_filter: subject_filter block.
        :param timeouts: timeouts block.
        :param topic_name: 
        :param webhook_endpoint: webhook_endpoint block.
        :param count: 
        :param depends_on: 
        :param lifecycle: 
        :param provider: 
        """
        config = EventgridEventSubscriptionConfig(
            name=name,
            scope=scope,
            event_delivery_schema=event_delivery_schema,
            eventhub_endpoint=eventhub_endpoint,
            hybrid_connection_endpoint=hybrid_connection_endpoint,
            included_event_types=included_event_types,
            labels=labels,
            retry_policy=retry_policy,
            storage_blob_dead_letter_destination=storage_blob_dead_letter_destination,
            storage_queue_endpoint=storage_queue_endpoint,
            subject_filter=subject_filter,
            timeouts=timeouts,
            topic_name=topic_name,
            webhook_endpoint=webhook_endpoint,
            count=count,
            depends_on=depends_on,
            lifecycle=lifecycle,
            provider=provider,
        )

        jsii.create(EventgridEventSubscription, self, [scope_, id, config])

    @jsii.member(jsii_name="synthesizeAttributes")
    def _synthesize_attributes(self) -> typing.Mapping[builtins.str, typing.Any]:
        return jsii.invoke(self, "synthesizeAttributes", [])

    @builtins.property # type: ignore
    @jsii.member(jsii_name="name")
    def name(self) -> builtins.str:
        return jsii.get(self, "name")

    @name.setter # type: ignore
    def name(self, value: builtins.str) -> None:
        jsii.set(self, "name", value)

    @builtins.property # type: ignore
    @jsii.member(jsii_name="scope")
    def scope(self) -> builtins.str:
        return jsii.get(self, "scope")

    @scope.setter # type: ignore
    def scope(self, value: builtins.str) -> None:
        jsii.set(self, "scope", value)

    @builtins.property # type: ignore
    @jsii.member(jsii_name="eventDeliverySchema")
    def event_delivery_schema(self) -> typing.Optional[builtins.str]:
        return jsii.get(self, "eventDeliverySchema")

    @event_delivery_schema.setter # type: ignore
    def event_delivery_schema(self, value: typing.Optional[builtins.str]) -> None:
        jsii.set(self, "eventDeliverySchema", value)

    @builtins.property # type: ignore
    @jsii.member(jsii_name="eventhubEndpoint")
    def eventhub_endpoint(
        self,
    ) -> typing.Optional[typing.List["EventgridEventSubscriptionEventhubEndpoint"]]:
        return jsii.get(self, "eventhubEndpoint")

    @eventhub_endpoint.setter # type: ignore
    def eventhub_endpoint(
        self,
        value: typing.Optional[typing.List["EventgridEventSubscriptionEventhubEndpoint"]],
    ) -> None:
        jsii.set(self, "eventhubEndpoint", value)

    @builtins.property # type: ignore
    @jsii.member(jsii_name="hybridConnectionEndpoint")
    def hybrid_connection_endpoint(
        self,
    ) -> typing.Optional[typing.List["EventgridEventSubscriptionHybridConnectionEndpoint"]]:
        return jsii.get(self, "hybridConnectionEndpoint")

    @hybrid_connection_endpoint.setter # type: ignore
    def hybrid_connection_endpoint(
        self,
        value: typing.Optional[typing.List["EventgridEventSubscriptionHybridConnectionEndpoint"]],
    ) -> None:
        jsii.set(self, "hybridConnectionEndpoint", value)

    @builtins.property # type: ignore
    @jsii.member(jsii_name="id")
    def id(self) -> typing.Optional[builtins.str]:
        return jsii.get(self, "id")

    @id.setter # type: ignore
    def id(self, value: typing.Optional[builtins.str]) -> None:
        jsii.set(self, "id", value)

    @builtins.property # type: ignore
    @jsii.member(jsii_name="includedEventTypes")
    def included_event_types(self) -> typing.Optional[typing.List[builtins.str]]:
        return jsii.get(self, "includedEventTypes")

    @included_event_types.setter # type: ignore
    def included_event_types(
        self,
        value: typing.Optional[typing.List[builtins.str]],
    ) -> None:
        jsii.set(self, "includedEventTypes", value)

    @builtins.property # type: ignore
    @jsii.member(jsii_name="labels")
    def labels(self) -> typing.Optional[typing.List[builtins.str]]:
        return jsii.get(self, "labels")

    @labels.setter # type: ignore
    def labels(self, value: typing.Optional[typing.List[builtins.str]]) -> None:
        jsii.set(self, "labels", value)

    @builtins.property # type: ignore
    @jsii.member(jsii_name="retryPolicy")
    def retry_policy(
        self,
    ) -> typing.Optional[typing.List["EventgridEventSubscriptionRetryPolicy"]]:
        return jsii.get(self, "retryPolicy")

    @retry_policy.setter # type: ignore
    def retry_policy(
        self,
        value: typing.Optional[typing.List["EventgridEventSubscriptionRetryPolicy"]],
    ) -> None:
        jsii.set(self, "retryPolicy", value)

    @builtins.property # type: ignore
    @jsii.member(jsii_name="storageBlobDeadLetterDestination")
    def storage_blob_dead_letter_destination(
        self,
    ) -> typing.Optional[typing.List["EventgridEventSubscriptionStorageBlobDeadLetterDestination"]]:
        return jsii.get(self, "storageBlobDeadLetterDestination")

    @storage_blob_dead_letter_destination.setter # type: ignore
    def storage_blob_dead_letter_destination(
        self,
        value: typing.Optional[typing.List["EventgridEventSubscriptionStorageBlobDeadLetterDestination"]],
    ) -> None:
        jsii.set(self, "storageBlobDeadLetterDestination", value)

    @builtins.property # type: ignore
    @jsii.member(jsii_name="storageQueueEndpoint")
    def storage_queue_endpoint(
        self,
    ) -> typing.Optional[typing.List["EventgridEventSubscriptionStorageQueueEndpoint"]]:
        return jsii.get(self, "storageQueueEndpoint")

    @storage_queue_endpoint.setter # type: ignore
    def storage_queue_endpoint(
        self,
        value: typing.Optional[typing.List["EventgridEventSubscriptionStorageQueueEndpoint"]],
    ) -> None:
        jsii.set(self, "storageQueueEndpoint", value)

    @builtins.property # type: ignore
    @jsii.member(jsii_name="subjectFilter")
    def subject_filter(
        self,
    ) -> typing.Optional[typing.List["EventgridEventSubscriptionSubjectFilter"]]:
        return jsii.get(self, "subjectFilter")

    @subject_filter.setter # type: ignore
    def subject_filter(
        self,
        value: typing.Optional[typing.List["EventgridEventSubscriptionSubjectFilter"]],
    ) -> None:
        jsii.set(self, "subjectFilter", value)

    @builtins.property # type: ignore
    @jsii.member(jsii_name="timeouts")
    def timeouts(self) -> typing.Optional["EventgridEventSubscriptionTimeouts"]:
        return jsii.get(self, "timeouts")

    @timeouts.setter # type: ignore
    def timeouts(
        self,
        value: typing.Optional["EventgridEventSubscriptionTimeouts"],
    ) -> None:
        jsii.set(self, "timeouts", value)

    @builtins.property # type: ignore
    @jsii.member(jsii_name="topicName")
    def topic_name(self) -> typing.Optional[builtins.str]:
        return jsii.get(self, "topicName")

    @topic_name.setter # type: ignore
    def topic_name(self, value: typing.Optional[builtins.str]) -> None:
        jsii.set(self, "topicName", value)

    @builtins.property # type: ignore
    @jsii.member(jsii_name="webhookEndpoint")
    def webhook_endpoint(
        self,
    ) -> typing.Optional[typing.List["EventgridEventSubscriptionWebhookEndpoint"]]:
        return jsii.get(self, "webhookEndpoint")

    @webhook_endpoint.setter # type: ignore
    def webhook_endpoint(
        self,
        value: typing.Optional[typing.List["EventgridEventSubscriptionWebhookEndpoint"]],
    ) -> None:
        jsii.set(self, "webhookEndpoint", value)


@jsii.data_type(
    jsii_type="@cdktf/provider-azurerm.EventgridEventSubscriptionConfig",
    jsii_struct_bases=[cdktf.TerraformMetaArguments],
    name_mapping={
        "count": "count",
        "depends_on": "dependsOn",
        "lifecycle": "lifecycle",
        "provider": "provider",
        "name": "name",
        "scope": "scope",
        "event_delivery_schema": "eventDeliverySchema",
        "eventhub_endpoint": "eventhubEndpoint",
        "hybrid_connection_endpoint": "hybridConnectionEndpoint",
        "included_event_types": "includedEventTypes",
        "labels": "labels",
        "retry_policy": "retryPolicy",
        "storage_blob_dead_letter_destination": "storageBlobDeadLetterDestination",
        "storage_queue_endpoint": "storageQueueEndpoint",
        "subject_filter": "subjectFilter",
        "timeouts": "timeouts",
        "topic_name": "topicName",
        "webhook_endpoint": "webhookEndpoint",
    },
)
class EventgridEventSubscriptionConfig(cdktf.TerraformMetaArguments):
    def __init__(
        self,
        *,
        count: typing.Optional[jsii.Number] = None,
        depends_on: typing.Optional[typing.List[cdktf.TerraformResource]] = None,
        lifecycle: typing.Optional[cdktf.TerraformResourceLifecycle] = None,
        provider: typing.Optional[cdktf.TerraformProvider] = None,
        name: builtins.str,
        scope: builtins.str,
        event_delivery_schema: typing.Optional[builtins.str] = None,
        eventhub_endpoint: typing.Optional[typing.List["EventgridEventSubscriptionEventhubEndpoint"]] = None,
        hybrid_connection_endpoint: typing.Optional[typing.List["EventgridEventSubscriptionHybridConnectionEndpoint"]] = None,
        included_event_types: typing.Optional[typing.List[builtins.str]] = None,
        labels: typing.Optional[typing.List[builtins.str]] = None,
        retry_policy: typing.Optional[typing.List["EventgridEventSubscriptionRetryPolicy"]] = None,
        storage_blob_dead_letter_destination: typing.Optional[typing.List["EventgridEventSubscriptionStorageBlobDeadLetterDestination"]] = None,
        storage_queue_endpoint: typing.Optional[typing.List["EventgridEventSubscriptionStorageQueueEndpoint"]] = None,
        subject_filter: typing.Optional[typing.List["EventgridEventSubscriptionSubjectFilter"]] = None,
        timeouts: typing.Optional["EventgridEventSubscriptionTimeouts"] = None,
        topic_name: typing.Optional[builtins.str] = None,
        webhook_endpoint: typing.Optional[typing.List["EventgridEventSubscriptionWebhookEndpoint"]] = None,
    ) -> None:
        """
        :param count: 
        :param depends_on: 
        :param lifecycle: 
        :param provider: 
        :param name: 
        :param scope: 
        :param event_delivery_schema: 
        :param eventhub_endpoint: eventhub_endpoint block.
        :param hybrid_connection_endpoint: hybrid_connection_endpoint block.
        :param included_event_types: 
        :param labels: 
        :param retry_policy: retry_policy block.
        :param storage_blob_dead_letter_destination: storage_blob_dead_letter_destination block.
        :param storage_queue_endpoint: storage_queue_endpoint block.
        :param subject_filter: subject_filter block.
        :param timeouts: timeouts block.
        :param topic_name: 
        :param webhook_endpoint: webhook_endpoint block.
        """
        if isinstance(lifecycle, dict):
            lifecycle = cdktf.TerraformResourceLifecycle(**lifecycle)
        if isinstance(timeouts, dict):
            timeouts = EventgridEventSubscriptionTimeouts(**timeouts)
        self._values: typing.Dict[str, typing.Any] = {
            "name": name,
            "scope": scope,
        }
        if count is not None:
            self._values["count"] = count
        if depends_on is not None:
            self._values["depends_on"] = depends_on
        if lifecycle is not None:
            self._values["lifecycle"] = lifecycle
        if provider is not None:
            self._values["provider"] = provider
        if event_delivery_schema is not None:
            self._values["event_delivery_schema"] = event_delivery_schema
        if eventhub_endpoint is not None:
            self._values["eventhub_endpoint"] = eventhub_endpoint
        if hybrid_connection_endpoint is not None:
            self._values["hybrid_connection_endpoint"] = hybrid_connection_endpoint
        if included_event_types is not None:
            self._values["included_event_types"] = included_event_types
        if labels is not None:
            self._values["labels"] = labels
        if retry_policy is not None:
            self._values["retry_policy"] = retry_policy
        if storage_blob_dead_letter_destination is not None:
            self._values["storage_blob_dead_letter_destination"] = storage_blob_dead_letter_destination
        if storage_queue_endpoint is not None:
            self._values["storage_queue_endpoint"] = storage_queue_endpoint
        if subject_filter is not None:
            self._values["subject_filter"] = subject_filter
        if timeouts is not None:
            self._values["timeouts"] = timeouts
        if topic_name is not None:
            self._values["topic_name"] = topic_name
        if webhook_endpoint is not None:
            self._values["webhook_endpoint"] = webhook_endpoint

    @builtins.property
    def count(self) -> typing.Optional[jsii.Number]:
        """
        :stability: experimental
        """
        result = self._values.get("count")
        return result

    @builtins.property
    def depends_on(self) -> typing.Optional[typing.List[cdktf.TerraformResource]]:
        """
        :stability: experimental
        """
        result = self._values.get("depends_on")
        return result

    @builtins.property
    def lifecycle(self) -> typing.Optional[cdktf.TerraformResourceLifecycle]:
        """
        :stability: experimental
        """
        result = self._values.get("lifecycle")
        return result

    @builtins.property
    def provider(self) -> typing.Optional[cdktf.TerraformProvider]:
        """
        :stability: experimental
        """
        result = self._values.get("provider")
        return result

    @builtins.property
    def name(self) -> builtins.str:
        result = self._values.get("name")
        assert result is not None, "Required property 'name' is missing"
        return result

    @builtins.property
    def scope(self) -> builtins.str:
        result = self._values.get("scope")
        assert result is not None, "Required property 'scope' is missing"
        return result

    @builtins.property
    def event_delivery_schema(self) -> typing.Optional[builtins.str]:
        result = self._values.get("event_delivery_schema")
        return result

    @builtins.property
    def eventhub_endpoint(
        self,
    ) -> typing.Optional[typing.List["EventgridEventSubscriptionEventhubEndpoint"]]:
        """eventhub_endpoint block."""
        result = self._values.get("eventhub_endpoint")
        return result

    @builtins.property
    def hybrid_connection_endpoint(
        self,
    ) -> typing.Optional[typing.List["EventgridEventSubscriptionHybridConnectionEndpoint"]]:
        """hybrid_connection_endpoint block."""
        result = self._values.get("hybrid_connection_endpoint")
        return result

    @builtins.property
    def included_event_types(self) -> typing.Optional[typing.List[builtins.str]]:
        result = self._values.get("included_event_types")
        return result

    @builtins.property
    def labels(self) -> typing.Optional[typing.List[builtins.str]]:
        result = self._values.get("labels")
        return result

    @builtins.property
    def retry_policy(
        self,
    ) -> typing.Optional[typing.List["EventgridEventSubscriptionRetryPolicy"]]:
        """retry_policy block."""
        result = self._values.get("retry_policy")
        return result

    @builtins.property
    def storage_blob_dead_letter_destination(
        self,
    ) -> typing.Optional[typing.List["EventgridEventSubscriptionStorageBlobDeadLetterDestination"]]:
        """storage_blob_dead_letter_destination block."""
        result = self._values.get("storage_blob_dead_letter_destination")
        return result

    @builtins.property
    def storage_queue_endpoint(
        self,
    ) -> typing.Optional[typing.List["EventgridEventSubscriptionStorageQueueEndpoint"]]:
        """storage_queue_endpoint block."""
        result = self._values.get("storage_queue_endpoint")
        return result

    @builtins.property
    def subject_filter(
        self,
    ) -> typing.Optional[typing.List["EventgridEventSubscriptionSubjectFilter"]]:
        """subject_filter block."""
        result = self._values.get("subject_filter")
        return result

    @builtins.property
    def timeouts(self) -> typing.Optional["EventgridEventSubscriptionTimeouts"]:
        """timeouts block."""
        result = self._values.get("timeouts")
        return result

    @builtins.property
    def topic_name(self) -> typing.Optional[builtins.str]:
        result = self._values.get("topic_name")
        return result

    @builtins.property
    def webhook_endpoint(
        self,
    ) -> typing.Optional[typing.List["EventgridEventSubscriptionWebhookEndpoint"]]:
        """webhook_endpoint block."""
        result = self._values.get("webhook_endpoint")
        return result

    def __eq__(self, rhs: typing.Any) -> builtins.bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs: typing.Any) -> builtins.bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return "EventgridEventSubscriptionConfig(%s)" % ", ".join(
            k + "=" + repr(v) for k, v in self._values.items()
        )


@jsii.data_type(
    jsii_type="@cdktf/provider-azurerm.EventgridEventSubscriptionEventhubEndpoint",
    jsii_struct_bases=[],
    name_mapping={"eventhub_id": "eventhubId"},
)
class EventgridEventSubscriptionEventhubEndpoint:
    def __init__(self, *, eventhub_id: builtins.str) -> None:
        """
        :param eventhub_id: 
        """
        self._values: typing.Dict[str, typing.Any] = {
            "eventhub_id": eventhub_id,
        }

    @builtins.property
    def eventhub_id(self) -> builtins.str:
        result = self._values.get("eventhub_id")
        assert result is not None, "Required property 'eventhub_id' is missing"
        return result

    def __eq__(self, rhs: typing.Any) -> builtins.bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs: typing.Any) -> builtins.bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return "EventgridEventSubscriptionEventhubEndpoint(%s)" % ", ".join(
            k + "=" + repr(v) for k, v in self._values.items()
        )


@jsii.data_type(
    jsii_type="@cdktf/provider-azurerm.EventgridEventSubscriptionHybridConnectionEndpoint",
    jsii_struct_bases=[],
    name_mapping={"hybrid_connection_id": "hybridConnectionId"},
)
class EventgridEventSubscriptionHybridConnectionEndpoint:
    def __init__(self, *, hybrid_connection_id: builtins.str) -> None:
        """
        :param hybrid_connection_id: 
        """
        self._values: typing.Dict[str, typing.Any] = {
            "hybrid_connection_id": hybrid_connection_id,
        }

    @builtins.property
    def hybrid_connection_id(self) -> builtins.str:
        result = self._values.get("hybrid_connection_id")
        assert result is not None, "Required property 'hybrid_connection_id' is missing"
        return result

    def __eq__(self, rhs: typing.Any) -> builtins.bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs: typing.Any) -> builtins.bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return "EventgridEventSubscriptionHybridConnectionEndpoint(%s)" % ", ".join(
            k + "=" + repr(v) for k, v in self._values.items()
        )


@jsii.data_type(
    jsii_type="@cdktf/provider-azurerm.EventgridEventSubscriptionRetryPolicy",
    jsii_struct_bases=[],
    name_mapping={
        "event_time_to_live": "eventTimeToLive",
        "max_delivery_attempts": "maxDeliveryAttempts",
    },
)
class EventgridEventSubscriptionRetryPolicy:
    def __init__(
        self,
        *,
        event_time_to_live: jsii.Number,
        max_delivery_attempts: jsii.Number,
    ) -> None:
        """
        :param event_time_to_live: 
        :param max_delivery_attempts: 
        """
        self._values: typing.Dict[str, typing.Any] = {
            "event_time_to_live": event_time_to_live,
            "max_delivery_attempts": max_delivery_attempts,
        }

    @builtins.property
    def event_time_to_live(self) -> jsii.Number:
        result = self._values.get("event_time_to_live")
        assert result is not None, "Required property 'event_time_to_live' is missing"
        return result

    @builtins.property
    def max_delivery_attempts(self) -> jsii.Number:
        result = self._values.get("max_delivery_attempts")
        assert result is not None, "Required property 'max_delivery_attempts' is missing"
        return result

    def __eq__(self, rhs: typing.Any) -> builtins.bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs: typing.Any) -> builtins.bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return "EventgridEventSubscriptionRetryPolicy(%s)" % ", ".join(
            k + "=" + repr(v) for k, v in self._values.items()
        )


@jsii.data_type(
    jsii_type="@cdktf/provider-azurerm.EventgridEventSubscriptionStorageBlobDeadLetterDestination",
    jsii_struct_bases=[],
    name_mapping={
        "storage_account_id": "storageAccountId",
        "storage_blob_container_name": "storageBlobContainerName",
    },
)
class EventgridEventSubscriptionStorageBlobDeadLetterDestination:
    def __init__(
        self,
        *,
        storage_account_id: builtins.str,
        storage_blob_container_name: builtins.str,
    ) -> None:
        """
        :param storage_account_id: 
        :param storage_blob_container_name: 
        """
        self._values: typing.Dict[str, typing.Any] = {
            "storage_account_id": storage_account_id,
            "storage_blob_container_name": storage_blob_container_name,
        }

    @builtins.property
    def storage_account_id(self) -> builtins.str:
        result = self._values.get("storage_account_id")
        assert result is not None, "Required property 'storage_account_id' is missing"
        return result

    @builtins.property
    def storage_blob_container_name(self) -> builtins.str:
        result = self._values.get("storage_blob_container_name")
        assert result is not None, "Required property 'storage_blob_container_name' is missing"
        return result

    def __eq__(self, rhs: typing.Any) -> builtins.bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs: typing.Any) -> builtins.bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return "EventgridEventSubscriptionStorageBlobDeadLetterDestination(%s)" % ", ".join(
            k + "=" + repr(v) for k, v in self._values.items()
        )


@jsii.data_type(
    jsii_type="@cdktf/provider-azurerm.EventgridEventSubscriptionStorageQueueEndpoint",
    jsii_struct_bases=[],
    name_mapping={"queue_name": "queueName", "storage_account_id": "storageAccountId"},
)
class EventgridEventSubscriptionStorageQueueEndpoint:
    def __init__(
        self,
        *,
        queue_name: builtins.str,
        storage_account_id: builtins.str,
    ) -> None:
        """
        :param queue_name: 
        :param storage_account_id: 
        """
        self._values: typing.Dict[str, typing.Any] = {
            "queue_name": queue_name,
            "storage_account_id": storage_account_id,
        }

    @builtins.property
    def queue_name(self) -> builtins.str:
        result = self._values.get("queue_name")
        assert result is not None, "Required property 'queue_name' is missing"
        return result

    @builtins.property
    def storage_account_id(self) -> builtins.str:
        result = self._values.get("storage_account_id")
        assert result is not None, "Required property 'storage_account_id' is missing"
        return result

    def __eq__(self, rhs: typing.Any) -> builtins.bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs: typing.Any) -> builtins.bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return "EventgridEventSubscriptionStorageQueueEndpoint(%s)" % ", ".join(
            k + "=" + repr(v) for k, v in self._values.items()
        )


@jsii.data_type(
    jsii_type="@cdktf/provider-azurerm.EventgridEventSubscriptionSubjectFilter",
    jsii_struct_bases=[],
    name_mapping={
        "case_sensitive": "caseSensitive",
        "subject_begins_with": "subjectBeginsWith",
        "subject_ends_with": "subjectEndsWith",
    },
)
class EventgridEventSubscriptionSubjectFilter:
    def __init__(
        self,
        *,
        case_sensitive: typing.Optional[builtins.bool] = None,
        subject_begins_with: typing.Optional[builtins.str] = None,
        subject_ends_with: typing.Optional[builtins.str] = None,
    ) -> None:
        """
        :param case_sensitive: 
        :param subject_begins_with: 
        :param subject_ends_with: 
        """
        self._values: typing.Dict[str, typing.Any] = {}
        if case_sensitive is not None:
            self._values["case_sensitive"] = case_sensitive
        if subject_begins_with is not None:
            self._values["subject_begins_with"] = subject_begins_with
        if subject_ends_with is not None:
            self._values["subject_ends_with"] = subject_ends_with

    @builtins.property
    def case_sensitive(self) -> typing.Optional[builtins.bool]:
        result = self._values.get("case_sensitive")
        return result

    @builtins.property
    def subject_begins_with(self) -> typing.Optional[builtins.str]:
        result = self._values.get("subject_begins_with")
        return result

    @builtins.property
    def subject_ends_with(self) -> typing.Optional[builtins.str]:
        result = self._values.get("subject_ends_with")
        return result

    def __eq__(self, rhs: typing.Any) -> builtins.bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs: typing.Any) -> builtins.bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return "EventgridEventSubscriptionSubjectFilter(%s)" % ", ".join(
            k + "=" + repr(v) for k, v in self._values.items()
        )


@jsii.data_type(
    jsii_type="@cdktf/provider-azurerm.EventgridEventSubscriptionTimeouts",
    jsii_struct_bases=[],
    name_mapping={
        "create": "create",
        "delete": "delete",
        "read": "read",
        "update": "update",
    },
)
class EventgridEventSubscriptionTimeouts:
    def __init__(
        self,
        *,
        create: typing.Optional[builtins.str] = None,
        delete: typing.Optional[builtins.str] = None,
        read: typing.Optional[builtins.str] = None,
        update: typing.Optional[builtins.str] = None,
    ) -> None:
        """
        :param create: 
        :param delete: 
        :param read: 
        :param update: 
        """
        self._values: typing.Dict[str, typing.Any] = {}
        if create is not None:
            self._values["create"] = create
        if delete is not None:
            self._values["delete"] = delete
        if read is not None:
            self._values["read"] = read
        if update is not None:
            self._values["update"] = update

    @builtins.property
    def create(self) -> typing.Optional[builtins.str]:
        result = self._values.get("create")
        return result

    @builtins.property
    def delete(self) -> typing.Optional[builtins.str]:
        result = self._values.get("delete")
        return result

    @builtins.property
    def read(self) -> typing.Optional[builtins.str]:
        result = self._values.get("read")
        return result

    @builtins.property
    def update(self) -> typing.Optional[builtins.str]:
        result = self._values.get("update")
        return result

    def __eq__(self, rhs: typing.Any) -> builtins.bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs: typing.Any) -> builtins.bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return "EventgridEventSubscriptionTimeouts(%s)" % ", ".join(
            k + "=" + repr(v) for k, v in self._values.items()
        )


@jsii.data_type(
    jsii_type="@cdktf/provider-azurerm.EventgridEventSubscriptionWebhookEndpoint",
    jsii_struct_bases=[],
    name_mapping={"url": "url"},
)
class EventgridEventSubscriptionWebhookEndpoint:
    def __init__(self, *, url: builtins.str) -> None:
        """
        :param url: 
        """
        self._values: typing.Dict[str, typing.Any] = {
            "url": url,
        }

    @builtins.property
    def url(self) -> builtins.str:
        result = self._values.get("url")
        assert result is not None, "Required property 'url' is missing"
        return result

    def __eq__(self, rhs: typing.Any) -> builtins.bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs: typing.Any) -> builtins.bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return "EventgridEventSubscriptionWebhookEndpoint(%s)" % ", ".join(
            k + "=" + repr(v) for k, v in self._values.items()
        )


class EventgridTopic(
    cdktf.TerraformResource,
    metaclass=jsii.JSIIMeta,
    jsii_type="@cdktf/provider-azurerm.EventgridTopic",
):
    def __init__(
        self,
        scope: constructs.Construct,
        id: builtins.str,
        *,
        location: builtins.str,
        name: builtins.str,
        resource_group_name: builtins.str,
        tags: typing.Optional[typing.Mapping[builtins.str, builtins.str]] = None,
        timeouts: typing.Optional["EventgridTopicTimeouts"] = None,
        count: typing.Optional[jsii.Number] = None,
        depends_on: typing.Optional[typing.List[cdktf.TerraformResource]] = None,
        lifecycle: typing.Optional[cdktf.TerraformResourceLifecycle] = None,
        provider: typing.Optional[cdktf.TerraformProvider] = None,
    ) -> None:
        """
        :param scope: -
        :param id: -
        :param location: 
        :param name: 
        :param resource_group_name: 
        :param tags: 
        :param timeouts: timeouts block.
        :param count: 
        :param depends_on: 
        :param lifecycle: 
        :param provider: 
        """
        config = EventgridTopicConfig(
            location=location,
            name=name,
            resource_group_name=resource_group_name,
            tags=tags,
            timeouts=timeouts,
            count=count,
            depends_on=depends_on,
            lifecycle=lifecycle,
            provider=provider,
        )

        jsii.create(EventgridTopic, self, [scope, id, config])

    @jsii.member(jsii_name="synthesizeAttributes")
    def _synthesize_attributes(self) -> typing.Mapping[builtins.str, typing.Any]:
        return jsii.invoke(self, "synthesizeAttributes", [])

    @builtins.property # type: ignore
    @jsii.member(jsii_name="endpoint")
    def endpoint(self) -> builtins.str:
        return jsii.get(self, "endpoint")

    @builtins.property # type: ignore
    @jsii.member(jsii_name="primaryAccessKey")
    def primary_access_key(self) -> builtins.str:
        return jsii.get(self, "primaryAccessKey")

    @builtins.property # type: ignore
    @jsii.member(jsii_name="secondaryAccessKey")
    def secondary_access_key(self) -> builtins.str:
        return jsii.get(self, "secondaryAccessKey")

    @builtins.property # type: ignore
    @jsii.member(jsii_name="location")
    def location(self) -> builtins.str:
        return jsii.get(self, "location")

    @location.setter # type: ignore
    def location(self, value: builtins.str) -> None:
        jsii.set(self, "location", value)

    @builtins.property # type: ignore
    @jsii.member(jsii_name="name")
    def name(self) -> builtins.str:
        return jsii.get(self, "name")

    @name.setter # type: ignore
    def name(self, value: builtins.str) -> None:
        jsii.set(self, "name", value)

    @builtins.property # type: ignore
    @jsii.member(jsii_name="resourceGroupName")
    def resource_group_name(self) -> builtins.str:
        return jsii.get(self, "resourceGroupName")

    @resource_group_name.setter # type: ignore
    def resource_group_name(self, value: builtins.str) -> None:
        jsii.set(self, "resourceGroupName", value)

    @builtins.property # type: ignore
    @jsii.member(jsii_name="id")
    def id(self) -> typing.Optional[builtins.str]:
        return jsii.get(self, "id")

    @id.setter # type: ignore
    def id(self, value: typing.Optional[builtins.str]) -> None:
        jsii.set(self, "id", value)

    @builtins.property # type: ignore
    @jsii.member(jsii_name="tags")
    def tags(self) -> typing.Optional[typing.Mapping[builtins.str, builtins.str]]:
        return jsii.get(self, "tags")

    @tags.setter # type: ignore
    def tags(
        self,
        value: typing.Optional[typing.Mapping[builtins.str, builtins.str]],
    ) -> None:
        jsii.set(self, "tags", value)

    @builtins.property # type: ignore
    @jsii.member(jsii_name="timeouts")
    def timeouts(self) -> typing.Optional["EventgridTopicTimeouts"]:
        return jsii.get(self, "timeouts")

    @timeouts.setter # type: ignore
    def timeouts(self, value: typing.Optional["EventgridTopicTimeouts"]) -> None:
        jsii.set(self, "timeouts", value)


@jsii.data_type(
    jsii_type="@cdktf/provider-azurerm.EventgridTopicConfig",
    jsii_struct_bases=[cdktf.TerraformMetaArguments],
    name_mapping={
        "count": "count",
        "depends_on": "dependsOn",
        "lifecycle": "lifecycle",
        "provider": "provider",
        "location": "location",
        "name": "name",
        "resource_group_name": "resourceGroupName",
        "tags": "tags",
        "timeouts": "timeouts",
    },
)
class EventgridTopicConfig(cdktf.TerraformMetaArguments):
    def __init__(
        self,
        *,
        count: typing.Optional[jsii.Number] = None,
        depends_on: typing.Optional[typing.List[cdktf.TerraformResource]] = None,
        lifecycle: typing.Optional[cdktf.TerraformResourceLifecycle] = None,
        provider: typing.Optional[cdktf.TerraformProvider] = None,
        location: builtins.str,
        name: builtins.str,
        resource_group_name: builtins.str,
        tags: typing.Optional[typing.Mapping[builtins.str, builtins.str]] = None,
        timeouts: typing.Optional["EventgridTopicTimeouts"] = None,
    ) -> None:
        """
        :param count: 
        :param depends_on: 
        :param lifecycle: 
        :param provider: 
        :param location: 
        :param name: 
        :param resource_group_name: 
        :param tags: 
        :param timeouts: timeouts block.
        """
        if isinstance(lifecycle, dict):
            lifecycle = cdktf.TerraformResourceLifecycle(**lifecycle)
        if isinstance(timeouts, dict):
            timeouts = EventgridTopicTimeouts(**timeouts)
        self._values: typing.Dict[str, typing.Any] = {
            "location": location,
            "name": name,
            "resource_group_name": resource_group_name,
        }
        if count is not None:
            self._values["count"] = count
        if depends_on is not None:
            self._values["depends_on"] = depends_on
        if lifecycle is not None:
            self._values["lifecycle"] = lifecycle
        if provider is not None:
            self._values["provider"] = provider
        if tags is not None:
            self._values["tags"] = tags
        if timeouts is not None:
            self._values["timeouts"] = timeouts

    @builtins.property
    def count(self) -> typing.Optional[jsii.Number]:
        """
        :stability: experimental
        """
        result = self._values.get("count")
        return result

    @builtins.property
    def depends_on(self) -> typing.Optional[typing.List[cdktf.TerraformResource]]:
        """
        :stability: experimental
        """
        result = self._values.get("depends_on")
        return result

    @builtins.property
    def lifecycle(self) -> typing.Optional[cdktf.TerraformResourceLifecycle]:
        """
        :stability: experimental
        """
        result = self._values.get("lifecycle")
        return result

    @builtins.property
    def provider(self) -> typing.Optional[cdktf.TerraformProvider]:
        """
        :stability: experimental
        """
        result = self._values.get("provider")
        return result

    @builtins.property
    def location(self) -> builtins.str:
        result = self._values.get("location")
        assert result is not None, "Required property 'location' is missing"
        return result

    @builtins.property
    def name(self) -> builtins.str:
        result = self._values.get("name")
        assert result is not None, "Required property 'name' is missing"
        return result

    @builtins.property
    def resource_group_name(self) -> builtins.str:
        result = self._values.get("resource_group_name")
        assert result is not None, "Required property 'resource_group_name' is missing"
        return result

    @builtins.property
    def tags(self) -> typing.Optional[typing.Mapping[builtins.str, builtins.str]]:
        result = self._values.get("tags")
        return result

    @builtins.property
    def timeouts(self) -> typing.Optional["EventgridTopicTimeouts"]:
        """timeouts block."""
        result = self._values.get("timeouts")
        return result

    def __eq__(self, rhs: typing.Any) -> builtins.bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs: typing.Any) -> builtins.bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return "EventgridTopicConfig(%s)" % ", ".join(
            k + "=" + repr(v) for k, v in self._values.items()
        )


@jsii.data_type(
    jsii_type="@cdktf/provider-azurerm.EventgridTopicTimeouts",
    jsii_struct_bases=[],
    name_mapping={
        "create": "create",
        "delete": "delete",
        "read": "read",
        "update": "update",
    },
)
class EventgridTopicTimeouts:
    def __init__(
        self,
        *,
        create: typing.Optional[builtins.str] = None,
        delete: typing.Optional[builtins.str] = None,
        read: typing.Optional[builtins.str] = None,
        update: typing.Optional[builtins.str] = None,
    ) -> None:
        """
        :param create: 
        :param delete: 
        :param read: 
        :param update: 
        """
        self._values: typing.Dict[str, typing.Any] = {}
        if create is not None:
            self._values["create"] = create
        if delete is not None:
            self._values["delete"] = delete
        if read is not None:
            self._values["read"] = read
        if update is not None:
            self._values["update"] = update

    @builtins.property
    def create(self) -> typing.Optional[builtins.str]:
        result = self._values.get("create")
        return result

    @builtins.property
    def delete(self) -> typing.Optional[builtins.str]:
        result = self._values.get("delete")
        return result

    @builtins.property
    def read(self) -> typing.Optional[builtins.str]:
        result = self._values.get("read")
        return result

    @builtins.property
    def update(self) -> typing.Optional[builtins.str]:
        result = self._values.get("update")
        return result

    def __eq__(self, rhs: typing.Any) -> builtins.bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs: typing.Any) -> builtins.bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return "EventgridTopicTimeouts(%s)" % ", ".join(
            k + "=" + repr(v) for k, v in self._values.items()
        )


class Eventhub(
    cdktf.TerraformResource,
    metaclass=jsii.JSIIMeta,
    jsii_type="@cdktf/provider-azurerm.Eventhub",
):
    def __init__(
        self,
        scope: constructs.Construct,
        id: builtins.str,
        *,
        message_retention: jsii.Number,
        name: builtins.str,
        namespace_name: builtins.str,
        partition_count: jsii.Number,
        resource_group_name: builtins.str,
        capture_description: typing.Optional[typing.List["EventhubCaptureDescription"]] = None,
        timeouts: typing.Optional["EventhubTimeouts"] = None,
        count: typing.Optional[jsii.Number] = None,
        depends_on: typing.Optional[typing.List[cdktf.TerraformResource]] = None,
        lifecycle: typing.Optional[cdktf.TerraformResourceLifecycle] = None,
        provider: typing.Optional[cdktf.TerraformProvider] = None,
    ) -> None:
        """
        :param scope: -
        :param id: -
        :param message_retention: 
        :param name: 
        :param namespace_name: 
        :param partition_count: 
        :param resource_group_name: 
        :param capture_description: capture_description block.
        :param timeouts: timeouts block.
        :param count: 
        :param depends_on: 
        :param lifecycle: 
        :param provider: 
        """
        config = EventhubConfig(
            message_retention=message_retention,
            name=name,
            namespace_name=namespace_name,
            partition_count=partition_count,
            resource_group_name=resource_group_name,
            capture_description=capture_description,
            timeouts=timeouts,
            count=count,
            depends_on=depends_on,
            lifecycle=lifecycle,
            provider=provider,
        )

        jsii.create(Eventhub, self, [scope, id, config])

    @jsii.member(jsii_name="synthesizeAttributes")
    def _synthesize_attributes(self) -> typing.Mapping[builtins.str, typing.Any]:
        return jsii.invoke(self, "synthesizeAttributes", [])

    @builtins.property # type: ignore
    @jsii.member(jsii_name="partitionIds")
    def partition_ids(self) -> typing.List[builtins.str]:
        return jsii.get(self, "partitionIds")

    @builtins.property # type: ignore
    @jsii.member(jsii_name="messageRetention")
    def message_retention(self) -> jsii.Number:
        return jsii.get(self, "messageRetention")

    @message_retention.setter # type: ignore
    def message_retention(self, value: jsii.Number) -> None:
        jsii.set(self, "messageRetention", value)

    @builtins.property # type: ignore
    @jsii.member(jsii_name="name")
    def name(self) -> builtins.str:
        return jsii.get(self, "name")

    @name.setter # type: ignore
    def name(self, value: builtins.str) -> None:
        jsii.set(self, "name", value)

    @builtins.property # type: ignore
    @jsii.member(jsii_name="namespaceName")
    def namespace_name(self) -> builtins.str:
        return jsii.get(self, "namespaceName")

    @namespace_name.setter # type: ignore
    def namespace_name(self, value: builtins.str) -> None:
        jsii.set(self, "namespaceName", value)

    @builtins.property # type: ignore
    @jsii.member(jsii_name="partitionCount")
    def partition_count(self) -> jsii.Number:
        return jsii.get(self, "partitionCount")

    @partition_count.setter # type: ignore
    def partition_count(self, value: jsii.Number) -> None:
        jsii.set(self, "partitionCount", value)

    @builtins.property # type: ignore
    @jsii.member(jsii_name="resourceGroupName")
    def resource_group_name(self) -> builtins.str:
        return jsii.get(self, "resourceGroupName")

    @resource_group_name.setter # type: ignore
    def resource_group_name(self, value: builtins.str) -> None:
        jsii.set(self, "resourceGroupName", value)

    @builtins.property # type: ignore
    @jsii.member(jsii_name="captureDescription")
    def capture_description(
        self,
    ) -> typing.Optional[typing.List["EventhubCaptureDescription"]]:
        return jsii.get(self, "captureDescription")

    @capture_description.setter # type: ignore
    def capture_description(
        self,
        value: typing.Optional[typing.List["EventhubCaptureDescription"]],
    ) -> None:
        jsii.set(self, "captureDescription", value)

    @builtins.property # type: ignore
    @jsii.member(jsii_name="id")
    def id(self) -> typing.Optional[builtins.str]:
        return jsii.get(self, "id")

    @id.setter # type: ignore
    def id(self, value: typing.Optional[builtins.str]) -> None:
        jsii.set(self, "id", value)

    @builtins.property # type: ignore
    @jsii.member(jsii_name="timeouts")
    def timeouts(self) -> typing.Optional["EventhubTimeouts"]:
        return jsii.get(self, "timeouts")

    @timeouts.setter # type: ignore
    def timeouts(self, value: typing.Optional["EventhubTimeouts"]) -> None:
        jsii.set(self, "timeouts", value)


class EventhubAuthorizationRule(
    cdktf.TerraformResource,
    metaclass=jsii.JSIIMeta,
    jsii_type="@cdktf/provider-azurerm.EventhubAuthorizationRule",
):
    def __init__(
        self,
        scope: constructs.Construct,
        id: builtins.str,
        *,
        eventhub_name: builtins.str,
        name: builtins.str,
        namespace_name: builtins.str,
        resource_group_name: builtins.str,
        listen: typing.Optional[builtins.bool] = None,
        manage: typing.Optional[builtins.bool] = None,
        send: typing.Optional[builtins.bool] = None,
        timeouts: typing.Optional["EventhubAuthorizationRuleTimeouts"] = None,
        count: typing.Optional[jsii.Number] = None,
        depends_on: typing.Optional[typing.List[cdktf.TerraformResource]] = None,
        lifecycle: typing.Optional[cdktf.TerraformResourceLifecycle] = None,
        provider: typing.Optional[cdktf.TerraformProvider] = None,
    ) -> None:
        """
        :param scope: -
        :param id: -
        :param eventhub_name: 
        :param name: 
        :param namespace_name: 
        :param resource_group_name: 
        :param listen: 
        :param manage: 
        :param send: 
        :param timeouts: timeouts block.
        :param count: 
        :param depends_on: 
        :param lifecycle: 
        :param provider: 
        """
        config = EventhubAuthorizationRuleConfig(
            eventhub_name=eventhub_name,
            name=name,
            namespace_name=namespace_name,
            resource_group_name=resource_group_name,
            listen=listen,
            manage=manage,
            send=send,
            timeouts=timeouts,
            count=count,
            depends_on=depends_on,
            lifecycle=lifecycle,
            provider=provider,
        )

        jsii.create(EventhubAuthorizationRule, self, [scope, id, config])

    @jsii.member(jsii_name="synthesizeAttributes")
    def _synthesize_attributes(self) -> typing.Mapping[builtins.str, typing.Any]:
        return jsii.invoke(self, "synthesizeAttributes", [])

    @builtins.property # type: ignore
    @jsii.member(jsii_name="primaryConnectionString")
    def primary_connection_string(self) -> builtins.str:
        return jsii.get(self, "primaryConnectionString")

    @builtins.property # type: ignore
    @jsii.member(jsii_name="primaryKey")
    def primary_key(self) -> builtins.str:
        return jsii.get(self, "primaryKey")

    @builtins.property # type: ignore
    @jsii.member(jsii_name="secondaryConnectionString")
    def secondary_connection_string(self) -> builtins.str:
        return jsii.get(self, "secondaryConnectionString")

    @builtins.property # type: ignore
    @jsii.member(jsii_name="secondaryKey")
    def secondary_key(self) -> builtins.str:
        return jsii.get(self, "secondaryKey")

    @builtins.property # type: ignore
    @jsii.member(jsii_name="eventhubName")
    def eventhub_name(self) -> builtins.str:
        return jsii.get(self, "eventhubName")

    @eventhub_name.setter # type: ignore
    def eventhub_name(self, value: builtins.str) -> None:
        jsii.set(self, "eventhubName", value)

    @builtins.property # type: ignore
    @jsii.member(jsii_name="name")
    def name(self) -> builtins.str:
        return jsii.get(self, "name")

    @name.setter # type: ignore
    def name(self, value: builtins.str) -> None:
        jsii.set(self, "name", value)

    @builtins.property # type: ignore
    @jsii.member(jsii_name="namespaceName")
    def namespace_name(self) -> builtins.str:
        return jsii.get(self, "namespaceName")

    @namespace_name.setter # type: ignore
    def namespace_name(self, value: builtins.str) -> None:
        jsii.set(self, "namespaceName", value)

    @builtins.property # type: ignore
    @jsii.member(jsii_name="resourceGroupName")
    def resource_group_name(self) -> builtins.str:
        return jsii.get(self, "resourceGroupName")

    @resource_group_name.setter # type: ignore
    def resource_group_name(self, value: builtins.str) -> None:
        jsii.set(self, "resourceGroupName", value)

    @builtins.property # type: ignore
    @jsii.member(jsii_name="id")
    def id(self) -> typing.Optional[builtins.str]:
        return jsii.get(self, "id")

    @id.setter # type: ignore
    def id(self, value: typing.Optional[builtins.str]) -> None:
        jsii.set(self, "id", value)

    @builtins.property # type: ignore
    @jsii.member(jsii_name="listen")
    def listen(self) -> typing.Optional[builtins.bool]:
        return jsii.get(self, "listen")

    @listen.setter # type: ignore
    def listen(self, value: typing.Optional[builtins.bool]) -> None:
        jsii.set(self, "listen", value)

    @builtins.property # type: ignore
    @jsii.member(jsii_name="manage")
    def manage(self) -> typing.Optional[builtins.bool]:
        return jsii.get(self, "manage")

    @manage.setter # type: ignore
    def manage(self, value: typing.Optional[builtins.bool]) -> None:
        jsii.set(self, "manage", value)

    @builtins.property # type: ignore
    @jsii.member(jsii_name="send")
    def send(self) -> typing.Optional[builtins.bool]:
        return jsii.get(self, "send")

    @send.setter # type: ignore
    def send(self, value: typing.Optional[builtins.bool]) -> None:
        jsii.set(self, "send", value)

    @builtins.property # type: ignore
    @jsii.member(jsii_name="timeouts")
    def timeouts(self) -> typing.Optional["EventhubAuthorizationRuleTimeouts"]:
        return jsii.get(self, "timeouts")

    @timeouts.setter # type: ignore
    def timeouts(
        self,
        value: typing.Optional["EventhubAuthorizationRuleTimeouts"],
    ) -> None:
        jsii.set(self, "timeouts", value)


@jsii.data_type(
    jsii_type="@cdktf/provider-azurerm.EventhubAuthorizationRuleConfig",
    jsii_struct_bases=[cdktf.TerraformMetaArguments],
    name_mapping={
        "count": "count",
        "depends_on": "dependsOn",
        "lifecycle": "lifecycle",
        "provider": "provider",
        "eventhub_name": "eventhubName",
        "name": "name",
        "namespace_name": "namespaceName",
        "resource_group_name": "resourceGroupName",
        "listen": "listen",
        "manage": "manage",
        "send": "send",
        "timeouts": "timeouts",
    },
)
class EventhubAuthorizationRuleConfig(cdktf.TerraformMetaArguments):
    def __init__(
        self,
        *,
        count: typing.Optional[jsii.Number] = None,
        depends_on: typing.Optional[typing.List[cdktf.TerraformResource]] = None,
        lifecycle: typing.Optional[cdktf.TerraformResourceLifecycle] = None,
        provider: typing.Optional[cdktf.TerraformProvider] = None,
        eventhub_name: builtins.str,
        name: builtins.str,
        namespace_name: builtins.str,
        resource_group_name: builtins.str,
        listen: typing.Optional[builtins.bool] = None,
        manage: typing.Optional[builtins.bool] = None,
        send: typing.Optional[builtins.bool] = None,
        timeouts: typing.Optional["EventhubAuthorizationRuleTimeouts"] = None,
    ) -> None:
        """
        :param count: 
        :param depends_on: 
        :param lifecycle: 
        :param provider: 
        :param eventhub_name: 
        :param name: 
        :param namespace_name: 
        :param resource_group_name: 
        :param listen: 
        :param manage: 
        :param send: 
        :param timeouts: timeouts block.
        """
        if isinstance(lifecycle, dict):
            lifecycle = cdktf.TerraformResourceLifecycle(**lifecycle)
        if isinstance(timeouts, dict):
            timeouts = EventhubAuthorizationRuleTimeouts(**timeouts)
        self._values: typing.Dict[str, typing.Any] = {
            "eventhub_name": eventhub_name,
            "name": name,
            "namespace_name": namespace_name,
            "resource_group_name": resource_group_name,
        }
        if count is not None:
            self._values["count"] = count
        if depends_on is not None:
            self._values["depends_on"] = depends_on
        if lifecycle is not None:
            self._values["lifecycle"] = lifecycle
        if provider is not None:
            self._values["provider"] = provider
        if listen is not None:
            self._values["listen"] = listen
        if manage is not None:
            self._values["manage"] = manage
        if send is not None:
            self._values["send"] = send
        if timeouts is not None:
            self._values["timeouts"] = timeouts

    @builtins.property
    def count(self) -> typing.Optional[jsii.Number]:
        """
        :stability: experimental
        """
        result = self._values.get("count")
        return result

    @builtins.property
    def depends_on(self) -> typing.Optional[typing.List[cdktf.TerraformResource]]:
        """
        :stability: experimental
        """
        result = self._values.get("depends_on")
        return result

    @builtins.property
    def lifecycle(self) -> typing.Optional[cdktf.TerraformResourceLifecycle]:
        """
        :stability: experimental
        """
        result = self._values.get("lifecycle")
        return result

    @builtins.property
    def provider(self) -> typing.Optional[cdktf.TerraformProvider]:
        """
        :stability: experimental
        """
        result = self._values.get("provider")
        return result

    @builtins.property
    def eventhub_name(self) -> builtins.str:
        result = self._values.get("eventhub_name")
        assert result is not None, "Required property 'eventhub_name' is missing"
        return result

    @builtins.property
    def name(self) -> builtins.str:
        result = self._values.get("name")
        assert result is not None, "Required property 'name' is missing"
        return result

    @builtins.property
    def namespace_name(self) -> builtins.str:
        result = self._values.get("namespace_name")
        assert result is not None, "Required property 'namespace_name' is missing"
        return result

    @builtins.property
    def resource_group_name(self) -> builtins.str:
        result = self._values.get("resource_group_name")
        assert result is not None, "Required property 'resource_group_name' is missing"
        return result

    @builtins.property
    def listen(self) -> typing.Optional[builtins.bool]:
        result = self._values.get("listen")
        return result

    @builtins.property
    def manage(self) -> typing.Optional[builtins.bool]:
        result = self._values.get("manage")
        return result

    @builtins.property
    def send(self) -> typing.Optional[builtins.bool]:
        result = self._values.get("send")
        return result

    @builtins.property
    def timeouts(self) -> typing.Optional["EventhubAuthorizationRuleTimeouts"]:
        """timeouts block."""
        result = self._values.get("timeouts")
        return result

    def __eq__(self, rhs: typing.Any) -> builtins.bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs: typing.Any) -> builtins.bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return "EventhubAuthorizationRuleConfig(%s)" % ", ".join(
            k + "=" + repr(v) for k, v in self._values.items()
        )


@jsii.data_type(
    jsii_type="@cdktf/provider-azurerm.EventhubAuthorizationRuleTimeouts",
    jsii_struct_bases=[],
    name_mapping={
        "create": "create",
        "delete": "delete",
        "read": "read",
        "update": "update",
    },
)
class EventhubAuthorizationRuleTimeouts:
    def __init__(
        self,
        *,
        create: typing.Optional[builtins.str] = None,
        delete: typing.Optional[builtins.str] = None,
        read: typing.Optional[builtins.str] = None,
        update: typing.Optional[builtins.str] = None,
    ) -> None:
        """
        :param create: 
        :param delete: 
        :param read: 
        :param update: 
        """
        self._values: typing.Dict[str, typing.Any] = {}
        if create is not None:
            self._values["create"] = create
        if delete is not None:
            self._values["delete"] = delete
        if read is not None:
            self._values["read"] = read
        if update is not None:
            self._values["update"] = update

    @builtins.property
    def create(self) -> typing.Optional[builtins.str]:
        result = self._values.get("create")
        return result

    @builtins.property
    def delete(self) -> typing.Optional[builtins.str]:
        result = self._values.get("delete")
        return result

    @builtins.property
    def read(self) -> typing.Optional[builtins.str]:
        result = self._values.get("read")
        return result

    @builtins.property
    def update(self) -> typing.Optional[builtins.str]:
        result = self._values.get("update")
        return result

    def __eq__(self, rhs: typing.Any) -> builtins.bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs: typing.Any) -> builtins.bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return "EventhubAuthorizationRuleTimeouts(%s)" % ", ".join(
            k + "=" + repr(v) for k, v in self._values.items()
        )


@jsii.data_type(
    jsii_type="@cdktf/provider-azurerm.EventhubCaptureDescription",
    jsii_struct_bases=[],
    name_mapping={
        "destination": "destination",
        "enabled": "enabled",
        "encoding": "encoding",
        "interval_in_seconds": "intervalInSeconds",
        "size_limit_in_bytes": "sizeLimitInBytes",
        "skip_empty_archives": "skipEmptyArchives",
    },
)
class EventhubCaptureDescription:
    def __init__(
        self,
        *,
        destination: typing.List["EventhubCaptureDescriptionDestination"],
        enabled: builtins.bool,
        encoding: builtins.str,
        interval_in_seconds: typing.Optional[jsii.Number] = None,
        size_limit_in_bytes: typing.Optional[jsii.Number] = None,
        skip_empty_archives: typing.Optional[builtins.bool] = None,
    ) -> None:
        """
        :param destination: destination block.
        :param enabled: 
        :param encoding: 
        :param interval_in_seconds: 
        :param size_limit_in_bytes: 
        :param skip_empty_archives: 
        """
        self._values: typing.Dict[str, typing.Any] = {
            "destination": destination,
            "enabled": enabled,
            "encoding": encoding,
        }
        if interval_in_seconds is not None:
            self._values["interval_in_seconds"] = interval_in_seconds
        if size_limit_in_bytes is not None:
            self._values["size_limit_in_bytes"] = size_limit_in_bytes
        if skip_empty_archives is not None:
            self._values["skip_empty_archives"] = skip_empty_archives

    @builtins.property
    def destination(self) -> typing.List["EventhubCaptureDescriptionDestination"]:
        """destination block."""
        result = self._values.get("destination")
        assert result is not None, "Required property 'destination' is missing"
        return result

    @builtins.property
    def enabled(self) -> builtins.bool:
        result = self._values.get("enabled")
        assert result is not None, "Required property 'enabled' is missing"
        return result

    @builtins.property
    def encoding(self) -> builtins.str:
        result = self._values.get("encoding")
        assert result is not None, "Required property 'encoding' is missing"
        return result

    @builtins.property
    def interval_in_seconds(self) -> typing.Optional[jsii.Number]:
        result = self._values.get("interval_in_seconds")
        return result

    @builtins.property
    def size_limit_in_bytes(self) -> typing.Optional[jsii.Number]:
        result = self._values.get("size_limit_in_bytes")
        return result

    @builtins.property
    def skip_empty_archives(self) -> typing.Optional[builtins.bool]:
        result = self._values.get("skip_empty_archives")
        return result

    def __eq__(self, rhs: typing.Any) -> builtins.bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs: typing.Any) -> builtins.bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return "EventhubCaptureDescription(%s)" % ", ".join(
            k + "=" + repr(v) for k, v in self._values.items()
        )


@jsii.data_type(
    jsii_type="@cdktf/provider-azurerm.EventhubCaptureDescriptionDestination",
    jsii_struct_bases=[],
    name_mapping={
        "archive_name_format": "archiveNameFormat",
        "blob_container_name": "blobContainerName",
        "name": "name",
        "storage_account_id": "storageAccountId",
    },
)
class EventhubCaptureDescriptionDestination:
    def __init__(
        self,
        *,
        archive_name_format: builtins.str,
        blob_container_name: builtins.str,
        name: builtins.str,
        storage_account_id: builtins.str,
    ) -> None:
        """
        :param archive_name_format: 
        :param blob_container_name: 
        :param name: 
        :param storage_account_id: 
        """
        self._values: typing.Dict[str, typing.Any] = {
            "archive_name_format": archive_name_format,
            "blob_container_name": blob_container_name,
            "name": name,
            "storage_account_id": storage_account_id,
        }

    @builtins.property
    def archive_name_format(self) -> builtins.str:
        result = self._values.get("archive_name_format")
        assert result is not None, "Required property 'archive_name_format' is missing"
        return result

    @builtins.property
    def blob_container_name(self) -> builtins.str:
        result = self._values.get("blob_container_name")
        assert result is not None, "Required property 'blob_container_name' is missing"
        return result

    @builtins.property
    def name(self) -> builtins.str:
        result = self._values.get("name")
        assert result is not None, "Required property 'name' is missing"
        return result

    @builtins.property
    def storage_account_id(self) -> builtins.str:
        result = self._values.get("storage_account_id")
        assert result is not None, "Required property 'storage_account_id' is missing"
        return result

    def __eq__(self, rhs: typing.Any) -> builtins.bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs: typing.Any) -> builtins.bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return "EventhubCaptureDescriptionDestination(%s)" % ", ".join(
            k + "=" + repr(v) for k, v in self._values.items()
        )


@jsii.data_type(
    jsii_type="@cdktf/provider-azurerm.EventhubConfig",
    jsii_struct_bases=[cdktf.TerraformMetaArguments],
    name_mapping={
        "count": "count",
        "depends_on": "dependsOn",
        "lifecycle": "lifecycle",
        "provider": "provider",
        "message_retention": "messageRetention",
        "name": "name",
        "namespace_name": "namespaceName",
        "partition_count": "partitionCount",
        "resource_group_name": "resourceGroupName",
        "capture_description": "captureDescription",
        "timeouts": "timeouts",
    },
)
class EventhubConfig(cdktf.TerraformMetaArguments):
    def __init__(
        self,
        *,
        count: typing.Optional[jsii.Number] = None,
        depends_on: typing.Optional[typing.List[cdktf.TerraformResource]] = None,
        lifecycle: typing.Optional[cdktf.TerraformResourceLifecycle] = None,
        provider: typing.Optional[cdktf.TerraformProvider] = None,
        message_retention: jsii.Number,
        name: builtins.str,
        namespace_name: builtins.str,
        partition_count: jsii.Number,
        resource_group_name: builtins.str,
        capture_description: typing.Optional[typing.List[EventhubCaptureDescription]] = None,
        timeouts: typing.Optional["EventhubTimeouts"] = None,
    ) -> None:
        """
        :param count: 
        :param depends_on: 
        :param lifecycle: 
        :param provider: 
        :param message_retention: 
        :param name: 
        :param namespace_name: 
        :param partition_count: 
        :param resource_group_name: 
        :param capture_description: capture_description block.
        :param timeouts: timeouts block.
        """
        if isinstance(lifecycle, dict):
            lifecycle = cdktf.TerraformResourceLifecycle(**lifecycle)
        if isinstance(timeouts, dict):
            timeouts = EventhubTimeouts(**timeouts)
        self._values: typing.Dict[str, typing.Any] = {
            "message_retention": message_retention,
            "name": name,
            "namespace_name": namespace_name,
            "partition_count": partition_count,
            "resource_group_name": resource_group_name,
        }
        if count is not None:
            self._values["count"] = count
        if depends_on is not None:
            self._values["depends_on"] = depends_on
        if lifecycle is not None:
            self._values["lifecycle"] = lifecycle
        if provider is not None:
            self._values["provider"] = provider
        if capture_description is not None:
            self._values["capture_description"] = capture_description
        if timeouts is not None:
            self._values["timeouts"] = timeouts

    @builtins.property
    def count(self) -> typing.Optional[jsii.Number]:
        """
        :stability: experimental
        """
        result = self._values.get("count")
        return result

    @builtins.property
    def depends_on(self) -> typing.Optional[typing.List[cdktf.TerraformResource]]:
        """
        :stability: experimental
        """
        result = self._values.get("depends_on")
        return result

    @builtins.property
    def lifecycle(self) -> typing.Optional[cdktf.TerraformResourceLifecycle]:
        """
        :stability: experimental
        """
        result = self._values.get("lifecycle")
        return result

    @builtins.property
    def provider(self) -> typing.Optional[cdktf.TerraformProvider]:
        """
        :stability: experimental
        """
        result = self._values.get("provider")
        return result

    @builtins.property
    def message_retention(self) -> jsii.Number:
        result = self._values.get("message_retention")
        assert result is not None, "Required property 'message_retention' is missing"
        return result

    @builtins.property
    def name(self) -> builtins.str:
        result = self._values.get("name")
        assert result is not None, "Required property 'name' is missing"
        return result

    @builtins.property
    def namespace_name(self) -> builtins.str:
        result = self._values.get("namespace_name")
        assert result is not None, "Required property 'namespace_name' is missing"
        return result

    @builtins.property
    def partition_count(self) -> jsii.Number:
        result = self._values.get("partition_count")
        assert result is not None, "Required property 'partition_count' is missing"
        return result

    @builtins.property
    def resource_group_name(self) -> builtins.str:
        result = self._values.get("resource_group_name")
        assert result is not None, "Required property 'resource_group_name' is missing"
        return result

    @builtins.property
    def capture_description(
        self,
    ) -> typing.Optional[typing.List[EventhubCaptureDescription]]:
        """capture_description block."""
        result = self._values.get("capture_description")
        return result

    @builtins.property
    def timeouts(self) -> typing.Optional["EventhubTimeouts"]:
        """timeouts block."""
        result = self._values.get("timeouts")
        return result

    def __eq__(self, rhs: typing.Any) -> builtins.bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs: typing.Any) -> builtins.bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return "EventhubConfig(%s)" % ", ".join(
            k + "=" + repr(v) for k, v in self._values.items()
        )


class EventhubConsumerGroup(
    cdktf.TerraformResource,
    metaclass=jsii.JSIIMeta,
    jsii_type="@cdktf/provider-azurerm.EventhubConsumerGroup",
):
    def __init__(
        self,
        scope: constructs.Construct,
        id: builtins.str,
        *,
        eventhub_name: builtins.str,
        name: builtins.str,
        namespace_name: builtins.str,
        resource_group_name: builtins.str,
        timeouts: typing.Optional["EventhubConsumerGroupTimeouts"] = None,
        user_metadata: typing.Optional[builtins.str] = None,
        count: typing.Optional[jsii.Number] = None,
        depends_on: typing.Optional[typing.List[cdktf.TerraformResource]] = None,
        lifecycle: typing.Optional[cdktf.TerraformResourceLifecycle] = None,
        provider: typing.Optional[cdktf.TerraformProvider] = None,
    ) -> None:
        """
        :param scope: -
        :param id: -
        :param eventhub_name: 
        :param name: 
        :param namespace_name: 
        :param resource_group_name: 
        :param timeouts: timeouts block.
        :param user_metadata: 
        :param count: 
        :param depends_on: 
        :param lifecycle: 
        :param provider: 
        """
        config = EventhubConsumerGroupConfig(
            eventhub_name=eventhub_name,
            name=name,
            namespace_name=namespace_name,
            resource_group_name=resource_group_name,
            timeouts=timeouts,
            user_metadata=user_metadata,
            count=count,
            depends_on=depends_on,
            lifecycle=lifecycle,
            provider=provider,
        )

        jsii.create(EventhubConsumerGroup, self, [scope, id, config])

    @jsii.member(jsii_name="synthesizeAttributes")
    def _synthesize_attributes(self) -> typing.Mapping[builtins.str, typing.Any]:
        return jsii.invoke(self, "synthesizeAttributes", [])

    @builtins.property # type: ignore
    @jsii.member(jsii_name="eventhubName")
    def eventhub_name(self) -> builtins.str:
        return jsii.get(self, "eventhubName")

    @eventhub_name.setter # type: ignore
    def eventhub_name(self, value: builtins.str) -> None:
        jsii.set(self, "eventhubName", value)

    @builtins.property # type: ignore
    @jsii.member(jsii_name="name")
    def name(self) -> builtins.str:
        return jsii.get(self, "name")

    @name.setter # type: ignore
    def name(self, value: builtins.str) -> None:
        jsii.set(self, "name", value)

    @builtins.property # type: ignore
    @jsii.member(jsii_name="namespaceName")
    def namespace_name(self) -> builtins.str:
        return jsii.get(self, "namespaceName")

    @namespace_name.setter # type: ignore
    def namespace_name(self, value: builtins.str) -> None:
        jsii.set(self, "namespaceName", value)

    @builtins.property # type: ignore
    @jsii.member(jsii_name="resourceGroupName")
    def resource_group_name(self) -> builtins.str:
        return jsii.get(self, "resourceGroupName")

    @resource_group_name.setter # type: ignore
    def resource_group_name(self, value: builtins.str) -> None:
        jsii.set(self, "resourceGroupName", value)

    @builtins.property # type: ignore
    @jsii.member(jsii_name="id")
    def id(self) -> typing.Optional[builtins.str]:
        return jsii.get(self, "id")

    @id.setter # type: ignore
    def id(self, value: typing.Optional[builtins.str]) -> None:
        jsii.set(self, "id", value)

    @builtins.property # type: ignore
    @jsii.member(jsii_name="timeouts")
    def timeouts(self) -> typing.Optional["EventhubConsumerGroupTimeouts"]:
        return jsii.get(self, "timeouts")

    @timeouts.setter # type: ignore
    def timeouts(self, value: typing.Optional["EventhubConsumerGroupTimeouts"]) -> None:
        jsii.set(self, "timeouts", value)

    @builtins.property # type: ignore
    @jsii.member(jsii_name="userMetadata")
    def user_metadata(self) -> typing.Optional[builtins.str]:
        return jsii.get(self, "userMetadata")

    @user_metadata.setter # type: ignore
    def user_metadata(self, value: typing.Optional[builtins.str]) -> None:
        jsii.set(self, "userMetadata", value)


@jsii.data_type(
    jsii_type="@cdktf/provider-azurerm.EventhubConsumerGroupConfig",
    jsii_struct_bases=[cdktf.TerraformMetaArguments],
    name_mapping={
        "count": "count",
        "depends_on": "dependsOn",
        "lifecycle": "lifecycle",
        "provider": "provider",
        "eventhub_name": "eventhubName",
        "name": "name",
        "namespace_name": "namespaceName",
        "resource_group_name": "resourceGroupName",
        "timeouts": "timeouts",
        "user_metadata": "userMetadata",
    },
)
class EventhubConsumerGroupConfig(cdktf.TerraformMetaArguments):
    def __init__(
        self,
        *,
        count: typing.Optional[jsii.Number] = None,
        depends_on: typing.Optional[typing.List[cdktf.TerraformResource]] = None,
        lifecycle: typing.Optional[cdktf.TerraformResourceLifecycle] = None,
        provider: typing.Optional[cdktf.TerraformProvider] = None,
        eventhub_name: builtins.str,
        name: builtins.str,
        namespace_name: builtins.str,
        resource_group_name: builtins.str,
        timeouts: typing.Optional["EventhubConsumerGroupTimeouts"] = None,
        user_metadata: typing.Optional[builtins.str] = None,
    ) -> None:
        """
        :param count: 
        :param depends_on: 
        :param lifecycle: 
        :param provider: 
        :param eventhub_name: 
        :param name: 
        :param namespace_name: 
        :param resource_group_name: 
        :param timeouts: timeouts block.
        :param user_metadata: 
        """
        if isinstance(lifecycle, dict):
            lifecycle = cdktf.TerraformResourceLifecycle(**lifecycle)
        if isinstance(timeouts, dict):
            timeouts = EventhubConsumerGroupTimeouts(**timeouts)
        self._values: typing.Dict[str, typing.Any] = {
            "eventhub_name": eventhub_name,
            "name": name,
            "namespace_name": namespace_name,
            "resource_group_name": resource_group_name,
        }
        if count is not None:
            self._values["count"] = count
        if depends_on is not None:
            self._values["depends_on"] = depends_on
        if lifecycle is not None:
            self._values["lifecycle"] = lifecycle
        if provider is not None:
            self._values["provider"] = provider
        if timeouts is not None:
            self._values["timeouts"] = timeouts
        if user_metadata is not None:
            self._values["user_metadata"] = user_metadata

    @builtins.property
    def count(self) -> typing.Optional[jsii.Number]:
        """
        :stability: experimental
        """
        result = self._values.get("count")
        return result

    @builtins.property
    def depends_on(self) -> typing.Optional[typing.List[cdktf.TerraformResource]]:
        """
        :stability: experimental
        """
        result = self._values.get("depends_on")
        return result

    @builtins.property
    def lifecycle(self) -> typing.Optional[cdktf.TerraformResourceLifecycle]:
        """
        :stability: experimental
        """
        result = self._values.get("lifecycle")
        return result

    @builtins.property
    def provider(self) -> typing.Optional[cdktf.TerraformProvider]:
        """
        :stability: experimental
        """
        result = self._values.get("provider")
        return result

    @builtins.property
    def eventhub_name(self) -> builtins.str:
        result = self._values.get("eventhub_name")
        assert result is not None, "Required property 'eventhub_name' is missing"
        return result

    @builtins.property
    def name(self) -> builtins.str:
        result = self._values.get("name")
        assert result is not None, "Required property 'name' is missing"
        return result

    @builtins.property
    def namespace_name(self) -> builtins.str:
        result = self._values.get("namespace_name")
        assert result is not None, "Required property 'namespace_name' is missing"
        return result

    @builtins.property
    def resource_group_name(self) -> builtins.str:
        result = self._values.get("resource_group_name")
        assert result is not None, "Required property 'resource_group_name' is missing"
        return result

    @builtins.property
    def timeouts(self) -> typing.Optional["EventhubConsumerGroupTimeouts"]:
        """timeouts block."""
        result = self._values.get("timeouts")
        return result

    @builtins.property
    def user_metadata(self) -> typing.Optional[builtins.str]:
        result = self._values.get("user_metadata")
        return result

    def __eq__(self, rhs: typing.Any) -> builtins.bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs: typing.Any) -> builtins.bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return "EventhubConsumerGroupConfig(%s)" % ", ".join(
            k + "=" + repr(v) for k, v in self._values.items()
        )


@jsii.data_type(
    jsii_type="@cdktf/provider-azurerm.EventhubConsumerGroupTimeouts",
    jsii_struct_bases=[],
    name_mapping={
        "create": "create",
        "delete": "delete",
        "read": "read",
        "update": "update",
    },
)
class EventhubConsumerGroupTimeouts:
    def __init__(
        self,
        *,
        create: typing.Optional[builtins.str] = None,
        delete: typing.Optional[builtins.str] = None,
        read: typing.Optional[builtins.str] = None,
        update: typing.Optional[builtins.str] = None,
    ) -> None:
        """
        :param create: 
        :param delete: 
        :param read: 
        :param update: 
        """
        self._values: typing.Dict[str, typing.Any] = {}
        if create is not None:
            self._values["create"] = create
        if delete is not None:
            self._values["delete"] = delete
        if read is not None:
            self._values["read"] = read
        if update is not None:
            self._values["update"] = update

    @builtins.property
    def create(self) -> typing.Optional[builtins.str]:
        result = self._values.get("create")
        return result

    @builtins.property
    def delete(self) -> typing.Optional[builtins.str]:
        result = self._values.get("delete")
        return result

    @builtins.property
    def read(self) -> typing.Optional[builtins.str]:
        result = self._values.get("read")
        return result

    @builtins.property
    def update(self) -> typing.Optional[builtins.str]:
        result = self._values.get("update")
        return result

    def __eq__(self, rhs: typing.Any) -> builtins.bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs: typing.Any) -> builtins.bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return "EventhubConsumerGroupTimeouts(%s)" % ", ".join(
            k + "=" + repr(v) for k, v in self._values.items()
        )


class EventhubNamespace(
    cdktf.TerraformResource,
    metaclass=jsii.JSIIMeta,
    jsii_type="@cdktf/provider-azurerm.EventhubNamespace",
):
    def __init__(
        self,
        scope: constructs.Construct,
        id: builtins.str,
        *,
        location: builtins.str,
        name: builtins.str,
        resource_group_name: builtins.str,
        sku: builtins.str,
        auto_inflate_enabled: typing.Optional[builtins.bool] = None,
        capacity: typing.Optional[jsii.Number] = None,
        maximum_throughput_units: typing.Optional[jsii.Number] = None,
        network_rulesets: typing.Optional[typing.List["EventhubNamespaceNetworkRulesets"]] = None,
        tags: typing.Optional[typing.Mapping[builtins.str, builtins.str]] = None,
        timeouts: typing.Optional["EventhubNamespaceTimeouts"] = None,
        count: typing.Optional[jsii.Number] = None,
        depends_on: typing.Optional[typing.List[cdktf.TerraformResource]] = None,
        lifecycle: typing.Optional[cdktf.TerraformResourceLifecycle] = None,
        provider: typing.Optional[cdktf.TerraformProvider] = None,
    ) -> None:
        """
        :param scope: -
        :param id: -
        :param location: 
        :param name: 
        :param resource_group_name: 
        :param sku: 
        :param auto_inflate_enabled: 
        :param capacity: 
        :param maximum_throughput_units: 
        :param network_rulesets: 
        :param tags: 
        :param timeouts: timeouts block.
        :param count: 
        :param depends_on: 
        :param lifecycle: 
        :param provider: 
        """
        config = EventhubNamespaceConfig(
            location=location,
            name=name,
            resource_group_name=resource_group_name,
            sku=sku,
            auto_inflate_enabled=auto_inflate_enabled,
            capacity=capacity,
            maximum_throughput_units=maximum_throughput_units,
            network_rulesets=network_rulesets,
            tags=tags,
            timeouts=timeouts,
            count=count,
            depends_on=depends_on,
            lifecycle=lifecycle,
            provider=provider,
        )

        jsii.create(EventhubNamespace, self, [scope, id, config])

    @jsii.member(jsii_name="synthesizeAttributes")
    def _synthesize_attributes(self) -> typing.Mapping[builtins.str, typing.Any]:
        return jsii.invoke(self, "synthesizeAttributes", [])

    @builtins.property # type: ignore
    @jsii.member(jsii_name="defaultPrimaryConnectionString")
    def default_primary_connection_string(self) -> builtins.str:
        return jsii.get(self, "defaultPrimaryConnectionString")

    @builtins.property # type: ignore
    @jsii.member(jsii_name="defaultPrimaryKey")
    def default_primary_key(self) -> builtins.str:
        return jsii.get(self, "defaultPrimaryKey")

    @builtins.property # type: ignore
    @jsii.member(jsii_name="defaultSecondaryConnectionString")
    def default_secondary_connection_string(self) -> builtins.str:
        return jsii.get(self, "defaultSecondaryConnectionString")

    @builtins.property # type: ignore
    @jsii.member(jsii_name="defaultSecondaryKey")
    def default_secondary_key(self) -> builtins.str:
        return jsii.get(self, "defaultSecondaryKey")

    @builtins.property # type: ignore
    @jsii.member(jsii_name="location")
    def location(self) -> builtins.str:
        return jsii.get(self, "location")

    @location.setter # type: ignore
    def location(self, value: builtins.str) -> None:
        jsii.set(self, "location", value)

    @builtins.property # type: ignore
    @jsii.member(jsii_name="name")
    def name(self) -> builtins.str:
        return jsii.get(self, "name")

    @name.setter # type: ignore
    def name(self, value: builtins.str) -> None:
        jsii.set(self, "name", value)

    @builtins.property # type: ignore
    @jsii.member(jsii_name="resourceGroupName")
    def resource_group_name(self) -> builtins.str:
        return jsii.get(self, "resourceGroupName")

    @resource_group_name.setter # type: ignore
    def resource_group_name(self, value: builtins.str) -> None:
        jsii.set(self, "resourceGroupName", value)

    @builtins.property # type: ignore
    @jsii.member(jsii_name="sku")
    def sku(self) -> builtins.str:
        return jsii.get(self, "sku")

    @sku.setter # type: ignore
    def sku(self, value: builtins.str) -> None:
        jsii.set(self, "sku", value)

    @builtins.property # type: ignore
    @jsii.member(jsii_name="autoInflateEnabled")
    def auto_inflate_enabled(self) -> typing.Optional[builtins.bool]:
        return jsii.get(self, "autoInflateEnabled")

    @auto_inflate_enabled.setter # type: ignore
    def auto_inflate_enabled(self, value: typing.Optional[builtins.bool]) -> None:
        jsii.set(self, "autoInflateEnabled", value)

    @builtins.property # type: ignore
    @jsii.member(jsii_name="capacity")
    def capacity(self) -> typing.Optional[jsii.Number]:
        return jsii.get(self, "capacity")

    @capacity.setter # type: ignore
    def capacity(self, value: typing.Optional[jsii.Number]) -> None:
        jsii.set(self, "capacity", value)

    @builtins.property # type: ignore
    @jsii.member(jsii_name="id")
    def id(self) -> typing.Optional[builtins.str]:
        return jsii.get(self, "id")

    @id.setter # type: ignore
    def id(self, value: typing.Optional[builtins.str]) -> None:
        jsii.set(self, "id", value)

    @builtins.property # type: ignore
    @jsii.member(jsii_name="maximumThroughputUnits")
    def maximum_throughput_units(self) -> typing.Optional[jsii.Number]:
        return jsii.get(self, "maximumThroughputUnits")

    @maximum_throughput_units.setter # type: ignore
    def maximum_throughput_units(self, value: typing.Optional[jsii.Number]) -> None:
        jsii.set(self, "maximumThroughputUnits", value)

    @builtins.property # type: ignore
    @jsii.member(jsii_name="networkRulesets")
    def network_rulesets(
        self,
    ) -> typing.Optional[typing.List["EventhubNamespaceNetworkRulesets"]]:
        return jsii.get(self, "networkRulesets")

    @network_rulesets.setter # type: ignore
    def network_rulesets(
        self,
        value: typing.Optional[typing.List["EventhubNamespaceNetworkRulesets"]],
    ) -> None:
        jsii.set(self, "networkRulesets", value)

    @builtins.property # type: ignore
    @jsii.member(jsii_name="tags")
    def tags(self) -> typing.Optional[typing.Mapping[builtins.str, builtins.str]]:
        return jsii.get(self, "tags")

    @tags.setter # type: ignore
    def tags(
        self,
        value: typing.Optional[typing.Mapping[builtins.str, builtins.str]],
    ) -> None:
        jsii.set(self, "tags", value)

    @builtins.property # type: ignore
    @jsii.member(jsii_name="timeouts")
    def timeouts(self) -> typing.Optional["EventhubNamespaceTimeouts"]:
        return jsii.get(self, "timeouts")

    @timeouts.setter # type: ignore
    def timeouts(self, value: typing.Optional["EventhubNamespaceTimeouts"]) -> None:
        jsii.set(self, "timeouts", value)


class EventhubNamespaceAuthorizationRule(
    cdktf.TerraformResource,
    metaclass=jsii.JSIIMeta,
    jsii_type="@cdktf/provider-azurerm.EventhubNamespaceAuthorizationRule",
):
    def __init__(
        self,
        scope: constructs.Construct,
        id: builtins.str,
        *,
        name: builtins.str,
        namespace_name: builtins.str,
        resource_group_name: builtins.str,
        listen: typing.Optional[builtins.bool] = None,
        manage: typing.Optional[builtins.bool] = None,
        send: typing.Optional[builtins.bool] = None,
        timeouts: typing.Optional["EventhubNamespaceAuthorizationRuleTimeouts"] = None,
        count: typing.Optional[jsii.Number] = None,
        depends_on: typing.Optional[typing.List[cdktf.TerraformResource]] = None,
        lifecycle: typing.Optional[cdktf.TerraformResourceLifecycle] = None,
        provider: typing.Optional[cdktf.TerraformProvider] = None,
    ) -> None:
        """
        :param scope: -
        :param id: -
        :param name: 
        :param namespace_name: 
        :param resource_group_name: 
        :param listen: 
        :param manage: 
        :param send: 
        :param timeouts: timeouts block.
        :param count: 
        :param depends_on: 
        :param lifecycle: 
        :param provider: 
        """
        config = EventhubNamespaceAuthorizationRuleConfig(
            name=name,
            namespace_name=namespace_name,
            resource_group_name=resource_group_name,
            listen=listen,
            manage=manage,
            send=send,
            timeouts=timeouts,
            count=count,
            depends_on=depends_on,
            lifecycle=lifecycle,
            provider=provider,
        )

        jsii.create(EventhubNamespaceAuthorizationRule, self, [scope, id, config])

    @jsii.member(jsii_name="synthesizeAttributes")
    def _synthesize_attributes(self) -> typing.Mapping[builtins.str, typing.Any]:
        return jsii.invoke(self, "synthesizeAttributes", [])

    @builtins.property # type: ignore
    @jsii.member(jsii_name="primaryConnectionString")
    def primary_connection_string(self) -> builtins.str:
        return jsii.get(self, "primaryConnectionString")

    @builtins.property # type: ignore
    @jsii.member(jsii_name="primaryKey")
    def primary_key(self) -> builtins.str:
        return jsii.get(self, "primaryKey")

    @builtins.property # type: ignore
    @jsii.member(jsii_name="secondaryConnectionString")
    def secondary_connection_string(self) -> builtins.str:
        return jsii.get(self, "secondaryConnectionString")

    @builtins.property # type: ignore
    @jsii.member(jsii_name="secondaryKey")
    def secondary_key(self) -> builtins.str:
        return jsii.get(self, "secondaryKey")

    @builtins.property # type: ignore
    @jsii.member(jsii_name="name")
    def name(self) -> builtins.str:
        return jsii.get(self, "name")

    @name.setter # type: ignore
    def name(self, value: builtins.str) -> None:
        jsii.set(self, "name", value)

    @builtins.property # type: ignore
    @jsii.member(jsii_name="namespaceName")
    def namespace_name(self) -> builtins.str:
        return jsii.get(self, "namespaceName")

    @namespace_name.setter # type: ignore
    def namespace_name(self, value: builtins.str) -> None:
        jsii.set(self, "namespaceName", value)

    @builtins.property # type: ignore
    @jsii.member(jsii_name="resourceGroupName")
    def resource_group_name(self) -> builtins.str:
        return jsii.get(self, "resourceGroupName")

    @resource_group_name.setter # type: ignore
    def resource_group_name(self, value: builtins.str) -> None:
        jsii.set(self, "resourceGroupName", value)

    @builtins.property # type: ignore
    @jsii.member(jsii_name="id")
    def id(self) -> typing.Optional[builtins.str]:
        return jsii.get(self, "id")

    @id.setter # type: ignore
    def id(self, value: typing.Optional[builtins.str]) -> None:
        jsii.set(self, "id", value)

    @builtins.property # type: ignore
    @jsii.member(jsii_name="listen")
    def listen(self) -> typing.Optional[builtins.bool]:
        return jsii.get(self, "listen")

    @listen.setter # type: ignore
    def listen(self, value: typing.Optional[builtins.bool]) -> None:
        jsii.set(self, "listen", value)

    @builtins.property # type: ignore
    @jsii.member(jsii_name="manage")
    def manage(self) -> typing.Optional[builtins.bool]:
        return jsii.get(self, "manage")

    @manage.setter # type: ignore
    def manage(self, value: typing.Optional[builtins.bool]) -> None:
        jsii.set(self, "manage", value)

    @builtins.property # type: ignore
    @jsii.member(jsii_name="send")
    def send(self) -> typing.Optional[builtins.bool]:
        return jsii.get(self, "send")

    @send.setter # type: ignore
    def send(self, value: typing.Optional[builtins.bool]) -> None:
        jsii.set(self, "send", value)

    @builtins.property # type: ignore
    @jsii.member(jsii_name="timeouts")
    def timeouts(self) -> typing.Optional["EventhubNamespaceAuthorizationRuleTimeouts"]:
        return jsii.get(self, "timeouts")

    @timeouts.setter # type: ignore
    def timeouts(
        self,
        value: typing.Optional["EventhubNamespaceAuthorizationRuleTimeouts"],
    ) -> None:
        jsii.set(self, "timeouts", value)


@jsii.data_type(
    jsii_type="@cdktf/provider-azurerm.EventhubNamespaceAuthorizationRuleConfig",
    jsii_struct_bases=[cdktf.TerraformMetaArguments],
    name_mapping={
        "count": "count",
        "depends_on": "dependsOn",
        "lifecycle": "lifecycle",
        "provider": "provider",
        "name": "name",
        "namespace_name": "namespaceName",
        "resource_group_name": "resourceGroupName",
        "listen": "listen",
        "manage": "manage",
        "send": "send",
        "timeouts": "timeouts",
    },
)
class EventhubNamespaceAuthorizationRuleConfig(cdktf.TerraformMetaArguments):
    def __init__(
        self,
        *,
        count: typing.Optional[jsii.Number] = None,
        depends_on: typing.Optional[typing.List[cdktf.TerraformResource]] = None,
        lifecycle: typing.Optional[cdktf.TerraformResourceLifecycle] = None,
        provider: typing.Optional[cdktf.TerraformProvider] = None,
        name: builtins.str,
        namespace_name: builtins.str,
        resource_group_name: builtins.str,
        listen: typing.Optional[builtins.bool] = None,
        manage: typing.Optional[builtins.bool] = None,
        send: typing.Optional[builtins.bool] = None,
        timeouts: typing.Optional["EventhubNamespaceAuthorizationRuleTimeouts"] = None,
    ) -> None:
        """
        :param count: 
        :param depends_on: 
        :param lifecycle: 
        :param provider: 
        :param name: 
        :param namespace_name: 
        :param resource_group_name: 
        :param listen: 
        :param manage: 
        :param send: 
        :param timeouts: timeouts block.
        """
        if isinstance(lifecycle, dict):
            lifecycle = cdktf.TerraformResourceLifecycle(**lifecycle)
        if isinstance(timeouts, dict):
            timeouts = EventhubNamespaceAuthorizationRuleTimeouts(**timeouts)
        self._values: typing.Dict[str, typing.Any] = {
            "name": name,
            "namespace_name": namespace_name,
            "resource_group_name": resource_group_name,
        }
        if count is not None:
            self._values["count"] = count
        if depends_on is not None:
            self._values["depends_on"] = depends_on
        if lifecycle is not None:
            self._values["lifecycle"] = lifecycle
        if provider is not None:
            self._values["provider"] = provider
        if listen is not None:
            self._values["listen"] = listen
        if manage is not None:
            self._values["manage"] = manage
        if send is not None:
            self._values["send"] = send
        if timeouts is not None:
            self._values["timeouts"] = timeouts

    @builtins.property
    def count(self) -> typing.Optional[jsii.Number]:
        """
        :stability: experimental
        """
        result = self._values.get("count")
        return result

    @builtins.property
    def depends_on(self) -> typing.Optional[typing.List[cdktf.TerraformResource]]:
        """
        :stability: experimental
        """
        result = self._values.get("depends_on")
        return result

    @builtins.property
    def lifecycle(self) -> typing.Optional[cdktf.TerraformResourceLifecycle]:
        """
        :stability: experimental
        """
        result = self._values.get("lifecycle")
        return result

    @builtins.property
    def provider(self) -> typing.Optional[cdktf.TerraformProvider]:
        """
        :stability: experimental
        """
        result = self._values.get("provider")
        return result

    @builtins.property
    def name(self) -> builtins.str:
        result = self._values.get("name")
        assert result is not None, "Required property 'name' is missing"
        return result

    @builtins.property
    def namespace_name(self) -> builtins.str:
        result = self._values.get("namespace_name")
        assert result is not None, "Required property 'namespace_name' is missing"
        return result

    @builtins.property
    def resource_group_name(self) -> builtins.str:
        result = self._values.get("resource_group_name")
        assert result is not None, "Required property 'resource_group_name' is missing"
        return result

    @builtins.property
    def listen(self) -> typing.Optional[builtins.bool]:
        result = self._values.get("listen")
        return result

    @builtins.property
    def manage(self) -> typing.Optional[builtins.bool]:
        result = self._values.get("manage")
        return result

    @builtins.property
    def send(self) -> typing.Optional[builtins.bool]:
        result = self._values.get("send")
        return result

    @builtins.property
    def timeouts(self) -> typing.Optional["EventhubNamespaceAuthorizationRuleTimeouts"]:
        """timeouts block."""
        result = self._values.get("timeouts")
        return result

    def __eq__(self, rhs: typing.Any) -> builtins.bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs: typing.Any) -> builtins.bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return "EventhubNamespaceAuthorizationRuleConfig(%s)" % ", ".join(
            k + "=" + repr(v) for k, v in self._values.items()
        )


@jsii.data_type(
    jsii_type="@cdktf/provider-azurerm.EventhubNamespaceAuthorizationRuleTimeouts",
    jsii_struct_bases=[],
    name_mapping={
        "create": "create",
        "delete": "delete",
        "read": "read",
        "update": "update",
    },
)
class EventhubNamespaceAuthorizationRuleTimeouts:
    def __init__(
        self,
        *,
        create: typing.Optional[builtins.str] = None,
        delete: typing.Optional[builtins.str] = None,
        read: typing.Optional[builtins.str] = None,
        update: typing.Optional[builtins.str] = None,
    ) -> None:
        """
        :param create: 
        :param delete: 
        :param read: 
        :param update: 
        """
        self._values: typing.Dict[str, typing.Any] = {}
        if create is not None:
            self._values["create"] = create
        if delete is not None:
            self._values["delete"] = delete
        if read is not None:
            self._values["read"] = read
        if update is not None:
            self._values["update"] = update

    @builtins.property
    def create(self) -> typing.Optional[builtins.str]:
        result = self._values.get("create")
        return result

    @builtins.property
    def delete(self) -> typing.Optional[builtins.str]:
        result = self._values.get("delete")
        return result

    @builtins.property
    def read(self) -> typing.Optional[builtins.str]:
        result = self._values.get("read")
        return result

    @builtins.property
    def update(self) -> typing.Optional[builtins.str]:
        result = self._values.get("update")
        return result

    def __eq__(self, rhs: typing.Any) -> builtins.bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs: typing.Any) -> builtins.bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return "EventhubNamespaceAuthorizationRuleTimeouts(%s)" % ", ".join(
            k + "=" + repr(v) for k, v in self._values.items()
        )


@jsii.data_type(
    jsii_type="@cdktf/provider-azurerm.EventhubNamespaceConfig",
    jsii_struct_bases=[cdktf.TerraformMetaArguments],
    name_mapping={
        "count": "count",
        "depends_on": "dependsOn",
        "lifecycle": "lifecycle",
        "provider": "provider",
        "location": "location",
        "name": "name",
        "resource_group_name": "resourceGroupName",
        "sku": "sku",
        "auto_inflate_enabled": "autoInflateEnabled",
        "capacity": "capacity",
        "maximum_throughput_units": "maximumThroughputUnits",
        "network_rulesets": "networkRulesets",
        "tags": "tags",
        "timeouts": "timeouts",
    },
)
class EventhubNamespaceConfig(cdktf.TerraformMetaArguments):
    def __init__(
        self,
        *,
        count: typing.Optional[jsii.Number] = None,
        depends_on: typing.Optional[typing.List[cdktf.TerraformResource]] = None,
        lifecycle: typing.Optional[cdktf.TerraformResourceLifecycle] = None,
        provider: typing.Optional[cdktf.TerraformProvider] = None,
        location: builtins.str,
        name: builtins.str,
        resource_group_name: builtins.str,
        sku: builtins.str,
        auto_inflate_enabled: typing.Optional[builtins.bool] = None,
        capacity: typing.Optional[jsii.Number] = None,
        maximum_throughput_units: typing.Optional[jsii.Number] = None,
        network_rulesets: typing.Optional[typing.List["EventhubNamespaceNetworkRulesets"]] = None,
        tags: typing.Optional[typing.Mapping[builtins.str, builtins.str]] = None,
        timeouts: typing.Optional["EventhubNamespaceTimeouts"] = None,
    ) -> None:
        """
        :param count: 
        :param depends_on: 
        :param lifecycle: 
        :param provider: 
        :param location: 
        :param name: 
        :param resource_group_name: 
        :param sku: 
        :param auto_inflate_enabled: 
        :param capacity: 
        :param maximum_throughput_units: 
        :param network_rulesets: 
        :param tags: 
        :param timeouts: timeouts block.
        """
        if isinstance(lifecycle, dict):
            lifecycle = cdktf.TerraformResourceLifecycle(**lifecycle)
        if isinstance(timeouts, dict):
            timeouts = EventhubNamespaceTimeouts(**timeouts)
        self._values: typing.Dict[str, typing.Any] = {
            "location": location,
            "name": name,
            "resource_group_name": resource_group_name,
            "sku": sku,
        }
        if count is not None:
            self._values["count"] = count
        if depends_on is not None:
            self._values["depends_on"] = depends_on
        if lifecycle is not None:
            self._values["lifecycle"] = lifecycle
        if provider is not None:
            self._values["provider"] = provider
        if auto_inflate_enabled is not None:
            self._values["auto_inflate_enabled"] = auto_inflate_enabled
        if capacity is not None:
            self._values["capacity"] = capacity
        if maximum_throughput_units is not None:
            self._values["maximum_throughput_units"] = maximum_throughput_units
        if network_rulesets is not None:
            self._values["network_rulesets"] = network_rulesets
        if tags is not None:
            self._values["tags"] = tags
        if timeouts is not None:
            self._values["timeouts"] = timeouts

    @builtins.property
    def count(self) -> typing.Optional[jsii.Number]:
        """
        :stability: experimental
        """
        result = self._values.get("count")
        return result

    @builtins.property
    def depends_on(self) -> typing.Optional[typing.List[cdktf.TerraformResource]]:
        """
        :stability: experimental
        """
        result = self._values.get("depends_on")
        return result

    @builtins.property
    def lifecycle(self) -> typing.Optional[cdktf.TerraformResourceLifecycle]:
        """
        :stability: experimental
        """
        result = self._values.get("lifecycle")
        return result

    @builtins.property
    def provider(self) -> typing.Optional[cdktf.TerraformProvider]:
        """
        :stability: experimental
        """
        result = self._values.get("provider")
        return result

    @builtins.property
    def location(self) -> builtins.str:
        result = self._values.get("location")
        assert result is not None, "Required property 'location' is missing"
        return result

    @builtins.property
    def name(self) -> builtins.str:
        result = self._values.get("name")
        assert result is not None, "Required property 'name' is missing"
        return result

    @builtins.property
    def resource_group_name(self) -> builtins.str:
        result = self._values.get("resource_group_name")
        assert result is not None, "Required property 'resource_group_name' is missing"
        return result

    @builtins.property
    def sku(self) -> builtins.str:
        result = self._values.get("sku")
        assert result is not None, "Required property 'sku' is missing"
        return result

    @builtins.property
    def auto_inflate_enabled(self) -> typing.Optional[builtins.bool]:
        result = self._values.get("auto_inflate_enabled")
        return result

    @builtins.property
    def capacity(self) -> typing.Optional[jsii.Number]:
        result = self._values.get("capacity")
        return result

    @builtins.property
    def maximum_throughput_units(self) -> typing.Optional[jsii.Number]:
        result = self._values.get("maximum_throughput_units")
        return result

    @builtins.property
    def network_rulesets(
        self,
    ) -> typing.Optional[typing.List["EventhubNamespaceNetworkRulesets"]]:
        result = self._values.get("network_rulesets")
        return result

    @builtins.property
    def tags(self) -> typing.Optional[typing.Mapping[builtins.str, builtins.str]]:
        result = self._values.get("tags")
        return result

    @builtins.property
    def timeouts(self) -> typing.Optional["EventhubNamespaceTimeouts"]:
        """timeouts block."""
        result = self._values.get("timeouts")
        return result

    def __eq__(self, rhs: typing.Any) -> builtins.bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs: typing.Any) -> builtins.bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return "EventhubNamespaceConfig(%s)" % ", ".join(
            k + "=" + repr(v) for k, v in self._values.items()
        )


class EventhubNamespaceDisasterRecoveryConfig(
    cdktf.TerraformResource,
    metaclass=jsii.JSIIMeta,
    jsii_type="@cdktf/provider-azurerm.EventhubNamespaceDisasterRecoveryConfig",
):
    def __init__(
        self,
        scope: constructs.Construct,
        id: builtins.str,
        *,
        name: builtins.str,
        namespace_name: builtins.str,
        partner_namespace_id: builtins.str,
        resource_group_name: builtins.str,
        alternate_name: typing.Optional[builtins.str] = None,
        timeouts: typing.Optional["EventhubNamespaceDisasterRecoveryConfigTimeouts"] = None,
        count: typing.Optional[jsii.Number] = None,
        depends_on: typing.Optional[typing.List[cdktf.TerraformResource]] = None,
        lifecycle: typing.Optional[cdktf.TerraformResourceLifecycle] = None,
        provider: typing.Optional[cdktf.TerraformProvider] = None,
    ) -> None:
        """
        :param scope: -
        :param id: -
        :param name: 
        :param namespace_name: 
        :param partner_namespace_id: 
        :param resource_group_name: 
        :param alternate_name: 
        :param timeouts: timeouts block.
        :param count: 
        :param depends_on: 
        :param lifecycle: 
        :param provider: 
        """
        config = EventhubNamespaceDisasterRecoveryConfigConfig(
            name=name,
            namespace_name=namespace_name,
            partner_namespace_id=partner_namespace_id,
            resource_group_name=resource_group_name,
            alternate_name=alternate_name,
            timeouts=timeouts,
            count=count,
            depends_on=depends_on,
            lifecycle=lifecycle,
            provider=provider,
        )

        jsii.create(EventhubNamespaceDisasterRecoveryConfig, self, [scope, id, config])

    @jsii.member(jsii_name="synthesizeAttributes")
    def _synthesize_attributes(self) -> typing.Mapping[builtins.str, typing.Any]:
        return jsii.invoke(self, "synthesizeAttributes", [])

    @builtins.property # type: ignore
    @jsii.member(jsii_name="name")
    def name(self) -> builtins.str:
        return jsii.get(self, "name")

    @name.setter # type: ignore
    def name(self, value: builtins.str) -> None:
        jsii.set(self, "name", value)

    @builtins.property # type: ignore
    @jsii.member(jsii_name="namespaceName")
    def namespace_name(self) -> builtins.str:
        return jsii.get(self, "namespaceName")

    @namespace_name.setter # type: ignore
    def namespace_name(self, value: builtins.str) -> None:
        jsii.set(self, "namespaceName", value)

    @builtins.property # type: ignore
    @jsii.member(jsii_name="partnerNamespaceId")
    def partner_namespace_id(self) -> builtins.str:
        return jsii.get(self, "partnerNamespaceId")

    @partner_namespace_id.setter # type: ignore
    def partner_namespace_id(self, value: builtins.str) -> None:
        jsii.set(self, "partnerNamespaceId", value)

    @builtins.property # type: ignore
    @jsii.member(jsii_name="resourceGroupName")
    def resource_group_name(self) -> builtins.str:
        return jsii.get(self, "resourceGroupName")

    @resource_group_name.setter # type: ignore
    def resource_group_name(self, value: builtins.str) -> None:
        jsii.set(self, "resourceGroupName", value)

    @builtins.property # type: ignore
    @jsii.member(jsii_name="alternateName")
    def alternate_name(self) -> typing.Optional[builtins.str]:
        return jsii.get(self, "alternateName")

    @alternate_name.setter # type: ignore
    def alternate_name(self, value: typing.Optional[builtins.str]) -> None:
        jsii.set(self, "alternateName", value)

    @builtins.property # type: ignore
    @jsii.member(jsii_name="id")
    def id(self) -> typing.Optional[builtins.str]:
        return jsii.get(self, "id")

    @id.setter # type: ignore
    def id(self, value: typing.Optional[builtins.str]) -> None:
        jsii.set(self, "id", value)

    @builtins.property # type: ignore
    @jsii.member(jsii_name="timeouts")
    def timeouts(
        self,
    ) -> typing.Optional["EventhubNamespaceDisasterRecoveryConfigTimeouts"]:
        return jsii.get(self, "timeouts")

    @timeouts.setter # type: ignore
    def timeouts(
        self,
        value: typing.Optional["EventhubNamespaceDisasterRecoveryConfigTimeouts"],
    ) -> None:
        jsii.set(self, "timeouts", value)


@jsii.data_type(
    jsii_type="@cdktf/provider-azurerm.EventhubNamespaceDisasterRecoveryConfigConfig",
    jsii_struct_bases=[cdktf.TerraformMetaArguments],
    name_mapping={
        "count": "count",
        "depends_on": "dependsOn",
        "lifecycle": "lifecycle",
        "provider": "provider",
        "name": "name",
        "namespace_name": "namespaceName",
        "partner_namespace_id": "partnerNamespaceId",
        "resource_group_name": "resourceGroupName",
        "alternate_name": "alternateName",
        "timeouts": "timeouts",
    },
)
class EventhubNamespaceDisasterRecoveryConfigConfig(cdktf.TerraformMetaArguments):
    def __init__(
        self,
        *,
        count: typing.Optional[jsii.Number] = None,
        depends_on: typing.Optional[typing.List[cdktf.TerraformResource]] = None,
        lifecycle: typing.Optional[cdktf.TerraformResourceLifecycle] = None,
        provider: typing.Optional[cdktf.TerraformProvider] = None,
        name: builtins.str,
        namespace_name: builtins.str,
        partner_namespace_id: builtins.str,
        resource_group_name: builtins.str,
        alternate_name: typing.Optional[builtins.str] = None,
        timeouts: typing.Optional["EventhubNamespaceDisasterRecoveryConfigTimeouts"] = None,
    ) -> None:
        """
        :param count: 
        :param depends_on: 
        :param lifecycle: 
        :param provider: 
        :param name: 
        :param namespace_name: 
        :param partner_namespace_id: 
        :param resource_group_name: 
        :param alternate_name: 
        :param timeouts: timeouts block.
        """
        if isinstance(lifecycle, dict):
            lifecycle = cdktf.TerraformResourceLifecycle(**lifecycle)
        if isinstance(timeouts, dict):
            timeouts = EventhubNamespaceDisasterRecoveryConfigTimeouts(**timeouts)
        self._values: typing.Dict[str, typing.Any] = {
            "name": name,
            "namespace_name": namespace_name,
            "partner_namespace_id": partner_namespace_id,
            "resource_group_name": resource_group_name,
        }
        if count is not None:
            self._values["count"] = count
        if depends_on is not None:
            self._values["depends_on"] = depends_on
        if lifecycle is not None:
            self._values["lifecycle"] = lifecycle
        if provider is not None:
            self._values["provider"] = provider
        if alternate_name is not None:
            self._values["alternate_name"] = alternate_name
        if timeouts is not None:
            self._values["timeouts"] = timeouts

    @builtins.property
    def count(self) -> typing.Optional[jsii.Number]:
        """
        :stability: experimental
        """
        result = self._values.get("count")
        return result

    @builtins.property
    def depends_on(self) -> typing.Optional[typing.List[cdktf.TerraformResource]]:
        """
        :stability: experimental
        """
        result = self._values.get("depends_on")
        return result

    @builtins.property
    def lifecycle(self) -> typing.Optional[cdktf.TerraformResourceLifecycle]:
        """
        :stability: experimental
        """
        result = self._values.get("lifecycle")
        return result

    @builtins.property
    def provider(self) -> typing.Optional[cdktf.TerraformProvider]:
        """
        :stability: experimental
        """
        result = self._values.get("provider")
        return result

    @builtins.property
    def name(self) -> builtins.str:
        result = self._values.get("name")
        assert result is not None, "Required property 'name' is missing"
        return result

    @builtins.property
    def namespace_name(self) -> builtins.str:
        result = self._values.get("namespace_name")
        assert result is not None, "Required property 'namespace_name' is missing"
        return result

    @builtins.property
    def partner_namespace_id(self) -> builtins.str:
        result = self._values.get("partner_namespace_id")
        assert result is not None, "Required property 'partner_namespace_id' is missing"
        return result

    @builtins.property
    def resource_group_name(self) -> builtins.str:
        result = self._values.get("resource_group_name")
        assert result is not None, "Required property 'resource_group_name' is missing"
        return result

    @builtins.property
    def alternate_name(self) -> typing.Optional[builtins.str]:
        result = self._values.get("alternate_name")
        return result

    @builtins.property
    def timeouts(
        self,
    ) -> typing.Optional["EventhubNamespaceDisasterRecoveryConfigTimeouts"]:
        """timeouts block."""
        result = self._values.get("timeouts")
        return result

    def __eq__(self, rhs: typing.Any) -> builtins.bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs: typing.Any) -> builtins.bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return "EventhubNamespaceDisasterRecoveryConfigConfig(%s)" % ", ".join(
            k + "=" + repr(v) for k, v in self._values.items()
        )


@jsii.data_type(
    jsii_type="@cdktf/provider-azurerm.EventhubNamespaceDisasterRecoveryConfigTimeouts",
    jsii_struct_bases=[],
    name_mapping={
        "create": "create",
        "delete": "delete",
        "read": "read",
        "update": "update",
    },
)
class EventhubNamespaceDisasterRecoveryConfigTimeouts:
    def __init__(
        self,
        *,
        create: typing.Optional[builtins.str] = None,
        delete: typing.Optional[builtins.str] = None,
        read: typing.Optional[builtins.str] = None,
        update: typing.Optional[builtins.str] = None,
    ) -> None:
        """
        :param create: 
        :param delete: 
        :param read: 
        :param update: 
        """
        self._values: typing.Dict[str, typing.Any] = {}
        if create is not None:
            self._values["create"] = create
        if delete is not None:
            self._values["delete"] = delete
        if read is not None:
            self._values["read"] = read
        if update is not None:
            self._values["update"] = update

    @builtins.property
    def create(self) -> typing.Optional[builtins.str]:
        result = self._values.get("create")
        return result

    @builtins.property
    def delete(self) -> typing.Optional[builtins.str]:
        result = self._values.get("delete")
        return result

    @builtins.property
    def read(self) -> typing.Optional[builtins.str]:
        result = self._values.get("read")
        return result

    @builtins.property
    def update(self) -> typing.Optional[builtins.str]:
        result = self._values.get("update")
        return result

    def __eq__(self, rhs: typing.Any) -> builtins.bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs: typing.Any) -> builtins.bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return "EventhubNamespaceDisasterRecoveryConfigTimeouts(%s)" % ", ".join(
            k + "=" + repr(v) for k, v in self._values.items()
        )


@jsii.data_type(
    jsii_type="@cdktf/provider-azurerm.EventhubNamespaceNetworkRulesets",
    jsii_struct_bases=[],
    name_mapping={
        "default_action": "defaultAction",
        "ip_rule": "ipRule",
        "virtual_network_rule": "virtualNetworkRule",
    },
)
class EventhubNamespaceNetworkRulesets:
    def __init__(
        self,
        *,
        default_action: typing.Optional[builtins.str] = None,
        ip_rule: typing.Optional[typing.List["EventhubNamespaceNetworkRulesetsIpRule"]] = None,
        virtual_network_rule: typing.Optional[typing.List["EventhubNamespaceNetworkRulesetsVirtualNetworkRule"]] = None,
    ) -> None:
        """
        :param default_action: 
        :param ip_rule: 
        :param virtual_network_rule: 
        """
        self._values: typing.Dict[str, typing.Any] = {}
        if default_action is not None:
            self._values["default_action"] = default_action
        if ip_rule is not None:
            self._values["ip_rule"] = ip_rule
        if virtual_network_rule is not None:
            self._values["virtual_network_rule"] = virtual_network_rule

    @builtins.property
    def default_action(self) -> typing.Optional[builtins.str]:
        result = self._values.get("default_action")
        return result

    @builtins.property
    def ip_rule(
        self,
    ) -> typing.Optional[typing.List["EventhubNamespaceNetworkRulesetsIpRule"]]:
        result = self._values.get("ip_rule")
        return result

    @builtins.property
    def virtual_network_rule(
        self,
    ) -> typing.Optional[typing.List["EventhubNamespaceNetworkRulesetsVirtualNetworkRule"]]:
        result = self._values.get("virtual_network_rule")
        return result

    def __eq__(self, rhs: typing.Any) -> builtins.bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs: typing.Any) -> builtins.bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return "EventhubNamespaceNetworkRulesets(%s)" % ", ".join(
            k + "=" + repr(v) for k, v in self._values.items()
        )


@jsii.data_type(
    jsii_type="@cdktf/provider-azurerm.EventhubNamespaceNetworkRulesetsIpRule",
    jsii_struct_bases=[],
    name_mapping={"action": "action", "ip_mask": "ipMask"},
)
class EventhubNamespaceNetworkRulesetsIpRule:
    def __init__(
        self,
        *,
        action: typing.Optional[builtins.str] = None,
        ip_mask: typing.Optional[builtins.str] = None,
    ) -> None:
        """
        :param action: 
        :param ip_mask: 
        """
        self._values: typing.Dict[str, typing.Any] = {}
        if action is not None:
            self._values["action"] = action
        if ip_mask is not None:
            self._values["ip_mask"] = ip_mask

    @builtins.property
    def action(self) -> typing.Optional[builtins.str]:
        result = self._values.get("action")
        return result

    @builtins.property
    def ip_mask(self) -> typing.Optional[builtins.str]:
        result = self._values.get("ip_mask")
        return result

    def __eq__(self, rhs: typing.Any) -> builtins.bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs: typing.Any) -> builtins.bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return "EventhubNamespaceNetworkRulesetsIpRule(%s)" % ", ".join(
            k + "=" + repr(v) for k, v in self._values.items()
        )


@jsii.data_type(
    jsii_type="@cdktf/provider-azurerm.EventhubNamespaceNetworkRulesetsVirtualNetworkRule",
    jsii_struct_bases=[],
    name_mapping={
        "ignore_missing_virtual_network_service_endpoint": "ignoreMissingVirtualNetworkServiceEndpoint",
        "subnet_id": "subnetId",
    },
)
class EventhubNamespaceNetworkRulesetsVirtualNetworkRule:
    def __init__(
        self,
        *,
        ignore_missing_virtual_network_service_endpoint: typing.Optional[builtins.bool] = None,
        subnet_id: typing.Optional[builtins.str] = None,
    ) -> None:
        """
        :param ignore_missing_virtual_network_service_endpoint: 
        :param subnet_id: 
        """
        self._values: typing.Dict[str, typing.Any] = {}
        if ignore_missing_virtual_network_service_endpoint is not None:
            self._values["ignore_missing_virtual_network_service_endpoint"] = ignore_missing_virtual_network_service_endpoint
        if subnet_id is not None:
            self._values["subnet_id"] = subnet_id

    @builtins.property
    def ignore_missing_virtual_network_service_endpoint(
        self,
    ) -> typing.Optional[builtins.bool]:
        result = self._values.get("ignore_missing_virtual_network_service_endpoint")
        return result

    @builtins.property
    def subnet_id(self) -> typing.Optional[builtins.str]:
        result = self._values.get("subnet_id")
        return result

    def __eq__(self, rhs: typing.Any) -> builtins.bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs: typing.Any) -> builtins.bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return "EventhubNamespaceNetworkRulesetsVirtualNetworkRule(%s)" % ", ".join(
            k + "=" + repr(v) for k, v in self._values.items()
        )


@jsii.data_type(
    jsii_type="@cdktf/provider-azurerm.EventhubNamespaceTimeouts",
    jsii_struct_bases=[],
    name_mapping={
        "create": "create",
        "delete": "delete",
        "read": "read",
        "update": "update",
    },
)
class EventhubNamespaceTimeouts:
    def __init__(
        self,
        *,
        create: typing.Optional[builtins.str] = None,
        delete: typing.Optional[builtins.str] = None,
        read: typing.Optional[builtins.str] = None,
        update: typing.Optional[builtins.str] = None,
    ) -> None:
        """
        :param create: 
        :param delete: 
        :param read: 
        :param update: 
        """
        self._values: typing.Dict[str, typing.Any] = {}
        if create is not None:
            self._values["create"] = create
        if delete is not None:
            self._values["delete"] = delete
        if read is not None:
            self._values["read"] = read
        if update is not None:
            self._values["update"] = update

    @builtins.property
    def create(self) -> typing.Optional[builtins.str]:
        result = self._values.get("create")
        return result

    @builtins.property
    def delete(self) -> typing.Optional[builtins.str]:
        result = self._values.get("delete")
        return result

    @builtins.property
    def read(self) -> typing.Optional[builtins.str]:
        result = self._values.get("read")
        return result

    @builtins.property
    def update(self) -> typing.Optional[builtins.str]:
        result = self._values.get("update")
        return result

    def __eq__(self, rhs: typing.Any) -> builtins.bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs: typing.Any) -> builtins.bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return "EventhubNamespaceTimeouts(%s)" % ", ".join(
            k + "=" + repr(v) for k, v in self._values.items()
        )


@jsii.data_type(
    jsii_type="@cdktf/provider-azurerm.EventhubTimeouts",
    jsii_struct_bases=[],
    name_mapping={
        "create": "create",
        "delete": "delete",
        "read": "read",
        "update": "update",
    },
)
class EventhubTimeouts:
    def __init__(
        self,
        *,
        create: typing.Optional[builtins.str] = None,
        delete: typing.Optional[builtins.str] = None,
        read: typing.Optional[builtins.str] = None,
        update: typing.Optional[builtins.str] = None,
    ) -> None:
        """
        :param create: 
        :param delete: 
        :param read: 
        :param update: 
        """
        self._values: typing.Dict[str, typing.Any] = {}
        if create is not None:
            self._values["create"] = create
        if delete is not None:
            self._values["delete"] = delete
        if read is not None:
            self._values["read"] = read
        if update is not None:
            self._values["update"] = update

    @builtins.property
    def create(self) -> typing.Optional[builtins.str]:
        result = self._values.get("create")
        return result

    @builtins.property
    def delete(self) -> typing.Optional[builtins.str]:
        result = self._values.get("delete")
        return result

    @builtins.property
    def read(self) -> typing.Optional[builtins.str]:
        result = self._values.get("read")
        return result

    @builtins.property
    def update(self) -> typing.Optional[builtins.str]:
        result = self._values.get("update")
        return result

    def __eq__(self, rhs: typing.Any) -> builtins.bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs: typing.Any) -> builtins.bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return "EventhubTimeouts(%s)" % ", ".join(
            k + "=" + repr(v) for k, v in self._values.items()
        )


class ExpressRouteCircuit(
    cdktf.TerraformResource,
    metaclass=jsii.JSIIMeta,
    jsii_type="@cdktf/provider-azurerm.ExpressRouteCircuit",
):
    def __init__(
        self,
        scope: constructs.Construct,
        id: builtins.str,
        *,
        bandwidth_in_mbps: jsii.Number,
        location: builtins.str,
        name: builtins.str,
        peering_location: builtins.str,
        resource_group_name: builtins.str,
        service_provider_name: builtins.str,
        sku: typing.List["ExpressRouteCircuitSku"],
        allow_classic_operations: typing.Optional[builtins.bool] = None,
        tags: typing.Optional[typing.Mapping[builtins.str, builtins.str]] = None,
        timeouts: typing.Optional["ExpressRouteCircuitTimeouts"] = None,
        count: typing.Optional[jsii.Number] = None,
        depends_on: typing.Optional[typing.List[cdktf.TerraformResource]] = None,
        lifecycle: typing.Optional[cdktf.TerraformResourceLifecycle] = None,
        provider: typing.Optional[cdktf.TerraformProvider] = None,
    ) -> None:
        """
        :param scope: -
        :param id: -
        :param bandwidth_in_mbps: 
        :param location: 
        :param name: 
        :param peering_location: 
        :param resource_group_name: 
        :param service_provider_name: 
        :param sku: sku block.
        :param allow_classic_operations: 
        :param tags: 
        :param timeouts: timeouts block.
        :param count: 
        :param depends_on: 
        :param lifecycle: 
        :param provider: 
        """
        config = ExpressRouteCircuitConfig(
            bandwidth_in_mbps=bandwidth_in_mbps,
            location=location,
            name=name,
            peering_location=peering_location,
            resource_group_name=resource_group_name,
            service_provider_name=service_provider_name,
            sku=sku,
            allow_classic_operations=allow_classic_operations,
            tags=tags,
            timeouts=timeouts,
            count=count,
            depends_on=depends_on,
            lifecycle=lifecycle,
            provider=provider,
        )

        jsii.create(ExpressRouteCircuit, self, [scope, id, config])

    @jsii.member(jsii_name="synthesizeAttributes")
    def _synthesize_attributes(self) -> typing.Mapping[builtins.str, typing.Any]:
        return jsii.invoke(self, "synthesizeAttributes", [])

    @builtins.property # type: ignore
    @jsii.member(jsii_name="serviceKey")
    def service_key(self) -> builtins.str:
        return jsii.get(self, "serviceKey")

    @builtins.property # type: ignore
    @jsii.member(jsii_name="serviceProviderProvisioningState")
    def service_provider_provisioning_state(self) -> builtins.str:
        return jsii.get(self, "serviceProviderProvisioningState")

    @builtins.property # type: ignore
    @jsii.member(jsii_name="bandwidthInMbps")
    def bandwidth_in_mbps(self) -> jsii.Number:
        return jsii.get(self, "bandwidthInMbps")

    @bandwidth_in_mbps.setter # type: ignore
    def bandwidth_in_mbps(self, value: jsii.Number) -> None:
        jsii.set(self, "bandwidthInMbps", value)

    @builtins.property # type: ignore
    @jsii.member(jsii_name="location")
    def location(self) -> builtins.str:
        return jsii.get(self, "location")

    @location.setter # type: ignore
    def location(self, value: builtins.str) -> None:
        jsii.set(self, "location", value)

    @builtins.property # type: ignore
    @jsii.member(jsii_name="name")
    def name(self) -> builtins.str:
        return jsii.get(self, "name")

    @name.setter # type: ignore
    def name(self, value: builtins.str) -> None:
        jsii.set(self, "name", value)

    @builtins.property # type: ignore
    @jsii.member(jsii_name="peeringLocation")
    def peering_location(self) -> builtins.str:
        return jsii.get(self, "peeringLocation")

    @peering_location.setter # type: ignore
    def peering_location(self, value: builtins.str) -> None:
        jsii.set(self, "peeringLocation", value)

    @builtins.property # type: ignore
    @jsii.member(jsii_name="resourceGroupName")
    def resource_group_name(self) -> builtins.str:
        return jsii.get(self, "resourceGroupName")

    @resource_group_name.setter # type: ignore
    def resource_group_name(self, value: builtins.str) -> None:
        jsii.set(self, "resourceGroupName", value)

    @builtins.property # type: ignore
    @jsii.member(jsii_name="serviceProviderName")
    def service_provider_name(self) -> builtins.str:
        return jsii.get(self, "serviceProviderName")

    @service_provider_name.setter # type: ignore
    def service_provider_name(self, value: builtins.str) -> None:
        jsii.set(self, "serviceProviderName", value)

    @builtins.property # type: ignore
    @jsii.member(jsii_name="sku")
    def sku(self) -> typing.List["ExpressRouteCircuitSku"]:
        return jsii.get(self, "sku")

    @sku.setter # type: ignore
    def sku(self, value: typing.List["ExpressRouteCircuitSku"]) -> None:
        jsii.set(self, "sku", value)

    @builtins.property # type: ignore
    @jsii.member(jsii_name="allowClassicOperations")
    def allow_classic_operations(self) -> typing.Optional[builtins.bool]:
        return jsii.get(self, "allowClassicOperations")

    @allow_classic_operations.setter # type: ignore
    def allow_classic_operations(self, value: typing.Optional[builtins.bool]) -> None:
        jsii.set(self, "allowClassicOperations", value)

    @builtins.property # type: ignore
    @jsii.member(jsii_name="id")
    def id(self) -> typing.Optional[builtins.str]:
        return jsii.get(self, "id")

    @id.setter # type: ignore
    def id(self, value: typing.Optional[builtins.str]) -> None:
        jsii.set(self, "id", value)

    @builtins.property # type: ignore
    @jsii.member(jsii_name="tags")
    def tags(self) -> typing.Optional[typing.Mapping[builtins.str, builtins.str]]:
        return jsii.get(self, "tags")

    @tags.setter # type: ignore
    def tags(
        self,
        value: typing.Optional[typing.Mapping[builtins.str, builtins.str]],
    ) -> None:
        jsii.set(self, "tags", value)

    @builtins.property # type: ignore
    @jsii.member(jsii_name="timeouts")
    def timeouts(self) -> typing.Optional["ExpressRouteCircuitTimeouts"]:
        return jsii.get(self, "timeouts")

    @timeouts.setter # type: ignore
    def timeouts(self, value: typing.Optional["ExpressRouteCircuitTimeouts"]) -> None:
        jsii.set(self, "timeouts", value)


class ExpressRouteCircuitAuthorization(
    cdktf.TerraformResource,
    metaclass=jsii.JSIIMeta,
    jsii_type="@cdktf/provider-azurerm.ExpressRouteCircuitAuthorization",
):
    def __init__(
        self,
        scope: constructs.Construct,
        id: builtins.str,
        *,
        express_route_circuit_name: builtins.str,
        name: builtins.str,
        resource_group_name: builtins.str,
        timeouts: typing.Optional["ExpressRouteCircuitAuthorizationTimeouts"] = None,
        count: typing.Optional[jsii.Number] = None,
        depends_on: typing.Optional[typing.List[cdktf.TerraformResource]] = None,
        lifecycle: typing.Optional[cdktf.TerraformResourceLifecycle] = None,
        provider: typing.Optional[cdktf.TerraformProvider] = None,
    ) -> None:
        """
        :param scope: -
        :param id: -
        :param express_route_circuit_name: 
        :param name: 
        :param resource_group_name: 
        :param timeouts: timeouts block.
        :param count: 
        :param depends_on: 
        :param lifecycle: 
        :param provider: 
        """
        config = ExpressRouteCircuitAuthorizationConfig(
            express_route_circuit_name=express_route_circuit_name,
            name=name,
            resource_group_name=resource_group_name,
            timeouts=timeouts,
            count=count,
            depends_on=depends_on,
            lifecycle=lifecycle,
            provider=provider,
        )

        jsii.create(ExpressRouteCircuitAuthorization, self, [scope, id, config])

    @jsii.member(jsii_name="synthesizeAttributes")
    def _synthesize_attributes(self) -> typing.Mapping[builtins.str, typing.Any]:
        return jsii.invoke(self, "synthesizeAttributes", [])

    @builtins.property # type: ignore
    @jsii.member(jsii_name="authorizationKey")
    def authorization_key(self) -> builtins.str:
        return jsii.get(self, "authorizationKey")

    @builtins.property # type: ignore
    @jsii.member(jsii_name="authorizationUseStatus")
    def authorization_use_status(self) -> builtins.str:
        return jsii.get(self, "authorizationUseStatus")

    @builtins.property # type: ignore
    @jsii.member(jsii_name="expressRouteCircuitName")
    def express_route_circuit_name(self) -> builtins.str:
        return jsii.get(self, "expressRouteCircuitName")

    @express_route_circuit_name.setter # type: ignore
    def express_route_circuit_name(self, value: builtins.str) -> None:
        jsii.set(self, "expressRouteCircuitName", value)

    @builtins.property # type: ignore
    @jsii.member(jsii_name="name")
    def name(self) -> builtins.str:
        return jsii.get(self, "name")

    @name.setter # type: ignore
    def name(self, value: builtins.str) -> None:
        jsii.set(self, "name", value)

    @builtins.property # type: ignore
    @jsii.member(jsii_name="resourceGroupName")
    def resource_group_name(self) -> builtins.str:
        return jsii.get(self, "resourceGroupName")

    @resource_group_name.setter # type: ignore
    def resource_group_name(self, value: builtins.str) -> None:
        jsii.set(self, "resourceGroupName", value)

    @builtins.property # type: ignore
    @jsii.member(jsii_name="id")
    def id(self) -> typing.Optional[builtins.str]:
        return jsii.get(self, "id")

    @id.setter # type: ignore
    def id(self, value: typing.Optional[builtins.str]) -> None:
        jsii.set(self, "id", value)

    @builtins.property # type: ignore
    @jsii.member(jsii_name="timeouts")
    def timeouts(self) -> typing.Optional["ExpressRouteCircuitAuthorizationTimeouts"]:
        return jsii.get(self, "timeouts")

    @timeouts.setter # type: ignore
    def timeouts(
        self,
        value: typing.Optional["ExpressRouteCircuitAuthorizationTimeouts"],
    ) -> None:
        jsii.set(self, "timeouts", value)


@jsii.data_type(
    jsii_type="@cdktf/provider-azurerm.ExpressRouteCircuitAuthorizationConfig",
    jsii_struct_bases=[cdktf.TerraformMetaArguments],
    name_mapping={
        "count": "count",
        "depends_on": "dependsOn",
        "lifecycle": "lifecycle",
        "provider": "provider",
        "express_route_circuit_name": "expressRouteCircuitName",
        "name": "name",
        "resource_group_name": "resourceGroupName",
        "timeouts": "timeouts",
    },
)
class ExpressRouteCircuitAuthorizationConfig(cdktf.TerraformMetaArguments):
    def __init__(
        self,
        *,
        count: typing.Optional[jsii.Number] = None,
        depends_on: typing.Optional[typing.List[cdktf.TerraformResource]] = None,
        lifecycle: typing.Optional[cdktf.TerraformResourceLifecycle] = None,
        provider: typing.Optional[cdktf.TerraformProvider] = None,
        express_route_circuit_name: builtins.str,
        name: builtins.str,
        resource_group_name: builtins.str,
        timeouts: typing.Optional["ExpressRouteCircuitAuthorizationTimeouts"] = None,
    ) -> None:
        """
        :param count: 
        :param depends_on: 
        :param lifecycle: 
        :param provider: 
        :param express_route_circuit_name: 
        :param name: 
        :param resource_group_name: 
        :param timeouts: timeouts block.
        """
        if isinstance(lifecycle, dict):
            lifecycle = cdktf.TerraformResourceLifecycle(**lifecycle)
        if isinstance(timeouts, dict):
            timeouts = ExpressRouteCircuitAuthorizationTimeouts(**timeouts)
        self._values: typing.Dict[str, typing.Any] = {
            "express_route_circuit_name": express_route_circuit_name,
            "name": name,
            "resource_group_name": resource_group_name,
        }
        if count is not None:
            self._values["count"] = count
        if depends_on is not None:
            self._values["depends_on"] = depends_on
        if lifecycle is not None:
            self._values["lifecycle"] = lifecycle
        if provider is not None:
            self._values["provider"] = provider
        if timeouts is not None:
            self._values["timeouts"] = timeouts

    @builtins.property
    def count(self) -> typing.Optional[jsii.Number]:
        """
        :stability: experimental
        """
        result = self._values.get("count")
        return result

    @builtins.property
    def depends_on(self) -> typing.Optional[typing.List[cdktf.TerraformResource]]:
        """
        :stability: experimental
        """
        result = self._values.get("depends_on")
        return result

    @builtins.property
    def lifecycle(self) -> typing.Optional[cdktf.TerraformResourceLifecycle]:
        """
        :stability: experimental
        """
        result = self._values.get("lifecycle")
        return result

    @builtins.property
    def provider(self) -> typing.Optional[cdktf.TerraformProvider]:
        """
        :stability: experimental
        """
        result = self._values.get("provider")
        return result

    @builtins.property
    def express_route_circuit_name(self) -> builtins.str:
        result = self._values.get("express_route_circuit_name")
        assert result is not None, "Required property 'express_route_circuit_name' is missing"
        return result

    @builtins.property
    def name(self) -> builtins.str:
        result = self._values.get("name")
        assert result is not None, "Required property 'name' is missing"
        return result

    @builtins.property
    def resource_group_name(self) -> builtins.str:
        result = self._values.get("resource_group_name")
        assert result is not None, "Required property 'resource_group_name' is missing"
        return result

    @builtins.property
    def timeouts(self) -> typing.Optional["ExpressRouteCircuitAuthorizationTimeouts"]:
        """timeouts block."""
        result = self._values.get("timeouts")
        return result

    def __eq__(self, rhs: typing.Any) -> builtins.bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs: typing.Any) -> builtins.bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return "ExpressRouteCircuitAuthorizationConfig(%s)" % ", ".join(
            k + "=" + repr(v) for k, v in self._values.items()
        )


@jsii.data_type(
    jsii_type="@cdktf/provider-azurerm.ExpressRouteCircuitAuthorizationTimeouts",
    jsii_struct_bases=[],
    name_mapping={
        "create": "create",
        "delete": "delete",
        "read": "read",
        "update": "update",
    },
)
class ExpressRouteCircuitAuthorizationTimeouts:
    def __init__(
        self,
        *,
        create: typing.Optional[builtins.str] = None,
        delete: typing.Optional[builtins.str] = None,
        read: typing.Optional[builtins.str] = None,
        update: typing.Optional[builtins.str] = None,
    ) -> None:
        """
        :param create: 
        :param delete: 
        :param read: 
        :param update: 
        """
        self._values: typing.Dict[str, typing.Any] = {}
        if create is not None:
            self._values["create"] = create
        if delete is not None:
            self._values["delete"] = delete
        if read is not None:
            self._values["read"] = read
        if update is not None:
            self._values["update"] = update

    @builtins.property
    def create(self) -> typing.Optional[builtins.str]:
        result = self._values.get("create")
        return result

    @builtins.property
    def delete(self) -> typing.Optional[builtins.str]:
        result = self._values.get("delete")
        return result

    @builtins.property
    def read(self) -> typing.Optional[builtins.str]:
        result = self._values.get("read")
        return result

    @builtins.property
    def update(self) -> typing.Optional[builtins.str]:
        result = self._values.get("update")
        return result

    def __eq__(self, rhs: typing.Any) -> builtins.bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs: typing.Any) -> builtins.bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return "ExpressRouteCircuitAuthorizationTimeouts(%s)" % ", ".join(
            k + "=" + repr(v) for k, v in self._values.items()
        )


@jsii.data_type(
    jsii_type="@cdktf/provider-azurerm.ExpressRouteCircuitConfig",
    jsii_struct_bases=[cdktf.TerraformMetaArguments],
    name_mapping={
        "count": "count",
        "depends_on": "dependsOn",
        "lifecycle": "lifecycle",
        "provider": "provider",
        "bandwidth_in_mbps": "bandwidthInMbps",
        "location": "location",
        "name": "name",
        "peering_location": "peeringLocation",
        "resource_group_name": "resourceGroupName",
        "service_provider_name": "serviceProviderName",
        "sku": "sku",
        "allow_classic_operations": "allowClassicOperations",
        "tags": "tags",
        "timeouts": "timeouts",
    },
)
class ExpressRouteCircuitConfig(cdktf.TerraformMetaArguments):
    def __init__(
        self,
        *,
        count: typing.Optional[jsii.Number] = None,
        depends_on: typing.Optional[typing.List[cdktf.TerraformResource]] = None,
        lifecycle: typing.Optional[cdktf.TerraformResourceLifecycle] = None,
        provider: typing.Optional[cdktf.TerraformProvider] = None,
        bandwidth_in_mbps: jsii.Number,
        location: builtins.str,
        name: builtins.str,
        peering_location: builtins.str,
        resource_group_name: builtins.str,
        service_provider_name: builtins.str,
        sku: typing.List["ExpressRouteCircuitSku"],
        allow_classic_operations: typing.Optional[builtins.bool] = None,
        tags: typing.Optional[typing.Mapping[builtins.str, builtins.str]] = None,
        timeouts: typing.Optional["ExpressRouteCircuitTimeouts"] = None,
    ) -> None:
        """
        :param count: 
        :param depends_on: 
        :param lifecycle: 
        :param provider: 
        :param bandwidth_in_mbps: 
        :param location: 
        :param name: 
        :param peering_location: 
        :param resource_group_name: 
        :param service_provider_name: 
        :param sku: sku block.
        :param allow_classic_operations: 
        :param tags: 
        :param timeouts: timeouts block.
        """
        if isinstance(lifecycle, dict):
            lifecycle = cdktf.TerraformResourceLifecycle(**lifecycle)
        if isinstance(timeouts, dict):
            timeouts = ExpressRouteCircuitTimeouts(**timeouts)
        self._values: typing.Dict[str, typing.Any] = {
            "bandwidth_in_mbps": bandwidth_in_mbps,
            "location": location,
            "name": name,
            "peering_location": peering_location,
            "resource_group_name": resource_group_name,
            "service_provider_name": service_provider_name,
            "sku": sku,
        }
        if count is not None:
            self._values["count"] = count
        if depends_on is not None:
            self._values["depends_on"] = depends_on
        if lifecycle is not None:
            self._values["lifecycle"] = lifecycle
        if provider is not None:
            self._values["provider"] = provider
        if allow_classic_operations is not None:
            self._values["allow_classic_operations"] = allow_classic_operations
        if tags is not None:
            self._values["tags"] = tags
        if timeouts is not None:
            self._values["timeouts"] = timeouts

    @builtins.property
    def count(self) -> typing.Optional[jsii.Number]:
        """
        :stability: experimental
        """
        result = self._values.get("count")
        return result

    @builtins.property
    def depends_on(self) -> typing.Optional[typing.List[cdktf.TerraformResource]]:
        """
        :stability: experimental
        """
        result = self._values.get("depends_on")
        return result

    @builtins.property
    def lifecycle(self) -> typing.Optional[cdktf.TerraformResourceLifecycle]:
        """
        :stability: experimental
        """
        result = self._values.get("lifecycle")
        return result

    @builtins.property
    def provider(self) -> typing.Optional[cdktf.TerraformProvider]:
        """
        :stability: experimental
        """
        result = self._values.get("provider")
        return result

    @builtins.property
    def bandwidth_in_mbps(self) -> jsii.Number:
        result = self._values.get("bandwidth_in_mbps")
        assert result is not None, "Required property 'bandwidth_in_mbps' is missing"
        return result

    @builtins.property
    def location(self) -> builtins.str:
        result = self._values.get("location")
        assert result is not None, "Required property 'location' is missing"
        return result

    @builtins.property
    def name(self) -> builtins.str:
        result = self._values.get("name")
        assert result is not None, "Required property 'name' is missing"
        return result

    @builtins.property
    def peering_location(self) -> builtins.str:
        result = self._values.get("peering_location")
        assert result is not None, "Required property 'peering_location' is missing"
        return result

    @builtins.property
    def resource_group_name(self) -> builtins.str:
        result = self._values.get("resource_group_name")
        assert result is not None, "Required property 'resource_group_name' is missing"
        return result

    @builtins.property
    def service_provider_name(self) -> builtins.str:
        result = self._values.get("service_provider_name")
        assert result is not None, "Required property 'service_provider_name' is missing"
        return result

    @builtins.property
    def sku(self) -> typing.List["ExpressRouteCircuitSku"]:
        """sku block."""
        result = self._values.get("sku")
        assert result is not None, "Required property 'sku' is missing"
        return result

    @builtins.property
    def allow_classic_operations(self) -> typing.Optional[builtins.bool]:
        result = self._values.get("allow_classic_operations")
        return result

    @builtins.property
    def tags(self) -> typing.Optional[typing.Mapping[builtins.str, builtins.str]]:
        result = self._values.get("tags")
        return result

    @builtins.property
    def timeouts(self) -> typing.Optional["ExpressRouteCircuitTimeouts"]:
        """timeouts block."""
        result = self._values.get("timeouts")
        return result

    def __eq__(self, rhs: typing.Any) -> builtins.bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs: typing.Any) -> builtins.bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return "ExpressRouteCircuitConfig(%s)" % ", ".join(
            k + "=" + repr(v) for k, v in self._values.items()
        )


class ExpressRouteCircuitPeering(
    cdktf.TerraformResource,
    metaclass=jsii.JSIIMeta,
    jsii_type="@cdktf/provider-azurerm.ExpressRouteCircuitPeering",
):
    def __init__(
        self,
        scope: constructs.Construct,
        id: builtins.str,
        *,
        express_route_circuit_name: builtins.str,
        peering_type: builtins.str,
        primary_peer_address_prefix: builtins.str,
        resource_group_name: builtins.str,
        secondary_peer_address_prefix: builtins.str,
        vlan_id: jsii.Number,
        microsoft_peering_config: typing.Optional[typing.List["ExpressRouteCircuitPeeringMicrosoftPeeringConfig"]] = None,
        peer_asn: typing.Optional[jsii.Number] = None,
        shared_key: typing.Optional[builtins.str] = None,
        timeouts: typing.Optional["ExpressRouteCircuitPeeringTimeouts"] = None,
        count: typing.Optional[jsii.Number] = None,
        depends_on: typing.Optional[typing.List[cdktf.TerraformResource]] = None,
        lifecycle: typing.Optional[cdktf.TerraformResourceLifecycle] = None,
        provider: typing.Optional[cdktf.TerraformProvider] = None,
    ) -> None:
        """
        :param scope: -
        :param id: -
        :param express_route_circuit_name: 
        :param peering_type: 
        :param primary_peer_address_prefix: 
        :param resource_group_name: 
        :param secondary_peer_address_prefix: 
        :param vlan_id: 
        :param microsoft_peering_config: microsoft_peering_config block.
        :param peer_asn: 
        :param shared_key: 
        :param timeouts: timeouts block.
        :param count: 
        :param depends_on: 
        :param lifecycle: 
        :param provider: 
        """
        config = ExpressRouteCircuitPeeringConfig(
            express_route_circuit_name=express_route_circuit_name,
            peering_type=peering_type,
            primary_peer_address_prefix=primary_peer_address_prefix,
            resource_group_name=resource_group_name,
            secondary_peer_address_prefix=secondary_peer_address_prefix,
            vlan_id=vlan_id,
            microsoft_peering_config=microsoft_peering_config,
            peer_asn=peer_asn,
            shared_key=shared_key,
            timeouts=timeouts,
            count=count,
            depends_on=depends_on,
            lifecycle=lifecycle,
            provider=provider,
        )

        jsii.create(ExpressRouteCircuitPeering, self, [scope, id, config])

    @jsii.member(jsii_name="synthesizeAttributes")
    def _synthesize_attributes(self) -> typing.Mapping[builtins.str, typing.Any]:
        return jsii.invoke(self, "synthesizeAttributes", [])

    @builtins.property # type: ignore
    @jsii.member(jsii_name="azureAsn")
    def azure_asn(self) -> jsii.Number:
        return jsii.get(self, "azureAsn")

    @builtins.property # type: ignore
    @jsii.member(jsii_name="primaryAzurePort")
    def primary_azure_port(self) -> builtins.str:
        return jsii.get(self, "primaryAzurePort")

    @builtins.property # type: ignore
    @jsii.member(jsii_name="secondaryAzurePort")
    def secondary_azure_port(self) -> builtins.str:
        return jsii.get(self, "secondaryAzurePort")

    @builtins.property # type: ignore
    @jsii.member(jsii_name="expressRouteCircuitName")
    def express_route_circuit_name(self) -> builtins.str:
        return jsii.get(self, "expressRouteCircuitName")

    @express_route_circuit_name.setter # type: ignore
    def express_route_circuit_name(self, value: builtins.str) -> None:
        jsii.set(self, "expressRouteCircuitName", value)

    @builtins.property # type: ignore
    @jsii.member(jsii_name="peeringType")
    def peering_type(self) -> builtins.str:
        return jsii.get(self, "peeringType")

    @peering_type.setter # type: ignore
    def peering_type(self, value: builtins.str) -> None:
        jsii.set(self, "peeringType", value)

    @builtins.property # type: ignore
    @jsii.member(jsii_name="primaryPeerAddressPrefix")
    def primary_peer_address_prefix(self) -> builtins.str:
        return jsii.get(self, "primaryPeerAddressPrefix")

    @primary_peer_address_prefix.setter # type: ignore
    def primary_peer_address_prefix(self, value: builtins.str) -> None:
        jsii.set(self, "primaryPeerAddressPrefix", value)

    @builtins.property # type: ignore
    @jsii.member(jsii_name="resourceGroupName")
    def resource_group_name(self) -> builtins.str:
        return jsii.get(self, "resourceGroupName")

    @resource_group_name.setter # type: ignore
    def resource_group_name(self, value: builtins.str) -> None:
        jsii.set(self, "resourceGroupName", value)

    @builtins.property # type: ignore
    @jsii.member(jsii_name="secondaryPeerAddressPrefix")
    def secondary_peer_address_prefix(self) -> builtins.str:
        return jsii.get(self, "secondaryPeerAddressPrefix")

    @secondary_peer_address_prefix.setter # type: ignore
    def secondary_peer_address_prefix(self, value: builtins.str) -> None:
        jsii.set(self, "secondaryPeerAddressPrefix", value)

    @builtins.property # type: ignore
    @jsii.member(jsii_name="vlanId")
    def vlan_id(self) -> jsii.Number:
        return jsii.get(self, "vlanId")

    @vlan_id.setter # type: ignore
    def vlan_id(self, value: jsii.Number) -> None:
        jsii.set(self, "vlanId", value)

    @builtins.property # type: ignore
    @jsii.member(jsii_name="id")
    def id(self) -> typing.Optional[builtins.str]:
        return jsii.get(self, "id")

    @id.setter # type: ignore
    def id(self, value: typing.Optional[builtins.str]) -> None:
        jsii.set(self, "id", value)

    @builtins.property # type: ignore
    @jsii.member(jsii_name="microsoftPeeringConfig")
    def microsoft_peering_config(
        self,
    ) -> typing.Optional[typing.List["ExpressRouteCircuitPeeringMicrosoftPeeringConfig"]]:
        return jsii.get(self, "microsoftPeeringConfig")

    @microsoft_peering_config.setter # type: ignore
    def microsoft_peering_config(
        self,
        value: typing.Optional[typing.List["ExpressRouteCircuitPeeringMicrosoftPeeringConfig"]],
    ) -> None:
        jsii.set(self, "microsoftPeeringConfig", value)

    @builtins.property # type: ignore
    @jsii.member(jsii_name="peerAsn")
    def peer_asn(self) -> typing.Optional[jsii.Number]:
        return jsii.get(self, "peerAsn")

    @peer_asn.setter # type: ignore
    def peer_asn(self, value: typing.Optional[jsii.Number]) -> None:
        jsii.set(self, "peerAsn", value)

    @builtins.property # type: ignore
    @jsii.member(jsii_name="sharedKey")
    def shared_key(self) -> typing.Optional[builtins.str]:
        return jsii.get(self, "sharedKey")

    @shared_key.setter # type: ignore
    def shared_key(self, value: typing.Optional[builtins.str]) -> None:
        jsii.set(self, "sharedKey", value)

    @builtins.property # type: ignore
    @jsii.member(jsii_name="timeouts")
    def timeouts(self) -> typing.Optional["ExpressRouteCircuitPeeringTimeouts"]:
        return jsii.get(self, "timeouts")

    @timeouts.setter # type: ignore
    def timeouts(
        self,
        value: typing.Optional["ExpressRouteCircuitPeeringTimeouts"],
    ) -> None:
        jsii.set(self, "timeouts", value)


@jsii.data_type(
    jsii_type="@cdktf/provider-azurerm.ExpressRouteCircuitPeeringConfig",
    jsii_struct_bases=[cdktf.TerraformMetaArguments],
    name_mapping={
        "count": "count",
        "depends_on": "dependsOn",
        "lifecycle": "lifecycle",
        "provider": "provider",
        "express_route_circuit_name": "expressRouteCircuitName",
        "peering_type": "peeringType",
        "primary_peer_address_prefix": "primaryPeerAddressPrefix",
        "resource_group_name": "resourceGroupName",
        "secondary_peer_address_prefix": "secondaryPeerAddressPrefix",
        "vlan_id": "vlanId",
        "microsoft_peering_config": "microsoftPeeringConfig",
        "peer_asn": "peerAsn",
        "shared_key": "sharedKey",
        "timeouts": "timeouts",
    },
)
class ExpressRouteCircuitPeeringConfig(cdktf.TerraformMetaArguments):
    def __init__(
        self,
        *,
        count: typing.Optional[jsii.Number] = None,
        depends_on: typing.Optional[typing.List[cdktf.TerraformResource]] = None,
        lifecycle: typing.Optional[cdktf.TerraformResourceLifecycle] = None,
        provider: typing.Optional[cdktf.TerraformProvider] = None,
        express_route_circuit_name: builtins.str,
        peering_type: builtins.str,
        primary_peer_address_prefix: builtins.str,
        resource_group_name: builtins.str,
        secondary_peer_address_prefix: builtins.str,
        vlan_id: jsii.Number,
        microsoft_peering_config: typing.Optional[typing.List["ExpressRouteCircuitPeeringMicrosoftPeeringConfig"]] = None,
        peer_asn: typing.Optional[jsii.Number] = None,
        shared_key: typing.Optional[builtins.str] = None,
        timeouts: typing.Optional["ExpressRouteCircuitPeeringTimeouts"] = None,
    ) -> None:
        """
        :param count: 
        :param depends_on: 
        :param lifecycle: 
        :param provider: 
        :param express_route_circuit_name: 
        :param peering_type: 
        :param primary_peer_address_prefix: 
        :param resource_group_name: 
        :param secondary_peer_address_prefix: 
        :param vlan_id: 
        :param microsoft_peering_config: microsoft_peering_config block.
        :param peer_asn: 
        :param shared_key: 
        :param timeouts: timeouts block.
        """
        if isinstance(lifecycle, dict):
            lifecycle = cdktf.TerraformResourceLifecycle(**lifecycle)
        if isinstance(timeouts, dict):
            timeouts = ExpressRouteCircuitPeeringTimeouts(**timeouts)
        self._values: typing.Dict[str, typing.Any] = {
            "express_route_circuit_name": express_route_circuit_name,
            "peering_type": peering_type,
            "primary_peer_address_prefix": primary_peer_address_prefix,
            "resource_group_name": resource_group_name,
            "secondary_peer_address_prefix": secondary_peer_address_prefix,
            "vlan_id": vlan_id,
        }
        if count is not None:
            self._values["count"] = count
        if depends_on is not None:
            self._values["depends_on"] = depends_on
        if lifecycle is not None:
            self._values["lifecycle"] = lifecycle
        if provider is not None:
            self._values["provider"] = provider
        if microsoft_peering_config is not None:
            self._values["microsoft_peering_config"] = microsoft_peering_config
        if peer_asn is not None:
            self._values["peer_asn"] = peer_asn
        if shared_key is not None:
            self._values["shared_key"] = shared_key
        if timeouts is not None:
            self._values["timeouts"] = timeouts

    @builtins.property
    def count(self) -> typing.Optional[jsii.Number]:
        """
        :stability: experimental
        """
        result = self._values.get("count")
        return result

    @builtins.property
    def depends_on(self) -> typing.Optional[typing.List[cdktf.TerraformResource]]:
        """
        :stability: experimental
        """
        result = self._values.get("depends_on")
        return result

    @builtins.property
    def lifecycle(self) -> typing.Optional[cdktf.TerraformResourceLifecycle]:
        """
        :stability: experimental
        """
        result = self._values.get("lifecycle")
        return result

    @builtins.property
    def provider(self) -> typing.Optional[cdktf.TerraformProvider]:
        """
        :stability: experimental
        """
        result = self._values.get("provider")
        return result

    @builtins.property
    def express_route_circuit_name(self) -> builtins.str:
        result = self._values.get("express_route_circuit_name")
        assert result is not None, "Required property 'express_route_circuit_name' is missing"
        return result

    @builtins.property
    def peering_type(self) -> builtins.str:
        result = self._values.get("peering_type")
        assert result is not None, "Required property 'peering_type' is missing"
        return result

    @builtins.property
    def primary_peer_address_prefix(self) -> builtins.str:
        result = self._values.get("primary_peer_address_prefix")
        assert result is not None, "Required property 'primary_peer_address_prefix' is missing"
        return result

    @builtins.property
    def resource_group_name(self) -> builtins.str:
        result = self._values.get("resource_group_name")
        assert result is not None, "Required property 'resource_group_name' is missing"
        return result

    @builtins.property
    def secondary_peer_address_prefix(self) -> builtins.str:
        result = self._values.get("secondary_peer_address_prefix")
        assert result is not None, "Required property 'secondary_peer_address_prefix' is missing"
        return result

    @builtins.property
    def vlan_id(self) -> jsii.Number:
        result = self._values.get("vlan_id")
        assert result is not None, "Required property 'vlan_id' is missing"
        return result

    @builtins.property
    def microsoft_peering_config(
        self,
    ) -> typing.Optional[typing.List["ExpressRouteCircuitPeeringMicrosoftPeeringConfig"]]:
        """microsoft_peering_config block."""
        result = self._values.get("microsoft_peering_config")
        return result

    @builtins.property
    def peer_asn(self) -> typing.Optional[jsii.Number]:
        result = self._values.get("peer_asn")
        return result

    @builtins.property
    def shared_key(self) -> typing.Optional[builtins.str]:
        result = self._values.get("shared_key")
        return result

    @builtins.property
    def timeouts(self) -> typing.Optional["ExpressRouteCircuitPeeringTimeouts"]:
        """timeouts block."""
        result = self._values.get("timeouts")
        return result

    def __eq__(self, rhs: typing.Any) -> builtins.bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs: typing.Any) -> builtins.bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return "ExpressRouteCircuitPeeringConfig(%s)" % ", ".join(
            k + "=" + repr(v) for k, v in self._values.items()
        )


@jsii.data_type(
    jsii_type="@cdktf/provider-azurerm.ExpressRouteCircuitPeeringMicrosoftPeeringConfig",
    jsii_struct_bases=[],
    name_mapping={"advertised_public_prefixes": "advertisedPublicPrefixes"},
)
class ExpressRouteCircuitPeeringMicrosoftPeeringConfig:
    def __init__(
        self,
        *,
        advertised_public_prefixes: typing.List[builtins.str],
    ) -> None:
        """
        :param advertised_public_prefixes: 
        """
        self._values: typing.Dict[str, typing.Any] = {
            "advertised_public_prefixes": advertised_public_prefixes,
        }

    @builtins.property
    def advertised_public_prefixes(self) -> typing.List[builtins.str]:
        result = self._values.get("advertised_public_prefixes")
        assert result is not None, "Required property 'advertised_public_prefixes' is missing"
        return result

    def __eq__(self, rhs: typing.Any) -> builtins.bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs: typing.Any) -> builtins.bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return "ExpressRouteCircuitPeeringMicrosoftPeeringConfig(%s)" % ", ".join(
            k + "=" + repr(v) for k, v in self._values.items()
        )


@jsii.data_type(
    jsii_type="@cdktf/provider-azurerm.ExpressRouteCircuitPeeringTimeouts",
    jsii_struct_bases=[],
    name_mapping={
        "create": "create",
        "delete": "delete",
        "read": "read",
        "update": "update",
    },
)
class ExpressRouteCircuitPeeringTimeouts:
    def __init__(
        self,
        *,
        create: typing.Optional[builtins.str] = None,
        delete: typing.Optional[builtins.str] = None,
        read: typing.Optional[builtins.str] = None,
        update: typing.Optional[builtins.str] = None,
    ) -> None:
        """
        :param create: 
        :param delete: 
        :param read: 
        :param update: 
        """
        self._values: typing.Dict[str, typing.Any] = {}
        if create is not None:
            self._values["create"] = create
        if delete is not None:
            self._values["delete"] = delete
        if read is not None:
            self._values["read"] = read
        if update is not None:
            self._values["update"] = update

    @builtins.property
    def create(self) -> typing.Optional[builtins.str]:
        result = self._values.get("create")
        return result

    @builtins.property
    def delete(self) -> typing.Optional[builtins.str]:
        result = self._values.get("delete")
        return result

    @builtins.property
    def read(self) -> typing.Optional[builtins.str]:
        result = self._values.get("read")
        return result

    @builtins.property
    def update(self) -> typing.Optional[builtins.str]:
        result = self._values.get("update")
        return result

    def __eq__(self, rhs: typing.Any) -> builtins.bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs: typing.Any) -> builtins.bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return "ExpressRouteCircuitPeeringTimeouts(%s)" % ", ".join(
            k + "=" + repr(v) for k, v in self._values.items()
        )


@jsii.data_type(
    jsii_type="@cdktf/provider-azurerm.ExpressRouteCircuitSku",
    jsii_struct_bases=[],
    name_mapping={"family": "family", "tier": "tier"},
)
class ExpressRouteCircuitSku:
    def __init__(self, *, family: builtins.str, tier: builtins.str) -> None:
        """
        :param family: 
        :param tier: 
        """
        self._values: typing.Dict[str, typing.Any] = {
            "family": family,
            "tier": tier,
        }

    @builtins.property
    def family(self) -> builtins.str:
        result = self._values.get("family")
        assert result is not None, "Required property 'family' is missing"
        return result

    @builtins.property
    def tier(self) -> builtins.str:
        result = self._values.get("tier")
        assert result is not None, "Required property 'tier' is missing"
        return result

    def __eq__(self, rhs: typing.Any) -> builtins.bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs: typing.Any) -> builtins.bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return "ExpressRouteCircuitSku(%s)" % ", ".join(
            k + "=" + repr(v) for k, v in self._values.items()
        )


@jsii.data_type(
    jsii_type="@cdktf/provider-azurerm.ExpressRouteCircuitTimeouts",
    jsii_struct_bases=[],
    name_mapping={
        "create": "create",
        "delete": "delete",
        "read": "read",
        "update": "update",
    },
)
class ExpressRouteCircuitTimeouts:
    def __init__(
        self,
        *,
        create: typing.Optional[builtins.str] = None,
        delete: typing.Optional[builtins.str] = None,
        read: typing.Optional[builtins.str] = None,
        update: typing.Optional[builtins.str] = None,
    ) -> None:
        """
        :param create: 
        :param delete: 
        :param read: 
        :param update: 
        """
        self._values: typing.Dict[str, typing.Any] = {}
        if create is not None:
            self._values["create"] = create
        if delete is not None:
            self._values["delete"] = delete
        if read is not None:
            self._values["read"] = read
        if update is not None:
            self._values["update"] = update

    @builtins.property
    def create(self) -> typing.Optional[builtins.str]:
        result = self._values.get("create")
        return result

    @builtins.property
    def delete(self) -> typing.Optional[builtins.str]:
        result = self._values.get("delete")
        return result

    @builtins.property
    def read(self) -> typing.Optional[builtins.str]:
        result = self._values.get("read")
        return result

    @builtins.property
    def update(self) -> typing.Optional[builtins.str]:
        result = self._values.get("update")
        return result

    def __eq__(self, rhs: typing.Any) -> builtins.bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs: typing.Any) -> builtins.bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return "ExpressRouteCircuitTimeouts(%s)" % ", ".join(
            k + "=" + repr(v) for k, v in self._values.items()
        )


class ExpressRouteGateway(
    cdktf.TerraformResource,
    metaclass=jsii.JSIIMeta,
    jsii_type="@cdktf/provider-azurerm.ExpressRouteGateway",
):
    def __init__(
        self,
        scope: constructs.Construct,
        id: builtins.str,
        *,
        location: builtins.str,
        name: builtins.str,
        resource_group_name: builtins.str,
        scale_units: jsii.Number,
        virtual_hub_id: builtins.str,
        tags: typing.Optional[typing.Mapping[builtins.str, builtins.str]] = None,
        timeouts: typing.Optional["ExpressRouteGatewayTimeouts"] = None,
        count: typing.Optional[jsii.Number] = None,
        depends_on: typing.Optional[typing.List[cdktf.TerraformResource]] = None,
        lifecycle: typing.Optional[cdktf.TerraformResourceLifecycle] = None,
        provider: typing.Optional[cdktf.TerraformProvider] = None,
    ) -> None:
        """
        :param scope: -
        :param id: -
        :param location: 
        :param name: 
        :param resource_group_name: 
        :param scale_units: 
        :param virtual_hub_id: 
        :param tags: 
        :param timeouts: timeouts block.
        :param count: 
        :param depends_on: 
        :param lifecycle: 
        :param provider: 
        """
        config = ExpressRouteGatewayConfig(
            location=location,
            name=name,
            resource_group_name=resource_group_name,
            scale_units=scale_units,
            virtual_hub_id=virtual_hub_id,
            tags=tags,
            timeouts=timeouts,
            count=count,
            depends_on=depends_on,
            lifecycle=lifecycle,
            provider=provider,
        )

        jsii.create(ExpressRouteGateway, self, [scope, id, config])

    @jsii.member(jsii_name="synthesizeAttributes")
    def _synthesize_attributes(self) -> typing.Mapping[builtins.str, typing.Any]:
        return jsii.invoke(self, "synthesizeAttributes", [])

    @builtins.property # type: ignore
    @jsii.member(jsii_name="location")
    def location(self) -> builtins.str:
        return jsii.get(self, "location")

    @location.setter # type: ignore
    def location(self, value: builtins.str) -> None:
        jsii.set(self, "location", value)

    @builtins.property # type: ignore
    @jsii.member(jsii_name="name")
    def name(self) -> builtins.str:
        return jsii.get(self, "name")

    @name.setter # type: ignore
    def name(self, value: builtins.str) -> None:
        jsii.set(self, "name", value)

    @builtins.property # type: ignore
    @jsii.member(jsii_name="resourceGroupName")
    def resource_group_name(self) -> builtins.str:
        return jsii.get(self, "resourceGroupName")

    @resource_group_name.setter # type: ignore
    def resource_group_name(self, value: builtins.str) -> None:
        jsii.set(self, "resourceGroupName", value)

    @builtins.property # type: ignore
    @jsii.member(jsii_name="scaleUnits")
    def scale_units(self) -> jsii.Number:
        return jsii.get(self, "scaleUnits")

    @scale_units.setter # type: ignore
    def scale_units(self, value: jsii.Number) -> None:
        jsii.set(self, "scaleUnits", value)

    @builtins.property # type: ignore
    @jsii.member(jsii_name="virtualHubId")
    def virtual_hub_id(self) -> builtins.str:
        return jsii.get(self, "virtualHubId")

    @virtual_hub_id.setter # type: ignore
    def virtual_hub_id(self, value: builtins.str) -> None:
        jsii.set(self, "virtualHubId", value)

    @builtins.property # type: ignore
    @jsii.member(jsii_name="id")
    def id(self) -> typing.Optional[builtins.str]:
        return jsii.get(self, "id")

    @id.setter # type: ignore
    def id(self, value: typing.Optional[builtins.str]) -> None:
        jsii.set(self, "id", value)

    @builtins.property # type: ignore
    @jsii.member(jsii_name="tags")
    def tags(self) -> typing.Optional[typing.Mapping[builtins.str, builtins.str]]:
        return jsii.get(self, "tags")

    @tags.setter # type: ignore
    def tags(
        self,
        value: typing.Optional[typing.Mapping[builtins.str, builtins.str]],
    ) -> None:
        jsii.set(self, "tags", value)

    @builtins.property # type: ignore
    @jsii.member(jsii_name="timeouts")
    def timeouts(self) -> typing.Optional["ExpressRouteGatewayTimeouts"]:
        return jsii.get(self, "timeouts")

    @timeouts.setter # type: ignore
    def timeouts(self, value: typing.Optional["ExpressRouteGatewayTimeouts"]) -> None:
        jsii.set(self, "timeouts", value)


@jsii.data_type(
    jsii_type="@cdktf/provider-azurerm.ExpressRouteGatewayConfig",
    jsii_struct_bases=[cdktf.TerraformMetaArguments],
    name_mapping={
        "count": "count",
        "depends_on": "dependsOn",
        "lifecycle": "lifecycle",
        "provider": "provider",
        "location": "location",
        "name": "name",
        "resource_group_name": "resourceGroupName",
        "scale_units": "scaleUnits",
        "virtual_hub_id": "virtualHubId",
        "tags": "tags",
        "timeouts": "timeouts",
    },
)
class ExpressRouteGatewayConfig(cdktf.TerraformMetaArguments):
    def __init__(
        self,
        *,
        count: typing.Optional[jsii.Number] = None,
        depends_on: typing.Optional[typing.List[cdktf.TerraformResource]] = None,
        lifecycle: typing.Optional[cdktf.TerraformResourceLifecycle] = None,
        provider: typing.Optional[cdktf.TerraformProvider] = None,
        location: builtins.str,
        name: builtins.str,
        resource_group_name: builtins.str,
        scale_units: jsii.Number,
        virtual_hub_id: builtins.str,
        tags: typing.Optional[typing.Mapping[builtins.str, builtins.str]] = None,
        timeouts: typing.Optional["ExpressRouteGatewayTimeouts"] = None,
    ) -> None:
        """
        :param count: 
        :param depends_on: 
        :param lifecycle: 
        :param provider: 
        :param location: 
        :param name: 
        :param resource_group_name: 
        :param scale_units: 
        :param virtual_hub_id: 
        :param tags: 
        :param timeouts: timeouts block.
        """
        if isinstance(lifecycle, dict):
            lifecycle = cdktf.TerraformResourceLifecycle(**lifecycle)
        if isinstance(timeouts, dict):
            timeouts = ExpressRouteGatewayTimeouts(**timeouts)
        self._values: typing.Dict[str, typing.Any] = {
            "location": location,
            "name": name,
            "resource_group_name": resource_group_name,
            "scale_units": scale_units,
            "virtual_hub_id": virtual_hub_id,
        }
        if count is not None:
            self._values["count"] = count
        if depends_on is not None:
            self._values["depends_on"] = depends_on
        if lifecycle is not None:
            self._values["lifecycle"] = lifecycle
        if provider is not None:
            self._values["provider"] = provider
        if tags is not None:
            self._values["tags"] = tags
        if timeouts is not None:
            self._values["timeouts"] = timeouts

    @builtins.property
    def count(self) -> typing.Optional[jsii.Number]:
        """
        :stability: experimental
        """
        result = self._values.get("count")
        return result

    @builtins.property
    def depends_on(self) -> typing.Optional[typing.List[cdktf.TerraformResource]]:
        """
        :stability: experimental
        """
        result = self._values.get("depends_on")
        return result

    @builtins.property
    def lifecycle(self) -> typing.Optional[cdktf.TerraformResourceLifecycle]:
        """
        :stability: experimental
        """
        result = self._values.get("lifecycle")
        return result

    @builtins.property
    def provider(self) -> typing.Optional[cdktf.TerraformProvider]:
        """
        :stability: experimental
        """
        result = self._values.get("provider")
        return result

    @builtins.property
    def location(self) -> builtins.str:
        result = self._values.get("location")
        assert result is not None, "Required property 'location' is missing"
        return result

    @builtins.property
    def name(self) -> builtins.str:
        result = self._values.get("name")
        assert result is not None, "Required property 'name' is missing"
        return result

    @builtins.property
    def resource_group_name(self) -> builtins.str:
        result = self._values.get("resource_group_name")
        assert result is not None, "Required property 'resource_group_name' is missing"
        return result

    @builtins.property
    def scale_units(self) -> jsii.Number:
        result = self._values.get("scale_units")
        assert result is not None, "Required property 'scale_units' is missing"
        return result

    @builtins.property
    def virtual_hub_id(self) -> builtins.str:
        result = self._values.get("virtual_hub_id")
        assert result is not None, "Required property 'virtual_hub_id' is missing"
        return result

    @builtins.property
    def tags(self) -> typing.Optional[typing.Mapping[builtins.str, builtins.str]]:
        result = self._values.get("tags")
        return result

    @builtins.property
    def timeouts(self) -> typing.Optional["ExpressRouteGatewayTimeouts"]:
        """timeouts block."""
        result = self._values.get("timeouts")
        return result

    def __eq__(self, rhs: typing.Any) -> builtins.bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs: typing.Any) -> builtins.bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return "ExpressRouteGatewayConfig(%s)" % ", ".join(
            k + "=" + repr(v) for k, v in self._values.items()
        )


@jsii.data_type(
    jsii_type="@cdktf/provider-azurerm.ExpressRouteGatewayTimeouts",
    jsii_struct_bases=[],
    name_mapping={
        "create": "create",
        "delete": "delete",
        "read": "read",
        "update": "update",
    },
)
class ExpressRouteGatewayTimeouts:
    def __init__(
        self,
        *,
        create: typing.Optional[builtins.str] = None,
        delete: typing.Optional[builtins.str] = None,
        read: typing.Optional[builtins.str] = None,
        update: typing.Optional[builtins.str] = None,
    ) -> None:
        """
        :param create: 
        :param delete: 
        :param read: 
        :param update: 
        """
        self._values: typing.Dict[str, typing.Any] = {}
        if create is not None:
            self._values["create"] = create
        if delete is not None:
            self._values["delete"] = delete
        if read is not None:
            self._values["read"] = read
        if update is not None:
            self._values["update"] = update

    @builtins.property
    def create(self) -> typing.Optional[builtins.str]:
        result = self._values.get("create")
        return result

    @builtins.property
    def delete(self) -> typing.Optional[builtins.str]:
        result = self._values.get("delete")
        return result

    @builtins.property
    def read(self) -> typing.Optional[builtins.str]:
        result = self._values.get("read")
        return result

    @builtins.property
    def update(self) -> typing.Optional[builtins.str]:
        result = self._values.get("update")
        return result

    def __eq__(self, rhs: typing.Any) -> builtins.bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs: typing.Any) -> builtins.bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return "ExpressRouteGatewayTimeouts(%s)" % ", ".join(
            k + "=" + repr(v) for k, v in self._values.items()
        )


class Firewall(
    cdktf.TerraformResource,
    metaclass=jsii.JSIIMeta,
    jsii_type="@cdktf/provider-azurerm.Firewall",
):
    def __init__(
        self,
        scope: constructs.Construct,
        id: builtins.str,
        *,
        ip_configuration: typing.List["FirewallIpConfiguration"],
        location: builtins.str,
        name: builtins.str,
        resource_group_name: builtins.str,
        tags: typing.Optional[typing.Mapping[builtins.str, builtins.str]] = None,
        timeouts: typing.Optional["FirewallTimeouts"] = None,
        zones: typing.Optional[typing.List[builtins.str]] = None,
        count: typing.Optional[jsii.Number] = None,
        depends_on: typing.Optional[typing.List[cdktf.TerraformResource]] = None,
        lifecycle: typing.Optional[cdktf.TerraformResourceLifecycle] = None,
        provider: typing.Optional[cdktf.TerraformProvider] = None,
    ) -> None:
        """
        :param scope: -
        :param id: -
        :param ip_configuration: ip_configuration block.
        :param location: 
        :param name: 
        :param resource_group_name: 
        :param tags: 
        :param timeouts: timeouts block.
        :param zones: 
        :param count: 
        :param depends_on: 
        :param lifecycle: 
        :param provider: 
        """
        config = FirewallConfig(
            ip_configuration=ip_configuration,
            location=location,
            name=name,
            resource_group_name=resource_group_name,
            tags=tags,
            timeouts=timeouts,
            zones=zones,
            count=count,
            depends_on=depends_on,
            lifecycle=lifecycle,
            provider=provider,
        )

        jsii.create(Firewall, self, [scope, id, config])

    @jsii.member(jsii_name="synthesizeAttributes")
    def _synthesize_attributes(self) -> typing.Mapping[builtins.str, typing.Any]:
        return jsii.invoke(self, "synthesizeAttributes", [])

    @builtins.property # type: ignore
    @jsii.member(jsii_name="ipConfiguration")
    def ip_configuration(self) -> typing.List["FirewallIpConfiguration"]:
        return jsii.get(self, "ipConfiguration")

    @ip_configuration.setter # type: ignore
    def ip_configuration(self, value: typing.List["FirewallIpConfiguration"]) -> None:
        jsii.set(self, "ipConfiguration", value)

    @builtins.property # type: ignore
    @jsii.member(jsii_name="location")
    def location(self) -> builtins.str:
        return jsii.get(self, "location")

    @location.setter # type: ignore
    def location(self, value: builtins.str) -> None:
        jsii.set(self, "location", value)

    @builtins.property # type: ignore
    @jsii.member(jsii_name="name")
    def name(self) -> builtins.str:
        return jsii.get(self, "name")

    @name.setter # type: ignore
    def name(self, value: builtins.str) -> None:
        jsii.set(self, "name", value)

    @builtins.property # type: ignore
    @jsii.member(jsii_name="resourceGroupName")
    def resource_group_name(self) -> builtins.str:
        return jsii.get(self, "resourceGroupName")

    @resource_group_name.setter # type: ignore
    def resource_group_name(self, value: builtins.str) -> None:
        jsii.set(self, "resourceGroupName", value)

    @builtins.property # type: ignore
    @jsii.member(jsii_name="id")
    def id(self) -> typing.Optional[builtins.str]:
        return jsii.get(self, "id")

    @id.setter # type: ignore
    def id(self, value: typing.Optional[builtins.str]) -> None:
        jsii.set(self, "id", value)

    @builtins.property # type: ignore
    @jsii.member(jsii_name="tags")
    def tags(self) -> typing.Optional[typing.Mapping[builtins.str, builtins.str]]:
        return jsii.get(self, "tags")

    @tags.setter # type: ignore
    def tags(
        self,
        value: typing.Optional[typing.Mapping[builtins.str, builtins.str]],
    ) -> None:
        jsii.set(self, "tags", value)

    @builtins.property # type: ignore
    @jsii.member(jsii_name="timeouts")
    def timeouts(self) -> typing.Optional["FirewallTimeouts"]:
        return jsii.get(self, "timeouts")

    @timeouts.setter # type: ignore
    def timeouts(self, value: typing.Optional["FirewallTimeouts"]) -> None:
        jsii.set(self, "timeouts", value)

    @builtins.property # type: ignore
    @jsii.member(jsii_name="zones")
    def zones(self) -> typing.Optional[typing.List[builtins.str]]:
        return jsii.get(self, "zones")

    @zones.setter # type: ignore
    def zones(self, value: typing.Optional[typing.List[builtins.str]]) -> None:
        jsii.set(self, "zones", value)


class FirewallApplicationRuleCollection(
    cdktf.TerraformResource,
    metaclass=jsii.JSIIMeta,
    jsii_type="@cdktf/provider-azurerm.FirewallApplicationRuleCollection",
):
    def __init__(
        self,
        scope: constructs.Construct,
        id: builtins.str,
        *,
        action: builtins.str,
        azure_firewall_name: builtins.str,
        name: builtins.str,
        priority: jsii.Number,
        resource_group_name: builtins.str,
        rule: typing.List["FirewallApplicationRuleCollectionRule"],
        timeouts: typing.Optional["FirewallApplicationRuleCollectionTimeouts"] = None,
        count: typing.Optional[jsii.Number] = None,
        depends_on: typing.Optional[typing.List[cdktf.TerraformResource]] = None,
        lifecycle: typing.Optional[cdktf.TerraformResourceLifecycle] = None,
        provider: typing.Optional[cdktf.TerraformProvider] = None,
    ) -> None:
        """
        :param scope: -
        :param id: -
        :param action: 
        :param azure_firewall_name: 
        :param name: 
        :param priority: 
        :param resource_group_name: 
        :param rule: rule block.
        :param timeouts: timeouts block.
        :param count: 
        :param depends_on: 
        :param lifecycle: 
        :param provider: 
        """
        config = FirewallApplicationRuleCollectionConfig(
            action=action,
            azure_firewall_name=azure_firewall_name,
            name=name,
            priority=priority,
            resource_group_name=resource_group_name,
            rule=rule,
            timeouts=timeouts,
            count=count,
            depends_on=depends_on,
            lifecycle=lifecycle,
            provider=provider,
        )

        jsii.create(FirewallApplicationRuleCollection, self, [scope, id, config])

    @jsii.member(jsii_name="synthesizeAttributes")
    def _synthesize_attributes(self) -> typing.Mapping[builtins.str, typing.Any]:
        return jsii.invoke(self, "synthesizeAttributes", [])

    @builtins.property # type: ignore
    @jsii.member(jsii_name="action")
    def action(self) -> builtins.str:
        return jsii.get(self, "action")

    @action.setter # type: ignore
    def action(self, value: builtins.str) -> None:
        jsii.set(self, "action", value)

    @builtins.property # type: ignore
    @jsii.member(jsii_name="azureFirewallName")
    def azure_firewall_name(self) -> builtins.str:
        return jsii.get(self, "azureFirewallName")

    @azure_firewall_name.setter # type: ignore
    def azure_firewall_name(self, value: builtins.str) -> None:
        jsii.set(self, "azureFirewallName", value)

    @builtins.property # type: ignore
    @jsii.member(jsii_name="name")
    def name(self) -> builtins.str:
        return jsii.get(self, "name")

    @name.setter # type: ignore
    def name(self, value: builtins.str) -> None:
        jsii.set(self, "name", value)

    @builtins.property # type: ignore
    @jsii.member(jsii_name="priority")
    def priority(self) -> jsii.Number:
        return jsii.get(self, "priority")

    @priority.setter # type: ignore
    def priority(self, value: jsii.Number) -> None:
        jsii.set(self, "priority", value)

    @builtins.property # type: ignore
    @jsii.member(jsii_name="resourceGroupName")
    def resource_group_name(self) -> builtins.str:
        return jsii.get(self, "resourceGroupName")

    @resource_group_name.setter # type: ignore
    def resource_group_name(self, value: builtins.str) -> None:
        jsii.set(self, "resourceGroupName", value)

    @builtins.property # type: ignore
    @jsii.member(jsii_name="rule")
    def rule(self) -> typing.List["FirewallApplicationRuleCollectionRule"]:
        return jsii.get(self, "rule")

    @rule.setter # type: ignore
    def rule(self, value: typing.List["FirewallApplicationRuleCollectionRule"]) -> None:
        jsii.set(self, "rule", value)

    @builtins.property # type: ignore
    @jsii.member(jsii_name="id")
    def id(self) -> typing.Optional[builtins.str]:
        return jsii.get(self, "id")

    @id.setter # type: ignore
    def id(self, value: typing.Optional[builtins.str]) -> None:
        jsii.set(self, "id", value)

    @builtins.property # type: ignore
    @jsii.member(jsii_name="timeouts")
    def timeouts(self) -> typing.Optional["FirewallApplicationRuleCollectionTimeouts"]:
        return jsii.get(self, "timeouts")

    @timeouts.setter # type: ignore
    def timeouts(
        self,
        value: typing.Optional["FirewallApplicationRuleCollectionTimeouts"],
    ) -> None:
        jsii.set(self, "timeouts", value)


@jsii.data_type(
    jsii_type="@cdktf/provider-azurerm.FirewallApplicationRuleCollectionConfig",
    jsii_struct_bases=[cdktf.TerraformMetaArguments],
    name_mapping={
        "count": "count",
        "depends_on": "dependsOn",
        "lifecycle": "lifecycle",
        "provider": "provider",
        "action": "action",
        "azure_firewall_name": "azureFirewallName",
        "name": "name",
        "priority": "priority",
        "resource_group_name": "resourceGroupName",
        "rule": "rule",
        "timeouts": "timeouts",
    },
)
class FirewallApplicationRuleCollectionConfig(cdktf.TerraformMetaArguments):
    def __init__(
        self,
        *,
        count: typing.Optional[jsii.Number] = None,
        depends_on: typing.Optional[typing.List[cdktf.TerraformResource]] = None,
        lifecycle: typing.Optional[cdktf.TerraformResourceLifecycle] = None,
        provider: typing.Optional[cdktf.TerraformProvider] = None,
        action: builtins.str,
        azure_firewall_name: builtins.str,
        name: builtins.str,
        priority: jsii.Number,
        resource_group_name: builtins.str,
        rule: typing.List["FirewallApplicationRuleCollectionRule"],
        timeouts: typing.Optional["FirewallApplicationRuleCollectionTimeouts"] = None,
    ) -> None:
        """
        :param count: 
        :param depends_on: 
        :param lifecycle: 
        :param provider: 
        :param action: 
        :param azure_firewall_name: 
        :param name: 
        :param priority: 
        :param resource_group_name: 
        :param rule: rule block.
        :param timeouts: timeouts block.
        """
        if isinstance(lifecycle, dict):
            lifecycle = cdktf.TerraformResourceLifecycle(**lifecycle)
        if isinstance(timeouts, dict):
            timeouts = FirewallApplicationRuleCollectionTimeouts(**timeouts)
        self._values: typing.Dict[str, typing.Any] = {
            "action": action,
            "azure_firewall_name": azure_firewall_name,
            "name": name,
            "priority": priority,
            "resource_group_name": resource_group_name,
            "rule": rule,
        }
        if count is not None:
            self._values["count"] = count
        if depends_on is not None:
            self._values["depends_on"] = depends_on
        if lifecycle is not None:
            self._values["lifecycle"] = lifecycle
        if provider is not None:
            self._values["provider"] = provider
        if timeouts is not None:
            self._values["timeouts"] = timeouts

    @builtins.property
    def count(self) -> typing.Optional[jsii.Number]:
        """
        :stability: experimental
        """
        result = self._values.get("count")
        return result

    @builtins.property
    def depends_on(self) -> typing.Optional[typing.List[cdktf.TerraformResource]]:
        """
        :stability: experimental
        """
        result = self._values.get("depends_on")
        return result

    @builtins.property
    def lifecycle(self) -> typing.Optional[cdktf.TerraformResourceLifecycle]:
        """
        :stability: experimental
        """
        result = self._values.get("lifecycle")
        return result

    @builtins.property
    def provider(self) -> typing.Optional[cdktf.TerraformProvider]:
        """
        :stability: experimental
        """
        result = self._values.get("provider")
        return result

    @builtins.property
    def action(self) -> builtins.str:
        result = self._values.get("action")
        assert result is not None, "Required property 'action' is missing"
        return result

    @builtins.property
    def azure_firewall_name(self) -> builtins.str:
        result = self._values.get("azure_firewall_name")
        assert result is not None, "Required property 'azure_firewall_name' is missing"
        return result

    @builtins.property
    def name(self) -> builtins.str:
        result = self._values.get("name")
        assert result is not None, "Required property 'name' is missing"
        return result

    @builtins.property
    def priority(self) -> jsii.Number:
        result = self._values.get("priority")
        assert result is not None, "Required property 'priority' is missing"
        return result

    @builtins.property
    def resource_group_name(self) -> builtins.str:
        result = self._values.get("resource_group_name")
        assert result is not None, "Required property 'resource_group_name' is missing"
        return result

    @builtins.property
    def rule(self) -> typing.List["FirewallApplicationRuleCollectionRule"]:
        """rule block."""
        result = self._values.get("rule")
        assert result is not None, "Required property 'rule' is missing"
        return result

    @builtins.property
    def timeouts(self) -> typing.Optional["FirewallApplicationRuleCollectionTimeouts"]:
        """timeouts block."""
        result = self._values.get("timeouts")
        return result

    def __eq__(self, rhs: typing.Any) -> builtins.bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs: typing.Any) -> builtins.bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return "FirewallApplicationRuleCollectionConfig(%s)" % ", ".join(
            k + "=" + repr(v) for k, v in self._values.items()
        )


@jsii.data_type(
    jsii_type="@cdktf/provider-azurerm.FirewallApplicationRuleCollectionRule",
    jsii_struct_bases=[],
    name_mapping={
        "name": "name",
        "source_addresses": "sourceAddresses",
        "description": "description",
        "fqdn_tags": "fqdnTags",
        "protocol": "protocol",
        "target_fqdns": "targetFqdns",
    },
)
class FirewallApplicationRuleCollectionRule:
    def __init__(
        self,
        *,
        name: builtins.str,
        source_addresses: typing.List[builtins.str],
        description: typing.Optional[builtins.str] = None,
        fqdn_tags: typing.Optional[typing.List[builtins.str]] = None,
        protocol: typing.Optional[typing.List["FirewallApplicationRuleCollectionRuleProtocol"]] = None,
        target_fqdns: typing.Optional[typing.List[builtins.str]] = None,
    ) -> None:
        """
        :param name: 
        :param source_addresses: 
        :param description: 
        :param fqdn_tags: 
        :param protocol: protocol block.
        :param target_fqdns: 
        """
        self._values: typing.Dict[str, typing.Any] = {
            "name": name,
            "source_addresses": source_addresses,
        }
        if description is not None:
            self._values["description"] = description
        if fqdn_tags is not None:
            self._values["fqdn_tags"] = fqdn_tags
        if protocol is not None:
            self._values["protocol"] = protocol
        if target_fqdns is not None:
            self._values["target_fqdns"] = target_fqdns

    @builtins.property
    def name(self) -> builtins.str:
        result = self._values.get("name")
        assert result is not None, "Required property 'name' is missing"
        return result

    @builtins.property
    def source_addresses(self) -> typing.List[builtins.str]:
        result = self._values.get("source_addresses")
        assert result is not None, "Required property 'source_addresses' is missing"
        return result

    @builtins.property
    def description(self) -> typing.Optional[builtins.str]:
        result = self._values.get("description")
        return result

    @builtins.property
    def fqdn_tags(self) -> typing.Optional[typing.List[builtins.str]]:
        result = self._values.get("fqdn_tags")
        return result

    @builtins.property
    def protocol(
        self,
    ) -> typing.Optional[typing.List["FirewallApplicationRuleCollectionRuleProtocol"]]:
        """protocol block."""
        result = self._values.get("protocol")
        return result

    @builtins.property
    def target_fqdns(self) -> typing.Optional[typing.List[builtins.str]]:
        result = self._values.get("target_fqdns")
        return result

    def __eq__(self, rhs: typing.Any) -> builtins.bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs: typing.Any) -> builtins.bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return "FirewallApplicationRuleCollectionRule(%s)" % ", ".join(
            k + "=" + repr(v) for k, v in self._values.items()
        )


@jsii.data_type(
    jsii_type="@cdktf/provider-azurerm.FirewallApplicationRuleCollectionRuleProtocol",
    jsii_struct_bases=[],
    name_mapping={"type": "type", "port": "port"},
)
class FirewallApplicationRuleCollectionRuleProtocol:
    def __init__(
        self,
        *,
        type: builtins.str,
        port: typing.Optional[jsii.Number] = None,
    ) -> None:
        """
        :param type: 
        :param port: 
        """
        self._values: typing.Dict[str, typing.Any] = {
            "type": type,
        }
        if port is not None:
            self._values["port"] = port

    @builtins.property
    def type(self) -> builtins.str:
        result = self._values.get("type")
        assert result is not None, "Required property 'type' is missing"
        return result

    @builtins.property
    def port(self) -> typing.Optional[jsii.Number]:
        result = self._values.get("port")
        return result

    def __eq__(self, rhs: typing.Any) -> builtins.bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs: typing.Any) -> builtins.bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return "FirewallApplicationRuleCollectionRuleProtocol(%s)" % ", ".join(
            k + "=" + repr(v) for k, v in self._values.items()
        )


@jsii.data_type(
    jsii_type="@cdktf/provider-azurerm.FirewallApplicationRuleCollectionTimeouts",
    jsii_struct_bases=[],
    name_mapping={
        "create": "create",
        "delete": "delete",
        "read": "read",
        "update": "update",
    },
)
class FirewallApplicationRuleCollectionTimeouts:
    def __init__(
        self,
        *,
        create: typing.Optional[builtins.str] = None,
        delete: typing.Optional[builtins.str] = None,
        read: typing.Optional[builtins.str] = None,
        update: typing.Optional[builtins.str] = None,
    ) -> None:
        """
        :param create: 
        :param delete: 
        :param read: 
        :param update: 
        """
        self._values: typing.Dict[str, typing.Any] = {}
        if create is not None:
            self._values["create"] = create
        if delete is not None:
            self._values["delete"] = delete
        if read is not None:
            self._values["read"] = read
        if update is not None:
            self._values["update"] = update

    @builtins.property
    def create(self) -> typing.Optional[builtins.str]:
        result = self._values.get("create")
        return result

    @builtins.property
    def delete(self) -> typing.Optional[builtins.str]:
        result = self._values.get("delete")
        return result

    @builtins.property
    def read(self) -> typing.Optional[builtins.str]:
        result = self._values.get("read")
        return result

    @builtins.property
    def update(self) -> typing.Optional[builtins.str]:
        result = self._values.get("update")
        return result

    def __eq__(self, rhs: typing.Any) -> builtins.bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs: typing.Any) -> builtins.bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return "FirewallApplicationRuleCollectionTimeouts(%s)" % ", ".join(
            k + "=" + repr(v) for k, v in self._values.items()
        )


@jsii.data_type(
    jsii_type="@cdktf/provider-azurerm.FirewallConfig",
    jsii_struct_bases=[cdktf.TerraformMetaArguments],
    name_mapping={
        "count": "count",
        "depends_on": "dependsOn",
        "lifecycle": "lifecycle",
        "provider": "provider",
        "ip_configuration": "ipConfiguration",
        "location": "location",
        "name": "name",
        "resource_group_name": "resourceGroupName",
        "tags": "tags",
        "timeouts": "timeouts",
        "zones": "zones",
    },
)
class FirewallConfig(cdktf.TerraformMetaArguments):
    def __init__(
        self,
        *,
        count: typing.Optional[jsii.Number] = None,
        depends_on: typing.Optional[typing.List[cdktf.TerraformResource]] = None,
        lifecycle: typing.Optional[cdktf.TerraformResourceLifecycle] = None,
        provider: typing.Optional[cdktf.TerraformProvider] = None,
        ip_configuration: typing.List["FirewallIpConfiguration"],
        location: builtins.str,
        name: builtins.str,
        resource_group_name: builtins.str,
        tags: typing.Optional[typing.Mapping[builtins.str, builtins.str]] = None,
        timeouts: typing.Optional["FirewallTimeouts"] = None,
        zones: typing.Optional[typing.List[builtins.str]] = None,
    ) -> None:
        """
        :param count: 
        :param depends_on: 
        :param lifecycle: 
        :param provider: 
        :param ip_configuration: ip_configuration block.
        :param location: 
        :param name: 
        :param resource_group_name: 
        :param tags: 
        :param timeouts: timeouts block.
        :param zones: 
        """
        if isinstance(lifecycle, dict):
            lifecycle = cdktf.TerraformResourceLifecycle(**lifecycle)
        if isinstance(timeouts, dict):
            timeouts = FirewallTimeouts(**timeouts)
        self._values: typing.Dict[str, typing.Any] = {
            "ip_configuration": ip_configuration,
            "location": location,
            "name": name,
            "resource_group_name": resource_group_name,
        }
        if count is not None:
            self._values["count"] = count
        if depends_on is not None:
            self._values["depends_on"] = depends_on
        if lifecycle is not None:
            self._values["lifecycle"] = lifecycle
        if provider is not None:
            self._values["provider"] = provider
        if tags is not None:
            self._values["tags"] = tags
        if timeouts is not None:
            self._values["timeouts"] = timeouts
        if zones is not None:
            self._values["zones"] = zones

    @builtins.property
    def count(self) -> typing.Optional[jsii.Number]:
        """
        :stability: experimental
        """
        result = self._values.get("count")
        return result

    @builtins.property
    def depends_on(self) -> typing.Optional[typing.List[cdktf.TerraformResource]]:
        """
        :stability: experimental
        """
        result = self._values.get("depends_on")
        return result

    @builtins.property
    def lifecycle(self) -> typing.Optional[cdktf.TerraformResourceLifecycle]:
        """
        :stability: experimental
        """
        result = self._values.get("lifecycle")
        return result

    @builtins.property
    def provider(self) -> typing.Optional[cdktf.TerraformProvider]:
        """
        :stability: experimental
        """
        result = self._values.get("provider")
        return result

    @builtins.property
    def ip_configuration(self) -> typing.List["FirewallIpConfiguration"]:
        """ip_configuration block."""
        result = self._values.get("ip_configuration")
        assert result is not None, "Required property 'ip_configuration' is missing"
        return result

    @builtins.property
    def location(self) -> builtins.str:
        result = self._values.get("location")
        assert result is not None, "Required property 'location' is missing"
        return result

    @builtins.property
    def name(self) -> builtins.str:
        result = self._values.get("name")
        assert result is not None, "Required property 'name' is missing"
        return result

    @builtins.property
    def resource_group_name(self) -> builtins.str:
        result = self._values.get("resource_group_name")
        assert result is not None, "Required property 'resource_group_name' is missing"
        return result

    @builtins.property
    def tags(self) -> typing.Optional[typing.Mapping[builtins.str, builtins.str]]:
        result = self._values.get("tags")
        return result

    @builtins.property
    def timeouts(self) -> typing.Optional["FirewallTimeouts"]:
        """timeouts block."""
        result = self._values.get("timeouts")
        return result

    @builtins.property
    def zones(self) -> typing.Optional[typing.List[builtins.str]]:
        result = self._values.get("zones")
        return result

    def __eq__(self, rhs: typing.Any) -> builtins.bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs: typing.Any) -> builtins.bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return "FirewallConfig(%s)" % ", ".join(
            k + "=" + repr(v) for k, v in self._values.items()
        )


@jsii.data_type(
    jsii_type="@cdktf/provider-azurerm.FirewallIpConfiguration",
    jsii_struct_bases=[],
    name_mapping={
        "name": "name",
        "public_ip_address_id": "publicIpAddressId",
        "subnet_id": "subnetId",
    },
)
class FirewallIpConfiguration:
    def __init__(
        self,
        *,
        name: builtins.str,
        public_ip_address_id: builtins.str,
        subnet_id: typing.Optional[builtins.str] = None,
    ) -> None:
        """
        :param name: 
        :param public_ip_address_id: 
        :param subnet_id: 
        """
        self._values: typing.Dict[str, typing.Any] = {
            "name": name,
            "public_ip_address_id": public_ip_address_id,
        }
        if subnet_id is not None:
            self._values["subnet_id"] = subnet_id

    @builtins.property
    def name(self) -> builtins.str:
        result = self._values.get("name")
        assert result is not None, "Required property 'name' is missing"
        return result

    @builtins.property
    def public_ip_address_id(self) -> builtins.str:
        result = self._values.get("public_ip_address_id")
        assert result is not None, "Required property 'public_ip_address_id' is missing"
        return result

    @builtins.property
    def subnet_id(self) -> typing.Optional[builtins.str]:
        result = self._values.get("subnet_id")
        return result

    def __eq__(self, rhs: typing.Any) -> builtins.bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs: typing.Any) -> builtins.bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return "FirewallIpConfiguration(%s)" % ", ".join(
            k + "=" + repr(v) for k, v in self._values.items()
        )


class FirewallNatRuleCollection(
    cdktf.TerraformResource,
    metaclass=jsii.JSIIMeta,
    jsii_type="@cdktf/provider-azurerm.FirewallNatRuleCollection",
):
    def __init__(
        self,
        scope: constructs.Construct,
        id: builtins.str,
        *,
        action: builtins.str,
        azure_firewall_name: builtins.str,
        name: builtins.str,
        priority: jsii.Number,
        resource_group_name: builtins.str,
        rule: typing.List["FirewallNatRuleCollectionRule"],
        timeouts: typing.Optional["FirewallNatRuleCollectionTimeouts"] = None,
        count: typing.Optional[jsii.Number] = None,
        depends_on: typing.Optional[typing.List[cdktf.TerraformResource]] = None,
        lifecycle: typing.Optional[cdktf.TerraformResourceLifecycle] = None,
        provider: typing.Optional[cdktf.TerraformProvider] = None,
    ) -> None:
        """
        :param scope: -
        :param id: -
        :param action: 
        :param azure_firewall_name: 
        :param name: 
        :param priority: 
        :param resource_group_name: 
        :param rule: rule block.
        :param timeouts: timeouts block.
        :param count: 
        :param depends_on: 
        :param lifecycle: 
        :param provider: 
        """
        config = FirewallNatRuleCollectionConfig(
            action=action,
            azure_firewall_name=azure_firewall_name,
            name=name,
            priority=priority,
            resource_group_name=resource_group_name,
            rule=rule,
            timeouts=timeouts,
            count=count,
            depends_on=depends_on,
            lifecycle=lifecycle,
            provider=provider,
        )

        jsii.create(FirewallNatRuleCollection, self, [scope, id, config])

    @jsii.member(jsii_name="synthesizeAttributes")
    def _synthesize_attributes(self) -> typing.Mapping[builtins.str, typing.Any]:
        return jsii.invoke(self, "synthesizeAttributes", [])

    @builtins.property # type: ignore
    @jsii.member(jsii_name="action")
    def action(self) -> builtins.str:
        return jsii.get(self, "action")

    @action.setter # type: ignore
    def action(self, value: builtins.str) -> None:
        jsii.set(self, "action", value)

    @builtins.property # type: ignore
    @jsii.member(jsii_name="azureFirewallName")
    def azure_firewall_name(self) -> builtins.str:
        return jsii.get(self, "azureFirewallName")

    @azure_firewall_name.setter # type: ignore
    def azure_firewall_name(self, value: builtins.str) -> None:
        jsii.set(self, "azureFirewallName", value)

    @builtins.property # type: ignore
    @jsii.member(jsii_name="name")
    def name(self) -> builtins.str:
        return jsii.get(self, "name")

    @name.setter # type: ignore
    def name(self, value: builtins.str) -> None:
        jsii.set(self, "name", value)

    @builtins.property # type: ignore
    @jsii.member(jsii_name="priority")
    def priority(self) -> jsii.Number:
        return jsii.get(self, "priority")

    @priority.setter # type: ignore
    def priority(self, value: jsii.Number) -> None:
        jsii.set(self, "priority", value)

    @builtins.property # type: ignore
    @jsii.member(jsii_name="resourceGroupName")
    def resource_group_name(self) -> builtins.str:
        return jsii.get(self, "resourceGroupName")

    @resource_group_name.setter # type: ignore
    def resource_group_name(self, value: builtins.str) -> None:
        jsii.set(self, "resourceGroupName", value)

    @builtins.property # type: ignore
    @jsii.member(jsii_name="rule")
    def rule(self) -> typing.List["FirewallNatRuleCollectionRule"]:
        return jsii.get(self, "rule")

    @rule.setter # type: ignore
    def rule(self, value: typing.List["FirewallNatRuleCollectionRule"]) -> None:
        jsii.set(self, "rule", value)

    @builtins.property # type: ignore
    @jsii.member(jsii_name="id")
    def id(self) -> typing.Optional[builtins.str]:
        return jsii.get(self, "id")

    @id.setter # type: ignore
    def id(self, value: typing.Optional[builtins.str]) -> None:
        jsii.set(self, "id", value)

    @builtins.property # type: ignore
    @jsii.member(jsii_name="timeouts")
    def timeouts(self) -> typing.Optional["FirewallNatRuleCollectionTimeouts"]:
        return jsii.get(self, "timeouts")

    @timeouts.setter # type: ignore
    def timeouts(
        self,
        value: typing.Optional["FirewallNatRuleCollectionTimeouts"],
    ) -> None:
        jsii.set(self, "timeouts", value)


@jsii.data_type(
    jsii_type="@cdktf/provider-azurerm.FirewallNatRuleCollectionConfig",
    jsii_struct_bases=[cdktf.TerraformMetaArguments],
    name_mapping={
        "count": "count",
        "depends_on": "dependsOn",
        "lifecycle": "lifecycle",
        "provider": "provider",
        "action": "action",
        "azure_firewall_name": "azureFirewallName",
        "name": "name",
        "priority": "priority",
        "resource_group_name": "resourceGroupName",
        "rule": "rule",
        "timeouts": "timeouts",
    },
)
class FirewallNatRuleCollectionConfig(cdktf.TerraformMetaArguments):
    def __init__(
        self,
        *,
        count: typing.Optional[jsii.Number] = None,
        depends_on: typing.Optional[typing.List[cdktf.TerraformResource]] = None,
        lifecycle: typing.Optional[cdktf.TerraformResourceLifecycle] = None,
        provider: typing.Optional[cdktf.TerraformProvider] = None,
        action: builtins.str,
        azure_firewall_name: builtins.str,
        name: builtins.str,
        priority: jsii.Number,
        resource_group_name: builtins.str,
        rule: typing.List["FirewallNatRuleCollectionRule"],
        timeouts: typing.Optional["FirewallNatRuleCollectionTimeouts"] = None,
    ) -> None:
        """
        :param count: 
        :param depends_on: 
        :param lifecycle: 
        :param provider: 
        :param action: 
        :param azure_firewall_name: 
        :param name: 
        :param priority: 
        :param resource_group_name: 
        :param rule: rule block.
        :param timeouts: timeouts block.
        """
        if isinstance(lifecycle, dict):
            lifecycle = cdktf.TerraformResourceLifecycle(**lifecycle)
        if isinstance(timeouts, dict):
            timeouts = FirewallNatRuleCollectionTimeouts(**timeouts)
        self._values: typing.Dict[str, typing.Any] = {
            "action": action,
            "azure_firewall_name": azure_firewall_name,
            "name": name,
            "priority": priority,
            "resource_group_name": resource_group_name,
            "rule": rule,
        }
        if count is not None:
            self._values["count"] = count
        if depends_on is not None:
            self._values["depends_on"] = depends_on
        if lifecycle is not None:
            self._values["lifecycle"] = lifecycle
        if provider is not None:
            self._values["provider"] = provider
        if timeouts is not None:
            self._values["timeouts"] = timeouts

    @builtins.property
    def count(self) -> typing.Optional[jsii.Number]:
        """
        :stability: experimental
        """
        result = self._values.get("count")
        return result

    @builtins.property
    def depends_on(self) -> typing.Optional[typing.List[cdktf.TerraformResource]]:
        """
        :stability: experimental
        """
        result = self._values.get("depends_on")
        return result

    @builtins.property
    def lifecycle(self) -> typing.Optional[cdktf.TerraformResourceLifecycle]:
        """
        :stability: experimental
        """
        result = self._values.get("lifecycle")
        return result

    @builtins.property
    def provider(self) -> typing.Optional[cdktf.TerraformProvider]:
        """
        :stability: experimental
        """
        result = self._values.get("provider")
        return result

    @builtins.property
    def action(self) -> builtins.str:
        result = self._values.get("action")
        assert result is not None, "Required property 'action' is missing"
        return result

    @builtins.property
    def azure_firewall_name(self) -> builtins.str:
        result = self._values.get("azure_firewall_name")
        assert result is not None, "Required property 'azure_firewall_name' is missing"
        return result

    @builtins.property
    def name(self) -> builtins.str:
        result = self._values.get("name")
        assert result is not None, "Required property 'name' is missing"
        return result

    @builtins.property
    def priority(self) -> jsii.Number:
        result = self._values.get("priority")
        assert result is not None, "Required property 'priority' is missing"
        return result

    @builtins.property
    def resource_group_name(self) -> builtins.str:
        result = self._values.get("resource_group_name")
        assert result is not None, "Required property 'resource_group_name' is missing"
        return result

    @builtins.property
    def rule(self) -> typing.List["FirewallNatRuleCollectionRule"]:
        """rule block."""
        result = self._values.get("rule")
        assert result is not None, "Required property 'rule' is missing"
        return result

    @builtins.property
    def timeouts(self) -> typing.Optional["FirewallNatRuleCollectionTimeouts"]:
        """timeouts block."""
        result = self._values.get("timeouts")
        return result

    def __eq__(self, rhs: typing.Any) -> builtins.bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs: typing.Any) -> builtins.bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return "FirewallNatRuleCollectionConfig(%s)" % ", ".join(
            k + "=" + repr(v) for k, v in self._values.items()
        )


@jsii.data_type(
    jsii_type="@cdktf/provider-azurerm.FirewallNatRuleCollectionRule",
    jsii_struct_bases=[],
    name_mapping={
        "destination_addresses": "destinationAddresses",
        "destination_ports": "destinationPorts",
        "name": "name",
        "protocols": "protocols",
        "source_addresses": "sourceAddresses",
        "translated_address": "translatedAddress",
        "translated_port": "translatedPort",
        "description": "description",
    },
)
class FirewallNatRuleCollectionRule:
    def __init__(
        self,
        *,
        destination_addresses: typing.List[builtins.str],
        destination_ports: typing.List[builtins.str],
        name: builtins.str,
        protocols: typing.List[builtins.str],
        source_addresses: typing.List[builtins.str],
        translated_address: builtins.str,
        translated_port: builtins.str,
        description: typing.Optional[builtins.str] = None,
    ) -> None:
        """
        :param destination_addresses: 
        :param destination_ports: 
        :param name: 
        :param protocols: 
        :param source_addresses: 
        :param translated_address: 
        :param translated_port: 
        :param description: 
        """
        self._values: typing.Dict[str, typing.Any] = {
            "destination_addresses": destination_addresses,
            "destination_ports": destination_ports,
            "name": name,
            "protocols": protocols,
            "source_addresses": source_addresses,
            "translated_address": translated_address,
            "translated_port": translated_port,
        }
        if description is not None:
            self._values["description"] = description

    @builtins.property
    def destination_addresses(self) -> typing.List[builtins.str]:
        result = self._values.get("destination_addresses")
        assert result is not None, "Required property 'destination_addresses' is missing"
        return result

    @builtins.property
    def destination_ports(self) -> typing.List[builtins.str]:
        result = self._values.get("destination_ports")
        assert result is not None, "Required property 'destination_ports' is missing"
        return result

    @builtins.property
    def name(self) -> builtins.str:
        result = self._values.get("name")
        assert result is not None, "Required property 'name' is missing"
        return result

    @builtins.property
    def protocols(self) -> typing.List[builtins.str]:
        result = self._values.get("protocols")
        assert result is not None, "Required property 'protocols' is missing"
        return result

    @builtins.property
    def source_addresses(self) -> typing.List[builtins.str]:
        result = self._values.get("source_addresses")
        assert result is not None, "Required property 'source_addresses' is missing"
        return result

    @builtins.property
    def translated_address(self) -> builtins.str:
        result = self._values.get("translated_address")
        assert result is not None, "Required property 'translated_address' is missing"
        return result

    @builtins.property
    def translated_port(self) -> builtins.str:
        result = self._values.get("translated_port")
        assert result is not None, "Required property 'translated_port' is missing"
        return result

    @builtins.property
    def description(self) -> typing.Optional[builtins.str]:
        result = self._values.get("description")
        return result

    def __eq__(self, rhs: typing.Any) -> builtins.bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs: typing.Any) -> builtins.bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return "FirewallNatRuleCollectionRule(%s)" % ", ".join(
            k + "=" + repr(v) for k, v in self._values.items()
        )


@jsii.data_type(
    jsii_type="@cdktf/provider-azurerm.FirewallNatRuleCollectionTimeouts",
    jsii_struct_bases=[],
    name_mapping={
        "create": "create",
        "delete": "delete",
        "read": "read",
        "update": "update",
    },
)
class FirewallNatRuleCollectionTimeouts:
    def __init__(
        self,
        *,
        create: typing.Optional[builtins.str] = None,
        delete: typing.Optional[builtins.str] = None,
        read: typing.Optional[builtins.str] = None,
        update: typing.Optional[builtins.str] = None,
    ) -> None:
        """
        :param create: 
        :param delete: 
        :param read: 
        :param update: 
        """
        self._values: typing.Dict[str, typing.Any] = {}
        if create is not None:
            self._values["create"] = create
        if delete is not None:
            self._values["delete"] = delete
        if read is not None:
            self._values["read"] = read
        if update is not None:
            self._values["update"] = update

    @builtins.property
    def create(self) -> typing.Optional[builtins.str]:
        result = self._values.get("create")
        return result

    @builtins.property
    def delete(self) -> typing.Optional[builtins.str]:
        result = self._values.get("delete")
        return result

    @builtins.property
    def read(self) -> typing.Optional[builtins.str]:
        result = self._values.get("read")
        return result

    @builtins.property
    def update(self) -> typing.Optional[builtins.str]:
        result = self._values.get("update")
        return result

    def __eq__(self, rhs: typing.Any) -> builtins.bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs: typing.Any) -> builtins.bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return "FirewallNatRuleCollectionTimeouts(%s)" % ", ".join(
            k + "=" + repr(v) for k, v in self._values.items()
        )


class FirewallNetworkRuleCollection(
    cdktf.TerraformResource,
    metaclass=jsii.JSIIMeta,
    jsii_type="@cdktf/provider-azurerm.FirewallNetworkRuleCollection",
):
    def __init__(
        self,
        scope: constructs.Construct,
        id: builtins.str,
        *,
        action: builtins.str,
        azure_firewall_name: builtins.str,
        name: builtins.str,
        priority: jsii.Number,
        resource_group_name: builtins.str,
        rule: typing.List["FirewallNetworkRuleCollectionRule"],
        timeouts: typing.Optional["FirewallNetworkRuleCollectionTimeouts"] = None,
        count: typing.Optional[jsii.Number] = None,
        depends_on: typing.Optional[typing.List[cdktf.TerraformResource]] = None,
        lifecycle: typing.Optional[cdktf.TerraformResourceLifecycle] = None,
        provider: typing.Optional[cdktf.TerraformProvider] = None,
    ) -> None:
        """
        :param scope: -
        :param id: -
        :param action: 
        :param azure_firewall_name: 
        :param name: 
        :param priority: 
        :param resource_group_name: 
        :param rule: rule block.
        :param timeouts: timeouts block.
        :param count: 
        :param depends_on: 
        :param lifecycle: 
        :param provider: 
        """
        config = FirewallNetworkRuleCollectionConfig(
            action=action,
            azure_firewall_name=azure_firewall_name,
            name=name,
            priority=priority,
            resource_group_name=resource_group_name,
            rule=rule,
            timeouts=timeouts,
            count=count,
            depends_on=depends_on,
            lifecycle=lifecycle,
            provider=provider,
        )

        jsii.create(FirewallNetworkRuleCollection, self, [scope, id, config])

    @jsii.member(jsii_name="synthesizeAttributes")
    def _synthesize_attributes(self) -> typing.Mapping[builtins.str, typing.Any]:
        return jsii.invoke(self, "synthesizeAttributes", [])

    @builtins.property # type: ignore
    @jsii.member(jsii_name="action")
    def action(self) -> builtins.str:
        return jsii.get(self, "action")

    @action.setter # type: ignore
    def action(self, value: builtins.str) -> None:
        jsii.set(self, "action", value)

    @builtins.property # type: ignore
    @jsii.member(jsii_name="azureFirewallName")
    def azure_firewall_name(self) -> builtins.str:
        return jsii.get(self, "azureFirewallName")

    @azure_firewall_name.setter # type: ignore
    def azure_firewall_name(self, value: builtins.str) -> None:
        jsii.set(self, "azureFirewallName", value)

    @builtins.property # type: ignore
    @jsii.member(jsii_name="name")
    def name(self) -> builtins.str:
        return jsii.get(self, "name")

    @name.setter # type: ignore
    def name(self, value: builtins.str) -> None:
        jsii.set(self, "name", value)

    @builtins.property # type: ignore
    @jsii.member(jsii_name="priority")
    def priority(self) -> jsii.Number:
        return jsii.get(self, "priority")

    @priority.setter # type: ignore
    def priority(self, value: jsii.Number) -> None:
        jsii.set(self, "priority", value)

    @builtins.property # type: ignore
    @jsii.member(jsii_name="resourceGroupName")
    def resource_group_name(self) -> builtins.str:
        return jsii.get(self, "resourceGroupName")

    @resource_group_name.setter # type: ignore
    def resource_group_name(self, value: builtins.str) -> None:
        jsii.set(self, "resourceGroupName", value)

    @builtins.property # type: ignore
    @jsii.member(jsii_name="rule")
    def rule(self) -> typing.List["FirewallNetworkRuleCollectionRule"]:
        return jsii.get(self, "rule")

    @rule.setter # type: ignore
    def rule(self, value: typing.List["FirewallNetworkRuleCollectionRule"]) -> None:
        jsii.set(self, "rule", value)

    @builtins.property # type: ignore
    @jsii.member(jsii_name="id")
    def id(self) -> typing.Optional[builtins.str]:
        return jsii.get(self, "id")

    @id.setter # type: ignore
    def id(self, value: typing.Optional[builtins.str]) -> None:
        jsii.set(self, "id", value)

    @builtins.property # type: ignore
    @jsii.member(jsii_name="timeouts")
    def timeouts(self) -> typing.Optional["FirewallNetworkRuleCollectionTimeouts"]:
        return jsii.get(self, "timeouts")

    @timeouts.setter # type: ignore
    def timeouts(
        self,
        value: typing.Optional["FirewallNetworkRuleCollectionTimeouts"],
    ) -> None:
        jsii.set(self, "timeouts", value)


@jsii.data_type(
    jsii_type="@cdktf/provider-azurerm.FirewallNetworkRuleCollectionConfig",
    jsii_struct_bases=[cdktf.TerraformMetaArguments],
    name_mapping={
        "count": "count",
        "depends_on": "dependsOn",
        "lifecycle": "lifecycle",
        "provider": "provider",
        "action": "action",
        "azure_firewall_name": "azureFirewallName",
        "name": "name",
        "priority": "priority",
        "resource_group_name": "resourceGroupName",
        "rule": "rule",
        "timeouts": "timeouts",
    },
)
class FirewallNetworkRuleCollectionConfig(cdktf.TerraformMetaArguments):
    def __init__(
        self,
        *,
        count: typing.Optional[jsii.Number] = None,
        depends_on: typing.Optional[typing.List[cdktf.TerraformResource]] = None,
        lifecycle: typing.Optional[cdktf.TerraformResourceLifecycle] = None,
        provider: typing.Optional[cdktf.TerraformProvider] = None,
        action: builtins.str,
        azure_firewall_name: builtins.str,
        name: builtins.str,
        priority: jsii.Number,
        resource_group_name: builtins.str,
        rule: typing.List["FirewallNetworkRuleCollectionRule"],
        timeouts: typing.Optional["FirewallNetworkRuleCollectionTimeouts"] = None,
    ) -> None:
        """
        :param count: 
        :param depends_on: 
        :param lifecycle: 
        :param provider: 
        :param action: 
        :param azure_firewall_name: 
        :param name: 
        :param priority: 
        :param resource_group_name: 
        :param rule: rule block.
        :param timeouts: timeouts block.
        """
        if isinstance(lifecycle, dict):
            lifecycle = cdktf.TerraformResourceLifecycle(**lifecycle)
        if isinstance(timeouts, dict):
            timeouts = FirewallNetworkRuleCollectionTimeouts(**timeouts)
        self._values: typing.Dict[str, typing.Any] = {
            "action": action,
            "azure_firewall_name": azure_firewall_name,
            "name": name,
            "priority": priority,
            "resource_group_name": resource_group_name,
            "rule": rule,
        }
        if count is not None:
            self._values["count"] = count
        if depends_on is not None:
            self._values["depends_on"] = depends_on
        if lifecycle is not None:
            self._values["lifecycle"] = lifecycle
        if provider is not None:
            self._values["provider"] = provider
        if timeouts is not None:
            self._values["timeouts"] = timeouts

    @builtins.property
    def count(self) -> typing.Optional[jsii.Number]:
        """
        :stability: experimental
        """
        result = self._values.get("count")
        return result

    @builtins.property
    def depends_on(self) -> typing.Optional[typing.List[cdktf.TerraformResource]]:
        """
        :stability: experimental
        """
        result = self._values.get("depends_on")
        return result

    @builtins.property
    def lifecycle(self) -> typing.Optional[cdktf.TerraformResourceLifecycle]:
        """
        :stability: experimental
        """
        result = self._values.get("lifecycle")
        return result

    @builtins.property
    def provider(self) -> typing.Optional[cdktf.TerraformProvider]:
        """
        :stability: experimental
        """
        result = self._values.get("provider")
        return result

    @builtins.property
    def action(self) -> builtins.str:
        result = self._values.get("action")
        assert result is not None, "Required property 'action' is missing"
        return result

    @builtins.property
    def azure_firewall_name(self) -> builtins.str:
        result = self._values.get("azure_firewall_name")
        assert result is not None, "Required property 'azure_firewall_name' is missing"
        return result

    @builtins.property
    def name(self) -> builtins.str:
        result = self._values.get("name")
        assert result is not None, "Required property 'name' is missing"
        return result

    @builtins.property
    def priority(self) -> jsii.Number:
        result = self._values.get("priority")
        assert result is not None, "Required property 'priority' is missing"
        return result

    @builtins.property
    def resource_group_name(self) -> builtins.str:
        result = self._values.get("resource_group_name")
        assert result is not None, "Required property 'resource_group_name' is missing"
        return result

    @builtins.property
    def rule(self) -> typing.List["FirewallNetworkRuleCollectionRule"]:
        """rule block."""
        result = self._values.get("rule")
        assert result is not None, "Required property 'rule' is missing"
        return result

    @builtins.property
    def timeouts(self) -> typing.Optional["FirewallNetworkRuleCollectionTimeouts"]:
        """timeouts block."""
        result = self._values.get("timeouts")
        return result

    def __eq__(self, rhs: typing.Any) -> builtins.bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs: typing.Any) -> builtins.bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return "FirewallNetworkRuleCollectionConfig(%s)" % ", ".join(
            k + "=" + repr(v) for k, v in self._values.items()
        )


@jsii.data_type(
    jsii_type="@cdktf/provider-azurerm.FirewallNetworkRuleCollectionRule",
    jsii_struct_bases=[],
    name_mapping={
        "destination_addresses": "destinationAddresses",
        "destination_ports": "destinationPorts",
        "name": "name",
        "protocols": "protocols",
        "source_addresses": "sourceAddresses",
        "description": "description",
    },
)
class FirewallNetworkRuleCollectionRule:
    def __init__(
        self,
        *,
        destination_addresses: typing.List[builtins.str],
        destination_ports: typing.List[builtins.str],
        name: builtins.str,
        protocols: typing.List[builtins.str],
        source_addresses: typing.List[builtins.str],
        description: typing.Optional[builtins.str] = None,
    ) -> None:
        """
        :param destination_addresses: 
        :param destination_ports: 
        :param name: 
        :param protocols: 
        :param source_addresses: 
        :param description: 
        """
        self._values: typing.Dict[str, typing.Any] = {
            "destination_addresses": destination_addresses,
            "destination_ports": destination_ports,
            "name": name,
            "protocols": protocols,
            "source_addresses": source_addresses,
        }
        if description is not None:
            self._values["description"] = description

    @builtins.property
    def destination_addresses(self) -> typing.List[builtins.str]:
        result = self._values.get("destination_addresses")
        assert result is not None, "Required property 'destination_addresses' is missing"
        return result

    @builtins.property
    def destination_ports(self) -> typing.List[builtins.str]:
        result = self._values.get("destination_ports")
        assert result is not None, "Required property 'destination_ports' is missing"
        return result

    @builtins.property
    def name(self) -> builtins.str:
        result = self._values.get("name")
        assert result is not None, "Required property 'name' is missing"
        return result

    @builtins.property
    def protocols(self) -> typing.List[builtins.str]:
        result = self._values.get("protocols")
        assert result is not None, "Required property 'protocols' is missing"
        return result

    @builtins.property
    def source_addresses(self) -> typing.List[builtins.str]:
        result = self._values.get("source_addresses")
        assert result is not None, "Required property 'source_addresses' is missing"
        return result

    @builtins.property
    def description(self) -> typing.Optional[builtins.str]:
        result = self._values.get("description")
        return result

    def __eq__(self, rhs: typing.Any) -> builtins.bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs: typing.Any) -> builtins.bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return "FirewallNetworkRuleCollectionRule(%s)" % ", ".join(
            k + "=" + repr(v) for k, v in self._values.items()
        )


@jsii.data_type(
    jsii_type="@cdktf/provider-azurerm.FirewallNetworkRuleCollectionTimeouts",
    jsii_struct_bases=[],
    name_mapping={
        "create": "create",
        "delete": "delete",
        "read": "read",
        "update": "update",
    },
)
class FirewallNetworkRuleCollectionTimeouts:
    def __init__(
        self,
        *,
        create: typing.Optional[builtins.str] = None,
        delete: typing.Optional[builtins.str] = None,
        read: typing.Optional[builtins.str] = None,
        update: typing.Optional[builtins.str] = None,
    ) -> None:
        """
        :param create: 
        :param delete: 
        :param read: 
        :param update: 
        """
        self._values: typing.Dict[str, typing.Any] = {}
        if create is not None:
            self._values["create"] = create
        if delete is not None:
            self._values["delete"] = delete
        if read is not None:
            self._values["read"] = read
        if update is not None:
            self._values["update"] = update

    @builtins.property
    def create(self) -> typing.Optional[builtins.str]:
        result = self._values.get("create")
        return result

    @builtins.property
    def delete(self) -> typing.Optional[builtins.str]:
        result = self._values.get("delete")
        return result

    @builtins.property
    def read(self) -> typing.Optional[builtins.str]:
        result = self._values.get("read")
        return result

    @builtins.property
    def update(self) -> typing.Optional[builtins.str]:
        result = self._values.get("update")
        return result

    def __eq__(self, rhs: typing.Any) -> builtins.bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs: typing.Any) -> builtins.bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return "FirewallNetworkRuleCollectionTimeouts(%s)" % ", ".join(
            k + "=" + repr(v) for k, v in self._values.items()
        )


@jsii.data_type(
    jsii_type="@cdktf/provider-azurerm.FirewallTimeouts",
    jsii_struct_bases=[],
    name_mapping={
        "create": "create",
        "delete": "delete",
        "read": "read",
        "update": "update",
    },
)
class FirewallTimeouts:
    def __init__(
        self,
        *,
        create: typing.Optional[builtins.str] = None,
        delete: typing.Optional[builtins.str] = None,
        read: typing.Optional[builtins.str] = None,
        update: typing.Optional[builtins.str] = None,
    ) -> None:
        """
        :param create: 
        :param delete: 
        :param read: 
        :param update: 
        """
        self._values: typing.Dict[str, typing.Any] = {}
        if create is not None:
            self._values["create"] = create
        if delete is not None:
            self._values["delete"] = delete
        if read is not None:
            self._values["read"] = read
        if update is not None:
            self._values["update"] = update

    @builtins.property
    def create(self) -> typing.Optional[builtins.str]:
        result = self._values.get("create")
        return result

    @builtins.property
    def delete(self) -> typing.Optional[builtins.str]:
        result = self._values.get("delete")
        return result

    @builtins.property
    def read(self) -> typing.Optional[builtins.str]:
        result = self._values.get("read")
        return result

    @builtins.property
    def update(self) -> typing.Optional[builtins.str]:
        result = self._values.get("update")
        return result

    def __eq__(self, rhs: typing.Any) -> builtins.bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs: typing.Any) -> builtins.bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return "FirewallTimeouts(%s)" % ", ".join(
            k + "=" + repr(v) for k, v in self._values.items()
        )


class Frontdoor(
    cdktf.TerraformResource,
    metaclass=jsii.JSIIMeta,
    jsii_type="@cdktf/provider-azurerm.Frontdoor",
):
    def __init__(
        self,
        scope: constructs.Construct,
        id: builtins.str,
        *,
        backend_pool: typing.List["FrontdoorBackendPool"],
        backend_pool_health_probe: typing.List["FrontdoorBackendPoolHealthProbe"],
        backend_pool_load_balancing: typing.List["FrontdoorBackendPoolLoadBalancing"],
        enforce_backend_pools_certificate_name_check: builtins.bool,
        frontend_endpoint: typing.List["FrontdoorFrontendEndpoint"],
        location: builtins.str,
        name: builtins.str,
        resource_group_name: builtins.str,
        routing_rule: typing.List["FrontdoorRoutingRule"],
        friendly_name: typing.Optional[builtins.str] = None,
        load_balancer_enabled: typing.Optional[builtins.bool] = None,
        tags: typing.Optional[typing.Mapping[builtins.str, builtins.str]] = None,
        timeouts: typing.Optional["FrontdoorTimeouts"] = None,
        count: typing.Optional[jsii.Number] = None,
        depends_on: typing.Optional[typing.List[cdktf.TerraformResource]] = None,
        lifecycle: typing.Optional[cdktf.TerraformResourceLifecycle] = None,
        provider: typing.Optional[cdktf.TerraformProvider] = None,
    ) -> None:
        """
        :param scope: -
        :param id: -
        :param backend_pool: backend_pool block.
        :param backend_pool_health_probe: backend_pool_health_probe block.
        :param backend_pool_load_balancing: backend_pool_load_balancing block.
        :param enforce_backend_pools_certificate_name_check: 
        :param frontend_endpoint: frontend_endpoint block.
        :param location: 
        :param name: 
        :param resource_group_name: 
        :param routing_rule: routing_rule block.
        :param friendly_name: 
        :param load_balancer_enabled: 
        :param tags: 
        :param timeouts: timeouts block.
        :param count: 
        :param depends_on: 
        :param lifecycle: 
        :param provider: 
        """
        config = FrontdoorConfig(
            backend_pool=backend_pool,
            backend_pool_health_probe=backend_pool_health_probe,
            backend_pool_load_balancing=backend_pool_load_balancing,
            enforce_backend_pools_certificate_name_check=enforce_backend_pools_certificate_name_check,
            frontend_endpoint=frontend_endpoint,
            location=location,
            name=name,
            resource_group_name=resource_group_name,
            routing_rule=routing_rule,
            friendly_name=friendly_name,
            load_balancer_enabled=load_balancer_enabled,
            tags=tags,
            timeouts=timeouts,
            count=count,
            depends_on=depends_on,
            lifecycle=lifecycle,
            provider=provider,
        )

        jsii.create(Frontdoor, self, [scope, id, config])

    @jsii.member(jsii_name="synthesizeAttributes")
    def _synthesize_attributes(self) -> typing.Mapping[builtins.str, typing.Any]:
        return jsii.invoke(self, "synthesizeAttributes", [])

    @builtins.property # type: ignore
    @jsii.member(jsii_name="cname")
    def cname(self) -> builtins.str:
        return jsii.get(self, "cname")

    @builtins.property # type: ignore
    @jsii.member(jsii_name="backendPool")
    def backend_pool(self) -> typing.List["FrontdoorBackendPool"]:
        return jsii.get(self, "backendPool")

    @backend_pool.setter # type: ignore
    def backend_pool(self, value: typing.List["FrontdoorBackendPool"]) -> None:
        jsii.set(self, "backendPool", value)

    @builtins.property # type: ignore
    @jsii.member(jsii_name="backendPoolHealthProbe")
    def backend_pool_health_probe(
        self,
    ) -> typing.List["FrontdoorBackendPoolHealthProbe"]:
        return jsii.get(self, "backendPoolHealthProbe")

    @backend_pool_health_probe.setter # type: ignore
    def backend_pool_health_probe(
        self,
        value: typing.List["FrontdoorBackendPoolHealthProbe"],
    ) -> None:
        jsii.set(self, "backendPoolHealthProbe", value)

    @builtins.property # type: ignore
    @jsii.member(jsii_name="backendPoolLoadBalancing")
    def backend_pool_load_balancing(
        self,
    ) -> typing.List["FrontdoorBackendPoolLoadBalancing"]:
        return jsii.get(self, "backendPoolLoadBalancing")

    @backend_pool_load_balancing.setter # type: ignore
    def backend_pool_load_balancing(
        self,
        value: typing.List["FrontdoorBackendPoolLoadBalancing"],
    ) -> None:
        jsii.set(self, "backendPoolLoadBalancing", value)

    @builtins.property # type: ignore
    @jsii.member(jsii_name="enforceBackendPoolsCertificateNameCheck")
    def enforce_backend_pools_certificate_name_check(self) -> builtins.bool:
        return jsii.get(self, "enforceBackendPoolsCertificateNameCheck")

    @enforce_backend_pools_certificate_name_check.setter # type: ignore
    def enforce_backend_pools_certificate_name_check(
        self,
        value: builtins.bool,
    ) -> None:
        jsii.set(self, "enforceBackendPoolsCertificateNameCheck", value)

    @builtins.property # type: ignore
    @jsii.member(jsii_name="frontendEndpoint")
    def frontend_endpoint(self) -> typing.List["FrontdoorFrontendEndpoint"]:
        return jsii.get(self, "frontendEndpoint")

    @frontend_endpoint.setter # type: ignore
    def frontend_endpoint(
        self,
        value: typing.List["FrontdoorFrontendEndpoint"],
    ) -> None:
        jsii.set(self, "frontendEndpoint", value)

    @builtins.property # type: ignore
    @jsii.member(jsii_name="location")
    def location(self) -> builtins.str:
        return jsii.get(self, "location")

    @location.setter # type: ignore
    def location(self, value: builtins.str) -> None:
        jsii.set(self, "location", value)

    @builtins.property # type: ignore
    @jsii.member(jsii_name="name")
    def name(self) -> builtins.str:
        return jsii.get(self, "name")

    @name.setter # type: ignore
    def name(self, value: builtins.str) -> None:
        jsii.set(self, "name", value)

    @builtins.property # type: ignore
    @jsii.member(jsii_name="resourceGroupName")
    def resource_group_name(self) -> builtins.str:
        return jsii.get(self, "resourceGroupName")

    @resource_group_name.setter # type: ignore
    def resource_group_name(self, value: builtins.str) -> None:
        jsii.set(self, "resourceGroupName", value)

    @builtins.property # type: ignore
    @jsii.member(jsii_name="routingRule")
    def routing_rule(self) -> typing.List["FrontdoorRoutingRule"]:
        return jsii.get(self, "routingRule")

    @routing_rule.setter # type: ignore
    def routing_rule(self, value: typing.List["FrontdoorRoutingRule"]) -> None:
        jsii.set(self, "routingRule", value)

    @builtins.property # type: ignore
    @jsii.member(jsii_name="friendlyName")
    def friendly_name(self) -> typing.Optional[builtins.str]:
        return jsii.get(self, "friendlyName")

    @friendly_name.setter # type: ignore
    def friendly_name(self, value: typing.Optional[builtins.str]) -> None:
        jsii.set(self, "friendlyName", value)

    @builtins.property # type: ignore
    @jsii.member(jsii_name="id")
    def id(self) -> typing.Optional[builtins.str]:
        return jsii.get(self, "id")

    @id.setter # type: ignore
    def id(self, value: typing.Optional[builtins.str]) -> None:
        jsii.set(self, "id", value)

    @builtins.property # type: ignore
    @jsii.member(jsii_name="loadBalancerEnabled")
    def load_balancer_enabled(self) -> typing.Optional[builtins.bool]:
        return jsii.get(self, "loadBalancerEnabled")

    @load_balancer_enabled.setter # type: ignore
    def load_balancer_enabled(self, value: typing.Optional[builtins.bool]) -> None:
        jsii.set(self, "loadBalancerEnabled", value)

    @builtins.property # type: ignore
    @jsii.member(jsii_name="tags")
    def tags(self) -> typing.Optional[typing.Mapping[builtins.str, builtins.str]]:
        return jsii.get(self, "tags")

    @tags.setter # type: ignore
    def tags(
        self,
        value: typing.Optional[typing.Mapping[builtins.str, builtins.str]],
    ) -> None:
        jsii.set(self, "tags", value)

    @builtins.property # type: ignore
    @jsii.member(jsii_name="timeouts")
    def timeouts(self) -> typing.Optional["FrontdoorTimeouts"]:
        return jsii.get(self, "timeouts")

    @timeouts.setter # type: ignore
    def timeouts(self, value: typing.Optional["FrontdoorTimeouts"]) -> None:
        jsii.set(self, "timeouts", value)


@jsii.data_type(
    jsii_type="@cdktf/provider-azurerm.FrontdoorBackendPool",
    jsii_struct_bases=[],
    name_mapping={
        "backend": "backend",
        "health_probe_name": "healthProbeName",
        "load_balancing_name": "loadBalancingName",
        "name": "name",
    },
)
class FrontdoorBackendPool:
    def __init__(
        self,
        *,
        backend: typing.List["FrontdoorBackendPoolBackend"],
        health_probe_name: builtins.str,
        load_balancing_name: builtins.str,
        name: builtins.str,
    ) -> None:
        """
        :param backend: backend block.
        :param health_probe_name: 
        :param load_balancing_name: 
        :param name: 
        """
        self._values: typing.Dict[str, typing.Any] = {
            "backend": backend,
            "health_probe_name": health_probe_name,
            "load_balancing_name": load_balancing_name,
            "name": name,
        }

    @builtins.property
    def backend(self) -> typing.List["FrontdoorBackendPoolBackend"]:
        """backend block."""
        result = self._values.get("backend")
        assert result is not None, "Required property 'backend' is missing"
        return result

    @builtins.property
    def health_probe_name(self) -> builtins.str:
        result = self._values.get("health_probe_name")
        assert result is not None, "Required property 'health_probe_name' is missing"
        return result

    @builtins.property
    def load_balancing_name(self) -> builtins.str:
        result = self._values.get("load_balancing_name")
        assert result is not None, "Required property 'load_balancing_name' is missing"
        return result

    @builtins.property
    def name(self) -> builtins.str:
        result = self._values.get("name")
        assert result is not None, "Required property 'name' is missing"
        return result

    def __eq__(self, rhs: typing.Any) -> builtins.bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs: typing.Any) -> builtins.bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return "FrontdoorBackendPool(%s)" % ", ".join(
            k + "=" + repr(v) for k, v in self._values.items()
        )


@jsii.data_type(
    jsii_type="@cdktf/provider-azurerm.FrontdoorBackendPoolBackend",
    jsii_struct_bases=[],
    name_mapping={
        "address": "address",
        "host_header": "hostHeader",
        "http_port": "httpPort",
        "https_port": "httpsPort",
        "enabled": "enabled",
        "priority": "priority",
        "weight": "weight",
    },
)
class FrontdoorBackendPoolBackend:
    def __init__(
        self,
        *,
        address: builtins.str,
        host_header: builtins.str,
        http_port: jsii.Number,
        https_port: jsii.Number,
        enabled: typing.Optional[builtins.bool] = None,
        priority: typing.Optional[jsii.Number] = None,
        weight: typing.Optional[jsii.Number] = None,
    ) -> None:
        """
        :param address: 
        :param host_header: 
        :param http_port: 
        :param https_port: 
        :param enabled: 
        :param priority: 
        :param weight: 
        """
        self._values: typing.Dict[str, typing.Any] = {
            "address": address,
            "host_header": host_header,
            "http_port": http_port,
            "https_port": https_port,
        }
        if enabled is not None:
            self._values["enabled"] = enabled
        if priority is not None:
            self._values["priority"] = priority
        if weight is not None:
            self._values["weight"] = weight

    @builtins.property
    def address(self) -> builtins.str:
        result = self._values.get("address")
        assert result is not None, "Required property 'address' is missing"
        return result

    @builtins.property
    def host_header(self) -> builtins.str:
        result = self._values.get("host_header")
        assert result is not None, "Required property 'host_header' is missing"
        return result

    @builtins.property
    def http_port(self) -> jsii.Number:
        result = self._values.get("http_port")
        assert result is not None, "Required property 'http_port' is missing"
        return result

    @builtins.property
    def https_port(self) -> jsii.Number:
        result = self._values.get("https_port")
        assert result is not None, "Required property 'https_port' is missing"
        return result

    @builtins.property
    def enabled(self) -> typing.Optional[builtins.bool]:
        result = self._values.get("enabled")
        return result

    @builtins.property
    def priority(self) -> typing.Optional[jsii.Number]:
        result = self._values.get("priority")
        return result

    @builtins.property
    def weight(self) -> typing.Optional[jsii.Number]:
        result = self._values.get("weight")
        return result

    def __eq__(self, rhs: typing.Any) -> builtins.bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs: typing.Any) -> builtins.bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return "FrontdoorBackendPoolBackend(%s)" % ", ".join(
            k + "=" + repr(v) for k, v in self._values.items()
        )


@jsii.data_type(
    jsii_type="@cdktf/provider-azurerm.FrontdoorBackendPoolHealthProbe",
    jsii_struct_bases=[],
    name_mapping={
        "name": "name",
        "interval_in_seconds": "intervalInSeconds",
        "path": "path",
        "protocol": "protocol",
    },
)
class FrontdoorBackendPoolHealthProbe:
    def __init__(
        self,
        *,
        name: builtins.str,
        interval_in_seconds: typing.Optional[jsii.Number] = None,
        path: typing.Optional[builtins.str] = None,
        protocol: typing.Optional[builtins.str] = None,
    ) -> None:
        """
        :param name: 
        :param interval_in_seconds: 
        :param path: 
        :param protocol: 
        """
        self._values: typing.Dict[str, typing.Any] = {
            "name": name,
        }
        if interval_in_seconds is not None:
            self._values["interval_in_seconds"] = interval_in_seconds
        if path is not None:
            self._values["path"] = path
        if protocol is not None:
            self._values["protocol"] = protocol

    @builtins.property
    def name(self) -> builtins.str:
        result = self._values.get("name")
        assert result is not None, "Required property 'name' is missing"
        return result

    @builtins.property
    def interval_in_seconds(self) -> typing.Optional[jsii.Number]:
        result = self._values.get("interval_in_seconds")
        return result

    @builtins.property
    def path(self) -> typing.Optional[builtins.str]:
        result = self._values.get("path")
        return result

    @builtins.property
    def protocol(self) -> typing.Optional[builtins.str]:
        result = self._values.get("protocol")
        return result

    def __eq__(self, rhs: typing.Any) -> builtins.bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs: typing.Any) -> builtins.bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return "FrontdoorBackendPoolHealthProbe(%s)" % ", ".join(
            k + "=" + repr(v) for k, v in self._values.items()
        )


@jsii.data_type(
    jsii_type="@cdktf/provider-azurerm.FrontdoorBackendPoolLoadBalancing",
    jsii_struct_bases=[],
    name_mapping={
        "name": "name",
        "additional_latency_milliseconds": "additionalLatencyMilliseconds",
        "sample_size": "sampleSize",
        "successful_samples_required": "successfulSamplesRequired",
    },
)
class FrontdoorBackendPoolLoadBalancing:
    def __init__(
        self,
        *,
        name: builtins.str,
        additional_latency_milliseconds: typing.Optional[jsii.Number] = None,
        sample_size: typing.Optional[jsii.Number] = None,
        successful_samples_required: typing.Optional[jsii.Number] = None,
    ) -> None:
        """
        :param name: 
        :param additional_latency_milliseconds: 
        :param sample_size: 
        :param successful_samples_required: 
        """
        self._values: typing.Dict[str, typing.Any] = {
            "name": name,
        }
        if additional_latency_milliseconds is not None:
            self._values["additional_latency_milliseconds"] = additional_latency_milliseconds
        if sample_size is not None:
            self._values["sample_size"] = sample_size
        if successful_samples_required is not None:
            self._values["successful_samples_required"] = successful_samples_required

    @builtins.property
    def name(self) -> builtins.str:
        result = self._values.get("name")
        assert result is not None, "Required property 'name' is missing"
        return result

    @builtins.property
    def additional_latency_milliseconds(self) -> typing.Optional[jsii.Number]:
        result = self._values.get("additional_latency_milliseconds")
        return result

    @builtins.property
    def sample_size(self) -> typing.Optional[jsii.Number]:
        result = self._values.get("sample_size")
        return result

    @builtins.property
    def successful_samples_required(self) -> typing.Optional[jsii.Number]:
        result = self._values.get("successful_samples_required")
        return result

    def __eq__(self, rhs: typing.Any) -> builtins.bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs: typing.Any) -> builtins.bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return "FrontdoorBackendPoolLoadBalancing(%s)" % ", ".join(
            k + "=" + repr(v) for k, v in self._values.items()
        )


@jsii.data_type(
    jsii_type="@cdktf/provider-azurerm.FrontdoorConfig",
    jsii_struct_bases=[cdktf.TerraformMetaArguments],
    name_mapping={
        "count": "count",
        "depends_on": "dependsOn",
        "lifecycle": "lifecycle",
        "provider": "provider",
        "backend_pool": "backendPool",
        "backend_pool_health_probe": "backendPoolHealthProbe",
        "backend_pool_load_balancing": "backendPoolLoadBalancing",
        "enforce_backend_pools_certificate_name_check": "enforceBackendPoolsCertificateNameCheck",
        "frontend_endpoint": "frontendEndpoint",
        "location": "location",
        "name": "name",
        "resource_group_name": "resourceGroupName",
        "routing_rule": "routingRule",
        "friendly_name": "friendlyName",
        "load_balancer_enabled": "loadBalancerEnabled",
        "tags": "tags",
        "timeouts": "timeouts",
    },
)
class FrontdoorConfig(cdktf.TerraformMetaArguments):
    def __init__(
        self,
        *,
        count: typing.Optional[jsii.Number] = None,
        depends_on: typing.Optional[typing.List[cdktf.TerraformResource]] = None,
        lifecycle: typing.Optional[cdktf.TerraformResourceLifecycle] = None,
        provider: typing.Optional[cdktf.TerraformProvider] = None,
        backend_pool: typing.List[FrontdoorBackendPool],
        backend_pool_health_probe: typing.List[FrontdoorBackendPoolHealthProbe],
        backend_pool_load_balancing: typing.List[FrontdoorBackendPoolLoadBalancing],
        enforce_backend_pools_certificate_name_check: builtins.bool,
        frontend_endpoint: typing.List["FrontdoorFrontendEndpoint"],
        location: builtins.str,
        name: builtins.str,
        resource_group_name: builtins.str,
        routing_rule: typing.List["FrontdoorRoutingRule"],
        friendly_name: typing.Optional[builtins.str] = None,
        load_balancer_enabled: typing.Optional[builtins.bool] = None,
        tags: typing.Optional[typing.Mapping[builtins.str, builtins.str]] = None,
        timeouts: typing.Optional["FrontdoorTimeouts"] = None,
    ) -> None:
        """
        :param count: 
        :param depends_on: 
        :param lifecycle: 
        :param provider: 
        :param backend_pool: backend_pool block.
        :param backend_pool_health_probe: backend_pool_health_probe block.
        :param backend_pool_load_balancing: backend_pool_load_balancing block.
        :param enforce_backend_pools_certificate_name_check: 
        :param frontend_endpoint: frontend_endpoint block.
        :param location: 
        :param name: 
        :param resource_group_name: 
        :param routing_rule: routing_rule block.
        :param friendly_name: 
        :param load_balancer_enabled: 
        :param tags: 
        :param timeouts: timeouts block.
        """
        if isinstance(lifecycle, dict):
            lifecycle = cdktf.TerraformResourceLifecycle(**lifecycle)
        if isinstance(timeouts, dict):
            timeouts = FrontdoorTimeouts(**timeouts)
        self._values: typing.Dict[str, typing.Any] = {
            "backend_pool": backend_pool,
            "backend_pool_health_probe": backend_pool_health_probe,
            "backend_pool_load_balancing": backend_pool_load_balancing,
            "enforce_backend_pools_certificate_name_check": enforce_backend_pools_certificate_name_check,
            "frontend_endpoint": frontend_endpoint,
            "location": location,
            "name": name,
            "resource_group_name": resource_group_name,
            "routing_rule": routing_rule,
        }
        if count is not None:
            self._values["count"] = count
        if depends_on is not None:
            self._values["depends_on"] = depends_on
        if lifecycle is not None:
            self._values["lifecycle"] = lifecycle
        if provider is not None:
            self._values["provider"] = provider
        if friendly_name is not None:
            self._values["friendly_name"] = friendly_name
        if load_balancer_enabled is not None:
            self._values["load_balancer_enabled"] = load_balancer_enabled
        if tags is not None:
            self._values["tags"] = tags
        if timeouts is not None:
            self._values["timeouts"] = timeouts

    @builtins.property
    def count(self) -> typing.Optional[jsii.Number]:
        """
        :stability: experimental
        """
        result = self._values.get("count")
        return result

    @builtins.property
    def depends_on(self) -> typing.Optional[typing.List[cdktf.TerraformResource]]:
        """
        :stability: experimental
        """
        result = self._values.get("depends_on")
        return result

    @builtins.property
    def lifecycle(self) -> typing.Optional[cdktf.TerraformResourceLifecycle]:
        """
        :stability: experimental
        """
        result = self._values.get("lifecycle")
        return result

    @builtins.property
    def provider(self) -> typing.Optional[cdktf.TerraformProvider]:
        """
        :stability: experimental
        """
        result = self._values.get("provider")
        return result

    @builtins.property
    def backend_pool(self) -> typing.List[FrontdoorBackendPool]:
        """backend_pool block."""
        result = self._values.get("backend_pool")
        assert result is not None, "Required property 'backend_pool' is missing"
        return result

    @builtins.property
    def backend_pool_health_probe(self) -> typing.List[FrontdoorBackendPoolHealthProbe]:
        """backend_pool_health_probe block."""
        result = self._values.get("backend_pool_health_probe")
        assert result is not None, "Required property 'backend_pool_health_probe' is missing"
        return result

    @builtins.property
    def backend_pool_load_balancing(
        self,
    ) -> typing.List[FrontdoorBackendPoolLoadBalancing]:
        """backend_pool_load_balancing block."""
        result = self._values.get("backend_pool_load_balancing")
        assert result is not None, "Required property 'backend_pool_load_balancing' is missing"
        return result

    @builtins.property
    def enforce_backend_pools_certificate_name_check(self) -> builtins.bool:
        result = self._values.get("enforce_backend_pools_certificate_name_check")
        assert result is not None, "Required property 'enforce_backend_pools_certificate_name_check' is missing"
        return result

    @builtins.property
    def frontend_endpoint(self) -> typing.List["FrontdoorFrontendEndpoint"]:
        """frontend_endpoint block."""
        result = self._values.get("frontend_endpoint")
        assert result is not None, "Required property 'frontend_endpoint' is missing"
        return result

    @builtins.property
    def location(self) -> builtins.str:
        result = self._values.get("location")
        assert result is not None, "Required property 'location' is missing"
        return result

    @builtins.property
    def name(self) -> builtins.str:
        result = self._values.get("name")
        assert result is not None, "Required property 'name' is missing"
        return result

    @builtins.property
    def resource_group_name(self) -> builtins.str:
        result = self._values.get("resource_group_name")
        assert result is not None, "Required property 'resource_group_name' is missing"
        return result

    @builtins.property
    def routing_rule(self) -> typing.List["FrontdoorRoutingRule"]:
        """routing_rule block."""
        result = self._values.get("routing_rule")
        assert result is not None, "Required property 'routing_rule' is missing"
        return result

    @builtins.property
    def friendly_name(self) -> typing.Optional[builtins.str]:
        result = self._values.get("friendly_name")
        return result

    @builtins.property
    def load_balancer_enabled(self) -> typing.Optional[builtins.bool]:
        result = self._values.get("load_balancer_enabled")
        return result

    @builtins.property
    def tags(self) -> typing.Optional[typing.Mapping[builtins.str, builtins.str]]:
        result = self._values.get("tags")
        return result

    @builtins.property
    def timeouts(self) -> typing.Optional["FrontdoorTimeouts"]:
        """timeouts block."""
        result = self._values.get("timeouts")
        return result

    def __eq__(self, rhs: typing.Any) -> builtins.bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs: typing.Any) -> builtins.bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return "FrontdoorConfig(%s)" % ", ".join(
            k + "=" + repr(v) for k, v in self._values.items()
        )


class FrontdoorFirewallPolicy(
    cdktf.TerraformResource,
    metaclass=jsii.JSIIMeta,
    jsii_type="@cdktf/provider-azurerm.FrontdoorFirewallPolicy",
):
    def __init__(
        self,
        scope: constructs.Construct,
        id: builtins.str,
        *,
        name: builtins.str,
        resource_group_name: builtins.str,
        custom_block_response_body: typing.Optional[builtins.str] = None,
        custom_block_response_status_code: typing.Optional[jsii.Number] = None,
        custom_rule: typing.Optional[typing.List["FrontdoorFirewallPolicyCustomRule"]] = None,
        enabled: typing.Optional[builtins.bool] = None,
        managed_rule: typing.Optional[typing.List["FrontdoorFirewallPolicyManagedRule"]] = None,
        mode: typing.Optional[builtins.str] = None,
        redirect_url: typing.Optional[builtins.str] = None,
        tags: typing.Optional[typing.Mapping[builtins.str, builtins.str]] = None,
        timeouts: typing.Optional["FrontdoorFirewallPolicyTimeouts"] = None,
        count: typing.Optional[jsii.Number] = None,
        depends_on: typing.Optional[typing.List[cdktf.TerraformResource]] = None,
        lifecycle: typing.Optional[cdktf.TerraformResourceLifecycle] = None,
        provider: typing.Optional[cdktf.TerraformProvider] = None,
    ) -> None:
        """
        :param scope: -
        :param id: -
        :param name: 
        :param resource_group_name: 
        :param custom_block_response_body: 
        :param custom_block_response_status_code: 
        :param custom_rule: custom_rule block.
        :param enabled: 
        :param managed_rule: managed_rule block.
        :param mode: 
        :param redirect_url: 
        :param tags: 
        :param timeouts: timeouts block.
        :param count: 
        :param depends_on: 
        :param lifecycle: 
        :param provider: 
        """
        config = FrontdoorFirewallPolicyConfig(
            name=name,
            resource_group_name=resource_group_name,
            custom_block_response_body=custom_block_response_body,
            custom_block_response_status_code=custom_block_response_status_code,
            custom_rule=custom_rule,
            enabled=enabled,
            managed_rule=managed_rule,
            mode=mode,
            redirect_url=redirect_url,
            tags=tags,
            timeouts=timeouts,
            count=count,
            depends_on=depends_on,
            lifecycle=lifecycle,
            provider=provider,
        )

        jsii.create(FrontdoorFirewallPolicy, self, [scope, id, config])

    @jsii.member(jsii_name="synthesizeAttributes")
    def _synthesize_attributes(self) -> typing.Mapping[builtins.str, typing.Any]:
        return jsii.invoke(self, "synthesizeAttributes", [])

    @builtins.property # type: ignore
    @jsii.member(jsii_name="frontendEndpointIds")
    def frontend_endpoint_ids(self) -> typing.List[builtins.str]:
        return jsii.get(self, "frontendEndpointIds")

    @builtins.property # type: ignore
    @jsii.member(jsii_name="location")
    def location(self) -> builtins.str:
        return jsii.get(self, "location")

    @builtins.property # type: ignore
    @jsii.member(jsii_name="name")
    def name(self) -> builtins.str:
        return jsii.get(self, "name")

    @name.setter # type: ignore
    def name(self, value: builtins.str) -> None:
        jsii.set(self, "name", value)

    @builtins.property # type: ignore
    @jsii.member(jsii_name="resourceGroupName")
    def resource_group_name(self) -> builtins.str:
        return jsii.get(self, "resourceGroupName")

    @resource_group_name.setter # type: ignore
    def resource_group_name(self, value: builtins.str) -> None:
        jsii.set(self, "resourceGroupName", value)

    @builtins.property # type: ignore
    @jsii.member(jsii_name="customBlockResponseBody")
    def custom_block_response_body(self) -> typing.Optional[builtins.str]:
        return jsii.get(self, "customBlockResponseBody")

    @custom_block_response_body.setter # type: ignore
    def custom_block_response_body(self, value: typing.Optional[builtins.str]) -> None:
        jsii.set(self, "customBlockResponseBody", value)

    @builtins.property # type: ignore
    @jsii.member(jsii_name="customBlockResponseStatusCode")
    def custom_block_response_status_code(self) -> typing.Optional[jsii.Number]:
        return jsii.get(self, "customBlockResponseStatusCode")

    @custom_block_response_status_code.setter # type: ignore
    def custom_block_response_status_code(
        self,
        value: typing.Optional[jsii.Number],
    ) -> None:
        jsii.set(self, "customBlockResponseStatusCode", value)

    @builtins.property # type: ignore
    @jsii.member(jsii_name="customRule")
    def custom_rule(
        self,
    ) -> typing.Optional[typing.List["FrontdoorFirewallPolicyCustomRule"]]:
        return jsii.get(self, "customRule")

    @custom_rule.setter # type: ignore
    def custom_rule(
        self,
        value: typing.Optional[typing.List["FrontdoorFirewallPolicyCustomRule"]],
    ) -> None:
        jsii.set(self, "customRule", value)

    @builtins.property # type: ignore
    @jsii.member(jsii_name="enabled")
    def enabled(self) -> typing.Optional[builtins.bool]:
        return jsii.get(self, "enabled")

    @enabled.setter # type: ignore
    def enabled(self, value: typing.Optional[builtins.bool]) -> None:
        jsii.set(self, "enabled", value)

    @builtins.property # type: ignore
    @jsii.member(jsii_name="id")
    def id(self) -> typing.Optional[builtins.str]:
        return jsii.get(self, "id")

    @id.setter # type: ignore
    def id(self, value: typing.Optional[builtins.str]) -> None:
        jsii.set(self, "id", value)

    @builtins.property # type: ignore
    @jsii.member(jsii_name="managedRule")
    def managed_rule(
        self,
    ) -> typing.Optional[typing.List["FrontdoorFirewallPolicyManagedRule"]]:
        return jsii.get(self, "managedRule")

    @managed_rule.setter # type: ignore
    def managed_rule(
        self,
        value: typing.Optional[typing.List["FrontdoorFirewallPolicyManagedRule"]],
    ) -> None:
        jsii.set(self, "managedRule", value)

    @builtins.property # type: ignore
    @jsii.member(jsii_name="mode")
    def mode(self) -> typing.Optional[builtins.str]:
        return jsii.get(self, "mode")

    @mode.setter # type: ignore
    def mode(self, value: typing.Optional[builtins.str]) -> None:
        jsii.set(self, "mode", value)

    @builtins.property # type: ignore
    @jsii.member(jsii_name="redirectUrl")
    def redirect_url(self) -> typing.Optional[builtins.str]:
        return jsii.get(self, "redirectUrl")

    @redirect_url.setter # type: ignore
    def redirect_url(self, value: typing.Optional[builtins.str]) -> None:
        jsii.set(self, "redirectUrl", value)

    @builtins.property # type: ignore
    @jsii.member(jsii_name="tags")
    def tags(self) -> typing.Optional[typing.Mapping[builtins.str, builtins.str]]:
        return jsii.get(self, "tags")

    @tags.setter # type: ignore
    def tags(
        self,
        value: typing.Optional[typing.Mapping[builtins.str, builtins.str]],
    ) -> None:
        jsii.set(self, "tags", value)

    @builtins.property # type: ignore
    @jsii.member(jsii_name="timeouts")
    def timeouts(self) -> typing.Optional["FrontdoorFirewallPolicyTimeouts"]:
        return jsii.get(self, "timeouts")

    @timeouts.setter # type: ignore
    def timeouts(
        self,
        value: typing.Optional["FrontdoorFirewallPolicyTimeouts"],
    ) -> None:
        jsii.set(self, "timeouts", value)


@jsii.data_type(
    jsii_type="@cdktf/provider-azurerm.FrontdoorFirewallPolicyConfig",
    jsii_struct_bases=[cdktf.TerraformMetaArguments],
    name_mapping={
        "count": "count",
        "depends_on": "dependsOn",
        "lifecycle": "lifecycle",
        "provider": "provider",
        "name": "name",
        "resource_group_name": "resourceGroupName",
        "custom_block_response_body": "customBlockResponseBody",
        "custom_block_response_status_code": "customBlockResponseStatusCode",
        "custom_rule": "customRule",
        "enabled": "enabled",
        "managed_rule": "managedRule",
        "mode": "mode",
        "redirect_url": "redirectUrl",
        "tags": "tags",
        "timeouts": "timeouts",
    },
)
class FrontdoorFirewallPolicyConfig(cdktf.TerraformMetaArguments):
    def __init__(
        self,
        *,
        count: typing.Optional[jsii.Number] = None,
        depends_on: typing.Optional[typing.List[cdktf.TerraformResource]] = None,
        lifecycle: typing.Optional[cdktf.TerraformResourceLifecycle] = None,
        provider: typing.Optional[cdktf.TerraformProvider] = None,
        name: builtins.str,
        resource_group_name: builtins.str,
        custom_block_response_body: typing.Optional[builtins.str] = None,
        custom_block_response_status_code: typing.Optional[jsii.Number] = None,
        custom_rule: typing.Optional[typing.List["FrontdoorFirewallPolicyCustomRule"]] = None,
        enabled: typing.Optional[builtins.bool] = None,
        managed_rule: typing.Optional[typing.List["FrontdoorFirewallPolicyManagedRule"]] = None,
        mode: typing.Optional[builtins.str] = None,
        redirect_url: typing.Optional[builtins.str] = None,
        tags: typing.Optional[typing.Mapping[builtins.str, builtins.str]] = None,
        timeouts: typing.Optional["FrontdoorFirewallPolicyTimeouts"] = None,
    ) -> None:
        """
        :param count: 
        :param depends_on: 
        :param lifecycle: 
        :param provider: 
        :param name: 
        :param resource_group_name: 
        :param custom_block_response_body: 
        :param custom_block_response_status_code: 
        :param custom_rule: custom_rule block.
        :param enabled: 
        :param managed_rule: managed_rule block.
        :param mode: 
        :param redirect_url: 
        :param tags: 
        :param timeouts: timeouts block.
        """
        if isinstance(lifecycle, dict):
            lifecycle = cdktf.TerraformResourceLifecycle(**lifecycle)
        if isinstance(timeouts, dict):
            timeouts = FrontdoorFirewallPolicyTimeouts(**timeouts)
        self._values: typing.Dict[str, typing.Any] = {
            "name": name,
            "resource_group_name": resource_group_name,
        }
        if count is not None:
            self._values["count"] = count
        if depends_on is not None:
            self._values["depends_on"] = depends_on
        if lifecycle is not None:
            self._values["lifecycle"] = lifecycle
        if provider is not None:
            self._values["provider"] = provider
        if custom_block_response_body is not None:
            self._values["custom_block_response_body"] = custom_block_response_body
        if custom_block_response_status_code is not None:
            self._values["custom_block_response_status_code"] = custom_block_response_status_code
        if custom_rule is not None:
            self._values["custom_rule"] = custom_rule
        if enabled is not None:
            self._values["enabled"] = enabled
        if managed_rule is not None:
            self._values["managed_rule"] = managed_rule
        if mode is not None:
            self._values["mode"] = mode
        if redirect_url is not None:
            self._values["redirect_url"] = redirect_url
        if tags is not None:
            self._values["tags"] = tags
        if timeouts is not None:
            self._values["timeouts"] = timeouts

    @builtins.property
    def count(self) -> typing.Optional[jsii.Number]:
        """
        :stability: experimental
        """
        result = self._values.get("count")
        return result

    @builtins.property
    def depends_on(self) -> typing.Optional[typing.List[cdktf.TerraformResource]]:
        """
        :stability: experimental
        """
        result = self._values.get("depends_on")
        return result

    @builtins.property
    def lifecycle(self) -> typing.Optional[cdktf.TerraformResourceLifecycle]:
        """
        :stability: experimental
        """
        result = self._values.get("lifecycle")
        return result

    @builtins.property
    def provider(self) -> typing.Optional[cdktf.TerraformProvider]:
        """
        :stability: experimental
        """
        result = self._values.get("provider")
        return result

    @builtins.property
    def name(self) -> builtins.str:
        result = self._values.get("name")
        assert result is not None, "Required property 'name' is missing"
        return result

    @builtins.property
    def resource_group_name(self) -> builtins.str:
        result = self._values.get("resource_group_name")
        assert result is not None, "Required property 'resource_group_name' is missing"
        return result

    @builtins.property
    def custom_block_response_body(self) -> typing.Optional[builtins.str]:
        result = self._values.get("custom_block_response_body")
        return result

    @builtins.property
    def custom_block_response_status_code(self) -> typing.Optional[jsii.Number]:
        result = self._values.get("custom_block_response_status_code")
        return result

    @builtins.property
    def custom_rule(
        self,
    ) -> typing.Optional[typing.List["FrontdoorFirewallPolicyCustomRule"]]:
        """custom_rule block."""
        result = self._values.get("custom_rule")
        return result

    @builtins.property
    def enabled(self) -> typing.Optional[builtins.bool]:
        result = self._values.get("enabled")
        return result

    @builtins.property
    def managed_rule(
        self,
    ) -> typing.Optional[typing.List["FrontdoorFirewallPolicyManagedRule"]]:
        """managed_rule block."""
        result = self._values.get("managed_rule")
        return result

    @builtins.property
    def mode(self) -> typing.Optional[builtins.str]:
        result = self._values.get("mode")
        return result

    @builtins.property
    def redirect_url(self) -> typing.Optional[builtins.str]:
        result = self._values.get("redirect_url")
        return result

    @builtins.property
    def tags(self) -> typing.Optional[typing.Mapping[builtins.str, builtins.str]]:
        result = self._values.get("tags")
        return result

    @builtins.property
    def timeouts(self) -> typing.Optional["FrontdoorFirewallPolicyTimeouts"]:
        """timeouts block."""
        result = self._values.get("timeouts")
        return result

    def __eq__(self, rhs: typing.Any) -> builtins.bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs: typing.Any) -> builtins.bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return "FrontdoorFirewallPolicyConfig(%s)" % ", ".join(
            k + "=" + repr(v) for k, v in self._values.items()
        )


@jsii.data_type(
    jsii_type="@cdktf/provider-azurerm.FrontdoorFirewallPolicyCustomRule",
    jsii_struct_bases=[],
    name_mapping={
        "action": "action",
        "name": "name",
        "type": "type",
        "enabled": "enabled",
        "match_condition": "matchCondition",
        "priority": "priority",
        "rate_limit_duration_in_minutes": "rateLimitDurationInMinutes",
        "rate_limit_threshold": "rateLimitThreshold",
    },
)
class FrontdoorFirewallPolicyCustomRule:
    def __init__(
        self,
        *,
        action: builtins.str,
        name: builtins.str,
        type: builtins.str,
        enabled: typing.Optional[builtins.bool] = None,
        match_condition: typing.Optional[typing.List["FrontdoorFirewallPolicyCustomRuleMatchCondition"]] = None,
        priority: typing.Optional[jsii.Number] = None,
        rate_limit_duration_in_minutes: typing.Optional[jsii.Number] = None,
        rate_limit_threshold: typing.Optional[jsii.Number] = None,
    ) -> None:
        """
        :param action: 
        :param name: 
        :param type: 
        :param enabled: 
        :param match_condition: match_condition block.
        :param priority: 
        :param rate_limit_duration_in_minutes: 
        :param rate_limit_threshold: 
        """
        self._values: typing.Dict[str, typing.Any] = {
            "action": action,
            "name": name,
            "type": type,
        }
        if enabled is not None:
            self._values["enabled"] = enabled
        if match_condition is not None:
            self._values["match_condition"] = match_condition
        if priority is not None:
            self._values["priority"] = priority
        if rate_limit_duration_in_minutes is not None:
            self._values["rate_limit_duration_in_minutes"] = rate_limit_duration_in_minutes
        if rate_limit_threshold is not None:
            self._values["rate_limit_threshold"] = rate_limit_threshold

    @builtins.property
    def action(self) -> builtins.str:
        result = self._values.get("action")
        assert result is not None, "Required property 'action' is missing"
        return result

    @builtins.property
    def name(self) -> builtins.str:
        result = self._values.get("name")
        assert result is not None, "Required property 'name' is missing"
        return result

    @builtins.property
    def type(self) -> builtins.str:
        result = self._values.get("type")
        assert result is not None, "Required property 'type' is missing"
        return result

    @builtins.property
    def enabled(self) -> typing.Optional[builtins.bool]:
        result = self._values.get("enabled")
        return result

    @builtins.property
    def match_condition(
        self,
    ) -> typing.Optional[typing.List["FrontdoorFirewallPolicyCustomRuleMatchCondition"]]:
        """match_condition block."""
        result = self._values.get("match_condition")
        return result

    @builtins.property
    def priority(self) -> typing.Optional[jsii.Number]:
        result = self._values.get("priority")
        return result

    @builtins.property
    def rate_limit_duration_in_minutes(self) -> typing.Optional[jsii.Number]:
        result = self._values.get("rate_limit_duration_in_minutes")
        return result

    @builtins.property
    def rate_limit_threshold(self) -> typing.Optional[jsii.Number]:
        result = self._values.get("rate_limit_threshold")
        return result

    def __eq__(self, rhs: typing.Any) -> builtins.bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs: typing.Any) -> builtins.bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return "FrontdoorFirewallPolicyCustomRule(%s)" % ", ".join(
            k + "=" + repr(v) for k, v in self._values.items()
        )


@jsii.data_type(
    jsii_type="@cdktf/provider-azurerm.FrontdoorFirewallPolicyCustomRuleMatchCondition",
    jsii_struct_bases=[],
    name_mapping={
        "match_values": "matchValues",
        "match_variable": "matchVariable",
        "operator": "operator",
        "negation_condition": "negationCondition",
        "selector": "selector",
        "transforms": "transforms",
    },
)
class FrontdoorFirewallPolicyCustomRuleMatchCondition:
    def __init__(
        self,
        *,
        match_values: typing.List[builtins.str],
        match_variable: builtins.str,
        operator: builtins.str,
        negation_condition: typing.Optional[builtins.bool] = None,
        selector: typing.Optional[builtins.str] = None,
        transforms: typing.Optional[typing.List[builtins.str]] = None,
    ) -> None:
        """
        :param match_values: 
        :param match_variable: 
        :param operator: 
        :param negation_condition: 
        :param selector: 
        :param transforms: 
        """
        self._values: typing.Dict[str, typing.Any] = {
            "match_values": match_values,
            "match_variable": match_variable,
            "operator": operator,
        }
        if negation_condition is not None:
            self._values["negation_condition"] = negation_condition
        if selector is not None:
            self._values["selector"] = selector
        if transforms is not None:
            self._values["transforms"] = transforms

    @builtins.property
    def match_values(self) -> typing.List[builtins.str]:
        result = self._values.get("match_values")
        assert result is not None, "Required property 'match_values' is missing"
        return result

    @builtins.property
    def match_variable(self) -> builtins.str:
        result = self._values.get("match_variable")
        assert result is not None, "Required property 'match_variable' is missing"
        return result

    @builtins.property
    def operator(self) -> builtins.str:
        result = self._values.get("operator")
        assert result is not None, "Required property 'operator' is missing"
        return result

    @builtins.property
    def negation_condition(self) -> typing.Optional[builtins.bool]:
        result = self._values.get("negation_condition")
        return result

    @builtins.property
    def selector(self) -> typing.Optional[builtins.str]:
        result = self._values.get("selector")
        return result

    @builtins.property
    def transforms(self) -> typing.Optional[typing.List[builtins.str]]:
        result = self._values.get("transforms")
        return result

    def __eq__(self, rhs: typing.Any) -> builtins.bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs: typing.Any) -> builtins.bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return "FrontdoorFirewallPolicyCustomRuleMatchCondition(%s)" % ", ".join(
            k + "=" + repr(v) for k, v in self._values.items()
        )


@jsii.data_type(
    jsii_type="@cdktf/provider-azurerm.FrontdoorFirewallPolicyManagedRule",
    jsii_struct_bases=[],
    name_mapping={
        "type": "type",
        "version": "version",
        "exclusion": "exclusion",
        "override": "override",
    },
)
class FrontdoorFirewallPolicyManagedRule:
    def __init__(
        self,
        *,
        type: builtins.str,
        version: builtins.str,
        exclusion: typing.Optional[typing.List["FrontdoorFirewallPolicyManagedRuleExclusion"]] = None,
        override: typing.Optional[typing.List["FrontdoorFirewallPolicyManagedRuleOverride"]] = None,
    ) -> None:
        """
        :param type: 
        :param version: 
        :param exclusion: exclusion block.
        :param override: override block.
        """
        self._values: typing.Dict[str, typing.Any] = {
            "type": type,
            "version": version,
        }
        if exclusion is not None:
            self._values["exclusion"] = exclusion
        if override is not None:
            self._values["override"] = override

    @builtins.property
    def type(self) -> builtins.str:
        result = self._values.get("type")
        assert result is not None, "Required property 'type' is missing"
        return result

    @builtins.property
    def version(self) -> builtins.str:
        result = self._values.get("version")
        assert result is not None, "Required property 'version' is missing"
        return result

    @builtins.property
    def exclusion(
        self,
    ) -> typing.Optional[typing.List["FrontdoorFirewallPolicyManagedRuleExclusion"]]:
        """exclusion block."""
        result = self._values.get("exclusion")
        return result

    @builtins.property
    def override(
        self,
    ) -> typing.Optional[typing.List["FrontdoorFirewallPolicyManagedRuleOverride"]]:
        """override block."""
        result = self._values.get("override")
        return result

    def __eq__(self, rhs: typing.Any) -> builtins.bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs: typing.Any) -> builtins.bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return "FrontdoorFirewallPolicyManagedRule(%s)" % ", ".join(
            k + "=" + repr(v) for k, v in self._values.items()
        )


@jsii.data_type(
    jsii_type="@cdktf/provider-azurerm.FrontdoorFirewallPolicyManagedRuleExclusion",
    jsii_struct_bases=[],
    name_mapping={
        "match_variable": "matchVariable",
        "operator": "operator",
        "selector": "selector",
    },
)
class FrontdoorFirewallPolicyManagedRuleExclusion:
    def __init__(
        self,
        *,
        match_variable: builtins.str,
        operator: builtins.str,
        selector: builtins.str,
    ) -> None:
        """
        :param match_variable: 
        :param operator: 
        :param selector: 
        """
        self._values: typing.Dict[str, typing.Any] = {
            "match_variable": match_variable,
            "operator": operator,
            "selector": selector,
        }

    @builtins.property
    def match_variable(self) -> builtins.str:
        result = self._values.get("match_variable")
        assert result is not None, "Required property 'match_variable' is missing"
        return result

    @builtins.property
    def operator(self) -> builtins.str:
        result = self._values.get("operator")
        assert result is not None, "Required property 'operator' is missing"
        return result

    @builtins.property
    def selector(self) -> builtins.str:
        result = self._values.get("selector")
        assert result is not None, "Required property 'selector' is missing"
        return result

    def __eq__(self, rhs: typing.Any) -> builtins.bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs: typing.Any) -> builtins.bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return "FrontdoorFirewallPolicyManagedRuleExclusion(%s)" % ", ".join(
            k + "=" + repr(v) for k, v in self._values.items()
        )


@jsii.data_type(
    jsii_type="@cdktf/provider-azurerm.FrontdoorFirewallPolicyManagedRuleOverride",
    jsii_struct_bases=[],
    name_mapping={
        "rule_group_name": "ruleGroupName",
        "exclusion": "exclusion",
        "rule": "rule",
    },
)
class FrontdoorFirewallPolicyManagedRuleOverride:
    def __init__(
        self,
        *,
        rule_group_name: builtins.str,
        exclusion: typing.Optional[typing.List["FrontdoorFirewallPolicyManagedRuleOverrideExclusion"]] = None,
        rule: typing.Optional[typing.List["FrontdoorFirewallPolicyManagedRuleOverrideRule"]] = None,
    ) -> None:
        """
        :param rule_group_name: 
        :param exclusion: exclusion block.
        :param rule: rule block.
        """
        self._values: typing.Dict[str, typing.Any] = {
            "rule_group_name": rule_group_name,
        }
        if exclusion is not None:
            self._values["exclusion"] = exclusion
        if rule is not None:
            self._values["rule"] = rule

    @builtins.property
    def rule_group_name(self) -> builtins.str:
        result = self._values.get("rule_group_name")
        assert result is not None, "Required property 'rule_group_name' is missing"
        return result

    @builtins.property
    def exclusion(
        self,
    ) -> typing.Optional[typing.List["FrontdoorFirewallPolicyManagedRuleOverrideExclusion"]]:
        """exclusion block."""
        result = self._values.get("exclusion")
        return result

    @builtins.property
    def rule(
        self,
    ) -> typing.Optional[typing.List["FrontdoorFirewallPolicyManagedRuleOverrideRule"]]:
        """rule block."""
        result = self._values.get("rule")
        return result

    def __eq__(self, rhs: typing.Any) -> builtins.bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs: typing.Any) -> builtins.bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return "FrontdoorFirewallPolicyManagedRuleOverride(%s)" % ", ".join(
            k + "=" + repr(v) for k, v in self._values.items()
        )


@jsii.data_type(
    jsii_type="@cdktf/provider-azurerm.FrontdoorFirewallPolicyManagedRuleOverrideExclusion",
    jsii_struct_bases=[],
    name_mapping={
        "match_variable": "matchVariable",
        "operator": "operator",
        "selector": "selector",
    },
)
class FrontdoorFirewallPolicyManagedRuleOverrideExclusion:
    def __init__(
        self,
        *,
        match_variable: builtins.str,
        operator: builtins.str,
        selector: builtins.str,
    ) -> None:
        """
        :param match_variable: 
        :param operator: 
        :param selector: 
        """
        self._values: typing.Dict[str, typing.Any] = {
            "match_variable": match_variable,
            "operator": operator,
            "selector": selector,
        }

    @builtins.property
    def match_variable(self) -> builtins.str:
        result = self._values.get("match_variable")
        assert result is not None, "Required property 'match_variable' is missing"
        return result

    @builtins.property
    def operator(self) -> builtins.str:
        result = self._values.get("operator")
        assert result is not None, "Required property 'operator' is missing"
        return result

    @builtins.property
    def selector(self) -> builtins.str:
        result = self._values.get("selector")
        assert result is not None, "Required property 'selector' is missing"
        return result

    def __eq__(self, rhs: typing.Any) -> builtins.bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs: typing.Any) -> builtins.bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return "FrontdoorFirewallPolicyManagedRuleOverrideExclusion(%s)" % ", ".join(
            k + "=" + repr(v) for k, v in self._values.items()
        )


@jsii.data_type(
    jsii_type="@cdktf/provider-azurerm.FrontdoorFirewallPolicyManagedRuleOverrideRule",
    jsii_struct_bases=[],
    name_mapping={
        "action": "action",
        "rule_id": "ruleId",
        "enabled": "enabled",
        "exclusion": "exclusion",
    },
)
class FrontdoorFirewallPolicyManagedRuleOverrideRule:
    def __init__(
        self,
        *,
        action: builtins.str,
        rule_id: builtins.str,
        enabled: typing.Optional[builtins.bool] = None,
        exclusion: typing.Optional[typing.List["FrontdoorFirewallPolicyManagedRuleOverrideRuleExclusion"]] = None,
    ) -> None:
        """
        :param action: 
        :param rule_id: 
        :param enabled: 
        :param exclusion: exclusion block.
        """
        self._values: typing.Dict[str, typing.Any] = {
            "action": action,
            "rule_id": rule_id,
        }
        if enabled is not None:
            self._values["enabled"] = enabled
        if exclusion is not None:
            self._values["exclusion"] = exclusion

    @builtins.property
    def action(self) -> builtins.str:
        result = self._values.get("action")
        assert result is not None, "Required property 'action' is missing"
        return result

    @builtins.property
    def rule_id(self) -> builtins.str:
        result = self._values.get("rule_id")
        assert result is not None, "Required property 'rule_id' is missing"
        return result

    @builtins.property
    def enabled(self) -> typing.Optional[builtins.bool]:
        result = self._values.get("enabled")
        return result

    @builtins.property
    def exclusion(
        self,
    ) -> typing.Optional[typing.List["FrontdoorFirewallPolicyManagedRuleOverrideRuleExclusion"]]:
        """exclusion block."""
        result = self._values.get("exclusion")
        return result

    def __eq__(self, rhs: typing.Any) -> builtins.bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs: typing.Any) -> builtins.bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return "FrontdoorFirewallPolicyManagedRuleOverrideRule(%s)" % ", ".join(
            k + "=" + repr(v) for k, v in self._values.items()
        )


@jsii.data_type(
    jsii_type="@cdktf/provider-azurerm.FrontdoorFirewallPolicyManagedRuleOverrideRuleExclusion",
    jsii_struct_bases=[],
    name_mapping={
        "match_variable": "matchVariable",
        "operator": "operator",
        "selector": "selector",
    },
)
class FrontdoorFirewallPolicyManagedRuleOverrideRuleExclusion:
    def __init__(
        self,
        *,
        match_variable: builtins.str,
        operator: builtins.str,
        selector: builtins.str,
    ) -> None:
        """
        :param match_variable: 
        :param operator: 
        :param selector: 
        """
        self._values: typing.Dict[str, typing.Any] = {
            "match_variable": match_variable,
            "operator": operator,
            "selector": selector,
        }

    @builtins.property
    def match_variable(self) -> builtins.str:
        result = self._values.get("match_variable")
        assert result is not None, "Required property 'match_variable' is missing"
        return result

    @builtins.property
    def operator(self) -> builtins.str:
        result = self._values.get("operator")
        assert result is not None, "Required property 'operator' is missing"
        return result

    @builtins.property
    def selector(self) -> builtins.str:
        result = self._values.get("selector")
        assert result is not None, "Required property 'selector' is missing"
        return result

    def __eq__(self, rhs: typing.Any) -> builtins.bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs: typing.Any) -> builtins.bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return "FrontdoorFirewallPolicyManagedRuleOverrideRuleExclusion(%s)" % ", ".join(
            k + "=" + repr(v) for k, v in self._values.items()
        )


@jsii.data_type(
    jsii_type="@cdktf/provider-azurerm.FrontdoorFirewallPolicyTimeouts",
    jsii_struct_bases=[],
    name_mapping={
        "create": "create",
        "delete": "delete",
        "read": "read",
        "update": "update",
    },
)
class FrontdoorFirewallPolicyTimeouts:
    def __init__(
        self,
        *,
        create: typing.Optional[builtins.str] = None,
        delete: typing.Optional[builtins.str] = None,
        read: typing.Optional[builtins.str] = None,
        update: typing.Optional[builtins.str] = None,
    ) -> None:
        """
        :param create: 
        :param delete: 
        :param read: 
        :param update: 
        """
        self._values: typing.Dict[str, typing.Any] = {}
        if create is not None:
            self._values["create"] = create
        if delete is not None:
            self._values["delete"] = delete
        if read is not None:
            self._values["read"] = read
        if update is not None:
            self._values["update"] = update

    @builtins.property
    def create(self) -> typing.Optional[builtins.str]:
        result = self._values.get("create")
        return result

    @builtins.property
    def delete(self) -> typing.Optional[builtins.str]:
        result = self._values.get("delete")
        return result

    @builtins.property
    def read(self) -> typing.Optional[builtins.str]:
        result = self._values.get("read")
        return result

    @builtins.property
    def update(self) -> typing.Optional[builtins.str]:
        result = self._values.get("update")
        return result

    def __eq__(self, rhs: typing.Any) -> builtins.bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs: typing.Any) -> builtins.bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return "FrontdoorFirewallPolicyTimeouts(%s)" % ", ".join(
            k + "=" + repr(v) for k, v in self._values.items()
        )


@jsii.data_type(
    jsii_type="@cdktf/provider-azurerm.FrontdoorFrontendEndpoint",
    jsii_struct_bases=[],
    name_mapping={
        "custom_https_provisioning_enabled": "customHttpsProvisioningEnabled",
        "host_name": "hostName",
        "name": "name",
        "custom_https_configuration": "customHttpsConfiguration",
        "session_affinity_enabled": "sessionAffinityEnabled",
        "session_affinity_ttl_seconds": "sessionAffinityTtlSeconds",
        "web_application_firewall_policy_link_id": "webApplicationFirewallPolicyLinkId",
    },
)
class FrontdoorFrontendEndpoint:
    def __init__(
        self,
        *,
        custom_https_provisioning_enabled: builtins.bool,
        host_name: builtins.str,
        name: builtins.str,
        custom_https_configuration: typing.Optional[typing.List["FrontdoorFrontendEndpointCustomHttpsConfiguration"]] = None,
        session_affinity_enabled: typing.Optional[builtins.bool] = None,
        session_affinity_ttl_seconds: typing.Optional[jsii.Number] = None,
        web_application_firewall_policy_link_id: typing.Optional[builtins.str] = None,
    ) -> None:
        """
        :param custom_https_provisioning_enabled: 
        :param host_name: 
        :param name: 
        :param custom_https_configuration: custom_https_configuration block.
        :param session_affinity_enabled: 
        :param session_affinity_ttl_seconds: 
        :param web_application_firewall_policy_link_id: 
        """
        self._values: typing.Dict[str, typing.Any] = {
            "custom_https_provisioning_enabled": custom_https_provisioning_enabled,
            "host_name": host_name,
            "name": name,
        }
        if custom_https_configuration is not None:
            self._values["custom_https_configuration"] = custom_https_configuration
        if session_affinity_enabled is not None:
            self._values["session_affinity_enabled"] = session_affinity_enabled
        if session_affinity_ttl_seconds is not None:
            self._values["session_affinity_ttl_seconds"] = session_affinity_ttl_seconds
        if web_application_firewall_policy_link_id is not None:
            self._values["web_application_firewall_policy_link_id"] = web_application_firewall_policy_link_id

    @builtins.property
    def custom_https_provisioning_enabled(self) -> builtins.bool:
        result = self._values.get("custom_https_provisioning_enabled")
        assert result is not None, "Required property 'custom_https_provisioning_enabled' is missing"
        return result

    @builtins.property
    def host_name(self) -> builtins.str:
        result = self._values.get("host_name")
        assert result is not None, "Required property 'host_name' is missing"
        return result

    @builtins.property
    def name(self) -> builtins.str:
        result = self._values.get("name")
        assert result is not None, "Required property 'name' is missing"
        return result

    @builtins.property
    def custom_https_configuration(
        self,
    ) -> typing.Optional[typing.List["FrontdoorFrontendEndpointCustomHttpsConfiguration"]]:
        """custom_https_configuration block."""
        result = self._values.get("custom_https_configuration")
        return result

    @builtins.property
    def session_affinity_enabled(self) -> typing.Optional[builtins.bool]:
        result = self._values.get("session_affinity_enabled")
        return result

    @builtins.property
    def session_affinity_ttl_seconds(self) -> typing.Optional[jsii.Number]:
        result = self._values.get("session_affinity_ttl_seconds")
        return result

    @builtins.property
    def web_application_firewall_policy_link_id(self) -> typing.Optional[builtins.str]:
        result = self._values.get("web_application_firewall_policy_link_id")
        return result

    def __eq__(self, rhs: typing.Any) -> builtins.bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs: typing.Any) -> builtins.bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return "FrontdoorFrontendEndpoint(%s)" % ", ".join(
            k + "=" + repr(v) for k, v in self._values.items()
        )


@jsii.data_type(
    jsii_type="@cdktf/provider-azurerm.FrontdoorFrontendEndpointCustomHttpsConfiguration",
    jsii_struct_bases=[],
    name_mapping={
        "azure_key_vault_certificate_secret_name": "azureKeyVaultCertificateSecretName",
        "azure_key_vault_certificate_secret_version": "azureKeyVaultCertificateSecretVersion",
        "azure_key_vault_certificate_vault_id": "azureKeyVaultCertificateVaultId",
        "certificate_source": "certificateSource",
    },
)
class FrontdoorFrontendEndpointCustomHttpsConfiguration:
    def __init__(
        self,
        *,
        azure_key_vault_certificate_secret_name: typing.Optional[builtins.str] = None,
        azure_key_vault_certificate_secret_version: typing.Optional[builtins.str] = None,
        azure_key_vault_certificate_vault_id: typing.Optional[builtins.str] = None,
        certificate_source: typing.Optional[builtins.str] = None,
    ) -> None:
        """
        :param azure_key_vault_certificate_secret_name: 
        :param azure_key_vault_certificate_secret_version: 
        :param azure_key_vault_certificate_vault_id: 
        :param certificate_source: 
        """
        self._values: typing.Dict[str, typing.Any] = {}
        if azure_key_vault_certificate_secret_name is not None:
            self._values["azure_key_vault_certificate_secret_name"] = azure_key_vault_certificate_secret_name
        if azure_key_vault_certificate_secret_version is not None:
            self._values["azure_key_vault_certificate_secret_version"] = azure_key_vault_certificate_secret_version
        if azure_key_vault_certificate_vault_id is not None:
            self._values["azure_key_vault_certificate_vault_id"] = azure_key_vault_certificate_vault_id
        if certificate_source is not None:
            self._values["certificate_source"] = certificate_source

    @builtins.property
    def azure_key_vault_certificate_secret_name(self) -> typing.Optional[builtins.str]:
        result = self._values.get("azure_key_vault_certificate_secret_name")
        return result

    @builtins.property
    def azure_key_vault_certificate_secret_version(
        self,
    ) -> typing.Optional[builtins.str]:
        result = self._values.get("azure_key_vault_certificate_secret_version")
        return result

    @builtins.property
    def azure_key_vault_certificate_vault_id(self) -> typing.Optional[builtins.str]:
        result = self._values.get("azure_key_vault_certificate_vault_id")
        return result

    @builtins.property
    def certificate_source(self) -> typing.Optional[builtins.str]:
        result = self._values.get("certificate_source")
        return result

    def __eq__(self, rhs: typing.Any) -> builtins.bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs: typing.Any) -> builtins.bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return "FrontdoorFrontendEndpointCustomHttpsConfiguration(%s)" % ", ".join(
            k + "=" + repr(v) for k, v in self._values.items()
        )


@jsii.data_type(
    jsii_type="@cdktf/provider-azurerm.FrontdoorRoutingRule",
    jsii_struct_bases=[],
    name_mapping={
        "accepted_protocols": "acceptedProtocols",
        "frontend_endpoints": "frontendEndpoints",
        "name": "name",
        "patterns_to_match": "patternsToMatch",
        "enabled": "enabled",
        "forwarding_configuration": "forwardingConfiguration",
        "redirect_configuration": "redirectConfiguration",
    },
)
class FrontdoorRoutingRule:
    def __init__(
        self,
        *,
        accepted_protocols: typing.List[builtins.str],
        frontend_endpoints: typing.List[builtins.str],
        name: builtins.str,
        patterns_to_match: typing.List[builtins.str],
        enabled: typing.Optional[builtins.bool] = None,
        forwarding_configuration: typing.Optional[typing.List["FrontdoorRoutingRuleForwardingConfiguration"]] = None,
        redirect_configuration: typing.Optional[typing.List["FrontdoorRoutingRuleRedirectConfiguration"]] = None,
    ) -> None:
        """
        :param accepted_protocols: 
        :param frontend_endpoints: 
        :param name: 
        :param patterns_to_match: 
        :param enabled: 
        :param forwarding_configuration: forwarding_configuration block.
        :param redirect_configuration: redirect_configuration block.
        """
        self._values: typing.Dict[str, typing.Any] = {
            "accepted_protocols": accepted_protocols,
            "frontend_endpoints": frontend_endpoints,
            "name": name,
            "patterns_to_match": patterns_to_match,
        }
        if enabled is not None:
            self._values["enabled"] = enabled
        if forwarding_configuration is not None:
            self._values["forwarding_configuration"] = forwarding_configuration
        if redirect_configuration is not None:
            self._values["redirect_configuration"] = redirect_configuration

    @builtins.property
    def accepted_protocols(self) -> typing.List[builtins.str]:
        result = self._values.get("accepted_protocols")
        assert result is not None, "Required property 'accepted_protocols' is missing"
        return result

    @builtins.property
    def frontend_endpoints(self) -> typing.List[builtins.str]:
        result = self._values.get("frontend_endpoints")
        assert result is not None, "Required property 'frontend_endpoints' is missing"
        return result

    @builtins.property
    def name(self) -> builtins.str:
        result = self._values.get("name")
        assert result is not None, "Required property 'name' is missing"
        return result

    @builtins.property
    def patterns_to_match(self) -> typing.List[builtins.str]:
        result = self._values.get("patterns_to_match")
        assert result is not None, "Required property 'patterns_to_match' is missing"
        return result

    @builtins.property
    def enabled(self) -> typing.Optional[builtins.bool]:
        result = self._values.get("enabled")
        return result

    @builtins.property
    def forwarding_configuration(
        self,
    ) -> typing.Optional[typing.List["FrontdoorRoutingRuleForwardingConfiguration"]]:
        """forwarding_configuration block."""
        result = self._values.get("forwarding_configuration")
        return result

    @builtins.property
    def redirect_configuration(
        self,
    ) -> typing.Optional[typing.List["FrontdoorRoutingRuleRedirectConfiguration"]]:
        """redirect_configuration block."""
        result = self._values.get("redirect_configuration")
        return result

    def __eq__(self, rhs: typing.Any) -> builtins.bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs: typing.Any) -> builtins.bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return "FrontdoorRoutingRule(%s)" % ", ".join(
            k + "=" + repr(v) for k, v in self._values.items()
        )


@jsii.data_type(
    jsii_type="@cdktf/provider-azurerm.FrontdoorRoutingRuleForwardingConfiguration",
    jsii_struct_bases=[],
    name_mapping={
        "backend_pool_name": "backendPoolName",
        "cache_enabled": "cacheEnabled",
        "cache_query_parameter_strip_directive": "cacheQueryParameterStripDirective",
        "cache_use_dynamic_compression": "cacheUseDynamicCompression",
        "custom_forwarding_path": "customForwardingPath",
        "forwarding_protocol": "forwardingProtocol",
    },
)
class FrontdoorRoutingRuleForwardingConfiguration:
    def __init__(
        self,
        *,
        backend_pool_name: builtins.str,
        cache_enabled: typing.Optional[builtins.bool] = None,
        cache_query_parameter_strip_directive: typing.Optional[builtins.str] = None,
        cache_use_dynamic_compression: typing.Optional[builtins.bool] = None,
        custom_forwarding_path: typing.Optional[builtins.str] = None,
        forwarding_protocol: typing.Optional[builtins.str] = None,
    ) -> None:
        """
        :param backend_pool_name: 
        :param cache_enabled: 
        :param cache_query_parameter_strip_directive: 
        :param cache_use_dynamic_compression: 
        :param custom_forwarding_path: 
        :param forwarding_protocol: 
        """
        self._values: typing.Dict[str, typing.Any] = {
            "backend_pool_name": backend_pool_name,
        }
        if cache_enabled is not None:
            self._values["cache_enabled"] = cache_enabled
        if cache_query_parameter_strip_directive is not None:
            self._values["cache_query_parameter_strip_directive"] = cache_query_parameter_strip_directive
        if cache_use_dynamic_compression is not None:
            self._values["cache_use_dynamic_compression"] = cache_use_dynamic_compression
        if custom_forwarding_path is not None:
            self._values["custom_forwarding_path"] = custom_forwarding_path
        if forwarding_protocol is not None:
            self._values["forwarding_protocol"] = forwarding_protocol

    @builtins.property
    def backend_pool_name(self) -> builtins.str:
        result = self._values.get("backend_pool_name")
        assert result is not None, "Required property 'backend_pool_name' is missing"
        return result

    @builtins.property
    def cache_enabled(self) -> typing.Optional[builtins.bool]:
        result = self._values.get("cache_enabled")
        return result

    @builtins.property
    def cache_query_parameter_strip_directive(self) -> typing.Optional[builtins.str]:
        result = self._values.get("cache_query_parameter_strip_directive")
        return result

    @builtins.property
    def cache_use_dynamic_compression(self) -> typing.Optional[builtins.bool]:
        result = self._values.get("cache_use_dynamic_compression")
        return result

    @builtins.property
    def custom_forwarding_path(self) -> typing.Optional[builtins.str]:
        result = self._values.get("custom_forwarding_path")
        return result

    @builtins.property
    def forwarding_protocol(self) -> typing.Optional[builtins.str]:
        result = self._values.get("forwarding_protocol")
        return result

    def __eq__(self, rhs: typing.Any) -> builtins.bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs: typing.Any) -> builtins.bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return "FrontdoorRoutingRuleForwardingConfiguration(%s)" % ", ".join(
            k + "=" + repr(v) for k, v in self._values.items()
        )


@jsii.data_type(
    jsii_type="@cdktf/provider-azurerm.FrontdoorRoutingRuleRedirectConfiguration",
    jsii_struct_bases=[],
    name_mapping={
        "redirect_protocol": "redirectProtocol",
        "redirect_type": "redirectType",
        "custom_fragment": "customFragment",
        "custom_host": "customHost",
        "custom_path": "customPath",
        "custom_query_string": "customQueryString",
    },
)
class FrontdoorRoutingRuleRedirectConfiguration:
    def __init__(
        self,
        *,
        redirect_protocol: builtins.str,
        redirect_type: builtins.str,
        custom_fragment: typing.Optional[builtins.str] = None,
        custom_host: typing.Optional[builtins.str] = None,
        custom_path: typing.Optional[builtins.str] = None,
        custom_query_string: typing.Optional[builtins.str] = None,
    ) -> None:
        """
        :param redirect_protocol: 
        :param redirect_type: 
        :param custom_fragment: 
        :param custom_host: 
        :param custom_path: 
        :param custom_query_string: 
        """
        self._values: typing.Dict[str, typing.Any] = {
            "redirect_protocol": redirect_protocol,
            "redirect_type": redirect_type,
        }
        if custom_fragment is not None:
            self._values["custom_fragment"] = custom_fragment
        if custom_host is not None:
            self._values["custom_host"] = custom_host
        if custom_path is not None:
            self._values["custom_path"] = custom_path
        if custom_query_string is not None:
            self._values["custom_query_string"] = custom_query_string

    @builtins.property
    def redirect_protocol(self) -> builtins.str:
        result = self._values.get("redirect_protocol")
        assert result is not None, "Required property 'redirect_protocol' is missing"
        return result

    @builtins.property
    def redirect_type(self) -> builtins.str:
        result = self._values.get("redirect_type")
        assert result is not None, "Required property 'redirect_type' is missing"
        return result

    @builtins.property
    def custom_fragment(self) -> typing.Optional[builtins.str]:
        result = self._values.get("custom_fragment")
        return result

    @builtins.property
    def custom_host(self) -> typing.Optional[builtins.str]:
        result = self._values.get("custom_host")
        return result

    @builtins.property
    def custom_path(self) -> typing.Optional[builtins.str]:
        result = self._values.get("custom_path")
        return result

    @builtins.property
    def custom_query_string(self) -> typing.Optional[builtins.str]:
        result = self._values.get("custom_query_string")
        return result

    def __eq__(self, rhs: typing.Any) -> builtins.bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs: typing.Any) -> builtins.bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return "FrontdoorRoutingRuleRedirectConfiguration(%s)" % ", ".join(
            k + "=" + repr(v) for k, v in self._values.items()
        )


@jsii.data_type(
    jsii_type="@cdktf/provider-azurerm.FrontdoorTimeouts",
    jsii_struct_bases=[],
    name_mapping={
        "create": "create",
        "delete": "delete",
        "read": "read",
        "update": "update",
    },
)
class FrontdoorTimeouts:
    def __init__(
        self,
        *,
        create: typing.Optional[builtins.str] = None,
        delete: typing.Optional[builtins.str] = None,
        read: typing.Optional[builtins.str] = None,
        update: typing.Optional[builtins.str] = None,
    ) -> None:
        """
        :param create: 
        :param delete: 
        :param read: 
        :param update: 
        """
        self._values: typing.Dict[str, typing.Any] = {}
        if create is not None:
            self._values["create"] = create
        if delete is not None:
            self._values["delete"] = delete
        if read is not None:
            self._values["read"] = read
        if update is not None:
            self._values["update"] = update

    @builtins.property
    def create(self) -> typing.Optional[builtins.str]:
        result = self._values.get("create")
        return result

    @builtins.property
    def delete(self) -> typing.Optional[builtins.str]:
        result = self._values.get("delete")
        return result

    @builtins.property
    def read(self) -> typing.Optional[builtins.str]:
        result = self._values.get("read")
        return result

    @builtins.property
    def update(self) -> typing.Optional[builtins.str]:
        result = self._values.get("update")
        return result

    def __eq__(self, rhs: typing.Any) -> builtins.bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs: typing.Any) -> builtins.bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return "FrontdoorTimeouts(%s)" % ", ".join(
            k + "=" + repr(v) for k, v in self._values.items()
        )


class FunctionApp(
    cdktf.TerraformResource,
    metaclass=jsii.JSIIMeta,
    jsii_type="@cdktf/provider-azurerm.FunctionApp",
):
    def __init__(
        self,
        scope: constructs.Construct,
        id: builtins.str,
        *,
        app_service_plan_id: builtins.str,
        location: builtins.str,
        name: builtins.str,
        resource_group_name: builtins.str,
        storage_connection_string: builtins.str,
        app_settings: typing.Optional[typing.Mapping[builtins.str, builtins.str]] = None,
        auth_settings: typing.Optional[typing.List["FunctionAppAuthSettings"]] = None,
        client_affinity_enabled: typing.Optional[builtins.bool] = None,
        connection_string: typing.Optional[typing.List["FunctionAppConnectionString"]] = None,
        enable_builtin_logging: typing.Optional[builtins.bool] = None,
        enabled: typing.Optional[builtins.bool] = None,
        https_only: typing.Optional[builtins.bool] = None,
        identity: typing.Optional[typing.List["FunctionAppIdentity"]] = None,
        site_config: typing.Optional[typing.List["FunctionAppSiteConfig"]] = None,
        tags: typing.Optional[typing.Mapping[builtins.str, builtins.str]] = None,
        timeouts: typing.Optional["FunctionAppTimeouts"] = None,
        version: typing.Optional[builtins.str] = None,
        count: typing.Optional[jsii.Number] = None,
        depends_on: typing.Optional[typing.List[cdktf.TerraformResource]] = None,
        lifecycle: typing.Optional[cdktf.TerraformResourceLifecycle] = None,
        provider: typing.Optional[cdktf.TerraformProvider] = None,
    ) -> None:
        """
        :param scope: -
        :param id: -
        :param app_service_plan_id: 
        :param location: 
        :param name: 
        :param resource_group_name: 
        :param storage_connection_string: 
        :param app_settings: 
        :param auth_settings: auth_settings block.
        :param client_affinity_enabled: 
        :param connection_string: connection_string block.
        :param enable_builtin_logging: 
        :param enabled: 
        :param https_only: 
        :param identity: identity block.
        :param site_config: site_config block.
        :param tags: 
        :param timeouts: timeouts block.
        :param version: 
        :param count: 
        :param depends_on: 
        :param lifecycle: 
        :param provider: 
        """
        config = FunctionAppConfig(
            app_service_plan_id=app_service_plan_id,
            location=location,
            name=name,
            resource_group_name=resource_group_name,
            storage_connection_string=storage_connection_string,
            app_settings=app_settings,
            auth_settings=auth_settings,
            client_affinity_enabled=client_affinity_enabled,
            connection_string=connection_string,
            enable_builtin_logging=enable_builtin_logging,
            enabled=enabled,
            https_only=https_only,
            identity=identity,
            site_config=site_config,
            tags=tags,
            timeouts=timeouts,
            version=version,
            count=count,
            depends_on=depends_on,
            lifecycle=lifecycle,
            provider=provider,
        )

        jsii.create(FunctionApp, self, [scope, id, config])

    @jsii.member(jsii_name="siteCredential")
    def site_credential(self, index: builtins.str) -> "FunctionAppSiteCredential":
        """
        :param index: -
        """
        return jsii.invoke(self, "siteCredential", [index])

    @jsii.member(jsii_name="synthesizeAttributes")
    def _synthesize_attributes(self) -> typing.Mapping[builtins.str, typing.Any]:
        return jsii.invoke(self, "synthesizeAttributes", [])

    @builtins.property # type: ignore
    @jsii.member(jsii_name="defaultHostname")
    def default_hostname(self) -> builtins.str:
        return jsii.get(self, "defaultHostname")

    @builtins.property # type: ignore
    @jsii.member(jsii_name="kind")
    def kind(self) -> builtins.str:
        return jsii.get(self, "kind")

    @builtins.property # type: ignore
    @jsii.member(jsii_name="outboundIpAddresses")
    def outbound_ip_addresses(self) -> builtins.str:
        return jsii.get(self, "outboundIpAddresses")

    @builtins.property # type: ignore
    @jsii.member(jsii_name="possibleOutboundIpAddresses")
    def possible_outbound_ip_addresses(self) -> builtins.str:
        return jsii.get(self, "possibleOutboundIpAddresses")

    @builtins.property # type: ignore
    @jsii.member(jsii_name="appServicePlanId")
    def app_service_plan_id(self) -> builtins.str:
        return jsii.get(self, "appServicePlanId")

    @app_service_plan_id.setter # type: ignore
    def app_service_plan_id(self, value: builtins.str) -> None:
        jsii.set(self, "appServicePlanId", value)

    @builtins.property # type: ignore
    @jsii.member(jsii_name="location")
    def location(self) -> builtins.str:
        return jsii.get(self, "location")

    @location.setter # type: ignore
    def location(self, value: builtins.str) -> None:
        jsii.set(self, "location", value)

    @builtins.property # type: ignore
    @jsii.member(jsii_name="name")
    def name(self) -> builtins.str:
        return jsii.get(self, "name")

    @name.setter # type: ignore
    def name(self, value: builtins.str) -> None:
        jsii.set(self, "name", value)

    @builtins.property # type: ignore
    @jsii.member(jsii_name="resourceGroupName")
    def resource_group_name(self) -> builtins.str:
        return jsii.get(self, "resourceGroupName")

    @resource_group_name.setter # type: ignore
    def resource_group_name(self, value: builtins.str) -> None:
        jsii.set(self, "resourceGroupName", value)

    @builtins.property # type: ignore
    @jsii.member(jsii_name="storageConnectionString")
    def storage_connection_string(self) -> builtins.str:
        return jsii.get(self, "storageConnectionString")

    @storage_connection_string.setter # type: ignore
    def storage_connection_string(self, value: builtins.str) -> None:
        jsii.set(self, "storageConnectionString", value)

    @builtins.property # type: ignore
    @jsii.member(jsii_name="appSettings")
    def app_settings(
        self,
    ) -> typing.Optional[typing.Mapping[builtins.str, builtins.str]]:
        return jsii.get(self, "appSettings")

    @app_settings.setter # type: ignore
    def app_settings(
        self,
        value: typing.Optional[typing.Mapping[builtins.str, builtins.str]],
    ) -> None:
        jsii.set(self, "appSettings", value)

    @builtins.property # type: ignore
    @jsii.member(jsii_name="authSettings")
    def auth_settings(self) -> typing.Optional[typing.List["FunctionAppAuthSettings"]]:
        return jsii.get(self, "authSettings")

    @auth_settings.setter # type: ignore
    def auth_settings(
        self,
        value: typing.Optional[typing.List["FunctionAppAuthSettings"]],
    ) -> None:
        jsii.set(self, "authSettings", value)

    @builtins.property # type: ignore
    @jsii.member(jsii_name="clientAffinityEnabled")
    def client_affinity_enabled(self) -> typing.Optional[builtins.bool]:
        return jsii.get(self, "clientAffinityEnabled")

    @client_affinity_enabled.setter # type: ignore
    def client_affinity_enabled(self, value: typing.Optional[builtins.bool]) -> None:
        jsii.set(self, "clientAffinityEnabled", value)

    @builtins.property # type: ignore
    @jsii.member(jsii_name="connectionString")
    def connection_string(
        self,
    ) -> typing.Optional[typing.List["FunctionAppConnectionString"]]:
        return jsii.get(self, "connectionString")

    @connection_string.setter # type: ignore
    def connection_string(
        self,
        value: typing.Optional[typing.List["FunctionAppConnectionString"]],
    ) -> None:
        jsii.set(self, "connectionString", value)

    @builtins.property # type: ignore
    @jsii.member(jsii_name="enableBuiltinLogging")
    def enable_builtin_logging(self) -> typing.Optional[builtins.bool]:
        return jsii.get(self, "enableBuiltinLogging")

    @enable_builtin_logging.setter # type: ignore
    def enable_builtin_logging(self, value: typing.Optional[builtins.bool]) -> None:
        jsii.set(self, "enableBuiltinLogging", value)

    @builtins.property # type: ignore
    @jsii.member(jsii_name="enabled")
    def enabled(self) -> typing.Optional[builtins.bool]:
        return jsii.get(self, "enabled")

    @enabled.setter # type: ignore
    def enabled(self, value: typing.Optional[builtins.bool]) -> None:
        jsii.set(self, "enabled", value)

    @builtins.property # type: ignore
    @jsii.member(jsii_name="httpsOnly")
    def https_only(self) -> typing.Optional[builtins.bool]:
        return jsii.get(self, "httpsOnly")

    @https_only.setter # type: ignore
    def https_only(self, value: typing.Optional[builtins.bool]) -> None:
        jsii.set(self, "httpsOnly", value)

    @builtins.property # type: ignore
    @jsii.member(jsii_name="id")
    def id(self) -> typing.Optional[builtins.str]:
        return jsii.get(self, "id")

    @id.setter # type: ignore
    def id(self, value: typing.Optional[builtins.str]) -> None:
        jsii.set(self, "id", value)

    @builtins.property # type: ignore
    @jsii.member(jsii_name="identity")
    def identity(self) -> typing.Optional[typing.List["FunctionAppIdentity"]]:
        return jsii.get(self, "identity")

    @identity.setter # type: ignore
    def identity(
        self,
        value: typing.Optional[typing.List["FunctionAppIdentity"]],
    ) -> None:
        jsii.set(self, "identity", value)

    @builtins.property # type: ignore
    @jsii.member(jsii_name="siteConfig")
    def site_config(self) -> typing.Optional[typing.List["FunctionAppSiteConfig"]]:
        return jsii.get(self, "siteConfig")

    @site_config.setter # type: ignore
    def site_config(
        self,
        value: typing.Optional[typing.List["FunctionAppSiteConfig"]],
    ) -> None:
        jsii.set(self, "siteConfig", value)

    @builtins.property # type: ignore
    @jsii.member(jsii_name="tags")
    def tags(self) -> typing.Optional[typing.Mapping[builtins.str, builtins.str]]:
        return jsii.get(self, "tags")

    @tags.setter # type: ignore
    def tags(
        self,
        value: typing.Optional[typing.Mapping[builtins.str, builtins.str]],
    ) -> None:
        jsii.set(self, "tags", value)

    @builtins.property # type: ignore
    @jsii.member(jsii_name="timeouts")
    def timeouts(self) -> typing.Optional["FunctionAppTimeouts"]:
        return jsii.get(self, "timeouts")

    @timeouts.setter # type: ignore
    def timeouts(self, value: typing.Optional["FunctionAppTimeouts"]) -> None:
        jsii.set(self, "timeouts", value)

    @builtins.property # type: ignore
    @jsii.member(jsii_name="version")
    def version(self) -> typing.Optional[builtins.str]:
        return jsii.get(self, "version")

    @version.setter # type: ignore
    def version(self, value: typing.Optional[builtins.str]) -> None:
        jsii.set(self, "version", value)


@jsii.data_type(
    jsii_type="@cdktf/provider-azurerm.FunctionAppAuthSettings",
    jsii_struct_bases=[],
    name_mapping={
        "enabled": "enabled",
        "active_directory": "activeDirectory",
        "additional_login_params": "additionalLoginParams",
        "allowed_external_redirect_urls": "allowedExternalRedirectUrls",
        "default_provider": "defaultProvider",
        "facebook": "facebook",
        "google": "google",
        "issuer": "issuer",
        "microsoft": "microsoft",
        "runtime_version": "runtimeVersion",
        "token_refresh_extension_hours": "tokenRefreshExtensionHours",
        "token_store_enabled": "tokenStoreEnabled",
        "twitter": "twitter",
        "unauthenticated_client_action": "unauthenticatedClientAction",
    },
)
class FunctionAppAuthSettings:
    def __init__(
        self,
        *,
        enabled: builtins.bool,
        active_directory: typing.Optional[typing.List["FunctionAppAuthSettingsActiveDirectory"]] = None,
        additional_login_params: typing.Optional[typing.Mapping[builtins.str, builtins.str]] = None,
        allowed_external_redirect_urls: typing.Optional[typing.List[builtins.str]] = None,
        default_provider: typing.Optional[builtins.str] = None,
        facebook: typing.Optional[typing.List["FunctionAppAuthSettingsFacebook"]] = None,
        google: typing.Optional[typing.List["FunctionAppAuthSettingsGoogle"]] = None,
        issuer: typing.Optional[builtins.str] = None,
        microsoft: typing.Optional[typing.List["FunctionAppAuthSettingsMicrosoft"]] = None,
        runtime_version: typing.Optional[builtins.str] = None,
        token_refresh_extension_hours: typing.Optional[jsii.Number] = None,
        token_store_enabled: typing.Optional[builtins.bool] = None,
        twitter: typing.Optional[typing.List["FunctionAppAuthSettingsTwitter"]] = None,
        unauthenticated_client_action: typing.Optional[builtins.str] = None,
    ) -> None:
        """
        :param enabled: 
        :param active_directory: active_directory block.
        :param additional_login_params: 
        :param allowed_external_redirect_urls: 
        :param default_provider: 
        :param facebook: facebook block.
        :param google: google block.
        :param issuer: 
        :param microsoft: microsoft block.
        :param runtime_version: 
        :param token_refresh_extension_hours: 
        :param token_store_enabled: 
        :param twitter: twitter block.
        :param unauthenticated_client_action: 
        """
        self._values: typing.Dict[str, typing.Any] = {
            "enabled": enabled,
        }
        if active_directory is not None:
            self._values["active_directory"] = active_directory
        if additional_login_params is not None:
            self._values["additional_login_params"] = additional_login_params
        if allowed_external_redirect_urls is not None:
            self._values["allowed_external_redirect_urls"] = allowed_external_redirect_urls
        if default_provider is not None:
            self._values["default_provider"] = default_provider
        if facebook is not None:
            self._values["facebook"] = facebook
        if google is not None:
            self._values["google"] = google
        if issuer is not None:
            self._values["issuer"] = issuer
        if microsoft is not None:
            self._values["microsoft"] = microsoft
        if runtime_version is not None:
            self._values["runtime_version"] = runtime_version
        if token_refresh_extension_hours is not None:
            self._values["token_refresh_extension_hours"] = token_refresh_extension_hours
        if token_store_enabled is not None:
            self._values["token_store_enabled"] = token_store_enabled
        if twitter is not None:
            self._values["twitter"] = twitter
        if unauthenticated_client_action is not None:
            self._values["unauthenticated_client_action"] = unauthenticated_client_action

    @builtins.property
    def enabled(self) -> builtins.bool:
        result = self._values.get("enabled")
        assert result is not None, "Required property 'enabled' is missing"
        return result

    @builtins.property
    def active_directory(
        self,
    ) -> typing.Optional[typing.List["FunctionAppAuthSettingsActiveDirectory"]]:
        """active_directory block."""
        result = self._values.get("active_directory")
        return result

    @builtins.property
    def additional_login_params(
        self,
    ) -> typing.Optional[typing.Mapping[builtins.str, builtins.str]]:
        result = self._values.get("additional_login_params")
        return result

    @builtins.property
    def allowed_external_redirect_urls(
        self,
    ) -> typing.Optional[typing.List[builtins.str]]:
        result = self._values.get("allowed_external_redirect_urls")
        return result

    @builtins.property
    def default_provider(self) -> typing.Optional[builtins.str]:
        result = self._values.get("default_provider")
        return result

    @builtins.property
    def facebook(
        self,
    ) -> typing.Optional[typing.List["FunctionAppAuthSettingsFacebook"]]:
        """facebook block."""
        result = self._values.get("facebook")
        return result

    @builtins.property
    def google(self) -> typing.Optional[typing.List["FunctionAppAuthSettingsGoogle"]]:
        """google block."""
        result = self._values.get("google")
        return result

    @builtins.property
    def issuer(self) -> typing.Optional[builtins.str]:
        result = self._values.get("issuer")
        return result

    @builtins.property
    def microsoft(
        self,
    ) -> typing.Optional[typing.List["FunctionAppAuthSettingsMicrosoft"]]:
        """microsoft block."""
        result = self._values.get("microsoft")
        return result

    @builtins.property
    def runtime_version(self) -> typing.Optional[builtins.str]:
        result = self._values.get("runtime_version")
        return result

    @builtins.property
    def token_refresh_extension_hours(self) -> typing.Optional[jsii.Number]:
        result = self._values.get("token_refresh_extension_hours")
        return result

    @builtins.property
    def token_store_enabled(self) -> typing.Optional[builtins.bool]:
        result = self._values.get("token_store_enabled")
        return result

    @builtins.property
    def twitter(self) -> typing.Optional[typing.List["FunctionAppAuthSettingsTwitter"]]:
        """twitter block."""
        result = self._values.get("twitter")
        return result

    @builtins.property
    def unauthenticated_client_action(self) -> typing.Optional[builtins.str]:
        result = self._values.get("unauthenticated_client_action")
        return result

    def __eq__(self, rhs: typing.Any) -> builtins.bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs: typing.Any) -> builtins.bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return "FunctionAppAuthSettings(%s)" % ", ".join(
            k + "=" + repr(v) for k, v in self._values.items()
        )


@jsii.data_type(
    jsii_type="@cdktf/provider-azurerm.FunctionAppAuthSettingsActiveDirectory",
    jsii_struct_bases=[],
    name_mapping={
        "client_id": "clientId",
        "allowed_audiences": "allowedAudiences",
        "client_secret": "clientSecret",
    },
)
class FunctionAppAuthSettingsActiveDirectory:
    def __init__(
        self,
        *,
        client_id: builtins.str,
        allowed_audiences: typing.Optional[typing.List[builtins.str]] = None,
        client_secret: typing.Optional[builtins.str] = None,
    ) -> None:
        """
        :param client_id: 
        :param allowed_audiences: 
        :param client_secret: 
        """
        self._values: typing.Dict[str, typing.Any] = {
            "client_id": client_id,
        }
        if allowed_audiences is not None:
            self._values["allowed_audiences"] = allowed_audiences
        if client_secret is not None:
            self._values["client_secret"] = client_secret

    @builtins.property
    def client_id(self) -> builtins.str:
        result = self._values.get("client_id")
        assert result is not None, "Required property 'client_id' is missing"
        return result

    @builtins.property
    def allowed_audiences(self) -> typing.Optional[typing.List[builtins.str]]:
        result = self._values.get("allowed_audiences")
        return result

    @builtins.property
    def client_secret(self) -> typing.Optional[builtins.str]:
        result = self._values.get("client_secret")
        return result

    def __eq__(self, rhs: typing.Any) -> builtins.bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs: typing.Any) -> builtins.bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return "FunctionAppAuthSettingsActiveDirectory(%s)" % ", ".join(
            k + "=" + repr(v) for k, v in self._values.items()
        )


@jsii.data_type(
    jsii_type="@cdktf/provider-azurerm.FunctionAppAuthSettingsFacebook",
    jsii_struct_bases=[],
    name_mapping={
        "app_id": "appId",
        "app_secret": "appSecret",
        "oauth_scopes": "oauthScopes",
    },
)
class FunctionAppAuthSettingsFacebook:
    def __init__(
        self,
        *,
        app_id: builtins.str,
        app_secret: builtins.str,
        oauth_scopes: typing.Optional[typing.List[builtins.str]] = None,
    ) -> None:
        """
        :param app_id: 
        :param app_secret: 
        :param oauth_scopes: 
        """
        self._values: typing.Dict[str, typing.Any] = {
            "app_id": app_id,
            "app_secret": app_secret,
        }
        if oauth_scopes is not None:
            self._values["oauth_scopes"] = oauth_scopes

    @builtins.property
    def app_id(self) -> builtins.str:
        result = self._values.get("app_id")
        assert result is not None, "Required property 'app_id' is missing"
        return result

    @builtins.property
    def app_secret(self) -> builtins.str:
        result = self._values.get("app_secret")
        assert result is not None, "Required property 'app_secret' is missing"
        return result

    @builtins.property
    def oauth_scopes(self) -> typing.Optional[typing.List[builtins.str]]:
        result = self._values.get("oauth_scopes")
        return result

    def __eq__(self, rhs: typing.Any) -> builtins.bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs: typing.Any) -> builtins.bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return "FunctionAppAuthSettingsFacebook(%s)" % ", ".join(
            k + "=" + repr(v) for k, v in self._values.items()
        )


@jsii.data_type(
    jsii_type="@cdktf/provider-azurerm.FunctionAppAuthSettingsGoogle",
    jsii_struct_bases=[],
    name_mapping={
        "client_id": "clientId",
        "client_secret": "clientSecret",
        "oauth_scopes": "oauthScopes",
    },
)
class FunctionAppAuthSettingsGoogle:
    def __init__(
        self,
        *,
        client_id: builtins.str,
        client_secret: builtins.str,
        oauth_scopes: typing.Optional[typing.List[builtins.str]] = None,
    ) -> None:
        """
        :param client_id: 
        :param client_secret: 
        :param oauth_scopes: 
        """
        self._values: typing.Dict[str, typing.Any] = {
            "client_id": client_id,
            "client_secret": client_secret,
        }
        if oauth_scopes is not None:
            self._values["oauth_scopes"] = oauth_scopes

    @builtins.property
    def client_id(self) -> builtins.str:
        result = self._values.get("client_id")
        assert result is not None, "Required property 'client_id' is missing"
        return result

    @builtins.property
    def client_secret(self) -> builtins.str:
        result = self._values.get("client_secret")
        assert result is not None, "Required property 'client_secret' is missing"
        return result

    @builtins.property
    def oauth_scopes(self) -> typing.Optional[typing.List[builtins.str]]:
        result = self._values.get("oauth_scopes")
        return result

    def __eq__(self, rhs: typing.Any) -> builtins.bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs: typing.Any) -> builtins.bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return "FunctionAppAuthSettingsGoogle(%s)" % ", ".join(
            k + "=" + repr(v) for k, v in self._values.items()
        )


@jsii.data_type(
    jsii_type="@cdktf/provider-azurerm.FunctionAppAuthSettingsMicrosoft",
    jsii_struct_bases=[],
    name_mapping={
        "client_id": "clientId",
        "client_secret": "clientSecret",
        "oauth_scopes": "oauthScopes",
    },
)
class FunctionAppAuthSettingsMicrosoft:
    def __init__(
        self,
        *,
        client_id: builtins.str,
        client_secret: builtins.str,
        oauth_scopes: typing.Optional[typing.List[builtins.str]] = None,
    ) -> None:
        """
        :param client_id: 
        :param client_secret: 
        :param oauth_scopes: 
        """
        self._values: typing.Dict[str, typing.Any] = {
            "client_id": client_id,
            "client_secret": client_secret,
        }
        if oauth_scopes is not None:
            self._values["oauth_scopes"] = oauth_scopes

    @builtins.property
    def client_id(self) -> builtins.str:
        result = self._values.get("client_id")
        assert result is not None, "Required property 'client_id' is missing"
        return result

    @builtins.property
    def client_secret(self) -> builtins.str:
        result = self._values.get("client_secret")
        assert result is not None, "Required property 'client_secret' is missing"
        return result

    @builtins.property
    def oauth_scopes(self) -> typing.Optional[typing.List[builtins.str]]:
        result = self._values.get("oauth_scopes")
        return result

    def __eq__(self, rhs: typing.Any) -> builtins.bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs: typing.Any) -> builtins.bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return "FunctionAppAuthSettingsMicrosoft(%s)" % ", ".join(
            k + "=" + repr(v) for k, v in self._values.items()
        )


@jsii.data_type(
    jsii_type="@cdktf/provider-azurerm.FunctionAppAuthSettingsTwitter",
    jsii_struct_bases=[],
    name_mapping={"consumer_key": "consumerKey", "consumer_secret": "consumerSecret"},
)
class FunctionAppAuthSettingsTwitter:
    def __init__(
        self,
        *,
        consumer_key: builtins.str,
        consumer_secret: builtins.str,
    ) -> None:
        """
        :param consumer_key: 
        :param consumer_secret: 
        """
        self._values: typing.Dict[str, typing.Any] = {
            "consumer_key": consumer_key,
            "consumer_secret": consumer_secret,
        }

    @builtins.property
    def consumer_key(self) -> builtins.str:
        result = self._values.get("consumer_key")
        assert result is not None, "Required property 'consumer_key' is missing"
        return result

    @builtins.property
    def consumer_secret(self) -> builtins.str:
        result = self._values.get("consumer_secret")
        assert result is not None, "Required property 'consumer_secret' is missing"
        return result

    def __eq__(self, rhs: typing.Any) -> builtins.bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs: typing.Any) -> builtins.bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return "FunctionAppAuthSettingsTwitter(%s)" % ", ".join(
            k + "=" + repr(v) for k, v in self._values.items()
        )


@jsii.data_type(
    jsii_type="@cdktf/provider-azurerm.FunctionAppConfig",
    jsii_struct_bases=[cdktf.TerraformMetaArguments],
    name_mapping={
        "count": "count",
        "depends_on": "dependsOn",
        "lifecycle": "lifecycle",
        "provider": "provider",
        "app_service_plan_id": "appServicePlanId",
        "location": "location",
        "name": "name",
        "resource_group_name": "resourceGroupName",
        "storage_connection_string": "storageConnectionString",
        "app_settings": "appSettings",
        "auth_settings": "authSettings",
        "client_affinity_enabled": "clientAffinityEnabled",
        "connection_string": "connectionString",
        "enable_builtin_logging": "enableBuiltinLogging",
        "enabled": "enabled",
        "https_only": "httpsOnly",
        "identity": "identity",
        "site_config": "siteConfig",
        "tags": "tags",
        "timeouts": "timeouts",
        "version": "version",
    },
)
class FunctionAppConfig(cdktf.TerraformMetaArguments):
    def __init__(
        self,
        *,
        count: typing.Optional[jsii.Number] = None,
        depends_on: typing.Optional[typing.List[cdktf.TerraformResource]] = None,
        lifecycle: typing.Optional[cdktf.TerraformResourceLifecycle] = None,
        provider: typing.Optional[cdktf.TerraformProvider] = None,
        app_service_plan_id: builtins.str,
        location: builtins.str,
        name: builtins.str,
        resource_group_name: builtins.str,
        storage_connection_string: builtins.str,
        app_settings: typing.Optional[typing.Mapping[builtins.str, builtins.str]] = None,
        auth_settings: typing.Optional[typing.List[FunctionAppAuthSettings]] = None,
        client_affinity_enabled: typing.Optional[builtins.bool] = None,
        connection_string: typing.Optional[typing.List["FunctionAppConnectionString"]] = None,
        enable_builtin_logging: typing.Optional[builtins.bool] = None,
        enabled: typing.Optional[builtins.bool] = None,
        https_only: typing.Optional[builtins.bool] = None,
        identity: typing.Optional[typing.List["FunctionAppIdentity"]] = None,
        site_config: typing.Optional[typing.List["FunctionAppSiteConfig"]] = None,
        tags: typing.Optional[typing.Mapping[builtins.str, builtins.str]] = None,
        timeouts: typing.Optional["FunctionAppTimeouts"] = None,
        version: typing.Optional[builtins.str] = None,
    ) -> None:
        """
        :param count: 
        :param depends_on: 
        :param lifecycle: 
        :param provider: 
        :param app_service_plan_id: 
        :param location: 
        :param name: 
        :param resource_group_name: 
        :param storage_connection_string: 
        :param app_settings: 
        :param auth_settings: auth_settings block.
        :param client_affinity_enabled: 
        :param connection_string: connection_string block.
        :param enable_builtin_logging: 
        :param enabled: 
        :param https_only: 
        :param identity: identity block.
        :param site_config: site_config block.
        :param tags: 
        :param timeouts: timeouts block.
        :param version: 
        """
        if isinstance(lifecycle, dict):
            lifecycle = cdktf.TerraformResourceLifecycle(**lifecycle)
        if isinstance(timeouts, dict):
            timeouts = FunctionAppTimeouts(**timeouts)
        self._values: typing.Dict[str, typing.Any] = {
            "app_service_plan_id": app_service_plan_id,
            "location": location,
            "name": name,
            "resource_group_name": resource_group_name,
            "storage_connection_string": storage_connection_string,
        }
        if count is not None:
            self._values["count"] = count
        if depends_on is not None:
            self._values["depends_on"] = depends_on
        if lifecycle is not None:
            self._values["lifecycle"] = lifecycle
        if provider is not None:
            self._values["provider"] = provider
        if app_settings is not None:
            self._values["app_settings"] = app_settings
        if auth_settings is not None:
            self._values["auth_settings"] = auth_settings
        if client_affinity_enabled is not None:
            self._values["client_affinity_enabled"] = client_affinity_enabled
        if connection_string is not None:
            self._values["connection_string"] = connection_string
        if enable_builtin_logging is not None:
            self._values["enable_builtin_logging"] = enable_builtin_logging
        if enabled is not None:
            self._values["enabled"] = enabled
        if https_only is not None:
            self._values["https_only"] = https_only
        if identity is not None:
            self._values["identity"] = identity
        if site_config is not None:
            self._values["site_config"] = site_config
        if tags is not None:
            self._values["tags"] = tags
        if timeouts is not None:
            self._values["timeouts"] = timeouts
        if version is not None:
            self._values["version"] = version

    @builtins.property
    def count(self) -> typing.Optional[jsii.Number]:
        """
        :stability: experimental
        """
        result = self._values.get("count")
        return result

    @builtins.property
    def depends_on(self) -> typing.Optional[typing.List[cdktf.TerraformResource]]:
        """
        :stability: experimental
        """
        result = self._values.get("depends_on")
        return result

    @builtins.property
    def lifecycle(self) -> typing.Optional[cdktf.TerraformResourceLifecycle]:
        """
        :stability: experimental
        """
        result = self._values.get("lifecycle")
        return result

    @builtins.property
    def provider(self) -> typing.Optional[cdktf.TerraformProvider]:
        """
        :stability: experimental
        """
        result = self._values.get("provider")
        return result

    @builtins.property
    def app_service_plan_id(self) -> builtins.str:
        result = self._values.get("app_service_plan_id")
        assert result is not None, "Required property 'app_service_plan_id' is missing"
        return result

    @builtins.property
    def location(self) -> builtins.str:
        result = self._values.get("location")
        assert result is not None, "Required property 'location' is missing"
        return result

    @builtins.property
    def name(self) -> builtins.str:
        result = self._values.get("name")
        assert result is not None, "Required property 'name' is missing"
        return result

    @builtins.property
    def resource_group_name(self) -> builtins.str:
        result = self._values.get("resource_group_name")
        assert result is not None, "Required property 'resource_group_name' is missing"
        return result

    @builtins.property
    def storage_connection_string(self) -> builtins.str:
        result = self._values.get("storage_connection_string")
        assert result is not None, "Required property 'storage_connection_string' is missing"
        return result

    @builtins.property
    def app_settings(
        self,
    ) -> typing.Optional[typing.Mapping[builtins.str, builtins.str]]:
        result = self._values.get("app_settings")
        return result

    @builtins.property
    def auth_settings(self) -> typing.Optional[typing.List[FunctionAppAuthSettings]]:
        """auth_settings block."""
        result = self._values.get("auth_settings")
        return result

    @builtins.property
    def client_affinity_enabled(self) -> typing.Optional[builtins.bool]:
        result = self._values.get("client_affinity_enabled")
        return result

    @builtins.property
    def connection_string(
        self,
    ) -> typing.Optional[typing.List["FunctionAppConnectionString"]]:
        """connection_string block."""
        result = self._values.get("connection_string")
        return result

    @builtins.property
    def enable_builtin_logging(self) -> typing.Optional[builtins.bool]:
        result = self._values.get("enable_builtin_logging")
        return result

    @builtins.property
    def enabled(self) -> typing.Optional[builtins.bool]:
        result = self._values.get("enabled")
        return result

    @builtins.property
    def https_only(self) -> typing.Optional[builtins.bool]:
        result = self._values.get("https_only")
        return result

    @builtins.property
    def identity(self) -> typing.Optional[typing.List["FunctionAppIdentity"]]:
        """identity block."""
        result = self._values.get("identity")
        return result

    @builtins.property
    def site_config(self) -> typing.Optional[typing.List["FunctionAppSiteConfig"]]:
        """site_config block."""
        result = self._values.get("site_config")
        return result

    @builtins.property
    def tags(self) -> typing.Optional[typing.Mapping[builtins.str, builtins.str]]:
        result = self._values.get("tags")
        return result

    @builtins.property
    def timeouts(self) -> typing.Optional["FunctionAppTimeouts"]:
        """timeouts block."""
        result = self._values.get("timeouts")
        return result

    @builtins.property
    def version(self) -> typing.Optional[builtins.str]:
        result = self._values.get("version")
        return result

    def __eq__(self, rhs: typing.Any) -> builtins.bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs: typing.Any) -> builtins.bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return "FunctionAppConfig(%s)" % ", ".join(
            k + "=" + repr(v) for k, v in self._values.items()
        )


@jsii.data_type(
    jsii_type="@cdktf/provider-azurerm.FunctionAppConnectionString",
    jsii_struct_bases=[],
    name_mapping={"name": "name", "type": "type", "value": "value"},
)
class FunctionAppConnectionString:
    def __init__(
        self,
        *,
        name: builtins.str,
        type: builtins.str,
        value: builtins.str,
    ) -> None:
        """
        :param name: 
        :param type: 
        :param value: 
        """
        self._values: typing.Dict[str, typing.Any] = {
            "name": name,
            "type": type,
            "value": value,
        }

    @builtins.property
    def name(self) -> builtins.str:
        result = self._values.get("name")
        assert result is not None, "Required property 'name' is missing"
        return result

    @builtins.property
    def type(self) -> builtins.str:
        result = self._values.get("type")
        assert result is not None, "Required property 'type' is missing"
        return result

    @builtins.property
    def value(self) -> builtins.str:
        result = self._values.get("value")
        assert result is not None, "Required property 'value' is missing"
        return result

    def __eq__(self, rhs: typing.Any) -> builtins.bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs: typing.Any) -> builtins.bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return "FunctionAppConnectionString(%s)" % ", ".join(
            k + "=" + repr(v) for k, v in self._values.items()
        )


@jsii.data_type(
    jsii_type="@cdktf/provider-azurerm.FunctionAppIdentity",
    jsii_struct_bases=[],
    name_mapping={"type": "type", "identity_ids": "identityIds"},
)
class FunctionAppIdentity:
    def __init__(
        self,
        *,
        type: builtins.str,
        identity_ids: typing.Optional[typing.List[builtins.str]] = None,
    ) -> None:
        """
        :param type: 
        :param identity_ids: 
        """
        self._values: typing.Dict[str, typing.Any] = {
            "type": type,
        }
        if identity_ids is not None:
            self._values["identity_ids"] = identity_ids

    @builtins.property
    def type(self) -> builtins.str:
        result = self._values.get("type")
        assert result is not None, "Required property 'type' is missing"
        return result

    @builtins.property
    def identity_ids(self) -> typing.Optional[typing.List[builtins.str]]:
        result = self._values.get("identity_ids")
        return result

    def __eq__(self, rhs: typing.Any) -> builtins.bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs: typing.Any) -> builtins.bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return "FunctionAppIdentity(%s)" % ", ".join(
            k + "=" + repr(v) for k, v in self._values.items()
        )


@jsii.data_type(
    jsii_type="@cdktf/provider-azurerm.FunctionAppSiteConfig",
    jsii_struct_bases=[],
    name_mapping={
        "always_on": "alwaysOn",
        "cors": "cors",
        "ftps_state": "ftpsState",
        "http2_enabled": "http2Enabled",
        "ip_restriction": "ipRestriction",
        "linux_fx_version": "linuxFxVersion",
        "min_tls_version": "minTlsVersion",
        "use32_bit_worker_process": "use32BitWorkerProcess",
        "websockets_enabled": "websocketsEnabled",
    },
)
class FunctionAppSiteConfig:
    def __init__(
        self,
        *,
        always_on: typing.Optional[builtins.bool] = None,
        cors: typing.Optional[typing.List["FunctionAppSiteConfigCors"]] = None,
        ftps_state: typing.Optional[builtins.str] = None,
        http2_enabled: typing.Optional[builtins.bool] = None,
        ip_restriction: typing.Optional[typing.List["FunctionAppSiteConfigIpRestriction"]] = None,
        linux_fx_version: typing.Optional[builtins.str] = None,
        min_tls_version: typing.Optional[builtins.str] = None,
        use32_bit_worker_process: typing.Optional[builtins.bool] = None,
        websockets_enabled: typing.Optional[builtins.bool] = None,
    ) -> None:
        """
        :param always_on: 
        :param cors: cors block.
        :param ftps_state: 
        :param http2_enabled: 
        :param ip_restriction: 
        :param linux_fx_version: 
        :param min_tls_version: 
        :param use32_bit_worker_process: 
        :param websockets_enabled: 
        """
        self._values: typing.Dict[str, typing.Any] = {}
        if always_on is not None:
            self._values["always_on"] = always_on
        if cors is not None:
            self._values["cors"] = cors
        if ftps_state is not None:
            self._values["ftps_state"] = ftps_state
        if http2_enabled is not None:
            self._values["http2_enabled"] = http2_enabled
        if ip_restriction is not None:
            self._values["ip_restriction"] = ip_restriction
        if linux_fx_version is not None:
            self._values["linux_fx_version"] = linux_fx_version
        if min_tls_version is not None:
            self._values["min_tls_version"] = min_tls_version
        if use32_bit_worker_process is not None:
            self._values["use32_bit_worker_process"] = use32_bit_worker_process
        if websockets_enabled is not None:
            self._values["websockets_enabled"] = websockets_enabled

    @builtins.property
    def always_on(self) -> typing.Optional[builtins.bool]:
        result = self._values.get("always_on")
        return result

    @builtins.property
    def cors(self) -> typing.Optional[typing.List["FunctionAppSiteConfigCors"]]:
        """cors block."""
        result = self._values.get("cors")
        return result

    @builtins.property
    def ftps_state(self) -> typing.Optional[builtins.str]:
        result = self._values.get("ftps_state")
        return result

    @builtins.property
    def http2_enabled(self) -> typing.Optional[builtins.bool]:
        result = self._values.get("http2_enabled")
        return result

    @builtins.property
    def ip_restriction(
        self,
    ) -> typing.Optional[typing.List["FunctionAppSiteConfigIpRestriction"]]:
        result = self._values.get("ip_restriction")
        return result

    @builtins.property
    def linux_fx_version(self) -> typing.Optional[builtins.str]:
        result = self._values.get("linux_fx_version")
        return result

    @builtins.property
    def min_tls_version(self) -> typing.Optional[builtins.str]:
        result = self._values.get("min_tls_version")
        return result

    @builtins.property
    def use32_bit_worker_process(self) -> typing.Optional[builtins.bool]:
        result = self._values.get("use32_bit_worker_process")
        return result

    @builtins.property
    def websockets_enabled(self) -> typing.Optional[builtins.bool]:
        result = self._values.get("websockets_enabled")
        return result

    def __eq__(self, rhs: typing.Any) -> builtins.bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs: typing.Any) -> builtins.bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return "FunctionAppSiteConfig(%s)" % ", ".join(
            k + "=" + repr(v) for k, v in self._values.items()
        )


@jsii.data_type(
    jsii_type="@cdktf/provider-azurerm.FunctionAppSiteConfigCors",
    jsii_struct_bases=[],
    name_mapping={
        "allowed_origins": "allowedOrigins",
        "support_credentials": "supportCredentials",
    },
)
class FunctionAppSiteConfigCors:
    def __init__(
        self,
        *,
        allowed_origins: typing.List[builtins.str],
        support_credentials: typing.Optional[builtins.bool] = None,
    ) -> None:
        """
        :param allowed_origins: 
        :param support_credentials: 
        """
        self._values: typing.Dict[str, typing.Any] = {
            "allowed_origins": allowed_origins,
        }
        if support_credentials is not None:
            self._values["support_credentials"] = support_credentials

    @builtins.property
    def allowed_origins(self) -> typing.List[builtins.str]:
        result = self._values.get("allowed_origins")
        assert result is not None, "Required property 'allowed_origins' is missing"
        return result

    @builtins.property
    def support_credentials(self) -> typing.Optional[builtins.bool]:
        result = self._values.get("support_credentials")
        return result

    def __eq__(self, rhs: typing.Any) -> builtins.bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs: typing.Any) -> builtins.bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return "FunctionAppSiteConfigCors(%s)" % ", ".join(
            k + "=" + repr(v) for k, v in self._values.items()
        )


@jsii.data_type(
    jsii_type="@cdktf/provider-azurerm.FunctionAppSiteConfigIpRestriction",
    jsii_struct_bases=[],
    name_mapping={"ip_address": "ipAddress", "subnet_id": "subnetId"},
)
class FunctionAppSiteConfigIpRestriction:
    def __init__(
        self,
        *,
        ip_address: typing.Optional[builtins.str] = None,
        subnet_id: typing.Optional[builtins.str] = None,
    ) -> None:
        """
        :param ip_address: 
        :param subnet_id: 
        """
        self._values: typing.Dict[str, typing.Any] = {}
        if ip_address is not None:
            self._values["ip_address"] = ip_address
        if subnet_id is not None:
            self._values["subnet_id"] = subnet_id

    @builtins.property
    def ip_address(self) -> typing.Optional[builtins.str]:
        result = self._values.get("ip_address")
        return result

    @builtins.property
    def subnet_id(self) -> typing.Optional[builtins.str]:
        result = self._values.get("subnet_id")
        return result

    def __eq__(self, rhs: typing.Any) -> builtins.bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs: typing.Any) -> builtins.bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return "FunctionAppSiteConfigIpRestriction(%s)" % ", ".join(
            k + "=" + repr(v) for k, v in self._values.items()
        )


class FunctionAppSiteCredential(
    cdktf.ComplexComputedList,
    metaclass=jsii.JSIIMeta,
    jsii_type="@cdktf/provider-azurerm.FunctionAppSiteCredential",
):
    def __init__(
        self,
        terraform_resource: cdktf.ITerraformResource,
        terraform_attribute: builtins.str,
        index: builtins.str,
    ) -> None:
        """
        :param terraform_resource: -
        :param terraform_attribute: -
        :param index: -

        :stability: experimental
        """
        jsii.create(FunctionAppSiteCredential, self, [terraform_resource, terraform_attribute, index])

    @builtins.property # type: ignore
    @jsii.member(jsii_name="password")
    def password(self) -> builtins.str:
        return jsii.get(self, "password")

    @builtins.property # type: ignore
    @jsii.member(jsii_name="username")
    def username(self) -> builtins.str:
        return jsii.get(self, "username")


@jsii.data_type(
    jsii_type="@cdktf/provider-azurerm.FunctionAppTimeouts",
    jsii_struct_bases=[],
    name_mapping={
        "create": "create",
        "delete": "delete",
        "read": "read",
        "update": "update",
    },
)
class FunctionAppTimeouts:
    def __init__(
        self,
        *,
        create: typing.Optional[builtins.str] = None,
        delete: typing.Optional[builtins.str] = None,
        read: typing.Optional[builtins.str] = None,
        update: typing.Optional[builtins.str] = None,
    ) -> None:
        """
        :param create: 
        :param delete: 
        :param read: 
        :param update: 
        """
        self._values: typing.Dict[str, typing.Any] = {}
        if create is not None:
            self._values["create"] = create
        if delete is not None:
            self._values["delete"] = delete
        if read is not None:
            self._values["read"] = read
        if update is not None:
            self._values["update"] = update

    @builtins.property
    def create(self) -> typing.Optional[builtins.str]:
        result = self._values.get("create")
        return result

    @builtins.property
    def delete(self) -> typing.Optional[builtins.str]:
        result = self._values.get("delete")
        return result

    @builtins.property
    def read(self) -> typing.Optional[builtins.str]:
        result = self._values.get("read")
        return result

    @builtins.property
    def update(self) -> typing.Optional[builtins.str]:
        result = self._values.get("update")
        return result

    def __eq__(self, rhs: typing.Any) -> builtins.bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs: typing.Any) -> builtins.bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return "FunctionAppTimeouts(%s)" % ", ".join(
            k + "=" + repr(v) for k, v in self._values.items()
        )


class HdinsightHadoopCluster(
    cdktf.TerraformResource,
    metaclass=jsii.JSIIMeta,
    jsii_type="@cdktf/provider-azurerm.HdinsightHadoopCluster",
):
    def __init__(
        self,
        scope: constructs.Construct,
        id: builtins.str,
        *,
        cluster_version: builtins.str,
        component_version: typing.List["HdinsightHadoopClusterComponentVersion"],
        gateway: typing.List["HdinsightHadoopClusterGateway"],
        location: builtins.str,
        name: builtins.str,
        resource_group_name: builtins.str,
        roles: typing.List["HdinsightHadoopClusterRoles"],
        tier: builtins.str,
        storage_account: typing.Optional[typing.List["HdinsightHadoopClusterStorageAccount"]] = None,
        storage_account_gen2: typing.Optional[typing.List["HdinsightHadoopClusterStorageAccountGen2"]] = None,
        tags: typing.Optional[typing.Mapping[builtins.str, builtins.str]] = None,
        timeouts: typing.Optional["HdinsightHadoopClusterTimeouts"] = None,
        count: typing.Optional[jsii.Number] = None,
        depends_on: typing.Optional[typing.List[cdktf.TerraformResource]] = None,
        lifecycle: typing.Optional[cdktf.TerraformResourceLifecycle] = None,
        provider: typing.Optional[cdktf.TerraformProvider] = None,
    ) -> None:
        """
        :param scope: -
        :param id: -
        :param cluster_version: 
        :param component_version: component_version block.
        :param gateway: gateway block.
        :param location: 
        :param name: 
        :param resource_group_name: 
        :param roles: roles block.
        :param tier: 
        :param storage_account: storage_account block.
        :param storage_account_gen2: storage_account_gen2 block.
        :param tags: 
        :param timeouts: timeouts block.
        :param count: 
        :param depends_on: 
        :param lifecycle: 
        :param provider: 
        """
        config = HdinsightHadoopClusterConfig(
            cluster_version=cluster_version,
            component_version=component_version,
            gateway=gateway,
            location=location,
            name=name,
            resource_group_name=resource_group_name,
            roles=roles,
            tier=tier,
            storage_account=storage_account,
            storage_account_gen2=storage_account_gen2,
            tags=tags,
            timeouts=timeouts,
            count=count,
            depends_on=depends_on,
            lifecycle=lifecycle,
            provider=provider,
        )

        jsii.create(HdinsightHadoopCluster, self, [scope, id, config])

    @jsii.member(jsii_name="synthesizeAttributes")
    def _synthesize_attributes(self) -> typing.Mapping[builtins.str, typing.Any]:
        return jsii.invoke(self, "synthesizeAttributes", [])

    @builtins.property # type: ignore
    @jsii.member(jsii_name="httpsEndpoint")
    def https_endpoint(self) -> builtins.str:
        return jsii.get(self, "httpsEndpoint")

    @builtins.property # type: ignore
    @jsii.member(jsii_name="sshEndpoint")
    def ssh_endpoint(self) -> builtins.str:
        return jsii.get(self, "sshEndpoint")

    @builtins.property # type: ignore
    @jsii.member(jsii_name="clusterVersion")
    def cluster_version(self) -> builtins.str:
        return jsii.get(self, "clusterVersion")

    @cluster_version.setter # type: ignore
    def cluster_version(self, value: builtins.str) -> None:
        jsii.set(self, "clusterVersion", value)

    @builtins.property # type: ignore
    @jsii.member(jsii_name="componentVersion")
    def component_version(
        self,
    ) -> typing.List["HdinsightHadoopClusterComponentVersion"]:
        return jsii.get(self, "componentVersion")

    @component_version.setter # type: ignore
    def component_version(
        self,
        value: typing.List["HdinsightHadoopClusterComponentVersion"],
    ) -> None:
        jsii.set(self, "componentVersion", value)

    @builtins.property # type: ignore
    @jsii.member(jsii_name="gateway")
    def gateway(self) -> typing.List["HdinsightHadoopClusterGateway"]:
        return jsii.get(self, "gateway")

    @gateway.setter # type: ignore
    def gateway(self, value: typing.List["HdinsightHadoopClusterGateway"]) -> None:
        jsii.set(self, "gateway", value)

    @builtins.property # type: ignore
    @jsii.member(jsii_name="location")
    def location(self) -> builtins.str:
        return jsii.get(self, "location")

    @location.setter # type: ignore
    def location(self, value: builtins.str) -> None:
        jsii.set(self, "location", value)

    @builtins.property # type: ignore
    @jsii.member(jsii_name="name")
    def name(self) -> builtins.str:
        return jsii.get(self, "name")

    @name.setter # type: ignore
    def name(self, value: builtins.str) -> None:
        jsii.set(self, "name", value)

    @builtins.property # type: ignore
    @jsii.member(jsii_name="resourceGroupName")
    def resource_group_name(self) -> builtins.str:
        return jsii.get(self, "resourceGroupName")

    @resource_group_name.setter # type: ignore
    def resource_group_name(self, value: builtins.str) -> None:
        jsii.set(self, "resourceGroupName", value)

    @builtins.property # type: ignore
    @jsii.member(jsii_name="roles")
    def roles(self) -> typing.List["HdinsightHadoopClusterRoles"]:
        return jsii.get(self, "roles")

    @roles.setter # type: ignore
    def roles(self, value: typing.List["HdinsightHadoopClusterRoles"]) -> None:
        jsii.set(self, "roles", value)

    @builtins.property # type: ignore
    @jsii.member(jsii_name="tier")
    def tier(self) -> builtins.str:
        return jsii.get(self, "tier")

    @tier.setter # type: ignore
    def tier(self, value: builtins.str) -> None:
        jsii.set(self, "tier", value)

    @builtins.property # type: ignore
    @jsii.member(jsii_name="id")
    def id(self) -> typing.Optional[builtins.str]:
        return jsii.get(self, "id")

    @id.setter # type: ignore
    def id(self, value: typing.Optional[builtins.str]) -> None:
        jsii.set(self, "id", value)

    @builtins.property # type: ignore
    @jsii.member(jsii_name="storageAccount")
    def storage_account(
        self,
    ) -> typing.Optional[typing.List["HdinsightHadoopClusterStorageAccount"]]:
        return jsii.get(self, "storageAccount")

    @storage_account.setter # type: ignore
    def storage_account(
        self,
        value: typing.Optional[typing.List["HdinsightHadoopClusterStorageAccount"]],
    ) -> None:
        jsii.set(self, "storageAccount", value)

    @builtins.property # type: ignore
    @jsii.member(jsii_name="storageAccountGen2")
    def storage_account_gen2(
        self,
    ) -> typing.Optional[typing.List["HdinsightHadoopClusterStorageAccountGen2"]]:
        return jsii.get(self, "storageAccountGen2")

    @storage_account_gen2.setter # type: ignore
    def storage_account_gen2(
        self,
        value: typing.Optional[typing.List["HdinsightHadoopClusterStorageAccountGen2"]],
    ) -> None:
        jsii.set(self, "storageAccountGen2", value)

    @builtins.property # type: ignore
    @jsii.member(jsii_name="tags")
    def tags(self) -> typing.Optional[typing.Mapping[builtins.str, builtins.str]]:
        return jsii.get(self, "tags")

    @tags.setter # type: ignore
    def tags(
        self,
        value: typing.Optional[typing.Mapping[builtins.str, builtins.str]],
    ) -> None:
        jsii.set(self, "tags", value)

    @builtins.property # type: ignore
    @jsii.member(jsii_name="timeouts")
    def timeouts(self) -> typing.Optional["HdinsightHadoopClusterTimeouts"]:
        return jsii.get(self, "timeouts")

    @timeouts.setter # type: ignore
    def timeouts(
        self,
        value: typing.Optional["HdinsightHadoopClusterTimeouts"],
    ) -> None:
        jsii.set(self, "timeouts", value)


@jsii.data_type(
    jsii_type="@cdktf/provider-azurerm.HdinsightHadoopClusterComponentVersion",
    jsii_struct_bases=[],
    name_mapping={"hadoop": "hadoop"},
)
class HdinsightHadoopClusterComponentVersion:
    def __init__(self, *, hadoop: builtins.str) -> None:
        """
        :param hadoop: 
        """
        self._values: typing.Dict[str, typing.Any] = {
            "hadoop": hadoop,
        }

    @builtins.property
    def hadoop(self) -> builtins.str:
        result = self._values.get("hadoop")
        assert result is not None, "Required property 'hadoop' is missing"
        return result

    def __eq__(self, rhs: typing.Any) -> builtins.bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs: typing.Any) -> builtins.bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return "HdinsightHadoopClusterComponentVersion(%s)" % ", ".join(
            k + "=" + repr(v) for k, v in self._values.items()
        )


@jsii.data_type(
    jsii_type="@cdktf/provider-azurerm.HdinsightHadoopClusterConfig",
    jsii_struct_bases=[cdktf.TerraformMetaArguments],
    name_mapping={
        "count": "count",
        "depends_on": "dependsOn",
        "lifecycle": "lifecycle",
        "provider": "provider",
        "cluster_version": "clusterVersion",
        "component_version": "componentVersion",
        "gateway": "gateway",
        "location": "location",
        "name": "name",
        "resource_group_name": "resourceGroupName",
        "roles": "roles",
        "tier": "tier",
        "storage_account": "storageAccount",
        "storage_account_gen2": "storageAccountGen2",
        "tags": "tags",
        "timeouts": "timeouts",
    },
)
class HdinsightHadoopClusterConfig(cdktf.TerraformMetaArguments):
    def __init__(
        self,
        *,
        count: typing.Optional[jsii.Number] = None,
        depends_on: typing.Optional[typing.List[cdktf.TerraformResource]] = None,
        lifecycle: typing.Optional[cdktf.TerraformResourceLifecycle] = None,
        provider: typing.Optional[cdktf.TerraformProvider] = None,
        cluster_version: builtins.str,
        component_version: typing.List[HdinsightHadoopClusterComponentVersion],
        gateway: typing.List["HdinsightHadoopClusterGateway"],
        location: builtins.str,
        name: builtins.str,
        resource_group_name: builtins.str,
        roles: typing.List["HdinsightHadoopClusterRoles"],
        tier: builtins.str,
        storage_account: typing.Optional[typing.List["HdinsightHadoopClusterStorageAccount"]] = None,
        storage_account_gen2: typing.Optional[typing.List["HdinsightHadoopClusterStorageAccountGen2"]] = None,
        tags: typing.Optional[typing.Mapping[builtins.str, builtins.str]] = None,
        timeouts: typing.Optional["HdinsightHadoopClusterTimeouts"] = None,
    ) -> None:
        """
        :param count: 
        :param depends_on: 
        :param lifecycle: 
        :param provider: 
        :param cluster_version: 
        :param component_version: component_version block.
        :param gateway: gateway block.
        :param location: 
        :param name: 
        :param resource_group_name: 
        :param roles: roles block.
        :param tier: 
        :param storage_account: storage_account block.
        :param storage_account_gen2: storage_account_gen2 block.
        :param tags: 
        :param timeouts: timeouts block.
        """
        if isinstance(lifecycle, dict):
            lifecycle = cdktf.TerraformResourceLifecycle(**lifecycle)
        if isinstance(timeouts, dict):
            timeouts = HdinsightHadoopClusterTimeouts(**timeouts)
        self._values: typing.Dict[str, typing.Any] = {
            "cluster_version": cluster_version,
            "component_version": component_version,
            "gateway": gateway,
            "location": location,
            "name": name,
            "resource_group_name": resource_group_name,
            "roles": roles,
            "tier": tier,
        }
        if count is not None:
            self._values["count"] = count
        if depends_on is not None:
            self._values["depends_on"] = depends_on
        if lifecycle is not None:
            self._values["lifecycle"] = lifecycle
        if provider is not None:
            self._values["provider"] = provider
        if storage_account is not None:
            self._values["storage_account"] = storage_account
        if storage_account_gen2 is not None:
            self._values["storage_account_gen2"] = storage_account_gen2
        if tags is not None:
            self._values["tags"] = tags
        if timeouts is not None:
            self._values["timeouts"] = timeouts

    @builtins.property
    def count(self) -> typing.Optional[jsii.Number]:
        """
        :stability: experimental
        """
        result = self._values.get("count")
        return result

    @builtins.property
    def depends_on(self) -> typing.Optional[typing.List[cdktf.TerraformResource]]:
        """
        :stability: experimental
        """
        result = self._values.get("depends_on")
        return result

    @builtins.property
    def lifecycle(self) -> typing.Optional[cdktf.TerraformResourceLifecycle]:
        """
        :stability: experimental
        """
        result = self._values.get("lifecycle")
        return result

    @builtins.property
    def provider(self) -> typing.Optional[cdktf.TerraformProvider]:
        """
        :stability: experimental
        """
        result = self._values.get("provider")
        return result

    @builtins.property
    def cluster_version(self) -> builtins.str:
        result = self._values.get("cluster_version")
        assert result is not None, "Required property 'cluster_version' is missing"
        return result

    @builtins.property
    def component_version(self) -> typing.List[HdinsightHadoopClusterComponentVersion]:
        """component_version block."""
        result = self._values.get("component_version")
        assert result is not None, "Required property 'component_version' is missing"
        return result

    @builtins.property
    def gateway(self) -> typing.List["HdinsightHadoopClusterGateway"]:
        """gateway block."""
        result = self._values.get("gateway")
        assert result is not None, "Required property 'gateway' is missing"
        return result

    @builtins.property
    def location(self) -> builtins.str:
        result = self._values.get("location")
        assert result is not None, "Required property 'location' is missing"
        return result

    @builtins.property
    def name(self) -> builtins.str:
        result = self._values.get("name")
        assert result is not None, "Required property 'name' is missing"
        return result

    @builtins.property
    def resource_group_name(self) -> builtins.str:
        result = self._values.get("resource_group_name")
        assert result is not None, "Required property 'resource_group_name' is missing"
        return result

    @builtins.property
    def roles(self) -> typing.List["HdinsightHadoopClusterRoles"]:
        """roles block."""
        result = self._values.get("roles")
        assert result is not None, "Required property 'roles' is missing"
        return result

    @builtins.property
    def tier(self) -> builtins.str:
        result = self._values.get("tier")
        assert result is not None, "Required property 'tier' is missing"
        return result

    @builtins.property
    def storage_account(
        self,
    ) -> typing.Optional[typing.List["HdinsightHadoopClusterStorageAccount"]]:
        """storage_account block."""
        result = self._values.get("storage_account")
        return result

    @builtins.property
    def storage_account_gen2(
        self,
    ) -> typing.Optional[typing.List["HdinsightHadoopClusterStorageAccountGen2"]]:
        """storage_account_gen2 block."""
        result = self._values.get("storage_account_gen2")
        return result

    @builtins.property
    def tags(self) -> typing.Optional[typing.Mapping[builtins.str, builtins.str]]:
        result = self._values.get("tags")
        return result

    @builtins.property
    def timeouts(self) -> typing.Optional["HdinsightHadoopClusterTimeouts"]:
        """timeouts block."""
        result = self._values.get("timeouts")
        return result

    def __eq__(self, rhs: typing.Any) -> builtins.bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs: typing.Any) -> builtins.bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return "HdinsightHadoopClusterConfig(%s)" % ", ".join(
            k + "=" + repr(v) for k, v in self._values.items()
        )


@jsii.data_type(
    jsii_type="@cdktf/provider-azurerm.HdinsightHadoopClusterGateway",
    jsii_struct_bases=[],
    name_mapping={
        "enabled": "enabled",
        "password": "password",
        "username": "username",
    },
)
class HdinsightHadoopClusterGateway:
    def __init__(
        self,
        *,
        enabled: builtins.bool,
        password: builtins.str,
        username: builtins.str,
    ) -> None:
        """
        :param enabled: 
        :param password: 
        :param username: 
        """
        self._values: typing.Dict[str, typing.Any] = {
            "enabled": enabled,
            "password": password,
            "username": username,
        }

    @builtins.property
    def enabled(self) -> builtins.bool:
        result = self._values.get("enabled")
        assert result is not None, "Required property 'enabled' is missing"
        return result

    @builtins.property
    def password(self) -> builtins.str:
        result = self._values.get("password")
        assert result is not None, "Required property 'password' is missing"
        return result

    @builtins.property
    def username(self) -> builtins.str:
        result = self._values.get("username")
        assert result is not None, "Required property 'username' is missing"
        return result

    def __eq__(self, rhs: typing.Any) -> builtins.bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs: typing.Any) -> builtins.bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return "HdinsightHadoopClusterGateway(%s)" % ", ".join(
            k + "=" + repr(v) for k, v in self._values.items()
        )


@jsii.data_type(
    jsii_type="@cdktf/provider-azurerm.HdinsightHadoopClusterRoles",
    jsii_struct_bases=[],
    name_mapping={
        "head_node": "headNode",
        "worker_node": "workerNode",
        "zookeeper_node": "zookeeperNode",
        "edge_node": "edgeNode",
    },
)
class HdinsightHadoopClusterRoles:
    def __init__(
        self,
        *,
        head_node: typing.List["HdinsightHadoopClusterRolesHeadNode"],
        worker_node: typing.List["HdinsightHadoopClusterRolesWorkerNode"],
        zookeeper_node: typing.List["HdinsightHadoopClusterRolesZookeeperNode"],
        edge_node: typing.Optional[typing.List["HdinsightHadoopClusterRolesEdgeNode"]] = None,
    ) -> None:
        """
        :param head_node: head_node block.
        :param worker_node: worker_node block.
        :param zookeeper_node: zookeeper_node block.
        :param edge_node: edge_node block.
        """
        self._values: typing.Dict[str, typing.Any] = {
            "head_node": head_node,
            "worker_node": worker_node,
            "zookeeper_node": zookeeper_node,
        }
        if edge_node is not None:
            self._values["edge_node"] = edge_node

    @builtins.property
    def head_node(self) -> typing.List["HdinsightHadoopClusterRolesHeadNode"]:
        """head_node block."""
        result = self._values.get("head_node")
        assert result is not None, "Required property 'head_node' is missing"
        return result

    @builtins.property
    def worker_node(self) -> typing.List["HdinsightHadoopClusterRolesWorkerNode"]:
        """worker_node block."""
        result = self._values.get("worker_node")
        assert result is not None, "Required property 'worker_node' is missing"
        return result

    @builtins.property
    def zookeeper_node(self) -> typing.List["HdinsightHadoopClusterRolesZookeeperNode"]:
        """zookeeper_node block."""
        result = self._values.get("zookeeper_node")
        assert result is not None, "Required property 'zookeeper_node' is missing"
        return result

    @builtins.property
    def edge_node(
        self,
    ) -> typing.Optional[typing.List["HdinsightHadoopClusterRolesEdgeNode"]]:
        """edge_node block."""
        result = self._values.get("edge_node")
        return result

    def __eq__(self, rhs: typing.Any) -> builtins.bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs: typing.Any) -> builtins.bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return "HdinsightHadoopClusterRoles(%s)" % ", ".join(
            k + "=" + repr(v) for k, v in self._values.items()
        )


@jsii.data_type(
    jsii_type="@cdktf/provider-azurerm.HdinsightHadoopClusterRolesEdgeNode",
    jsii_struct_bases=[],
    name_mapping={
        "install_script_action": "installScriptAction",
        "target_instance_count": "targetInstanceCount",
        "vm_size": "vmSize",
    },
)
class HdinsightHadoopClusterRolesEdgeNode:
    def __init__(
        self,
        *,
        install_script_action: typing.List["HdinsightHadoopClusterRolesEdgeNodeInstallScriptAction"],
        target_instance_count: jsii.Number,
        vm_size: builtins.str,
    ) -> None:
        """
        :param install_script_action: install_script_action block.
        :param target_instance_count: 
        :param vm_size: 
        """
        self._values: typing.Dict[str, typing.Any] = {
            "install_script_action": install_script_action,
            "target_instance_count": target_instance_count,
            "vm_size": vm_size,
        }

    @builtins.property
    def install_script_action(
        self,
    ) -> typing.List["HdinsightHadoopClusterRolesEdgeNodeInstallScriptAction"]:
        """install_script_action block."""
        result = self._values.get("install_script_action")
        assert result is not None, "Required property 'install_script_action' is missing"
        return result

    @builtins.property
    def target_instance_count(self) -> jsii.Number:
        result = self._values.get("target_instance_count")
        assert result is not None, "Required property 'target_instance_count' is missing"
        return result

    @builtins.property
    def vm_size(self) -> builtins.str:
        result = self._values.get("vm_size")
        assert result is not None, "Required property 'vm_size' is missing"
        return result

    def __eq__(self, rhs: typing.Any) -> builtins.bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs: typing.Any) -> builtins.bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return "HdinsightHadoopClusterRolesEdgeNode(%s)" % ", ".join(
            k + "=" + repr(v) for k, v in self._values.items()
        )


@jsii.data_type(
    jsii_type="@cdktf/provider-azurerm.HdinsightHadoopClusterRolesEdgeNodeInstallScriptAction",
    jsii_struct_bases=[],
    name_mapping={"name": "name", "uri": "uri"},
)
class HdinsightHadoopClusterRolesEdgeNodeInstallScriptAction:
    def __init__(self, *, name: builtins.str, uri: builtins.str) -> None:
        """
        :param name: 
        :param uri: 
        """
        self._values: typing.Dict[str, typing.Any] = {
            "name": name,
            "uri": uri,
        }

    @builtins.property
    def name(self) -> builtins.str:
        result = self._values.get("name")
        assert result is not None, "Required property 'name' is missing"
        return result

    @builtins.property
    def uri(self) -> builtins.str:
        result = self._values.get("uri")
        assert result is not None, "Required property 'uri' is missing"
        return result

    def __eq__(self, rhs: typing.Any) -> builtins.bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs: typing.Any) -> builtins.bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return "HdinsightHadoopClusterRolesEdgeNodeInstallScriptAction(%s)" % ", ".join(
            k + "=" + repr(v) for k, v in self._values.items()
        )


@jsii.data_type(
    jsii_type="@cdktf/provider-azurerm.HdinsightHadoopClusterRolesHeadNode",
    jsii_struct_bases=[],
    name_mapping={
        "username": "username",
        "vm_size": "vmSize",
        "password": "password",
        "ssh_keys": "sshKeys",
        "subnet_id": "subnetId",
        "virtual_network_id": "virtualNetworkId",
    },
)
class HdinsightHadoopClusterRolesHeadNode:
    def __init__(
        self,
        *,
        username: builtins.str,
        vm_size: builtins.str,
        password: typing.Optional[builtins.str] = None,
        ssh_keys: typing.Optional[typing.List[builtins.str]] = None,
        subnet_id: typing.Optional[builtins.str] = None,
        virtual_network_id: typing.Optional[builtins.str] = None,
    ) -> None:
        """
        :param username: 
        :param vm_size: 
        :param password: 
        :param ssh_keys: 
        :param subnet_id: 
        :param virtual_network_id: 
        """
        self._values: typing.Dict[str, typing.Any] = {
            "username": username,
            "vm_size": vm_size,
        }
        if password is not None:
            self._values["password"] = password
        if ssh_keys is not None:
            self._values["ssh_keys"] = ssh_keys
        if subnet_id is not None:
            self._values["subnet_id"] = subnet_id
        if virtual_network_id is not None:
            self._values["virtual_network_id"] = virtual_network_id

    @builtins.property
    def username(self) -> builtins.str:
        result = self._values.get("username")
        assert result is not None, "Required property 'username' is missing"
        return result

    @builtins.property
    def vm_size(self) -> builtins.str:
        result = self._values.get("vm_size")
        assert result is not None, "Required property 'vm_size' is missing"
        return result

    @builtins.property
    def password(self) -> typing.Optional[builtins.str]:
        result = self._values.get("password")
        return result

    @builtins.property
    def ssh_keys(self) -> typing.Optional[typing.List[builtins.str]]:
        result = self._values.get("ssh_keys")
        return result

    @builtins.property
    def subnet_id(self) -> typing.Optional[builtins.str]:
        result = self._values.get("subnet_id")
        return result

    @builtins.property
    def virtual_network_id(self) -> typing.Optional[builtins.str]:
        result = self._values.get("virtual_network_id")
        return result

    def __eq__(self, rhs: typing.Any) -> builtins.bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs: typing.Any) -> builtins.bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return "HdinsightHadoopClusterRolesHeadNode(%s)" % ", ".join(
            k + "=" + repr(v) for k, v in self._values.items()
        )


@jsii.data_type(
    jsii_type="@cdktf/provider-azurerm.HdinsightHadoopClusterRolesWorkerNode",
    jsii_struct_bases=[],
    name_mapping={
        "target_instance_count": "targetInstanceCount",
        "username": "username",
        "vm_size": "vmSize",
        "min_instance_count": "minInstanceCount",
        "password": "password",
        "ssh_keys": "sshKeys",
        "subnet_id": "subnetId",
        "virtual_network_id": "virtualNetworkId",
    },
)
class HdinsightHadoopClusterRolesWorkerNode:
    def __init__(
        self,
        *,
        target_instance_count: jsii.Number,
        username: builtins.str,
        vm_size: builtins.str,
        min_instance_count: typing.Optional[jsii.Number] = None,
        password: typing.Optional[builtins.str] = None,
        ssh_keys: typing.Optional[typing.List[builtins.str]] = None,
        subnet_id: typing.Optional[builtins.str] = None,
        virtual_network_id: typing.Optional[builtins.str] = None,
    ) -> None:
        """
        :param target_instance_count: 
        :param username: 
        :param vm_size: 
        :param min_instance_count: 
        :param password: 
        :param ssh_keys: 
        :param subnet_id: 
        :param virtual_network_id: 
        """
        self._values: typing.Dict[str, typing.Any] = {
            "target_instance_count": target_instance_count,
            "username": username,
            "vm_size": vm_size,
        }
        if min_instance_count is not None:
            self._values["min_instance_count"] = min_instance_count
        if password is not None:
            self._values["password"] = password
        if ssh_keys is not None:
            self._values["ssh_keys"] = ssh_keys
        if subnet_id is not None:
            self._values["subnet_id"] = subnet_id
        if virtual_network_id is not None:
            self._values["virtual_network_id"] = virtual_network_id

    @builtins.property
    def target_instance_count(self) -> jsii.Number:
        result = self._values.get("target_instance_count")
        assert result is not None, "Required property 'target_instance_count' is missing"
        return result

    @builtins.property
    def username(self) -> builtins.str:
        result = self._values.get("username")
        assert result is not None, "Required property 'username' is missing"
        return result

    @builtins.property
    def vm_size(self) -> builtins.str:
        result = self._values.get("vm_size")
        assert result is not None, "Required property 'vm_size' is missing"
        return result

    @builtins.property
    def min_instance_count(self) -> typing.Optional[jsii.Number]:
        result = self._values.get("min_instance_count")
        return result

    @builtins.property
    def password(self) -> typing.Optional[builtins.str]:
        result = self._values.get("password")
        return result

    @builtins.property
    def ssh_keys(self) -> typing.Optional[typing.List[builtins.str]]:
        result = self._values.get("ssh_keys")
        return result

    @builtins.property
    def subnet_id(self) -> typing.Optional[builtins.str]:
        result = self._values.get("subnet_id")
        return result

    @builtins.property
    def virtual_network_id(self) -> typing.Optional[builtins.str]:
        result = self._values.get("virtual_network_id")
        return result

    def __eq__(self, rhs: typing.Any) -> builtins.bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs: typing.Any) -> builtins.bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return "HdinsightHadoopClusterRolesWorkerNode(%s)" % ", ".join(
            k + "=" + repr(v) for k, v in self._values.items()
        )


@jsii.data_type(
    jsii_type="@cdktf/provider-azurerm.HdinsightHadoopClusterRolesZookeeperNode",
    jsii_struct_bases=[],
    name_mapping={
        "username": "username",
        "vm_size": "vmSize",
        "password": "password",
        "ssh_keys": "sshKeys",
        "subnet_id": "subnetId",
        "virtual_network_id": "virtualNetworkId",
    },
)
class HdinsightHadoopClusterRolesZookeeperNode:
    def __init__(
        self,
        *,
        username: builtins.str,
        vm_size: builtins.str,
        password: typing.Optional[builtins.str] = None,
        ssh_keys: typing.Optional[typing.List[builtins.str]] = None,
        subnet_id: typing.Optional[builtins.str] = None,
        virtual_network_id: typing.Optional[builtins.str] = None,
    ) -> None:
        """
        :param username: 
        :param vm_size: 
        :param password: 
        :param ssh_keys: 
        :param subnet_id: 
        :param virtual_network_id: 
        """
        self._values: typing.Dict[str, typing.Any] = {
            "username": username,
            "vm_size": vm_size,
        }
        if password is not None:
            self._values["password"] = password
        if ssh_keys is not None:
            self._values["ssh_keys"] = ssh_keys
        if subnet_id is not None:
            self._values["subnet_id"] = subnet_id
        if virtual_network_id is not None:
            self._values["virtual_network_id"] = virtual_network_id

    @builtins.property
    def username(self) -> builtins.str:
        result = self._values.get("username")
        assert result is not None, "Required property 'username' is missing"
        return result

    @builtins.property
    def vm_size(self) -> builtins.str:
        result = self._values.get("vm_size")
        assert result is not None, "Required property 'vm_size' is missing"
        return result

    @builtins.property
    def password(self) -> typing.Optional[builtins.str]:
        result = self._values.get("password")
        return result

    @builtins.property
    def ssh_keys(self) -> typing.Optional[typing.List[builtins.str]]:
        result = self._values.get("ssh_keys")
        return result

    @builtins.property
    def subnet_id(self) -> typing.Optional[builtins.str]:
        result = self._values.get("subnet_id")
        return result

    @builtins.property
    def virtual_network_id(self) -> typing.Optional[builtins.str]:
        result = self._values.get("virtual_network_id")
        return result

    def __eq__(self, rhs: typing.Any) -> builtins.bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs: typing.Any) -> builtins.bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return "HdinsightHadoopClusterRolesZookeeperNode(%s)" % ", ".join(
            k + "=" + repr(v) for k, v in self._values.items()
        )


@jsii.data_type(
    jsii_type="@cdktf/provider-azurerm.HdinsightHadoopClusterStorageAccount",
    jsii_struct_bases=[],
    name_mapping={
        "is_default": "isDefault",
        "storage_account_key": "storageAccountKey",
        "storage_container_id": "storageContainerId",
    },
)
class HdinsightHadoopClusterStorageAccount:
    def __init__(
        self,
        *,
        is_default: builtins.bool,
        storage_account_key: builtins.str,
        storage_container_id: builtins.str,
    ) -> None:
        """
        :param is_default: 
        :param storage_account_key: 
        :param storage_container_id: 
        """
        self._values: typing.Dict[str, typing.Any] = {
            "is_default": is_default,
            "storage_account_key": storage_account_key,
            "storage_container_id": storage_container_id,
        }

    @builtins.property
    def is_default(self) -> builtins.bool:
        result = self._values.get("is_default")
        assert result is not None, "Required property 'is_default' is missing"
        return result

    @builtins.property
    def storage_account_key(self) -> builtins.str:
        result = self._values.get("storage_account_key")
        assert result is not None, "Required property 'storage_account_key' is missing"
        return result

    @builtins.property
    def storage_container_id(self) -> builtins.str:
        result = self._values.get("storage_container_id")
        assert result is not None, "Required property 'storage_container_id' is missing"
        return result

    def __eq__(self, rhs: typing.Any) -> builtins.bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs: typing.Any) -> builtins.bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return "HdinsightHadoopClusterStorageAccount(%s)" % ", ".join(
            k + "=" + repr(v) for k, v in self._values.items()
        )


@jsii.data_type(
    jsii_type="@cdktf/provider-azurerm.HdinsightHadoopClusterStorageAccountGen2",
    jsii_struct_bases=[],
    name_mapping={
        "filesystem_id": "filesystemId",
        "is_default": "isDefault",
        "managed_identity_resource_id": "managedIdentityResourceId",
        "storage_resource_id": "storageResourceId",
    },
)
class HdinsightHadoopClusterStorageAccountGen2:
    def __init__(
        self,
        *,
        filesystem_id: builtins.str,
        is_default: builtins.bool,
        managed_identity_resource_id: builtins.str,
        storage_resource_id: builtins.str,
    ) -> None:
        """
        :param filesystem_id: 
        :param is_default: 
        :param managed_identity_resource_id: 
        :param storage_resource_id: 
        """
        self._values: typing.Dict[str, typing.Any] = {
            "filesystem_id": filesystem_id,
            "is_default": is_default,
            "managed_identity_resource_id": managed_identity_resource_id,
            "storage_resource_id": storage_resource_id,
        }

    @builtins.property
    def filesystem_id(self) -> builtins.str:
        result = self._values.get("filesystem_id")
        assert result is not None, "Required property 'filesystem_id' is missing"
        return result

    @builtins.property
    def is_default(self) -> builtins.bool:
        result = self._values.get("is_default")
        assert result is not None, "Required property 'is_default' is missing"
        return result

    @builtins.property
    def managed_identity_resource_id(self) -> builtins.str:
        result = self._values.get("managed_identity_resource_id")
        assert result is not None, "Required property 'managed_identity_resource_id' is missing"
        return result

    @builtins.property
    def storage_resource_id(self) -> builtins.str:
        result = self._values.get("storage_resource_id")
        assert result is not None, "Required property 'storage_resource_id' is missing"
        return result

    def __eq__(self, rhs: typing.Any) -> builtins.bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs: typing.Any) -> builtins.bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return "HdinsightHadoopClusterStorageAccountGen2(%s)" % ", ".join(
            k + "=" + repr(v) for k, v in self._values.items()
        )


@jsii.data_type(
    jsii_type="@cdktf/provider-azurerm.HdinsightHadoopClusterTimeouts",
    jsii_struct_bases=[],
    name_mapping={
        "create": "create",
        "delete": "delete",
        "read": "read",
        "update": "update",
    },
)
class HdinsightHadoopClusterTimeouts:
    def __init__(
        self,
        *,
        create: typing.Optional[builtins.str] = None,
        delete: typing.Optional[builtins.str] = None,
        read: typing.Optional[builtins.str] = None,
        update: typing.Optional[builtins.str] = None,
    ) -> None:
        """
        :param create: 
        :param delete: 
        :param read: 
        :param update: 
        """
        self._values: typing.Dict[str, typing.Any] = {}
        if create is not None:
            self._values["create"] = create
        if delete is not None:
            self._values["delete"] = delete
        if read is not None:
            self._values["read"] = read
        if update is not None:
            self._values["update"] = update

    @builtins.property
    def create(self) -> typing.Optional[builtins.str]:
        result = self._values.get("create")
        return result

    @builtins.property
    def delete(self) -> typing.Optional[builtins.str]:
        result = self._values.get("delete")
        return result

    @builtins.property
    def read(self) -> typing.Optional[builtins.str]:
        result = self._values.get("read")
        return result

    @builtins.property
    def update(self) -> typing.Optional[builtins.str]:
        result = self._values.get("update")
        return result

    def __eq__(self, rhs: typing.Any) -> builtins.bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs: typing.Any) -> builtins.bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return "HdinsightHadoopClusterTimeouts(%s)" % ", ".join(
            k + "=" + repr(v) for k, v in self._values.items()
        )


class HdinsightHbaseCluster(
    cdktf.TerraformResource,
    metaclass=jsii.JSIIMeta,
    jsii_type="@cdktf/provider-azurerm.HdinsightHbaseCluster",
):
    def __init__(
        self,
        scope: constructs.Construct,
        id: builtins.str,
        *,
        cluster_version: builtins.str,
        component_version: typing.List["HdinsightHbaseClusterComponentVersion"],
        gateway: typing.List["HdinsightHbaseClusterGateway"],
        location: builtins.str,
        name: builtins.str,
        resource_group_name: builtins.str,
        roles: typing.List["HdinsightHbaseClusterRoles"],
        tier: builtins.str,
        storage_account: typing.Optional[typing.List["HdinsightHbaseClusterStorageAccount"]] = None,
        storage_account_gen2: typing.Optional[typing.List["HdinsightHbaseClusterStorageAccountGen2"]] = None,
        tags: typing.Optional[typing.Mapping[builtins.str, builtins.str]] = None,
        timeouts: typing.Optional["HdinsightHbaseClusterTimeouts"] = None,
        count: typing.Optional[jsii.Number] = None,
        depends_on: typing.Optional[typing.List[cdktf.TerraformResource]] = None,
        lifecycle: typing.Optional[cdktf.TerraformResourceLifecycle] = None,
        provider: typing.Optional[cdktf.TerraformProvider] = None,
    ) -> None:
        """
        :param scope: -
        :param id: -
        :param cluster_version: 
        :param component_version: component_version block.
        :param gateway: gateway block.
        :param location: 
        :param name: 
        :param resource_group_name: 
        :param roles: roles block.
        :param tier: 
        :param storage_account: storage_account block.
        :param storage_account_gen2: storage_account_gen2 block.
        :param tags: 
        :param timeouts: timeouts block.
        :param count: 
        :param depends_on: 
        :param lifecycle: 
        :param provider: 
        """
        config = HdinsightHbaseClusterConfig(
            cluster_version=cluster_version,
            component_version=component_version,
            gateway=gateway,
            location=location,
            name=name,
            resource_group_name=resource_group_name,
            roles=roles,
            tier=tier,
            storage_account=storage_account,
            storage_account_gen2=storage_account_gen2,
            tags=tags,
            timeouts=timeouts,
            count=count,
            depends_on=depends_on,
            lifecycle=lifecycle,
            provider=provider,
        )

        jsii.create(HdinsightHbaseCluster, self, [scope, id, config])

    @jsii.member(jsii_name="synthesizeAttributes")
    def _synthesize_attributes(self) -> typing.Mapping[builtins.str, typing.Any]:
        return jsii.invoke(self, "synthesizeAttributes", [])

    @builtins.property # type: ignore
    @jsii.member(jsii_name="httpsEndpoint")
    def https_endpoint(self) -> builtins.str:
        return jsii.get(self, "httpsEndpoint")

    @builtins.property # type: ignore
    @jsii.member(jsii_name="sshEndpoint")
    def ssh_endpoint(self) -> builtins.str:
        return jsii.get(self, "sshEndpoint")

    @builtins.property # type: ignore
    @jsii.member(jsii_name="clusterVersion")
    def cluster_version(self) -> builtins.str:
        return jsii.get(self, "clusterVersion")

    @cluster_version.setter # type: ignore
    def cluster_version(self, value: builtins.str) -> None:
        jsii.set(self, "clusterVersion", value)

    @builtins.property # type: ignore
    @jsii.member(jsii_name="componentVersion")
    def component_version(self) -> typing.List["HdinsightHbaseClusterComponentVersion"]:
        return jsii.get(self, "componentVersion")

    @component_version.setter # type: ignore
    def component_version(
        self,
        value: typing.List["HdinsightHbaseClusterComponentVersion"],
    ) -> None:
        jsii.set(self, "componentVersion", value)

    @builtins.property # type: ignore
    @jsii.member(jsii_name="gateway")
    def gateway(self) -> typing.List["HdinsightHbaseClusterGateway"]:
        return jsii.get(self, "gateway")

    @gateway.setter # type: ignore
    def gateway(self, value: typing.List["HdinsightHbaseClusterGateway"]) -> None:
        jsii.set(self, "gateway", value)

    @builtins.property # type: ignore
    @jsii.member(jsii_name="location")
    def location(self) -> builtins.str:
        return jsii.get(self, "location")

    @location.setter # type: ignore
    def location(self, value: builtins.str) -> None:
        jsii.set(self, "location", value)

    @builtins.property # type: ignore
    @jsii.member(jsii_name="name")
    def name(self) -> builtins.str:
        return jsii.get(self, "name")

    @name.setter # type: ignore
    def name(self, value: builtins.str) -> None:
        jsii.set(self, "name", value)

    @builtins.property # type: ignore
    @jsii.member(jsii_name="resourceGroupName")
    def resource_group_name(self) -> builtins.str:
        return jsii.get(self, "resourceGroupName")

    @resource_group_name.setter # type: ignore
    def resource_group_name(self, value: builtins.str) -> None:
        jsii.set(self, "resourceGroupName", value)

    @builtins.property # type: ignore
    @jsii.member(jsii_name="roles")
    def roles(self) -> typing.List["HdinsightHbaseClusterRoles"]:
        return jsii.get(self, "roles")

    @roles.setter # type: ignore
    def roles(self, value: typing.List["HdinsightHbaseClusterRoles"]) -> None:
        jsii.set(self, "roles", value)

    @builtins.property # type: ignore
    @jsii.member(jsii_name="tier")
    def tier(self) -> builtins.str:
        return jsii.get(self, "tier")

    @tier.setter # type: ignore
    def tier(self, value: builtins.str) -> None:
        jsii.set(self, "tier", value)

    @builtins.property # type: ignore
    @jsii.member(jsii_name="id")
    def id(self) -> typing.Optional[builtins.str]:
        return jsii.get(self, "id")

    @id.setter # type: ignore
    def id(self, value: typing.Optional[builtins.str]) -> None:
        jsii.set(self, "id", value)

    @builtins.property # type: ignore
    @jsii.member(jsii_name="storageAccount")
    def storage_account(
        self,
    ) -> typing.Optional[typing.List["HdinsightHbaseClusterStorageAccount"]]:
        return jsii.get(self, "storageAccount")

    @storage_account.setter # type: ignore
    def storage_account(
        self,
        value: typing.Optional[typing.List["HdinsightHbaseClusterStorageAccount"]],
    ) -> None:
        jsii.set(self, "storageAccount", value)

    @builtins.property # type: ignore
    @jsii.member(jsii_name="storageAccountGen2")
    def storage_account_gen2(
        self,
    ) -> typing.Optional[typing.List["HdinsightHbaseClusterStorageAccountGen2"]]:
        return jsii.get(self, "storageAccountGen2")

    @storage_account_gen2.setter # type: ignore
    def storage_account_gen2(
        self,
        value: typing.Optional[typing.List["HdinsightHbaseClusterStorageAccountGen2"]],
    ) -> None:
        jsii.set(self, "storageAccountGen2", value)

    @builtins.property # type: ignore
    @jsii.member(jsii_name="tags")
    def tags(self) -> typing.Optional[typing.Mapping[builtins.str, builtins.str]]:
        return jsii.get(self, "tags")

    @tags.setter # type: ignore
    def tags(
        self,
        value: typing.Optional[typing.Mapping[builtins.str, builtins.str]],
    ) -> None:
        jsii.set(self, "tags", value)

    @builtins.property # type: ignore
    @jsii.member(jsii_name="timeouts")
    def timeouts(self) -> typing.Optional["HdinsightHbaseClusterTimeouts"]:
        return jsii.get(self, "timeouts")

    @timeouts.setter # type: ignore
    def timeouts(self, value: typing.Optional["HdinsightHbaseClusterTimeouts"]) -> None:
        jsii.set(self, "timeouts", value)


@jsii.data_type(
    jsii_type="@cdktf/provider-azurerm.HdinsightHbaseClusterComponentVersion",
    jsii_struct_bases=[],
    name_mapping={"hbase": "hbase"},
)
class HdinsightHbaseClusterComponentVersion:
    def __init__(self, *, hbase: builtins.str) -> None:
        """
        :param hbase: 
        """
        self._values: typing.Dict[str, typing.Any] = {
            "hbase": hbase,
        }

    @builtins.property
    def hbase(self) -> builtins.str:
        result = self._values.get("hbase")
        assert result is not None, "Required property 'hbase' is missing"
        return result

    def __eq__(self, rhs: typing.Any) -> builtins.bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs: typing.Any) -> builtins.bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return "HdinsightHbaseClusterComponentVersion(%s)" % ", ".join(
            k + "=" + repr(v) for k, v in self._values.items()
        )


@jsii.data_type(
    jsii_type="@cdktf/provider-azurerm.HdinsightHbaseClusterConfig",
    jsii_struct_bases=[cdktf.TerraformMetaArguments],
    name_mapping={
        "count": "count",
        "depends_on": "dependsOn",
        "lifecycle": "lifecycle",
        "provider": "provider",
        "cluster_version": "clusterVersion",
        "component_version": "componentVersion",
        "gateway": "gateway",
        "location": "location",
        "name": "name",
        "resource_group_name": "resourceGroupName",
        "roles": "roles",
        "tier": "tier",
        "storage_account": "storageAccount",
        "storage_account_gen2": "storageAccountGen2",
        "tags": "tags",
        "timeouts": "timeouts",
    },
)
class HdinsightHbaseClusterConfig(cdktf.TerraformMetaArguments):
    def __init__(
        self,
        *,
        count: typing.Optional[jsii.Number] = None,
        depends_on: typing.Optional[typing.List[cdktf.TerraformResource]] = None,
        lifecycle: typing.Optional[cdktf.TerraformResourceLifecycle] = None,
        provider: typing.Optional[cdktf.TerraformProvider] = None,
        cluster_version: builtins.str,
        component_version: typing.List[HdinsightHbaseClusterComponentVersion],
        gateway: typing.List["HdinsightHbaseClusterGateway"],
        location: builtins.str,
        name: builtins.str,
        resource_group_name: builtins.str,
        roles: typing.List["HdinsightHbaseClusterRoles"],
        tier: builtins.str,
        storage_account: typing.Optional[typing.List["HdinsightHbaseClusterStorageAccount"]] = None,
        storage_account_gen2: typing.Optional[typing.List["HdinsightHbaseClusterStorageAccountGen2"]] = None,
        tags: typing.Optional[typing.Mapping[builtins.str, builtins.str]] = None,
        timeouts: typing.Optional["HdinsightHbaseClusterTimeouts"] = None,
    ) -> None:
        """
        :param count: 
        :param depends_on: 
        :param lifecycle: 
        :param provider: 
        :param cluster_version: 
        :param component_version: component_version block.
        :param gateway: gateway block.
        :param location: 
        :param name: 
        :param resource_group_name: 
        :param roles: roles block.
        :param tier: 
        :param storage_account: storage_account block.
        :param storage_account_gen2: storage_account_gen2 block.
        :param tags: 
        :param timeouts: timeouts block.
        """
        if isinstance(lifecycle, dict):
            lifecycle = cdktf.TerraformResourceLifecycle(**lifecycle)
        if isinstance(timeouts, dict):
            timeouts = HdinsightHbaseClusterTimeouts(**timeouts)
        self._values: typing.Dict[str, typing.Any] = {
            "cluster_version": cluster_version,
            "component_version": component_version,
            "gateway": gateway,
            "location": location,
            "name": name,
            "resource_group_name": resource_group_name,
            "roles": roles,
            "tier": tier,
        }
        if count is not None:
            self._values["count"] = count
        if depends_on is not None:
            self._values["depends_on"] = depends_on
        if lifecycle is not None:
            self._values["lifecycle"] = lifecycle
        if provider is not None:
            self._values["provider"] = provider
        if storage_account is not None:
            self._values["storage_account"] = storage_account
        if storage_account_gen2 is not None:
            self._values["storage_account_gen2"] = storage_account_gen2
        if tags is not None:
            self._values["tags"] = tags
        if timeouts is not None:
            self._values["timeouts"] = timeouts

    @builtins.property
    def count(self) -> typing.Optional[jsii.Number]:
        """
        :stability: experimental
        """
        result = self._values.get("count")
        return result

    @builtins.property
    def depends_on(self) -> typing.Optional[typing.List[cdktf.TerraformResource]]:
        """
        :stability: experimental
        """
        result = self._values.get("depends_on")
        return result

    @builtins.property
    def lifecycle(self) -> typing.Optional[cdktf.TerraformResourceLifecycle]:
        """
        :stability: experimental
        """
        result = self._values.get("lifecycle")
        return result

    @builtins.property
    def provider(self) -> typing.Optional[cdktf.TerraformProvider]:
        """
        :stability: experimental
        """
        result = self._values.get("provider")
        return result

    @builtins.property
    def cluster_version(self) -> builtins.str:
        result = self._values.get("cluster_version")
        assert result is not None, "Required property 'cluster_version' is missing"
        return result

    @builtins.property
    def component_version(self) -> typing.List[HdinsightHbaseClusterComponentVersion]:
        """component_version block."""
        result = self._values.get("component_version")
        assert result is not None, "Required property 'component_version' is missing"
        return result

    @builtins.property
    def gateway(self) -> typing.List["HdinsightHbaseClusterGateway"]:
        """gateway block."""
        result = self._values.get("gateway")
        assert result is not None, "Required property 'gateway' is missing"
        return result

    @builtins.property
    def location(self) -> builtins.str:
        result = self._values.get("location")
        assert result is not None, "Required property 'location' is missing"
        return result

    @builtins.property
    def name(self) -> builtins.str:
        result = self._values.get("name")
        assert result is not None, "Required property 'name' is missing"
        return result

    @builtins.property
    def resource_group_name(self) -> builtins.str:
        result = self._values.get("resource_group_name")
        assert result is not None, "Required property 'resource_group_name' is missing"
        return result

    @builtins.property
    def roles(self) -> typing.List["HdinsightHbaseClusterRoles"]:
        """roles block."""
        result = self._values.get("roles")
        assert result is not None, "Required property 'roles' is missing"
        return result

    @builtins.property
    def tier(self) -> builtins.str:
        result = self._values.get("tier")
        assert result is not None, "Required property 'tier' is missing"
        return result

    @builtins.property
    def storage_account(
        self,
    ) -> typing.Optional[typing.List["HdinsightHbaseClusterStorageAccount"]]:
        """storage_account block."""
        result = self._values.get("storage_account")
        return result

    @builtins.property
    def storage_account_gen2(
        self,
    ) -> typing.Optional[typing.List["HdinsightHbaseClusterStorageAccountGen2"]]:
        """storage_account_gen2 block."""
        result = self._values.get("storage_account_gen2")
        return result

    @builtins.property
    def tags(self) -> typing.Optional[typing.Mapping[builtins.str, builtins.str]]:
        result = self._values.get("tags")
        return result

    @builtins.property
    def timeouts(self) -> typing.Optional["HdinsightHbaseClusterTimeouts"]:
        """timeouts block."""
        result = self._values.get("timeouts")
        return result

    def __eq__(self, rhs: typing.Any) -> builtins.bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs: typing.Any) -> builtins.bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return "HdinsightHbaseClusterConfig(%s)" % ", ".join(
            k + "=" + repr(v) for k, v in self._values.items()
        )


@jsii.data_type(
    jsii_type="@cdktf/provider-azurerm.HdinsightHbaseClusterGateway",
    jsii_struct_bases=[],
    name_mapping={
        "enabled": "enabled",
        "password": "password",
        "username": "username",
    },
)
class HdinsightHbaseClusterGateway:
    def __init__(
        self,
        *,
        enabled: builtins.bool,
        password: builtins.str,
        username: builtins.str,
    ) -> None:
        """
        :param enabled: 
        :param password: 
        :param username: 
        """
        self._values: typing.Dict[str, typing.Any] = {
            "enabled": enabled,
            "password": password,
            "username": username,
        }

    @builtins.property
    def enabled(self) -> builtins.bool:
        result = self._values.get("enabled")
        assert result is not None, "Required property 'enabled' is missing"
        return result

    @builtins.property
    def password(self) -> builtins.str:
        result = self._values.get("password")
        assert result is not None, "Required property 'password' is missing"
        return result

    @builtins.property
    def username(self) -> builtins.str:
        result = self._values.get("username")
        assert result is not None, "Required property 'username' is missing"
        return result

    def __eq__(self, rhs: typing.Any) -> builtins.bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs: typing.Any) -> builtins.bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return "HdinsightHbaseClusterGateway(%s)" % ", ".join(
            k + "=" + repr(v) for k, v in self._values.items()
        )


@jsii.data_type(
    jsii_type="@cdktf/provider-azurerm.HdinsightHbaseClusterRoles",
    jsii_struct_bases=[],
    name_mapping={
        "head_node": "headNode",
        "worker_node": "workerNode",
        "zookeeper_node": "zookeeperNode",
    },
)
class HdinsightHbaseClusterRoles:
    def __init__(
        self,
        *,
        head_node: typing.List["HdinsightHbaseClusterRolesHeadNode"],
        worker_node: typing.List["HdinsightHbaseClusterRolesWorkerNode"],
        zookeeper_node: typing.List["HdinsightHbaseClusterRolesZookeeperNode"],
    ) -> None:
        """
        :param head_node: head_node block.
        :param worker_node: worker_node block.
        :param zookeeper_node: zookeeper_node block.
        """
        self._values: typing.Dict[str, typing.Any] = {
            "head_node": head_node,
            "worker_node": worker_node,
            "zookeeper_node": zookeeper_node,
        }

    @builtins.property
    def head_node(self) -> typing.List["HdinsightHbaseClusterRolesHeadNode"]:
        """head_node block."""
        result = self._values.get("head_node")
        assert result is not None, "Required property 'head_node' is missing"
        return result

    @builtins.property
    def worker_node(self) -> typing.List["HdinsightHbaseClusterRolesWorkerNode"]:
        """worker_node block."""
        result = self._values.get("worker_node")
        assert result is not None, "Required property 'worker_node' is missing"
        return result

    @builtins.property
    def zookeeper_node(self) -> typing.List["HdinsightHbaseClusterRolesZookeeperNode"]:
        """zookeeper_node block."""
        result = self._values.get("zookeeper_node")
        assert result is not None, "Required property 'zookeeper_node' is missing"
        return result

    def __eq__(self, rhs: typing.Any) -> builtins.bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs: typing.Any) -> builtins.bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return "HdinsightHbaseClusterRoles(%s)" % ", ".join(
            k + "=" + repr(v) for k, v in self._values.items()
        )


@jsii.data_type(
    jsii_type="@cdktf/provider-azurerm.HdinsightHbaseClusterRolesHeadNode",
    jsii_struct_bases=[],
    name_mapping={
        "username": "username",
        "vm_size": "vmSize",
        "password": "password",
        "ssh_keys": "sshKeys",
        "subnet_id": "subnetId",
        "virtual_network_id": "virtualNetworkId",
    },
)
class HdinsightHbaseClusterRolesHeadNode:
    def __init__(
        self,
        *,
        username: builtins.str,
        vm_size: builtins.str,
        password: typing.Optional[builtins.str] = None,
        ssh_keys: typing.Optional[typing.List[builtins.str]] = None,
        subnet_id: typing.Optional[builtins.str] = None,
        virtual_network_id: typing.Optional[builtins.str] = None,
    ) -> None:
        """
        :param username: 
        :param vm_size: 
        :param password: 
        :param ssh_keys: 
        :param subnet_id: 
        :param virtual_network_id: 
        """
        self._values: typing.Dict[str, typing.Any] = {
            "username": username,
            "vm_size": vm_size,
        }
        if password is not None:
            self._values["password"] = password
        if ssh_keys is not None:
            self._values["ssh_keys"] = ssh_keys
        if subnet_id is not None:
            self._values["subnet_id"] = subnet_id
        if virtual_network_id is not None:
            self._values["virtual_network_id"] = virtual_network_id

    @builtins.property
    def username(self) -> builtins.str:
        result = self._values.get("username")
        assert result is not None, "Required property 'username' is missing"
        return result

    @builtins.property
    def vm_size(self) -> builtins.str:
        result = self._values.get("vm_size")
        assert result is not None, "Required property 'vm_size' is missing"
        return result

    @builtins.property
    def password(self) -> typing.Optional[builtins.str]:
        result = self._values.get("password")
        return result

    @builtins.property
    def ssh_keys(self) -> typing.Optional[typing.List[builtins.str]]:
        result = self._values.get("ssh_keys")
        return result

    @builtins.property
    def subnet_id(self) -> typing.Optional[builtins.str]:
        result = self._values.get("subnet_id")
        return result

    @builtins.property
    def virtual_network_id(self) -> typing.Optional[builtins.str]:
        result = self._values.get("virtual_network_id")
        return result

    def __eq__(self, rhs: typing.Any) -> builtins.bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs: typing.Any) -> builtins.bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return "HdinsightHbaseClusterRolesHeadNode(%s)" % ", ".join(
            k + "=" + repr(v) for k, v in self._values.items()
        )


@jsii.data_type(
    jsii_type="@cdktf/provider-azurerm.HdinsightHbaseClusterRolesWorkerNode",
    jsii_struct_bases=[],
    name_mapping={
        "target_instance_count": "targetInstanceCount",
        "username": "username",
        "vm_size": "vmSize",
        "min_instance_count": "minInstanceCount",
        "password": "password",
        "ssh_keys": "sshKeys",
        "subnet_id": "subnetId",
        "virtual_network_id": "virtualNetworkId",
    },
)
class HdinsightHbaseClusterRolesWorkerNode:
    def __init__(
        self,
        *,
        target_instance_count: jsii.Number,
        username: builtins.str,
        vm_size: builtins.str,
        min_instance_count: typing.Optional[jsii.Number] = None,
        password: typing.Optional[builtins.str] = None,
        ssh_keys: typing.Optional[typing.List[builtins.str]] = None,
        subnet_id: typing.Optional[builtins.str] = None,
        virtual_network_id: typing.Optional[builtins.str] = None,
    ) -> None:
        """
        :param target_instance_count: 
        :param username: 
        :param vm_size: 
        :param min_instance_count: 
        :param password: 
        :param ssh_keys: 
        :param subnet_id: 
        :param virtual_network_id: 
        """
        self._values: typing.Dict[str, typing.Any] = {
            "target_instance_count": target_instance_count,
            "username": username,
            "vm_size": vm_size,
        }
        if min_instance_count is not None:
            self._values["min_instance_count"] = min_instance_count
        if password is not None:
            self._values["password"] = password
        if ssh_keys is not None:
            self._values["ssh_keys"] = ssh_keys
        if subnet_id is not None:
            self._values["subnet_id"] = subnet_id
        if virtual_network_id is not None:
            self._values["virtual_network_id"] = virtual_network_id

    @builtins.property
    def target_instance_count(self) -> jsii.Number:
        result = self._values.get("target_instance_count")
        assert result is not None, "Required property 'target_instance_count' is missing"
        return result

    @builtins.property
    def username(self) -> builtins.str:
        result = self._values.get("username")
        assert result is not None, "Required property 'username' is missing"
        return result

    @builtins.property
    def vm_size(self) -> builtins.str:
        result = self._values.get("vm_size")
        assert result is not None, "Required property 'vm_size' is missing"
        return result

    @builtins.property
    def min_instance_count(self) -> typing.Optional[jsii.Number]:
        result = self._values.get("min_instance_count")
        return result

    @builtins.property
    def password(self) -> typing.Optional[builtins.str]:
        result = self._values.get("password")
        return result

    @builtins.property
    def ssh_keys(self) -> typing.Optional[typing.List[builtins.str]]:
        result = self._values.get("ssh_keys")
        return result

    @builtins.property
    def subnet_id(self) -> typing.Optional[builtins.str]:
        result = self._values.get("subnet_id")
        return result

    @builtins.property
    def virtual_network_id(self) -> typing.Optional[builtins.str]:
        result = self._values.get("virtual_network_id")
        return result

    def __eq__(self, rhs: typing.Any) -> builtins.bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs: typing.Any) -> builtins.bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return "HdinsightHbaseClusterRolesWorkerNode(%s)" % ", ".join(
            k + "=" + repr(v) for k, v in self._values.items()
        )


@jsii.data_type(
    jsii_type="@cdktf/provider-azurerm.HdinsightHbaseClusterRolesZookeeperNode",
    jsii_struct_bases=[],
    name_mapping={
        "username": "username",
        "vm_size": "vmSize",
        "password": "password",
        "ssh_keys": "sshKeys",
        "subnet_id": "subnetId",
        "virtual_network_id": "virtualNetworkId",
    },
)
class HdinsightHbaseClusterRolesZookeeperNode:
    def __init__(
        self,
        *,
        username: builtins.str,
        vm_size: builtins.str,
        password: typing.Optional[builtins.str] = None,
        ssh_keys: typing.Optional[typing.List[builtins.str]] = None,
        subnet_id: typing.Optional[builtins.str] = None,
        virtual_network_id: typing.Optional[builtins.str] = None,
    ) -> None:
        """
        :param username: 
        :param vm_size: 
        :param password: 
        :param ssh_keys: 
        :param subnet_id: 
        :param virtual_network_id: 
        """
        self._values: typing.Dict[str, typing.Any] = {
            "username": username,
            "vm_size": vm_size,
        }
        if password is not None:
            self._values["password"] = password
        if ssh_keys is not None:
            self._values["ssh_keys"] = ssh_keys
        if subnet_id is not None:
            self._values["subnet_id"] = subnet_id
        if virtual_network_id is not None:
            self._values["virtual_network_id"] = virtual_network_id

    @builtins.property
    def username(self) -> builtins.str:
        result = self._values.get("username")
        assert result is not None, "Required property 'username' is missing"
        return result

    @builtins.property
    def vm_size(self) -> builtins.str:
        result = self._values.get("vm_size")
        assert result is not None, "Required property 'vm_size' is missing"
        return result

    @builtins.property
    def password(self) -> typing.Optional[builtins.str]:
        result = self._values.get("password")
        return result

    @builtins.property
    def ssh_keys(self) -> typing.Optional[typing.List[builtins.str]]:
        result = self._values.get("ssh_keys")
        return result

    @builtins.property
    def subnet_id(self) -> typing.Optional[builtins.str]:
        result = self._values.get("subnet_id")
        return result

    @builtins.property
    def virtual_network_id(self) -> typing.Optional[builtins.str]:
        result = self._values.get("virtual_network_id")
        return result

    def __eq__(self, rhs: typing.Any) -> builtins.bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs: typing.Any) -> builtins.bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return "HdinsightHbaseClusterRolesZookeeperNode(%s)" % ", ".join(
            k + "=" + repr(v) for k, v in self._values.items()
        )


@jsii.data_type(
    jsii_type="@cdktf/provider-azurerm.HdinsightHbaseClusterStorageAccount",
    jsii_struct_bases=[],
    name_mapping={
        "is_default": "isDefault",
        "storage_account_key": "storageAccountKey",
        "storage_container_id": "storageContainerId",
    },
)
class HdinsightHbaseClusterStorageAccount:
    def __init__(
        self,
        *,
        is_default: builtins.bool,
        storage_account_key: builtins.str,
        storage_container_id: builtins.str,
    ) -> None:
        """
        :param is_default: 
        :param storage_account_key: 
        :param storage_container_id: 
        """
        self._values: typing.Dict[str, typing.Any] = {
            "is_default": is_default,
            "storage_account_key": storage_account_key,
            "storage_container_id": storage_container_id,
        }

    @builtins.property
    def is_default(self) -> builtins.bool:
        result = self._values.get("is_default")
        assert result is not None, "Required property 'is_default' is missing"
        return result

    @builtins.property
    def storage_account_key(self) -> builtins.str:
        result = self._values.get("storage_account_key")
        assert result is not None, "Required property 'storage_account_key' is missing"
        return result

    @builtins.property
    def storage_container_id(self) -> builtins.str:
        result = self._values.get("storage_container_id")
        assert result is not None, "Required property 'storage_container_id' is missing"
        return result

    def __eq__(self, rhs: typing.Any) -> builtins.bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs: typing.Any) -> builtins.bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return "HdinsightHbaseClusterStorageAccount(%s)" % ", ".join(
            k + "=" + repr(v) for k, v in self._values.items()
        )


@jsii.data_type(
    jsii_type="@cdktf/provider-azurerm.HdinsightHbaseClusterStorageAccountGen2",
    jsii_struct_bases=[],
    name_mapping={
        "filesystem_id": "filesystemId",
        "is_default": "isDefault",
        "managed_identity_resource_id": "managedIdentityResourceId",
        "storage_resource_id": "storageResourceId",
    },
)
class HdinsightHbaseClusterStorageAccountGen2:
    def __init__(
        self,
        *,
        filesystem_id: builtins.str,
        is_default: builtins.bool,
        managed_identity_resource_id: builtins.str,
        storage_resource_id: builtins.str,
    ) -> None:
        """
        :param filesystem_id: 
        :param is_default: 
        :param managed_identity_resource_id: 
        :param storage_resource_id: 
        """
        self._values: typing.Dict[str, typing.Any] = {
            "filesystem_id": filesystem_id,
            "is_default": is_default,
            "managed_identity_resource_id": managed_identity_resource_id,
            "storage_resource_id": storage_resource_id,
        }

    @builtins.property
    def filesystem_id(self) -> builtins.str:
        result = self._values.get("filesystem_id")
        assert result is not None, "Required property 'filesystem_id' is missing"
        return result

    @builtins.property
    def is_default(self) -> builtins.bool:
        result = self._values.get("is_default")
        assert result is not None, "Required property 'is_default' is missing"
        return result

    @builtins.property
    def managed_identity_resource_id(self) -> builtins.str:
        result = self._values.get("managed_identity_resource_id")
        assert result is not None, "Required property 'managed_identity_resource_id' is missing"
        return result

    @builtins.property
    def storage_resource_id(self) -> builtins.str:
        result = self._values.get("storage_resource_id")
        assert result is not None, "Required property 'storage_resource_id' is missing"
        return result

    def __eq__(self, rhs: typing.Any) -> builtins.bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs: typing.Any) -> builtins.bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return "HdinsightHbaseClusterStorageAccountGen2(%s)" % ", ".join(
            k + "=" + repr(v) for k, v in self._values.items()
        )


@jsii.data_type(
    jsii_type="@cdktf/provider-azurerm.HdinsightHbaseClusterTimeouts",
    jsii_struct_bases=[],
    name_mapping={
        "create": "create",
        "delete": "delete",
        "read": "read",
        "update": "update",
    },
)
class HdinsightHbaseClusterTimeouts:
    def __init__(
        self,
        *,
        create: typing.Optional[builtins.str] = None,
        delete: typing.Optional[builtins.str] = None,
        read: typing.Optional[builtins.str] = None,
        update: typing.Optional[builtins.str] = None,
    ) -> None:
        """
        :param create: 
        :param delete: 
        :param read: 
        :param update: 
        """
        self._values: typing.Dict[str, typing.Any] = {}
        if create is not None:
            self._values["create"] = create
        if delete is not None:
            self._values["delete"] = delete
        if read is not None:
            self._values["read"] = read
        if update is not None:
            self._values["update"] = update

    @builtins.property
    def create(self) -> typing.Optional[builtins.str]:
        result = self._values.get("create")
        return result

    @builtins.property
    def delete(self) -> typing.Optional[builtins.str]:
        result = self._values.get("delete")
        return result

    @builtins.property
    def read(self) -> typing.Optional[builtins.str]:
        result = self._values.get("read")
        return result

    @builtins.property
    def update(self) -> typing.Optional[builtins.str]:
        result = self._values.get("update")
        return result

    def __eq__(self, rhs: typing.Any) -> builtins.bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs: typing.Any) -> builtins.bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return "HdinsightHbaseClusterTimeouts(%s)" % ", ".join(
            k + "=" + repr(v) for k, v in self._values.items()
        )


class HdinsightInteractiveQueryCluster(
    cdktf.TerraformResource,
    metaclass=jsii.JSIIMeta,
    jsii_type="@cdktf/provider-azurerm.HdinsightInteractiveQueryCluster",
):
    def __init__(
        self,
        scope: constructs.Construct,
        id: builtins.str,
        *,
        cluster_version: builtins.str,
        component_version: typing.List["HdinsightInteractiveQueryClusterComponentVersion"],
        gateway: typing.List["HdinsightInteractiveQueryClusterGateway"],
        location: builtins.str,
        name: builtins.str,
        resource_group_name: builtins.str,
        roles: typing.List["HdinsightInteractiveQueryClusterRoles"],
        tier: builtins.str,
        storage_account: typing.Optional[typing.List["HdinsightInteractiveQueryClusterStorageAccount"]] = None,
        storage_account_gen2: typing.Optional[typing.List["HdinsightInteractiveQueryClusterStorageAccountGen2"]] = None,
        tags: typing.Optional[typing.Mapping[builtins.str, builtins.str]] = None,
        timeouts: typing.Optional["HdinsightInteractiveQueryClusterTimeouts"] = None,
        count: typing.Optional[jsii.Number] = None,
        depends_on: typing.Optional[typing.List[cdktf.TerraformResource]] = None,
        lifecycle: typing.Optional[cdktf.TerraformResourceLifecycle] = None,
        provider: typing.Optional[cdktf.TerraformProvider] = None,
    ) -> None:
        """
        :param scope: -
        :param id: -
        :param cluster_version: 
        :param component_version: component_version block.
        :param gateway: gateway block.
        :param location: 
        :param name: 
        :param resource_group_name: 
        :param roles: roles block.
        :param tier: 
        :param storage_account: storage_account block.
        :param storage_account_gen2: storage_account_gen2 block.
        :param tags: 
        :param timeouts: timeouts block.
        :param count: 
        :param depends_on: 
        :param lifecycle: 
        :param provider: 
        """
        config = HdinsightInteractiveQueryClusterConfig(
            cluster_version=cluster_version,
            component_version=component_version,
            gateway=gateway,
            location=location,
            name=name,
            resource_group_name=resource_group_name,
            roles=roles,
            tier=tier,
            storage_account=storage_account,
            storage_account_gen2=storage_account_gen2,
            tags=tags,
            timeouts=timeouts,
            count=count,
            depends_on=depends_on,
            lifecycle=lifecycle,
            provider=provider,
        )

        jsii.create(HdinsightInteractiveQueryCluster, self, [scope, id, config])

    @jsii.member(jsii_name="synthesizeAttributes")
    def _synthesize_attributes(self) -> typing.Mapping[builtins.str, typing.Any]:
        return jsii.invoke(self, "synthesizeAttributes", [])

    @builtins.property # type: ignore
    @jsii.member(jsii_name="httpsEndpoint")
    def https_endpoint(self) -> builtins.str:
        return jsii.get(self, "httpsEndpoint")

    @builtins.property # type: ignore
    @jsii.member(jsii_name="sshEndpoint")
    def ssh_endpoint(self) -> builtins.str:
        return jsii.get(self, "sshEndpoint")

    @builtins.property # type: ignore
    @jsii.member(jsii_name="clusterVersion")
    def cluster_version(self) -> builtins.str:
        return jsii.get(self, "clusterVersion")

    @cluster_version.setter # type: ignore
    def cluster_version(self, value: builtins.str) -> None:
        jsii.set(self, "clusterVersion", value)

    @builtins.property # type: ignore
    @jsii.member(jsii_name="componentVersion")
    def component_version(
        self,
    ) -> typing.List["HdinsightInteractiveQueryClusterComponentVersion"]:
        return jsii.get(self, "componentVersion")

    @component_version.setter # type: ignore
    def component_version(
        self,
        value: typing.List["HdinsightInteractiveQueryClusterComponentVersion"],
    ) -> None:
        jsii.set(self, "componentVersion", value)

    @builtins.property # type: ignore
    @jsii.member(jsii_name="gateway")
    def gateway(self) -> typing.List["HdinsightInteractiveQueryClusterGateway"]:
        return jsii.get(self, "gateway")

    @gateway.setter # type: ignore
    def gateway(
        self,
        value: typing.List["HdinsightInteractiveQueryClusterGateway"],
    ) -> None:
        jsii.set(self, "gateway", value)

    @builtins.property # type: ignore
    @jsii.member(jsii_name="location")
    def location(self) -> builtins.str:
        return jsii.get(self, "location")

    @location.setter # type: ignore
    def location(self, value: builtins.str) -> None:
        jsii.set(self, "location", value)

    @builtins.property # type: ignore
    @jsii.member(jsii_name="name")
    def name(self) -> builtins.str:
        return jsii.get(self, "name")

    @name.setter # type: ignore
    def name(self, value: builtins.str) -> None:
        jsii.set(self, "name", value)

    @builtins.property # type: ignore
    @jsii.member(jsii_name="resourceGroupName")
    def resource_group_name(self) -> builtins.str:
        return jsii.get(self, "resourceGroupName")

    @resource_group_name.setter # type: ignore
    def resource_group_name(self, value: builtins.str) -> None:
        jsii.set(self, "resourceGroupName", value)

    @builtins.property # type: ignore
    @jsii.member(jsii_name="roles")
    def roles(self) -> typing.List["HdinsightInteractiveQueryClusterRoles"]:
        return jsii.get(self, "roles")

    @roles.setter # type: ignore
    def roles(
        self,
        value: typing.List["HdinsightInteractiveQueryClusterRoles"],
    ) -> None:
        jsii.set(self, "roles", value)

    @builtins.property # type: ignore
    @jsii.member(jsii_name="tier")
    def tier(self) -> builtins.str:
        return jsii.get(self, "tier")

    @tier.setter # type: ignore
    def tier(self, value: builtins.str) -> None:
        jsii.set(self, "tier", value)

    @builtins.property # type: ignore
    @jsii.member(jsii_name="id")
    def id(self) -> typing.Optional[builtins.str]:
        return jsii.get(self, "id")

    @id.setter # type: ignore
    def id(self, value: typing.Optional[builtins.str]) -> None:
        jsii.set(self, "id", value)

    @builtins.property # type: ignore
    @jsii.member(jsii_name="storageAccount")
    def storage_account(
        self,
    ) -> typing.Optional[typing.List["HdinsightInteractiveQueryClusterStorageAccount"]]:
        return jsii.get(self, "storageAccount")

    @storage_account.setter # type: ignore
    def storage_account(
        self,
        value: typing.Optional[typing.List["HdinsightInteractiveQueryClusterStorageAccount"]],
    ) -> None:
        jsii.set(self, "storageAccount", value)

    @builtins.property # type: ignore
    @jsii.member(jsii_name="storageAccountGen2")
    def storage_account_gen2(
        self,
    ) -> typing.Optional[typing.List["HdinsightInteractiveQueryClusterStorageAccountGen2"]]:
        return jsii.get(self, "storageAccountGen2")

    @storage_account_gen2.setter # type: ignore
    def storage_account_gen2(
        self,
        value: typing.Optional[typing.List["HdinsightInteractiveQueryClusterStorageAccountGen2"]],
    ) -> None:
        jsii.set(self, "storageAccountGen2", value)

    @builtins.property # type: ignore
    @jsii.member(jsii_name="tags")
    def tags(self) -> typing.Optional[typing.Mapping[builtins.str, builtins.str]]:
        return jsii.get(self, "tags")

    @tags.setter # type: ignore
    def tags(
        self,
        value: typing.Optional[typing.Mapping[builtins.str, builtins.str]],
    ) -> None:
        jsii.set(self, "tags", value)

    @builtins.property # type: ignore
    @jsii.member(jsii_name="timeouts")
    def timeouts(self) -> typing.Optional["HdinsightInteractiveQueryClusterTimeouts"]:
        return jsii.get(self, "timeouts")

    @timeouts.setter # type: ignore
    def timeouts(
        self,
        value: typing.Optional["HdinsightInteractiveQueryClusterTimeouts"],
    ) -> None:
        jsii.set(self, "timeouts", value)


@jsii.data_type(
    jsii_type="@cdktf/provider-azurerm.HdinsightInteractiveQueryClusterComponentVersion",
    jsii_struct_bases=[],
    name_mapping={"interactive_hive": "interactiveHive"},
)
class HdinsightInteractiveQueryClusterComponentVersion:
    def __init__(self, *, interactive_hive: builtins.str) -> None:
        """
        :param interactive_hive: 
        """
        self._values: typing.Dict[str, typing.Any] = {
            "interactive_hive": interactive_hive,
        }

    @builtins.property
    def interactive_hive(self) -> builtins.str:
        result = self._values.get("interactive_hive")
        assert result is not None, "Required property 'interactive_hive' is missing"
        return result

    def __eq__(self, rhs: typing.Any) -> builtins.bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs: typing.Any) -> builtins.bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return "HdinsightInteractiveQueryClusterComponentVersion(%s)" % ", ".join(
            k + "=" + repr(v) for k, v in self._values.items()
        )


@jsii.data_type(
    jsii_type="@cdktf/provider-azurerm.HdinsightInteractiveQueryClusterConfig",
    jsii_struct_bases=[cdktf.TerraformMetaArguments],
    name_mapping={
        "count": "count",
        "depends_on": "dependsOn",
        "lifecycle": "lifecycle",
        "provider": "provider",
        "cluster_version": "clusterVersion",
        "component_version": "componentVersion",
        "gateway": "gateway",
        "location": "location",
        "name": "name",
        "resource_group_name": "resourceGroupName",
        "roles": "roles",
        "tier": "tier",
        "storage_account": "storageAccount",
        "storage_account_gen2": "storageAccountGen2",
        "tags": "tags",
        "timeouts": "timeouts",
    },
)
class HdinsightInteractiveQueryClusterConfig(cdktf.TerraformMetaArguments):
    def __init__(
        self,
        *,
        count: typing.Optional[jsii.Number] = None,
        depends_on: typing.Optional[typing.List[cdktf.TerraformResource]] = None,
        lifecycle: typing.Optional[cdktf.TerraformResourceLifecycle] = None,
        provider: typing.Optional[cdktf.TerraformProvider] = None,
        cluster_version: builtins.str,
        component_version: typing.List[HdinsightInteractiveQueryClusterComponentVersion],
        gateway: typing.List["HdinsightInteractiveQueryClusterGateway"],
        location: builtins.str,
        name: builtins.str,
        resource_group_name: builtins.str,
        roles: typing.List["HdinsightInteractiveQueryClusterRoles"],
        tier: builtins.str,
        storage_account: typing.Optional[typing.List["HdinsightInteractiveQueryClusterStorageAccount"]] = None,
        storage_account_gen2: typing.Optional[typing.List["HdinsightInteractiveQueryClusterStorageAccountGen2"]] = None,
        tags: typing.Optional[typing.Mapping[builtins.str, builtins.str]] = None,
        timeouts: typing.Optional["HdinsightInteractiveQueryClusterTimeouts"] = None,
    ) -> None:
        """
        :param count: 
        :param depends_on: 
        :param lifecycle: 
        :param provider: 
        :param cluster_version: 
        :param component_version: component_version block.
        :param gateway: gateway block.
        :param location: 
        :param name: 
        :param resource_group_name: 
        :param roles: roles block.
        :param tier: 
        :param storage_account: storage_account block.
        :param storage_account_gen2: storage_account_gen2 block.
        :param tags: 
        :param timeouts: timeouts block.
        """
        if isinstance(lifecycle, dict):
            lifecycle = cdktf.TerraformResourceLifecycle(**lifecycle)
        if isinstance(timeouts, dict):
            timeouts = HdinsightInteractiveQueryClusterTimeouts(**timeouts)
        self._values: typing.Dict[str, typing.Any] = {
            "cluster_version": cluster_version,
            "component_version": component_version,
            "gateway": gateway,
            "location": location,
            "name": name,
            "resource_group_name": resource_group_name,
            "roles": roles,
            "tier": tier,
        }
        if count is not None:
            self._values["count"] = count
        if depends_on is not None:
            self._values["depends_on"] = depends_on
        if lifecycle is not None:
            self._values["lifecycle"] = lifecycle
        if provider is not None:
            self._values["provider"] = provider
        if storage_account is not None:
            self._values["storage_account"] = storage_account
        if storage_account_gen2 is not None:
            self._values["storage_account_gen2"] = storage_account_gen2
        if tags is not None:
            self._values["tags"] = tags
        if timeouts is not None:
            self._values["timeouts"] = timeouts

    @builtins.property
    def count(self) -> typing.Optional[jsii.Number]:
        """
        :stability: experimental
        """
        result = self._values.get("count")
        return result

    @builtins.property
    def depends_on(self) -> typing.Optional[typing.List[cdktf.TerraformResource]]:
        """
        :stability: experimental
        """
        result = self._values.get("depends_on")
        return result

    @builtins.property
    def lifecycle(self) -> typing.Optional[cdktf.TerraformResourceLifecycle]:
        """
        :stability: experimental
        """
        result = self._values.get("lifecycle")
        return result

    @builtins.property
    def provider(self) -> typing.Optional[cdktf.TerraformProvider]:
        """
        :stability: experimental
        """
        result = self._values.get("provider")
        return result

    @builtins.property
    def cluster_version(self) -> builtins.str:
        result = self._values.get("cluster_version")
        assert result is not None, "Required property 'cluster_version' is missing"
        return result

    @builtins.property
    def component_version(
        self,
    ) -> typing.List[HdinsightInteractiveQueryClusterComponentVersion]:
        """component_version block."""
        result = self._values.get("component_version")
        assert result is not None, "Required property 'component_version' is missing"
        return result

    @builtins.property
    def gateway(self) -> typing.List["HdinsightInteractiveQueryClusterGateway"]:
        """gateway block."""
        result = self._values.get("gateway")
        assert result is not None, "Required property 'gateway' is missing"
        return result

    @builtins.property
    def location(self) -> builtins.str:
        result = self._values.get("location")
        assert result is not None, "Required property 'location' is missing"
        return result

    @builtins.property
    def name(self) -> builtins.str:
        result = self._values.get("name")
        assert result is not None, "Required property 'name' is missing"
        return result

    @builtins.property
    def resource_group_name(self) -> builtins.str:
        result = self._values.get("resource_group_name")
        assert result is not None, "Required property 'resource_group_name' is missing"
        return result

    @builtins.property
    def roles(self) -> typing.List["HdinsightInteractiveQueryClusterRoles"]:
        """roles block."""
        result = self._values.get("roles")
        assert result is not None, "Required property 'roles' is missing"
        return result

    @builtins.property
    def tier(self) -> builtins.str:
        result = self._values.get("tier")
        assert result is not None, "Required property 'tier' is missing"
        return result

    @builtins.property
    def storage_account(
        self,
    ) -> typing.Optional[typing.List["HdinsightInteractiveQueryClusterStorageAccount"]]:
        """storage_account block."""
        result = self._values.get("storage_account")
        return result

    @builtins.property
    def storage_account_gen2(
        self,
    ) -> typing.Optional[typing.List["HdinsightInteractiveQueryClusterStorageAccountGen2"]]:
        """storage_account_gen2 block."""
        result = self._values.get("storage_account_gen2")
        return result

    @builtins.property
    def tags(self) -> typing.Optional[typing.Mapping[builtins.str, builtins.str]]:
        result = self._values.get("tags")
        return result

    @builtins.property
    def timeouts(self) -> typing.Optional["HdinsightInteractiveQueryClusterTimeouts"]:
        """timeouts block."""
        result = self._values.get("timeouts")
        return result

    def __eq__(self, rhs: typing.Any) -> builtins.bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs: typing.Any) -> builtins.bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return "HdinsightInteractiveQueryClusterConfig(%s)" % ", ".join(
            k + "=" + repr(v) for k, v in self._values.items()
        )


@jsii.data_type(
    jsii_type="@cdktf/provider-azurerm.HdinsightInteractiveQueryClusterGateway",
    jsii_struct_bases=[],
    name_mapping={
        "enabled": "enabled",
        "password": "password",
        "username": "username",
    },
)
class HdinsightInteractiveQueryClusterGateway:
    def __init__(
        self,
        *,
        enabled: builtins.bool,
        password: builtins.str,
        username: builtins.str,
    ) -> None:
        """
        :param enabled: 
        :param password: 
        :param username: 
        """
        self._values: typing.Dict[str, typing.Any] = {
            "enabled": enabled,
            "password": password,
            "username": username,
        }

    @builtins.property
    def enabled(self) -> builtins.bool:
        result = self._values.get("enabled")
        assert result is not None, "Required property 'enabled' is missing"
        return result

    @builtins.property
    def password(self) -> builtins.str:
        result = self._values.get("password")
        assert result is not None, "Required property 'password' is missing"
        return result

    @builtins.property
    def username(self) -> builtins.str:
        result = self._values.get("username")
        assert result is not None, "Required property 'username' is missing"
        return result

    def __eq__(self, rhs: typing.Any) -> builtins.bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs: typing.Any) -> builtins.bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return "HdinsightInteractiveQueryClusterGateway(%s)" % ", ".join(
            k + "=" + repr(v) for k, v in self._values.items()
        )


@jsii.data_type(
    jsii_type="@cdktf/provider-azurerm.HdinsightInteractiveQueryClusterRoles",
    jsii_struct_bases=[],
    name_mapping={
        "head_node": "headNode",
        "worker_node": "workerNode",
        "zookeeper_node": "zookeeperNode",
    },
)
class HdinsightInteractiveQueryClusterRoles:
    def __init__(
        self,
        *,
        head_node: typing.List["HdinsightInteractiveQueryClusterRolesHeadNode"],
        worker_node: typing.List["HdinsightInteractiveQueryClusterRolesWorkerNode"],
        zookeeper_node: typing.List["HdinsightInteractiveQueryClusterRolesZookeeperNode"],
    ) -> None:
        """
        :param head_node: head_node block.
        :param worker_node: worker_node block.
        :param zookeeper_node: zookeeper_node block.
        """
        self._values: typing.Dict[str, typing.Any] = {
            "head_node": head_node,
            "worker_node": worker_node,
            "zookeeper_node": zookeeper_node,
        }

    @builtins.property
    def head_node(self) -> typing.List["HdinsightInteractiveQueryClusterRolesHeadNode"]:
        """head_node block."""
        result = self._values.get("head_node")
        assert result is not None, "Required property 'head_node' is missing"
        return result

    @builtins.property
    def worker_node(
        self,
    ) -> typing.List["HdinsightInteractiveQueryClusterRolesWorkerNode"]:
        """worker_node block."""
        result = self._values.get("worker_node")
        assert result is not None, "Required property 'worker_node' is missing"
        return result

    @builtins.property
    def zookeeper_node(
        self,
    ) -> typing.List["HdinsightInteractiveQueryClusterRolesZookeeperNode"]:
        """zookeeper_node block."""
        result = self._values.get("zookeeper_node")
        assert result is not None, "Required property 'zookeeper_node' is missing"
        return result

    def __eq__(self, rhs: typing.Any) -> builtins.bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs: typing.Any) -> builtins.bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return "HdinsightInteractiveQueryClusterRoles(%s)" % ", ".join(
            k + "=" + repr(v) for k, v in self._values.items()
        )


@jsii.data_type(
    jsii_type="@cdktf/provider-azurerm.HdinsightInteractiveQueryClusterRolesHeadNode",
    jsii_struct_bases=[],
    name_mapping={
        "username": "username",
        "vm_size": "vmSize",
        "password": "password",
        "ssh_keys": "sshKeys",
        "subnet_id": "subnetId",
        "virtual_network_id": "virtualNetworkId",
    },
)
class HdinsightInteractiveQueryClusterRolesHeadNode:
    def __init__(
        self,
        *,
        username: builtins.str,
        vm_size: builtins.str,
        password: typing.Optional[builtins.str] = None,
        ssh_keys: typing.Optional[typing.List[builtins.str]] = None,
        subnet_id: typing.Optional[builtins.str] = None,
        virtual_network_id: typing.Optional[builtins.str] = None,
    ) -> None:
        """
        :param username: 
        :param vm_size: 
        :param password: 
        :param ssh_keys: 
        :param subnet_id: 
        :param virtual_network_id: 
        """
        self._values: typing.Dict[str, typing.Any] = {
            "username": username,
            "vm_size": vm_size,
        }
        if password is not None:
            self._values["password"] = password
        if ssh_keys is not None:
            self._values["ssh_keys"] = ssh_keys
        if subnet_id is not None:
            self._values["subnet_id"] = subnet_id
        if virtual_network_id is not None:
            self._values["virtual_network_id"] = virtual_network_id

    @builtins.property
    def username(self) -> builtins.str:
        result = self._values.get("username")
        assert result is not None, "Required property 'username' is missing"
        return result

    @builtins.property
    def vm_size(self) -> builtins.str:
        result = self._values.get("vm_size")
        assert result is not None, "Required property 'vm_size' is missing"
        return result

    @builtins.property
    def password(self) -> typing.Optional[builtins.str]:
        result = self._values.get("password")
        return result

    @builtins.property
    def ssh_keys(self) -> typing.Optional[typing.List[builtins.str]]:
        result = self._values.get("ssh_keys")
        return result

    @builtins.property
    def subnet_id(self) -> typing.Optional[builtins.str]:
        result = self._values.get("subnet_id")
        return result

    @builtins.property
    def virtual_network_id(self) -> typing.Optional[builtins.str]:
        result = self._values.get("virtual_network_id")
        return result

    def __eq__(self, rhs: typing.Any) -> builtins.bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs: typing.Any) -> builtins.bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return "HdinsightInteractiveQueryClusterRolesHeadNode(%s)" % ", ".join(
            k + "=" + repr(v) for k, v in self._values.items()
        )


@jsii.data_type(
    jsii_type="@cdktf/provider-azurerm.HdinsightInteractiveQueryClusterRolesWorkerNode",
    jsii_struct_bases=[],
    name_mapping={
        "target_instance_count": "targetInstanceCount",
        "username": "username",
        "vm_size": "vmSize",
        "min_instance_count": "minInstanceCount",
        "password": "password",
        "ssh_keys": "sshKeys",
        "subnet_id": "subnetId",
        "virtual_network_id": "virtualNetworkId",
    },
)
class HdinsightInteractiveQueryClusterRolesWorkerNode:
    def __init__(
        self,
        *,
        target_instance_count: jsii.Number,
        username: builtins.str,
        vm_size: builtins.str,
        min_instance_count: typing.Optional[jsii.Number] = None,
        password: typing.Optional[builtins.str] = None,
        ssh_keys: typing.Optional[typing.List[builtins.str]] = None,
        subnet_id: typing.Optional[builtins.str] = None,
        virtual_network_id: typing.Optional[builtins.str] = None,
    ) -> None:
        """
        :param target_instance_count: 
        :param username: 
        :param vm_size: 
        :param min_instance_count: 
        :param password: 
        :param ssh_keys: 
        :param subnet_id: 
        :param virtual_network_id: 
        """
        self._values: typing.Dict[str, typing.Any] = {
            "target_instance_count": target_instance_count,
            "username": username,
            "vm_size": vm_size,
        }
        if min_instance_count is not None:
            self._values["min_instance_count"] = min_instance_count
        if password is not None:
            self._values["password"] = password
        if ssh_keys is not None:
            self._values["ssh_keys"] = ssh_keys
        if subnet_id is not None:
            self._values["subnet_id"] = subnet_id
        if virtual_network_id is not None:
            self._values["virtual_network_id"] = virtual_network_id

    @builtins.property
    def target_instance_count(self) -> jsii.Number:
        result = self._values.get("target_instance_count")
        assert result is not None, "Required property 'target_instance_count' is missing"
        return result

    @builtins.property
    def username(self) -> builtins.str:
        result = self._values.get("username")
        assert result is not None, "Required property 'username' is missing"
        return result

    @builtins.property
    def vm_size(self) -> builtins.str:
        result = self._values.get("vm_size")
        assert result is not None, "Required property 'vm_size' is missing"
        return result

    @builtins.property
    def min_instance_count(self) -> typing.Optional[jsii.Number]:
        result = self._values.get("min_instance_count")
        return result

    @builtins.property
    def password(self) -> typing.Optional[builtins.str]:
        result = self._values.get("password")
        return result

    @builtins.property
    def ssh_keys(self) -> typing.Optional[typing.List[builtins.str]]:
        result = self._values.get("ssh_keys")
        return result

    @builtins.property
    def subnet_id(self) -> typing.Optional[builtins.str]:
        result = self._values.get("subnet_id")
        return result

    @builtins.property
    def virtual_network_id(self) -> typing.Optional[builtins.str]:
        result = self._values.get("virtual_network_id")
        return result

    def __eq__(self, rhs: typing.Any) -> builtins.bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs: typing.Any) -> builtins.bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return "HdinsightInteractiveQueryClusterRolesWorkerNode(%s)" % ", ".join(
            k + "=" + repr(v) for k, v in self._values.items()
        )


@jsii.data_type(
    jsii_type="@cdktf/provider-azurerm.HdinsightInteractiveQueryClusterRolesZookeeperNode",
    jsii_struct_bases=[],
    name_mapping={
        "username": "username",
        "vm_size": "vmSize",
        "password": "password",
        "ssh_keys": "sshKeys",
        "subnet_id": "subnetId",
        "virtual_network_id": "virtualNetworkId",
    },
)
class HdinsightInteractiveQueryClusterRolesZookeeperNode:
    def __init__(
        self,
        *,
        username: builtins.str,
        vm_size: builtins.str,
        password: typing.Optional[builtins.str] = None,
        ssh_keys: typing.Optional[typing.List[builtins.str]] = None,
        subnet_id: typing.Optional[builtins.str] = None,
        virtual_network_id: typing.Optional[builtins.str] = None,
    ) -> None:
        """
        :param username: 
        :param vm_size: 
        :param password: 
        :param ssh_keys: 
        :param subnet_id: 
        :param virtual_network_id: 
        """
        self._values: typing.Dict[str, typing.Any] = {
            "username": username,
            "vm_size": vm_size,
        }
        if password is not None:
            self._values["password"] = password
        if ssh_keys is not None:
            self._values["ssh_keys"] = ssh_keys
        if subnet_id is not None:
            self._values["subnet_id"] = subnet_id
        if virtual_network_id is not None:
            self._values["virtual_network_id"] = virtual_network_id

    @builtins.property
    def username(self) -> builtins.str:
        result = self._values.get("username")
        assert result is not None, "Required property 'username' is missing"
        return result

    @builtins.property
    def vm_size(self) -> builtins.str:
        result = self._values.get("vm_size")
        assert result is not None, "Required property 'vm_size' is missing"
        return result

    @builtins.property
    def password(self) -> typing.Optional[builtins.str]:
        result = self._values.get("password")
        return result

    @builtins.property
    def ssh_keys(self) -> typing.Optional[typing.List[builtins.str]]:
        result = self._values.get("ssh_keys")
        return result

    @builtins.property
    def subnet_id(self) -> typing.Optional[builtins.str]:
        result = self._values.get("subnet_id")
        return result

    @builtins.property
    def virtual_network_id(self) -> typing.Optional[builtins.str]:
        result = self._values.get("virtual_network_id")
        return result

    def __eq__(self, rhs: typing.Any) -> builtins.bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs: typing.Any) -> builtins.bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return "HdinsightInteractiveQueryClusterRolesZookeeperNode(%s)" % ", ".join(
            k + "=" + repr(v) for k, v in self._values.items()
        )


@jsii.data_type(
    jsii_type="@cdktf/provider-azurerm.HdinsightInteractiveQueryClusterStorageAccount",
    jsii_struct_bases=[],
    name_mapping={
        "is_default": "isDefault",
        "storage_account_key": "storageAccountKey",
        "storage_container_id": "storageContainerId",
    },
)
class HdinsightInteractiveQueryClusterStorageAccount:
    def __init__(
        self,
        *,
        is_default: builtins.bool,
        storage_account_key: builtins.str,
        storage_container_id: builtins.str,
    ) -> None:
        """
        :param is_default: 
        :param storage_account_key: 
        :param storage_container_id: 
        """
        self._values: typing.Dict[str, typing.Any] = {
            "is_default": is_default,
            "storage_account_key": storage_account_key,
            "storage_container_id": storage_container_id,
        }

    @builtins.property
    def is_default(self) -> builtins.bool:
        result = self._values.get("is_default")
        assert result is not None, "Required property 'is_default' is missing"
        return result

    @builtins.property
    def storage_account_key(self) -> builtins.str:
        result = self._values.get("storage_account_key")
        assert result is not None, "Required property 'storage_account_key' is missing"
        return result

    @builtins.property
    def storage_container_id(self) -> builtins.str:
        result = self._values.get("storage_container_id")
        assert result is not None, "Required property 'storage_container_id' is missing"
        return result

    def __eq__(self, rhs: typing.Any) -> builtins.bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs: typing.Any) -> builtins.bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return "HdinsightInteractiveQueryClusterStorageAccount(%s)" % ", ".join(
            k + "=" + repr(v) for k, v in self._values.items()
        )


@jsii.data_type(
    jsii_type="@cdktf/provider-azurerm.HdinsightInteractiveQueryClusterStorageAccountGen2",
    jsii_struct_bases=[],
    name_mapping={
        "filesystem_id": "filesystemId",
        "is_default": "isDefault",
        "managed_identity_resource_id": "managedIdentityResourceId",
        "storage_resource_id": "storageResourceId",
    },
)
class HdinsightInteractiveQueryClusterStorageAccountGen2:
    def __init__(
        self,
        *,
        filesystem_id: builtins.str,
        is_default: builtins.bool,
        managed_identity_resource_id: builtins.str,
        storage_resource_id: builtins.str,
    ) -> None:
        """
        :param filesystem_id: 
        :param is_default: 
        :param managed_identity_resource_id: 
        :param storage_resource_id: 
        """
        self._values: typing.Dict[str, typing.Any] = {
            "filesystem_id": filesystem_id,
            "is_default": is_default,
            "managed_identity_resource_id": managed_identity_resource_id,
            "storage_resource_id": storage_resource_id,
        }

    @builtins.property
    def filesystem_id(self) -> builtins.str:
        result = self._values.get("filesystem_id")
        assert result is not None, "Required property 'filesystem_id' is missing"
        return result

    @builtins.property
    def is_default(self) -> builtins.bool:
        result = self._values.get("is_default")
        assert result is not None, "Required property 'is_default' is missing"
        return result

    @builtins.property
    def managed_identity_resource_id(self) -> builtins.str:
        result = self._values.get("managed_identity_resource_id")
        assert result is not None, "Required property 'managed_identity_resource_id' is missing"
        return result

    @builtins.property
    def storage_resource_id(self) -> builtins.str:
        result = self._values.get("storage_resource_id")
        assert result is not None, "Required property 'storage_resource_id' is missing"
        return result

    def __eq__(self, rhs: typing.Any) -> builtins.bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs: typing.Any) -> builtins.bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return "HdinsightInteractiveQueryClusterStorageAccountGen2(%s)" % ", ".join(
            k + "=" + repr(v) for k, v in self._values.items()
        )


@jsii.data_type(
    jsii_type="@cdktf/provider-azurerm.HdinsightInteractiveQueryClusterTimeouts",
    jsii_struct_bases=[],
    name_mapping={
        "create": "create",
        "delete": "delete",
        "read": "read",
        "update": "update",
    },
)
class HdinsightInteractiveQueryClusterTimeouts:
    def __init__(
        self,
        *,
        create: typing.Optional[builtins.str] = None,
        delete: typing.Optional[builtins.str] = None,
        read: typing.Optional[builtins.str] = None,
        update: typing.Optional[builtins.str] = None,
    ) -> None:
        """
        :param create: 
        :param delete: 
        :param read: 
        :param update: 
        """
        self._values: typing.Dict[str, typing.Any] = {}
        if create is not None:
            self._values["create"] = create
        if delete is not None:
            self._values["delete"] = delete
        if read is not None:
            self._values["read"] = read
        if update is not None:
            self._values["update"] = update

    @builtins.property
    def create(self) -> typing.Optional[builtins.str]:
        result = self._values.get("create")
        return result

    @builtins.property
    def delete(self) -> typing.Optional[builtins.str]:
        result = self._values.get("delete")
        return result

    @builtins.property
    def read(self) -> typing.Optional[builtins.str]:
        result = self._values.get("read")
        return result

    @builtins.property
    def update(self) -> typing.Optional[builtins.str]:
        result = self._values.get("update")
        return result

    def __eq__(self, rhs: typing.Any) -> builtins.bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs: typing.Any) -> builtins.bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return "HdinsightInteractiveQueryClusterTimeouts(%s)" % ", ".join(
            k + "=" + repr(v) for k, v in self._values.items()
        )


class HdinsightKafkaCluster(
    cdktf.TerraformResource,
    metaclass=jsii.JSIIMeta,
    jsii_type="@cdktf/provider-azurerm.HdinsightKafkaCluster",
):
    def __init__(
        self,
        scope: constructs.Construct,
        id: builtins.str,
        *,
        cluster_version: builtins.str,
        component_version: typing.List["HdinsightKafkaClusterComponentVersion"],
        gateway: typing.List["HdinsightKafkaClusterGateway"],
        location: builtins.str,
        name: builtins.str,
        resource_group_name: builtins.str,
        roles: typing.List["HdinsightKafkaClusterRoles"],
        tier: builtins.str,
        storage_account: typing.Optional[typing.List["HdinsightKafkaClusterStorageAccount"]] = None,
        storage_account_gen2: typing.Optional[typing.List["HdinsightKafkaClusterStorageAccountGen2"]] = None,
        tags: typing.Optional[typing.Mapping[builtins.str, builtins.str]] = None,
        timeouts: typing.Optional["HdinsightKafkaClusterTimeouts"] = None,
        count: typing.Optional[jsii.Number] = None,
        depends_on: typing.Optional[typing.List[cdktf.TerraformResource]] = None,
        lifecycle: typing.Optional[cdktf.TerraformResourceLifecycle] = None,
        provider: typing.Optional[cdktf.TerraformProvider] = None,
    ) -> None:
        """
        :param scope: -
        :param id: -
        :param cluster_version: 
        :param component_version: component_version block.
        :param gateway: gateway block.
        :param location: 
        :param name: 
        :param resource_group_name: 
        :param roles: roles block.
        :param tier: 
        :param storage_account: storage_account block.
        :param storage_account_gen2: storage_account_gen2 block.
        :param tags: 
        :param timeouts: timeouts block.
        :param count: 
        :param depends_on: 
        :param lifecycle: 
        :param provider: 
        """
        config = HdinsightKafkaClusterConfig(
            cluster_version=cluster_version,
            component_version=component_version,
            gateway=gateway,
            location=location,
            name=name,
            resource_group_name=resource_group_name,
            roles=roles,
            tier=tier,
            storage_account=storage_account,
            storage_account_gen2=storage_account_gen2,
            tags=tags,
            timeouts=timeouts,
            count=count,
            depends_on=depends_on,
            lifecycle=lifecycle,
            provider=provider,
        )

        jsii.create(HdinsightKafkaCluster, self, [scope, id, config])

    @jsii.member(jsii_name="synthesizeAttributes")
    def _synthesize_attributes(self) -> typing.Mapping[builtins.str, typing.Any]:
        return jsii.invoke(self, "synthesizeAttributes", [])

    @builtins.property # type: ignore
    @jsii.member(jsii_name="httpsEndpoint")
    def https_endpoint(self) -> builtins.str:
        return jsii.get(self, "httpsEndpoint")

    @builtins.property # type: ignore
    @jsii.member(jsii_name="sshEndpoint")
    def ssh_endpoint(self) -> builtins.str:
        return jsii.get(self, "sshEndpoint")

    @builtins.property # type: ignore
    @jsii.member(jsii_name="clusterVersion")
    def cluster_version(self) -> builtins.str:
        return jsii.get(self, "clusterVersion")

    @cluster_version.setter # type: ignore
    def cluster_version(self, value: builtins.str) -> None:
        jsii.set(self, "clusterVersion", value)

    @builtins.property # type: ignore
    @jsii.member(jsii_name="componentVersion")
    def component_version(self) -> typing.List["HdinsightKafkaClusterComponentVersion"]:
        return jsii.get(self, "componentVersion")

    @component_version.setter # type: ignore
    def component_version(
        self,
        value: typing.List["HdinsightKafkaClusterComponentVersion"],
    ) -> None:
        jsii.set(self, "componentVersion", value)

    @builtins.property # type: ignore
    @jsii.member(jsii_name="gateway")
    def gateway(self) -> typing.List["HdinsightKafkaClusterGateway"]:
        return jsii.get(self, "gateway")

    @gateway.setter # type: ignore
    def gateway(self, value: typing.List["HdinsightKafkaClusterGateway"]) -> None:
        jsii.set(self, "gateway", value)

    @builtins.property # type: ignore
    @jsii.member(jsii_name="location")
    def location(self) -> builtins.str:
        return jsii.get(self, "location")

    @location.setter # type: ignore
    def location(self, value: builtins.str) -> None:
        jsii.set(self, "location", value)

    @builtins.property # type: ignore
    @jsii.member(jsii_name="name")
    def name(self) -> builtins.str:
        return jsii.get(self, "name")

    @name.setter # type: ignore
    def name(self, value: builtins.str) -> None:
        jsii.set(self, "name", value)

    @builtins.property # type: ignore
    @jsii.member(jsii_name="resourceGroupName")
    def resource_group_name(self) -> builtins.str:
        return jsii.get(self, "resourceGroupName")

    @resource_group_name.setter # type: ignore
    def resource_group_name(self, value: builtins.str) -> None:
        jsii.set(self, "resourceGroupName", value)

    @builtins.property # type: ignore
    @jsii.member(jsii_name="roles")
    def roles(self) -> typing.List["HdinsightKafkaClusterRoles"]:
        return jsii.get(self, "roles")

    @roles.setter # type: ignore
    def roles(self, value: typing.List["HdinsightKafkaClusterRoles"]) -> None:
        jsii.set(self, "roles", value)

    @builtins.property # type: ignore
    @jsii.member(jsii_name="tier")
    def tier(self) -> builtins.str:
        return jsii.get(self, "tier")

    @tier.setter # type: ignore
    def tier(self, value: builtins.str) -> None:
        jsii.set(self, "tier", value)

    @builtins.property # type: ignore
    @jsii.member(jsii_name="id")
    def id(self) -> typing.Optional[builtins.str]:
        return jsii.get(self, "id")

    @id.setter # type: ignore
    def id(self, value: typing.Optional[builtins.str]) -> None:
        jsii.set(self, "id", value)

    @builtins.property # type: ignore
    @jsii.member(jsii_name="storageAccount")
    def storage_account(
        self,
    ) -> typing.Optional[typing.List["HdinsightKafkaClusterStorageAccount"]]:
        return jsii.get(self, "storageAccount")

    @storage_account.setter # type: ignore
    def storage_account(
        self,
        value: typing.Optional[typing.List["HdinsightKafkaClusterStorageAccount"]],
    ) -> None:
        jsii.set(self, "storageAccount", value)

    @builtins.property # type: ignore
    @jsii.member(jsii_name="storageAccountGen2")
    def storage_account_gen2(
        self,
    ) -> typing.Optional[typing.List["HdinsightKafkaClusterStorageAccountGen2"]]:
        return jsii.get(self, "storageAccountGen2")

    @storage_account_gen2.setter # type: ignore
    def storage_account_gen2(
        self,
        value: typing.Optional[typing.List["HdinsightKafkaClusterStorageAccountGen2"]],
    ) -> None:
        jsii.set(self, "storageAccountGen2", value)

    @builtins.property # type: ignore
    @jsii.member(jsii_name="tags")
    def tags(self) -> typing.Optional[typing.Mapping[builtins.str, builtins.str]]:
        return jsii.get(self, "tags")

    @tags.setter # type: ignore
    def tags(
        self,
        value: typing.Optional[typing.Mapping[builtins.str, builtins.str]],
    ) -> None:
        jsii.set(self, "tags", value)

    @builtins.property # type: ignore
    @jsii.member(jsii_name="timeouts")
    def timeouts(self) -> typing.Optional["HdinsightKafkaClusterTimeouts"]:
        return jsii.get(self, "timeouts")

    @timeouts.setter # type: ignore
    def timeouts(self, value: typing.Optional["HdinsightKafkaClusterTimeouts"]) -> None:
        jsii.set(self, "timeouts", value)


@jsii.data_type(
    jsii_type="@cdktf/provider-azurerm.HdinsightKafkaClusterComponentVersion",
    jsii_struct_bases=[],
    name_mapping={"kafka": "kafka"},
)
class HdinsightKafkaClusterComponentVersion:
    def __init__(self, *, kafka: builtins.str) -> None:
        """
        :param kafka: 
        """
        self._values: typing.Dict[str, typing.Any] = {
            "kafka": kafka,
        }

    @builtins.property
    def kafka(self) -> builtins.str:
        result = self._values.get("kafka")
        assert result is not None, "Required property 'kafka' is missing"
        return result

    def __eq__(self, rhs: typing.Any) -> builtins.bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs: typing.Any) -> builtins.bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return "HdinsightKafkaClusterComponentVersion(%s)" % ", ".join(
            k + "=" + repr(v) for k, v in self._values.items()
        )


@jsii.data_type(
    jsii_type="@cdktf/provider-azurerm.HdinsightKafkaClusterConfig",
    jsii_struct_bases=[cdktf.TerraformMetaArguments],
    name_mapping={
        "count": "count",
        "depends_on": "dependsOn",
        "lifecycle": "lifecycle",
        "provider": "provider",
        "cluster_version": "clusterVersion",
        "component_version": "componentVersion",
        "gateway": "gateway",
        "location": "location",
        "name": "name",
        "resource_group_name": "resourceGroupName",
        "roles": "roles",
        "tier": "tier",
        "storage_account": "storageAccount",
        "storage_account_gen2": "storageAccountGen2",
        "tags": "tags",
        "timeouts": "timeouts",
    },
)
class HdinsightKafkaClusterConfig(cdktf.TerraformMetaArguments):
    def __init__(
        self,
        *,
        count: typing.Optional[jsii.Number] = None,
        depends_on: typing.Optional[typing.List[cdktf.TerraformResource]] = None,
        lifecycle: typing.Optional[cdktf.TerraformResourceLifecycle] = None,
        provider: typing.Optional[cdktf.TerraformProvider] = None,
        cluster_version: builtins.str,
        component_version: typing.List[HdinsightKafkaClusterComponentVersion],
        gateway: typing.List["HdinsightKafkaClusterGateway"],
        location: builtins.str,
        name: builtins.str,
        resource_group_name: builtins.str,
        roles: typing.List["HdinsightKafkaClusterRoles"],
        tier: builtins.str,
        storage_account: typing.Optional[typing.List["HdinsightKafkaClusterStorageAccount"]] = None,
        storage_account_gen2: typing.Optional[typing.List["HdinsightKafkaClusterStorageAccountGen2"]] = None,
        tags: typing.Optional[typing.Mapping[builtins.str, builtins.str]] = None,
        timeouts: typing.Optional["HdinsightKafkaClusterTimeouts"] = None,
    ) -> None:
        """
        :param count: 
        :param depends_on: 
        :param lifecycle: 
        :param provider: 
        :param cluster_version: 
        :param component_version: component_version block.
        :param gateway: gateway block.
        :param location: 
        :param name: 
        :param resource_group_name: 
        :param roles: roles block.
        :param tier: 
        :param storage_account: storage_account block.
        :param storage_account_gen2: storage_account_gen2 block.
        :param tags: 
        :param timeouts: timeouts block.
        """
        if isinstance(lifecycle, dict):
            lifecycle = cdktf.TerraformResourceLifecycle(**lifecycle)
        if isinstance(timeouts, dict):
            timeouts = HdinsightKafkaClusterTimeouts(**timeouts)
        self._values: typing.Dict[str, typing.Any] = {
            "cluster_version": cluster_version,
            "component_version": component_version,
            "gateway": gateway,
            "location": location,
            "name": name,
            "resource_group_name": resource_group_name,
            "roles": roles,
            "tier": tier,
        }
        if count is not None:
            self._values["count"] = count
        if depends_on is not None:
            self._values["depends_on"] = depends_on
        if lifecycle is not None:
            self._values["lifecycle"] = lifecycle
        if provider is not None:
            self._values["provider"] = provider
        if storage_account is not None:
            self._values["storage_account"] = storage_account
        if storage_account_gen2 is not None:
            self._values["storage_account_gen2"] = storage_account_gen2
        if tags is not None:
            self._values["tags"] = tags
        if timeouts is not None:
            self._values["timeouts"] = timeouts

    @builtins.property
    def count(self) -> typing.Optional[jsii.Number]:
        """
        :stability: experimental
        """
        result = self._values.get("count")
        return result

    @builtins.property
    def depends_on(self) -> typing.Optional[typing.List[cdktf.TerraformResource]]:
        """
        :stability: experimental
        """
        result = self._values.get("depends_on")
        return result

    @builtins.property
    def lifecycle(self) -> typing.Optional[cdktf.TerraformResourceLifecycle]:
        """
        :stability: experimental
        """
        result = self._values.get("lifecycle")
        return result

    @builtins.property
    def provider(self) -> typing.Optional[cdktf.TerraformProvider]:
        """
        :stability: experimental
        """
        result = self._values.get("provider")
        return result

    @builtins.property
    def cluster_version(self) -> builtins.str:
        result = self._values.get("cluster_version")
        assert result is not None, "Required property 'cluster_version' is missing"
        return result

    @builtins.property
    def component_version(self) -> typing.List[HdinsightKafkaClusterComponentVersion]:
        """component_version block."""
        result = self._values.get("component_version")
        assert result is not None, "Required property 'component_version' is missing"
        return result

    @builtins.property
    def gateway(self) -> typing.List["HdinsightKafkaClusterGateway"]:
        """gateway block."""
        result = self._values.get("gateway")
        assert result is not None, "Required property 'gateway' is missing"
        return result

    @builtins.property
    def location(self) -> builtins.str:
        result = self._values.get("location")
        assert result is not None, "Required property 'location' is missing"
        return result

    @builtins.property
    def name(self) -> builtins.str:
        result = self._values.get("name")
        assert result is not None, "Required property 'name' is missing"
        return result

    @builtins.property
    def resource_group_name(self) -> builtins.str:
        result = self._values.get("resource_group_name")
        assert result is not None, "Required property 'resource_group_name' is missing"
        return result

    @builtins.property
    def roles(self) -> typing.List["HdinsightKafkaClusterRoles"]:
        """roles block."""
        result = self._values.get("roles")
        assert result is not None, "Required property 'roles' is missing"
        return result

    @builtins.property
    def tier(self) -> builtins.str:
        result = self._values.get("tier")
        assert result is not None, "Required property 'tier' is missing"
        return result

    @builtins.property
    def storage_account(
        self,
    ) -> typing.Optional[typing.List["HdinsightKafkaClusterStorageAccount"]]:
        """storage_account block."""
        result = self._values.get("storage_account")
        return result

    @builtins.property
    def storage_account_gen2(
        self,
    ) -> typing.Optional[typing.List["HdinsightKafkaClusterStorageAccountGen2"]]:
        """storage_account_gen2 block."""
        result = self._values.get("storage_account_gen2")
        return result

    @builtins.property
    def tags(self) -> typing.Optional[typing.Mapping[builtins.str, builtins.str]]:
        result = self._values.get("tags")
        return result

    @builtins.property
    def timeouts(self) -> typing.Optional["HdinsightKafkaClusterTimeouts"]:
        """timeouts block."""
        result = self._values.get("timeouts")
        return result

    def __eq__(self, rhs: typing.Any) -> builtins.bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs: typing.Any) -> builtins.bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return "HdinsightKafkaClusterConfig(%s)" % ", ".join(
            k + "=" + repr(v) for k, v in self._values.items()
        )


@jsii.data_type(
    jsii_type="@cdktf/provider-azurerm.HdinsightKafkaClusterGateway",
    jsii_struct_bases=[],
    name_mapping={
        "enabled": "enabled",
        "password": "password",
        "username": "username",
    },
)
class HdinsightKafkaClusterGateway:
    def __init__(
        self,
        *,
        enabled: builtins.bool,
        password: builtins.str,
        username: builtins.str,
    ) -> None:
        """
        :param enabled: 
        :param password: 
        :param username: 
        """
        self._values: typing.Dict[str, typing.Any] = {
            "enabled": enabled,
            "password": password,
            "username": username,
        }

    @builtins.property
    def enabled(self) -> builtins.bool:
        result = self._values.get("enabled")
        assert result is not None, "Required property 'enabled' is missing"
        return result

    @builtins.property
    def password(self) -> builtins.str:
        result = self._values.get("password")
        assert result is not None, "Required property 'password' is missing"
        return result

    @builtins.property
    def username(self) -> builtins.str:
        result = self._values.get("username")
        assert result is not None, "Required property 'username' is missing"
        return result

    def __eq__(self, rhs: typing.Any) -> builtins.bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs: typing.Any) -> builtins.bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return "HdinsightKafkaClusterGateway(%s)" % ", ".join(
            k + "=" + repr(v) for k, v in self._values.items()
        )


@jsii.data_type(
    jsii_type="@cdktf/provider-azurerm.HdinsightKafkaClusterRoles",
    jsii_struct_bases=[],
    name_mapping={
        "head_node": "headNode",
        "worker_node": "workerNode",
        "zookeeper_node": "zookeeperNode",
    },
)
class HdinsightKafkaClusterRoles:
    def __init__(
        self,
        *,
        head_node: typing.List["HdinsightKafkaClusterRolesHeadNode"],
        worker_node: typing.List["HdinsightKafkaClusterRolesWorkerNode"],
        zookeeper_node: typing.List["HdinsightKafkaClusterRolesZookeeperNode"],
    ) -> None:
        """
        :param head_node: head_node block.
        :param worker_node: worker_node block.
        :param zookeeper_node: zookeeper_node block.
        """
        self._values: typing.Dict[str, typing.Any] = {
            "head_node": head_node,
            "worker_node": worker_node,
            "zookeeper_node": zookeeper_node,
        }

    @builtins.property
    def head_node(self) -> typing.List["HdinsightKafkaClusterRolesHeadNode"]:
        """head_node block."""
        result = self._values.get("head_node")
        assert result is not None, "Required property 'head_node' is missing"
        return result

    @builtins.property
    def worker_node(self) -> typing.List["HdinsightKafkaClusterRolesWorkerNode"]:
        """worker_node block."""
        result = self._values.get("worker_node")
        assert result is not None, "Required property 'worker_node' is missing"
        return result

    @builtins.property
    def zookeeper_node(self) -> typing.List["HdinsightKafkaClusterRolesZookeeperNode"]:
        """zookeeper_node block."""
        result = self._values.get("zookeeper_node")
        assert result is not None, "Required property 'zookeeper_node' is missing"
        return result

    def __eq__(self, rhs: typing.Any) -> builtins.bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs: typing.Any) -> builtins.bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return "HdinsightKafkaClusterRoles(%s)" % ", ".join(
            k + "=" + repr(v) for k, v in self._values.items()
        )


@jsii.data_type(
    jsii_type="@cdktf/provider-azurerm.HdinsightKafkaClusterRolesHeadNode",
    jsii_struct_bases=[],
    name_mapping={
        "username": "username",
        "vm_size": "vmSize",
        "password": "password",
        "ssh_keys": "sshKeys",
        "subnet_id": "subnetId",
        "virtual_network_id": "virtualNetworkId",
    },
)
class HdinsightKafkaClusterRolesHeadNode:
    def __init__(
        self,
        *,
        username: builtins.str,
        vm_size: builtins.str,
        password: typing.Optional[builtins.str] = None,
        ssh_keys: typing.Optional[typing.List[builtins.str]] = None,
        subnet_id: typing.Optional[builtins.str] = None,
        virtual_network_id: typing.Optional[builtins.str] = None,
    ) -> None:
        """
        :param username: 
        :param vm_size: 
        :param password: 
        :param ssh_keys: 
        :param subnet_id: 
        :param virtual_network_id: 
        """
        self._values: typing.Dict[str, typing.Any] = {
            "username": username,
            "vm_size": vm_size,
        }
        if password is not None:
            self._values["password"] = password
        if ssh_keys is not None:
            self._values["ssh_keys"] = ssh_keys
        if subnet_id is not None:
            self._values["subnet_id"] = subnet_id
        if virtual_network_id is not None:
            self._values["virtual_network_id"] = virtual_network_id

    @builtins.property
    def username(self) -> builtins.str:
        result = self._values.get("username")
        assert result is not None, "Required property 'username' is missing"
        return result

    @builtins.property
    def vm_size(self) -> builtins.str:
        result = self._values.get("vm_size")
        assert result is not None, "Required property 'vm_size' is missing"
        return result

    @builtins.property
    def password(self) -> typing.Optional[builtins.str]:
        result = self._values.get("password")
        return result

    @builtins.property
    def ssh_keys(self) -> typing.Optional[typing.List[builtins.str]]:
        result = self._values.get("ssh_keys")
        return result

    @builtins.property
    def subnet_id(self) -> typing.Optional[builtins.str]:
        result = self._values.get("subnet_id")
        return result

    @builtins.property
    def virtual_network_id(self) -> typing.Optional[builtins.str]:
        result = self._values.get("virtual_network_id")
        return result

    def __eq__(self, rhs: typing.Any) -> builtins.bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs: typing.Any) -> builtins.bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return "HdinsightKafkaClusterRolesHeadNode(%s)" % ", ".join(
            k + "=" + repr(v) for k, v in self._values.items()
        )


@jsii.data_type(
    jsii_type="@cdktf/provider-azurerm.HdinsightKafkaClusterRolesWorkerNode",
    jsii_struct_bases=[],
    name_mapping={
        "number_of_disks_per_node": "numberOfDisksPerNode",
        "target_instance_count": "targetInstanceCount",
        "username": "username",
        "vm_size": "vmSize",
        "min_instance_count": "minInstanceCount",
        "password": "password",
        "ssh_keys": "sshKeys",
        "subnet_id": "subnetId",
        "virtual_network_id": "virtualNetworkId",
    },
)
class HdinsightKafkaClusterRolesWorkerNode:
    def __init__(
        self,
        *,
        number_of_disks_per_node: jsii.Number,
        target_instance_count: jsii.Number,
        username: builtins.str,
        vm_size: builtins.str,
        min_instance_count: typing.Optional[jsii.Number] = None,
        password: typing.Optional[builtins.str] = None,
        ssh_keys: typing.Optional[typing.List[builtins.str]] = None,
        subnet_id: typing.Optional[builtins.str] = None,
        virtual_network_id: typing.Optional[builtins.str] = None,
    ) -> None:
        """
        :param number_of_disks_per_node: 
        :param target_instance_count: 
        :param username: 
        :param vm_size: 
        :param min_instance_count: 
        :param password: 
        :param ssh_keys: 
        :param subnet_id: 
        :param virtual_network_id: 
        """
        self._values: typing.Dict[str, typing.Any] = {
            "number_of_disks_per_node": number_of_disks_per_node,
            "target_instance_count": target_instance_count,
            "username": username,
            "vm_size": vm_size,
        }
        if min_instance_count is not None:
            self._values["min_instance_count"] = min_instance_count
        if password is not None:
            self._values["password"] = password
        if ssh_keys is not None:
            self._values["ssh_keys"] = ssh_keys
        if subnet_id is not None:
            self._values["subnet_id"] = subnet_id
        if virtual_network_id is not None:
            self._values["virtual_network_id"] = virtual_network_id

    @builtins.property
    def number_of_disks_per_node(self) -> jsii.Number:
        result = self._values.get("number_of_disks_per_node")
        assert result is not None, "Required property 'number_of_disks_per_node' is missing"
        return result

    @builtins.property
    def target_instance_count(self) -> jsii.Number:
        result = self._values.get("target_instance_count")
        assert result is not None, "Required property 'target_instance_count' is missing"
        return result

    @builtins.property
    def username(self) -> builtins.str:
        result = self._values.get("username")
        assert result is not None, "Required property 'username' is missing"
        return result

    @builtins.property
    def vm_size(self) -> builtins.str:
        result = self._values.get("vm_size")
        assert result is not None, "Required property 'vm_size' is missing"
        return result

    @builtins.property
    def min_instance_count(self) -> typing.Optional[jsii.Number]:
        result = self._values.get("min_instance_count")
        return result

    @builtins.property
    def password(self) -> typing.Optional[builtins.str]:
        result = self._values.get("password")
        return result

    @builtins.property
    def ssh_keys(self) -> typing.Optional[typing.List[builtins.str]]:
        result = self._values.get("ssh_keys")
        return result

    @builtins.property
    def subnet_id(self) -> typing.Optional[builtins.str]:
        result = self._values.get("subnet_id")
        return result

    @builtins.property
    def virtual_network_id(self) -> typing.Optional[builtins.str]:
        result = self._values.get("virtual_network_id")
        return result

    def __eq__(self, rhs: typing.Any) -> builtins.bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs: typing.Any) -> builtins.bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return "HdinsightKafkaClusterRolesWorkerNode(%s)" % ", ".join(
            k + "=" + repr(v) for k, v in self._values.items()
        )


@jsii.data_type(
    jsii_type="@cdktf/provider-azurerm.HdinsightKafkaClusterRolesZookeeperNode",
    jsii_struct_bases=[],
    name_mapping={
        "username": "username",
        "vm_size": "vmSize",
        "password": "password",
        "ssh_keys": "sshKeys",
        "subnet_id": "subnetId",
        "virtual_network_id": "virtualNetworkId",
    },
)
class HdinsightKafkaClusterRolesZookeeperNode:
    def __init__(
        self,
        *,
        username: builtins.str,
        vm_size: builtins.str,
        password: typing.Optional[builtins.str] = None,
        ssh_keys: typing.Optional[typing.List[builtins.str]] = None,
        subnet_id: typing.Optional[builtins.str] = None,
        virtual_network_id: typing.Optional[builtins.str] = None,
    ) -> None:
        """
        :param username: 
        :param vm_size: 
        :param password: 
        :param ssh_keys: 
        :param subnet_id: 
        :param virtual_network_id: 
        """
        self._values: typing.Dict[str, typing.Any] = {
            "username": username,
            "vm_size": vm_size,
        }
        if password is not None:
            self._values["password"] = password
        if ssh_keys is not None:
            self._values["ssh_keys"] = ssh_keys
        if subnet_id is not None:
            self._values["subnet_id"] = subnet_id
        if virtual_network_id is not None:
            self._values["virtual_network_id"] = virtual_network_id

    @builtins.property
    def username(self) -> builtins.str:
        result = self._values.get("username")
        assert result is not None, "Required property 'username' is missing"
        return result

    @builtins.property
    def vm_size(self) -> builtins.str:
        result = self._values.get("vm_size")
        assert result is not None, "Required property 'vm_size' is missing"
        return result

    @builtins.property
    def password(self) -> typing.Optional[builtins.str]:
        result = self._values.get("password")
        return result

    @builtins.property
    def ssh_keys(self) -> typing.Optional[typing.List[builtins.str]]:
        result = self._values.get("ssh_keys")
        return result

    @builtins.property
    def subnet_id(self) -> typing.Optional[builtins.str]:
        result = self._values.get("subnet_id")
        return result

    @builtins.property
    def virtual_network_id(self) -> typing.Optional[builtins.str]:
        result = self._values.get("virtual_network_id")
        return result

    def __eq__(self, rhs: typing.Any) -> builtins.bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs: typing.Any) -> builtins.bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return "HdinsightKafkaClusterRolesZookeeperNode(%s)" % ", ".join(
            k + "=" + repr(v) for k, v in self._values.items()
        )


@jsii.data_type(
    jsii_type="@cdktf/provider-azurerm.HdinsightKafkaClusterStorageAccount",
    jsii_struct_bases=[],
    name_mapping={
        "is_default": "isDefault",
        "storage_account_key": "storageAccountKey",
        "storage_container_id": "storageContainerId",
    },
)
class HdinsightKafkaClusterStorageAccount:
    def __init__(
        self,
        *,
        is_default: builtins.bool,
        storage_account_key: builtins.str,
        storage_container_id: builtins.str,
    ) -> None:
        """
        :param is_default: 
        :param storage_account_key: 
        :param storage_container_id: 
        """
        self._values: typing.Dict[str, typing.Any] = {
            "is_default": is_default,
            "storage_account_key": storage_account_key,
            "storage_container_id": storage_container_id,
        }

    @builtins.property
    def is_default(self) -> builtins.bool:
        result = self._values.get("is_default")
        assert result is not None, "Required property 'is_default' is missing"
        return result

    @builtins.property
    def storage_account_key(self) -> builtins.str:
        result = self._values.get("storage_account_key")
        assert result is not None, "Required property 'storage_account_key' is missing"
        return result

    @builtins.property
    def storage_container_id(self) -> builtins.str:
        result = self._values.get("storage_container_id")
        assert result is not None, "Required property 'storage_container_id' is missing"
        return result

    def __eq__(self, rhs: typing.Any) -> builtins.bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs: typing.Any) -> builtins.bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return "HdinsightKafkaClusterStorageAccount(%s)" % ", ".join(
            k + "=" + repr(v) for k, v in self._values.items()
        )


@jsii.data_type(
    jsii_type="@cdktf/provider-azurerm.HdinsightKafkaClusterStorageAccountGen2",
    jsii_struct_bases=[],
    name_mapping={
        "filesystem_id": "filesystemId",
        "is_default": "isDefault",
        "managed_identity_resource_id": "managedIdentityResourceId",
        "storage_resource_id": "storageResourceId",
    },
)
class HdinsightKafkaClusterStorageAccountGen2:
    def __init__(
        self,
        *,
        filesystem_id: builtins.str,
        is_default: builtins.bool,
        managed_identity_resource_id: builtins.str,
        storage_resource_id: builtins.str,
    ) -> None:
        """
        :param filesystem_id: 
        :param is_default: 
        :param managed_identity_resource_id: 
        :param storage_resource_id: 
        """
        self._values: typing.Dict[str, typing.Any] = {
            "filesystem_id": filesystem_id,
            "is_default": is_default,
            "managed_identity_resource_id": managed_identity_resource_id,
            "storage_resource_id": storage_resource_id,
        }

    @builtins.property
    def filesystem_id(self) -> builtins.str:
        result = self._values.get("filesystem_id")
        assert result is not None, "Required property 'filesystem_id' is missing"
        return result

    @builtins.property
    def is_default(self) -> builtins.bool:
        result = self._values.get("is_default")
        assert result is not None, "Required property 'is_default' is missing"
        return result

    @builtins.property
    def managed_identity_resource_id(self) -> builtins.str:
        result = self._values.get("managed_identity_resource_id")
        assert result is not None, "Required property 'managed_identity_resource_id' is missing"
        return result

    @builtins.property
    def storage_resource_id(self) -> builtins.str:
        result = self._values.get("storage_resource_id")
        assert result is not None, "Required property 'storage_resource_id' is missing"
        return result

    def __eq__(self, rhs: typing.Any) -> builtins.bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs: typing.Any) -> builtins.bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return "HdinsightKafkaClusterStorageAccountGen2(%s)" % ", ".join(
            k + "=" + repr(v) for k, v in self._values.items()
        )


@jsii.data_type(
    jsii_type="@cdktf/provider-azurerm.HdinsightKafkaClusterTimeouts",
    jsii_struct_bases=[],
    name_mapping={
        "create": "create",
        "delete": "delete",
        "read": "read",
        "update": "update",
    },
)
class HdinsightKafkaClusterTimeouts:
    def __init__(
        self,
        *,
        create: typing.Optional[builtins.str] = None,
        delete: typing.Optional[builtins.str] = None,
        read: typing.Optional[builtins.str] = None,
        update: typing.Optional[builtins.str] = None,
    ) -> None:
        """
        :param create: 
        :param delete: 
        :param read: 
        :param update: 
        """
        self._values: typing.Dict[str, typing.Any] = {}
        if create is not None:
            self._values["create"] = create
        if delete is not None:
            self._values["delete"] = delete
        if read is not None:
            self._values["read"] = read
        if update is not None:
            self._values["update"] = update

    @builtins.property
    def create(self) -> typing.Optional[builtins.str]:
        result = self._values.get("create")
        return result

    @builtins.property
    def delete(self) -> typing.Optional[builtins.str]:
        result = self._values.get("delete")
        return result

    @builtins.property
    def read(self) -> typing.Optional[builtins.str]:
        result = self._values.get("read")
        return result

    @builtins.property
    def update(self) -> typing.Optional[builtins.str]:
        result = self._values.get("update")
        return result

    def __eq__(self, rhs: typing.Any) -> builtins.bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs: typing.Any) -> builtins.bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return "HdinsightKafkaClusterTimeouts(%s)" % ", ".join(
            k + "=" + repr(v) for k, v in self._values.items()
        )


class HdinsightMlServicesCluster(
    cdktf.TerraformResource,
    metaclass=jsii.JSIIMeta,
    jsii_type="@cdktf/provider-azurerm.HdinsightMlServicesCluster",
):
    def __init__(
        self,
        scope: constructs.Construct,
        id: builtins.str,
        *,
        cluster_version: builtins.str,
        gateway: typing.List["HdinsightMlServicesClusterGateway"],
        location: builtins.str,
        name: builtins.str,
        resource_group_name: builtins.str,
        roles: typing.List["HdinsightMlServicesClusterRoles"],
        rstudio: builtins.bool,
        tier: builtins.str,
        storage_account: typing.Optional[typing.List["HdinsightMlServicesClusterStorageAccount"]] = None,
        tags: typing.Optional[typing.Mapping[builtins.str, builtins.str]] = None,
        timeouts: typing.Optional["HdinsightMlServicesClusterTimeouts"] = None,
        count: typing.Optional[jsii.Number] = None,
        depends_on: typing.Optional[typing.List[cdktf.TerraformResource]] = None,
        lifecycle: typing.Optional[cdktf.TerraformResourceLifecycle] = None,
        provider: typing.Optional[cdktf.TerraformProvider] = None,
    ) -> None:
        """
        :param scope: -
        :param id: -
        :param cluster_version: 
        :param gateway: gateway block.
        :param location: 
        :param name: 
        :param resource_group_name: 
        :param roles: roles block.
        :param rstudio: 
        :param tier: 
        :param storage_account: storage_account block.
        :param tags: 
        :param timeouts: timeouts block.
        :param count: 
        :param depends_on: 
        :param lifecycle: 
        :param provider: 
        """
        config = HdinsightMlServicesClusterConfig(
            cluster_version=cluster_version,
            gateway=gateway,
            location=location,
            name=name,
            resource_group_name=resource_group_name,
            roles=roles,
            rstudio=rstudio,
            tier=tier,
            storage_account=storage_account,
            tags=tags,
            timeouts=timeouts,
            count=count,
            depends_on=depends_on,
            lifecycle=lifecycle,
            provider=provider,
        )

        jsii.create(HdinsightMlServicesCluster, self, [scope, id, config])

    @jsii.member(jsii_name="synthesizeAttributes")
    def _synthesize_attributes(self) -> typing.Mapping[builtins.str, typing.Any]:
        return jsii.invoke(self, "synthesizeAttributes", [])

    @builtins.property # type: ignore
    @jsii.member(jsii_name="edgeSshEndpoint")
    def edge_ssh_endpoint(self) -> builtins.str:
        return jsii.get(self, "edgeSshEndpoint")

    @builtins.property # type: ignore
    @jsii.member(jsii_name="httpsEndpoint")
    def https_endpoint(self) -> builtins.str:
        return jsii.get(self, "httpsEndpoint")

    @builtins.property # type: ignore
    @jsii.member(jsii_name="sshEndpoint")
    def ssh_endpoint(self) -> builtins.str:
        return jsii.get(self, "sshEndpoint")

    @builtins.property # type: ignore
    @jsii.member(jsii_name="clusterVersion")
    def cluster_version(self) -> builtins.str:
        return jsii.get(self, "clusterVersion")

    @cluster_version.setter # type: ignore
    def cluster_version(self, value: builtins.str) -> None:
        jsii.set(self, "clusterVersion", value)

    @builtins.property # type: ignore
    @jsii.member(jsii_name="gateway")
    def gateway(self) -> typing.List["HdinsightMlServicesClusterGateway"]:
        return jsii.get(self, "gateway")

    @gateway.setter # type: ignore
    def gateway(self, value: typing.List["HdinsightMlServicesClusterGateway"]) -> None:
        jsii.set(self, "gateway", value)

    @builtins.property # type: ignore
    @jsii.member(jsii_name="location")
    def location(self) -> builtins.str:
        return jsii.get(self, "location")

    @location.setter # type: ignore
    def location(self, value: builtins.str) -> None:
        jsii.set(self, "location", value)

    @builtins.property # type: ignore
    @jsii.member(jsii_name="name")
    def name(self) -> builtins.str:
        return jsii.get(self, "name")

    @name.setter # type: ignore
    def name(self, value: builtins.str) -> None:
        jsii.set(self, "name", value)

    @builtins.property # type: ignore
    @jsii.member(jsii_name="resourceGroupName")
    def resource_group_name(self) -> builtins.str:
        return jsii.get(self, "resourceGroupName")

    @resource_group_name.setter # type: ignore
    def resource_group_name(self, value: builtins.str) -> None:
        jsii.set(self, "resourceGroupName", value)

    @builtins.property # type: ignore
    @jsii.member(jsii_name="roles")
    def roles(self) -> typing.List["HdinsightMlServicesClusterRoles"]:
        return jsii.get(self, "roles")

    @roles.setter # type: ignore
    def roles(self, value: typing.List["HdinsightMlServicesClusterRoles"]) -> None:
        jsii.set(self, "roles", value)

    @builtins.property # type: ignore
    @jsii.member(jsii_name="rstudio")
    def rstudio(self) -> builtins.bool:
        return jsii.get(self, "rstudio")

    @rstudio.setter # type: ignore
    def rstudio(self, value: builtins.bool) -> None:
        jsii.set(self, "rstudio", value)

    @builtins.property # type: ignore
    @jsii.member(jsii_name="tier")
    def tier(self) -> builtins.str:
        return jsii.get(self, "tier")

    @tier.setter # type: ignore
    def tier(self, value: builtins.str) -> None:
        jsii.set(self, "tier", value)

    @builtins.property # type: ignore
    @jsii.member(jsii_name="id")
    def id(self) -> typing.Optional[builtins.str]:
        return jsii.get(self, "id")

    @id.setter # type: ignore
    def id(self, value: typing.Optional[builtins.str]) -> None:
        jsii.set(self, "id", value)

    @builtins.property # type: ignore
    @jsii.member(jsii_name="storageAccount")
    def storage_account(
        self,
    ) -> typing.Optional[typing.List["HdinsightMlServicesClusterStorageAccount"]]:
        return jsii.get(self, "storageAccount")

    @storage_account.setter # type: ignore
    def storage_account(
        self,
        value: typing.Optional[typing.List["HdinsightMlServicesClusterStorageAccount"]],
    ) -> None:
        jsii.set(self, "storageAccount", value)

    @builtins.property # type: ignore
    @jsii.member(jsii_name="tags")
    def tags(self) -> typing.Optional[typing.Mapping[builtins.str, builtins.str]]:
        return jsii.get(self, "tags")

    @tags.setter # type: ignore
    def tags(
        self,
        value: typing.Optional[typing.Mapping[builtins.str, builtins.str]],
    ) -> None:
        jsii.set(self, "tags", value)

    @builtins.property # type: ignore
    @jsii.member(jsii_name="timeouts")
    def timeouts(self) -> typing.Optional["HdinsightMlServicesClusterTimeouts"]:
        return jsii.get(self, "timeouts")

    @timeouts.setter # type: ignore
    def timeouts(
        self,
        value: typing.Optional["HdinsightMlServicesClusterTimeouts"],
    ) -> None:
        jsii.set(self, "timeouts", value)


@jsii.data_type(
    jsii_type="@cdktf/provider-azurerm.HdinsightMlServicesClusterConfig",
    jsii_struct_bases=[cdktf.TerraformMetaArguments],
    name_mapping={
        "count": "count",
        "depends_on": "dependsOn",
        "lifecycle": "lifecycle",
        "provider": "provider",
        "cluster_version": "clusterVersion",
        "gateway": "gateway",
        "location": "location",
        "name": "name",
        "resource_group_name": "resourceGroupName",
        "roles": "roles",
        "rstudio": "rstudio",
        "tier": "tier",
        "storage_account": "storageAccount",
        "tags": "tags",
        "timeouts": "timeouts",
    },
)
class HdinsightMlServicesClusterConfig(cdktf.TerraformMetaArguments):
    def __init__(
        self,
        *,
        count: typing.Optional[jsii.Number] = None,
        depends_on: typing.Optional[typing.List[cdktf.TerraformResource]] = None,
        lifecycle: typing.Optional[cdktf.TerraformResourceLifecycle] = None,
        provider: typing.Optional[cdktf.TerraformProvider] = None,
        cluster_version: builtins.str,
        gateway: typing.List["HdinsightMlServicesClusterGateway"],
        location: builtins.str,
        name: builtins.str,
        resource_group_name: builtins.str,
        roles: typing.List["HdinsightMlServicesClusterRoles"],
        rstudio: builtins.bool,
        tier: builtins.str,
        storage_account: typing.Optional[typing.List["HdinsightMlServicesClusterStorageAccount"]] = None,
        tags: typing.Optional[typing.Mapping[builtins.str, builtins.str]] = None,
        timeouts: typing.Optional["HdinsightMlServicesClusterTimeouts"] = None,
    ) -> None:
        """
        :param count: 
        :param depends_on: 
        :param lifecycle: 
        :param provider: 
        :param cluster_version: 
        :param gateway: gateway block.
        :param location: 
        :param name: 
        :param resource_group_name: 
        :param roles: roles block.
        :param rstudio: 
        :param tier: 
        :param storage_account: storage_account block.
        :param tags: 
        :param timeouts: timeouts block.
        """
        if isinstance(lifecycle, dict):
            lifecycle = cdktf.TerraformResourceLifecycle(**lifecycle)
        if isinstance(timeouts, dict):
            timeouts = HdinsightMlServicesClusterTimeouts(**timeouts)
        self._values: typing.Dict[str, typing.Any] = {
            "cluster_version": cluster_version,
            "gateway": gateway,
            "location": location,
            "name": name,
            "resource_group_name": resource_group_name,
            "roles": roles,
            "rstudio": rstudio,
            "tier": tier,
        }
        if count is not None:
            self._values["count"] = count
        if depends_on is not None:
            self._values["depends_on"] = depends_on
        if lifecycle is not None:
            self._values["lifecycle"] = lifecycle
        if provider is not None:
            self._values["provider"] = provider
        if storage_account is not None:
            self._values["storage_account"] = storage_account
        if tags is not None:
            self._values["tags"] = tags
        if timeouts is not None:
            self._values["timeouts"] = timeouts

    @builtins.property
    def count(self) -> typing.Optional[jsii.Number]:
        """
        :stability: experimental
        """
        result = self._values.get("count")
        return result

    @builtins.property
    def depends_on(self) -> typing.Optional[typing.List[cdktf.TerraformResource]]:
        """
        :stability: experimental
        """
        result = self._values.get("depends_on")
        return result

    @builtins.property
    def lifecycle(self) -> typing.Optional[cdktf.TerraformResourceLifecycle]:
        """
        :stability: experimental
        """
        result = self._values.get("lifecycle")
        return result

    @builtins.property
    def provider(self) -> typing.Optional[cdktf.TerraformProvider]:
        """
        :stability: experimental
        """
        result = self._values.get("provider")
        return result

    @builtins.property
    def cluster_version(self) -> builtins.str:
        result = self._values.get("cluster_version")
        assert result is not None, "Required property 'cluster_version' is missing"
        return result

    @builtins.property
    def gateway(self) -> typing.List["HdinsightMlServicesClusterGateway"]:
        """gateway block."""
        result = self._values.get("gateway")
        assert result is not None, "Required property 'gateway' is missing"
        return result

    @builtins.property
    def location(self) -> builtins.str:
        result = self._values.get("location")
        assert result is not None, "Required property 'location' is missing"
        return result

    @builtins.property
    def name(self) -> builtins.str:
        result = self._values.get("name")
        assert result is not None, "Required property 'name' is missing"
        return result

    @builtins.property
    def resource_group_name(self) -> builtins.str:
        result = self._values.get("resource_group_name")
        assert result is not None, "Required property 'resource_group_name' is missing"
        return result

    @builtins.property
    def roles(self) -> typing.List["HdinsightMlServicesClusterRoles"]:
        """roles block."""
        result = self._values.get("roles")
        assert result is not None, "Required property 'roles' is missing"
        return result

    @builtins.property
    def rstudio(self) -> builtins.bool:
        result = self._values.get("rstudio")
        assert result is not None, "Required property 'rstudio' is missing"
        return result

    @builtins.property
    def tier(self) -> builtins.str:
        result = self._values.get("tier")
        assert result is not None, "Required property 'tier' is missing"
        return result

    @builtins.property
    def storage_account(
        self,
    ) -> typing.Optional[typing.List["HdinsightMlServicesClusterStorageAccount"]]:
        """storage_account block."""
        result = self._values.get("storage_account")
        return result

    @builtins.property
    def tags(self) -> typing.Optional[typing.Mapping[builtins.str, builtins.str]]:
        result = self._values.get("tags")
        return result

    @builtins.property
    def timeouts(self) -> typing.Optional["HdinsightMlServicesClusterTimeouts"]:
        """timeouts block."""
        result = self._values.get("timeouts")
        return result

    def __eq__(self, rhs: typing.Any) -> builtins.bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs: typing.Any) -> builtins.bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return "HdinsightMlServicesClusterConfig(%s)" % ", ".join(
            k + "=" + repr(v) for k, v in self._values.items()
        )


@jsii.data_type(
    jsii_type="@cdktf/provider-azurerm.HdinsightMlServicesClusterGateway",
    jsii_struct_bases=[],
    name_mapping={
        "enabled": "enabled",
        "password": "password",
        "username": "username",
    },
)
class HdinsightMlServicesClusterGateway:
    def __init__(
        self,
        *,
        enabled: builtins.bool,
        password: builtins.str,
        username: builtins.str,
    ) -> None:
        """
        :param enabled: 
        :param password: 
        :param username: 
        """
        self._values: typing.Dict[str, typing.Any] = {
            "enabled": enabled,
            "password": password,
            "username": username,
        }

    @builtins.property
    def enabled(self) -> builtins.bool:
        result = self._values.get("enabled")
        assert result is not None, "Required property 'enabled' is missing"
        return result

    @builtins.property
    def password(self) -> builtins.str:
        result = self._values.get("password")
        assert result is not None, "Required property 'password' is missing"
        return result

    @builtins.property
    def username(self) -> builtins.str:
        result = self._values.get("username")
        assert result is not None, "Required property 'username' is missing"
        return result

    def __eq__(self, rhs: typing.Any) -> builtins.bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs: typing.Any) -> builtins.bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return "HdinsightMlServicesClusterGateway(%s)" % ", ".join(
            k + "=" + repr(v) for k, v in self._values.items()
        )


@jsii.data_type(
    jsii_type="@cdktf/provider-azurerm.HdinsightMlServicesClusterRoles",
    jsii_struct_bases=[],
    name_mapping={
        "edge_node": "edgeNode",
        "head_node": "headNode",
        "worker_node": "workerNode",
        "zookeeper_node": "zookeeperNode",
    },
)
class HdinsightMlServicesClusterRoles:
    def __init__(
        self,
        *,
        edge_node: typing.List["HdinsightMlServicesClusterRolesEdgeNode"],
        head_node: typing.List["HdinsightMlServicesClusterRolesHeadNode"],
        worker_node: typing.List["HdinsightMlServicesClusterRolesWorkerNode"],
        zookeeper_node: typing.List["HdinsightMlServicesClusterRolesZookeeperNode"],
    ) -> None:
        """
        :param edge_node: edge_node block.
        :param head_node: head_node block.
        :param worker_node: worker_node block.
        :param zookeeper_node: zookeeper_node block.
        """
        self._values: typing.Dict[str, typing.Any] = {
            "edge_node": edge_node,
            "head_node": head_node,
            "worker_node": worker_node,
            "zookeeper_node": zookeeper_node,
        }

    @builtins.property
    def edge_node(self) -> typing.List["HdinsightMlServicesClusterRolesEdgeNode"]:
        """edge_node block."""
        result = self._values.get("edge_node")
        assert result is not None, "Required property 'edge_node' is missing"
        return result

    @builtins.property
    def head_node(self) -> typing.List["HdinsightMlServicesClusterRolesHeadNode"]:
        """head_node block."""
        result = self._values.get("head_node")
        assert result is not None, "Required property 'head_node' is missing"
        return result

    @builtins.property
    def worker_node(self) -> typing.List["HdinsightMlServicesClusterRolesWorkerNode"]:
        """worker_node block."""
        result = self._values.get("worker_node")
        assert result is not None, "Required property 'worker_node' is missing"
        return result

    @builtins.property
    def zookeeper_node(
        self,
    ) -> typing.List["HdinsightMlServicesClusterRolesZookeeperNode"]:
        """zookeeper_node block."""
        result = self._values.get("zookeeper_node")
        assert result is not None, "Required property 'zookeeper_node' is missing"
        return result

    def __eq__(self, rhs: typing.Any) -> builtins.bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs: typing.Any) -> builtins.bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return "HdinsightMlServicesClusterRoles(%s)" % ", ".join(
            k + "=" + repr(v) for k, v in self._values.items()
        )


@jsii.data_type(
    jsii_type="@cdktf/provider-azurerm.HdinsightMlServicesClusterRolesEdgeNode",
    jsii_struct_bases=[],
    name_mapping={
        "username": "username",
        "vm_size": "vmSize",
        "password": "password",
        "ssh_keys": "sshKeys",
        "subnet_id": "subnetId",
        "virtual_network_id": "virtualNetworkId",
    },
)
class HdinsightMlServicesClusterRolesEdgeNode:
    def __init__(
        self,
        *,
        username: builtins.str,
        vm_size: builtins.str,
        password: typing.Optional[builtins.str] = None,
        ssh_keys: typing.Optional[typing.List[builtins.str]] = None,
        subnet_id: typing.Optional[builtins.str] = None,
        virtual_network_id: typing.Optional[builtins.str] = None,
    ) -> None:
        """
        :param username: 
        :param vm_size: 
        :param password: 
        :param ssh_keys: 
        :param subnet_id: 
        :param virtual_network_id: 
        """
        self._values: typing.Dict[str, typing.Any] = {
            "username": username,
            "vm_size": vm_size,
        }
        if password is not None:
            self._values["password"] = password
        if ssh_keys is not None:
            self._values["ssh_keys"] = ssh_keys
        if subnet_id is not None:
            self._values["subnet_id"] = subnet_id
        if virtual_network_id is not None:
            self._values["virtual_network_id"] = virtual_network_id

    @builtins.property
    def username(self) -> builtins.str:
        result = self._values.get("username")
        assert result is not None, "Required property 'username' is missing"
        return result

    @builtins.property
    def vm_size(self) -> builtins.str:
        result = self._values.get("vm_size")
        assert result is not None, "Required property 'vm_size' is missing"
        return result

    @builtins.property
    def password(self) -> typing.Optional[builtins.str]:
        result = self._values.get("password")
        return result

    @builtins.property
    def ssh_keys(self) -> typing.Optional[typing.List[builtins.str]]:
        result = self._values.get("ssh_keys")
        return result

    @builtins.property
    def subnet_id(self) -> typing.Optional[builtins.str]:
        result = self._values.get("subnet_id")
        return result

    @builtins.property
    def virtual_network_id(self) -> typing.Optional[builtins.str]:
        result = self._values.get("virtual_network_id")
        return result

    def __eq__(self, rhs: typing.Any) -> builtins.bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs: typing.Any) -> builtins.bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return "HdinsightMlServicesClusterRolesEdgeNode(%s)" % ", ".join(
            k + "=" + repr(v) for k, v in self._values.items()
        )


@jsii.data_type(
    jsii_type="@cdktf/provider-azurerm.HdinsightMlServicesClusterRolesHeadNode",
    jsii_struct_bases=[],
    name_mapping={
        "username": "username",
        "vm_size": "vmSize",
        "password": "password",
        "ssh_keys": "sshKeys",
        "subnet_id": "subnetId",
        "virtual_network_id": "virtualNetworkId",
    },
)
class HdinsightMlServicesClusterRolesHeadNode:
    def __init__(
        self,
        *,
        username: builtins.str,
        vm_size: builtins.str,
        password: typing.Optional[builtins.str] = None,
        ssh_keys: typing.Optional[typing.List[builtins.str]] = None,
        subnet_id: typing.Optional[builtins.str] = None,
        virtual_network_id: typing.Optional[builtins.str] = None,
    ) -> None:
        """
        :param username: 
        :param vm_size: 
        :param password: 
        :param ssh_keys: 
        :param subnet_id: 
        :param virtual_network_id: 
        """
        self._values: typing.Dict[str, typing.Any] = {
            "username": username,
            "vm_size": vm_size,
        }
        if password is not None:
            self._values["password"] = password
        if ssh_keys is not None:
            self._values["ssh_keys"] = ssh_keys
        if subnet_id is not None:
            self._values["subnet_id"] = subnet_id
        if virtual_network_id is not None:
            self._values["virtual_network_id"] = virtual_network_id

    @builtins.property
    def username(self) -> builtins.str:
        result = self._values.get("username")
        assert result is not None, "Required property 'username' is missing"
        return result

    @builtins.property
    def vm_size(self) -> builtins.str:
        result = self._values.get("vm_size")
        assert result is not None, "Required property 'vm_size' is missing"
        return result

    @builtins.property
    def password(self) -> typing.Optional[builtins.str]:
        result = self._values.get("password")
        return result

    @builtins.property
    def ssh_keys(self) -> typing.Optional[typing.List[builtins.str]]:
        result = self._values.get("ssh_keys")
        return result

    @builtins.property
    def subnet_id(self) -> typing.Optional[builtins.str]:
        result = self._values.get("subnet_id")
        return result

    @builtins.property
    def virtual_network_id(self) -> typing.Optional[builtins.str]:
        result = self._values.get("virtual_network_id")
        return result

    def __eq__(self, rhs: typing.Any) -> builtins.bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs: typing.Any) -> builtins.bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return "HdinsightMlServicesClusterRolesHeadNode(%s)" % ", ".join(
            k + "=" + repr(v) for k, v in self._values.items()
        )


@jsii.data_type(
    jsii_type="@cdktf/provider-azurerm.HdinsightMlServicesClusterRolesWorkerNode",
    jsii_struct_bases=[],
    name_mapping={
        "target_instance_count": "targetInstanceCount",
        "username": "username",
        "vm_size": "vmSize",
        "min_instance_count": "minInstanceCount",
        "password": "password",
        "ssh_keys": "sshKeys",
        "subnet_id": "subnetId",
        "virtual_network_id": "virtualNetworkId",
    },
)
class HdinsightMlServicesClusterRolesWorkerNode:
    def __init__(
        self,
        *,
        target_instance_count: jsii.Number,
        username: builtins.str,
        vm_size: builtins.str,
        min_instance_count: typing.Optional[jsii.Number] = None,
        password: typing.Optional[builtins.str] = None,
        ssh_keys: typing.Optional[typing.List[builtins.str]] = None,
        subnet_id: typing.Optional[builtins.str] = None,
        virtual_network_id: typing.Optional[builtins.str] = None,
    ) -> None:
        """
        :param target_instance_count: 
        :param username: 
        :param vm_size: 
        :param min_instance_count: 
        :param password: 
        :param ssh_keys: 
        :param subnet_id: 
        :param virtual_network_id: 
        """
        self._values: typing.Dict[str, typing.Any] = {
            "target_instance_count": target_instance_count,
            "username": username,
            "vm_size": vm_size,
        }
        if min_instance_count is not None:
            self._values["min_instance_count"] = min_instance_count
        if password is not None:
            self._values["password"] = password
        if ssh_keys is not None:
            self._values["ssh_keys"] = ssh_keys
        if subnet_id is not None:
            self._values["subnet_id"] = subnet_id
        if virtual_network_id is not None:
            self._values["virtual_network_id"] = virtual_network_id

    @builtins.property
    def target_instance_count(self) -> jsii.Number:
        result = self._values.get("target_instance_count")
        assert result is not None, "Required property 'target_instance_count' is missing"
        return result

    @builtins.property
    def username(self) -> builtins.str:
        result = self._values.get("username")
        assert result is not None, "Required property 'username' is missing"
        return result

    @builtins.property
    def vm_size(self) -> builtins.str:
        result = self._values.get("vm_size")
        assert result is not None, "Required property 'vm_size' is missing"
        return result

    @builtins.property
    def min_instance_count(self) -> typing.Optional[jsii.Number]:
        result = self._values.get("min_instance_count")
        return result

    @builtins.property
    def password(self) -> typing.Optional[builtins.str]:
        result = self._values.get("password")
        return result

    @builtins.property
    def ssh_keys(self) -> typing.Optional[typing.List[builtins.str]]:
        result = self._values.get("ssh_keys")
        return result

    @builtins.property
    def subnet_id(self) -> typing.Optional[builtins.str]:
        result = self._values.get("subnet_id")
        return result

    @builtins.property
    def virtual_network_id(self) -> typing.Optional[builtins.str]:
        result = self._values.get("virtual_network_id")
        return result

    def __eq__(self, rhs: typing.Any) -> builtins.bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs: typing.Any) -> builtins.bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return "HdinsightMlServicesClusterRolesWorkerNode(%s)" % ", ".join(
            k + "=" + repr(v) for k, v in self._values.items()
        )


@jsii.data_type(
    jsii_type="@cdktf/provider-azurerm.HdinsightMlServicesClusterRolesZookeeperNode",
    jsii_struct_bases=[],
    name_mapping={
        "username": "username",
        "vm_size": "vmSize",
        "password": "password",
        "ssh_keys": "sshKeys",
        "subnet_id": "subnetId",
        "virtual_network_id": "virtualNetworkId",
    },
)
class HdinsightMlServicesClusterRolesZookeeperNode:
    def __init__(
        self,
        *,
        username: builtins.str,
        vm_size: builtins.str,
        password: typing.Optional[builtins.str] = None,
        ssh_keys: typing.Optional[typing.List[builtins.str]] = None,
        subnet_id: typing.Optional[builtins.str] = None,
        virtual_network_id: typing.Optional[builtins.str] = None,
    ) -> None:
        """
        :param username: 
        :param vm_size: 
        :param password: 
        :param ssh_keys: 
        :param subnet_id: 
        :param virtual_network_id: 
        """
        self._values: typing.Dict[str, typing.Any] = {
            "username": username,
            "vm_size": vm_size,
        }
        if password is not None:
            self._values["password"] = password
        if ssh_keys is not None:
            self._values["ssh_keys"] = ssh_keys
        if subnet_id is not None:
            self._values["subnet_id"] = subnet_id
        if virtual_network_id is not None:
            self._values["virtual_network_id"] = virtual_network_id

    @builtins.property
    def username(self) -> builtins.str:
        result = self._values.get("username")
        assert result is not None, "Required property 'username' is missing"
        return result

    @builtins.property
    def vm_size(self) -> builtins.str:
        result = self._values.get("vm_size")
        assert result is not None, "Required property 'vm_size' is missing"
        return result

    @builtins.property
    def password(self) -> typing.Optional[builtins.str]:
        result = self._values.get("password")
        return result

    @builtins.property
    def ssh_keys(self) -> typing.Optional[typing.List[builtins.str]]:
        result = self._values.get("ssh_keys")
        return result

    @builtins.property
    def subnet_id(self) -> typing.Optional[builtins.str]:
        result = self._values.get("subnet_id")
        return result

    @builtins.property
    def virtual_network_id(self) -> typing.Optional[builtins.str]:
        result = self._values.get("virtual_network_id")
        return result

    def __eq__(self, rhs: typing.Any) -> builtins.bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs: typing.Any) -> builtins.bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return "HdinsightMlServicesClusterRolesZookeeperNode(%s)" % ", ".join(
            k + "=" + repr(v) for k, v in self._values.items()
        )


@jsii.data_type(
    jsii_type="@cdktf/provider-azurerm.HdinsightMlServicesClusterStorageAccount",
    jsii_struct_bases=[],
    name_mapping={
        "is_default": "isDefault",
        "storage_account_key": "storageAccountKey",
        "storage_container_id": "storageContainerId",
    },
)
class HdinsightMlServicesClusterStorageAccount:
    def __init__(
        self,
        *,
        is_default: builtins.bool,
        storage_account_key: builtins.str,
        storage_container_id: builtins.str,
    ) -> None:
        """
        :param is_default: 
        :param storage_account_key: 
        :param storage_container_id: 
        """
        self._values: typing.Dict[str, typing.Any] = {
            "is_default": is_default,
            "storage_account_key": storage_account_key,
            "storage_container_id": storage_container_id,
        }

    @builtins.property
    def is_default(self) -> builtins.bool:
        result = self._values.get("is_default")
        assert result is not None, "Required property 'is_default' is missing"
        return result

    @builtins.property
    def storage_account_key(self) -> builtins.str:
        result = self._values.get("storage_account_key")
        assert result is not None, "Required property 'storage_account_key' is missing"
        return result

    @builtins.property
    def storage_container_id(self) -> builtins.str:
        result = self._values.get("storage_container_id")
        assert result is not None, "Required property 'storage_container_id' is missing"
        return result

    def __eq__(self, rhs: typing.Any) -> builtins.bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs: typing.Any) -> builtins.bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return "HdinsightMlServicesClusterStorageAccount(%s)" % ", ".join(
            k + "=" + repr(v) for k, v in self._values.items()
        )


@jsii.data_type(
    jsii_type="@cdktf/provider-azurerm.HdinsightMlServicesClusterTimeouts",
    jsii_struct_bases=[],
    name_mapping={
        "create": "create",
        "delete": "delete",
        "read": "read",
        "update": "update",
    },
)
class HdinsightMlServicesClusterTimeouts:
    def __init__(
        self,
        *,
        create: typing.Optional[builtins.str] = None,
        delete: typing.Optional[builtins.str] = None,
        read: typing.Optional[builtins.str] = None,
        update: typing.Optional[builtins.str] = None,
    ) -> None:
        """
        :param create: 
        :param delete: 
        :param read: 
        :param update: 
        """
        self._values: typing.Dict[str, typing.Any] = {}
        if create is not None:
            self._values["create"] = create
        if delete is not None:
            self._values["delete"] = delete
        if read is not None:
            self._values["read"] = read
        if update is not None:
            self._values["update"] = update

    @builtins.property
    def create(self) -> typing.Optional[builtins.str]:
        result = self._values.get("create")
        return result

    @builtins.property
    def delete(self) -> typing.Optional[builtins.str]:
        result = self._values.get("delete")
        return result

    @builtins.property
    def read(self) -> typing.Optional[builtins.str]:
        result = self._values.get("read")
        return result

    @builtins.property
    def update(self) -> typing.Optional[builtins.str]:
        result = self._values.get("update")
        return result

    def __eq__(self, rhs: typing.Any) -> builtins.bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs: typing.Any) -> builtins.bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return "HdinsightMlServicesClusterTimeouts(%s)" % ", ".join(
            k + "=" + repr(v) for k, v in self._values.items()
        )


class HdinsightRserverCluster(
    cdktf.TerraformResource,
    metaclass=jsii.JSIIMeta,
    jsii_type="@cdktf/provider-azurerm.HdinsightRserverCluster",
):
    def __init__(
        self,
        scope: constructs.Construct,
        id: builtins.str,
        *,
        cluster_version: builtins.str,
        gateway: typing.List["HdinsightRserverClusterGateway"],
        location: builtins.str,
        name: builtins.str,
        resource_group_name: builtins.str,
        roles: typing.List["HdinsightRserverClusterRoles"],
        rstudio: builtins.bool,
        tier: builtins.str,
        storage_account: typing.Optional[typing.List["HdinsightRserverClusterStorageAccount"]] = None,
        tags: typing.Optional[typing.Mapping[builtins.str, builtins.str]] = None,
        timeouts: typing.Optional["HdinsightRserverClusterTimeouts"] = None,
        count: typing.Optional[jsii.Number] = None,
        depends_on: typing.Optional[typing.List[cdktf.TerraformResource]] = None,
        lifecycle: typing.Optional[cdktf.TerraformResourceLifecycle] = None,
        provider: typing.Optional[cdktf.TerraformProvider] = None,
    ) -> None:
        """
        :param scope: -
        :param id: -
        :param cluster_version: 
        :param gateway: gateway block.
        :param location: 
        :param name: 
        :param resource_group_name: 
        :param roles: roles block.
        :param rstudio: 
        :param tier: 
        :param storage_account: storage_account block.
        :param tags: 
        :param timeouts: timeouts block.
        :param count: 
        :param depends_on: 
        :param lifecycle: 
        :param provider: 
        """
        config = HdinsightRserverClusterConfig(
            cluster_version=cluster_version,
            gateway=gateway,
            location=location,
            name=name,
            resource_group_name=resource_group_name,
            roles=roles,
            rstudio=rstudio,
            tier=tier,
            storage_account=storage_account,
            tags=tags,
            timeouts=timeouts,
            count=count,
            depends_on=depends_on,
            lifecycle=lifecycle,
            provider=provider,
        )

        jsii.create(HdinsightRserverCluster, self, [scope, id, config])

    @jsii.member(jsii_name="synthesizeAttributes")
    def _synthesize_attributes(self) -> typing.Mapping[builtins.str, typing.Any]:
        return jsii.invoke(self, "synthesizeAttributes", [])

    @builtins.property # type: ignore
    @jsii.member(jsii_name="edgeSshEndpoint")
    def edge_ssh_endpoint(self) -> builtins.str:
        return jsii.get(self, "edgeSshEndpoint")

    @builtins.property # type: ignore
    @jsii.member(jsii_name="httpsEndpoint")
    def https_endpoint(self) -> builtins.str:
        return jsii.get(self, "httpsEndpoint")

    @builtins.property # type: ignore
    @jsii.member(jsii_name="sshEndpoint")
    def ssh_endpoint(self) -> builtins.str:
        return jsii.get(self, "sshEndpoint")

    @builtins.property # type: ignore
    @jsii.member(jsii_name="clusterVersion")
    def cluster_version(self) -> builtins.str:
        return jsii.get(self, "clusterVersion")

    @cluster_version.setter # type: ignore
    def cluster_version(self, value: builtins.str) -> None:
        jsii.set(self, "clusterVersion", value)

    @builtins.property # type: ignore
    @jsii.member(jsii_name="gateway")
    def gateway(self) -> typing.List["HdinsightRserverClusterGateway"]:
        return jsii.get(self, "gateway")

    @gateway.setter # type: ignore
    def gateway(self, value: typing.List["HdinsightRserverClusterGateway"]) -> None:
        jsii.set(self, "gateway", value)

    @builtins.property # type: ignore
    @jsii.member(jsii_name="location")
    def location(self) -> builtins.str:
        return jsii.get(self, "location")

    @location.setter # type: ignore
    def location(self, value: builtins.str) -> None:
        jsii.set(self, "location", value)

    @builtins.property # type: ignore
    @jsii.member(jsii_name="name")
    def name(self) -> builtins.str:
        return jsii.get(self, "name")

    @name.setter # type: ignore
    def name(self, value: builtins.str) -> None:
        jsii.set(self, "name", value)

    @builtins.property # type: ignore
    @jsii.member(jsii_name="resourceGroupName")
    def resource_group_name(self) -> builtins.str:
        return jsii.get(self, "resourceGroupName")

    @resource_group_name.setter # type: ignore
    def resource_group_name(self, value: builtins.str) -> None:
        jsii.set(self, "resourceGroupName", value)

    @builtins.property # type: ignore
    @jsii.member(jsii_name="roles")
    def roles(self) -> typing.List["HdinsightRserverClusterRoles"]:
        return jsii.get(self, "roles")

    @roles.setter # type: ignore
    def roles(self, value: typing.List["HdinsightRserverClusterRoles"]) -> None:
        jsii.set(self, "roles", value)

    @builtins.property # type: ignore
    @jsii.member(jsii_name="rstudio")
    def rstudio(self) -> builtins.bool:
        return jsii.get(self, "rstudio")

    @rstudio.setter # type: ignore
    def rstudio(self, value: builtins.bool) -> None:
        jsii.set(self, "rstudio", value)

    @builtins.property # type: ignore
    @jsii.member(jsii_name="tier")
    def tier(self) -> builtins.str:
        return jsii.get(self, "tier")

    @tier.setter # type: ignore
    def tier(self, value: builtins.str) -> None:
        jsii.set(self, "tier", value)

    @builtins.property # type: ignore
    @jsii.member(jsii_name="id")
    def id(self) -> typing.Optional[builtins.str]:
        return jsii.get(self, "id")

    @id.setter # type: ignore
    def id(self, value: typing.Optional[builtins.str]) -> None:
        jsii.set(self, "id", value)

    @builtins.property # type: ignore
    @jsii.member(jsii_name="storageAccount")
    def storage_account(
        self,
    ) -> typing.Optional[typing.List["HdinsightRserverClusterStorageAccount"]]:
        return jsii.get(self, "storageAccount")

    @storage_account.setter # type: ignore
    def storage_account(
        self,
        value: typing.Optional[typing.List["HdinsightRserverClusterStorageAccount"]],
    ) -> None:
        jsii.set(self, "storageAccount", value)

    @builtins.property # type: ignore
    @jsii.member(jsii_name="tags")
    def tags(self) -> typing.Optional[typing.Mapping[builtins.str, builtins.str]]:
        return jsii.get(self, "tags")

    @tags.setter # type: ignore
    def tags(
        self,
        value: typing.Optional[typing.Mapping[builtins.str, builtins.str]],
    ) -> None:
        jsii.set(self, "tags", value)

    @builtins.property # type: ignore
    @jsii.member(jsii_name="timeouts")
    def timeouts(self) -> typing.Optional["HdinsightRserverClusterTimeouts"]:
        return jsii.get(self, "timeouts")

    @timeouts.setter # type: ignore
    def timeouts(
        self,
        value: typing.Optional["HdinsightRserverClusterTimeouts"],
    ) -> None:
        jsii.set(self, "timeouts", value)


@jsii.data_type(
    jsii_type="@cdktf/provider-azurerm.HdinsightRserverClusterConfig",
    jsii_struct_bases=[cdktf.TerraformMetaArguments],
    name_mapping={
        "count": "count",
        "depends_on": "dependsOn",
        "lifecycle": "lifecycle",
        "provider": "provider",
        "cluster_version": "clusterVersion",
        "gateway": "gateway",
        "location": "location",
        "name": "name",
        "resource_group_name": "resourceGroupName",
        "roles": "roles",
        "rstudio": "rstudio",
        "tier": "tier",
        "storage_account": "storageAccount",
        "tags": "tags",
        "timeouts": "timeouts",
    },
)
class HdinsightRserverClusterConfig(cdktf.TerraformMetaArguments):
    def __init__(
        self,
        *,
        count: typing.Optional[jsii.Number] = None,
        depends_on: typing.Optional[typing.List[cdktf.TerraformResource]] = None,
        lifecycle: typing.Optional[cdktf.TerraformResourceLifecycle] = None,
        provider: typing.Optional[cdktf.TerraformProvider] = None,
        cluster_version: builtins.str,
        gateway: typing.List["HdinsightRserverClusterGateway"],
        location: builtins.str,
        name: builtins.str,
        resource_group_name: builtins.str,
        roles: typing.List["HdinsightRserverClusterRoles"],
        rstudio: builtins.bool,
        tier: builtins.str,
        storage_account: typing.Optional[typing.List["HdinsightRserverClusterStorageAccount"]] = None,
        tags: typing.Optional[typing.Mapping[builtins.str, builtins.str]] = None,
        timeouts: typing.Optional["HdinsightRserverClusterTimeouts"] = None,
    ) -> None:
        """
        :param count: 
        :param depends_on: 
        :param lifecycle: 
        :param provider: 
        :param cluster_version: 
        :param gateway: gateway block.
        :param location: 
        :param name: 
        :param resource_group_name: 
        :param roles: roles block.
        :param rstudio: 
        :param tier: 
        :param storage_account: storage_account block.
        :param tags: 
        :param timeouts: timeouts block.
        """
        if isinstance(lifecycle, dict):
            lifecycle = cdktf.TerraformResourceLifecycle(**lifecycle)
        if isinstance(timeouts, dict):
            timeouts = HdinsightRserverClusterTimeouts(**timeouts)
        self._values: typing.Dict[str, typing.Any] = {
            "cluster_version": cluster_version,
            "gateway": gateway,
            "location": location,
            "name": name,
            "resource_group_name": resource_group_name,
            "roles": roles,
            "rstudio": rstudio,
            "tier": tier,
        }
        if count is not None:
            self._values["count"] = count
        if depends_on is not None:
            self._values["depends_on"] = depends_on
        if lifecycle is not None:
            self._values["lifecycle"] = lifecycle
        if provider is not None:
            self._values["provider"] = provider
        if storage_account is not None:
            self._values["storage_account"] = storage_account
        if tags is not None:
            self._values["tags"] = tags
        if timeouts is not None:
            self._values["timeouts"] = timeouts

    @builtins.property
    def count(self) -> typing.Optional[jsii.Number]:
        """
        :stability: experimental
        """
        result = self._values.get("count")
        return result

    @builtins.property
    def depends_on(self) -> typing.Optional[typing.List[cdktf.TerraformResource]]:
        """
        :stability: experimental
        """
        result = self._values.get("depends_on")
        return result

    @builtins.property
    def lifecycle(self) -> typing.Optional[cdktf.TerraformResourceLifecycle]:
        """
        :stability: experimental
        """
        result = self._values.get("lifecycle")
        return result

    @builtins.property
    def provider(self) -> typing.Optional[cdktf.TerraformProvider]:
        """
        :stability: experimental
        """
        result = self._values.get("provider")
        return result

    @builtins.property
    def cluster_version(self) -> builtins.str:
        result = self._values.get("cluster_version")
        assert result is not None, "Required property 'cluster_version' is missing"
        return result

    @builtins.property
    def gateway(self) -> typing.List["HdinsightRserverClusterGateway"]:
        """gateway block."""
        result = self._values.get("gateway")
        assert result is not None, "Required property 'gateway' is missing"
        return result

    @builtins.property
    def location(self) -> builtins.str:
        result = self._values.get("location")
        assert result is not None, "Required property 'location' is missing"
        return result

    @builtins.property
    def name(self) -> builtins.str:
        result = self._values.get("name")
        assert result is not None, "Required property 'name' is missing"
        return result

    @builtins.property
    def resource_group_name(self) -> builtins.str:
        result = self._values.get("resource_group_name")
        assert result is not None, "Required property 'resource_group_name' is missing"
        return result

    @builtins.property
    def roles(self) -> typing.List["HdinsightRserverClusterRoles"]:
        """roles block."""
        result = self._values.get("roles")
        assert result is not None, "Required property 'roles' is missing"
        return result

    @builtins.property
    def rstudio(self) -> builtins.bool:
        result = self._values.get("rstudio")
        assert result is not None, "Required property 'rstudio' is missing"
        return result

    @builtins.property
    def tier(self) -> builtins.str:
        result = self._values.get("tier")
        assert result is not None, "Required property 'tier' is missing"
        return result

    @builtins.property
    def storage_account(
        self,
    ) -> typing.Optional[typing.List["HdinsightRserverClusterStorageAccount"]]:
        """storage_account block."""
        result = self._values.get("storage_account")
        return result

    @builtins.property
    def tags(self) -> typing.Optional[typing.Mapping[builtins.str, builtins.str]]:
        result = self._values.get("tags")
        return result

    @builtins.property
    def timeouts(self) -> typing.Optional["HdinsightRserverClusterTimeouts"]:
        """timeouts block."""
        result = self._values.get("timeouts")
        return result

    def __eq__(self, rhs: typing.Any) -> builtins.bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs: typing.Any) -> builtins.bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return "HdinsightRserverClusterConfig(%s)" % ", ".join(
            k + "=" + repr(v) for k, v in self._values.items()
        )


@jsii.data_type(
    jsii_type="@cdktf/provider-azurerm.HdinsightRserverClusterGateway",
    jsii_struct_bases=[],
    name_mapping={
        "enabled": "enabled",
        "password": "password",
        "username": "username",
    },
)
class HdinsightRserverClusterGateway:
    def __init__(
        self,
        *,
        enabled: builtins.bool,
        password: builtins.str,
        username: builtins.str,
    ) -> None:
        """
        :param enabled: 
        :param password: 
        :param username: 
        """
        self._values: typing.Dict[str, typing.Any] = {
            "enabled": enabled,
            "password": password,
            "username": username,
        }

    @builtins.property
    def enabled(self) -> builtins.bool:
        result = self._values.get("enabled")
        assert result is not None, "Required property 'enabled' is missing"
        return result

    @builtins.property
    def password(self) -> builtins.str:
        result = self._values.get("password")
        assert result is not None, "Required property 'password' is missing"
        return result

    @builtins.property
    def username(self) -> builtins.str:
        result = self._values.get("username")
        assert result is not None, "Required property 'username' is missing"
        return result

    def __eq__(self, rhs: typing.Any) -> builtins.bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs: typing.Any) -> builtins.bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return "HdinsightRserverClusterGateway(%s)" % ", ".join(
            k + "=" + repr(v) for k, v in self._values.items()
        )


@jsii.data_type(
    jsii_type="@cdktf/provider-azurerm.HdinsightRserverClusterRoles",
    jsii_struct_bases=[],
    name_mapping={
        "edge_node": "edgeNode",
        "head_node": "headNode",
        "worker_node": "workerNode",
        "zookeeper_node": "zookeeperNode",
    },
)
class HdinsightRserverClusterRoles:
    def __init__(
        self,
        *,
        edge_node: typing.List["HdinsightRserverClusterRolesEdgeNode"],
        head_node: typing.List["HdinsightRserverClusterRolesHeadNode"],
        worker_node: typing.List["HdinsightRserverClusterRolesWorkerNode"],
        zookeeper_node: typing.List["HdinsightRserverClusterRolesZookeeperNode"],
    ) -> None:
        """
        :param edge_node: edge_node block.
        :param head_node: head_node block.
        :param worker_node: worker_node block.
        :param zookeeper_node: zookeeper_node block.
        """
        self._values: typing.Dict[str, typing.Any] = {
            "edge_node": edge_node,
            "head_node": head_node,
            "worker_node": worker_node,
            "zookeeper_node": zookeeper_node,
        }

    @builtins.property
    def edge_node(self) -> typing.List["HdinsightRserverClusterRolesEdgeNode"]:
        """edge_node block."""
        result = self._values.get("edge_node")
        assert result is not None, "Required property 'edge_node' is missing"
        return result

    @builtins.property
    def head_node(self) -> typing.List["HdinsightRserverClusterRolesHeadNode"]:
        """head_node block."""
        result = self._values.get("head_node")
        assert result is not None, "Required property 'head_node' is missing"
        return result

    @builtins.property
    def worker_node(self) -> typing.List["HdinsightRserverClusterRolesWorkerNode"]:
        """worker_node block."""
        result = self._values.get("worker_node")
        assert result is not None, "Required property 'worker_node' is missing"
        return result

    @builtins.property
    def zookeeper_node(
        self,
    ) -> typing.List["HdinsightRserverClusterRolesZookeeperNode"]:
        """zookeeper_node block."""
        result = self._values.get("zookeeper_node")
        assert result is not None, "Required property 'zookeeper_node' is missing"
        return result

    def __eq__(self, rhs: typing.Any) -> builtins.bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs: typing.Any) -> builtins.bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return "HdinsightRserverClusterRoles(%s)" % ", ".join(
            k + "=" + repr(v) for k, v in self._values.items()
        )


@jsii.data_type(
    jsii_type="@cdktf/provider-azurerm.HdinsightRserverClusterRolesEdgeNode",
    jsii_struct_bases=[],
    name_mapping={
        "username": "username",
        "vm_size": "vmSize",
        "password": "password",
        "ssh_keys": "sshKeys",
        "subnet_id": "subnetId",
        "virtual_network_id": "virtualNetworkId",
    },
)
class HdinsightRserverClusterRolesEdgeNode:
    def __init__(
        self,
        *,
        username: builtins.str,
        vm_size: builtins.str,
        password: typing.Optional[builtins.str] = None,
        ssh_keys: typing.Optional[typing.List[builtins.str]] = None,
        subnet_id: typing.Optional[builtins.str] = None,
        virtual_network_id: typing.Optional[builtins.str] = None,
    ) -> None:
        """
        :param username: 
        :param vm_size: 
        :param password: 
        :param ssh_keys: 
        :param subnet_id: 
        :param virtual_network_id: 
        """
        self._values: typing.Dict[str, typing.Any] = {
            "username": username,
            "vm_size": vm_size,
        }
        if password is not None:
            self._values["password"] = password
        if ssh_keys is not None:
            self._values["ssh_keys"] = ssh_keys
        if subnet_id is not None:
            self._values["subnet_id"] = subnet_id
        if virtual_network_id is not None:
            self._values["virtual_network_id"] = virtual_network_id

    @builtins.property
    def username(self) -> builtins.str:
        result = self._values.get("username")
        assert result is not None, "Required property 'username' is missing"
        return result

    @builtins.property
    def vm_size(self) -> builtins.str:
        result = self._values.get("vm_size")
        assert result is not None, "Required property 'vm_size' is missing"
        return result

    @builtins.property
    def password(self) -> typing.Optional[builtins.str]:
        result = self._values.get("password")
        return result

    @builtins.property
    def ssh_keys(self) -> typing.Optional[typing.List[builtins.str]]:
        result = self._values.get("ssh_keys")
        return result

    @builtins.property
    def subnet_id(self) -> typing.Optional[builtins.str]:
        result = self._values.get("subnet_id")
        return result

    @builtins.property
    def virtual_network_id(self) -> typing.Optional[builtins.str]:
        result = self._values.get("virtual_network_id")
        return result

    def __eq__(self, rhs: typing.Any) -> builtins.bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs: typing.Any) -> builtins.bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return "HdinsightRserverClusterRolesEdgeNode(%s)" % ", ".join(
            k + "=" + repr(v) for k, v in self._values.items()
        )


@jsii.data_type(
    jsii_type="@cdktf/provider-azurerm.HdinsightRserverClusterRolesHeadNode",
    jsii_struct_bases=[],
    name_mapping={
        "username": "username",
        "vm_size": "vmSize",
        "password": "password",
        "ssh_keys": "sshKeys",
        "subnet_id": "subnetId",
        "virtual_network_id": "virtualNetworkId",
    },
)
class HdinsightRserverClusterRolesHeadNode:
    def __init__(
        self,
        *,
        username: builtins.str,
        vm_size: builtins.str,
        password: typing.Optional[builtins.str] = None,
        ssh_keys: typing.Optional[typing.List[builtins.str]] = None,
        subnet_id: typing.Optional[builtins.str] = None,
        virtual_network_id: typing.Optional[builtins.str] = None,
    ) -> None:
        """
        :param username: 
        :param vm_size: 
        :param password: 
        :param ssh_keys: 
        :param subnet_id: 
        :param virtual_network_id: 
        """
        self._values: typing.Dict[str, typing.Any] = {
            "username": username,
            "vm_size": vm_size,
        }
        if password is not None:
            self._values["password"] = password
        if ssh_keys is not None:
            self._values["ssh_keys"] = ssh_keys
        if subnet_id is not None:
            self._values["subnet_id"] = subnet_id
        if virtual_network_id is not None:
            self._values["virtual_network_id"] = virtual_network_id

    @builtins.property
    def username(self) -> builtins.str:
        result = self._values.get("username")
        assert result is not None, "Required property 'username' is missing"
        return result

    @builtins.property
    def vm_size(self) -> builtins.str:
        result = self._values.get("vm_size")
        assert result is not None, "Required property 'vm_size' is missing"
        return result

    @builtins.property
    def password(self) -> typing.Optional[builtins.str]:
        result = self._values.get("password")
        return result

    @builtins.property
    def ssh_keys(self) -> typing.Optional[typing.List[builtins.str]]:
        result = self._values.get("ssh_keys")
        return result

    @builtins.property
    def subnet_id(self) -> typing.Optional[builtins.str]:
        result = self._values.get("subnet_id")
        return result

    @builtins.property
    def virtual_network_id(self) -> typing.Optional[builtins.str]:
        result = self._values.get("virtual_network_id")
        return result

    def __eq__(self, rhs: typing.Any) -> builtins.bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs: typing.Any) -> builtins.bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return "HdinsightRserverClusterRolesHeadNode(%s)" % ", ".join(
            k + "=" + repr(v) for k, v in self._values.items()
        )


@jsii.data_type(
    jsii_type="@cdktf/provider-azurerm.HdinsightRserverClusterRolesWorkerNode",
    jsii_struct_bases=[],
    name_mapping={
        "target_instance_count": "targetInstanceCount",
        "username": "username",
        "vm_size": "vmSize",
        "min_instance_count": "minInstanceCount",
        "password": "password",
        "ssh_keys": "sshKeys",
        "subnet_id": "subnetId",
        "virtual_network_id": "virtualNetworkId",
    },
)
class HdinsightRserverClusterRolesWorkerNode:
    def __init__(
        self,
        *,
        target_instance_count: jsii.Number,
        username: builtins.str,
        vm_size: builtins.str,
        min_instance_count: typing.Optional[jsii.Number] = None,
        password: typing.Optional[builtins.str] = None,
        ssh_keys: typing.Optional[typing.List[builtins.str]] = None,
        subnet_id: typing.Optional[builtins.str] = None,
        virtual_network_id: typing.Optional[builtins.str] = None,
    ) -> None:
        """
        :param target_instance_count: 
        :param username: 
        :param vm_size: 
        :param min_instance_count: 
        :param password: 
        :param ssh_keys: 
        :param subnet_id: 
        :param virtual_network_id: 
        """
        self._values: typing.Dict[str, typing.Any] = {
            "target_instance_count": target_instance_count,
            "username": username,
            "vm_size": vm_size,
        }
        if min_instance_count is not None:
            self._values["min_instance_count"] = min_instance_count
        if password is not None:
            self._values["password"] = password
        if ssh_keys is not None:
            self._values["ssh_keys"] = ssh_keys
        if subnet_id is not None:
            self._values["subnet_id"] = subnet_id
        if virtual_network_id is not None:
            self._values["virtual_network_id"] = virtual_network_id

    @builtins.property
    def target_instance_count(self) -> jsii.Number:
        result = self._values.get("target_instance_count")
        assert result is not None, "Required property 'target_instance_count' is missing"
        return result

    @builtins.property
    def username(self) -> builtins.str:
        result = self._values.get("username")
        assert result is not None, "Required property 'username' is missing"
        return result

    @builtins.property
    def vm_size(self) -> builtins.str:
        result = self._values.get("vm_size")
        assert result is not None, "Required property 'vm_size' is missing"
        return result

    @builtins.property
    def min_instance_count(self) -> typing.Optional[jsii.Number]:
        result = self._values.get("min_instance_count")
        return result

    @builtins.property
    def password(self) -> typing.Optional[builtins.str]:
        result = self._values.get("password")
        return result

    @builtins.property
    def ssh_keys(self) -> typing.Optional[typing.List[builtins.str]]:
        result = self._values.get("ssh_keys")
        return result

    @builtins.property
    def subnet_id(self) -> typing.Optional[builtins.str]:
        result = self._values.get("subnet_id")
        return result

    @builtins.property
    def virtual_network_id(self) -> typing.Optional[builtins.str]:
        result = self._values.get("virtual_network_id")
        return result

    def __eq__(self, rhs: typing.Any) -> builtins.bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs: typing.Any) -> builtins.bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return "HdinsightRserverClusterRolesWorkerNode(%s)" % ", ".join(
            k + "=" + repr(v) for k, v in self._values.items()
        )


@jsii.data_type(
    jsii_type="@cdktf/provider-azurerm.HdinsightRserverClusterRolesZookeeperNode",
    jsii_struct_bases=[],
    name_mapping={
        "username": "username",
        "vm_size": "vmSize",
        "password": "password",
        "ssh_keys": "sshKeys",
        "subnet_id": "subnetId",
        "virtual_network_id": "virtualNetworkId",
    },
)
class HdinsightRserverClusterRolesZookeeperNode:
    def __init__(
        self,
        *,
        username: builtins.str,
        vm_size: builtins.str,
        password: typing.Optional[builtins.str] = None,
        ssh_keys: typing.Optional[typing.List[builtins.str]] = None,
        subnet_id: typing.Optional[builtins.str] = None,
        virtual_network_id: typing.Optional[builtins.str] = None,
    ) -> None:
        """
        :param username: 
        :param vm_size: 
        :param password: 
        :param ssh_keys: 
        :param subnet_id: 
        :param virtual_network_id: 
        """
        self._values: typing.Dict[str, typing.Any] = {
            "username": username,
            "vm_size": vm_size,
        }
        if password is not None:
            self._values["password"] = password
        if ssh_keys is not None:
            self._values["ssh_keys"] = ssh_keys
        if subnet_id is not None:
            self._values["subnet_id"] = subnet_id
        if virtual_network_id is not None:
            self._values["virtual_network_id"] = virtual_network_id

    @builtins.property
    def username(self) -> builtins.str:
        result = self._values.get("username")
        assert result is not None, "Required property 'username' is missing"
        return result

    @builtins.property
    def vm_size(self) -> builtins.str:
        result = self._values.get("vm_size")
        assert result is not None, "Required property 'vm_size' is missing"
        return result

    @builtins.property
    def password(self) -> typing.Optional[builtins.str]:
        result = self._values.get("password")
        return result

    @builtins.property
    def ssh_keys(self) -> typing.Optional[typing.List[builtins.str]]:
        result = self._values.get("ssh_keys")
        return result

    @builtins.property
    def subnet_id(self) -> typing.Optional[builtins.str]:
        result = self._values.get("subnet_id")
        return result

    @builtins.property
    def virtual_network_id(self) -> typing.Optional[builtins.str]:
        result = self._values.get("virtual_network_id")
        return result

    def __eq__(self, rhs: typing.Any) -> builtins.bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs: typing.Any) -> builtins.bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return "HdinsightRserverClusterRolesZookeeperNode(%s)" % ", ".join(
            k + "=" + repr(v) for k, v in self._values.items()
        )


@jsii.data_type(
    jsii_type="@cdktf/provider-azurerm.HdinsightRserverClusterStorageAccount",
    jsii_struct_bases=[],
    name_mapping={
        "is_default": "isDefault",
        "storage_account_key": "storageAccountKey",
        "storage_container_id": "storageContainerId",
    },
)
class HdinsightRserverClusterStorageAccount:
    def __init__(
        self,
        *,
        is_default: builtins.bool,
        storage_account_key: builtins.str,
        storage_container_id: builtins.str,
    ) -> None:
        """
        :param is_default: 
        :param storage_account_key: 
        :param storage_container_id: 
        """
        self._values: typing.Dict[str, typing.Any] = {
            "is_default": is_default,
            "storage_account_key": storage_account_key,
            "storage_container_id": storage_container_id,
        }

    @builtins.property
    def is_default(self) -> builtins.bool:
        result = self._values.get("is_default")
        assert result is not None, "Required property 'is_default' is missing"
        return result

    @builtins.property
    def storage_account_key(self) -> builtins.str:
        result = self._values.get("storage_account_key")
        assert result is not None, "Required property 'storage_account_key' is missing"
        return result

    @builtins.property
    def storage_container_id(self) -> builtins.str:
        result = self._values.get("storage_container_id")
        assert result is not None, "Required property 'storage_container_id' is missing"
        return result

    def __eq__(self, rhs: typing.Any) -> builtins.bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs: typing.Any) -> builtins.bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return "HdinsightRserverClusterStorageAccount(%s)" % ", ".join(
            k + "=" + repr(v) for k, v in self._values.items()
        )


@jsii.data_type(
    jsii_type="@cdktf/provider-azurerm.HdinsightRserverClusterTimeouts",
    jsii_struct_bases=[],
    name_mapping={
        "create": "create",
        "delete": "delete",
        "read": "read",
        "update": "update",
    },
)
class HdinsightRserverClusterTimeouts:
    def __init__(
        self,
        *,
        create: typing.Optional[builtins.str] = None,
        delete: typing.Optional[builtins.str] = None,
        read: typing.Optional[builtins.str] = None,
        update: typing.Optional[builtins.str] = None,
    ) -> None:
        """
        :param create: 
        :param delete: 
        :param read: 
        :param update: 
        """
        self._values: typing.Dict[str, typing.Any] = {}
        if create is not None:
            self._values["create"] = create
        if delete is not None:
            self._values["delete"] = delete
        if read is not None:
            self._values["read"] = read
        if update is not None:
            self._values["update"] = update

    @builtins.property
    def create(self) -> typing.Optional[builtins.str]:
        result = self._values.get("create")
        return result

    @builtins.property
    def delete(self) -> typing.Optional[builtins.str]:
        result = self._values.get("delete")
        return result

    @builtins.property
    def read(self) -> typing.Optional[builtins.str]:
        result = self._values.get("read")
        return result

    @builtins.property
    def update(self) -> typing.Optional[builtins.str]:
        result = self._values.get("update")
        return result

    def __eq__(self, rhs: typing.Any) -> builtins.bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs: typing.Any) -> builtins.bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return "HdinsightRserverClusterTimeouts(%s)" % ", ".join(
            k + "=" + repr(v) for k, v in self._values.items()
        )


class HdinsightSparkCluster(
    cdktf.TerraformResource,
    metaclass=jsii.JSIIMeta,
    jsii_type="@cdktf/provider-azurerm.HdinsightSparkCluster",
):
    def __init__(
        self,
        scope: constructs.Construct,
        id: builtins.str,
        *,
        cluster_version: builtins.str,
        component_version: typing.List["HdinsightSparkClusterComponentVersion"],
        gateway: typing.List["HdinsightSparkClusterGateway"],
        location: builtins.str,
        name: builtins.str,
        resource_group_name: builtins.str,
        roles: typing.List["HdinsightSparkClusterRoles"],
        tier: builtins.str,
        storage_account: typing.Optional[typing.List["HdinsightSparkClusterStorageAccount"]] = None,
        storage_account_gen2: typing.Optional[typing.List["HdinsightSparkClusterStorageAccountGen2"]] = None,
        tags: typing.Optional[typing.Mapping[builtins.str, builtins.str]] = None,
        timeouts: typing.Optional["HdinsightSparkClusterTimeouts"] = None,
        count: typing.Optional[jsii.Number] = None,
        depends_on: typing.Optional[typing.List[cdktf.TerraformResource]] = None,
        lifecycle: typing.Optional[cdktf.TerraformResourceLifecycle] = None,
        provider: typing.Optional[cdktf.TerraformProvider] = None,
    ) -> None:
        """
        :param scope: -
        :param id: -
        :param cluster_version: 
        :param component_version: component_version block.
        :param gateway: gateway block.
        :param location: 
        :param name: 
        :param resource_group_name: 
        :param roles: roles block.
        :param tier: 
        :param storage_account: storage_account block.
        :param storage_account_gen2: storage_account_gen2 block.
        :param tags: 
        :param timeouts: timeouts block.
        :param count: 
        :param depends_on: 
        :param lifecycle: 
        :param provider: 
        """
        config = HdinsightSparkClusterConfig(
            cluster_version=cluster_version,
            component_version=component_version,
            gateway=gateway,
            location=location,
            name=name,
            resource_group_name=resource_group_name,
            roles=roles,
            tier=tier,
            storage_account=storage_account,
            storage_account_gen2=storage_account_gen2,
            tags=tags,
            timeouts=timeouts,
            count=count,
            depends_on=depends_on,
            lifecycle=lifecycle,
            provider=provider,
        )

        jsii.create(HdinsightSparkCluster, self, [scope, id, config])

    @jsii.member(jsii_name="synthesizeAttributes")
    def _synthesize_attributes(self) -> typing.Mapping[builtins.str, typing.Any]:
        return jsii.invoke(self, "synthesizeAttributes", [])

    @builtins.property # type: ignore
    @jsii.member(jsii_name="httpsEndpoint")
    def https_endpoint(self) -> builtins.str:
        return jsii.get(self, "httpsEndpoint")

    @builtins.property # type: ignore
    @jsii.member(jsii_name="sshEndpoint")
    def ssh_endpoint(self) -> builtins.str:
        return jsii.get(self, "sshEndpoint")

    @builtins.property # type: ignore
    @jsii.member(jsii_name="clusterVersion")
    def cluster_version(self) -> builtins.str:
        return jsii.get(self, "clusterVersion")

    @cluster_version.setter # type: ignore
    def cluster_version(self, value: builtins.str) -> None:
        jsii.set(self, "clusterVersion", value)

    @builtins.property # type: ignore
    @jsii.member(jsii_name="componentVersion")
    def component_version(self) -> typing.List["HdinsightSparkClusterComponentVersion"]:
        return jsii.get(self, "componentVersion")

    @component_version.setter # type: ignore
    def component_version(
        self,
        value: typing.List["HdinsightSparkClusterComponentVersion"],
    ) -> None:
        jsii.set(self, "componentVersion", value)

    @builtins.property # type: ignore
    @jsii.member(jsii_name="gateway")
    def gateway(self) -> typing.List["HdinsightSparkClusterGateway"]:
        return jsii.get(self, "gateway")

    @gateway.setter # type: ignore
    def gateway(self, value: typing.List["HdinsightSparkClusterGateway"]) -> None:
        jsii.set(self, "gateway", value)

    @builtins.property # type: ignore
    @jsii.member(jsii_name="location")
    def location(self) -> builtins.str:
        return jsii.get(self, "location")

    @location.setter # type: ignore
    def location(self, value: builtins.str) -> None:
        jsii.set(self, "location", value)

    @builtins.property # type: ignore
    @jsii.member(jsii_name="name")
    def name(self) -> builtins.str:
        return jsii.get(self, "name")

    @name.setter # type: ignore
    def name(self, value: builtins.str) -> None:
        jsii.set(self, "name", value)

    @builtins.property # type: ignore
    @jsii.member(jsii_name="resourceGroupName")
    def resource_group_name(self) -> builtins.str:
        return jsii.get(self, "resourceGroupName")

    @resource_group_name.setter # type: ignore
    def resource_group_name(self, value: builtins.str) -> None:
        jsii.set(self, "resourceGroupName", value)

    @builtins.property # type: ignore
    @jsii.member(jsii_name="roles")
    def roles(self) -> typing.List["HdinsightSparkClusterRoles"]:
        return jsii.get(self, "roles")

    @roles.setter # type: ignore
    def roles(self, value: typing.List["HdinsightSparkClusterRoles"]) -> None:
        jsii.set(self, "roles", value)

    @builtins.property # type: ignore
    @jsii.member(jsii_name="tier")
    def tier(self) -> builtins.str:
        return jsii.get(self, "tier")

    @tier.setter # type: ignore
    def tier(self, value: builtins.str) -> None:
        jsii.set(self, "tier", value)

    @builtins.property # type: ignore
    @jsii.member(jsii_name="id")
    def id(self) -> typing.Optional[builtins.str]:
        return jsii.get(self, "id")

    @id.setter # type: ignore
    def id(self, value: typing.Optional[builtins.str]) -> None:
        jsii.set(self, "id", value)

    @builtins.property # type: ignore
    @jsii.member(jsii_name="storageAccount")
    def storage_account(
        self,
    ) -> typing.Optional[typing.List["HdinsightSparkClusterStorageAccount"]]:
        return jsii.get(self, "storageAccount")

    @storage_account.setter # type: ignore
    def storage_account(
        self,
        value: typing.Optional[typing.List["HdinsightSparkClusterStorageAccount"]],
    ) -> None:
        jsii.set(self, "storageAccount", value)

    @builtins.property # type: ignore
    @jsii.member(jsii_name="storageAccountGen2")
    def storage_account_gen2(
        self,
    ) -> typing.Optional[typing.List["HdinsightSparkClusterStorageAccountGen2"]]:
        return jsii.get(self, "storageAccountGen2")

    @storage_account_gen2.setter # type: ignore
    def storage_account_gen2(
        self,
        value: typing.Optional[typing.List["HdinsightSparkClusterStorageAccountGen2"]],
    ) -> None:
        jsii.set(self, "storageAccountGen2", value)

    @builtins.property # type: ignore
    @jsii.member(jsii_name="tags")
    def tags(self) -> typing.Optional[typing.Mapping[builtins.str, builtins.str]]:
        return jsii.get(self, "tags")

    @tags.setter # type: ignore
    def tags(
        self,
        value: typing.Optional[typing.Mapping[builtins.str, builtins.str]],
    ) -> None:
        jsii.set(self, "tags", value)

    @builtins.property # type: ignore
    @jsii.member(jsii_name="timeouts")
    def timeouts(self) -> typing.Optional["HdinsightSparkClusterTimeouts"]:
        return jsii.get(self, "timeouts")

    @timeouts.setter # type: ignore
    def timeouts(self, value: typing.Optional["HdinsightSparkClusterTimeouts"]) -> None:
        jsii.set(self, "timeouts", value)


@jsii.data_type(
    jsii_type="@cdktf/provider-azurerm.HdinsightSparkClusterComponentVersion",
    jsii_struct_bases=[],
    name_mapping={"spark": "spark"},
)
class HdinsightSparkClusterComponentVersion:
    def __init__(self, *, spark: builtins.str) -> None:
        """
        :param spark: 
        """
        self._values: typing.Dict[str, typing.Any] = {
            "spark": spark,
        }

    @builtins.property
    def spark(self) -> builtins.str:
        result = self._values.get("spark")
        assert result is not None, "Required property 'spark' is missing"
        return result

    def __eq__(self, rhs: typing.Any) -> builtins.bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs: typing.Any) -> builtins.bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return "HdinsightSparkClusterComponentVersion(%s)" % ", ".join(
            k + "=" + repr(v) for k, v in self._values.items()
        )


@jsii.data_type(
    jsii_type="@cdktf/provider-azurerm.HdinsightSparkClusterConfig",
    jsii_struct_bases=[cdktf.TerraformMetaArguments],
    name_mapping={
        "count": "count",
        "depends_on": "dependsOn",
        "lifecycle": "lifecycle",
        "provider": "provider",
        "cluster_version": "clusterVersion",
        "component_version": "componentVersion",
        "gateway": "gateway",
        "location": "location",
        "name": "name",
        "resource_group_name": "resourceGroupName",
        "roles": "roles",
        "tier": "tier",
        "storage_account": "storageAccount",
        "storage_account_gen2": "storageAccountGen2",
        "tags": "tags",
        "timeouts": "timeouts",
    },
)
class HdinsightSparkClusterConfig(cdktf.TerraformMetaArguments):
    def __init__(
        self,
        *,
        count: typing.Optional[jsii.Number] = None,
        depends_on: typing.Optional[typing.List[cdktf.TerraformResource]] = None,
        lifecycle: typing.Optional[cdktf.TerraformResourceLifecycle] = None,
        provider: typing.Optional[cdktf.TerraformProvider] = None,
        cluster_version: builtins.str,
        component_version: typing.List[HdinsightSparkClusterComponentVersion],
        gateway: typing.List["HdinsightSparkClusterGateway"],
        location: builtins.str,
        name: builtins.str,
        resource_group_name: builtins.str,
        roles: typing.List["HdinsightSparkClusterRoles"],
        tier: builtins.str,
        storage_account: typing.Optional[typing.List["HdinsightSparkClusterStorageAccount"]] = None,
        storage_account_gen2: typing.Optional[typing.List["HdinsightSparkClusterStorageAccountGen2"]] = None,
        tags: typing.Optional[typing.Mapping[builtins.str, builtins.str]] = None,
        timeouts: typing.Optional["HdinsightSparkClusterTimeouts"] = None,
    ) -> None:
        """
        :param count: 
        :param depends_on: 
        :param lifecycle: 
        :param provider: 
        :param cluster_version: 
        :param component_version: component_version block.
        :param gateway: gateway block.
        :param location: 
        :param name: 
        :param resource_group_name: 
        :param roles: roles block.
        :param tier: 
        :param storage_account: storage_account block.
        :param storage_account_gen2: storage_account_gen2 block.
        :param tags: 
        :param timeouts: timeouts block.
        """
        if isinstance(lifecycle, dict):
            lifecycle = cdktf.TerraformResourceLifecycle(**lifecycle)
        if isinstance(timeouts, dict):
            timeouts = HdinsightSparkClusterTimeouts(**timeouts)
        self._values: typing.Dict[str, typing.Any] = {
            "cluster_version": cluster_version,
            "component_version": component_version,
            "gateway": gateway,
            "location": location,
            "name": name,
            "resource_group_name": resource_group_name,
            "roles": roles,
            "tier": tier,
        }
        if count is not None:
            self._values["count"] = count
        if depends_on is not None:
            self._values["depends_on"] = depends_on
        if lifecycle is not None:
            self._values["lifecycle"] = lifecycle
        if provider is not None:
            self._values["provider"] = provider
        if storage_account is not None:
            self._values["storage_account"] = storage_account
        if storage_account_gen2 is not None:
            self._values["storage_account_gen2"] = storage_account_gen2
        if tags is not None:
            self._values["tags"] = tags
        if timeouts is not None:
            self._values["timeouts"] = timeouts

    @builtins.property
    def count(self) -> typing.Optional[jsii.Number]:
        """
        :stability: experimental
        """
        result = self._values.get("count")
        return result

    @builtins.property
    def depends_on(self) -> typing.Optional[typing.List[cdktf.TerraformResource]]:
        """
        :stability: experimental
        """
        result = self._values.get("depends_on")
        return result

    @builtins.property
    def lifecycle(self) -> typing.Optional[cdktf.TerraformResourceLifecycle]:
        """
        :stability: experimental
        """
        result = self._values.get("lifecycle")
        return result

    @builtins.property
    def provider(self) -> typing.Optional[cdktf.TerraformProvider]:
        """
        :stability: experimental
        """
        result = self._values.get("provider")
        return result

    @builtins.property
    def cluster_version(self) -> builtins.str:
        result = self._values.get("cluster_version")
        assert result is not None, "Required property 'cluster_version' is missing"
        return result

    @builtins.property
    def component_version(self) -> typing.List[HdinsightSparkClusterComponentVersion]:
        """component_version block."""
        result = self._values.get("component_version")
        assert result is not None, "Required property 'component_version' is missing"
        return result

    @builtins.property
    def gateway(self) -> typing.List["HdinsightSparkClusterGateway"]:
        """gateway block."""
        result = self._values.get("gateway")
        assert result is not None, "Required property 'gateway' is missing"
        return result

    @builtins.property
    def location(self) -> builtins.str:
        result = self._values.get("location")
        assert result is not None, "Required property 'location' is missing"
        return result

    @builtins.property
    def name(self) -> builtins.str:
        result = self._values.get("name")
        assert result is not None, "Required property 'name' is missing"
        return result

    @builtins.property
    def resource_group_name(self) -> builtins.str:
        result = self._values.get("resource_group_name")
        assert result is not None, "Required property 'resource_group_name' is missing"
        return result

    @builtins.property
    def roles(self) -> typing.List["HdinsightSparkClusterRoles"]:
        """roles block."""
        result = self._values.get("roles")
        assert result is not None, "Required property 'roles' is missing"
        return result

    @builtins.property
    def tier(self) -> builtins.str:
        result = self._values.get("tier")
        assert result is not None, "Required property 'tier' is missing"
        return result

    @builtins.property
    def storage_account(
        self,
    ) -> typing.Optional[typing.List["HdinsightSparkClusterStorageAccount"]]:
        """storage_account block."""
        result = self._values.get("storage_account")
        return result

    @builtins.property
    def storage_account_gen2(
        self,
    ) -> typing.Optional[typing.List["HdinsightSparkClusterStorageAccountGen2"]]:
        """storage_account_gen2 block."""
        result = self._values.get("storage_account_gen2")
        return result

    @builtins.property
    def tags(self) -> typing.Optional[typing.Mapping[builtins.str, builtins.str]]:
        result = self._values.get("tags")
        return result

    @builtins.property
    def timeouts(self) -> typing.Optional["HdinsightSparkClusterTimeouts"]:
        """timeouts block."""
        result = self._values.get("timeouts")
        return result

    def __eq__(self, rhs: typing.Any) -> builtins.bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs: typing.Any) -> builtins.bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return "HdinsightSparkClusterConfig(%s)" % ", ".join(
            k + "=" + repr(v) for k, v in self._values.items()
        )


@jsii.data_type(
    jsii_type="@cdktf/provider-azurerm.HdinsightSparkClusterGateway",
    jsii_struct_bases=[],
    name_mapping={
        "enabled": "enabled",
        "password": "password",
        "username": "username",
    },
)
class HdinsightSparkClusterGateway:
    def __init__(
        self,
        *,
        enabled: builtins.bool,
        password: builtins.str,
        username: builtins.str,
    ) -> None:
        """
        :param enabled: 
        :param password: 
        :param username: 
        """
        self._values: typing.Dict[str, typing.Any] = {
            "enabled": enabled,
            "password": password,
            "username": username,
        }

    @builtins.property
    def enabled(self) -> builtins.bool:
        result = self._values.get("enabled")
        assert result is not None, "Required property 'enabled' is missing"
        return result

    @builtins.property
    def password(self) -> builtins.str:
        result = self._values.get("password")
        assert result is not None, "Required property 'password' is missing"
        return result

    @builtins.property
    def username(self) -> builtins.str:
        result = self._values.get("username")
        assert result is not None, "Required property 'username' is missing"
        return result

    def __eq__(self, rhs: typing.Any) -> builtins.bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs: typing.Any) -> builtins.bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return "HdinsightSparkClusterGateway(%s)" % ", ".join(
            k + "=" + repr(v) for k, v in self._values.items()
        )


@jsii.data_type(
    jsii_type="@cdktf/provider-azurerm.HdinsightSparkClusterRoles",
    jsii_struct_bases=[],
    name_mapping={
        "head_node": "headNode",
        "worker_node": "workerNode",
        "zookeeper_node": "zookeeperNode",
    },
)
class HdinsightSparkClusterRoles:
    def __init__(
        self,
        *,
        head_node: typing.List["HdinsightSparkClusterRolesHeadNode"],
        worker_node: typing.List["HdinsightSparkClusterRolesWorkerNode"],
        zookeeper_node: typing.List["HdinsightSparkClusterRolesZookeeperNode"],
    ) -> None:
        """
        :param head_node: head_node block.
        :param worker_node: worker_node block.
        :param zookeeper_node: zookeeper_node block.
        """
        self._values: typing.Dict[str, typing.Any] = {
            "head_node": head_node,
            "worker_node": worker_node,
            "zookeeper_node": zookeeper_node,
        }

    @builtins.property
    def head_node(self) -> typing.List["HdinsightSparkClusterRolesHeadNode"]:
        """head_node block."""
        result = self._values.get("head_node")
        assert result is not None, "Required property 'head_node' is missing"
        return result

    @builtins.property
    def worker_node(self) -> typing.List["HdinsightSparkClusterRolesWorkerNode"]:
        """worker_node block."""
        result = self._values.get("worker_node")
        assert result is not None, "Required property 'worker_node' is missing"
        return result

    @builtins.property
    def zookeeper_node(self) -> typing.List["HdinsightSparkClusterRolesZookeeperNode"]:
        """zookeeper_node block."""
        result = self._values.get("zookeeper_node")
        assert result is not None, "Required property 'zookeeper_node' is missing"
        return result

    def __eq__(self, rhs: typing.Any) -> builtins.bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs: typing.Any) -> builtins.bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return "HdinsightSparkClusterRoles(%s)" % ", ".join(
            k + "=" + repr(v) for k, v in self._values.items()
        )


@jsii.data_type(
    jsii_type="@cdktf/provider-azurerm.HdinsightSparkClusterRolesHeadNode",
    jsii_struct_bases=[],
    name_mapping={
        "username": "username",
        "vm_size": "vmSize",
        "password": "password",
        "ssh_keys": "sshKeys",
        "subnet_id": "subnetId",
        "virtual_network_id": "virtualNetworkId",
    },
)
class HdinsightSparkClusterRolesHeadNode:
    def __init__(
        self,
        *,
        username: builtins.str,
        vm_size: builtins.str,
        password: typing.Optional[builtins.str] = None,
        ssh_keys: typing.Optional[typing.List[builtins.str]] = None,
        subnet_id: typing.Optional[builtins.str] = None,
        virtual_network_id: typing.Optional[builtins.str] = None,
    ) -> None:
        """
        :param username: 
        :param vm_size: 
        :param password: 
        :param ssh_keys: 
        :param subnet_id: 
        :param virtual_network_id: 
        """
        self._values: typing.Dict[str, typing.Any] = {
            "username": username,
            "vm_size": vm_size,
        }
        if password is not None:
            self._values["password"] = password
        if ssh_keys is not None:
            self._values["ssh_keys"] = ssh_keys
        if subnet_id is not None:
            self._values["subnet_id"] = subnet_id
        if virtual_network_id is not None:
            self._values["virtual_network_id"] = virtual_network_id

    @builtins.property
    def username(self) -> builtins.str:
        result = self._values.get("username")
        assert result is not None, "Required property 'username' is missing"
        return result

    @builtins.property
    def vm_size(self) -> builtins.str:
        result = self._values.get("vm_size")
        assert result is not None, "Required property 'vm_size' is missing"
        return result

    @builtins.property
    def password(self) -> typing.Optional[builtins.str]:
        result = self._values.get("password")
        return result

    @builtins.property
    def ssh_keys(self) -> typing.Optional[typing.List[builtins.str]]:
        result = self._values.get("ssh_keys")
        return result

    @builtins.property
    def subnet_id(self) -> typing.Optional[builtins.str]:
        result = self._values.get("subnet_id")
        return result

    @builtins.property
    def virtual_network_id(self) -> typing.Optional[builtins.str]:
        result = self._values.get("virtual_network_id")
        return result

    def __eq__(self, rhs: typing.Any) -> builtins.bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs: typing.Any) -> builtins.bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return "HdinsightSparkClusterRolesHeadNode(%s)" % ", ".join(
            k + "=" + repr(v) for k, v in self._values.items()
        )


@jsii.data_type(
    jsii_type="@cdktf/provider-azurerm.HdinsightSparkClusterRolesWorkerNode",
    jsii_struct_bases=[],
    name_mapping={
        "target_instance_count": "targetInstanceCount",
        "username": "username",
        "vm_size": "vmSize",
        "min_instance_count": "minInstanceCount",
        "password": "password",
        "ssh_keys": "sshKeys",
        "subnet_id": "subnetId",
        "virtual_network_id": "virtualNetworkId",
    },
)
class HdinsightSparkClusterRolesWorkerNode:
    def __init__(
        self,
        *,
        target_instance_count: jsii.Number,
        username: builtins.str,
        vm_size: builtins.str,
        min_instance_count: typing.Optional[jsii.Number] = None,
        password: typing.Optional[builtins.str] = None,
        ssh_keys: typing.Optional[typing.List[builtins.str]] = None,
        subnet_id: typing.Optional[builtins.str] = None,
        virtual_network_id: typing.Optional[builtins.str] = None,
    ) -> None:
        """
        :param target_instance_count: 
        :param username: 
        :param vm_size: 
        :param min_instance_count: 
        :param password: 
        :param ssh_keys: 
        :param subnet_id: 
        :param virtual_network_id: 
        """
        self._values: typing.Dict[str, typing.Any] = {
            "target_instance_count": target_instance_count,
            "username": username,
            "vm_size": vm_size,
        }
        if min_instance_count is not None:
            self._values["min_instance_count"] = min_instance_count
        if password is not None:
            self._values["password"] = password
        if ssh_keys is not None:
            self._values["ssh_keys"] = ssh_keys
        if subnet_id is not None:
            self._values["subnet_id"] = subnet_id
        if virtual_network_id is not None:
            self._values["virtual_network_id"] = virtual_network_id

    @builtins.property
    def target_instance_count(self) -> jsii.Number:
        result = self._values.get("target_instance_count")
        assert result is not None, "Required property 'target_instance_count' is missing"
        return result

    @builtins.property
    def username(self) -> builtins.str:
        result = self._values.get("username")
        assert result is not None, "Required property 'username' is missing"
        return result

    @builtins.property
    def vm_size(self) -> builtins.str:
        result = self._values.get("vm_size")
        assert result is not None, "Required property 'vm_size' is missing"
        return result

    @builtins.property
    def min_instance_count(self) -> typing.Optional[jsii.Number]:
        result = self._values.get("min_instance_count")
        return result

    @builtins.property
    def password(self) -> typing.Optional[builtins.str]:
        result = self._values.get("password")
        return result

    @builtins.property
    def ssh_keys(self) -> typing.Optional[typing.List[builtins.str]]:
        result = self._values.get("ssh_keys")
        return result

    @builtins.property
    def subnet_id(self) -> typing.Optional[builtins.str]:
        result = self._values.get("subnet_id")
        return result

    @builtins.property
    def virtual_network_id(self) -> typing.Optional[builtins.str]:
        result = self._values.get("virtual_network_id")
        return result

    def __eq__(self, rhs: typing.Any) -> builtins.bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs: typing.Any) -> builtins.bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return "HdinsightSparkClusterRolesWorkerNode(%s)" % ", ".join(
            k + "=" + repr(v) for k, v in self._values.items()
        )


@jsii.data_type(
    jsii_type="@cdktf/provider-azurerm.HdinsightSparkClusterRolesZookeeperNode",
    jsii_struct_bases=[],
    name_mapping={
        "username": "username",
        "vm_size": "vmSize",
        "password": "password",
        "ssh_keys": "sshKeys",
        "subnet_id": "subnetId",
        "virtual_network_id": "virtualNetworkId",
    },
)
class HdinsightSparkClusterRolesZookeeperNode:
    def __init__(
        self,
        *,
        username: builtins.str,
        vm_size: builtins.str,
        password: typing.Optional[builtins.str] = None,
        ssh_keys: typing.Optional[typing.List[builtins.str]] = None,
        subnet_id: typing.Optional[builtins.str] = None,
        virtual_network_id: typing.Optional[builtins.str] = None,
    ) -> None:
        """
        :param username: 
        :param vm_size: 
        :param password: 
        :param ssh_keys: 
        :param subnet_id: 
        :param virtual_network_id: 
        """
        self._values: typing.Dict[str, typing.Any] = {
            "username": username,
            "vm_size": vm_size,
        }
        if password is not None:
            self._values["password"] = password
        if ssh_keys is not None:
            self._values["ssh_keys"] = ssh_keys
        if subnet_id is not None:
            self._values["subnet_id"] = subnet_id
        if virtual_network_id is not None:
            self._values["virtual_network_id"] = virtual_network_id

    @builtins.property
    def username(self) -> builtins.str:
        result = self._values.get("username")
        assert result is not None, "Required property 'username' is missing"
        return result

    @builtins.property
    def vm_size(self) -> builtins.str:
        result = self._values.get("vm_size")
        assert result is not None, "Required property 'vm_size' is missing"
        return result

    @builtins.property
    def password(self) -> typing.Optional[builtins.str]:
        result = self._values.get("password")
        return result

    @builtins.property
    def ssh_keys(self) -> typing.Optional[typing.List[builtins.str]]:
        result = self._values.get("ssh_keys")
        return result

    @builtins.property
    def subnet_id(self) -> typing.Optional[builtins.str]:
        result = self._values.get("subnet_id")
        return result

    @builtins.property
    def virtual_network_id(self) -> typing.Optional[builtins.str]:
        result = self._values.get("virtual_network_id")
        return result

    def __eq__(self, rhs: typing.Any) -> builtins.bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs: typing.Any) -> builtins.bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return "HdinsightSparkClusterRolesZookeeperNode(%s)" % ", ".join(
            k + "=" + repr(v) for k, v in self._values.items()
        )


@jsii.data_type(
    jsii_type="@cdktf/provider-azurerm.HdinsightSparkClusterStorageAccount",
    jsii_struct_bases=[],
    name_mapping={
        "is_default": "isDefault",
        "storage_account_key": "storageAccountKey",
        "storage_container_id": "storageContainerId",
    },
)
class HdinsightSparkClusterStorageAccount:
    def __init__(
        self,
        *,
        is_default: builtins.bool,
        storage_account_key: builtins.str,
        storage_container_id: builtins.str,
    ) -> None:
        """
        :param is_default: 
        :param storage_account_key: 
        :param storage_container_id: 
        """
        self._values: typing.Dict[str, typing.Any] = {
            "is_default": is_default,
            "storage_account_key": storage_account_key,
            "storage_container_id": storage_container_id,
        }

    @builtins.property
    def is_default(self) -> builtins.bool:
        result = self._values.get("is_default")
        assert result is not None, "Required property 'is_default' is missing"
        return result

    @builtins.property
    def storage_account_key(self) -> builtins.str:
        result = self._values.get("storage_account_key")
        assert result is not None, "Required property 'storage_account_key' is missing"
        return result

    @builtins.property
    def storage_container_id(self) -> builtins.str:
        result = self._values.get("storage_container_id")
        assert result is not None, "Required property 'storage_container_id' is missing"
        return result

    def __eq__(self, rhs: typing.Any) -> builtins.bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs: typing.Any) -> builtins.bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return "HdinsightSparkClusterStorageAccount(%s)" % ", ".join(
            k + "=" + repr(v) for k, v in self._values.items()
        )


@jsii.data_type(
    jsii_type="@cdktf/provider-azurerm.HdinsightSparkClusterStorageAccountGen2",
    jsii_struct_bases=[],
    name_mapping={
        "filesystem_id": "filesystemId",
        "is_default": "isDefault",
        "managed_identity_resource_id": "managedIdentityResourceId",
        "storage_resource_id": "storageResourceId",
    },
)
class HdinsightSparkClusterStorageAccountGen2:
    def __init__(
        self,
        *,
        filesystem_id: builtins.str,
        is_default: builtins.bool,
        managed_identity_resource_id: builtins.str,
        storage_resource_id: builtins.str,
    ) -> None:
        """
        :param filesystem_id: 
        :param is_default: 
        :param managed_identity_resource_id: 
        :param storage_resource_id: 
        """
        self._values: typing.Dict[str, typing.Any] = {
            "filesystem_id": filesystem_id,
            "is_default": is_default,
            "managed_identity_resource_id": managed_identity_resource_id,
            "storage_resource_id": storage_resource_id,
        }

    @builtins.property
    def filesystem_id(self) -> builtins.str:
        result = self._values.get("filesystem_id")
        assert result is not None, "Required property 'filesystem_id' is missing"
        return result

    @builtins.property
    def is_default(self) -> builtins.bool:
        result = self._values.get("is_default")
        assert result is not None, "Required property 'is_default' is missing"
        return result

    @builtins.property
    def managed_identity_resource_id(self) -> builtins.str:
        result = self._values.get("managed_identity_resource_id")
        assert result is not None, "Required property 'managed_identity_resource_id' is missing"
        return result

    @builtins.property
    def storage_resource_id(self) -> builtins.str:
        result = self._values.get("storage_resource_id")
        assert result is not None, "Required property 'storage_resource_id' is missing"
        return result

    def __eq__(self, rhs: typing.Any) -> builtins.bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs: typing.Any) -> builtins.bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return "HdinsightSparkClusterStorageAccountGen2(%s)" % ", ".join(
            k + "=" + repr(v) for k, v in self._values.items()
        )


@jsii.data_type(
    jsii_type="@cdktf/provider-azurerm.HdinsightSparkClusterTimeouts",
    jsii_struct_bases=[],
    name_mapping={
        "create": "create",
        "delete": "delete",
        "read": "read",
        "update": "update",
    },
)
class HdinsightSparkClusterTimeouts:
    def __init__(
        self,
        *,
        create: typing.Optional[builtins.str] = None,
        delete: typing.Optional[builtins.str] = None,
        read: typing.Optional[builtins.str] = None,
        update: typing.Optional[builtins.str] = None,
    ) -> None:
        """
        :param create: 
        :param delete: 
        :param read: 
        :param update: 
        """
        self._values: typing.Dict[str, typing.Any] = {}
        if create is not None:
            self._values["create"] = create
        if delete is not None:
            self._values["delete"] = delete
        if read is not None:
            self._values["read"] = read
        if update is not None:
            self._values["update"] = update

    @builtins.property
    def create(self) -> typing.Optional[builtins.str]:
        result = self._values.get("create")
        return result

    @builtins.property
    def delete(self) -> typing.Optional[builtins.str]:
        result = self._values.get("delete")
        return result

    @builtins.property
    def read(self) -> typing.Optional[builtins.str]:
        result = self._values.get("read")
        return result

    @builtins.property
    def update(self) -> typing.Optional[builtins.str]:
        result = self._values.get("update")
        return result

    def __eq__(self, rhs: typing.Any) -> builtins.bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs: typing.Any) -> builtins.bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return "HdinsightSparkClusterTimeouts(%s)" % ", ".join(
            k + "=" + repr(v) for k, v in self._values.items()
        )


class HdinsightStormCluster(
    cdktf.TerraformResource,
    metaclass=jsii.JSIIMeta,
    jsii_type="@cdktf/provider-azurerm.HdinsightStormCluster",
):
    def __init__(
        self,
        scope: constructs.Construct,
        id: builtins.str,
        *,
        cluster_version: builtins.str,
        component_version: typing.List["HdinsightStormClusterComponentVersion"],
        gateway: typing.List["HdinsightStormClusterGateway"],
        location: builtins.str,
        name: builtins.str,
        resource_group_name: builtins.str,
        roles: typing.List["HdinsightStormClusterRoles"],
        tier: builtins.str,
        storage_account: typing.Optional[typing.List["HdinsightStormClusterStorageAccount"]] = None,
        tags: typing.Optional[typing.Mapping[builtins.str, builtins.str]] = None,
        timeouts: typing.Optional["HdinsightStormClusterTimeouts"] = None,
        count: typing.Optional[jsii.Number] = None,
        depends_on: typing.Optional[typing.List[cdktf.TerraformResource]] = None,
        lifecycle: typing.Optional[cdktf.TerraformResourceLifecycle] = None,
        provider: typing.Optional[cdktf.TerraformProvider] = None,
    ) -> None:
        """
        :param scope: -
        :param id: -
        :param cluster_version: 
        :param component_version: component_version block.
        :param gateway: gateway block.
        :param location: 
        :param name: 
        :param resource_group_name: 
        :param roles: roles block.
        :param tier: 
        :param storage_account: storage_account block.
        :param tags: 
        :param timeouts: timeouts block.
        :param count: 
        :param depends_on: 
        :param lifecycle: 
        :param provider: 
        """
        config = HdinsightStormClusterConfig(
            cluster_version=cluster_version,
            component_version=component_version,
            gateway=gateway,
            location=location,
            name=name,
            resource_group_name=resource_group_name,
            roles=roles,
            tier=tier,
            storage_account=storage_account,
            tags=tags,
            timeouts=timeouts,
            count=count,
            depends_on=depends_on,
            lifecycle=lifecycle,
            provider=provider,
        )

        jsii.create(HdinsightStormCluster, self, [scope, id, config])

    @jsii.member(jsii_name="synthesizeAttributes")
    def _synthesize_attributes(self) -> typing.Mapping[builtins.str, typing.Any]:
        return jsii.invoke(self, "synthesizeAttributes", [])

    @builtins.property # type: ignore
    @jsii.member(jsii_name="httpsEndpoint")
    def https_endpoint(self) -> builtins.str:
        return jsii.get(self, "httpsEndpoint")

    @builtins.property # type: ignore
    @jsii.member(jsii_name="sshEndpoint")
    def ssh_endpoint(self) -> builtins.str:
        return jsii.get(self, "sshEndpoint")

    @builtins.property # type: ignore
    @jsii.member(jsii_name="clusterVersion")
    def cluster_version(self) -> builtins.str:
        return jsii.get(self, "clusterVersion")

    @cluster_version.setter # type: ignore
    def cluster_version(self, value: builtins.str) -> None:
        jsii.set(self, "clusterVersion", value)

    @builtins.property # type: ignore
    @jsii.member(jsii_name="componentVersion")
    def component_version(self) -> typing.List["HdinsightStormClusterComponentVersion"]:
        return jsii.get(self, "componentVersion")

    @component_version.setter # type: ignore
    def component_version(
        self,
        value: typing.List["HdinsightStormClusterComponentVersion"],
    ) -> None:
        jsii.set(self, "componentVersion", value)

    @builtins.property # type: ignore
    @jsii.member(jsii_name="gateway")
    def gateway(self) -> typing.List["HdinsightStormClusterGateway"]:
        return jsii.get(self, "gateway")

    @gateway.setter # type: ignore
    def gateway(self, value: typing.List["HdinsightStormClusterGateway"]) -> None:
        jsii.set(self, "gateway", value)

    @builtins.property # type: ignore
    @jsii.member(jsii_name="location")
    def location(self) -> builtins.str:
        return jsii.get(self, "location")

    @location.setter # type: ignore
    def location(self, value: builtins.str) -> None:
        jsii.set(self, "location", value)

    @builtins.property # type: ignore
    @jsii.member(jsii_name="name")
    def name(self) -> builtins.str:
        return jsii.get(self, "name")

    @name.setter # type: ignore
    def name(self, value: builtins.str) -> None:
        jsii.set(self, "name", value)

    @builtins.property # type: ignore
    @jsii.member(jsii_name="resourceGroupName")
    def resource_group_name(self) -> builtins.str:
        return jsii.get(self, "resourceGroupName")

    @resource_group_name.setter # type: ignore
    def resource_group_name(self, value: builtins.str) -> None:
        jsii.set(self, "resourceGroupName", value)

    @builtins.property # type: ignore
    @jsii.member(jsii_name="roles")
    def roles(self) -> typing.List["HdinsightStormClusterRoles"]:
        return jsii.get(self, "roles")

    @roles.setter # type: ignore
    def roles(self, value: typing.List["HdinsightStormClusterRoles"]) -> None:
        jsii.set(self, "roles", value)

    @builtins.property # type: ignore
    @jsii.member(jsii_name="tier")
    def tier(self) -> builtins.str:
        return jsii.get(self, "tier")

    @tier.setter # type: ignore
    def tier(self, value: builtins.str) -> None:
        jsii.set(self, "tier", value)

    @builtins.property # type: ignore
    @jsii.member(jsii_name="id")
    def id(self) -> typing.Optional[builtins.str]:
        return jsii.get(self, "id")

    @id.setter # type: ignore
    def id(self, value: typing.Optional[builtins.str]) -> None:
        jsii.set(self, "id", value)

    @builtins.property # type: ignore
    @jsii.member(jsii_name="storageAccount")
    def storage_account(
        self,
    ) -> typing.Optional[typing.List["HdinsightStormClusterStorageAccount"]]:
        return jsii.get(self, "storageAccount")

    @storage_account.setter # type: ignore
    def storage_account(
        self,
        value: typing.Optional[typing.List["HdinsightStormClusterStorageAccount"]],
    ) -> None:
        jsii.set(self, "storageAccount", value)

    @builtins.property # type: ignore
    @jsii.member(jsii_name="tags")
    def tags(self) -> typing.Optional[typing.Mapping[builtins.str, builtins.str]]:
        return jsii.get(self, "tags")

    @tags.setter # type: ignore
    def tags(
        self,
        value: typing.Optional[typing.Mapping[builtins.str, builtins.str]],
    ) -> None:
        jsii.set(self, "tags", value)

    @builtins.property # type: ignore
    @jsii.member(jsii_name="timeouts")
    def timeouts(self) -> typing.Optional["HdinsightStormClusterTimeouts"]:
        return jsii.get(self, "timeouts")

    @timeouts.setter # type: ignore
    def timeouts(self, value: typing.Optional["HdinsightStormClusterTimeouts"]) -> None:
        jsii.set(self, "timeouts", value)


@jsii.data_type(
    jsii_type="@cdktf/provider-azurerm.HdinsightStormClusterComponentVersion",
    jsii_struct_bases=[],
    name_mapping={"storm": "storm"},
)
class HdinsightStormClusterComponentVersion:
    def __init__(self, *, storm: builtins.str) -> None:
        """
        :param storm: 
        """
        self._values: typing.Dict[str, typing.Any] = {
            "storm": storm,
        }

    @builtins.property
    def storm(self) -> builtins.str:
        result = self._values.get("storm")
        assert result is not None, "Required property 'storm' is missing"
        return result

    def __eq__(self, rhs: typing.Any) -> builtins.bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs: typing.Any) -> builtins.bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return "HdinsightStormClusterComponentVersion(%s)" % ", ".join(
            k + "=" + repr(v) for k, v in self._values.items()
        )


@jsii.data_type(
    jsii_type="@cdktf/provider-azurerm.HdinsightStormClusterConfig",
    jsii_struct_bases=[cdktf.TerraformMetaArguments],
    name_mapping={
        "count": "count",
        "depends_on": "dependsOn",
        "lifecycle": "lifecycle",
        "provider": "provider",
        "cluster_version": "clusterVersion",
        "component_version": "componentVersion",
        "gateway": "gateway",
        "location": "location",
        "name": "name",
        "resource_group_name": "resourceGroupName",
        "roles": "roles",
        "tier": "tier",
        "storage_account": "storageAccount",
        "tags": "tags",
        "timeouts": "timeouts",
    },
)
class HdinsightStormClusterConfig(cdktf.TerraformMetaArguments):
    def __init__(
        self,
        *,
        count: typing.Optional[jsii.Number] = None,
        depends_on: typing.Optional[typing.List[cdktf.TerraformResource]] = None,
        lifecycle: typing.Optional[cdktf.TerraformResourceLifecycle] = None,
        provider: typing.Optional[cdktf.TerraformProvider] = None,
        cluster_version: builtins.str,
        component_version: typing.List[HdinsightStormClusterComponentVersion],
        gateway: typing.List["HdinsightStormClusterGateway"],
        location: builtins.str,
        name: builtins.str,
        resource_group_name: builtins.str,
        roles: typing.List["HdinsightStormClusterRoles"],
        tier: builtins.str,
        storage_account: typing.Optional[typing.List["HdinsightStormClusterStorageAccount"]] = None,
        tags: typing.Optional[typing.Mapping[builtins.str, builtins.str]] = None,
        timeouts: typing.Optional["HdinsightStormClusterTimeouts"] = None,
    ) -> None:
        """
        :param count: 
        :param depends_on: 
        :param lifecycle: 
        :param provider: 
        :param cluster_version: 
        :param component_version: component_version block.
        :param gateway: gateway block.
        :param location: 
        :param name: 
        :param resource_group_name: 
        :param roles: roles block.
        :param tier: 
        :param storage_account: storage_account block.
        :param tags: 
        :param timeouts: timeouts block.
        """
        if isinstance(lifecycle, dict):
            lifecycle = cdktf.TerraformResourceLifecycle(**lifecycle)
        if isinstance(timeouts, dict):
            timeouts = HdinsightStormClusterTimeouts(**timeouts)
        self._values: typing.Dict[str, typing.Any] = {
            "cluster_version": cluster_version,
            "component_version": component_version,
            "gateway": gateway,
            "location": location,
            "name": name,
            "resource_group_name": resource_group_name,
            "roles": roles,
            "tier": tier,
        }
        if count is not None:
            self._values["count"] = count
        if depends_on is not None:
            self._values["depends_on"] = depends_on
        if lifecycle is not None:
            self._values["lifecycle"] = lifecycle
        if provider is not None:
            self._values["provider"] = provider
        if storage_account is not None:
            self._values["storage_account"] = storage_account
        if tags is not None:
            self._values["tags"] = tags
        if timeouts is not None:
            self._values["timeouts"] = timeouts

    @builtins.property
    def count(self) -> typing.Optional[jsii.Number]:
        """
        :stability: experimental
        """
        result = self._values.get("count")
        return result

    @builtins.property
    def depends_on(self) -> typing.Optional[typing.List[cdktf.TerraformResource]]:
        """
        :stability: experimental
        """
        result = self._values.get("depends_on")
        return result

    @builtins.property
    def lifecycle(self) -> typing.Optional[cdktf.TerraformResourceLifecycle]:
        """
        :stability: experimental
        """
        result = self._values.get("lifecycle")
        return result

    @builtins.property
    def provider(self) -> typing.Optional[cdktf.TerraformProvider]:
        """
        :stability: experimental
        """
        result = self._values.get("provider")
        return result

    @builtins.property
    def cluster_version(self) -> builtins.str:
        result = self._values.get("cluster_version")
        assert result is not None, "Required property 'cluster_version' is missing"
        return result

    @builtins.property
    def component_version(self) -> typing.List[HdinsightStormClusterComponentVersion]:
        """component_version block."""
        result = self._values.get("component_version")
        assert result is not None, "Required property 'component_version' is missing"
        return result

    @builtins.property
    def gateway(self) -> typing.List["HdinsightStormClusterGateway"]:
        """gateway block."""
        result = self._values.get("gateway")
        assert result is not None, "Required property 'gateway' is missing"
        return result

    @builtins.property
    def location(self) -> builtins.str:
        result = self._values.get("location")
        assert result is not None, "Required property 'location' is missing"
        return result

    @builtins.property
    def name(self) -> builtins.str:
        result = self._values.get("name")
        assert result is not None, "Required property 'name' is missing"
        return result

    @builtins.property
    def resource_group_name(self) -> builtins.str:
        result = self._values.get("resource_group_name")
        assert result is not None, "Required property 'resource_group_name' is missing"
        return result

    @builtins.property
    def roles(self) -> typing.List["HdinsightStormClusterRoles"]:
        """roles block."""
        result = self._values.get("roles")
        assert result is not None, "Required property 'roles' is missing"
        return result

    @builtins.property
    def tier(self) -> builtins.str:
        result = self._values.get("tier")
        assert result is not None, "Required property 'tier' is missing"
        return result

    @builtins.property
    def storage_account(
        self,
    ) -> typing.Optional[typing.List["HdinsightStormClusterStorageAccount"]]:
        """storage_account block."""
        result = self._values.get("storage_account")
        return result

    @builtins.property
    def tags(self) -> typing.Optional[typing.Mapping[builtins.str, builtins.str]]:
        result = self._values.get("tags")
        return result

    @builtins.property
    def timeouts(self) -> typing.Optional["HdinsightStormClusterTimeouts"]:
        """timeouts block."""
        result = self._values.get("timeouts")
        return result

    def __eq__(self, rhs: typing.Any) -> builtins.bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs: typing.Any) -> builtins.bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return "HdinsightStormClusterConfig(%s)" % ", ".join(
            k + "=" + repr(v) for k, v in self._values.items()
        )


@jsii.data_type(
    jsii_type="@cdktf/provider-azurerm.HdinsightStormClusterGateway",
    jsii_struct_bases=[],
    name_mapping={
        "enabled": "enabled",
        "password": "password",
        "username": "username",
    },
)
class HdinsightStormClusterGateway:
    def __init__(
        self,
        *,
        enabled: builtins.bool,
        password: builtins.str,
        username: builtins.str,
    ) -> None:
        """
        :param enabled: 
        :param password: 
        :param username: 
        """
        self._values: typing.Dict[str, typing.Any] = {
            "enabled": enabled,
            "password": password,
            "username": username,
        }

    @builtins.property
    def enabled(self) -> builtins.bool:
        result = self._values.get("enabled")
        assert result is not None, "Required property 'enabled' is missing"
        return result

    @builtins.property
    def password(self) -> builtins.str:
        result = self._values.get("password")
        assert result is not None, "Required property 'password' is missing"
        return result

    @builtins.property
    def username(self) -> builtins.str:
        result = self._values.get("username")
        assert result is not None, "Required property 'username' is missing"
        return result

    def __eq__(self, rhs: typing.Any) -> builtins.bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs: typing.Any) -> builtins.bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return "HdinsightStormClusterGateway(%s)" % ", ".join(
            k + "=" + repr(v) for k, v in self._values.items()
        )


@jsii.data_type(
    jsii_type="@cdktf/provider-azurerm.HdinsightStormClusterRoles",
    jsii_struct_bases=[],
    name_mapping={
        "head_node": "headNode",
        "worker_node": "workerNode",
        "zookeeper_node": "zookeeperNode",
    },
)
class HdinsightStormClusterRoles:
    def __init__(
        self,
        *,
        head_node: typing.List["HdinsightStormClusterRolesHeadNode"],
        worker_node: typing.List["HdinsightStormClusterRolesWorkerNode"],
        zookeeper_node: typing.List["HdinsightStormClusterRolesZookeeperNode"],
    ) -> None:
        """
        :param head_node: head_node block.
        :param worker_node: worker_node block.
        :param zookeeper_node: zookeeper_node block.
        """
        self._values: typing.Dict[str, typing.Any] = {
            "head_node": head_node,
            "worker_node": worker_node,
            "zookeeper_node": zookeeper_node,
        }

    @builtins.property
    def head_node(self) -> typing.List["HdinsightStormClusterRolesHeadNode"]:
        """head_node block."""
        result = self._values.get("head_node")
        assert result is not None, "Required property 'head_node' is missing"
        return result

    @builtins.property
    def worker_node(self) -> typing.List["HdinsightStormClusterRolesWorkerNode"]:
        """worker_node block."""
        result = self._values.get("worker_node")
        assert result is not None, "Required property 'worker_node' is missing"
        return result

    @builtins.property
    def zookeeper_node(self) -> typing.List["HdinsightStormClusterRolesZookeeperNode"]:
        """zookeeper_node block."""
        result = self._values.get("zookeeper_node")
        assert result is not None, "Required property 'zookeeper_node' is missing"
        return result

    def __eq__(self, rhs: typing.Any) -> builtins.bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs: typing.Any) -> builtins.bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return "HdinsightStormClusterRoles(%s)" % ", ".join(
            k + "=" + repr(v) for k, v in self._values.items()
        )


@jsii.data_type(
    jsii_type="@cdktf/provider-azurerm.HdinsightStormClusterRolesHeadNode",
    jsii_struct_bases=[],
    name_mapping={
        "username": "username",
        "vm_size": "vmSize",
        "password": "password",
        "ssh_keys": "sshKeys",
        "subnet_id": "subnetId",
        "virtual_network_id": "virtualNetworkId",
    },
)
class HdinsightStormClusterRolesHeadNode:
    def __init__(
        self,
        *,
        username: builtins.str,
        vm_size: builtins.str,
        password: typing.Optional[builtins.str] = None,
        ssh_keys: typing.Optional[typing.List[builtins.str]] = None,
        subnet_id: typing.Optional[builtins.str] = None,
        virtual_network_id: typing.Optional[builtins.str] = None,
    ) -> None:
        """
        :param username: 
        :param vm_size: 
        :param password: 
        :param ssh_keys: 
        :param subnet_id: 
        :param virtual_network_id: 
        """
        self._values: typing.Dict[str, typing.Any] = {
            "username": username,
            "vm_size": vm_size,
        }
        if password is not None:
            self._values["password"] = password
        if ssh_keys is not None:
            self._values["ssh_keys"] = ssh_keys
        if subnet_id is not None:
            self._values["subnet_id"] = subnet_id
        if virtual_network_id is not None:
            self._values["virtual_network_id"] = virtual_network_id

    @builtins.property
    def username(self) -> builtins.str:
        result = self._values.get("username")
        assert result is not None, "Required property 'username' is missing"
        return result

    @builtins.property
    def vm_size(self) -> builtins.str:
        result = self._values.get("vm_size")
        assert result is not None, "Required property 'vm_size' is missing"
        return result

    @builtins.property
    def password(self) -> typing.Optional[builtins.str]:
        result = self._values.get("password")
        return result

    @builtins.property
    def ssh_keys(self) -> typing.Optional[typing.List[builtins.str]]:
        result = self._values.get("ssh_keys")
        return result

    @builtins.property
    def subnet_id(self) -> typing.Optional[builtins.str]:
        result = self._values.get("subnet_id")
        return result

    @builtins.property
    def virtual_network_id(self) -> typing.Optional[builtins.str]:
        result = self._values.get("virtual_network_id")
        return result

    def __eq__(self, rhs: typing.Any) -> builtins.bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs: typing.Any) -> builtins.bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return "HdinsightStormClusterRolesHeadNode(%s)" % ", ".join(
            k + "=" + repr(v) for k, v in self._values.items()
        )


@jsii.data_type(
    jsii_type="@cdktf/provider-azurerm.HdinsightStormClusterRolesWorkerNode",
    jsii_struct_bases=[],
    name_mapping={
        "target_instance_count": "targetInstanceCount",
        "username": "username",
        "vm_size": "vmSize",
        "min_instance_count": "minInstanceCount",
        "password": "password",
        "ssh_keys": "sshKeys",
        "subnet_id": "subnetId",
        "virtual_network_id": "virtualNetworkId",
    },
)
class HdinsightStormClusterRolesWorkerNode:
    def __init__(
        self,
        *,
        target_instance_count: jsii.Number,
        username: builtins.str,
        vm_size: builtins.str,
        min_instance_count: typing.Optional[jsii.Number] = None,
        password: typing.Optional[builtins.str] = None,
        ssh_keys: typing.Optional[typing.List[builtins.str]] = None,
        subnet_id: typing.Optional[builtins.str] = None,
        virtual_network_id: typing.Optional[builtins.str] = None,
    ) -> None:
        """
        :param target_instance_count: 
        :param username: 
        :param vm_size: 
        :param min_instance_count: 
        :param password: 
        :param ssh_keys: 
        :param subnet_id: 
        :param virtual_network_id: 
        """
        self._values: typing.Dict[str, typing.Any] = {
            "target_instance_count": target_instance_count,
            "username": username,
            "vm_size": vm_size,
        }
        if min_instance_count is not None:
            self._values["min_instance_count"] = min_instance_count
        if password is not None:
            self._values["password"] = password
        if ssh_keys is not None:
            self._values["ssh_keys"] = ssh_keys
        if subnet_id is not None:
            self._values["subnet_id"] = subnet_id
        if virtual_network_id is not None:
            self._values["virtual_network_id"] = virtual_network_id

    @builtins.property
    def target_instance_count(self) -> jsii.Number:
        result = self._values.get("target_instance_count")
        assert result is not None, "Required property 'target_instance_count' is missing"
        return result

    @builtins.property
    def username(self) -> builtins.str:
        result = self._values.get("username")
        assert result is not None, "Required property 'username' is missing"
        return result

    @builtins.property
    def vm_size(self) -> builtins.str:
        result = self._values.get("vm_size")
        assert result is not None, "Required property 'vm_size' is missing"
        return result

    @builtins.property
    def min_instance_count(self) -> typing.Optional[jsii.Number]:
        result = self._values.get("min_instance_count")
        return result

    @builtins.property
    def password(self) -> typing.Optional[builtins.str]:
        result = self._values.get("password")
        return result

    @builtins.property
    def ssh_keys(self) -> typing.Optional[typing.List[builtins.str]]:
        result = self._values.get("ssh_keys")
        return result

    @builtins.property
    def subnet_id(self) -> typing.Optional[builtins.str]:
        result = self._values.get("subnet_id")
        return result

    @builtins.property
    def virtual_network_id(self) -> typing.Optional[builtins.str]:
        result = self._values.get("virtual_network_id")
        return result

    def __eq__(self, rhs: typing.Any) -> builtins.bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs: typing.Any) -> builtins.bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return "HdinsightStormClusterRolesWorkerNode(%s)" % ", ".join(
            k + "=" + repr(v) for k, v in self._values.items()
        )


@jsii.data_type(
    jsii_type="@cdktf/provider-azurerm.HdinsightStormClusterRolesZookeeperNode",
    jsii_struct_bases=[],
    name_mapping={
        "username": "username",
        "vm_size": "vmSize",
        "password": "password",
        "ssh_keys": "sshKeys",
        "subnet_id": "subnetId",
        "virtual_network_id": "virtualNetworkId",
    },
)
class HdinsightStormClusterRolesZookeeperNode:
    def __init__(
        self,
        *,
        username: builtins.str,
        vm_size: builtins.str,
        password: typing.Optional[builtins.str] = None,
        ssh_keys: typing.Optional[typing.List[builtins.str]] = None,
        subnet_id: typing.Optional[builtins.str] = None,
        virtual_network_id: typing.Optional[builtins.str] = None,
    ) -> None:
        """
        :param username: 
        :param vm_size: 
        :param password: 
        :param ssh_keys: 
        :param subnet_id: 
        :param virtual_network_id: 
        """
        self._values: typing.Dict[str, typing.Any] = {
            "username": username,
            "vm_size": vm_size,
        }
        if password is not None:
            self._values["password"] = password
        if ssh_keys is not None:
            self._values["ssh_keys"] = ssh_keys
        if subnet_id is not None:
            self._values["subnet_id"] = subnet_id
        if virtual_network_id is not None:
            self._values["virtual_network_id"] = virtual_network_id

    @builtins.property
    def username(self) -> builtins.str:
        result = self._values.get("username")
        assert result is not None, "Required property 'username' is missing"
        return result

    @builtins.property
    def vm_size(self) -> builtins.str:
        result = self._values.get("vm_size")
        assert result is not None, "Required property 'vm_size' is missing"
        return result

    @builtins.property
    def password(self) -> typing.Optional[builtins.str]:
        result = self._values.get("password")
        return result

    @builtins.property
    def ssh_keys(self) -> typing.Optional[typing.List[builtins.str]]:
        result = self._values.get("ssh_keys")
        return result

    @builtins.property
    def subnet_id(self) -> typing.Optional[builtins.str]:
        result = self._values.get("subnet_id")
        return result

    @builtins.property
    def virtual_network_id(self) -> typing.Optional[builtins.str]:
        result = self._values.get("virtual_network_id")
        return result

    def __eq__(self, rhs: typing.Any) -> builtins.bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs: typing.Any) -> builtins.bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return "HdinsightStormClusterRolesZookeeperNode(%s)" % ", ".join(
            k + "=" + repr(v) for k, v in self._values.items()
        )


@jsii.data_type(
    jsii_type="@cdktf/provider-azurerm.HdinsightStormClusterStorageAccount",
    jsii_struct_bases=[],
    name_mapping={
        "is_default": "isDefault",
        "storage_account_key": "storageAccountKey",
        "storage_container_id": "storageContainerId",
    },
)
class HdinsightStormClusterStorageAccount:
    def __init__(
        self,
        *,
        is_default: builtins.bool,
        storage_account_key: builtins.str,
        storage_container_id: builtins.str,
    ) -> None:
        """
        :param is_default: 
        :param storage_account_key: 
        :param storage_container_id: 
        """
        self._values: typing.Dict[str, typing.Any] = {
            "is_default": is_default,
            "storage_account_key": storage_account_key,
            "storage_container_id": storage_container_id,
        }

    @builtins.property
    def is_default(self) -> builtins.bool:
        result = self._values.get("is_default")
        assert result is not None, "Required property 'is_default' is missing"
        return result

    @builtins.property
    def storage_account_key(self) -> builtins.str:
        result = self._values.get("storage_account_key")
        assert result is not None, "Required property 'storage_account_key' is missing"
        return result

    @builtins.property
    def storage_container_id(self) -> builtins.str:
        result = self._values.get("storage_container_id")
        assert result is not None, "Required property 'storage_container_id' is missing"
        return result

    def __eq__(self, rhs: typing.Any) -> builtins.bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs: typing.Any) -> builtins.bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return "HdinsightStormClusterStorageAccount(%s)" % ", ".join(
            k + "=" + repr(v) for k, v in self._values.items()
        )


@jsii.data_type(
    jsii_type="@cdktf/provider-azurerm.HdinsightStormClusterTimeouts",
    jsii_struct_bases=[],
    name_mapping={
        "create": "create",
        "delete": "delete",
        "read": "read",
        "update": "update",
    },
)
class HdinsightStormClusterTimeouts:
    def __init__(
        self,
        *,
        create: typing.Optional[builtins.str] = None,
        delete: typing.Optional[builtins.str] = None,
        read: typing.Optional[builtins.str] = None,
        update: typing.Optional[builtins.str] = None,
    ) -> None:
        """
        :param create: 
        :param delete: 
        :param read: 
        :param update: 
        """
        self._values: typing.Dict[str, typing.Any] = {}
        if create is not None:
            self._values["create"] = create
        if delete is not None:
            self._values["delete"] = delete
        if read is not None:
            self._values["read"] = read
        if update is not None:
            self._values["update"] = update

    @builtins.property
    def create(self) -> typing.Optional[builtins.str]:
        result = self._values.get("create")
        return result

    @builtins.property
    def delete(self) -> typing.Optional[builtins.str]:
        result = self._values.get("delete")
        return result

    @builtins.property
    def read(self) -> typing.Optional[builtins.str]:
        result = self._values.get("read")
        return result

    @builtins.property
    def update(self) -> typing.Optional[builtins.str]:
        result = self._values.get("update")
        return result

    def __eq__(self, rhs: typing.Any) -> builtins.bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs: typing.Any) -> builtins.bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return "HdinsightStormClusterTimeouts(%s)" % ", ".join(
            k + "=" + repr(v) for k, v in self._values.items()
        )


class HealthcareService(
    cdktf.TerraformResource,
    metaclass=jsii.JSIIMeta,
    jsii_type="@cdktf/provider-azurerm.HealthcareService",
):
    def __init__(
        self,
        scope: constructs.Construct,
        id: builtins.str,
        *,
        access_policy_object_ids: typing.List[builtins.str],
        location: builtins.str,
        name: builtins.str,
        resource_group_name: builtins.str,
        authentication_configuration: typing.Optional[typing.List["HealthcareServiceAuthenticationConfiguration"]] = None,
        cors_configuration: typing.Optional[typing.List["HealthcareServiceCorsConfiguration"]] = None,
        cosmosdb_throughput: typing.Optional[jsii.Number] = None,
        kind: typing.Optional[builtins.str] = None,
        tags: typing.Optional[typing.Mapping[builtins.str, builtins.str]] = None,
        timeouts: typing.Optional["HealthcareServiceTimeouts"] = None,
        count: typing.Optional[jsii.Number] = None,
        depends_on: typing.Optional[typing.List[cdktf.TerraformResource]] = None,
        lifecycle: typing.Optional[cdktf.TerraformResourceLifecycle] = None,
        provider: typing.Optional[cdktf.TerraformProvider] = None,
    ) -> None:
        """
        :param scope: -
        :param id: -
        :param access_policy_object_ids: 
        :param location: 
        :param name: 
        :param resource_group_name: 
        :param authentication_configuration: authentication_configuration block.
        :param cors_configuration: cors_configuration block.
        :param cosmosdb_throughput: 
        :param kind: 
        :param tags: 
        :param timeouts: timeouts block.
        :param count: 
        :param depends_on: 
        :param lifecycle: 
        :param provider: 
        """
        config = HealthcareServiceConfig(
            access_policy_object_ids=access_policy_object_ids,
            location=location,
            name=name,
            resource_group_name=resource_group_name,
            authentication_configuration=authentication_configuration,
            cors_configuration=cors_configuration,
            cosmosdb_throughput=cosmosdb_throughput,
            kind=kind,
            tags=tags,
            timeouts=timeouts,
            count=count,
            depends_on=depends_on,
            lifecycle=lifecycle,
            provider=provider,
        )

        jsii.create(HealthcareService, self, [scope, id, config])

    @jsii.member(jsii_name="synthesizeAttributes")
    def _synthesize_attributes(self) -> typing.Mapping[builtins.str, typing.Any]:
        return jsii.invoke(self, "synthesizeAttributes", [])

    @builtins.property # type: ignore
    @jsii.member(jsii_name="accessPolicyObjectIds")
    def access_policy_object_ids(self) -> typing.List[builtins.str]:
        return jsii.get(self, "accessPolicyObjectIds")

    @access_policy_object_ids.setter # type: ignore
    def access_policy_object_ids(self, value: typing.List[builtins.str]) -> None:
        jsii.set(self, "accessPolicyObjectIds", value)

    @builtins.property # type: ignore
    @jsii.member(jsii_name="location")
    def location(self) -> builtins.str:
        return jsii.get(self, "location")

    @location.setter # type: ignore
    def location(self, value: builtins.str) -> None:
        jsii.set(self, "location", value)

    @builtins.property # type: ignore
    @jsii.member(jsii_name="name")
    def name(self) -> builtins.str:
        return jsii.get(self, "name")

    @name.setter # type: ignore
    def name(self, value: builtins.str) -> None:
        jsii.set(self, "name", value)

    @builtins.property # type: ignore
    @jsii.member(jsii_name="resourceGroupName")
    def resource_group_name(self) -> builtins.str:
        return jsii.get(self, "resourceGroupName")

    @resource_group_name.setter # type: ignore
    def resource_group_name(self, value: builtins.str) -> None:
        jsii.set(self, "resourceGroupName", value)

    @builtins.property # type: ignore
    @jsii.member(jsii_name="authenticationConfiguration")
    def authentication_configuration(
        self,
    ) -> typing.Optional[typing.List["HealthcareServiceAuthenticationConfiguration"]]:
        return jsii.get(self, "authenticationConfiguration")

    @authentication_configuration.setter # type: ignore
    def authentication_configuration(
        self,
        value: typing.Optional[typing.List["HealthcareServiceAuthenticationConfiguration"]],
    ) -> None:
        jsii.set(self, "authenticationConfiguration", value)

    @builtins.property # type: ignore
    @jsii.member(jsii_name="corsConfiguration")
    def cors_configuration(
        self,
    ) -> typing.Optional[typing.List["HealthcareServiceCorsConfiguration"]]:
        return jsii.get(self, "corsConfiguration")

    @cors_configuration.setter # type: ignore
    def cors_configuration(
        self,
        value: typing.Optional[typing.List["HealthcareServiceCorsConfiguration"]],
    ) -> None:
        jsii.set(self, "corsConfiguration", value)

    @builtins.property # type: ignore
    @jsii.member(jsii_name="cosmosdbThroughput")
    def cosmosdb_throughput(self) -> typing.Optional[jsii.Number]:
        return jsii.get(self, "cosmosdbThroughput")

    @cosmosdb_throughput.setter # type: ignore
    def cosmosdb_throughput(self, value: typing.Optional[jsii.Number]) -> None:
        jsii.set(self, "cosmosdbThroughput", value)

    @builtins.property # type: ignore
    @jsii.member(jsii_name="id")
    def id(self) -> typing.Optional[builtins.str]:
        return jsii.get(self, "id")

    @id.setter # type: ignore
    def id(self, value: typing.Optional[builtins.str]) -> None:
        jsii.set(self, "id", value)

    @builtins.property # type: ignore
    @jsii.member(jsii_name="kind")
    def kind(self) -> typing.Optional[builtins.str]:
        return jsii.get(self, "kind")

    @kind.setter # type: ignore
    def kind(self, value: typing.Optional[builtins.str]) -> None:
        jsii.set(self, "kind", value)

    @builtins.property # type: ignore
    @jsii.member(jsii_name="tags")
    def tags(self) -> typing.Optional[typing.Mapping[builtins.str, builtins.str]]:
        return jsii.get(self, "tags")

    @tags.setter # type: ignore
    def tags(
        self,
        value: typing.Optional[typing.Mapping[builtins.str, builtins.str]],
    ) -> None:
        jsii.set(self, "tags", value)

    @builtins.property # type: ignore
    @jsii.member(jsii_name="timeouts")
    def timeouts(self) -> typing.Optional["HealthcareServiceTimeouts"]:
        return jsii.get(self, "timeouts")

    @timeouts.setter # type: ignore
    def timeouts(self, value: typing.Optional["HealthcareServiceTimeouts"]) -> None:
        jsii.set(self, "timeouts", value)


@jsii.data_type(
    jsii_type="@cdktf/provider-azurerm.HealthcareServiceAuthenticationConfiguration",
    jsii_struct_bases=[],
    name_mapping={
        "audience": "audience",
        "authority": "authority",
        "smart_proxy_enabled": "smartProxyEnabled",
    },
)
class HealthcareServiceAuthenticationConfiguration:
    def __init__(
        self,
        *,
        audience: typing.Optional[builtins.str] = None,
        authority: typing.Optional[builtins.str] = None,
        smart_proxy_enabled: typing.Optional[builtins.bool] = None,
    ) -> None:
        """
        :param audience: 
        :param authority: 
        :param smart_proxy_enabled: 
        """
        self._values: typing.Dict[str, typing.Any] = {}
        if audience is not None:
            self._values["audience"] = audience
        if authority is not None:
            self._values["authority"] = authority
        if smart_proxy_enabled is not None:
            self._values["smart_proxy_enabled"] = smart_proxy_enabled

    @builtins.property
    def audience(self) -> typing.Optional[builtins.str]:
        result = self._values.get("audience")
        return result

    @builtins.property
    def authority(self) -> typing.Optional[builtins.str]:
        result = self._values.get("authority")
        return result

    @builtins.property
    def smart_proxy_enabled(self) -> typing.Optional[builtins.bool]:
        result = self._values.get("smart_proxy_enabled")
        return result

    def __eq__(self, rhs: typing.Any) -> builtins.bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs: typing.Any) -> builtins.bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return "HealthcareServiceAuthenticationConfiguration(%s)" % ", ".join(
            k + "=" + repr(v) for k, v in self._values.items()
        )


@jsii.data_type(
    jsii_type="@cdktf/provider-azurerm.HealthcareServiceConfig",
    jsii_struct_bases=[cdktf.TerraformMetaArguments],
    name_mapping={
        "count": "count",
        "depends_on": "dependsOn",
        "lifecycle": "lifecycle",
        "provider": "provider",
        "access_policy_object_ids": "accessPolicyObjectIds",
        "location": "location",
        "name": "name",
        "resource_group_name": "resourceGroupName",
        "authentication_configuration": "authenticationConfiguration",
        "cors_configuration": "corsConfiguration",
        "cosmosdb_throughput": "cosmosdbThroughput",
        "kind": "kind",
        "tags": "tags",
        "timeouts": "timeouts",
    },
)
class HealthcareServiceConfig(cdktf.TerraformMetaArguments):
    def __init__(
        self,
        *,
        count: typing.Optional[jsii.Number] = None,
        depends_on: typing.Optional[typing.List[cdktf.TerraformResource]] = None,
        lifecycle: typing.Optional[cdktf.TerraformResourceLifecycle] = None,
        provider: typing.Optional[cdktf.TerraformProvider] = None,
        access_policy_object_ids: typing.List[builtins.str],
        location: builtins.str,
        name: builtins.str,
        resource_group_name: builtins.str,
        authentication_configuration: typing.Optional[typing.List[HealthcareServiceAuthenticationConfiguration]] = None,
        cors_configuration: typing.Optional[typing.List["HealthcareServiceCorsConfiguration"]] = None,
        cosmosdb_throughput: typing.Optional[jsii.Number] = None,
        kind: typing.Optional[builtins.str] = None,
        tags: typing.Optional[typing.Mapping[builtins.str, builtins.str]] = None,
        timeouts: typing.Optional["HealthcareServiceTimeouts"] = None,
    ) -> None:
        """
        :param count: 
        :param depends_on: 
        :param lifecycle: 
        :param provider: 
        :param access_policy_object_ids: 
        :param location: 
        :param name: 
        :param resource_group_name: 
        :param authentication_configuration: authentication_configuration block.
        :param cors_configuration: cors_configuration block.
        :param cosmosdb_throughput: 
        :param kind: 
        :param tags: 
        :param timeouts: timeouts block.
        """
        if isinstance(lifecycle, dict):
            lifecycle = cdktf.TerraformResourceLifecycle(**lifecycle)
        if isinstance(timeouts, dict):
            timeouts = HealthcareServiceTimeouts(**timeouts)
        self._values: typing.Dict[str, typing.Any] = {
            "access_policy_object_ids": access_policy_object_ids,
            "location": location,
            "name": name,
            "resource_group_name": resource_group_name,
        }
        if count is not None:
            self._values["count"] = count
        if depends_on is not None:
            self._values["depends_on"] = depends_on
        if lifecycle is not None:
            self._values["lifecycle"] = lifecycle
        if provider is not None:
            self._values["provider"] = provider
        if authentication_configuration is not None:
            self._values["authentication_configuration"] = authentication_configuration
        if cors_configuration is not None:
            self._values["cors_configuration"] = cors_configuration
        if cosmosdb_throughput is not None:
            self._values["cosmosdb_throughput"] = cosmosdb_throughput
        if kind is not None:
            self._values["kind"] = kind
        if tags is not None:
            self._values["tags"] = tags
        if timeouts is not None:
            self._values["timeouts"] = timeouts

    @builtins.property
    def count(self) -> typing.Optional[jsii.Number]:
        """
        :stability: experimental
        """
        result = self._values.get("count")
        return result

    @builtins.property
    def depends_on(self) -> typing.Optional[typing.List[cdktf.TerraformResource]]:
        """
        :stability: experimental
        """
        result = self._values.get("depends_on")
        return result

    @builtins.property
    def lifecycle(self) -> typing.Optional[cdktf.TerraformResourceLifecycle]:
        """
        :stability: experimental
        """
        result = self._values.get("lifecycle")
        return result

    @builtins.property
    def provider(self) -> typing.Optional[cdktf.TerraformProvider]:
        """
        :stability: experimental
        """
        result = self._values.get("provider")
        return result

    @builtins.property
    def access_policy_object_ids(self) -> typing.List[builtins.str]:
        result = self._values.get("access_policy_object_ids")
        assert result is not None, "Required property 'access_policy_object_ids' is missing"
        return result

    @builtins.property
    def location(self) -> builtins.str:
        result = self._values.get("location")
        assert result is not None, "Required property 'location' is missing"
        return result

    @builtins.property
    def name(self) -> builtins.str:
        result = self._values.get("name")
        assert result is not None, "Required property 'name' is missing"
        return result

    @builtins.property
    def resource_group_name(self) -> builtins.str:
        result = self._values.get("resource_group_name")
        assert result is not None, "Required property 'resource_group_name' is missing"
        return result

    @builtins.property
    def authentication_configuration(
        self,
    ) -> typing.Optional[typing.List[HealthcareServiceAuthenticationConfiguration]]:
        """authentication_configuration block."""
        result = self._values.get("authentication_configuration")
        return result

    @builtins.property
    def cors_configuration(
        self,
    ) -> typing.Optional[typing.List["HealthcareServiceCorsConfiguration"]]:
        """cors_configuration block."""
        result = self._values.get("cors_configuration")
        return result

    @builtins.property
    def cosmosdb_throughput(self) -> typing.Optional[jsii.Number]:
        result = self._values.get("cosmosdb_throughput")
        return result

    @builtins.property
    def kind(self) -> typing.Optional[builtins.str]:
        result = self._values.get("kind")
        return result

    @builtins.property
    def tags(self) -> typing.Optional[typing.Mapping[builtins.str, builtins.str]]:
        result = self._values.get("tags")
        return result

    @builtins.property
    def timeouts(self) -> typing.Optional["HealthcareServiceTimeouts"]:
        """timeouts block."""
        result = self._values.get("timeouts")
        return result

    def __eq__(self, rhs: typing.Any) -> builtins.bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs: typing.Any) -> builtins.bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return "HealthcareServiceConfig(%s)" % ", ".join(
            k + "=" + repr(v) for k, v in self._values.items()
        )


@jsii.data_type(
    jsii_type="@cdktf/provider-azurerm.HealthcareServiceCorsConfiguration",
    jsii_struct_bases=[],
    name_mapping={
        "allow_credentials": "allowCredentials",
        "allowed_headers": "allowedHeaders",
        "allowed_methods": "allowedMethods",
        "allowed_origins": "allowedOrigins",
        "max_age_in_seconds": "maxAgeInSeconds",
    },
)
class HealthcareServiceCorsConfiguration:
    def __init__(
        self,
        *,
        allow_credentials: typing.Optional[builtins.bool] = None,
        allowed_headers: typing.Optional[typing.List[builtins.str]] = None,
        allowed_methods: typing.Optional[typing.List[builtins.str]] = None,
        allowed_origins: typing.Optional[typing.List[builtins.str]] = None,
        max_age_in_seconds: typing.Optional[jsii.Number] = None,
    ) -> None:
        """
        :param allow_credentials: 
        :param allowed_headers: 
        :param allowed_methods: 
        :param allowed_origins: 
        :param max_age_in_seconds: 
        """
        self._values: typing.Dict[str, typing.Any] = {}
        if allow_credentials is not None:
            self._values["allow_credentials"] = allow_credentials
        if allowed_headers is not None:
            self._values["allowed_headers"] = allowed_headers
        if allowed_methods is not None:
            self._values["allowed_methods"] = allowed_methods
        if allowed_origins is not None:
            self._values["allowed_origins"] = allowed_origins
        if max_age_in_seconds is not None:
            self._values["max_age_in_seconds"] = max_age_in_seconds

    @builtins.property
    def allow_credentials(self) -> typing.Optional[builtins.bool]:
        result = self._values.get("allow_credentials")
        return result

    @builtins.property
    def allowed_headers(self) -> typing.Optional[typing.List[builtins.str]]:
        result = self._values.get("allowed_headers")
        return result

    @builtins.property
    def allowed_methods(self) -> typing.Optional[typing.List[builtins.str]]:
        result = self._values.get("allowed_methods")
        return result

    @builtins.property
    def allowed_origins(self) -> typing.Optional[typing.List[builtins.str]]:
        result = self._values.get("allowed_origins")
        return result

    @builtins.property
    def max_age_in_seconds(self) -> typing.Optional[jsii.Number]:
        result = self._values.get("max_age_in_seconds")
        return result

    def __eq__(self, rhs: typing.Any) -> builtins.bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs: typing.Any) -> builtins.bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return "HealthcareServiceCorsConfiguration(%s)" % ", ".join(
            k + "=" + repr(v) for k, v in self._values.items()
        )


@jsii.data_type(
    jsii_type="@cdktf/provider-azurerm.HealthcareServiceTimeouts",
    jsii_struct_bases=[],
    name_mapping={
        "create": "create",
        "delete": "delete",
        "read": "read",
        "update": "update",
    },
)
class HealthcareServiceTimeouts:
    def __init__(
        self,
        *,
        create: typing.Optional[builtins.str] = None,
        delete: typing.Optional[builtins.str] = None,
        read: typing.Optional[builtins.str] = None,
        update: typing.Optional[builtins.str] = None,
    ) -> None:
        """
        :param create: 
        :param delete: 
        :param read: 
        :param update: 
        """
        self._values: typing.Dict[str, typing.Any] = {}
        if create is not None:
            self._values["create"] = create
        if delete is not None:
            self._values["delete"] = delete
        if read is not None:
            self._values["read"] = read
        if update is not None:
            self._values["update"] = update

    @builtins.property
    def create(self) -> typing.Optional[builtins.str]:
        result = self._values.get("create")
        return result

    @builtins.property
    def delete(self) -> typing.Optional[builtins.str]:
        result = self._values.get("delete")
        return result

    @builtins.property
    def read(self) -> typing.Optional[builtins.str]:
        result = self._values.get("read")
        return result

    @builtins.property
    def update(self) -> typing.Optional[builtins.str]:
        result = self._values.get("update")
        return result

    def __eq__(self, rhs: typing.Any) -> builtins.bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs: typing.Any) -> builtins.bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return "HealthcareServiceTimeouts(%s)" % ", ".join(
            k + "=" + repr(v) for k, v in self._values.items()
        )


class Image(
    cdktf.TerraformResource,
    metaclass=jsii.JSIIMeta,
    jsii_type="@cdktf/provider-azurerm.Image",
):
    def __init__(
        self,
        scope: constructs.Construct,
        id: builtins.str,
        *,
        location: builtins.str,
        name: builtins.str,
        resource_group_name: builtins.str,
        data_disk: typing.Optional[typing.List["ImageDataDisk"]] = None,
        hyper_v_generation: typing.Optional[builtins.str] = None,
        os_disk: typing.Optional[typing.List["ImageOsDisk"]] = None,
        source_virtual_machine_id: typing.Optional[builtins.str] = None,
        tags: typing.Optional[typing.Mapping[builtins.str, builtins.str]] = None,
        timeouts: typing.Optional["ImageTimeouts"] = None,
        zone_resilient: typing.Optional[builtins.bool] = None,
        count: typing.Optional[jsii.Number] = None,
        depends_on: typing.Optional[typing.List[cdktf.TerraformResource]] = None,
        lifecycle: typing.Optional[cdktf.TerraformResourceLifecycle] = None,
        provider: typing.Optional[cdktf.TerraformProvider] = None,
    ) -> None:
        """
        :param scope: -
        :param id: -
        :param location: 
        :param name: 
        :param resource_group_name: 
        :param data_disk: data_disk block.
        :param hyper_v_generation: 
        :param os_disk: os_disk block.
        :param source_virtual_machine_id: 
        :param tags: 
        :param timeouts: timeouts block.
        :param zone_resilient: 
        :param count: 
        :param depends_on: 
        :param lifecycle: 
        :param provider: 
        """
        config = ImageConfig(
            location=location,
            name=name,
            resource_group_name=resource_group_name,
            data_disk=data_disk,
            hyper_v_generation=hyper_v_generation,
            os_disk=os_disk,
            source_virtual_machine_id=source_virtual_machine_id,
            tags=tags,
            timeouts=timeouts,
            zone_resilient=zone_resilient,
            count=count,
            depends_on=depends_on,
            lifecycle=lifecycle,
            provider=provider,
        )

        jsii.create(Image, self, [scope, id, config])

    @jsii.member(jsii_name="synthesizeAttributes")
    def _synthesize_attributes(self) -> typing.Mapping[builtins.str, typing.Any]:
        return jsii.invoke(self, "synthesizeAttributes", [])

    @builtins.property # type: ignore
    @jsii.member(jsii_name="location")
    def location(self) -> builtins.str:
        return jsii.get(self, "location")

    @location.setter # type: ignore
    def location(self, value: builtins.str) -> None:
        jsii.set(self, "location", value)

    @builtins.property # type: ignore
    @jsii.member(jsii_name="name")
    def name(self) -> builtins.str:
        return jsii.get(self, "name")

    @name.setter # type: ignore
    def name(self, value: builtins.str) -> None:
        jsii.set(self, "name", value)

    @builtins.property # type: ignore
    @jsii.member(jsii_name="resourceGroupName")
    def resource_group_name(self) -> builtins.str:
        return jsii.get(self, "resourceGroupName")

    @resource_group_name.setter # type: ignore
    def resource_group_name(self, value: builtins.str) -> None:
        jsii.set(self, "resourceGroupName", value)

    @builtins.property # type: ignore
    @jsii.member(jsii_name="dataDisk")
    def data_disk(self) -> typing.Optional[typing.List["ImageDataDisk"]]:
        return jsii.get(self, "dataDisk")

    @data_disk.setter # type: ignore
    def data_disk(self, value: typing.Optional[typing.List["ImageDataDisk"]]) -> None:
        jsii.set(self, "dataDisk", value)

    @builtins.property # type: ignore
    @jsii.member(jsii_name="hyperVGeneration")
    def hyper_v_generation(self) -> typing.Optional[builtins.str]:
        return jsii.get(self, "hyperVGeneration")

    @hyper_v_generation.setter # type: ignore
    def hyper_v_generation(self, value: typing.Optional[builtins.str]) -> None:
        jsii.set(self, "hyperVGeneration", value)

    @builtins.property # type: ignore
    @jsii.member(jsii_name="id")
    def id(self) -> typing.Optional[builtins.str]:
        return jsii.get(self, "id")

    @id.setter # type: ignore
    def id(self, value: typing.Optional[builtins.str]) -> None:
        jsii.set(self, "id", value)

    @builtins.property # type: ignore
    @jsii.member(jsii_name="osDisk")
    def os_disk(self) -> typing.Optional[typing.List["ImageOsDisk"]]:
        return jsii.get(self, "osDisk")

    @os_disk.setter # type: ignore
    def os_disk(self, value: typing.Optional[typing.List["ImageOsDisk"]]) -> None:
        jsii.set(self, "osDisk", value)

    @builtins.property # type: ignore
    @jsii.member(jsii_name="sourceVirtualMachineId")
    def source_virtual_machine_id(self) -> typing.Optional[builtins.str]:
        return jsii.get(self, "sourceVirtualMachineId")

    @source_virtual_machine_id.setter # type: ignore
    def source_virtual_machine_id(self, value: typing.Optional[builtins.str]) -> None:
        jsii.set(self, "sourceVirtualMachineId", value)

    @builtins.property # type: ignore
    @jsii.member(jsii_name="tags")
    def tags(self) -> typing.Optional[typing.Mapping[builtins.str, builtins.str]]:
        return jsii.get(self, "tags")

    @tags.setter # type: ignore
    def tags(
        self,
        value: typing.Optional[typing.Mapping[builtins.str, builtins.str]],
    ) -> None:
        jsii.set(self, "tags", value)

    @builtins.property # type: ignore
    @jsii.member(jsii_name="timeouts")
    def timeouts(self) -> typing.Optional["ImageTimeouts"]:
        return jsii.get(self, "timeouts")

    @timeouts.setter # type: ignore
    def timeouts(self, value: typing.Optional["ImageTimeouts"]) -> None:
        jsii.set(self, "timeouts", value)

    @builtins.property # type: ignore
    @jsii.member(jsii_name="zoneResilient")
    def zone_resilient(self) -> typing.Optional[builtins.bool]:
        return jsii.get(self, "zoneResilient")

    @zone_resilient.setter # type: ignore
    def zone_resilient(self, value: typing.Optional[builtins.bool]) -> None:
        jsii.set(self, "zoneResilient", value)


@jsii.data_type(
    jsii_type="@cdktf/provider-azurerm.ImageConfig",
    jsii_struct_bases=[cdktf.TerraformMetaArguments],
    name_mapping={
        "count": "count",
        "depends_on": "dependsOn",
        "lifecycle": "lifecycle",
        "provider": "provider",
        "location": "location",
        "name": "name",
        "resource_group_name": "resourceGroupName",
        "data_disk": "dataDisk",
        "hyper_v_generation": "hyperVGeneration",
        "os_disk": "osDisk",
        "source_virtual_machine_id": "sourceVirtualMachineId",
        "tags": "tags",
        "timeouts": "timeouts",
        "zone_resilient": "zoneResilient",
    },
)
class ImageConfig(cdktf.TerraformMetaArguments):
    def __init__(
        self,
        *,
        count: typing.Optional[jsii.Number] = None,
        depends_on: typing.Optional[typing.List[cdktf.TerraformResource]] = None,
        lifecycle: typing.Optional[cdktf.TerraformResourceLifecycle] = None,
        provider: typing.Optional[cdktf.TerraformProvider] = None,
        location: builtins.str,
        name: builtins.str,
        resource_group_name: builtins.str,
        data_disk: typing.Optional[typing.List["ImageDataDisk"]] = None,
        hyper_v_generation: typing.Optional[builtins.str] = None,
        os_disk: typing.Optional[typing.List["ImageOsDisk"]] = None,
        source_virtual_machine_id: typing.Optional[builtins.str] = None,
        tags: typing.Optional[typing.Mapping[builtins.str, builtins.str]] = None,
        timeouts: typing.Optional["ImageTimeouts"] = None,
        zone_resilient: typing.Optional[builtins.bool] = None,
    ) -> None:
        """
        :param count: 
        :param depends_on: 
        :param lifecycle: 
        :param provider: 
        :param location: 
        :param name: 
        :param resource_group_name: 
        :param data_disk: data_disk block.
        :param hyper_v_generation: 
        :param os_disk: os_disk block.
        :param source_virtual_machine_id: 
        :param tags: 
        :param timeouts: timeouts block.
        :param zone_resilient: 
        """
        if isinstance(lifecycle, dict):
            lifecycle = cdktf.TerraformResourceLifecycle(**lifecycle)
        if isinstance(timeouts, dict):
            timeouts = ImageTimeouts(**timeouts)
        self._values: typing.Dict[str, typing.Any] = {
            "location": location,
            "name": name,
            "resource_group_name": resource_group_name,
        }
        if count is not None:
            self._values["count"] = count
        if depends_on is not None:
            self._values["depends_on"] = depends_on
        if lifecycle is not None:
            self._values["lifecycle"] = lifecycle
        if provider is not None:
            self._values["provider"] = provider
        if data_disk is not None:
            self._values["data_disk"] = data_disk
        if hyper_v_generation is not None:
            self._values["hyper_v_generation"] = hyper_v_generation
        if os_disk is not None:
            self._values["os_disk"] = os_disk
        if source_virtual_machine_id is not None:
            self._values["source_virtual_machine_id"] = source_virtual_machine_id
        if tags is not None:
            self._values["tags"] = tags
        if timeouts is not None:
            self._values["timeouts"] = timeouts
        if zone_resilient is not None:
            self._values["zone_resilient"] = zone_resilient

    @builtins.property
    def count(self) -> typing.Optional[jsii.Number]:
        """
        :stability: experimental
        """
        result = self._values.get("count")
        return result

    @builtins.property
    def depends_on(self) -> typing.Optional[typing.List[cdktf.TerraformResource]]:
        """
        :stability: experimental
        """
        result = self._values.get("depends_on")
        return result

    @builtins.property
    def lifecycle(self) -> typing.Optional[cdktf.TerraformResourceLifecycle]:
        """
        :stability: experimental
        """
        result = self._values.get("lifecycle")
        return result

    @builtins.property
    def provider(self) -> typing.Optional[cdktf.TerraformProvider]:
        """
        :stability: experimental
        """
        result = self._values.get("provider")
        return result

    @builtins.property
    def location(self) -> builtins.str:
        result = self._values.get("location")
        assert result is not None, "Required property 'location' is missing"
        return result

    @builtins.property
    def name(self) -> builtins.str:
        result = self._values.get("name")
        assert result is not None, "Required property 'name' is missing"
        return result

    @builtins.property
    def resource_group_name(self) -> builtins.str:
        result = self._values.get("resource_group_name")
        assert result is not None, "Required property 'resource_group_name' is missing"
        return result

    @builtins.property
    def data_disk(self) -> typing.Optional[typing.List["ImageDataDisk"]]:
        """data_disk block."""
        result = self._values.get("data_disk")
        return result

    @builtins.property
    def hyper_v_generation(self) -> typing.Optional[builtins.str]:
        result = self._values.get("hyper_v_generation")
        return result

    @builtins.property
    def os_disk(self) -> typing.Optional[typing.List["ImageOsDisk"]]:
        """os_disk block."""
        result = self._values.get("os_disk")
        return result

    @builtins.property
    def source_virtual_machine_id(self) -> typing.Optional[builtins.str]:
        result = self._values.get("source_virtual_machine_id")
        return result

    @builtins.property
    def tags(self) -> typing.Optional[typing.Mapping[builtins.str, builtins.str]]:
        result = self._values.get("tags")
        return result

    @builtins.property
    def timeouts(self) -> typing.Optional["ImageTimeouts"]:
        """timeouts block."""
        result = self._values.get("timeouts")
        return result

    @builtins.property
    def zone_resilient(self) -> typing.Optional[builtins.bool]:
        result = self._values.get("zone_resilient")
        return result

    def __eq__(self, rhs: typing.Any) -> builtins.bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs: typing.Any) -> builtins.bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return "ImageConfig(%s)" % ", ".join(
            k + "=" + repr(v) for k, v in self._values.items()
        )


@jsii.data_type(
    jsii_type="@cdktf/provider-azurerm.ImageDataDisk",
    jsii_struct_bases=[],
    name_mapping={
        "blob_uri": "blobUri",
        "caching": "caching",
        "lun": "lun",
        "managed_disk_id": "managedDiskId",
        "size_gb": "sizeGb",
    },
)
class ImageDataDisk:
    def __init__(
        self,
        *,
        blob_uri: typing.Optional[builtins.str] = None,
        caching: typing.Optional[builtins.str] = None,
        lun: typing.Optional[jsii.Number] = None,
        managed_disk_id: typing.Optional[builtins.str] = None,
        size_gb: typing.Optional[jsii.Number] = None,
    ) -> None:
        """
        :param blob_uri: 
        :param caching: 
        :param lun: 
        :param managed_disk_id: 
        :param size_gb: 
        """
        self._values: typing.Dict[str, typing.Any] = {}
        if blob_uri is not None:
            self._values["blob_uri"] = blob_uri
        if caching is not None:
            self._values["caching"] = caching
        if lun is not None:
            self._values["lun"] = lun
        if managed_disk_id is not None:
            self._values["managed_disk_id"] = managed_disk_id
        if size_gb is not None:
            self._values["size_gb"] = size_gb

    @builtins.property
    def blob_uri(self) -> typing.Optional[builtins.str]:
        result = self._values.get("blob_uri")
        return result

    @builtins.property
    def caching(self) -> typing.Optional[builtins.str]:
        result = self._values.get("caching")
        return result

    @builtins.property
    def lun(self) -> typing.Optional[jsii.Number]:
        result = self._values.get("lun")
        return result

    @builtins.property
    def managed_disk_id(self) -> typing.Optional[builtins.str]:
        result = self._values.get("managed_disk_id")
        return result

    @builtins.property
    def size_gb(self) -> typing.Optional[jsii.Number]:
        result = self._values.get("size_gb")
        return result

    def __eq__(self, rhs: typing.Any) -> builtins.bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs: typing.Any) -> builtins.bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return "ImageDataDisk(%s)" % ", ".join(
            k + "=" + repr(v) for k, v in self._values.items()
        )


@jsii.data_type(
    jsii_type="@cdktf/provider-azurerm.ImageOsDisk",
    jsii_struct_bases=[],
    name_mapping={
        "blob_uri": "blobUri",
        "caching": "caching",
        "managed_disk_id": "managedDiskId",
        "os_state": "osState",
        "os_type": "osType",
        "size_gb": "sizeGb",
    },
)
class ImageOsDisk:
    def __init__(
        self,
        *,
        blob_uri: typing.Optional[builtins.str] = None,
        caching: typing.Optional[builtins.str] = None,
        managed_disk_id: typing.Optional[builtins.str] = None,
        os_state: typing.Optional[builtins.str] = None,
        os_type: typing.Optional[builtins.str] = None,
        size_gb: typing.Optional[jsii.Number] = None,
    ) -> None:
        """
        :param blob_uri: 
        :param caching: 
        :param managed_disk_id: 
        :param os_state: 
        :param os_type: 
        :param size_gb: 
        """
        self._values: typing.Dict[str, typing.Any] = {}
        if blob_uri is not None:
            self._values["blob_uri"] = blob_uri
        if caching is not None:
            self._values["caching"] = caching
        if managed_disk_id is not None:
            self._values["managed_disk_id"] = managed_disk_id
        if os_state is not None:
            self._values["os_state"] = os_state
        if os_type is not None:
            self._values["os_type"] = os_type
        if size_gb is not None:
            self._values["size_gb"] = size_gb

    @builtins.property
    def blob_uri(self) -> typing.Optional[builtins.str]:
        result = self._values.get("blob_uri")
        return result

    @builtins.property
    def caching(self) -> typing.Optional[builtins.str]:
        result = self._values.get("caching")
        return result

    @builtins.property
    def managed_disk_id(self) -> typing.Optional[builtins.str]:
        result = self._values.get("managed_disk_id")
        return result

    @builtins.property
    def os_state(self) -> typing.Optional[builtins.str]:
        result = self._values.get("os_state")
        return result

    @builtins.property
    def os_type(self) -> typing.Optional[builtins.str]:
        result = self._values.get("os_type")
        return result

    @builtins.property
    def size_gb(self) -> typing.Optional[jsii.Number]:
        result = self._values.get("size_gb")
        return result

    def __eq__(self, rhs: typing.Any) -> builtins.bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs: typing.Any) -> builtins.bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return "ImageOsDisk(%s)" % ", ".join(
            k + "=" + repr(v) for k, v in self._values.items()
        )


@jsii.data_type(
    jsii_type="@cdktf/provider-azurerm.ImageTimeouts",
    jsii_struct_bases=[],
    name_mapping={
        "create": "create",
        "delete": "delete",
        "read": "read",
        "update": "update",
    },
)
class ImageTimeouts:
    def __init__(
        self,
        *,
        create: typing.Optional[builtins.str] = None,
        delete: typing.Optional[builtins.str] = None,
        read: typing.Optional[builtins.str] = None,
        update: typing.Optional[builtins.str] = None,
    ) -> None:
        """
        :param create: 
        :param delete: 
        :param read: 
        :param update: 
        """
        self._values: typing.Dict[str, typing.Any] = {}
        if create is not None:
            self._values["create"] = create
        if delete is not None:
            self._values["delete"] = delete
        if read is not None:
            self._values["read"] = read
        if update is not None:
            self._values["update"] = update

    @builtins.property
    def create(self) -> typing.Optional[builtins.str]:
        result = self._values.get("create")
        return result

    @builtins.property
    def delete(self) -> typing.Optional[builtins.str]:
        result = self._values.get("delete")
        return result

    @builtins.property
    def read(self) -> typing.Optional[builtins.str]:
        result = self._values.get("read")
        return result

    @builtins.property
    def update(self) -> typing.Optional[builtins.str]:
        result = self._values.get("update")
        return result

    def __eq__(self, rhs: typing.Any) -> builtins.bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs: typing.Any) -> builtins.bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return "ImageTimeouts(%s)" % ", ".join(
            k + "=" + repr(v) for k, v in self._values.items()
        )


class Iothub(
    cdktf.TerraformResource,
    metaclass=jsii.JSIIMeta,
    jsii_type="@cdktf/provider-azurerm.Iothub",
):
    def __init__(
        self,
        scope: constructs.Construct,
        id: builtins.str,
        *,
        location: builtins.str,
        name: builtins.str,
        resource_group_name: builtins.str,
        sku: typing.List["IothubSku"],
        endpoint: typing.Optional[typing.List["IothubEndpoint"]] = None,
        event_hub_partition_count: typing.Optional[jsii.Number] = None,
        event_hub_retention_in_days: typing.Optional[jsii.Number] = None,
        fallback_route: typing.Optional[typing.List["IothubFallbackRoute"]] = None,
        file_upload: typing.Optional[typing.List["IothubFileUpload"]] = None,
        ip_filter_rule: typing.Optional[typing.List["IothubIpFilterRule"]] = None,
        route: typing.Optional[typing.List["IothubRoute"]] = None,
        tags: typing.Optional[typing.Mapping[builtins.str, builtins.str]] = None,
        timeouts: typing.Optional["IothubTimeouts"] = None,
        count: typing.Optional[jsii.Number] = None,
        depends_on: typing.Optional[typing.List[cdktf.TerraformResource]] = None,
        lifecycle: typing.Optional[cdktf.TerraformResourceLifecycle] = None,
        provider: typing.Optional[cdktf.TerraformProvider] = None,
    ) -> None:
        """
        :param scope: -
        :param id: -
        :param location: 
        :param name: 
        :param resource_group_name: 
        :param sku: sku block.
        :param endpoint: endpoint block.
        :param event_hub_partition_count: 
        :param event_hub_retention_in_days: 
        :param fallback_route: fallback_route block.
        :param file_upload: file_upload block.
        :param ip_filter_rule: ip_filter_rule block.
        :param route: route block.
        :param tags: 
        :param timeouts: timeouts block.
        :param count: 
        :param depends_on: 
        :param lifecycle: 
        :param provider: 
        """
        config = IothubConfig(
            location=location,
            name=name,
            resource_group_name=resource_group_name,
            sku=sku,
            endpoint=endpoint,
            event_hub_partition_count=event_hub_partition_count,
            event_hub_retention_in_days=event_hub_retention_in_days,
            fallback_route=fallback_route,
            file_upload=file_upload,
            ip_filter_rule=ip_filter_rule,
            route=route,
            tags=tags,
            timeouts=timeouts,
            count=count,
            depends_on=depends_on,
            lifecycle=lifecycle,
            provider=provider,
        )

        jsii.create(Iothub, self, [scope, id, config])

    @jsii.member(jsii_name="sharedAccessPolicy")
    def shared_access_policy(self, index: builtins.str) -> "IothubSharedAccessPolicy":
        """
        :param index: -
        """
        return jsii.invoke(self, "sharedAccessPolicy", [index])

    @jsii.member(jsii_name="synthesizeAttributes")
    def _synthesize_attributes(self) -> typing.Mapping[builtins.str, typing.Any]:
        return jsii.invoke(self, "synthesizeAttributes", [])

    @builtins.property # type: ignore
    @jsii.member(jsii_name="eventHubEventsEndpoint")
    def event_hub_events_endpoint(self) -> builtins.str:
        return jsii.get(self, "eventHubEventsEndpoint")

    @builtins.property # type: ignore
    @jsii.member(jsii_name="eventHubEventsPath")
    def event_hub_events_path(self) -> builtins.str:
        return jsii.get(self, "eventHubEventsPath")

    @builtins.property # type: ignore
    @jsii.member(jsii_name="eventHubOperationsEndpoint")
    def event_hub_operations_endpoint(self) -> builtins.str:
        return jsii.get(self, "eventHubOperationsEndpoint")

    @builtins.property # type: ignore
    @jsii.member(jsii_name="eventHubOperationsPath")
    def event_hub_operations_path(self) -> builtins.str:
        return jsii.get(self, "eventHubOperationsPath")

    @builtins.property # type: ignore
    @jsii.member(jsii_name="hostname")
    def hostname(self) -> builtins.str:
        return jsii.get(self, "hostname")

    @builtins.property # type: ignore
    @jsii.member(jsii_name="type")
    def type(self) -> builtins.str:
        return jsii.get(self, "type")

    @builtins.property # type: ignore
    @jsii.member(jsii_name="location")
    def location(self) -> builtins.str:
        return jsii.get(self, "location")

    @location.setter # type: ignore
    def location(self, value: builtins.str) -> None:
        jsii.set(self, "location", value)

    @builtins.property # type: ignore
    @jsii.member(jsii_name="name")
    def name(self) -> builtins.str:
        return jsii.get(self, "name")

    @name.setter # type: ignore
    def name(self, value: builtins.str) -> None:
        jsii.set(self, "name", value)

    @builtins.property # type: ignore
    @jsii.member(jsii_name="resourceGroupName")
    def resource_group_name(self) -> builtins.str:
        return jsii.get(self, "resourceGroupName")

    @resource_group_name.setter # type: ignore
    def resource_group_name(self, value: builtins.str) -> None:
        jsii.set(self, "resourceGroupName", value)

    @builtins.property # type: ignore
    @jsii.member(jsii_name="sku")
    def sku(self) -> typing.List["IothubSku"]:
        return jsii.get(self, "sku")

    @sku.setter # type: ignore
    def sku(self, value: typing.List["IothubSku"]) -> None:
        jsii.set(self, "sku", value)

    @builtins.property # type: ignore
    @jsii.member(jsii_name="endpoint")
    def endpoint(self) -> typing.Optional[typing.List["IothubEndpoint"]]:
        return jsii.get(self, "endpoint")

    @endpoint.setter # type: ignore
    def endpoint(self, value: typing.Optional[typing.List["IothubEndpoint"]]) -> None:
        jsii.set(self, "endpoint", value)

    @builtins.property # type: ignore
    @jsii.member(jsii_name="eventHubPartitionCount")
    def event_hub_partition_count(self) -> typing.Optional[jsii.Number]:
        return jsii.get(self, "eventHubPartitionCount")

    @event_hub_partition_count.setter # type: ignore
    def event_hub_partition_count(self, value: typing.Optional[jsii.Number]) -> None:
        jsii.set(self, "eventHubPartitionCount", value)

    @builtins.property # type: ignore
    @jsii.member(jsii_name="eventHubRetentionInDays")
    def event_hub_retention_in_days(self) -> typing.Optional[jsii.Number]:
        return jsii.get(self, "eventHubRetentionInDays")

    @event_hub_retention_in_days.setter # type: ignore
    def event_hub_retention_in_days(self, value: typing.Optional[jsii.Number]) -> None:
        jsii.set(self, "eventHubRetentionInDays", value)

    @builtins.property # type: ignore
    @jsii.member(jsii_name="fallbackRoute")
    def fallback_route(self) -> typing.Optional[typing.List["IothubFallbackRoute"]]:
        return jsii.get(self, "fallbackRoute")

    @fallback_route.setter # type: ignore
    def fallback_route(
        self,
        value: typing.Optional[typing.List["IothubFallbackRoute"]],
    ) -> None:
        jsii.set(self, "fallbackRoute", value)

    @builtins.property # type: ignore
    @jsii.member(jsii_name="fileUpload")
    def file_upload(self) -> typing.Optional[typing.List["IothubFileUpload"]]:
        return jsii.get(self, "fileUpload")

    @file_upload.setter # type: ignore
    def file_upload(
        self,
        value: typing.Optional[typing.List["IothubFileUpload"]],
    ) -> None:
        jsii.set(self, "fileUpload", value)

    @builtins.property # type: ignore
    @jsii.member(jsii_name="id")
    def id(self) -> typing.Optional[builtins.str]:
        return jsii.get(self, "id")

    @id.setter # type: ignore
    def id(self, value: typing.Optional[builtins.str]) -> None:
        jsii.set(self, "id", value)

    @builtins.property # type: ignore
    @jsii.member(jsii_name="ipFilterRule")
    def ip_filter_rule(self) -> typing.Optional[typing.List["IothubIpFilterRule"]]:
        return jsii.get(self, "ipFilterRule")

    @ip_filter_rule.setter # type: ignore
    def ip_filter_rule(
        self,
        value: typing.Optional[typing.List["IothubIpFilterRule"]],
    ) -> None:
        jsii.set(self, "ipFilterRule", value)

    @builtins.property # type: ignore
    @jsii.member(jsii_name="route")
    def route(self) -> typing.Optional[typing.List["IothubRoute"]]:
        return jsii.get(self, "route")

    @route.setter # type: ignore
    def route(self, value: typing.Optional[typing.List["IothubRoute"]]) -> None:
        jsii.set(self, "route", value)

    @builtins.property # type: ignore
    @jsii.member(jsii_name="tags")
    def tags(self) -> typing.Optional[typing.Mapping[builtins.str, builtins.str]]:
        return jsii.get(self, "tags")

    @tags.setter # type: ignore
    def tags(
        self,
        value: typing.Optional[typing.Mapping[builtins.str, builtins.str]],
    ) -> None:
        jsii.set(self, "tags", value)

    @builtins.property # type: ignore
    @jsii.member(jsii_name="timeouts")
    def timeouts(self) -> typing.Optional["IothubTimeouts"]:
        return jsii.get(self, "timeouts")

    @timeouts.setter # type: ignore
    def timeouts(self, value: typing.Optional["IothubTimeouts"]) -> None:
        jsii.set(self, "timeouts", value)


@jsii.data_type(
    jsii_type="@cdktf/provider-azurerm.IothubConfig",
    jsii_struct_bases=[cdktf.TerraformMetaArguments],
    name_mapping={
        "count": "count",
        "depends_on": "dependsOn",
        "lifecycle": "lifecycle",
        "provider": "provider",
        "location": "location",
        "name": "name",
        "resource_group_name": "resourceGroupName",
        "sku": "sku",
        "endpoint": "endpoint",
        "event_hub_partition_count": "eventHubPartitionCount",
        "event_hub_retention_in_days": "eventHubRetentionInDays",
        "fallback_route": "fallbackRoute",
        "file_upload": "fileUpload",
        "ip_filter_rule": "ipFilterRule",
        "route": "route",
        "tags": "tags",
        "timeouts": "timeouts",
    },
)
class IothubConfig(cdktf.TerraformMetaArguments):
    def __init__(
        self,
        *,
        count: typing.Optional[jsii.Number] = None,
        depends_on: typing.Optional[typing.List[cdktf.TerraformResource]] = None,
        lifecycle: typing.Optional[cdktf.TerraformResourceLifecycle] = None,
        provider: typing.Optional[cdktf.TerraformProvider] = None,
        location: builtins.str,
        name: builtins.str,
        resource_group_name: builtins.str,
        sku: typing.List["IothubSku"],
        endpoint: typing.Optional[typing.List["IothubEndpoint"]] = None,
        event_hub_partition_count: typing.Optional[jsii.Number] = None,
        event_hub_retention_in_days: typing.Optional[jsii.Number] = None,
        fallback_route: typing.Optional[typing.List["IothubFallbackRoute"]] = None,
        file_upload: typing.Optional[typing.List["IothubFileUpload"]] = None,
        ip_filter_rule: typing.Optional[typing.List["IothubIpFilterRule"]] = None,
        route: typing.Optional[typing.List["IothubRoute"]] = None,
        tags: typing.Optional[typing.Mapping[builtins.str, builtins.str]] = None,
        timeouts: typing.Optional["IothubTimeouts"] = None,
    ) -> None:
        """
        :param count: 
        :param depends_on: 
        :param lifecycle: 
        :param provider: 
        :param location: 
        :param name: 
        :param resource_group_name: 
        :param sku: sku block.
        :param endpoint: endpoint block.
        :param event_hub_partition_count: 
        :param event_hub_retention_in_days: 
        :param fallback_route: fallback_route block.
        :param file_upload: file_upload block.
        :param ip_filter_rule: ip_filter_rule block.
        :param route: route block.
        :param tags: 
        :param timeouts: timeouts block.
        """
        if isinstance(lifecycle, dict):
            lifecycle = cdktf.TerraformResourceLifecycle(**lifecycle)
        if isinstance(timeouts, dict):
            timeouts = IothubTimeouts(**timeouts)
        self._values: typing.Dict[str, typing.Any] = {
            "location": location,
            "name": name,
            "resource_group_name": resource_group_name,
            "sku": sku,
        }
        if count is not None:
            self._values["count"] = count
        if depends_on is not None:
            self._values["depends_on"] = depends_on
        if lifecycle is not None:
            self._values["lifecycle"] = lifecycle
        if provider is not None:
            self._values["provider"] = provider
        if endpoint is not None:
            self._values["endpoint"] = endpoint
        if event_hub_partition_count is not None:
            self._values["event_hub_partition_count"] = event_hub_partition_count
        if event_hub_retention_in_days is not None:
            self._values["event_hub_retention_in_days"] = event_hub_retention_in_days
        if fallback_route is not None:
            self._values["fallback_route"] = fallback_route
        if file_upload is not None:
            self._values["file_upload"] = file_upload
        if ip_filter_rule is not None:
            self._values["ip_filter_rule"] = ip_filter_rule
        if route is not None:
            self._values["route"] = route
        if tags is not None:
            self._values["tags"] = tags
        if timeouts is not None:
            self._values["timeouts"] = timeouts

    @builtins.property
    def count(self) -> typing.Optional[jsii.Number]:
        """
        :stability: experimental
        """
        result = self._values.get("count")
        return result

    @builtins.property
    def depends_on(self) -> typing.Optional[typing.List[cdktf.TerraformResource]]:
        """
        :stability: experimental
        """
        result = self._values.get("depends_on")
        return result

    @builtins.property
    def lifecycle(self) -> typing.Optional[cdktf.TerraformResourceLifecycle]:
        """
        :stability: experimental
        """
        result = self._values.get("lifecycle")
        return result

    @builtins.property
    def provider(self) -> typing.Optional[cdktf.TerraformProvider]:
        """
        :stability: experimental
        """
        result = self._values.get("provider")
        return result

    @builtins.property
    def location(self) -> builtins.str:
        result = self._values.get("location")
        assert result is not None, "Required property 'location' is missing"
        return result

    @builtins.property
    def name(self) -> builtins.str:
        result = self._values.get("name")
        assert result is not None, "Required property 'name' is missing"
        return result

    @builtins.property
    def resource_group_name(self) -> builtins.str:
        result = self._values.get("resource_group_name")
        assert result is not None, "Required property 'resource_group_name' is missing"
        return result

    @builtins.property
    def sku(self) -> typing.List["IothubSku"]:
        """sku block."""
        result = self._values.get("sku")
        assert result is not None, "Required property 'sku' is missing"
        return result

    @builtins.property
    def endpoint(self) -> typing.Optional[typing.List["IothubEndpoint"]]:
        """endpoint block."""
        result = self._values.get("endpoint")
        return result

    @builtins.property
    def event_hub_partition_count(self) -> typing.Optional[jsii.Number]:
        result = self._values.get("event_hub_partition_count")
        return result

    @builtins.property
    def event_hub_retention_in_days(self) -> typing.Optional[jsii.Number]:
        result = self._values.get("event_hub_retention_in_days")
        return result

    @builtins.property
    def fallback_route(self) -> typing.Optional[typing.List["IothubFallbackRoute"]]:
        """fallback_route block."""
        result = self._values.get("fallback_route")
        return result

    @builtins.property
    def file_upload(self) -> typing.Optional[typing.List["IothubFileUpload"]]:
        """file_upload block."""
        result = self._values.get("file_upload")
        return result

    @builtins.property
    def ip_filter_rule(self) -> typing.Optional[typing.List["IothubIpFilterRule"]]:
        """ip_filter_rule block."""
        result = self._values.get("ip_filter_rule")
        return result

    @builtins.property
    def route(self) -> typing.Optional[typing.List["IothubRoute"]]:
        """route block."""
        result = self._values.get("route")
        return result

    @builtins.property
    def tags(self) -> typing.Optional[typing.Mapping[builtins.str, builtins.str]]:
        result = self._values.get("tags")
        return result

    @builtins.property
    def timeouts(self) -> typing.Optional["IothubTimeouts"]:
        """timeouts block."""
        result = self._values.get("timeouts")
        return result

    def __eq__(self, rhs: typing.Any) -> builtins.bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs: typing.Any) -> builtins.bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return "IothubConfig(%s)" % ", ".join(
            k + "=" + repr(v) for k, v in self._values.items()
        )


class IothubConsumerGroup(
    cdktf.TerraformResource,
    metaclass=jsii.JSIIMeta,
    jsii_type="@cdktf/provider-azurerm.IothubConsumerGroup",
):
    def __init__(
        self,
        scope: constructs.Construct,
        id: builtins.str,
        *,
        eventhub_endpoint_name: builtins.str,
        iothub_name: builtins.str,
        name: builtins.str,
        resource_group_name: builtins.str,
        timeouts: typing.Optional["IothubConsumerGroupTimeouts"] = None,
        count: typing.Optional[jsii.Number] = None,
        depends_on: typing.Optional[typing.List[cdktf.TerraformResource]] = None,
        lifecycle: typing.Optional[cdktf.TerraformResourceLifecycle] = None,
        provider: typing.Optional[cdktf.TerraformProvider] = None,
    ) -> None:
        """
        :param scope: -
        :param id: -
        :param eventhub_endpoint_name: 
        :param iothub_name: 
        :param name: 
        :param resource_group_name: 
        :param timeouts: timeouts block.
        :param count: 
        :param depends_on: 
        :param lifecycle: 
        :param provider: 
        """
        config = IothubConsumerGroupConfig(
            eventhub_endpoint_name=eventhub_endpoint_name,
            iothub_name=iothub_name,
            name=name,
            resource_group_name=resource_group_name,
            timeouts=timeouts,
            count=count,
            depends_on=depends_on,
            lifecycle=lifecycle,
            provider=provider,
        )

        jsii.create(IothubConsumerGroup, self, [scope, id, config])

    @jsii.member(jsii_name="synthesizeAttributes")
    def _synthesize_attributes(self) -> typing.Mapping[builtins.str, typing.Any]:
        return jsii.invoke(self, "synthesizeAttributes", [])

    @builtins.property # type: ignore
    @jsii.member(jsii_name="eventhubEndpointName")
    def eventhub_endpoint_name(self) -> builtins.str:
        return jsii.get(self, "eventhubEndpointName")

    @eventhub_endpoint_name.setter # type: ignore
    def eventhub_endpoint_name(self, value: builtins.str) -> None:
        jsii.set(self, "eventhubEndpointName", value)

    @builtins.property # type: ignore
    @jsii.member(jsii_name="iothubName")
    def iothub_name(self) -> builtins.str:
        return jsii.get(self, "iothubName")

    @iothub_name.setter # type: ignore
    def iothub_name(self, value: builtins.str) -> None:
        jsii.set(self, "iothubName", value)

    @builtins.property # type: ignore
    @jsii.member(jsii_name="name")
    def name(self) -> builtins.str:
        return jsii.get(self, "name")

    @name.setter # type: ignore
    def name(self, value: builtins.str) -> None:
        jsii.set(self, "name", value)

    @builtins.property # type: ignore
    @jsii.member(jsii_name="resourceGroupName")
    def resource_group_name(self) -> builtins.str:
        return jsii.get(self, "resourceGroupName")

    @resource_group_name.setter # type: ignore
    def resource_group_name(self, value: builtins.str) -> None:
        jsii.set(self, "resourceGroupName", value)

    @builtins.property # type: ignore
    @jsii.member(jsii_name="id")
    def id(self) -> typing.Optional[builtins.str]:
        return jsii.get(self, "id")

    @id.setter # type: ignore
    def id(self, value: typing.Optional[builtins.str]) -> None:
        jsii.set(self, "id", value)

    @builtins.property # type: ignore
    @jsii.member(jsii_name="timeouts")
    def timeouts(self) -> typing.Optional["IothubConsumerGroupTimeouts"]:
        return jsii.get(self, "timeouts")

    @timeouts.setter # type: ignore
    def timeouts(self, value: typing.Optional["IothubConsumerGroupTimeouts"]) -> None:
        jsii.set(self, "timeouts", value)


@jsii.data_type(
    jsii_type="@cdktf/provider-azurerm.IothubConsumerGroupConfig",
    jsii_struct_bases=[cdktf.TerraformMetaArguments],
    name_mapping={
        "count": "count",
        "depends_on": "dependsOn",
        "lifecycle": "lifecycle",
        "provider": "provider",
        "eventhub_endpoint_name": "eventhubEndpointName",
        "iothub_name": "iothubName",
        "name": "name",
        "resource_group_name": "resourceGroupName",
        "timeouts": "timeouts",
    },
)
class IothubConsumerGroupConfig(cdktf.TerraformMetaArguments):
    def __init__(
        self,
        *,
        count: typing.Optional[jsii.Number] = None,
        depends_on: typing.Optional[typing.List[cdktf.TerraformResource]] = None,
        lifecycle: typing.Optional[cdktf.TerraformResourceLifecycle] = None,
        provider: typing.Optional[cdktf.TerraformProvider] = None,
        eventhub_endpoint_name: builtins.str,
        iothub_name: builtins.str,
        name: builtins.str,
        resource_group_name: builtins.str,
        timeouts: typing.Optional["IothubConsumerGroupTimeouts"] = None,
    ) -> None:
        """
        :param count: 
        :param depends_on: 
        :param lifecycle: 
        :param provider: 
        :param eventhub_endpoint_name: 
        :param iothub_name: 
        :param name: 
        :param resource_group_name: 
        :param timeouts: timeouts block.
        """
        if isinstance(lifecycle, dict):
            lifecycle = cdktf.TerraformResourceLifecycle(**lifecycle)
        if isinstance(timeouts, dict):
            timeouts = IothubConsumerGroupTimeouts(**timeouts)
        self._values: typing.Dict[str, typing.Any] = {
            "eventhub_endpoint_name": eventhub_endpoint_name,
            "iothub_name": iothub_name,
            "name": name,
            "resource_group_name": resource_group_name,
        }
        if count is not None:
            self._values["count"] = count
        if depends_on is not None:
            self._values["depends_on"] = depends_on
        if lifecycle is not None:
            self._values["lifecycle"] = lifecycle
        if provider is not None:
            self._values["provider"] = provider
        if timeouts is not None:
            self._values["timeouts"] = timeouts

    @builtins.property
    def count(self) -> typing.Optional[jsii.Number]:
        """
        :stability: experimental
        """
        result = self._values.get("count")
        return result

    @builtins.property
    def depends_on(self) -> typing.Optional[typing.List[cdktf.TerraformResource]]:
        """
        :stability: experimental
        """
        result = self._values.get("depends_on")
        return result

    @builtins.property
    def lifecycle(self) -> typing.Optional[cdktf.TerraformResourceLifecycle]:
        """
        :stability: experimental
        """
        result = self._values.get("lifecycle")
        return result

    @builtins.property
    def provider(self) -> typing.Optional[cdktf.TerraformProvider]:
        """
        :stability: experimental
        """
        result = self._values.get("provider")
        return result

    @builtins.property
    def eventhub_endpoint_name(self) -> builtins.str:
        result = self._values.get("eventhub_endpoint_name")
        assert result is not None, "Required property 'eventhub_endpoint_name' is missing"
        return result

    @builtins.property
    def iothub_name(self) -> builtins.str:
        result = self._values.get("iothub_name")
        assert result is not None, "Required property 'iothub_name' is missing"
        return result

    @builtins.property
    def name(self) -> builtins.str:
        result = self._values.get("name")
        assert result is not None, "Required property 'name' is missing"
        return result

    @builtins.property
    def resource_group_name(self) -> builtins.str:
        result = self._values.get("resource_group_name")
        assert result is not None, "Required property 'resource_group_name' is missing"
        return result

    @builtins.property
    def timeouts(self) -> typing.Optional["IothubConsumerGroupTimeouts"]:
        """timeouts block."""
        result = self._values.get("timeouts")
        return result

    def __eq__(self, rhs: typing.Any) -> builtins.bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs: typing.Any) -> builtins.bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return "IothubConsumerGroupConfig(%s)" % ", ".join(
            k + "=" + repr(v) for k, v in self._values.items()
        )


@jsii.data_type(
    jsii_type="@cdktf/provider-azurerm.IothubConsumerGroupTimeouts",
    jsii_struct_bases=[],
    name_mapping={
        "create": "create",
        "delete": "delete",
        "read": "read",
        "update": "update",
    },
)
class IothubConsumerGroupTimeouts:
    def __init__(
        self,
        *,
        create: typing.Optional[builtins.str] = None,
        delete: typing.Optional[builtins.str] = None,
        read: typing.Optional[builtins.str] = None,
        update: typing.Optional[builtins.str] = None,
    ) -> None:
        """
        :param create: 
        :param delete: 
        :param read: 
        :param update: 
        """
        self._values: typing.Dict[str, typing.Any] = {}
        if create is not None:
            self._values["create"] = create
        if delete is not None:
            self._values["delete"] = delete
        if read is not None:
            self._values["read"] = read
        if update is not None:
            self._values["update"] = update

    @builtins.property
    def create(self) -> typing.Optional[builtins.str]:
        result = self._values.get("create")
        return result

    @builtins.property
    def delete(self) -> typing.Optional[builtins.str]:
        result = self._values.get("delete")
        return result

    @builtins.property
    def read(self) -> typing.Optional[builtins.str]:
        result = self._values.get("read")
        return result

    @builtins.property
    def update(self) -> typing.Optional[builtins.str]:
        result = self._values.get("update")
        return result

    def __eq__(self, rhs: typing.Any) -> builtins.bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs: typing.Any) -> builtins.bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return "IothubConsumerGroupTimeouts(%s)" % ", ".join(
            k + "=" + repr(v) for k, v in self._values.items()
        )


class IothubDps(
    cdktf.TerraformResource,
    metaclass=jsii.JSIIMeta,
    jsii_type="@cdktf/provider-azurerm.IothubDps",
):
    def __init__(
        self,
        scope: constructs.Construct,
        id: builtins.str,
        *,
        location: builtins.str,
        name: builtins.str,
        resource_group_name: builtins.str,
        sku: typing.List["IothubDpsSku"],
        linked_hub: typing.Optional[typing.List["IothubDpsLinkedHub"]] = None,
        tags: typing.Optional[typing.Mapping[builtins.str, builtins.str]] = None,
        timeouts: typing.Optional["IothubDpsTimeouts"] = None,
        count: typing.Optional[jsii.Number] = None,
        depends_on: typing.Optional[typing.List[cdktf.TerraformResource]] = None,
        lifecycle: typing.Optional[cdktf.TerraformResourceLifecycle] = None,
        provider: typing.Optional[cdktf.TerraformProvider] = None,
    ) -> None:
        """
        :param scope: -
        :param id: -
        :param location: 
        :param name: 
        :param resource_group_name: 
        :param sku: sku block.
        :param linked_hub: linked_hub block.
        :param tags: 
        :param timeouts: timeouts block.
        :param count: 
        :param depends_on: 
        :param lifecycle: 
        :param provider: 
        """
        config = IothubDpsConfig(
            location=location,
            name=name,
            resource_group_name=resource_group_name,
            sku=sku,
            linked_hub=linked_hub,
            tags=tags,
            timeouts=timeouts,
            count=count,
            depends_on=depends_on,
            lifecycle=lifecycle,
            provider=provider,
        )

        jsii.create(IothubDps, self, [scope, id, config])

    @jsii.member(jsii_name="synthesizeAttributes")
    def _synthesize_attributes(self) -> typing.Mapping[builtins.str, typing.Any]:
        return jsii.invoke(self, "synthesizeAttributes", [])

    @builtins.property # type: ignore
    @jsii.member(jsii_name="allocationPolicy")
    def allocation_policy(self) -> builtins.str:
        return jsii.get(self, "allocationPolicy")

    @builtins.property # type: ignore
    @jsii.member(jsii_name="deviceProvisioningHostName")
    def device_provisioning_host_name(self) -> builtins.str:
        return jsii.get(self, "deviceProvisioningHostName")

    @builtins.property # type: ignore
    @jsii.member(jsii_name="idScope")
    def id_scope(self) -> builtins.str:
        return jsii.get(self, "idScope")

    @builtins.property # type: ignore
    @jsii.member(jsii_name="serviceOperationsHostName")
    def service_operations_host_name(self) -> builtins.str:
        return jsii.get(self, "serviceOperationsHostName")

    @builtins.property # type: ignore
    @jsii.member(jsii_name="location")
    def location(self) -> builtins.str:
        return jsii.get(self, "location")

    @location.setter # type: ignore
    def location(self, value: builtins.str) -> None:
        jsii.set(self, "location", value)

    @builtins.property # type: ignore
    @jsii.member(jsii_name="name")
    def name(self) -> builtins.str:
        return jsii.get(self, "name")

    @name.setter # type: ignore
    def name(self, value: builtins.str) -> None:
        jsii.set(self, "name", value)

    @builtins.property # type: ignore
    @jsii.member(jsii_name="resourceGroupName")
    def resource_group_name(self) -> builtins.str:
        return jsii.get(self, "resourceGroupName")

    @resource_group_name.setter # type: ignore
    def resource_group_name(self, value: builtins.str) -> None:
        jsii.set(self, "resourceGroupName", value)

    @builtins.property # type: ignore
    @jsii.member(jsii_name="sku")
    def sku(self) -> typing.List["IothubDpsSku"]:
        return jsii.get(self, "sku")

    @sku.setter # type: ignore
    def sku(self, value: typing.List["IothubDpsSku"]) -> None:
        jsii.set(self, "sku", value)

    @builtins.property # type: ignore
    @jsii.member(jsii_name="id")
    def id(self) -> typing.Optional[builtins.str]:
        return jsii.get(self, "id")

    @id.setter # type: ignore
    def id(self, value: typing.Optional[builtins.str]) -> None:
        jsii.set(self, "id", value)

    @builtins.property # type: ignore
    @jsii.member(jsii_name="linkedHub")
    def linked_hub(self) -> typing.Optional[typing.List["IothubDpsLinkedHub"]]:
        return jsii.get(self, "linkedHub")

    @linked_hub.setter # type: ignore
    def linked_hub(
        self,
        value: typing.Optional[typing.List["IothubDpsLinkedHub"]],
    ) -> None:
        jsii.set(self, "linkedHub", value)

    @builtins.property # type: ignore
    @jsii.member(jsii_name="tags")
    def tags(self) -> typing.Optional[typing.Mapping[builtins.str, builtins.str]]:
        return jsii.get(self, "tags")

    @tags.setter # type: ignore
    def tags(
        self,
        value: typing.Optional[typing.Mapping[builtins.str, builtins.str]],
    ) -> None:
        jsii.set(self, "tags", value)

    @builtins.property # type: ignore
    @jsii.member(jsii_name="timeouts")
    def timeouts(self) -> typing.Optional["IothubDpsTimeouts"]:
        return jsii.get(self, "timeouts")

    @timeouts.setter # type: ignore
    def timeouts(self, value: typing.Optional["IothubDpsTimeouts"]) -> None:
        jsii.set(self, "timeouts", value)


class IothubDpsCertificate(
    cdktf.TerraformResource,
    metaclass=jsii.JSIIMeta,
    jsii_type="@cdktf/provider-azurerm.IothubDpsCertificate",
):
    def __init__(
        self,
        scope: constructs.Construct,
        id: builtins.str,
        *,
        certificate_content: builtins.str,
        iot_dps_name: builtins.str,
        name: builtins.str,
        resource_group_name: builtins.str,
        timeouts: typing.Optional["IothubDpsCertificateTimeouts"] = None,
        count: typing.Optional[jsii.Number] = None,
        depends_on: typing.Optional[typing.List[cdktf.TerraformResource]] = None,
        lifecycle: typing.Optional[cdktf.TerraformResourceLifecycle] = None,
        provider: typing.Optional[cdktf.TerraformProvider] = None,
    ) -> None:
        """
        :param scope: -
        :param id: -
        :param certificate_content: 
        :param iot_dps_name: 
        :param name: 
        :param resource_group_name: 
        :param timeouts: timeouts block.
        :param count: 
        :param depends_on: 
        :param lifecycle: 
        :param provider: 
        """
        config = IothubDpsCertificateConfig(
            certificate_content=certificate_content,
            iot_dps_name=iot_dps_name,
            name=name,
            resource_group_name=resource_group_name,
            timeouts=timeouts,
            count=count,
            depends_on=depends_on,
            lifecycle=lifecycle,
            provider=provider,
        )

        jsii.create(IothubDpsCertificate, self, [scope, id, config])

    @jsii.member(jsii_name="synthesizeAttributes")
    def _synthesize_attributes(self) -> typing.Mapping[builtins.str, typing.Any]:
        return jsii.invoke(self, "synthesizeAttributes", [])

    @builtins.property # type: ignore
    @jsii.member(jsii_name="certificateContent")
    def certificate_content(self) -> builtins.str:
        return jsii.get(self, "certificateContent")

    @certificate_content.setter # type: ignore
    def certificate_content(self, value: builtins.str) -> None:
        jsii.set(self, "certificateContent", value)

    @builtins.property # type: ignore
    @jsii.member(jsii_name="iotDpsName")
    def iot_dps_name(self) -> builtins.str:
        return jsii.get(self, "iotDpsName")

    @iot_dps_name.setter # type: ignore
    def iot_dps_name(self, value: builtins.str) -> None:
        jsii.set(self, "iotDpsName", value)

    @builtins.property # type: ignore
    @jsii.member(jsii_name="name")
    def name(self) -> builtins.str:
        return jsii.get(self, "name")

    @name.setter # type: ignore
    def name(self, value: builtins.str) -> None:
        jsii.set(self, "name", value)

    @builtins.property # type: ignore
    @jsii.member(jsii_name="resourceGroupName")
    def resource_group_name(self) -> builtins.str:
        return jsii.get(self, "resourceGroupName")

    @resource_group_name.setter # type: ignore
    def resource_group_name(self, value: builtins.str) -> None:
        jsii.set(self, "resourceGroupName", value)

    @builtins.property # type: ignore
    @jsii.member(jsii_name="id")
    def id(self) -> typing.Optional[builtins.str]:
        return jsii.get(self, "id")

    @id.setter # type: ignore
    def id(self, value: typing.Optional[builtins.str]) -> None:
        jsii.set(self, "id", value)

    @builtins.property # type: ignore
    @jsii.member(jsii_name="timeouts")
    def timeouts(self) -> typing.Optional["IothubDpsCertificateTimeouts"]:
        return jsii.get(self, "timeouts")

    @timeouts.setter # type: ignore
    def timeouts(self, value: typing.Optional["IothubDpsCertificateTimeouts"]) -> None:
        jsii.set(self, "timeouts", value)


@jsii.data_type(
    jsii_type="@cdktf/provider-azurerm.IothubDpsCertificateConfig",
    jsii_struct_bases=[cdktf.TerraformMetaArguments],
    name_mapping={
        "count": "count",
        "depends_on": "dependsOn",
        "lifecycle": "lifecycle",
        "provider": "provider",
        "certificate_content": "certificateContent",
        "iot_dps_name": "iotDpsName",
        "name": "name",
        "resource_group_name": "resourceGroupName",
        "timeouts": "timeouts",
    },
)
class IothubDpsCertificateConfig(cdktf.TerraformMetaArguments):
    def __init__(
        self,
        *,
        count: typing.Optional[jsii.Number] = None,
        depends_on: typing.Optional[typing.List[cdktf.TerraformResource]] = None,
        lifecycle: typing.Optional[cdktf.TerraformResourceLifecycle] = None,
        provider: typing.Optional[cdktf.TerraformProvider] = None,
        certificate_content: builtins.str,
        iot_dps_name: builtins.str,
        name: builtins.str,
        resource_group_name: builtins.str,
        timeouts: typing.Optional["IothubDpsCertificateTimeouts"] = None,
    ) -> None:
        """
        :param count: 
        :param depends_on: 
        :param lifecycle: 
        :param provider: 
        :param certificate_content: 
        :param iot_dps_name: 
        :param name: 
        :param resource_group_name: 
        :param timeouts: timeouts block.
        """
        if isinstance(lifecycle, dict):
            lifecycle = cdktf.TerraformResourceLifecycle(**lifecycle)
        if isinstance(timeouts, dict):
            timeouts = IothubDpsCertificateTimeouts(**timeouts)
        self._values: typing.Dict[str, typing.Any] = {
            "certificate_content": certificate_content,
            "iot_dps_name": iot_dps_name,
            "name": name,
            "resource_group_name": resource_group_name,
        }
        if count is not None:
            self._values["count"] = count
        if depends_on is not None:
            self._values["depends_on"] = depends_on
        if lifecycle is not None:
            self._values["lifecycle"] = lifecycle
        if provider is not None:
            self._values["provider"] = provider
        if timeouts is not None:
            self._values["timeouts"] = timeouts

    @builtins.property
    def count(self) -> typing.Optional[jsii.Number]:
        """
        :stability: experimental
        """
        result = self._values.get("count")
        return result

    @builtins.property
    def depends_on(self) -> typing.Optional[typing.List[cdktf.TerraformResource]]:
        """
        :stability: experimental
        """
        result = self._values.get("depends_on")
        return result

    @builtins.property
    def lifecycle(self) -> typing.Optional[cdktf.TerraformResourceLifecycle]:
        """
        :stability: experimental
        """
        result = self._values.get("lifecycle")
        return result

    @builtins.property
    def provider(self) -> typing.Optional[cdktf.TerraformProvider]:
        """
        :stability: experimental
        """
        result = self._values.get("provider")
        return result

    @builtins.property
    def certificate_content(self) -> builtins.str:
        result = self._values.get("certificate_content")
        assert result is not None, "Required property 'certificate_content' is missing"
        return result

    @builtins.property
    def iot_dps_name(self) -> builtins.str:
        result = self._values.get("iot_dps_name")
        assert result is not None, "Required property 'iot_dps_name' is missing"
        return result

    @builtins.property
    def name(self) -> builtins.str:
        result = self._values.get("name")
        assert result is not None, "Required property 'name' is missing"
        return result

    @builtins.property
    def resource_group_name(self) -> builtins.str:
        result = self._values.get("resource_group_name")
        assert result is not None, "Required property 'resource_group_name' is missing"
        return result

    @builtins.property
    def timeouts(self) -> typing.Optional["IothubDpsCertificateTimeouts"]:
        """timeouts block."""
        result = self._values.get("timeouts")
        return result

    def __eq__(self, rhs: typing.Any) -> builtins.bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs: typing.Any) -> builtins.bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return "IothubDpsCertificateConfig(%s)" % ", ".join(
            k + "=" + repr(v) for k, v in self._values.items()
        )


@jsii.data_type(
    jsii_type="@cdktf/provider-azurerm.IothubDpsCertificateTimeouts",
    jsii_struct_bases=[],
    name_mapping={
        "create": "create",
        "delete": "delete",
        "read": "read",
        "update": "update",
    },
)
class IothubDpsCertificateTimeouts:
    def __init__(
        self,
        *,
        create: typing.Optional[builtins.str] = None,
        delete: typing.Optional[builtins.str] = None,
        read: typing.Optional[builtins.str] = None,
        update: typing.Optional[builtins.str] = None,
    ) -> None:
        """
        :param create: 
        :param delete: 
        :param read: 
        :param update: 
        """
        self._values: typing.Dict[str, typing.Any] = {}
        if create is not None:
            self._values["create"] = create
        if delete is not None:
            self._values["delete"] = delete
        if read is not None:
            self._values["read"] = read
        if update is not None:
            self._values["update"] = update

    @builtins.property
    def create(self) -> typing.Optional[builtins.str]:
        result = self._values.get("create")
        return result

    @builtins.property
    def delete(self) -> typing.Optional[builtins.str]:
        result = self._values.get("delete")
        return result

    @builtins.property
    def read(self) -> typing.Optional[builtins.str]:
        result = self._values.get("read")
        return result

    @builtins.property
    def update(self) -> typing.Optional[builtins.str]:
        result = self._values.get("update")
        return result

    def __eq__(self, rhs: typing.Any) -> builtins.bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs: typing.Any) -> builtins.bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return "IothubDpsCertificateTimeouts(%s)" % ", ".join(
            k + "=" + repr(v) for k, v in self._values.items()
        )


@jsii.data_type(
    jsii_type="@cdktf/provider-azurerm.IothubDpsConfig",
    jsii_struct_bases=[cdktf.TerraformMetaArguments],
    name_mapping={
        "count": "count",
        "depends_on": "dependsOn",
        "lifecycle": "lifecycle",
        "provider": "provider",
        "location": "location",
        "name": "name",
        "resource_group_name": "resourceGroupName",
        "sku": "sku",
        "linked_hub": "linkedHub",
        "tags": "tags",
        "timeouts": "timeouts",
    },
)
class IothubDpsConfig(cdktf.TerraformMetaArguments):
    def __init__(
        self,
        *,
        count: typing.Optional[jsii.Number] = None,
        depends_on: typing.Optional[typing.List[cdktf.TerraformResource]] = None,
        lifecycle: typing.Optional[cdktf.TerraformResourceLifecycle] = None,
        provider: typing.Optional[cdktf.TerraformProvider] = None,
        location: builtins.str,
        name: builtins.str,
        resource_group_name: builtins.str,
        sku: typing.List["IothubDpsSku"],
        linked_hub: typing.Optional[typing.List["IothubDpsLinkedHub"]] = None,
        tags: typing.Optional[typing.Mapping[builtins.str, builtins.str]] = None,
        timeouts: typing.Optional["IothubDpsTimeouts"] = None,
    ) -> None:
        """
        :param count: 
        :param depends_on: 
        :param lifecycle: 
        :param provider: 
        :param location: 
        :param name: 
        :param resource_group_name: 
        :param sku: sku block.
        :param linked_hub: linked_hub block.
        :param tags: 
        :param timeouts: timeouts block.
        """
        if isinstance(lifecycle, dict):
            lifecycle = cdktf.TerraformResourceLifecycle(**lifecycle)
        if isinstance(timeouts, dict):
            timeouts = IothubDpsTimeouts(**timeouts)
        self._values: typing.Dict[str, typing.Any] = {
            "location": location,
            "name": name,
            "resource_group_name": resource_group_name,
            "sku": sku,
        }
        if count is not None:
            self._values["count"] = count
        if depends_on is not None:
            self._values["depends_on"] = depends_on
        if lifecycle is not None:
            self._values["lifecycle"] = lifecycle
        if provider is not None:
            self._values["provider"] = provider
        if linked_hub is not None:
            self._values["linked_hub"] = linked_hub
        if tags is not None:
            self._values["tags"] = tags
        if timeouts is not None:
            self._values["timeouts"] = timeouts

    @builtins.property
    def count(self) -> typing.Optional[jsii.Number]:
        """
        :stability: experimental
        """
        result = self._values.get("count")
        return result

    @builtins.property
    def depends_on(self) -> typing.Optional[typing.List[cdktf.TerraformResource]]:
        """
        :stability: experimental
        """
        result = self._values.get("depends_on")
        return result

    @builtins.property
    def lifecycle(self) -> typing.Optional[cdktf.TerraformResourceLifecycle]:
        """
        :stability: experimental
        """
        result = self._values.get("lifecycle")
        return result

    @builtins.property
    def provider(self) -> typing.Optional[cdktf.TerraformProvider]:
        """
        :stability: experimental
        """
        result = self._values.get("provider")
        return result

    @builtins.property
    def location(self) -> builtins.str:
        result = self._values.get("location")
        assert result is not None, "Required property 'location' is missing"
        return result

    @builtins.property
    def name(self) -> builtins.str:
        result = self._values.get("name")
        assert result is not None, "Required property 'name' is missing"
        return result

    @builtins.property
    def resource_group_name(self) -> builtins.str:
        result = self._values.get("resource_group_name")
        assert result is not None, "Required property 'resource_group_name' is missing"
        return result

    @builtins.property
    def sku(self) -> typing.List["IothubDpsSku"]:
        """sku block."""
        result = self._values.get("sku")
        assert result is not None, "Required property 'sku' is missing"
        return result

    @builtins.property
    def linked_hub(self) -> typing.Optional[typing.List["IothubDpsLinkedHub"]]:
        """linked_hub block."""
        result = self._values.get("linked_hub")
        return result

    @builtins.property
    def tags(self) -> typing.Optional[typing.Mapping[builtins.str, builtins.str]]:
        result = self._values.get("tags")
        return result

    @builtins.property
    def timeouts(self) -> typing.Optional["IothubDpsTimeouts"]:
        """timeouts block."""
        result = self._values.get("timeouts")
        return result

    def __eq__(self, rhs: typing.Any) -> builtins.bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs: typing.Any) -> builtins.bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return "IothubDpsConfig(%s)" % ", ".join(
            k + "=" + repr(v) for k, v in self._values.items()
        )


@jsii.data_type(
    jsii_type="@cdktf/provider-azurerm.IothubDpsLinkedHub",
    jsii_struct_bases=[],
    name_mapping={
        "connection_string": "connectionString",
        "location": "location",
        "allocation_weight": "allocationWeight",
        "apply_allocation_policy": "applyAllocationPolicy",
    },
)
class IothubDpsLinkedHub:
    def __init__(
        self,
        *,
        connection_string: builtins.str,
        location: builtins.str,
        allocation_weight: typing.Optional[jsii.Number] = None,
        apply_allocation_policy: typing.Optional[builtins.bool] = None,
    ) -> None:
        """
        :param connection_string: 
        :param location: 
        :param allocation_weight: 
        :param apply_allocation_policy: 
        """
        self._values: typing.Dict[str, typing.Any] = {
            "connection_string": connection_string,
            "location": location,
        }
        if allocation_weight is not None:
            self._values["allocation_weight"] = allocation_weight
        if apply_allocation_policy is not None:
            self._values["apply_allocation_policy"] = apply_allocation_policy

    @builtins.property
    def connection_string(self) -> builtins.str:
        result = self._values.get("connection_string")
        assert result is not None, "Required property 'connection_string' is missing"
        return result

    @builtins.property
    def location(self) -> builtins.str:
        result = self._values.get("location")
        assert result is not None, "Required property 'location' is missing"
        return result

    @builtins.property
    def allocation_weight(self) -> typing.Optional[jsii.Number]:
        result = self._values.get("allocation_weight")
        return result

    @builtins.property
    def apply_allocation_policy(self) -> typing.Optional[builtins.bool]:
        result = self._values.get("apply_allocation_policy")
        return result

    def __eq__(self, rhs: typing.Any) -> builtins.bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs: typing.Any) -> builtins.bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return "IothubDpsLinkedHub(%s)" % ", ".join(
            k + "=" + repr(v) for k, v in self._values.items()
        )


class IothubDpsSharedAccessPolicy(
    cdktf.TerraformResource,
    metaclass=jsii.JSIIMeta,
    jsii_type="@cdktf/provider-azurerm.IothubDpsSharedAccessPolicy",
):
    def __init__(
        self,
        scope: constructs.Construct,
        id: builtins.str,
        *,
        iothub_dps_name: builtins.str,
        name: builtins.str,
        resource_group_name: builtins.str,
        enrollment_read: typing.Optional[builtins.bool] = None,
        enrollment_write: typing.Optional[builtins.bool] = None,
        registration_read: typing.Optional[builtins.bool] = None,
        registration_write: typing.Optional[builtins.bool] = None,
        service_config: typing.Optional[builtins.bool] = None,
        timeouts: typing.Optional["IothubDpsSharedAccessPolicyTimeouts"] = None,
        count: typing.Optional[jsii.Number] = None,
        depends_on: typing.Optional[typing.List[cdktf.TerraformResource]] = None,
        lifecycle: typing.Optional[cdktf.TerraformResourceLifecycle] = None,
        provider: typing.Optional[cdktf.TerraformProvider] = None,
    ) -> None:
        """
        :param scope: -
        :param id: -
        :param iothub_dps_name: 
        :param name: 
        :param resource_group_name: 
        :param enrollment_read: 
        :param enrollment_write: 
        :param registration_read: 
        :param registration_write: 
        :param service_config: 
        :param timeouts: timeouts block.
        :param count: 
        :param depends_on: 
        :param lifecycle: 
        :param provider: 
        """
        config = IothubDpsSharedAccessPolicyConfig(
            iothub_dps_name=iothub_dps_name,
            name=name,
            resource_group_name=resource_group_name,
            enrollment_read=enrollment_read,
            enrollment_write=enrollment_write,
            registration_read=registration_read,
            registration_write=registration_write,
            service_config=service_config,
            timeouts=timeouts,
            count=count,
            depends_on=depends_on,
            lifecycle=lifecycle,
            provider=provider,
        )

        jsii.create(IothubDpsSharedAccessPolicy, self, [scope, id, config])

    @jsii.member(jsii_name="synthesizeAttributes")
    def _synthesize_attributes(self) -> typing.Mapping[builtins.str, typing.Any]:
        return jsii.invoke(self, "synthesizeAttributes", [])

    @builtins.property # type: ignore
    @jsii.member(jsii_name="primaryConnectionString")
    def primary_connection_string(self) -> builtins.str:
        return jsii.get(self, "primaryConnectionString")

    @builtins.property # type: ignore
    @jsii.member(jsii_name="primaryKey")
    def primary_key(self) -> builtins.str:
        return jsii.get(self, "primaryKey")

    @builtins.property # type: ignore
    @jsii.member(jsii_name="secondaryConnectionString")
    def secondary_connection_string(self) -> builtins.str:
        return jsii.get(self, "secondaryConnectionString")

    @builtins.property # type: ignore
    @jsii.member(jsii_name="secondaryKey")
    def secondary_key(self) -> builtins.str:
        return jsii.get(self, "secondaryKey")

    @builtins.property # type: ignore
    @jsii.member(jsii_name="iothubDpsName")
    def iothub_dps_name(self) -> builtins.str:
        return jsii.get(self, "iothubDpsName")

    @iothub_dps_name.setter # type: ignore
    def iothub_dps_name(self, value: builtins.str) -> None:
        jsii.set(self, "iothubDpsName", value)

    @builtins.property # type: ignore
    @jsii.member(jsii_name="name")
    def name(self) -> builtins.str:
        return jsii.get(self, "name")

    @name.setter # type: ignore
    def name(self, value: builtins.str) -> None:
        jsii.set(self, "name", value)

    @builtins.property # type: ignore
    @jsii.member(jsii_name="resourceGroupName")
    def resource_group_name(self) -> builtins.str:
        return jsii.get(self, "resourceGroupName")

    @resource_group_name.setter # type: ignore
    def resource_group_name(self, value: builtins.str) -> None:
        jsii.set(self, "resourceGroupName", value)

    @builtins.property # type: ignore
    @jsii.member(jsii_name="enrollmentRead")
    def enrollment_read(self) -> typing.Optional[builtins.bool]:
        return jsii.get(self, "enrollmentRead")

    @enrollment_read.setter # type: ignore
    def enrollment_read(self, value: typing.Optional[builtins.bool]) -> None:
        jsii.set(self, "enrollmentRead", value)

    @builtins.property # type: ignore
    @jsii.member(jsii_name="enrollmentWrite")
    def enrollment_write(self) -> typing.Optional[builtins.bool]:
        return jsii.get(self, "enrollmentWrite")

    @enrollment_write.setter # type: ignore
    def enrollment_write(self, value: typing.Optional[builtins.bool]) -> None:
        jsii.set(self, "enrollmentWrite", value)

    @builtins.property # type: ignore
    @jsii.member(jsii_name="id")
    def id(self) -> typing.Optional[builtins.str]:
        return jsii.get(self, "id")

    @id.setter # type: ignore
    def id(self, value: typing.Optional[builtins.str]) -> None:
        jsii.set(self, "id", value)

    @builtins.property # type: ignore
    @jsii.member(jsii_name="registrationRead")
    def registration_read(self) -> typing.Optional[builtins.bool]:
        return jsii.get(self, "registrationRead")

    @registration_read.setter # type: ignore
    def registration_read(self, value: typing.Optional[builtins.bool]) -> None:
        jsii.set(self, "registrationRead", value)

    @builtins.property # type: ignore
    @jsii.member(jsii_name="registrationWrite")
    def registration_write(self) -> typing.Optional[builtins.bool]:
        return jsii.get(self, "registrationWrite")

    @registration_write.setter # type: ignore
    def registration_write(self, value: typing.Optional[builtins.bool]) -> None:
        jsii.set(self, "registrationWrite", value)

    @builtins.property # type: ignore
    @jsii.member(jsii_name="serviceConfig")
    def service_config(self) -> typing.Optional[builtins.bool]:
        return jsii.get(self, "serviceConfig")

    @service_config.setter # type: ignore
    def service_config(self, value: typing.Optional[builtins.bool]) -> None:
        jsii.set(self, "serviceConfig", value)

    @builtins.property # type: ignore
    @jsii.member(jsii_name="timeouts")
    def timeouts(self) -> typing.Optional["IothubDpsSharedAccessPolicyTimeouts"]:
        return jsii.get(self, "timeouts")

    @timeouts.setter # type: ignore
    def timeouts(
        self,
        value: typing.Optional["IothubDpsSharedAccessPolicyTimeouts"],
    ) -> None:
        jsii.set(self, "timeouts", value)


@jsii.data_type(
    jsii_type="@cdktf/provider-azurerm.IothubDpsSharedAccessPolicyConfig",
    jsii_struct_bases=[cdktf.TerraformMetaArguments],
    name_mapping={
        "count": "count",
        "depends_on": "dependsOn",
        "lifecycle": "lifecycle",
        "provider": "provider",
        "iothub_dps_name": "iothubDpsName",
        "name": "name",
        "resource_group_name": "resourceGroupName",
        "enrollment_read": "enrollmentRead",
        "enrollment_write": "enrollmentWrite",
        "registration_read": "registrationRead",
        "registration_write": "registrationWrite",
        "service_config": "serviceConfig",
        "timeouts": "timeouts",
    },
)
class IothubDpsSharedAccessPolicyConfig(cdktf.TerraformMetaArguments):
    def __init__(
        self,
        *,
        count: typing.Optional[jsii.Number] = None,
        depends_on: typing.Optional[typing.List[cdktf.TerraformResource]] = None,
        lifecycle: typing.Optional[cdktf.TerraformResourceLifecycle] = None,
        provider: typing.Optional[cdktf.TerraformProvider] = None,
        iothub_dps_name: builtins.str,
        name: builtins.str,
        resource_group_name: builtins.str,
        enrollment_read: typing.Optional[builtins.bool] = None,
        enrollment_write: typing.Optional[builtins.bool] = None,
        registration_read: typing.Optional[builtins.bool] = None,
        registration_write: typing.Optional[builtins.bool] = None,
        service_config: typing.Optional[builtins.bool] = None,
        timeouts: typing.Optional["IothubDpsSharedAccessPolicyTimeouts"] = None,
    ) -> None:
        """
        :param count: 
        :param depends_on: 
        :param lifecycle: 
        :param provider: 
        :param iothub_dps_name: 
        :param name: 
        :param resource_group_name: 
        :param enrollment_read: 
        :param enrollment_write: 
        :param registration_read: 
        :param registration_write: 
        :param service_config: 
        :param timeouts: timeouts block.
        """
        if isinstance(lifecycle, dict):
            lifecycle = cdktf.TerraformResourceLifecycle(**lifecycle)
        if isinstance(timeouts, dict):
            timeouts = IothubDpsSharedAccessPolicyTimeouts(**timeouts)
        self._values: typing.Dict[str, typing.Any] = {
            "iothub_dps_name": iothub_dps_name,
            "name": name,
            "resource_group_name": resource_group_name,
        }
        if count is not None:
            self._values["count"] = count
        if depends_on is not None:
            self._values["depends_on"] = depends_on
        if lifecycle is not None:
            self._values["lifecycle"] = lifecycle
        if provider is not None:
            self._values["provider"] = provider
        if enrollment_read is not None:
            self._values["enrollment_read"] = enrollment_read
        if enrollment_write is not None:
            self._values["enrollment_write"] = enrollment_write
        if registration_read is not None:
            self._values["registration_read"] = registration_read
        if registration_write is not None:
            self._values["registration_write"] = registration_write
        if service_config is not None:
            self._values["service_config"] = service_config
        if timeouts is not None:
            self._values["timeouts"] = timeouts

    @builtins.property
    def count(self) -> typing.Optional[jsii.Number]:
        """
        :stability: experimental
        """
        result = self._values.get("count")
        return result

    @builtins.property
    def depends_on(self) -> typing.Optional[typing.List[cdktf.TerraformResource]]:
        """
        :stability: experimental
        """
        result = self._values.get("depends_on")
        return result

    @builtins.property
    def lifecycle(self) -> typing.Optional[cdktf.TerraformResourceLifecycle]:
        """
        :stability: experimental
        """
        result = self._values.get("lifecycle")
        return result

    @builtins.property
    def provider(self) -> typing.Optional[cdktf.TerraformProvider]:
        """
        :stability: experimental
        """
        result = self._values.get("provider")
        return result

    @builtins.property
    def iothub_dps_name(self) -> builtins.str:
        result = self._values.get("iothub_dps_name")
        assert result is not None, "Required property 'iothub_dps_name' is missing"
        return result

    @builtins.property
    def name(self) -> builtins.str:
        result = self._values.get("name")
        assert result is not None, "Required property 'name' is missing"
        return result

    @builtins.property
    def resource_group_name(self) -> builtins.str:
        result = self._values.get("resource_group_name")
        assert result is not None, "Required property 'resource_group_name' is missing"
        return result

    @builtins.property
    def enrollment_read(self) -> typing.Optional[builtins.bool]:
        result = self._values.get("enrollment_read")
        return result

    @builtins.property
    def enrollment_write(self) -> typing.Optional[builtins.bool]:
        result = self._values.get("enrollment_write")
        return result

    @builtins.property
    def registration_read(self) -> typing.Optional[builtins.bool]:
        result = self._values.get("registration_read")
        return result

    @builtins.property
    def registration_write(self) -> typing.Optional[builtins.bool]:
        result = self._values.get("registration_write")
        return result

    @builtins.property
    def service_config(self) -> typing.Optional[builtins.bool]:
        result = self._values.get("service_config")
        return result

    @builtins.property
    def timeouts(self) -> typing.Optional["IothubDpsSharedAccessPolicyTimeouts"]:
        """timeouts block."""
        result = self._values.get("timeouts")
        return result

    def __eq__(self, rhs: typing.Any) -> builtins.bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs: typing.Any) -> builtins.bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return "IothubDpsSharedAccessPolicyConfig(%s)" % ", ".join(
            k + "=" + repr(v) for k, v in self._values.items()
        )


@jsii.data_type(
    jsii_type="@cdktf/provider-azurerm.IothubDpsSharedAccessPolicyTimeouts",
    jsii_struct_bases=[],
    name_mapping={
        "create": "create",
        "delete": "delete",
        "read": "read",
        "update": "update",
    },
)
class IothubDpsSharedAccessPolicyTimeouts:
    def __init__(
        self,
        *,
        create: typing.Optional[builtins.str] = None,
        delete: typing.Optional[builtins.str] = None,
        read: typing.Optional[builtins.str] = None,
        update: typing.Optional[builtins.str] = None,
    ) -> None:
        """
        :param create: 
        :param delete: 
        :param read: 
        :param update: 
        """
        self._values: typing.Dict[str, typing.Any] = {}
        if create is not None:
            self._values["create"] = create
        if delete is not None:
            self._values["delete"] = delete
        if read is not None:
            self._values["read"] = read
        if update is not None:
            self._values["update"] = update

    @builtins.property
    def create(self) -> typing.Optional[builtins.str]:
        result = self._values.get("create")
        return result

    @builtins.property
    def delete(self) -> typing.Optional[builtins.str]:
        result = self._values.get("delete")
        return result

    @builtins.property
    def read(self) -> typing.Optional[builtins.str]:
        result = self._values.get("read")
        return result

    @builtins.property
    def update(self) -> typing.Optional[builtins.str]:
        result = self._values.get("update")
        return result

    def __eq__(self, rhs: typing.Any) -> builtins.bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs: typing.Any) -> builtins.bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return "IothubDpsSharedAccessPolicyTimeouts(%s)" % ", ".join(
            k + "=" + repr(v) for k, v in self._values.items()
        )


@jsii.data_type(
    jsii_type="@cdktf/provider-azurerm.IothubDpsSku",
    jsii_struct_bases=[],
    name_mapping={"capacity": "capacity", "name": "name"},
)
class IothubDpsSku:
    def __init__(self, *, capacity: jsii.Number, name: builtins.str) -> None:
        """
        :param capacity: 
        :param name: 
        """
        self._values: typing.Dict[str, typing.Any] = {
            "capacity": capacity,
            "name": name,
        }

    @builtins.property
    def capacity(self) -> jsii.Number:
        result = self._values.get("capacity")
        assert result is not None, "Required property 'capacity' is missing"
        return result

    @builtins.property
    def name(self) -> builtins.str:
        result = self._values.get("name")
        assert result is not None, "Required property 'name' is missing"
        return result

    def __eq__(self, rhs: typing.Any) -> builtins.bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs: typing.Any) -> builtins.bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return "IothubDpsSku(%s)" % ", ".join(
            k + "=" + repr(v) for k, v in self._values.items()
        )


@jsii.data_type(
    jsii_type="@cdktf/provider-azurerm.IothubDpsTimeouts",
    jsii_struct_bases=[],
    name_mapping={
        "create": "create",
        "delete": "delete",
        "read": "read",
        "update": "update",
    },
)
class IothubDpsTimeouts:
    def __init__(
        self,
        *,
        create: typing.Optional[builtins.str] = None,
        delete: typing.Optional[builtins.str] = None,
        read: typing.Optional[builtins.str] = None,
        update: typing.Optional[builtins.str] = None,
    ) -> None:
        """
        :param create: 
        :param delete: 
        :param read: 
        :param update: 
        """
        self._values: typing.Dict[str, typing.Any] = {}
        if create is not None:
            self._values["create"] = create
        if delete is not None:
            self._values["delete"] = delete
        if read is not None:
            self._values["read"] = read
        if update is not None:
            self._values["update"] = update

    @builtins.property
    def create(self) -> typing.Optional[builtins.str]:
        result = self._values.get("create")
        return result

    @builtins.property
    def delete(self) -> typing.Optional[builtins.str]:
        result = self._values.get("delete")
        return result

    @builtins.property
    def read(self) -> typing.Optional[builtins.str]:
        result = self._values.get("read")
        return result

    @builtins.property
    def update(self) -> typing.Optional[builtins.str]:
        result = self._values.get("update")
        return result

    def __eq__(self, rhs: typing.Any) -> builtins.bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs: typing.Any) -> builtins.bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return "IothubDpsTimeouts(%s)" % ", ".join(
            k + "=" + repr(v) for k, v in self._values.items()
        )


@jsii.data_type(
    jsii_type="@cdktf/provider-azurerm.IothubEndpoint",
    jsii_struct_bases=[],
    name_mapping={
        "connection_string": "connectionString",
        "name": "name",
        "type": "type",
        "batch_frequency_in_seconds": "batchFrequencyInSeconds",
        "container_name": "containerName",
        "encoding": "encoding",
        "file_name_format": "fileNameFormat",
        "max_chunk_size_in_bytes": "maxChunkSizeInBytes",
    },
)
class IothubEndpoint:
    def __init__(
        self,
        *,
        connection_string: builtins.str,
        name: builtins.str,
        type: builtins.str,
        batch_frequency_in_seconds: typing.Optional[jsii.Number] = None,
        container_name: typing.Optional[builtins.str] = None,
        encoding: typing.Optional[builtins.str] = None,
        file_name_format: typing.Optional[builtins.str] = None,
        max_chunk_size_in_bytes: typing.Optional[jsii.Number] = None,
    ) -> None:
        """
        :param connection_string: 
        :param name: 
        :param type: 
        :param batch_frequency_in_seconds: 
        :param container_name: 
        :param encoding: 
        :param file_name_format: 
        :param max_chunk_size_in_bytes: 
        """
        self._values: typing.Dict[str, typing.Any] = {
            "connection_string": connection_string,
            "name": name,
            "type": type,
        }
        if batch_frequency_in_seconds is not None:
            self._values["batch_frequency_in_seconds"] = batch_frequency_in_seconds
        if container_name is not None:
            self._values["container_name"] = container_name
        if encoding is not None:
            self._values["encoding"] = encoding
        if file_name_format is not None:
            self._values["file_name_format"] = file_name_format
        if max_chunk_size_in_bytes is not None:
            self._values["max_chunk_size_in_bytes"] = max_chunk_size_in_bytes

    @builtins.property
    def connection_string(self) -> builtins.str:
        result = self._values.get("connection_string")
        assert result is not None, "Required property 'connection_string' is missing"
        return result

    @builtins.property
    def name(self) -> builtins.str:
        result = self._values.get("name")
        assert result is not None, "Required property 'name' is missing"
        return result

    @builtins.property
    def type(self) -> builtins.str:
        result = self._values.get("type")
        assert result is not None, "Required property 'type' is missing"
        return result

    @builtins.property
    def batch_frequency_in_seconds(self) -> typing.Optional[jsii.Number]:
        result = self._values.get("batch_frequency_in_seconds")
        return result

    @builtins.property
    def container_name(self) -> typing.Optional[builtins.str]:
        result = self._values.get("container_name")
        return result

    @builtins.property
    def encoding(self) -> typing.Optional[builtins.str]:
        result = self._values.get("encoding")
        return result

    @builtins.property
    def file_name_format(self) -> typing.Optional[builtins.str]:
        result = self._values.get("file_name_format")
        return result

    @builtins.property
    def max_chunk_size_in_bytes(self) -> typing.Optional[jsii.Number]:
        result = self._values.get("max_chunk_size_in_bytes")
        return result

    def __eq__(self, rhs: typing.Any) -> builtins.bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs: typing.Any) -> builtins.bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return "IothubEndpoint(%s)" % ", ".join(
            k + "=" + repr(v) for k, v in self._values.items()
        )


class IothubEndpointEventhub(
    cdktf.TerraformResource,
    metaclass=jsii.JSIIMeta,
    jsii_type="@cdktf/provider-azurerm.IothubEndpointEventhub",
):
    def __init__(
        self,
        scope: constructs.Construct,
        id: builtins.str,
        *,
        connection_string: builtins.str,
        iothub_name: builtins.str,
        name: builtins.str,
        resource_group_name: builtins.str,
        timeouts: typing.Optional["IothubEndpointEventhubTimeouts"] = None,
        count: typing.Optional[jsii.Number] = None,
        depends_on: typing.Optional[typing.List[cdktf.TerraformResource]] = None,
        lifecycle: typing.Optional[cdktf.TerraformResourceLifecycle] = None,
        provider: typing.Optional[cdktf.TerraformProvider] = None,
    ) -> None:
        """
        :param scope: -
        :param id: -
        :param connection_string: 
        :param iothub_name: 
        :param name: 
        :param resource_group_name: 
        :param timeouts: timeouts block.
        :param count: 
        :param depends_on: 
        :param lifecycle: 
        :param provider: 
        """
        config = IothubEndpointEventhubConfig(
            connection_string=connection_string,
            iothub_name=iothub_name,
            name=name,
            resource_group_name=resource_group_name,
            timeouts=timeouts,
            count=count,
            depends_on=depends_on,
            lifecycle=lifecycle,
            provider=provider,
        )

        jsii.create(IothubEndpointEventhub, self, [scope, id, config])

    @jsii.member(jsii_name="synthesizeAttributes")
    def _synthesize_attributes(self) -> typing.Mapping[builtins.str, typing.Any]:
        return jsii.invoke(self, "synthesizeAttributes", [])

    @builtins.property # type: ignore
    @jsii.member(jsii_name="connectionString")
    def connection_string(self) -> builtins.str:
        return jsii.get(self, "connectionString")

    @connection_string.setter # type: ignore
    def connection_string(self, value: builtins.str) -> None:
        jsii.set(self, "connectionString", value)

    @builtins.property # type: ignore
    @jsii.member(jsii_name="iothubName")
    def iothub_name(self) -> builtins.str:
        return jsii.get(self, "iothubName")

    @iothub_name.setter # type: ignore
    def iothub_name(self, value: builtins.str) -> None:
        jsii.set(self, "iothubName", value)

    @builtins.property # type: ignore
    @jsii.member(jsii_name="name")
    def name(self) -> builtins.str:
        return jsii.get(self, "name")

    @name.setter # type: ignore
    def name(self, value: builtins.str) -> None:
        jsii.set(self, "name", value)

    @builtins.property # type: ignore
    @jsii.member(jsii_name="resourceGroupName")
    def resource_group_name(self) -> builtins.str:
        return jsii.get(self, "resourceGroupName")

    @resource_group_name.setter # type: ignore
    def resource_group_name(self, value: builtins.str) -> None:
        jsii.set(self, "resourceGroupName", value)

    @builtins.property # type: ignore
    @jsii.member(jsii_name="id")
    def id(self) -> typing.Optional[builtins.str]:
        return jsii.get(self, "id")

    @id.setter # type: ignore
    def id(self, value: typing.Optional[builtins.str]) -> None:
        jsii.set(self, "id", value)

    @builtins.property # type: ignore
    @jsii.member(jsii_name="timeouts")
    def timeouts(self) -> typing.Optional["IothubEndpointEventhubTimeouts"]:
        return jsii.get(self, "timeouts")

    @timeouts.setter # type: ignore
    def timeouts(
        self,
        value: typing.Optional["IothubEndpointEventhubTimeouts"],
    ) -> None:
        jsii.set(self, "timeouts", value)


@jsii.data_type(
    jsii_type="@cdktf/provider-azurerm.IothubEndpointEventhubConfig",
    jsii_struct_bases=[cdktf.TerraformMetaArguments],
    name_mapping={
        "count": "count",
        "depends_on": "dependsOn",
        "lifecycle": "lifecycle",
        "provider": "provider",
        "connection_string": "connectionString",
        "iothub_name": "iothubName",
        "name": "name",
        "resource_group_name": "resourceGroupName",
        "timeouts": "timeouts",
    },
)
class IothubEndpointEventhubConfig(cdktf.TerraformMetaArguments):
    def __init__(
        self,
        *,
        count: typing.Optional[jsii.Number] = None,
        depends_on: typing.Optional[typing.List[cdktf.TerraformResource]] = None,
        lifecycle: typing.Optional[cdktf.TerraformResourceLifecycle] = None,
        provider: typing.Optional[cdktf.TerraformProvider] = None,
        connection_string: builtins.str,
        iothub_name: builtins.str,
        name: builtins.str,
        resource_group_name: builtins.str,
        timeouts: typing.Optional["IothubEndpointEventhubTimeouts"] = None,
    ) -> None:
        """
        :param count: 
        :param depends_on: 
        :param lifecycle: 
        :param provider: 
        :param connection_string: 
        :param iothub_name: 
        :param name: 
        :param resource_group_name: 
        :param timeouts: timeouts block.
        """
        if isinstance(lifecycle, dict):
            lifecycle = cdktf.TerraformResourceLifecycle(**lifecycle)
        if isinstance(timeouts, dict):
            timeouts = IothubEndpointEventhubTimeouts(**timeouts)
        self._values: typing.Dict[str, typing.Any] = {
            "connection_string": connection_string,
            "iothub_name": iothub_name,
            "name": name,
            "resource_group_name": resource_group_name,
        }
        if count is not None:
            self._values["count"] = count
        if depends_on is not None:
            self._values["depends_on"] = depends_on
        if lifecycle is not None:
            self._values["lifecycle"] = lifecycle
        if provider is not None:
            self._values["provider"] = provider
        if timeouts is not None:
            self._values["timeouts"] = timeouts

    @builtins.property
    def count(self) -> typing.Optional[jsii.Number]:
        """
        :stability: experimental
        """
        result = self._values.get("count")
        return result

    @builtins.property
    def depends_on(self) -> typing.Optional[typing.List[cdktf.TerraformResource]]:
        """
        :stability: experimental
        """
        result = self._values.get("depends_on")
        return result

    @builtins.property
    def lifecycle(self) -> typing.Optional[cdktf.TerraformResourceLifecycle]:
        """
        :stability: experimental
        """
        result = self._values.get("lifecycle")
        return result

    @builtins.property
    def provider(self) -> typing.Optional[cdktf.TerraformProvider]:
        """
        :stability: experimental
        """
        result = self._values.get("provider")
        return result

    @builtins.property
    def connection_string(self) -> builtins.str:
        result = self._values.get("connection_string")
        assert result is not None, "Required property 'connection_string' is missing"
        return result

    @builtins.property
    def iothub_name(self) -> builtins.str:
        result = self._values.get("iothub_name")
        assert result is not None, "Required property 'iothub_name' is missing"
        return result

    @builtins.property
    def name(self) -> builtins.str:
        result = self._values.get("name")
        assert result is not None, "Required property 'name' is missing"
        return result

    @builtins.property
    def resource_group_name(self) -> builtins.str:
        result = self._values.get("resource_group_name")
        assert result is not None, "Required property 'resource_group_name' is missing"
        return result

    @builtins.property
    def timeouts(self) -> typing.Optional["IothubEndpointEventhubTimeouts"]:
        """timeouts block."""
        result = self._values.get("timeouts")
        return result

    def __eq__(self, rhs: typing.Any) -> builtins.bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs: typing.Any) -> builtins.bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return "IothubEndpointEventhubConfig(%s)" % ", ".join(
            k + "=" + repr(v) for k, v in self._values.items()
        )


@jsii.data_type(
    jsii_type="@cdktf/provider-azurerm.IothubEndpointEventhubTimeouts",
    jsii_struct_bases=[],
    name_mapping={
        "create": "create",
        "delete": "delete",
        "read": "read",
        "update": "update",
    },
)
class IothubEndpointEventhubTimeouts:
    def __init__(
        self,
        *,
        create: typing.Optional[builtins.str] = None,
        delete: typing.Optional[builtins.str] = None,
        read: typing.Optional[builtins.str] = None,
        update: typing.Optional[builtins.str] = None,
    ) -> None:
        """
        :param create: 
        :param delete: 
        :param read: 
        :param update: 
        """
        self._values: typing.Dict[str, typing.Any] = {}
        if create is not None:
            self._values["create"] = create
        if delete is not None:
            self._values["delete"] = delete
        if read is not None:
            self._values["read"] = read
        if update is not None:
            self._values["update"] = update

    @builtins.property
    def create(self) -> typing.Optional[builtins.str]:
        result = self._values.get("create")
        return result

    @builtins.property
    def delete(self) -> typing.Optional[builtins.str]:
        result = self._values.get("delete")
        return result

    @builtins.property
    def read(self) -> typing.Optional[builtins.str]:
        result = self._values.get("read")
        return result

    @builtins.property
    def update(self) -> typing.Optional[builtins.str]:
        result = self._values.get("update")
        return result

    def __eq__(self, rhs: typing.Any) -> builtins.bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs: typing.Any) -> builtins.bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return "IothubEndpointEventhubTimeouts(%s)" % ", ".join(
            k + "=" + repr(v) for k, v in self._values.items()
        )


class IothubEndpointServicebusQueue(
    cdktf.TerraformResource,
    metaclass=jsii.JSIIMeta,
    jsii_type="@cdktf/provider-azurerm.IothubEndpointServicebusQueue",
):
    def __init__(
        self,
        scope: constructs.Construct,
        id: builtins.str,
        *,
        connection_string: builtins.str,
        iothub_name: builtins.str,
        name: builtins.str,
        resource_group_name: builtins.str,
        timeouts: typing.Optional["IothubEndpointServicebusQueueTimeouts"] = None,
        count: typing.Optional[jsii.Number] = None,
        depends_on: typing.Optional[typing.List[cdktf.TerraformResource]] = None,
        lifecycle: typing.Optional[cdktf.TerraformResourceLifecycle] = None,
        provider: typing.Optional[cdktf.TerraformProvider] = None,
    ) -> None:
        """
        :param scope: -
        :param id: -
        :param connection_string: 
        :param iothub_name: 
        :param name: 
        :param resource_group_name: 
        :param timeouts: timeouts block.
        :param count: 
        :param depends_on: 
        :param lifecycle: 
        :param provider: 
        """
        config = IothubEndpointServicebusQueueConfig(
            connection_string=connection_string,
            iothub_name=iothub_name,
            name=name,
            resource_group_name=resource_group_name,
            timeouts=timeouts,
            count=count,
            depends_on=depends_on,
            lifecycle=lifecycle,
            provider=provider,
        )

        jsii.create(IothubEndpointServicebusQueue, self, [scope, id, config])

    @jsii.member(jsii_name="synthesizeAttributes")
    def _synthesize_attributes(self) -> typing.Mapping[builtins.str, typing.Any]:
        return jsii.invoke(self, "synthesizeAttributes", [])

    @builtins.property # type: ignore
    @jsii.member(jsii_name="connectionString")
    def connection_string(self) -> builtins.str:
        return jsii.get(self, "connectionString")

    @connection_string.setter # type: ignore
    def connection_string(self, value: builtins.str) -> None:
        jsii.set(self, "connectionString", value)

    @builtins.property # type: ignore
    @jsii.member(jsii_name="iothubName")
    def iothub_name(self) -> builtins.str:
        return jsii.get(self, "iothubName")

    @iothub_name.setter # type: ignore
    def iothub_name(self, value: builtins.str) -> None:
        jsii.set(self, "iothubName", value)

    @builtins.property # type: ignore
    @jsii.member(jsii_name="name")
    def name(self) -> builtins.str:
        return jsii.get(self, "name")

    @name.setter # type: ignore
    def name(self, value: builtins.str) -> None:
        jsii.set(self, "name", value)

    @builtins.property # type: ignore
    @jsii.member(jsii_name="resourceGroupName")
    def resource_group_name(self) -> builtins.str:
        return jsii.get(self, "resourceGroupName")

    @resource_group_name.setter # type: ignore
    def resource_group_name(self, value: builtins.str) -> None:
        jsii.set(self, "resourceGroupName", value)

    @builtins.property # type: ignore
    @jsii.member(jsii_name="id")
    def id(self) -> typing.Optional[builtins.str]:
        return jsii.get(self, "id")

    @id.setter # type: ignore
    def id(self, value: typing.Optional[builtins.str]) -> None:
        jsii.set(self, "id", value)

    @builtins.property # type: ignore
    @jsii.member(jsii_name="timeouts")
    def timeouts(self) -> typing.Optional["IothubEndpointServicebusQueueTimeouts"]:
        return jsii.get(self, "timeouts")

    @timeouts.setter # type: ignore
    def timeouts(
        self,
        value: typing.Optional["IothubEndpointServicebusQueueTimeouts"],
    ) -> None:
        jsii.set(self, "timeouts", value)


@jsii.data_type(
    jsii_type="@cdktf/provider-azurerm.IothubEndpointServicebusQueueConfig",
    jsii_struct_bases=[cdktf.TerraformMetaArguments],
    name_mapping={
        "count": "count",
        "depends_on": "dependsOn",
        "lifecycle": "lifecycle",
        "provider": "provider",
        "connection_string": "connectionString",
        "iothub_name": "iothubName",
        "name": "name",
        "resource_group_name": "resourceGroupName",
        "timeouts": "timeouts",
    },
)
class IothubEndpointServicebusQueueConfig(cdktf.TerraformMetaArguments):
    def __init__(
        self,
        *,
        count: typing.Optional[jsii.Number] = None,
        depends_on: typing.Optional[typing.List[cdktf.TerraformResource]] = None,
        lifecycle: typing.Optional[cdktf.TerraformResourceLifecycle] = None,
        provider: typing.Optional[cdktf.TerraformProvider] = None,
        connection_string: builtins.str,
        iothub_name: builtins.str,
        name: builtins.str,
        resource_group_name: builtins.str,
        timeouts: typing.Optional["IothubEndpointServicebusQueueTimeouts"] = None,
    ) -> None:
        """
        :param count: 
        :param depends_on: 
        :param lifecycle: 
        :param provider: 
        :param connection_string: 
        :param iothub_name: 
        :param name: 
        :param resource_group_name: 
        :param timeouts: timeouts block.
        """
        if isinstance(lifecycle, dict):
            lifecycle = cdktf.TerraformResourceLifecycle(**lifecycle)
        if isinstance(timeouts, dict):
            timeouts = IothubEndpointServicebusQueueTimeouts(**timeouts)
        self._values: typing.Dict[str, typing.Any] = {
            "connection_string": connection_string,
            "iothub_name": iothub_name,
            "name": name,
            "resource_group_name": resource_group_name,
        }
        if count is not None:
            self._values["count"] = count
        if depends_on is not None:
            self._values["depends_on"] = depends_on
        if lifecycle is not None:
            self._values["lifecycle"] = lifecycle
        if provider is not None:
            self._values["provider"] = provider
        if timeouts is not None:
            self._values["timeouts"] = timeouts

    @builtins.property
    def count(self) -> typing.Optional[jsii.Number]:
        """
        :stability: experimental
        """
        result = self._values.get("count")
        return result

    @builtins.property
    def depends_on(self) -> typing.Optional[typing.List[cdktf.TerraformResource]]:
        """
        :stability: experimental
        """
        result = self._values.get("depends_on")
        return result

    @builtins.property
    def lifecycle(self) -> typing.Optional[cdktf.TerraformResourceLifecycle]:
        """
        :stability: experimental
        """
        result = self._values.get("lifecycle")
        return result

    @builtins.property
    def provider(self) -> typing.Optional[cdktf.TerraformProvider]:
        """
        :stability: experimental
        """
        result = self._values.get("provider")
        return result

    @builtins.property
    def connection_string(self) -> builtins.str:
        result = self._values.get("connection_string")
        assert result is not None, "Required property 'connection_string' is missing"
        return result

    @builtins.property
    def iothub_name(self) -> builtins.str:
        result = self._values.get("iothub_name")
        assert result is not None, "Required property 'iothub_name' is missing"
        return result

    @builtins.property
    def name(self) -> builtins.str:
        result = self._values.get("name")
        assert result is not None, "Required property 'name' is missing"
        return result

    @builtins.property
    def resource_group_name(self) -> builtins.str:
        result = self._values.get("resource_group_name")
        assert result is not None, "Required property 'resource_group_name' is missing"
        return result

    @builtins.property
    def timeouts(self) -> typing.Optional["IothubEndpointServicebusQueueTimeouts"]:
        """timeouts block."""
        result = self._values.get("timeouts")
        return result

    def __eq__(self, rhs: typing.Any) -> builtins.bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs: typing.Any) -> builtins.bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return "IothubEndpointServicebusQueueConfig(%s)" % ", ".join(
            k + "=" + repr(v) for k, v in self._values.items()
        )


@jsii.data_type(
    jsii_type="@cdktf/provider-azurerm.IothubEndpointServicebusQueueTimeouts",
    jsii_struct_bases=[],
    name_mapping={
        "create": "create",
        "delete": "delete",
        "read": "read",
        "update": "update",
    },
)
class IothubEndpointServicebusQueueTimeouts:
    def __init__(
        self,
        *,
        create: typing.Optional[builtins.str] = None,
        delete: typing.Optional[builtins.str] = None,
        read: typing.Optional[builtins.str] = None,
        update: typing.Optional[builtins.str] = None,
    ) -> None:
        """
        :param create: 
        :param delete: 
        :param read: 
        :param update: 
        """
        self._values: typing.Dict[str, typing.Any] = {}
        if create is not None:
            self._values["create"] = create
        if delete is not None:
            self._values["delete"] = delete
        if read is not None:
            self._values["read"] = read
        if update is not None:
            self._values["update"] = update

    @builtins.property
    def create(self) -> typing.Optional[builtins.str]:
        result = self._values.get("create")
        return result

    @builtins.property
    def delete(self) -> typing.Optional[builtins.str]:
        result = self._values.get("delete")
        return result

    @builtins.property
    def read(self) -> typing.Optional[builtins.str]:
        result = self._values.get("read")
        return result

    @builtins.property
    def update(self) -> typing.Optional[builtins.str]:
        result = self._values.get("update")
        return result

    def __eq__(self, rhs: typing.Any) -> builtins.bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs: typing.Any) -> builtins.bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return "IothubEndpointServicebusQueueTimeouts(%s)" % ", ".join(
            k + "=" + repr(v) for k, v in self._values.items()
        )


class IothubEndpointServicebusTopic(
    cdktf.TerraformResource,
    metaclass=jsii.JSIIMeta,
    jsii_type="@cdktf/provider-azurerm.IothubEndpointServicebusTopic",
):
    def __init__(
        self,
        scope: constructs.Construct,
        id: builtins.str,
        *,
        connection_string: builtins.str,
        iothub_name: builtins.str,
        name: builtins.str,
        resource_group_name: builtins.str,
        timeouts: typing.Optional["IothubEndpointServicebusTopicTimeouts"] = None,
        count: typing.Optional[jsii.Number] = None,
        depends_on: typing.Optional[typing.List[cdktf.TerraformResource]] = None,
        lifecycle: typing.Optional[cdktf.TerraformResourceLifecycle] = None,
        provider: typing.Optional[cdktf.TerraformProvider] = None,
    ) -> None:
        """
        :param scope: -
        :param id: -
        :param connection_string: 
        :param iothub_name: 
        :param name: 
        :param resource_group_name: 
        :param timeouts: timeouts block.
        :param count: 
        :param depends_on: 
        :param lifecycle: 
        :param provider: 
        """
        config = IothubEndpointServicebusTopicConfig(
            connection_string=connection_string,
            iothub_name=iothub_name,
            name=name,
            resource_group_name=resource_group_name,
            timeouts=timeouts,
            count=count,
            depends_on=depends_on,
            lifecycle=lifecycle,
            provider=provider,
        )

        jsii.create(IothubEndpointServicebusTopic, self, [scope, id, config])

    @jsii.member(jsii_name="synthesizeAttributes")
    def _synthesize_attributes(self) -> typing.Mapping[builtins.str, typing.Any]:
        return jsii.invoke(self, "synthesizeAttributes", [])

    @builtins.property # type: ignore
    @jsii.member(jsii_name="connectionString")
    def connection_string(self) -> builtins.str:
        return jsii.get(self, "connectionString")

    @connection_string.setter # type: ignore
    def connection_string(self, value: builtins.str) -> None:
        jsii.set(self, "connectionString", value)

    @builtins.property # type: ignore
    @jsii.member(jsii_name="iothubName")
    def iothub_name(self) -> builtins.str:
        return jsii.get(self, "iothubName")

    @iothub_name.setter # type: ignore
    def iothub_name(self, value: builtins.str) -> None:
        jsii.set(self, "iothubName", value)

    @builtins.property # type: ignore
    @jsii.member(jsii_name="name")
    def name(self) -> builtins.str:
        return jsii.get(self, "name")

    @name.setter # type: ignore
    def name(self, value: builtins.str) -> None:
        jsii.set(self, "name", value)

    @builtins.property # type: ignore
    @jsii.member(jsii_name="resourceGroupName")
    def resource_group_name(self) -> builtins.str:
        return jsii.get(self, "resourceGroupName")

    @resource_group_name.setter # type: ignore
    def resource_group_name(self, value: builtins.str) -> None:
        jsii.set(self, "resourceGroupName", value)

    @builtins.property # type: ignore
    @jsii.member(jsii_name="id")
    def id(self) -> typing.Optional[builtins.str]:
        return jsii.get(self, "id")

    @id.setter # type: ignore
    def id(self, value: typing.Optional[builtins.str]) -> None:
        jsii.set(self, "id", value)

    @builtins.property # type: ignore
    @jsii.member(jsii_name="timeouts")
    def timeouts(self) -> typing.Optional["IothubEndpointServicebusTopicTimeouts"]:
        return jsii.get(self, "timeouts")

    @timeouts.setter # type: ignore
    def timeouts(
        self,
        value: typing.Optional["IothubEndpointServicebusTopicTimeouts"],
    ) -> None:
        jsii.set(self, "timeouts", value)


@jsii.data_type(
    jsii_type="@cdktf/provider-azurerm.IothubEndpointServicebusTopicConfig",
    jsii_struct_bases=[cdktf.TerraformMetaArguments],
    name_mapping={
        "count": "count",
        "depends_on": "dependsOn",
        "lifecycle": "lifecycle",
        "provider": "provider",
        "connection_string": "connectionString",
        "iothub_name": "iothubName",
        "name": "name",
        "resource_group_name": "resourceGroupName",
        "timeouts": "timeouts",
    },
)
class IothubEndpointServicebusTopicConfig(cdktf.TerraformMetaArguments):
    def __init__(
        self,
        *,
        count: typing.Optional[jsii.Number] = None,
        depends_on: typing.Optional[typing.List[cdktf.TerraformResource]] = None,
        lifecycle: typing.Optional[cdktf.TerraformResourceLifecycle] = None,
        provider: typing.Optional[cdktf.TerraformProvider] = None,
        connection_string: builtins.str,
        iothub_name: builtins.str,
        name: builtins.str,
        resource_group_name: builtins.str,
        timeouts: typing.Optional["IothubEndpointServicebusTopicTimeouts"] = None,
    ) -> None:
        """
        :param count: 
        :param depends_on: 
        :param lifecycle: 
        :param provider: 
        :param connection_string: 
        :param iothub_name: 
        :param name: 
        :param resource_group_name: 
        :param timeouts: timeouts block.
        """
        if isinstance(lifecycle, dict):
            lifecycle = cdktf.TerraformResourceLifecycle(**lifecycle)
        if isinstance(timeouts, dict):
            timeouts = IothubEndpointServicebusTopicTimeouts(**timeouts)
        self._values: typing.Dict[str, typing.Any] = {
            "connection_string": connection_string,
            "iothub_name": iothub_name,
            "name": name,
            "resource_group_name": resource_group_name,
        }
        if count is not None:
            self._values["count"] = count
        if depends_on is not None:
            self._values["depends_on"] = depends_on
        if lifecycle is not None:
            self._values["lifecycle"] = lifecycle
        if provider is not None:
            self._values["provider"] = provider
        if timeouts is not None:
            self._values["timeouts"] = timeouts

    @builtins.property
    def count(self) -> typing.Optional[jsii.Number]:
        """
        :stability: experimental
        """
        result = self._values.get("count")
        return result

    @builtins.property
    def depends_on(self) -> typing.Optional[typing.List[cdktf.TerraformResource]]:
        """
        :stability: experimental
        """
        result = self._values.get("depends_on")
        return result

    @builtins.property
    def lifecycle(self) -> typing.Optional[cdktf.TerraformResourceLifecycle]:
        """
        :stability: experimental
        """
        result = self._values.get("lifecycle")
        return result

    @builtins.property
    def provider(self) -> typing.Optional[cdktf.TerraformProvider]:
        """
        :stability: experimental
        """
        result = self._values.get("provider")
        return result

    @builtins.property
    def connection_string(self) -> builtins.str:
        result = self._values.get("connection_string")
        assert result is not None, "Required property 'connection_string' is missing"
        return result

    @builtins.property
    def iothub_name(self) -> builtins.str:
        result = self._values.get("iothub_name")
        assert result is not None, "Required property 'iothub_name' is missing"
        return result

    @builtins.property
    def name(self) -> builtins.str:
        result = self._values.get("name")
        assert result is not None, "Required property 'name' is missing"
        return result

    @builtins.property
    def resource_group_name(self) -> builtins.str:
        result = self._values.get("resource_group_name")
        assert result is not None, "Required property 'resource_group_name' is missing"
        return result

    @builtins.property
    def timeouts(self) -> typing.Optional["IothubEndpointServicebusTopicTimeouts"]:
        """timeouts block."""
        result = self._values.get("timeouts")
        return result

    def __eq__(self, rhs: typing.Any) -> builtins.bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs: typing.Any) -> builtins.bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return "IothubEndpointServicebusTopicConfig(%s)" % ", ".join(
            k + "=" + repr(v) for k, v in self._values.items()
        )


@jsii.data_type(
    jsii_type="@cdktf/provider-azurerm.IothubEndpointServicebusTopicTimeouts",
    jsii_struct_bases=[],
    name_mapping={
        "create": "create",
        "delete": "delete",
        "read": "read",
        "update": "update",
    },
)
class IothubEndpointServicebusTopicTimeouts:
    def __init__(
        self,
        *,
        create: typing.Optional[builtins.str] = None,
        delete: typing.Optional[builtins.str] = None,
        read: typing.Optional[builtins.str] = None,
        update: typing.Optional[builtins.str] = None,
    ) -> None:
        """
        :param create: 
        :param delete: 
        :param read: 
        :param update: 
        """
        self._values: typing.Dict[str, typing.Any] = {}
        if create is not None:
            self._values["create"] = create
        if delete is not None:
            self._values["delete"] = delete
        if read is not None:
            self._values["read"] = read
        if update is not None:
            self._values["update"] = update

    @builtins.property
    def create(self) -> typing.Optional[builtins.str]:
        result = self._values.get("create")
        return result

    @builtins.property
    def delete(self) -> typing.Optional[builtins.str]:
        result = self._values.get("delete")
        return result

    @builtins.property
    def read(self) -> typing.Optional[builtins.str]:
        result = self._values.get("read")
        return result

    @builtins.property
    def update(self) -> typing.Optional[builtins.str]:
        result = self._values.get("update")
        return result

    def __eq__(self, rhs: typing.Any) -> builtins.bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs: typing.Any) -> builtins.bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return "IothubEndpointServicebusTopicTimeouts(%s)" % ", ".join(
            k + "=" + repr(v) for k, v in self._values.items()
        )


class IothubEndpointStorageContainer(
    cdktf.TerraformResource,
    metaclass=jsii.JSIIMeta,
    jsii_type="@cdktf/provider-azurerm.IothubEndpointStorageContainer",
):
    def __init__(
        self,
        scope: constructs.Construct,
        id: builtins.str,
        *,
        connection_string: builtins.str,
        container_name: builtins.str,
        iothub_name: builtins.str,
        name: builtins.str,
        resource_group_name: builtins.str,
        batch_frequency_in_seconds: typing.Optional[jsii.Number] = None,
        encoding: typing.Optional[builtins.str] = None,
        file_name_format: typing.Optional[builtins.str] = None,
        max_chunk_size_in_bytes: typing.Optional[jsii.Number] = None,
        timeouts: typing.Optional["IothubEndpointStorageContainerTimeouts"] = None,
        count: typing.Optional[jsii.Number] = None,
        depends_on: typing.Optional[typing.List[cdktf.TerraformResource]] = None,
        lifecycle: typing.Optional[cdktf.TerraformResourceLifecycle] = None,
        provider: typing.Optional[cdktf.TerraformProvider] = None,
    ) -> None:
        """
        :param scope: -
        :param id: -
        :param connection_string: 
        :param container_name: 
        :param iothub_name: 
        :param name: 
        :param resource_group_name: 
        :param batch_frequency_in_seconds: 
        :param encoding: 
        :param file_name_format: 
        :param max_chunk_size_in_bytes: 
        :param timeouts: timeouts block.
        :param count: 
        :param depends_on: 
        :param lifecycle: 
        :param provider: 
        """
        config = IothubEndpointStorageContainerConfig(
            connection_string=connection_string,
            container_name=container_name,
            iothub_name=iothub_name,
            name=name,
            resource_group_name=resource_group_name,
            batch_frequency_in_seconds=batch_frequency_in_seconds,
            encoding=encoding,
            file_name_format=file_name_format,
            max_chunk_size_in_bytes=max_chunk_size_in_bytes,
            timeouts=timeouts,
            count=count,
            depends_on=depends_on,
            lifecycle=lifecycle,
            provider=provider,
        )

        jsii.create(IothubEndpointStorageContainer, self, [scope, id, config])

    @jsii.member(jsii_name="synthesizeAttributes")
    def _synthesize_attributes(self) -> typing.Mapping[builtins.str, typing.Any]:
        return jsii.invoke(self, "synthesizeAttributes", [])

    @builtins.property # type: ignore
    @jsii.member(jsii_name="connectionString")
    def connection_string(self) -> builtins.str:
        return jsii.get(self, "connectionString")

    @connection_string.setter # type: ignore
    def connection_string(self, value: builtins.str) -> None:
        jsii.set(self, "connectionString", value)

    @builtins.property # type: ignore
    @jsii.member(jsii_name="containerName")
    def container_name(self) -> builtins.str:
        return jsii.get(self, "containerName")

    @container_name.setter # type: ignore
    def container_name(self, value: builtins.str) -> None:
        jsii.set(self, "containerName", value)

    @builtins.property # type: ignore
    @jsii.member(jsii_name="iothubName")
    def iothub_name(self) -> builtins.str:
        return jsii.get(self, "iothubName")

    @iothub_name.setter # type: ignore
    def iothub_name(self, value: builtins.str) -> None:
        jsii.set(self, "iothubName", value)

    @builtins.property # type: ignore
    @jsii.member(jsii_name="name")
    def name(self) -> builtins.str:
        return jsii.get(self, "name")

    @name.setter # type: ignore
    def name(self, value: builtins.str) -> None:
        jsii.set(self, "name", value)

    @builtins.property # type: ignore
    @jsii.member(jsii_name="resourceGroupName")
    def resource_group_name(self) -> builtins.str:
        return jsii.get(self, "resourceGroupName")

    @resource_group_name.setter # type: ignore
    def resource_group_name(self, value: builtins.str) -> None:
        jsii.set(self, "resourceGroupName", value)

    @builtins.property # type: ignore
    @jsii.member(jsii_name="batchFrequencyInSeconds")
    def batch_frequency_in_seconds(self) -> typing.Optional[jsii.Number]:
        return jsii.get(self, "batchFrequencyInSeconds")

    @batch_frequency_in_seconds.setter # type: ignore
    def batch_frequency_in_seconds(self, value: typing.Optional[jsii.Number]) -> None:
        jsii.set(self, "batchFrequencyInSeconds", value)

    @builtins.property # type: ignore
    @jsii.member(jsii_name="encoding")
    def encoding(self) -> typing.Optional[builtins.str]:
        return jsii.get(self, "encoding")

    @encoding.setter # type: ignore
    def encoding(self, value: typing.Optional[builtins.str]) -> None:
        jsii.set(self, "encoding", value)

    @builtins.property # type: ignore
    @jsii.member(jsii_name="fileNameFormat")
    def file_name_format(self) -> typing.Optional[builtins.str]:
        return jsii.get(self, "fileNameFormat")

    @file_name_format.setter # type: ignore
    def file_name_format(self, value: typing.Optional[builtins.str]) -> None:
        jsii.set(self, "fileNameFormat", value)

    @builtins.property # type: ignore
    @jsii.member(jsii_name="id")
    def id(self) -> typing.Optional[builtins.str]:
        return jsii.get(self, "id")

    @id.setter # type: ignore
    def id(self, value: typing.Optional[builtins.str]) -> None:
        jsii.set(self, "id", value)

    @builtins.property # type: ignore
    @jsii.member(jsii_name="maxChunkSizeInBytes")
    def max_chunk_size_in_bytes(self) -> typing.Optional[jsii.Number]:
        return jsii.get(self, "maxChunkSizeInBytes")

    @max_chunk_size_in_bytes.setter # type: ignore
    def max_chunk_size_in_bytes(self, value: typing.Optional[jsii.Number]) -> None:
        jsii.set(self, "maxChunkSizeInBytes", value)

    @builtins.property # type: ignore
    @jsii.member(jsii_name="timeouts")
    def timeouts(self) -> typing.Optional["IothubEndpointStorageContainerTimeouts"]:
        return jsii.get(self, "timeouts")

    @timeouts.setter # type: ignore
    def timeouts(
        self,
        value: typing.Optional["IothubEndpointStorageContainerTimeouts"],
    ) -> None:
        jsii.set(self, "timeouts", value)


@jsii.data_type(
    jsii_type="@cdktf/provider-azurerm.IothubEndpointStorageContainerConfig",
    jsii_struct_bases=[cdktf.TerraformMetaArguments],
    name_mapping={
        "count": "count",
        "depends_on": "dependsOn",
        "lifecycle": "lifecycle",
        "provider": "provider",
        "connection_string": "connectionString",
        "container_name": "containerName",
        "iothub_name": "iothubName",
        "name": "name",
        "resource_group_name": "resourceGroupName",
        "batch_frequency_in_seconds": "batchFrequencyInSeconds",
        "encoding": "encoding",
        "file_name_format": "fileNameFormat",
        "max_chunk_size_in_bytes": "maxChunkSizeInBytes",
        "timeouts": "timeouts",
    },
)
class IothubEndpointStorageContainerConfig(cdktf.TerraformMetaArguments):
    def __init__(
        self,
        *,
        count: typing.Optional[jsii.Number] = None,
        depends_on: typing.Optional[typing.List[cdktf.TerraformResource]] = None,
        lifecycle: typing.Optional[cdktf.TerraformResourceLifecycle] = None,
        provider: typing.Optional[cdktf.TerraformProvider] = None,
        connection_string: builtins.str,
        container_name: builtins.str,
        iothub_name: builtins.str,
        name: builtins.str,
        resource_group_name: builtins.str,
        batch_frequency_in_seconds: typing.Optional[jsii.Number] = None,
        encoding: typing.Optional[builtins.str] = None,
        file_name_format: typing.Optional[builtins.str] = None,
        max_chunk_size_in_bytes: typing.Optional[jsii.Number] = None,
        timeouts: typing.Optional["IothubEndpointStorageContainerTimeouts"] = None,
    ) -> None:
        """
        :param count: 
        :param depends_on: 
        :param lifecycle: 
        :param provider: 
        :param connection_string: 
        :param container_name: 
        :param iothub_name: 
        :param name: 
        :param resource_group_name: 
        :param batch_frequency_in_seconds: 
        :param encoding: 
        :param file_name_format: 
        :param max_chunk_size_in_bytes: 
        :param timeouts: timeouts block.
        """
        if isinstance(lifecycle, dict):
            lifecycle = cdktf.TerraformResourceLifecycle(**lifecycle)
        if isinstance(timeouts, dict):
            timeouts = IothubEndpointStorageContainerTimeouts(**timeouts)
        self._values: typing.Dict[str, typing.Any] = {
            "connection_string": connection_string,
            "container_name": container_name,
            "iothub_name": iothub_name,
            "name": name,
            "resource_group_name": resource_group_name,
        }
        if count is not None:
            self._values["count"] = count
        if depends_on is not None:
            self._values["depends_on"] = depends_on
        if lifecycle is not None:
            self._values["lifecycle"] = lifecycle
        if provider is not None:
            self._values["provider"] = provider
        if batch_frequency_in_seconds is not None:
            self._values["batch_frequency_in_seconds"] = batch_frequency_in_seconds
        if encoding is not None:
            self._values["encoding"] = encoding
        if file_name_format is not None:
            self._values["file_name_format"] = file_name_format
        if max_chunk_size_in_bytes is not None:
            self._values["max_chunk_size_in_bytes"] = max_chunk_size_in_bytes
        if timeouts is not None:
            self._values["timeouts"] = timeouts

    @builtins.property
    def count(self) -> typing.Optional[jsii.Number]:
        """
        :stability: experimental
        """
        result = self._values.get("count")
        return result

    @builtins.property
    def depends_on(self) -> typing.Optional[typing.List[cdktf.TerraformResource]]:
        """
        :stability: experimental
        """
        result = self._values.get("depends_on")
        return result

    @builtins.property
    def lifecycle(self) -> typing.Optional[cdktf.TerraformResourceLifecycle]:
        """
        :stability: experimental
        """
        result = self._values.get("lifecycle")
        return result

    @builtins.property
    def provider(self) -> typing.Optional[cdktf.TerraformProvider]:
        """
        :stability: experimental
        """
        result = self._values.get("provider")
        return result

    @builtins.property
    def connection_string(self) -> builtins.str:
        result = self._values.get("connection_string")
        assert result is not None, "Required property 'connection_string' is missing"
        return result

    @builtins.property
    def container_name(self) -> builtins.str:
        result = self._values.get("container_name")
        assert result is not None, "Required property 'container_name' is missing"
        return result

    @builtins.property
    def iothub_name(self) -> builtins.str:
        result = self._values.get("iothub_name")
        assert result is not None, "Required property 'iothub_name' is missing"
        return result

    @builtins.property
    def name(self) -> builtins.str:
        result = self._values.get("name")
        assert result is not None, "Required property 'name' is missing"
        return result

    @builtins.property
    def resource_group_name(self) -> builtins.str:
        result = self._values.get("resource_group_name")
        assert result is not None, "Required property 'resource_group_name' is missing"
        return result

    @builtins.property
    def batch_frequency_in_seconds(self) -> typing.Optional[jsii.Number]:
        result = self._values.get("batch_frequency_in_seconds")
        return result

    @builtins.property
    def encoding(self) -> typing.Optional[builtins.str]:
        result = self._values.get("encoding")
        return result

    @builtins.property
    def file_name_format(self) -> typing.Optional[builtins.str]:
        result = self._values.get("file_name_format")
        return result

    @builtins.property
    def max_chunk_size_in_bytes(self) -> typing.Optional[jsii.Number]:
        result = self._values.get("max_chunk_size_in_bytes")
        return result

    @builtins.property
    def timeouts(self) -> typing.Optional["IothubEndpointStorageContainerTimeouts"]:
        """timeouts block."""
        result = self._values.get("timeouts")
        return result

    def __eq__(self, rhs: typing.Any) -> builtins.bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs: typing.Any) -> builtins.bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return "IothubEndpointStorageContainerConfig(%s)" % ", ".join(
            k + "=" + repr(v) for k, v in self._values.items()
        )


@jsii.data_type(
    jsii_type="@cdktf/provider-azurerm.IothubEndpointStorageContainerTimeouts",
    jsii_struct_bases=[],
    name_mapping={
        "create": "create",
        "delete": "delete",
        "read": "read",
        "update": "update",
    },
)
class IothubEndpointStorageContainerTimeouts:
    def __init__(
        self,
        *,
        create: typing.Optional[builtins.str] = None,
        delete: typing.Optional[builtins.str] = None,
        read: typing.Optional[builtins.str] = None,
        update: typing.Optional[builtins.str] = None,
    ) -> None:
        """
        :param create: 
        :param delete: 
        :param read: 
        :param update: 
        """
        self._values: typing.Dict[str, typing.Any] = {}
        if create is not None:
            self._values["create"] = create
        if delete is not None:
            self._values["delete"] = delete
        if read is not None:
            self._values["read"] = read
        if update is not None:
            self._values["update"] = update

    @builtins.property
    def create(self) -> typing.Optional[builtins.str]:
        result = self._values.get("create")
        return result

    @builtins.property
    def delete(self) -> typing.Optional[builtins.str]:
        result = self._values.get("delete")
        return result

    @builtins.property
    def read(self) -> typing.Optional[builtins.str]:
        result = self._values.get("read")
        return result

    @builtins.property
    def update(self) -> typing.Optional[builtins.str]:
        result = self._values.get("update")
        return result

    def __eq__(self, rhs: typing.Any) -> builtins.bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs: typing.Any) -> builtins.bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return "IothubEndpointStorageContainerTimeouts(%s)" % ", ".join(
            k + "=" + repr(v) for k, v in self._values.items()
        )


@jsii.data_type(
    jsii_type="@cdktf/provider-azurerm.IothubFallbackRoute",
    jsii_struct_bases=[],
    name_mapping={
        "condition": "condition",
        "enabled": "enabled",
        "endpoint_names": "endpointNames",
        "source": "source",
    },
)
class IothubFallbackRoute:
    def __init__(
        self,
        *,
        condition: typing.Optional[builtins.str] = None,
        enabled: typing.Optional[builtins.bool] = None,
        endpoint_names: typing.Optional[typing.List[builtins.str]] = None,
        source: typing.Optional[builtins.str] = None,
    ) -> None:
        """
        :param condition: 
        :param enabled: 
        :param endpoint_names: 
        :param source: 
        """
        self._values: typing.Dict[str, typing.Any] = {}
        if condition is not None:
            self._values["condition"] = condition
        if enabled is not None:
            self._values["enabled"] = enabled
        if endpoint_names is not None:
            self._values["endpoint_names"] = endpoint_names
        if source is not None:
            self._values["source"] = source

    @builtins.property
    def condition(self) -> typing.Optional[builtins.str]:
        result = self._values.get("condition")
        return result

    @builtins.property
    def enabled(self) -> typing.Optional[builtins.bool]:
        result = self._values.get("enabled")
        return result

    @builtins.property
    def endpoint_names(self) -> typing.Optional[typing.List[builtins.str]]:
        result = self._values.get("endpoint_names")
        return result

    @builtins.property
    def source(self) -> typing.Optional[builtins.str]:
        result = self._values.get("source")
        return result

    def __eq__(self, rhs: typing.Any) -> builtins.bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs: typing.Any) -> builtins.bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return "IothubFallbackRoute(%s)" % ", ".join(
            k + "=" + repr(v) for k, v in self._values.items()
        )


class IothubFallbackRouteA(
    cdktf.TerraformResource,
    metaclass=jsii.JSIIMeta,
    jsii_type="@cdktf/provider-azurerm.IothubFallbackRouteA",
):
    def __init__(
        self,
        scope: constructs.Construct,
        id: builtins.str,
        *,
        enabled: builtins.bool,
        endpoint_names: typing.List[builtins.str],
        iothub_name: builtins.str,
        resource_group_name: builtins.str,
        condition: typing.Optional[builtins.str] = None,
        timeouts: typing.Optional["IothubFallbackRouteTimeouts"] = None,
        count: typing.Optional[jsii.Number] = None,
        depends_on: typing.Optional[typing.List[cdktf.TerraformResource]] = None,
        lifecycle: typing.Optional[cdktf.TerraformResourceLifecycle] = None,
        provider: typing.Optional[cdktf.TerraformProvider] = None,
    ) -> None:
        """
        :param scope: -
        :param id: -
        :param enabled: 
        :param endpoint_names: 
        :param iothub_name: 
        :param resource_group_name: 
        :param condition: 
        :param timeouts: timeouts block.
        :param count: 
        :param depends_on: 
        :param lifecycle: 
        :param provider: 
        """
        config = IothubFallbackRouteAConfig(
            enabled=enabled,
            endpoint_names=endpoint_names,
            iothub_name=iothub_name,
            resource_group_name=resource_group_name,
            condition=condition,
            timeouts=timeouts,
            count=count,
            depends_on=depends_on,
            lifecycle=lifecycle,
            provider=provider,
        )

        jsii.create(IothubFallbackRouteA, self, [scope, id, config])

    @jsii.member(jsii_name="synthesizeAttributes")
    def _synthesize_attributes(self) -> typing.Mapping[builtins.str, typing.Any]:
        return jsii.invoke(self, "synthesizeAttributes", [])

    @builtins.property # type: ignore
    @jsii.member(jsii_name="enabled")
    def enabled(self) -> builtins.bool:
        return jsii.get(self, "enabled")

    @enabled.setter # type: ignore
    def enabled(self, value: builtins.bool) -> None:
        jsii.set(self, "enabled", value)

    @builtins.property # type: ignore
    @jsii.member(jsii_name="endpointNames")
    def endpoint_names(self) -> typing.List[builtins.str]:
        return jsii.get(self, "endpointNames")

    @endpoint_names.setter # type: ignore
    def endpoint_names(self, value: typing.List[builtins.str]) -> None:
        jsii.set(self, "endpointNames", value)

    @builtins.property # type: ignore
    @jsii.member(jsii_name="iothubName")
    def iothub_name(self) -> builtins.str:
        return jsii.get(self, "iothubName")

    @iothub_name.setter # type: ignore
    def iothub_name(self, value: builtins.str) -> None:
        jsii.set(self, "iothubName", value)

    @builtins.property # type: ignore
    @jsii.member(jsii_name="resourceGroupName")
    def resource_group_name(self) -> builtins.str:
        return jsii.get(self, "resourceGroupName")

    @resource_group_name.setter # type: ignore
    def resource_group_name(self, value: builtins.str) -> None:
        jsii.set(self, "resourceGroupName", value)

    @builtins.property # type: ignore
    @jsii.member(jsii_name="condition")
    def condition(self) -> typing.Optional[builtins.str]:
        return jsii.get(self, "condition")

    @condition.setter # type: ignore
    def condition(self, value: typing.Optional[builtins.str]) -> None:
        jsii.set(self, "condition", value)

    @builtins.property # type: ignore
    @jsii.member(jsii_name="id")
    def id(self) -> typing.Optional[builtins.str]:
        return jsii.get(self, "id")

    @id.setter # type: ignore
    def id(self, value: typing.Optional[builtins.str]) -> None:
        jsii.set(self, "id", value)

    @builtins.property # type: ignore
    @jsii.member(jsii_name="timeouts")
    def timeouts(self) -> typing.Optional["IothubFallbackRouteTimeouts"]:
        return jsii.get(self, "timeouts")

    @timeouts.setter # type: ignore
    def timeouts(self, value: typing.Optional["IothubFallbackRouteTimeouts"]) -> None:
        jsii.set(self, "timeouts", value)


@jsii.data_type(
    jsii_type="@cdktf/provider-azurerm.IothubFallbackRouteAConfig",
    jsii_struct_bases=[cdktf.TerraformMetaArguments],
    name_mapping={
        "count": "count",
        "depends_on": "dependsOn",
        "lifecycle": "lifecycle",
        "provider": "provider",
        "enabled": "enabled",
        "endpoint_names": "endpointNames",
        "iothub_name": "iothubName",
        "resource_group_name": "resourceGroupName",
        "condition": "condition",
        "timeouts": "timeouts",
    },
)
class IothubFallbackRouteAConfig(cdktf.TerraformMetaArguments):
    def __init__(
        self,
        *,
        count: typing.Optional[jsii.Number] = None,
        depends_on: typing.Optional[typing.List[cdktf.TerraformResource]] = None,
        lifecycle: typing.Optional[cdktf.TerraformResourceLifecycle] = None,
        provider: typing.Optional[cdktf.TerraformProvider] = None,
        enabled: builtins.bool,
        endpoint_names: typing.List[builtins.str],
        iothub_name: builtins.str,
        resource_group_name: builtins.str,
        condition: typing.Optional[builtins.str] = None,
        timeouts: typing.Optional["IothubFallbackRouteTimeouts"] = None,
    ) -> None:
        """
        :param count: 
        :param depends_on: 
        :param lifecycle: 
        :param provider: 
        :param enabled: 
        :param endpoint_names: 
        :param iothub_name: 
        :param resource_group_name: 
        :param condition: 
        :param timeouts: timeouts block.
        """
        if isinstance(lifecycle, dict):
            lifecycle = cdktf.TerraformResourceLifecycle(**lifecycle)
        if isinstance(timeouts, dict):
            timeouts = IothubFallbackRouteTimeouts(**timeouts)
        self._values: typing.Dict[str, typing.Any] = {
            "enabled": enabled,
            "endpoint_names": endpoint_names,
            "iothub_name": iothub_name,
            "resource_group_name": resource_group_name,
        }
        if count is not None:
            self._values["count"] = count
        if depends_on is not None:
            self._values["depends_on"] = depends_on
        if lifecycle is not None:
            self._values["lifecycle"] = lifecycle
        if provider is not None:
            self._values["provider"] = provider
        if condition is not None:
            self._values["condition"] = condition
        if timeouts is not None:
            self._values["timeouts"] = timeouts

    @builtins.property
    def count(self) -> typing.Optional[jsii.Number]:
        """
        :stability: experimental
        """
        result = self._values.get("count")
        return result

    @builtins.property
    def depends_on(self) -> typing.Optional[typing.List[cdktf.TerraformResource]]:
        """
        :stability: experimental
        """
        result = self._values.get("depends_on")
        return result

    @builtins.property
    def lifecycle(self) -> typing.Optional[cdktf.TerraformResourceLifecycle]:
        """
        :stability: experimental
        """
        result = self._values.get("lifecycle")
        return result

    @builtins.property
    def provider(self) -> typing.Optional[cdktf.TerraformProvider]:
        """
        :stability: experimental
        """
        result = self._values.get("provider")
        return result

    @builtins.property
    def enabled(self) -> builtins.bool:
        result = self._values.get("enabled")
        assert result is not None, "Required property 'enabled' is missing"
        return result

    @builtins.property
    def endpoint_names(self) -> typing.List[builtins.str]:
        result = self._values.get("endpoint_names")
        assert result is not None, "Required property 'endpoint_names' is missing"
        return result

    @builtins.property
    def iothub_name(self) -> builtins.str:
        result = self._values.get("iothub_name")
        assert result is not None, "Required property 'iothub_name' is missing"
        return result

    @builtins.property
    def resource_group_name(self) -> builtins.str:
        result = self._values.get("resource_group_name")
        assert result is not None, "Required property 'resource_group_name' is missing"
        return result

    @builtins.property
    def condition(self) -> typing.Optional[builtins.str]:
        result = self._values.get("condition")
        return result

    @builtins.property
    def timeouts(self) -> typing.Optional["IothubFallbackRouteTimeouts"]:
        """timeouts block."""
        result = self._values.get("timeouts")
        return result

    def __eq__(self, rhs: typing.Any) -> builtins.bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs: typing.Any) -> builtins.bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return "IothubFallbackRouteAConfig(%s)" % ", ".join(
            k + "=" + repr(v) for k, v in self._values.items()
        )


@jsii.data_type(
    jsii_type="@cdktf/provider-azurerm.IothubFallbackRouteTimeouts",
    jsii_struct_bases=[],
    name_mapping={
        "create": "create",
        "delete": "delete",
        "read": "read",
        "update": "update",
    },
)
class IothubFallbackRouteTimeouts:
    def __init__(
        self,
        *,
        create: typing.Optional[builtins.str] = None,
        delete: typing.Optional[builtins.str] = None,
        read: typing.Optional[builtins.str] = None,
        update: typing.Optional[builtins.str] = None,
    ) -> None:
        """
        :param create: 
        :param delete: 
        :param read: 
        :param update: 
        """
        self._values: typing.Dict[str, typing.Any] = {}
        if create is not None:
            self._values["create"] = create
        if delete is not None:
            self._values["delete"] = delete
        if read is not None:
            self._values["read"] = read
        if update is not None:
            self._values["update"] = update

    @builtins.property
    def create(self) -> typing.Optional[builtins.str]:
        result = self._values.get("create")
        return result

    @builtins.property
    def delete(self) -> typing.Optional[builtins.str]:
        result = self._values.get("delete")
        return result

    @builtins.property
    def read(self) -> typing.Optional[builtins.str]:
        result = self._values.get("read")
        return result

    @builtins.property
    def update(self) -> typing.Optional[builtins.str]:
        result = self._values.get("update")
        return result

    def __eq__(self, rhs: typing.Any) -> builtins.bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs: typing.Any) -> builtins.bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return "IothubFallbackRouteTimeouts(%s)" % ", ".join(
            k + "=" + repr(v) for k, v in self._values.items()
        )


@jsii.data_type(
    jsii_type="@cdktf/provider-azurerm.IothubFileUpload",
    jsii_struct_bases=[],
    name_mapping={
        "connection_string": "connectionString",
        "container_name": "containerName",
        "default_ttl": "defaultTtl",
        "lock_duration": "lockDuration",
        "max_delivery_count": "maxDeliveryCount",
        "notifications": "notifications",
        "sas_ttl": "sasTtl",
    },
)
class IothubFileUpload:
    def __init__(
        self,
        *,
        connection_string: builtins.str,
        container_name: builtins.str,
        default_ttl: typing.Optional[builtins.str] = None,
        lock_duration: typing.Optional[builtins.str] = None,
        max_delivery_count: typing.Optional[jsii.Number] = None,
        notifications: typing.Optional[builtins.bool] = None,
        sas_ttl: typing.Optional[builtins.str] = None,
    ) -> None:
        """
        :param connection_string: 
        :param container_name: 
        :param default_ttl: 
        :param lock_duration: 
        :param max_delivery_count: 
        :param notifications: 
        :param sas_ttl: 
        """
        self._values: typing.Dict[str, typing.Any] = {
            "connection_string": connection_string,
            "container_name": container_name,
        }
        if default_ttl is not None:
            self._values["default_ttl"] = default_ttl
        if lock_duration is not None:
            self._values["lock_duration"] = lock_duration
        if max_delivery_count is not None:
            self._values["max_delivery_count"] = max_delivery_count
        if notifications is not None:
            self._values["notifications"] = notifications
        if sas_ttl is not None:
            self._values["sas_ttl"] = sas_ttl

    @builtins.property
    def connection_string(self) -> builtins.str:
        result = self._values.get("connection_string")
        assert result is not None, "Required property 'connection_string' is missing"
        return result

    @builtins.property
    def container_name(self) -> builtins.str:
        result = self._values.get("container_name")
        assert result is not None, "Required property 'container_name' is missing"
        return result

    @builtins.property
    def default_ttl(self) -> typing.Optional[builtins.str]:
        result = self._values.get("default_ttl")
        return result

    @builtins.property
    def lock_duration(self) -> typing.Optional[builtins.str]:
        result = self._values.get("lock_duration")
        return result

    @builtins.property
    def max_delivery_count(self) -> typing.Optional[jsii.Number]:
        result = self._values.get("max_delivery_count")
        return result

    @builtins.property
    def notifications(self) -> typing.Optional[builtins.bool]:
        result = self._values.get("notifications")
        return result

    @builtins.property
    def sas_ttl(self) -> typing.Optional[builtins.str]:
        result = self._values.get("sas_ttl")
        return result

    def __eq__(self, rhs: typing.Any) -> builtins.bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs: typing.Any) -> builtins.bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return "IothubFileUpload(%s)" % ", ".join(
            k + "=" + repr(v) for k, v in self._values.items()
        )


@jsii.data_type(
    jsii_type="@cdktf/provider-azurerm.IothubIpFilterRule",
    jsii_struct_bases=[],
    name_mapping={"action": "action", "ip_mask": "ipMask", "name": "name"},
)
class IothubIpFilterRule:
    def __init__(
        self,
        *,
        action: builtins.str,
        ip_mask: builtins.str,
        name: builtins.str,
    ) -> None:
        """
        :param action: 
        :param ip_mask: 
        :param name: 
        """
        self._values: typing.Dict[str, typing.Any] = {
            "action": action,
            "ip_mask": ip_mask,
            "name": name,
        }

    @builtins.property
    def action(self) -> builtins.str:
        result = self._values.get("action")
        assert result is not None, "Required property 'action' is missing"
        return result

    @builtins.property
    def ip_mask(self) -> builtins.str:
        result = self._values.get("ip_mask")
        assert result is not None, "Required property 'ip_mask' is missing"
        return result

    @builtins.property
    def name(self) -> builtins.str:
        result = self._values.get("name")
        assert result is not None, "Required property 'name' is missing"
        return result

    def __eq__(self, rhs: typing.Any) -> builtins.bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs: typing.Any) -> builtins.bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return "IothubIpFilterRule(%s)" % ", ".join(
            k + "=" + repr(v) for k, v in self._values.items()
        )


@jsii.data_type(
    jsii_type="@cdktf/provider-azurerm.IothubRoute",
    jsii_struct_bases=[],
    name_mapping={
        "enabled": "enabled",
        "endpoint_names": "endpointNames",
        "name": "name",
        "source": "source",
        "condition": "condition",
    },
)
class IothubRoute:
    def __init__(
        self,
        *,
        enabled: builtins.bool,
        endpoint_names: typing.List[builtins.str],
        name: builtins.str,
        source: builtins.str,
        condition: typing.Optional[builtins.str] = None,
    ) -> None:
        """
        :param enabled: 
        :param endpoint_names: 
        :param name: 
        :param source: 
        :param condition: 
        """
        self._values: typing.Dict[str, typing.Any] = {
            "enabled": enabled,
            "endpoint_names": endpoint_names,
            "name": name,
            "source": source,
        }
        if condition is not None:
            self._values["condition"] = condition

    @builtins.property
    def enabled(self) -> builtins.bool:
        result = self._values.get("enabled")
        assert result is not None, "Required property 'enabled' is missing"
        return result

    @builtins.property
    def endpoint_names(self) -> typing.List[builtins.str]:
        result = self._values.get("endpoint_names")
        assert result is not None, "Required property 'endpoint_names' is missing"
        return result

    @builtins.property
    def name(self) -> builtins.str:
        result = self._values.get("name")
        assert result is not None, "Required property 'name' is missing"
        return result

    @builtins.property
    def source(self) -> builtins.str:
        result = self._values.get("source")
        assert result is not None, "Required property 'source' is missing"
        return result

    @builtins.property
    def condition(self) -> typing.Optional[builtins.str]:
        result = self._values.get("condition")
        return result

    def __eq__(self, rhs: typing.Any) -> builtins.bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs: typing.Any) -> builtins.bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return "IothubRoute(%s)" % ", ".join(
            k + "=" + repr(v) for k, v in self._values.items()
        )


class IothubRouteA(
    cdktf.TerraformResource,
    metaclass=jsii.JSIIMeta,
    jsii_type="@cdktf/provider-azurerm.IothubRouteA",
):
    def __init__(
        self,
        scope: constructs.Construct,
        id: builtins.str,
        *,
        enabled: builtins.bool,
        endpoint_names: typing.List[builtins.str],
        iothub_name: builtins.str,
        name: builtins.str,
        resource_group_name: builtins.str,
        source: builtins.str,
        condition: typing.Optional[builtins.str] = None,
        timeouts: typing.Optional["IothubRouteTimeouts"] = None,
        count: typing.Optional[jsii.Number] = None,
        depends_on: typing.Optional[typing.List[cdktf.TerraformResource]] = None,
        lifecycle: typing.Optional[cdktf.TerraformResourceLifecycle] = None,
        provider: typing.Optional[cdktf.TerraformProvider] = None,
    ) -> None:
        """
        :param scope: -
        :param id: -
        :param enabled: 
        :param endpoint_names: 
        :param iothub_name: 
        :param name: 
        :param resource_group_name: 
        :param source: 
        :param condition: 
        :param timeouts: timeouts block.
        :param count: 
        :param depends_on: 
        :param lifecycle: 
        :param provider: 
        """
        config = IothubRouteAConfig(
            enabled=enabled,
            endpoint_names=endpoint_names,
            iothub_name=iothub_name,
            name=name,
            resource_group_name=resource_group_name,
            source=source,
            condition=condition,
            timeouts=timeouts,
            count=count,
            depends_on=depends_on,
            lifecycle=lifecycle,
            provider=provider,
        )

        jsii.create(IothubRouteA, self, [scope, id, config])

    @jsii.member(jsii_name="synthesizeAttributes")
    def _synthesize_attributes(self) -> typing.Mapping[builtins.str, typing.Any]:
        return jsii.invoke(self, "synthesizeAttributes", [])

    @builtins.property # type: ignore
    @jsii.member(jsii_name="enabled")
    def enabled(self) -> builtins.bool:
        return jsii.get(self, "enabled")

    @enabled.setter # type: ignore
    def enabled(self, value: builtins.bool) -> None:
        jsii.set(self, "enabled", value)

    @builtins.property # type: ignore
    @jsii.member(jsii_name="endpointNames")
    def endpoint_names(self) -> typing.List[builtins.str]:
        return jsii.get(self, "endpointNames")

    @endpoint_names.setter # type: ignore
    def endpoint_names(self, value: typing.List[builtins.str]) -> None:
        jsii.set(self, "endpointNames", value)

    @builtins.property # type: ignore
    @jsii.member(jsii_name="iothubName")
    def iothub_name(self) -> builtins.str:
        return jsii.get(self, "iothubName")

    @iothub_name.setter # type: ignore
    def iothub_name(self, value: builtins.str) -> None:
        jsii.set(self, "iothubName", value)

    @builtins.property # type: ignore
    @jsii.member(jsii_name="name")
    def name(self) -> builtins.str:
        return jsii.get(self, "name")

    @name.setter # type: ignore
    def name(self, value: builtins.str) -> None:
        jsii.set(self, "name", value)

    @builtins.property # type: ignore
    @jsii.member(jsii_name="resourceGroupName")
    def resource_group_name(self) -> builtins.str:
        return jsii.get(self, "resourceGroupName")

    @resource_group_name.setter # type: ignore
    def resource_group_name(self, value: builtins.str) -> None:
        jsii.set(self, "resourceGroupName", value)

    @builtins.property # type: ignore
    @jsii.member(jsii_name="source")
    def source(self) -> builtins.str:
        return jsii.get(self, "source")

    @source.setter # type: ignore
    def source(self, value: builtins.str) -> None:
        jsii.set(self, "source", value)

    @builtins.property # type: ignore
    @jsii.member(jsii_name="condition")
    def condition(self) -> typing.Optional[builtins.str]:
        return jsii.get(self, "condition")

    @condition.setter # type: ignore
    def condition(self, value: typing.Optional[builtins.str]) -> None:
        jsii.set(self, "condition", value)

    @builtins.property # type: ignore
    @jsii.member(jsii_name="id")
    def id(self) -> typing.Optional[builtins.str]:
        return jsii.get(self, "id")

    @id.setter # type: ignore
    def id(self, value: typing.Optional[builtins.str]) -> None:
        jsii.set(self, "id", value)

    @builtins.property # type: ignore
    @jsii.member(jsii_name="timeouts")
    def timeouts(self) -> typing.Optional["IothubRouteTimeouts"]:
        return jsii.get(self, "timeouts")

    @timeouts.setter # type: ignore
    def timeouts(self, value: typing.Optional["IothubRouteTimeouts"]) -> None:
        jsii.set(self, "timeouts", value)


@jsii.data_type(
    jsii_type="@cdktf/provider-azurerm.IothubRouteAConfig",
    jsii_struct_bases=[cdktf.TerraformMetaArguments],
    name_mapping={
        "count": "count",
        "depends_on": "dependsOn",
        "lifecycle": "lifecycle",
        "provider": "provider",
        "enabled": "enabled",
        "endpoint_names": "endpointNames",
        "iothub_name": "iothubName",
        "name": "name",
        "resource_group_name": "resourceGroupName",
        "source": "source",
        "condition": "condition",
        "timeouts": "timeouts",
    },
)
class IothubRouteAConfig(cdktf.TerraformMetaArguments):
    def __init__(
        self,
        *,
        count: typing.Optional[jsii.Number] = None,
        depends_on: typing.Optional[typing.List[cdktf.TerraformResource]] = None,
        lifecycle: typing.Optional[cdktf.TerraformResourceLifecycle] = None,
        provider: typing.Optional[cdktf.TerraformProvider] = None,
        enabled: builtins.bool,
        endpoint_names: typing.List[builtins.str],
        iothub_name: builtins.str,
        name: builtins.str,
        resource_group_name: builtins.str,
        source: builtins.str,
        condition: typing.Optional[builtins.str] = None,
        timeouts: typing.Optional["IothubRouteTimeouts"] = None,
    ) -> None:
        """
        :param count: 
        :param depends_on: 
        :param lifecycle: 
        :param provider: 
        :param enabled: 
        :param endpoint_names: 
        :param iothub_name: 
        :param name: 
        :param resource_group_name: 
        :param source: 
        :param condition: 
        :param timeouts: timeouts block.
        """
        if isinstance(lifecycle, dict):
            lifecycle = cdktf.TerraformResourceLifecycle(**lifecycle)
        if isinstance(timeouts, dict):
            timeouts = IothubRouteTimeouts(**timeouts)
        self._values: typing.Dict[str, typing.Any] = {
            "enabled": enabled,
            "endpoint_names": endpoint_names,
            "iothub_name": iothub_name,
            "name": name,
            "resource_group_name": resource_group_name,
            "source": source,
        }
        if count is not None:
            self._values["count"] = count
        if depends_on is not None:
            self._values["depends_on"] = depends_on
        if lifecycle is not None:
            self._values["lifecycle"] = lifecycle
        if provider is not None:
            self._values["provider"] = provider
        if condition is not None:
            self._values["condition"] = condition
        if timeouts is not None:
            self._values["timeouts"] = timeouts

    @builtins.property
    def count(self) -> typing.Optional[jsii.Number]:
        """
        :stability: experimental
        """
        result = self._values.get("count")
        return result

    @builtins.property
    def depends_on(self) -> typing.Optional[typing.List[cdktf.TerraformResource]]:
        """
        :stability: experimental
        """
        result = self._values.get("depends_on")
        return result

    @builtins.property
    def lifecycle(self) -> typing.Optional[cdktf.TerraformResourceLifecycle]:
        """
        :stability: experimental
        """
        result = self._values.get("lifecycle")
        return result

    @builtins.property
    def provider(self) -> typing.Optional[cdktf.TerraformProvider]:
        """
        :stability: experimental
        """
        result = self._values.get("provider")
        return result

    @builtins.property
    def enabled(self) -> builtins.bool:
        result = self._values.get("enabled")
        assert result is not None, "Required property 'enabled' is missing"
        return result

    @builtins.property
    def endpoint_names(self) -> typing.List[builtins.str]:
        result = self._values.get("endpoint_names")
        assert result is not None, "Required property 'endpoint_names' is missing"
        return result

    @builtins.property
    def iothub_name(self) -> builtins.str:
        result = self._values.get("iothub_name")
        assert result is not None, "Required property 'iothub_name' is missing"
        return result

    @builtins.property
    def name(self) -> builtins.str:
        result = self._values.get("name")
        assert result is not None, "Required property 'name' is missing"
        return result

    @builtins.property
    def resource_group_name(self) -> builtins.str:
        result = self._values.get("resource_group_name")
        assert result is not None, "Required property 'resource_group_name' is missing"
        return result

    @builtins.property
    def source(self) -> builtins.str:
        result = self._values.get("source")
        assert result is not None, "Required property 'source' is missing"
        return result

    @builtins.property
    def condition(self) -> typing.Optional[builtins.str]:
        result = self._values.get("condition")
        return result

    @builtins.property
    def timeouts(self) -> typing.Optional["IothubRouteTimeouts"]:
        """timeouts block."""
        result = self._values.get("timeouts")
        return result

    def __eq__(self, rhs: typing.Any) -> builtins.bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs: typing.Any) -> builtins.bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return "IothubRouteAConfig(%s)" % ", ".join(
            k + "=" + repr(v) for k, v in self._values.items()
        )


@jsii.data_type(
    jsii_type="@cdktf/provider-azurerm.IothubRouteTimeouts",
    jsii_struct_bases=[],
    name_mapping={
        "create": "create",
        "delete": "delete",
        "read": "read",
        "update": "update",
    },
)
class IothubRouteTimeouts:
    def __init__(
        self,
        *,
        create: typing.Optional[builtins.str] = None,
        delete: typing.Optional[builtins.str] = None,
        read: typing.Optional[builtins.str] = None,
        update: typing.Optional[builtins.str] = None,
    ) -> None:
        """
        :param create: 
        :param delete: 
        :param read: 
        :param update: 
        """
        self._values: typing.Dict[str, typing.Any] = {}
        if create is not None:
            self._values["create"] = create
        if delete is not None:
            self._values["delete"] = delete
        if read is not None:
            self._values["read"] = read
        if update is not None:
            self._values["update"] = update

    @builtins.property
    def create(self) -> typing.Optional[builtins.str]:
        result = self._values.get("create")
        return result

    @builtins.property
    def delete(self) -> typing.Optional[builtins.str]:
        result = self._values.get("delete")
        return result

    @builtins.property
    def read(self) -> typing.Optional[builtins.str]:
        result = self._values.get("read")
        return result

    @builtins.property
    def update(self) -> typing.Optional[builtins.str]:
        result = self._values.get("update")
        return result

    def __eq__(self, rhs: typing.Any) -> builtins.bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs: typing.Any) -> builtins.bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return "IothubRouteTimeouts(%s)" % ", ".join(
            k + "=" + repr(v) for k, v in self._values.items()
        )


class IothubSharedAccessPolicy(
    cdktf.ComplexComputedList,
    metaclass=jsii.JSIIMeta,
    jsii_type="@cdktf/provider-azurerm.IothubSharedAccessPolicy",
):
    def __init__(
        self,
        terraform_resource: cdktf.ITerraformResource,
        terraform_attribute: builtins.str,
        index: builtins.str,
    ) -> None:
        """
        :param terraform_resource: -
        :param terraform_attribute: -
        :param index: -

        :stability: experimental
        """
        jsii.create(IothubSharedAccessPolicy, self, [terraform_resource, terraform_attribute, index])

    @builtins.property # type: ignore
    @jsii.member(jsii_name="keyName")
    def key_name(self) -> builtins.str:
        return jsii.get(self, "keyName")

    @builtins.property # type: ignore
    @jsii.member(jsii_name="permissions")
    def permissions(self) -> builtins.str:
        return jsii.get(self, "permissions")

    @builtins.property # type: ignore
    @jsii.member(jsii_name="primaryKey")
    def primary_key(self) -> builtins.str:
        return jsii.get(self, "primaryKey")

    @builtins.property # type: ignore
    @jsii.member(jsii_name="secondaryKey")
    def secondary_key(self) -> builtins.str:
        return jsii.get(self, "secondaryKey")


class IothubSharedAccessPolicyA(
    cdktf.TerraformResource,
    metaclass=jsii.JSIIMeta,
    jsii_type="@cdktf/provider-azurerm.IothubSharedAccessPolicyA",
):
    def __init__(
        self,
        scope: constructs.Construct,
        id: builtins.str,
        *,
        iothub_name: builtins.str,
        name: builtins.str,
        resource_group_name: builtins.str,
        device_connect: typing.Optional[builtins.bool] = None,
        registry_read: typing.Optional[builtins.bool] = None,
        registry_write: typing.Optional[builtins.bool] = None,
        service_connect: typing.Optional[builtins.bool] = None,
        timeouts: typing.Optional["IothubSharedAccessPolicyTimeouts"] = None,
        count: typing.Optional[jsii.Number] = None,
        depends_on: typing.Optional[typing.List[cdktf.TerraformResource]] = None,
        lifecycle: typing.Optional[cdktf.TerraformResourceLifecycle] = None,
        provider: typing.Optional[cdktf.TerraformProvider] = None,
    ) -> None:
        """
        :param scope: -
        :param id: -
        :param iothub_name: 
        :param name: 
        :param resource_group_name: 
        :param device_connect: 
        :param registry_read: 
        :param registry_write: 
        :param service_connect: 
        :param timeouts: timeouts block.
        :param count: 
        :param depends_on: 
        :param lifecycle: 
        :param provider: 
        """
        config = IothubSharedAccessPolicyAConfig(
            iothub_name=iothub_name,
            name=name,
            resource_group_name=resource_group_name,
            device_connect=device_connect,
            registry_read=registry_read,
            registry_write=registry_write,
            service_connect=service_connect,
            timeouts=timeouts,
            count=count,
            depends_on=depends_on,
            lifecycle=lifecycle,
            provider=provider,
        )

        jsii.create(IothubSharedAccessPolicyA, self, [scope, id, config])

    @jsii.member(jsii_name="synthesizeAttributes")
    def _synthesize_attributes(self) -> typing.Mapping[builtins.str, typing.Any]:
        return jsii.invoke(self, "synthesizeAttributes", [])

    @builtins.property # type: ignore
    @jsii.member(jsii_name="primaryConnectionString")
    def primary_connection_string(self) -> builtins.str:
        return jsii.get(self, "primaryConnectionString")

    @builtins.property # type: ignore
    @jsii.member(jsii_name="primaryKey")
    def primary_key(self) -> builtins.str:
        return jsii.get(self, "primaryKey")

    @builtins.property # type: ignore
    @jsii.member(jsii_name="secondaryConnectionString")
    def secondary_connection_string(self) -> builtins.str:
        return jsii.get(self, "secondaryConnectionString")

    @builtins.property # type: ignore
    @jsii.member(jsii_name="secondaryKey")
    def secondary_key(self) -> builtins.str:
        return jsii.get(self, "secondaryKey")

    @builtins.property # type: ignore
    @jsii.member(jsii_name="iothubName")
    def iothub_name(self) -> builtins.str:
        return jsii.get(self, "iothubName")

    @iothub_name.setter # type: ignore
    def iothub_name(self, value: builtins.str) -> None:
        jsii.set(self, "iothubName", value)

    @builtins.property # type: ignore
    @jsii.member(jsii_name="name")
    def name(self) -> builtins.str:
        return jsii.get(self, "name")

    @name.setter # type: ignore
    def name(self, value: builtins.str) -> None:
        jsii.set(self, "name", value)

    @builtins.property # type: ignore
    @jsii.member(jsii_name="resourceGroupName")
    def resource_group_name(self) -> builtins.str:
        return jsii.get(self, "resourceGroupName")

    @resource_group_name.setter # type: ignore
    def resource_group_name(self, value: builtins.str) -> None:
        jsii.set(self, "resourceGroupName", value)

    @builtins.property # type: ignore
    @jsii.member(jsii_name="deviceConnect")
    def device_connect(self) -> typing.Optional[builtins.bool]:
        return jsii.get(self, "deviceConnect")

    @device_connect.setter # type: ignore
    def device_connect(self, value: typing.Optional[builtins.bool]) -> None:
        jsii.set(self, "deviceConnect", value)

    @builtins.property # type: ignore
    @jsii.member(jsii_name="id")
    def id(self) -> typing.Optional[builtins.str]:
        return jsii.get(self, "id")

    @id.setter # type: ignore
    def id(self, value: typing.Optional[builtins.str]) -> None:
        jsii.set(self, "id", value)

    @builtins.property # type: ignore
    @jsii.member(jsii_name="registryRead")
    def registry_read(self) -> typing.Optional[builtins.bool]:
        return jsii.get(self, "registryRead")

    @registry_read.setter # type: ignore
    def registry_read(self, value: typing.Optional[builtins.bool]) -> None:
        jsii.set(self, "registryRead", value)

    @builtins.property # type: ignore
    @jsii.member(jsii_name="registryWrite")
    def registry_write(self) -> typing.Optional[builtins.bool]:
        return jsii.get(self, "registryWrite")

    @registry_write.setter # type: ignore
    def registry_write(self, value: typing.Optional[builtins.bool]) -> None:
        jsii.set(self, "registryWrite", value)

    @builtins.property # type: ignore
    @jsii.member(jsii_name="serviceConnect")
    def service_connect(self) -> typing.Optional[builtins.bool]:
        return jsii.get(self, "serviceConnect")

    @service_connect.setter # type: ignore
    def service_connect(self, value: typing.Optional[builtins.bool]) -> None:
        jsii.set(self, "serviceConnect", value)

    @builtins.property # type: ignore
    @jsii.member(jsii_name="timeouts")
    def timeouts(self) -> typing.Optional["IothubSharedAccessPolicyTimeouts"]:
        return jsii.get(self, "timeouts")

    @timeouts.setter # type: ignore
    def timeouts(
        self,
        value: typing.Optional["IothubSharedAccessPolicyTimeouts"],
    ) -> None:
        jsii.set(self, "timeouts", value)


@jsii.data_type(
    jsii_type="@cdktf/provider-azurerm.IothubSharedAccessPolicyAConfig",
    jsii_struct_bases=[cdktf.TerraformMetaArguments],
    name_mapping={
        "count": "count",
        "depends_on": "dependsOn",
        "lifecycle": "lifecycle",
        "provider": "provider",
        "iothub_name": "iothubName",
        "name": "name",
        "resource_group_name": "resourceGroupName",
        "device_connect": "deviceConnect",
        "registry_read": "registryRead",
        "registry_write": "registryWrite",
        "service_connect": "serviceConnect",
        "timeouts": "timeouts",
    },
)
class IothubSharedAccessPolicyAConfig(cdktf.TerraformMetaArguments):
    def __init__(
        self,
        *,
        count: typing.Optional[jsii.Number] = None,
        depends_on: typing.Optional[typing.List[cdktf.TerraformResource]] = None,
        lifecycle: typing.Optional[cdktf.TerraformResourceLifecycle] = None,
        provider: typing.Optional[cdktf.TerraformProvider] = None,
        iothub_name: builtins.str,
        name: builtins.str,
        resource_group_name: builtins.str,
        device_connect: typing.Optional[builtins.bool] = None,
        registry_read: typing.Optional[builtins.bool] = None,
        registry_write: typing.Optional[builtins.bool] = None,
        service_connect: typing.Optional[builtins.bool] = None,
        timeouts: typing.Optional["IothubSharedAccessPolicyTimeouts"] = None,
    ) -> None:
        """
        :param count: 
        :param depends_on: 
        :param lifecycle: 
        :param provider: 
        :param iothub_name: 
        :param name: 
        :param resource_group_name: 
        :param device_connect: 
        :param registry_read: 
        :param registry_write: 
        :param service_connect: 
        :param timeouts: timeouts block.
        """
        if isinstance(lifecycle, dict):
            lifecycle = cdktf.TerraformResourceLifecycle(**lifecycle)
        if isinstance(timeouts, dict):
            timeouts = IothubSharedAccessPolicyTimeouts(**timeouts)
        self._values: typing.Dict[str, typing.Any] = {
            "iothub_name": iothub_name,
            "name": name,
            "resource_group_name": resource_group_name,
        }
        if count is not None:
            self._values["count"] = count
        if depends_on is not None:
            self._values["depends_on"] = depends_on
        if lifecycle is not None:
            self._values["lifecycle"] = lifecycle
        if provider is not None:
            self._values["provider"] = provider
        if device_connect is not None:
            self._values["device_connect"] = device_connect
        if registry_read is not None:
            self._values["registry_read"] = registry_read
        if registry_write is not None:
            self._values["registry_write"] = registry_write
        if service_connect is not None:
            self._values["service_connect"] = service_connect
        if timeouts is not None:
            self._values["timeouts"] = timeouts

    @builtins.property
    def count(self) -> typing.Optional[jsii.Number]:
        """
        :stability: experimental
        """
        result = self._values.get("count")
        return result

    @builtins.property
    def depends_on(self) -> typing.Optional[typing.List[cdktf.TerraformResource]]:
        """
        :stability: experimental
        """
        result = self._values.get("depends_on")
        return result

    @builtins.property
    def lifecycle(self) -> typing.Optional[cdktf.TerraformResourceLifecycle]:
        """
        :stability: experimental
        """
        result = self._values.get("lifecycle")
        return result

    @builtins.property
    def provider(self) -> typing.Optional[cdktf.TerraformProvider]:
        """
        :stability: experimental
        """
        result = self._values.get("provider")
        return result

    @builtins.property
    def iothub_name(self) -> builtins.str:
        result = self._values.get("iothub_name")
        assert result is not None, "Required property 'iothub_name' is missing"
        return result

    @builtins.property
    def name(self) -> builtins.str:
        result = self._values.get("name")
        assert result is not None, "Required property 'name' is missing"
        return result

    @builtins.property
    def resource_group_name(self) -> builtins.str:
        result = self._values.get("resource_group_name")
        assert result is not None, "Required property 'resource_group_name' is missing"
        return result

    @builtins.property
    def device_connect(self) -> typing.Optional[builtins.bool]:
        result = self._values.get("device_connect")
        return result

    @builtins.property
    def registry_read(self) -> typing.Optional[builtins.bool]:
        result = self._values.get("registry_read")
        return result

    @builtins.property
    def registry_write(self) -> typing.Optional[builtins.bool]:
        result = self._values.get("registry_write")
        return result

    @builtins.property
    def service_connect(self) -> typing.Optional[builtins.bool]:
        result = self._values.get("service_connect")
        return result

    @builtins.property
    def timeouts(self) -> typing.Optional["IothubSharedAccessPolicyTimeouts"]:
        """timeouts block."""
        result = self._values.get("timeouts")
        return result

    def __eq__(self, rhs: typing.Any) -> builtins.bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs: typing.Any) -> builtins.bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return "IothubSharedAccessPolicyAConfig(%s)" % ", ".join(
            k + "=" + repr(v) for k, v in self._values.items()
        )


@jsii.data_type(
    jsii_type="@cdktf/provider-azurerm.IothubSharedAccessPolicyTimeouts",
    jsii_struct_bases=[],
    name_mapping={
        "create": "create",
        "delete": "delete",
        "read": "read",
        "update": "update",
    },
)
class IothubSharedAccessPolicyTimeouts:
    def __init__(
        self,
        *,
        create: typing.Optional[builtins.str] = None,
        delete: typing.Optional[builtins.str] = None,
        read: typing.Optional[builtins.str] = None,
        update: typing.Optional[builtins.str] = None,
    ) -> None:
        """
        :param create: 
        :param delete: 
        :param read: 
        :param update: 
        """
        self._values: typing.Dict[str, typing.Any] = {}
        if create is not None:
            self._values["create"] = create
        if delete is not None:
            self._values["delete"] = delete
        if read is not None:
            self._values["read"] = read
        if update is not None:
            self._values["update"] = update

    @builtins.property
    def create(self) -> typing.Optional[builtins.str]:
        result = self._values.get("create")
        return result

    @builtins.property
    def delete(self) -> typing.Optional[builtins.str]:
        result = self._values.get("delete")
        return result

    @builtins.property
    def read(self) -> typing.Optional[builtins.str]:
        result = self._values.get("read")
        return result

    @builtins.property
    def update(self) -> typing.Optional[builtins.str]:
        result = self._values.get("update")
        return result

    def __eq__(self, rhs: typing.Any) -> builtins.bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs: typing.Any) -> builtins.bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return "IothubSharedAccessPolicyTimeouts(%s)" % ", ".join(
            k + "=" + repr(v) for k, v in self._values.items()
        )


@jsii.data_type(
    jsii_type="@cdktf/provider-azurerm.IothubSku",
    jsii_struct_bases=[],
    name_mapping={"capacity": "capacity", "name": "name"},
)
class IothubSku:
    def __init__(self, *, capacity: jsii.Number, name: builtins.str) -> None:
        """
        :param capacity: 
        :param name: 
        """
        self._values: typing.Dict[str, typing.Any] = {
            "capacity": capacity,
            "name": name,
        }

    @builtins.property
    def capacity(self) -> jsii.Number:
        result = self._values.get("capacity")
        assert result is not None, "Required property 'capacity' is missing"
        return result

    @builtins.property
    def name(self) -> builtins.str:
        result = self._values.get("name")
        assert result is not None, "Required property 'name' is missing"
        return result

    def __eq__(self, rhs: typing.Any) -> builtins.bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs: typing.Any) -> builtins.bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return "IothubSku(%s)" % ", ".join(
            k + "=" + repr(v) for k, v in self._values.items()
        )


@jsii.data_type(
    jsii_type="@cdktf/provider-azurerm.IothubTimeouts",
    jsii_struct_bases=[],
    name_mapping={
        "create": "create",
        "delete": "delete",
        "read": "read",
        "update": "update",
    },
)
class IothubTimeouts:
    def __init__(
        self,
        *,
        create: typing.Optional[builtins.str] = None,
        delete: typing.Optional[builtins.str] = None,
        read: typing.Optional[builtins.str] = None,
        update: typing.Optional[builtins.str] = None,
    ) -> None:
        """
        :param create: 
        :param delete: 
        :param read: 
        :param update: 
        """
        self._values: typing.Dict[str, typing.Any] = {}
        if create is not None:
            self._values["create"] = create
        if delete is not None:
            self._values["delete"] = delete
        if read is not None:
            self._values["read"] = read
        if update is not None:
            self._values["update"] = update

    @builtins.property
    def create(self) -> typing.Optional[builtins.str]:
        result = self._values.get("create")
        return result

    @builtins.property
    def delete(self) -> typing.Optional[builtins.str]:
        result = self._values.get("delete")
        return result

    @builtins.property
    def read(self) -> typing.Optional[builtins.str]:
        result = self._values.get("read")
        return result

    @builtins.property
    def update(self) -> typing.Optional[builtins.str]:
        result = self._values.get("update")
        return result

    def __eq__(self, rhs: typing.Any) -> builtins.bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs: typing.Any) -> builtins.bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return "IothubTimeouts(%s)" % ", ".join(
            k + "=" + repr(v) for k, v in self._values.items()
        )


class KeyVault(
    cdktf.TerraformResource,
    metaclass=jsii.JSIIMeta,
    jsii_type="@cdktf/provider-azurerm.KeyVault",
):
    def __init__(
        self,
        scope: constructs.Construct,
        id: builtins.str,
        *,
        location: builtins.str,
        name: builtins.str,
        resource_group_name: builtins.str,
        sku_name: builtins.str,
        tenant_id: builtins.str,
        access_policy: typing.Optional[typing.List["KeyVaultAccessPolicy"]] = None,
        enabled_for_deployment: typing.Optional[builtins.bool] = None,
        enabled_for_disk_encryption: typing.Optional[builtins.bool] = None,
        enabled_for_template_deployment: typing.Optional[builtins.bool] = None,
        network_acls: typing.Optional[typing.List["KeyVaultNetworkAcls"]] = None,
        purge_protection_enabled: typing.Optional[builtins.bool] = None,
        soft_delete_enabled: typing.Optional[builtins.bool] = None,
        tags: typing.Optional[typing.Mapping[builtins.str, builtins.str]] = None,
        timeouts: typing.Optional["KeyVaultTimeouts"] = None,
        count: typing.Optional[jsii.Number] = None,
        depends_on: typing.Optional[typing.List[cdktf.TerraformResource]] = None,
        lifecycle: typing.Optional[cdktf.TerraformResourceLifecycle] = None,
        provider: typing.Optional[cdktf.TerraformProvider] = None,
    ) -> None:
        """
        :param scope: -
        :param id: -
        :param location: 
        :param name: 
        :param resource_group_name: 
        :param sku_name: 
        :param tenant_id: 
        :param access_policy: 
        :param enabled_for_deployment: 
        :param enabled_for_disk_encryption: 
        :param enabled_for_template_deployment: 
        :param network_acls: network_acls block.
        :param purge_protection_enabled: 
        :param soft_delete_enabled: 
        :param tags: 
        :param timeouts: timeouts block.
        :param count: 
        :param depends_on: 
        :param lifecycle: 
        :param provider: 
        """
        config = KeyVaultConfig(
            location=location,
            name=name,
            resource_group_name=resource_group_name,
            sku_name=sku_name,
            tenant_id=tenant_id,
            access_policy=access_policy,
            enabled_for_deployment=enabled_for_deployment,
            enabled_for_disk_encryption=enabled_for_disk_encryption,
            enabled_for_template_deployment=enabled_for_template_deployment,
            network_acls=network_acls,
            purge_protection_enabled=purge_protection_enabled,
            soft_delete_enabled=soft_delete_enabled,
            tags=tags,
            timeouts=timeouts,
            count=count,
            depends_on=depends_on,
            lifecycle=lifecycle,
            provider=provider,
        )

        jsii.create(KeyVault, self, [scope, id, config])

    @jsii.member(jsii_name="synthesizeAttributes")
    def _synthesize_attributes(self) -> typing.Mapping[builtins.str, typing.Any]:
        return jsii.invoke(self, "synthesizeAttributes", [])

    @builtins.property # type: ignore
    @jsii.member(jsii_name="vaultUri")
    def vault_uri(self) -> builtins.str:
        return jsii.get(self, "vaultUri")

    @builtins.property # type: ignore
    @jsii.member(jsii_name="location")
    def location(self) -> builtins.str:
        return jsii.get(self, "location")

    @location.setter # type: ignore
    def location(self, value: builtins.str) -> None:
        jsii.set(self, "location", value)

    @builtins.property # type: ignore
    @jsii.member(jsii_name="name")
    def name(self) -> builtins.str:
        return jsii.get(self, "name")

    @name.setter # type: ignore
    def name(self, value: builtins.str) -> None:
        jsii.set(self, "name", value)

    @builtins.property # type: ignore
    @jsii.member(jsii_name="resourceGroupName")
    def resource_group_name(self) -> builtins.str:
        return jsii.get(self, "resourceGroupName")

    @resource_group_name.setter # type: ignore
    def resource_group_name(self, value: builtins.str) -> None:
        jsii.set(self, "resourceGroupName", value)

    @builtins.property # type: ignore
    @jsii.member(jsii_name="skuName")
    def sku_name(self) -> builtins.str:
        return jsii.get(self, "skuName")

    @sku_name.setter # type: ignore
    def sku_name(self, value: builtins.str) -> None:
        jsii.set(self, "skuName", value)

    @builtins.property # type: ignore
    @jsii.member(jsii_name="tenantId")
    def tenant_id(self) -> builtins.str:
        return jsii.get(self, "tenantId")

    @tenant_id.setter # type: ignore
    def tenant_id(self, value: builtins.str) -> None:
        jsii.set(self, "tenantId", value)

    @builtins.property # type: ignore
    @jsii.member(jsii_name="accessPolicy")
    def access_policy(self) -> typing.Optional[typing.List["KeyVaultAccessPolicy"]]:
        return jsii.get(self, "accessPolicy")

    @access_policy.setter # type: ignore
    def access_policy(
        self,
        value: typing.Optional[typing.List["KeyVaultAccessPolicy"]],
    ) -> None:
        jsii.set(self, "accessPolicy", value)

    @builtins.property # type: ignore
    @jsii.member(jsii_name="enabledForDeployment")
    def enabled_for_deployment(self) -> typing.Optional[builtins.bool]:
        return jsii.get(self, "enabledForDeployment")

    @enabled_for_deployment.setter # type: ignore
    def enabled_for_deployment(self, value: typing.Optional[builtins.bool]) -> None:
        jsii.set(self, "enabledForDeployment", value)

    @builtins.property # type: ignore
    @jsii.member(jsii_name="enabledForDiskEncryption")
    def enabled_for_disk_encryption(self) -> typing.Optional[builtins.bool]:
        return jsii.get(self, "enabledForDiskEncryption")

    @enabled_for_disk_encryption.setter # type: ignore
    def enabled_for_disk_encryption(
        self,
        value: typing.Optional[builtins.bool],
    ) -> None:
        jsii.set(self, "enabledForDiskEncryption", value)

    @builtins.property # type: ignore
    @jsii.member(jsii_name="enabledForTemplateDeployment")
    def enabled_for_template_deployment(self) -> typing.Optional[builtins.bool]:
        return jsii.get(self, "enabledForTemplateDeployment")

    @enabled_for_template_deployment.setter # type: ignore
    def enabled_for_template_deployment(
        self,
        value: typing.Optional[builtins.bool],
    ) -> None:
        jsii.set(self, "enabledForTemplateDeployment", value)

    @builtins.property # type: ignore
    @jsii.member(jsii_name="id")
    def id(self) -> typing.Optional[builtins.str]:
        return jsii.get(self, "id")

    @id.setter # type: ignore
    def id(self, value: typing.Optional[builtins.str]) -> None:
        jsii.set(self, "id", value)

    @builtins.property # type: ignore
    @jsii.member(jsii_name="networkAcls")
    def network_acls(self) -> typing.Optional[typing.List["KeyVaultNetworkAcls"]]:
        return jsii.get(self, "networkAcls")

    @network_acls.setter # type: ignore
    def network_acls(
        self,
        value: typing.Optional[typing.List["KeyVaultNetworkAcls"]],
    ) -> None:
        jsii.set(self, "networkAcls", value)

    @builtins.property # type: ignore
    @jsii.member(jsii_name="purgeProtectionEnabled")
    def purge_protection_enabled(self) -> typing.Optional[builtins.bool]:
        return jsii.get(self, "purgeProtectionEnabled")

    @purge_protection_enabled.setter # type: ignore
    def purge_protection_enabled(self, value: typing.Optional[builtins.bool]) -> None:
        jsii.set(self, "purgeProtectionEnabled", value)

    @builtins.property # type: ignore
    @jsii.member(jsii_name="softDeleteEnabled")
    def soft_delete_enabled(self) -> typing.Optional[builtins.bool]:
        return jsii.get(self, "softDeleteEnabled")

    @soft_delete_enabled.setter # type: ignore
    def soft_delete_enabled(self, value: typing.Optional[builtins.bool]) -> None:
        jsii.set(self, "softDeleteEnabled", value)

    @builtins.property # type: ignore
    @jsii.member(jsii_name="tags")
    def tags(self) -> typing.Optional[typing.Mapping[builtins.str, builtins.str]]:
        return jsii.get(self, "tags")

    @tags.setter # type: ignore
    def tags(
        self,
        value: typing.Optional[typing.Mapping[builtins.str, builtins.str]],
    ) -> None:
        jsii.set(self, "tags", value)

    @builtins.property # type: ignore
    @jsii.member(jsii_name="timeouts")
    def timeouts(self) -> typing.Optional["KeyVaultTimeouts"]:
        return jsii.get(self, "timeouts")

    @timeouts.setter # type: ignore
    def timeouts(self, value: typing.Optional["KeyVaultTimeouts"]) -> None:
        jsii.set(self, "timeouts", value)


@jsii.data_type(
    jsii_type="@cdktf/provider-azurerm.KeyVaultAccessPolicy",
    jsii_struct_bases=[],
    name_mapping={
        "application_id": "applicationId",
        "certificate_permissions": "certificatePermissions",
        "key_permissions": "keyPermissions",
        "object_id": "objectId",
        "secret_permissions": "secretPermissions",
        "storage_permissions": "storagePermissions",
        "tenant_id": "tenantId",
    },
)
class KeyVaultAccessPolicy:
    def __init__(
        self,
        *,
        application_id: typing.Optional[builtins.str] = None,
        certificate_permissions: typing.Optional[typing.List[builtins.str]] = None,
        key_permissions: typing.Optional[typing.List[builtins.str]] = None,
        object_id: typing.Optional[builtins.str] = None,
        secret_permissions: typing.Optional[typing.List[builtins.str]] = None,
        storage_permissions: typing.Optional[typing.List[builtins.str]] = None,
        tenant_id: typing.Optional[builtins.str] = None,
    ) -> None:
        """
        :param application_id: 
        :param certificate_permissions: 
        :param key_permissions: 
        :param object_id: 
        :param secret_permissions: 
        :param storage_permissions: 
        :param tenant_id: 
        """
        self._values: typing.Dict[str, typing.Any] = {}
        if application_id is not None:
            self._values["application_id"] = application_id
        if certificate_permissions is not None:
            self._values["certificate_permissions"] = certificate_permissions
        if key_permissions is not None:
            self._values["key_permissions"] = key_permissions
        if object_id is not None:
            self._values["object_id"] = object_id
        if secret_permissions is not None:
            self._values["secret_permissions"] = secret_permissions
        if storage_permissions is not None:
            self._values["storage_permissions"] = storage_permissions
        if tenant_id is not None:
            self._values["tenant_id"] = tenant_id

    @builtins.property
    def application_id(self) -> typing.Optional[builtins.str]:
        result = self._values.get("application_id")
        return result

    @builtins.property
    def certificate_permissions(self) -> typing.Optional[typing.List[builtins.str]]:
        result = self._values.get("certificate_permissions")
        return result

    @builtins.property
    def key_permissions(self) -> typing.Optional[typing.List[builtins.str]]:
        result = self._values.get("key_permissions")
        return result

    @builtins.property
    def object_id(self) -> typing.Optional[builtins.str]:
        result = self._values.get("object_id")
        return result

    @builtins.property
    def secret_permissions(self) -> typing.Optional[typing.List[builtins.str]]:
        result = self._values.get("secret_permissions")
        return result

    @builtins.property
    def storage_permissions(self) -> typing.Optional[typing.List[builtins.str]]:
        result = self._values.get("storage_permissions")
        return result

    @builtins.property
    def tenant_id(self) -> typing.Optional[builtins.str]:
        result = self._values.get("tenant_id")
        return result

    def __eq__(self, rhs: typing.Any) -> builtins.bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs: typing.Any) -> builtins.bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return "KeyVaultAccessPolicy(%s)" % ", ".join(
            k + "=" + repr(v) for k, v in self._values.items()
        )


class KeyVaultAccessPolicyA(
    cdktf.TerraformResource,
    metaclass=jsii.JSIIMeta,
    jsii_type="@cdktf/provider-azurerm.KeyVaultAccessPolicyA",
):
    def __init__(
        self,
        scope: constructs.Construct,
        id: builtins.str,
        *,
        key_vault_id: builtins.str,
        object_id: builtins.str,
        tenant_id: builtins.str,
        application_id: typing.Optional[builtins.str] = None,
        certificate_permissions: typing.Optional[typing.List[builtins.str]] = None,
        key_permissions: typing.Optional[typing.List[builtins.str]] = None,
        secret_permissions: typing.Optional[typing.List[builtins.str]] = None,
        storage_permissions: typing.Optional[typing.List[builtins.str]] = None,
        timeouts: typing.Optional["KeyVaultAccessPolicyTimeouts"] = None,
        count: typing.Optional[jsii.Number] = None,
        depends_on: typing.Optional[typing.List[cdktf.TerraformResource]] = None,
        lifecycle: typing.Optional[cdktf.TerraformResourceLifecycle] = None,
        provider: typing.Optional[cdktf.TerraformProvider] = None,
    ) -> None:
        """
        :param scope: -
        :param id: -
        :param key_vault_id: 
        :param object_id: 
        :param tenant_id: 
        :param application_id: 
        :param certificate_permissions: 
        :param key_permissions: 
        :param secret_permissions: 
        :param storage_permissions: 
        :param timeouts: timeouts block.
        :param count: 
        :param depends_on: 
        :param lifecycle: 
        :param provider: 
        """
        config = KeyVaultAccessPolicyAConfig(
            key_vault_id=key_vault_id,
            object_id=object_id,
            tenant_id=tenant_id,
            application_id=application_id,
            certificate_permissions=certificate_permissions,
            key_permissions=key_permissions,
            secret_permissions=secret_permissions,
            storage_permissions=storage_permissions,
            timeouts=timeouts,
            count=count,
            depends_on=depends_on,
            lifecycle=lifecycle,
            provider=provider,
        )

        jsii.create(KeyVaultAccessPolicyA, self, [scope, id, config])

    @jsii.member(jsii_name="synthesizeAttributes")
    def _synthesize_attributes(self) -> typing.Mapping[builtins.str, typing.Any]:
        return jsii.invoke(self, "synthesizeAttributes", [])

    @builtins.property # type: ignore
    @jsii.member(jsii_name="keyVaultId")
    def key_vault_id(self) -> builtins.str:
        return jsii.get(self, "keyVaultId")

    @key_vault_id.setter # type: ignore
    def key_vault_id(self, value: builtins.str) -> None:
        jsii.set(self, "keyVaultId", value)

    @builtins.property # type: ignore
    @jsii.member(jsii_name="objectId")
    def object_id(self) -> builtins.str:
        return jsii.get(self, "objectId")

    @object_id.setter # type: ignore
    def object_id(self, value: builtins.str) -> None:
        jsii.set(self, "objectId", value)

    @builtins.property # type: ignore
    @jsii.member(jsii_name="tenantId")
    def tenant_id(self) -> builtins.str:
        return jsii.get(self, "tenantId")

    @tenant_id.setter # type: ignore
    def tenant_id(self, value: builtins.str) -> None:
        jsii.set(self, "tenantId", value)

    @builtins.property # type: ignore
    @jsii.member(jsii_name="applicationId")
    def application_id(self) -> typing.Optional[builtins.str]:
        return jsii.get(self, "applicationId")

    @application_id.setter # type: ignore
    def application_id(self, value: typing.Optional[builtins.str]) -> None:
        jsii.set(self, "applicationId", value)

    @builtins.property # type: ignore
    @jsii.member(jsii_name="certificatePermissions")
    def certificate_permissions(self) -> typing.Optional[typing.List[builtins.str]]:
        return jsii.get(self, "certificatePermissions")

    @certificate_permissions.setter # type: ignore
    def certificate_permissions(
        self,
        value: typing.Optional[typing.List[builtins.str]],
    ) -> None:
        jsii.set(self, "certificatePermissions", value)

    @builtins.property # type: ignore
    @jsii.member(jsii_name="id")
    def id(self) -> typing.Optional[builtins.str]:
        return jsii.get(self, "id")

    @id.setter # type: ignore
    def id(self, value: typing.Optional[builtins.str]) -> None:
        jsii.set(self, "id", value)

    @builtins.property # type: ignore
    @jsii.member(jsii_name="keyPermissions")
    def key_permissions(self) -> typing.Optional[typing.List[builtins.str]]:
        return jsii.get(self, "keyPermissions")

    @key_permissions.setter # type: ignore
    def key_permissions(
        self,
        value: typing.Optional[typing.List[builtins.str]],
    ) -> None:
        jsii.set(self, "keyPermissions", value)

    @builtins.property # type: ignore
    @jsii.member(jsii_name="secretPermissions")
    def secret_permissions(self) -> typing.Optional[typing.List[builtins.str]]:
        return jsii.get(self, "secretPermissions")

    @secret_permissions.setter # type: ignore
    def secret_permissions(
        self,
        value: typing.Optional[typing.List[builtins.str]],
    ) -> None:
        jsii.set(self, "secretPermissions", value)

    @builtins.property # type: ignore
    @jsii.member(jsii_name="storagePermissions")
    def storage_permissions(self) -> typing.Optional[typing.List[builtins.str]]:
        return jsii.get(self, "storagePermissions")

    @storage_permissions.setter # type: ignore
    def storage_permissions(
        self,
        value: typing.Optional[typing.List[builtins.str]],
    ) -> None:
        jsii.set(self, "storagePermissions", value)

    @builtins.property # type: ignore
    @jsii.member(jsii_name="timeouts")
    def timeouts(self) -> typing.Optional["KeyVaultAccessPolicyTimeouts"]:
        return jsii.get(self, "timeouts")

    @timeouts.setter # type: ignore
    def timeouts(self, value: typing.Optional["KeyVaultAccessPolicyTimeouts"]) -> None:
        jsii.set(self, "timeouts", value)


@jsii.data_type(
    jsii_type="@cdktf/provider-azurerm.KeyVaultAccessPolicyAConfig",
    jsii_struct_bases=[cdktf.TerraformMetaArguments],
    name_mapping={
        "count": "count",
        "depends_on": "dependsOn",
        "lifecycle": "lifecycle",
        "provider": "provider",
        "key_vault_id": "keyVaultId",
        "object_id": "objectId",
        "tenant_id": "tenantId",
        "application_id": "applicationId",
        "certificate_permissions": "certificatePermissions",
        "key_permissions": "keyPermissions",
        "secret_permissions": "secretPermissions",
        "storage_permissions": "storagePermissions",
        "timeouts": "timeouts",
    },
)
class KeyVaultAccessPolicyAConfig(cdktf.TerraformMetaArguments):
    def __init__(
        self,
        *,
        count: typing.Optional[jsii.Number] = None,
        depends_on: typing.Optional[typing.List[cdktf.TerraformResource]] = None,
        lifecycle: typing.Optional[cdktf.TerraformResourceLifecycle] = None,
        provider: typing.Optional[cdktf.TerraformProvider] = None,
        key_vault_id: builtins.str,
        object_id: builtins.str,
        tenant_id: builtins.str,
        application_id: typing.Optional[builtins.str] = None,
        certificate_permissions: typing.Optional[typing.List[builtins.str]] = None,
        key_permissions: typing.Optional[typing.List[builtins.str]] = None,
        secret_permissions: typing.Optional[typing.List[builtins.str]] = None,
        storage_permissions: typing.Optional[typing.List[builtins.str]] = None,
        timeouts: typing.Optional["KeyVaultAccessPolicyTimeouts"] = None,
    ) -> None:
        """
        :param count: 
        :param depends_on: 
        :param lifecycle: 
        :param provider: 
        :param key_vault_id: 
        :param object_id: 
        :param tenant_id: 
        :param application_id: 
        :param certificate_permissions: 
        :param key_permissions: 
        :param secret_permissions: 
        :param storage_permissions: 
        :param timeouts: timeouts block.
        """
        if isinstance(lifecycle, dict):
            lifecycle = cdktf.TerraformResourceLifecycle(**lifecycle)
        if isinstance(timeouts, dict):
            timeouts = KeyVaultAccessPolicyTimeouts(**timeouts)
        self._values: typing.Dict[str, typing.Any] = {
            "key_vault_id": key_vault_id,
            "object_id": object_id,
            "tenant_id": tenant_id,
        }
        if count is not None:
            self._values["count"] = count
        if depends_on is not None:
            self._values["depends_on"] = depends_on
        if lifecycle is not None:
            self._values["lifecycle"] = lifecycle
        if provider is not None:
            self._values["provider"] = provider
        if application_id is not None:
            self._values["application_id"] = application_id
        if certificate_permissions is not None:
            self._values["certificate_permissions"] = certificate_permissions
        if key_permissions is not None:
            self._values["key_permissions"] = key_permissions
        if secret_permissions is not None:
            self._values["secret_permissions"] = secret_permissions
        if storage_permissions is not None:
            self._values["storage_permissions"] = storage_permissions
        if timeouts is not None:
            self._values["timeouts"] = timeouts

    @builtins.property
    def count(self) -> typing.Optional[jsii.Number]:
        """
        :stability: experimental
        """
        result = self._values.get("count")
        return result

    @builtins.property
    def depends_on(self) -> typing.Optional[typing.List[cdktf.TerraformResource]]:
        """
        :stability: experimental
        """
        result = self._values.get("depends_on")
        return result

    @builtins.property
    def lifecycle(self) -> typing.Optional[cdktf.TerraformResourceLifecycle]:
        """
        :stability: experimental
        """
        result = self._values.get("lifecycle")
        return result

    @builtins.property
    def provider(self) -> typing.Optional[cdktf.TerraformProvider]:
        """
        :stability: experimental
        """
        result = self._values.get("provider")
        return result

    @builtins.property
    def key_vault_id(self) -> builtins.str:
        result = self._values.get("key_vault_id")
        assert result is not None, "Required property 'key_vault_id' is missing"
        return result

    @builtins.property
    def object_id(self) -> builtins.str:
        result = self._values.get("object_id")
        assert result is not None, "Required property 'object_id' is missing"
        return result

    @builtins.property
    def tenant_id(self) -> builtins.str:
        result = self._values.get("tenant_id")
        assert result is not None, "Required property 'tenant_id' is missing"
        return result

    @builtins.property
    def application_id(self) -> typing.Optional[builtins.str]:
        result = self._values.get("application_id")
        return result

    @builtins.property
    def certificate_permissions(self) -> typing.Optional[typing.List[builtins.str]]:
        result = self._values.get("certificate_permissions")
        return result

    @builtins.property
    def key_permissions(self) -> typing.Optional[typing.List[builtins.str]]:
        result = self._values.get("key_permissions")
        return result

    @builtins.property
    def secret_permissions(self) -> typing.Optional[typing.List[builtins.str]]:
        result = self._values.get("secret_permissions")
        return result

    @builtins.property
    def storage_permissions(self) -> typing.Optional[typing.List[builtins.str]]:
        result = self._values.get("storage_permissions")
        return result

    @builtins.property
    def timeouts(self) -> typing.Optional["KeyVaultAccessPolicyTimeouts"]:
        """timeouts block."""
        result = self._values.get("timeouts")
        return result

    def __eq__(self, rhs: typing.Any) -> builtins.bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs: typing.Any) -> builtins.bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return "KeyVaultAccessPolicyAConfig(%s)" % ", ".join(
            k + "=" + repr(v) for k, v in self._values.items()
        )


@jsii.data_type(
    jsii_type="@cdktf/provider-azurerm.KeyVaultAccessPolicyTimeouts",
    jsii_struct_bases=[],
    name_mapping={
        "create": "create",
        "delete": "delete",
        "read": "read",
        "update": "update",
    },
)
class KeyVaultAccessPolicyTimeouts:
    def __init__(
        self,
        *,
        create: typing.Optional[builtins.str] = None,
        delete: typing.Optional[builtins.str] = None,
        read: typing.Optional[builtins.str] = None,
        update: typing.Optional[builtins.str] = None,
    ) -> None:
        """
        :param create: 
        :param delete: 
        :param read: 
        :param update: 
        """
        self._values: typing.Dict[str, typing.Any] = {}
        if create is not None:
            self._values["create"] = create
        if delete is not None:
            self._values["delete"] = delete
        if read is not None:
            self._values["read"] = read
        if update is not None:
            self._values["update"] = update

    @builtins.property
    def create(self) -> typing.Optional[builtins.str]:
        result = self._values.get("create")
        return result

    @builtins.property
    def delete(self) -> typing.Optional[builtins.str]:
        result = self._values.get("delete")
        return result

    @builtins.property
    def read(self) -> typing.Optional[builtins.str]:
        result = self._values.get("read")
        return result

    @builtins.property
    def update(self) -> typing.Optional[builtins.str]:
        result = self._values.get("update")
        return result

    def __eq__(self, rhs: typing.Any) -> builtins.bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs: typing.Any) -> builtins.bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return "KeyVaultAccessPolicyTimeouts(%s)" % ", ".join(
            k + "=" + repr(v) for k, v in self._values.items()
        )


class KeyVaultCertificate(
    cdktf.TerraformResource,
    metaclass=jsii.JSIIMeta,
    jsii_type="@cdktf/provider-azurerm.KeyVaultCertificate",
):
    def __init__(
        self,
        scope: constructs.Construct,
        id: builtins.str,
        *,
        certificate_policy: typing.List["KeyVaultCertificateCertificatePolicy"],
        key_vault_id: builtins.str,
        name: builtins.str,
        certificate: typing.Optional[typing.List["KeyVaultCertificateCertificate"]] = None,
        tags: typing.Optional[typing.Mapping[builtins.str, builtins.str]] = None,
        timeouts: typing.Optional["KeyVaultCertificateTimeouts"] = None,
        count: typing.Optional[jsii.Number] = None,
        depends_on: typing.Optional[typing.List[cdktf.TerraformResource]] = None,
        lifecycle: typing.Optional[cdktf.TerraformResourceLifecycle] = None,
        provider: typing.Optional[cdktf.TerraformProvider] = None,
    ) -> None:
        """
        :param scope: -
        :param id: -
        :param certificate_policy: certificate_policy block.
        :param key_vault_id: 
        :param name: 
        :param certificate: certificate block.
        :param tags: 
        :param timeouts: timeouts block.
        :param count: 
        :param depends_on: 
        :param lifecycle: 
        :param provider: 
        """
        config = KeyVaultCertificateConfig(
            certificate_policy=certificate_policy,
            key_vault_id=key_vault_id,
            name=name,
            certificate=certificate,
            tags=tags,
            timeouts=timeouts,
            count=count,
            depends_on=depends_on,
            lifecycle=lifecycle,
            provider=provider,
        )

        jsii.create(KeyVaultCertificate, self, [scope, id, config])

    @jsii.member(jsii_name="synthesizeAttributes")
    def _synthesize_attributes(self) -> typing.Mapping[builtins.str, typing.Any]:
        return jsii.invoke(self, "synthesizeAttributes", [])

    @builtins.property # type: ignore
    @jsii.member(jsii_name="certificateData")
    def certificate_data(self) -> builtins.str:
        return jsii.get(self, "certificateData")

    @builtins.property # type: ignore
    @jsii.member(jsii_name="secretId")
    def secret_id(self) -> builtins.str:
        return jsii.get(self, "secretId")

    @builtins.property # type: ignore
    @jsii.member(jsii_name="thumbprint")
    def thumbprint(self) -> builtins.str:
        return jsii.get(self, "thumbprint")

    @builtins.property # type: ignore
    @jsii.member(jsii_name="version")
    def version(self) -> builtins.str:
        return jsii.get(self, "version")

    @builtins.property # type: ignore
    @jsii.member(jsii_name="certificatePolicy")
    def certificate_policy(self) -> typing.List["KeyVaultCertificateCertificatePolicy"]:
        return jsii.get(self, "certificatePolicy")

    @certificate_policy.setter # type: ignore
    def certificate_policy(
        self,
        value: typing.List["KeyVaultCertificateCertificatePolicy"],
    ) -> None:
        jsii.set(self, "certificatePolicy", value)

    @builtins.property # type: ignore
    @jsii.member(jsii_name="keyVaultId")
    def key_vault_id(self) -> builtins.str:
        return jsii.get(self, "keyVaultId")

    @key_vault_id.setter # type: ignore
    def key_vault_id(self, value: builtins.str) -> None:
        jsii.set(self, "keyVaultId", value)

    @builtins.property # type: ignore
    @jsii.member(jsii_name="name")
    def name(self) -> builtins.str:
        return jsii.get(self, "name")

    @name.setter # type: ignore
    def name(self, value: builtins.str) -> None:
        jsii.set(self, "name", value)

    @builtins.property # type: ignore
    @jsii.member(jsii_name="certificate")
    def certificate(
        self,
    ) -> typing.Optional[typing.List["KeyVaultCertificateCertificate"]]:
        return jsii.get(self, "certificate")

    @certificate.setter # type: ignore
    def certificate(
        self,
        value: typing.Optional[typing.List["KeyVaultCertificateCertificate"]],
    ) -> None:
        jsii.set(self, "certificate", value)

    @builtins.property # type: ignore
    @jsii.member(jsii_name="id")
    def id(self) -> typing.Optional[builtins.str]:
        return jsii.get(self, "id")

    @id.setter # type: ignore
    def id(self, value: typing.Optional[builtins.str]) -> None:
        jsii.set(self, "id", value)

    @builtins.property # type: ignore
    @jsii.member(jsii_name="tags")
    def tags(self) -> typing.Optional[typing.Mapping[builtins.str, builtins.str]]:
        return jsii.get(self, "tags")

    @tags.setter # type: ignore
    def tags(
        self,
        value: typing.Optional[typing.Mapping[builtins.str, builtins.str]],
    ) -> None:
        jsii.set(self, "tags", value)

    @builtins.property # type: ignore
    @jsii.member(jsii_name="timeouts")
    def timeouts(self) -> typing.Optional["KeyVaultCertificateTimeouts"]:
        return jsii.get(self, "timeouts")

    @timeouts.setter # type: ignore
    def timeouts(self, value: typing.Optional["KeyVaultCertificateTimeouts"]) -> None:
        jsii.set(self, "timeouts", value)


@jsii.data_type(
    jsii_type="@cdktf/provider-azurerm.KeyVaultCertificateCertificate",
    jsii_struct_bases=[],
    name_mapping={"contents": "contents", "password": "password"},
)
class KeyVaultCertificateCertificate:
    def __init__(
        self,
        *,
        contents: builtins.str,
        password: typing.Optional[builtins.str] = None,
    ) -> None:
        """
        :param contents: 
        :param password: 
        """
        self._values: typing.Dict[str, typing.Any] = {
            "contents": contents,
        }
        if password is not None:
            self._values["password"] = password

    @builtins.property
    def contents(self) -> builtins.str:
        result = self._values.get("contents")
        assert result is not None, "Required property 'contents' is missing"
        return result

    @builtins.property
    def password(self) -> typing.Optional[builtins.str]:
        result = self._values.get("password")
        return result

    def __eq__(self, rhs: typing.Any) -> builtins.bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs: typing.Any) -> builtins.bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return "KeyVaultCertificateCertificate(%s)" % ", ".join(
            k + "=" + repr(v) for k, v in self._values.items()
        )


@jsii.data_type(
    jsii_type="@cdktf/provider-azurerm.KeyVaultCertificateCertificatePolicy",
    jsii_struct_bases=[],
    name_mapping={
        "issuer_parameters": "issuerParameters",
        "key_properties": "keyProperties",
        "secret_properties": "secretProperties",
        "lifetime_action": "lifetimeAction",
        "x509_certificate_properties": "x509CertificateProperties",
    },
)
class KeyVaultCertificateCertificatePolicy:
    def __init__(
        self,
        *,
        issuer_parameters: typing.List["KeyVaultCertificateCertificatePolicyIssuerParameters"],
        key_properties: typing.List["KeyVaultCertificateCertificatePolicyKeyProperties"],
        secret_properties: typing.List["KeyVaultCertificateCertificatePolicySecretProperties"],
        lifetime_action: typing.Optional[typing.List["KeyVaultCertificateCertificatePolicyLifetimeAction"]] = None,
        x509_certificate_properties: typing.Optional[typing.List["KeyVaultCertificateCertificatePolicyX509CertificateProperties"]] = None,
    ) -> None:
        """
        :param issuer_parameters: issuer_parameters block.
        :param key_properties: key_properties block.
        :param secret_properties: secret_properties block.
        :param lifetime_action: lifetime_action block.
        :param x509_certificate_properties: x509_certificate_properties block.
        """
        self._values: typing.Dict[str, typing.Any] = {
            "issuer_parameters": issuer_parameters,
            "key_properties": key_properties,
            "secret_properties": secret_properties,
        }
        if lifetime_action is not None:
            self._values["lifetime_action"] = lifetime_action
        if x509_certificate_properties is not None:
            self._values["x509_certificate_properties"] = x509_certificate_properties

    @builtins.property
    def issuer_parameters(
        self,
    ) -> typing.List["KeyVaultCertificateCertificatePolicyIssuerParameters"]:
        """issuer_parameters block."""
        result = self._values.get("issuer_parameters")
        assert result is not None, "Required property 'issuer_parameters' is missing"
        return result

    @builtins.property
    def key_properties(
        self,
    ) -> typing.List["KeyVaultCertificateCertificatePolicyKeyProperties"]:
        """key_properties block."""
        result = self._values.get("key_properties")
        assert result is not None, "Required property 'key_properties' is missing"
        return result

    @builtins.property
    def secret_properties(
        self,
    ) -> typing.List["KeyVaultCertificateCertificatePolicySecretProperties"]:
        """secret_properties block."""
        result = self._values.get("secret_properties")
        assert result is not None, "Required property 'secret_properties' is missing"
        return result

    @builtins.property
    def lifetime_action(
        self,
    ) -> typing.Optional[typing.List["KeyVaultCertificateCertificatePolicyLifetimeAction"]]:
        """lifetime_action block."""
        result = self._values.get("lifetime_action")
        return result

    @builtins.property
    def x509_certificate_properties(
        self,
    ) -> typing.Optional[typing.List["KeyVaultCertificateCertificatePolicyX509CertificateProperties"]]:
        """x509_certificate_properties block."""
        result = self._values.get("x509_certificate_properties")
        return result

    def __eq__(self, rhs: typing.Any) -> builtins.bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs: typing.Any) -> builtins.bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return "KeyVaultCertificateCertificatePolicy(%s)" % ", ".join(
            k + "=" + repr(v) for k, v in self._values.items()
        )


@jsii.data_type(
    jsii_type="@cdktf/provider-azurerm.KeyVaultCertificateCertificatePolicyIssuerParameters",
    jsii_struct_bases=[],
    name_mapping={"name": "name"},
)
class KeyVaultCertificateCertificatePolicyIssuerParameters:
    def __init__(self, *, name: builtins.str) -> None:
        """
        :param name: 
        """
        self._values: typing.Dict[str, typing.Any] = {
            "name": name,
        }

    @builtins.property
    def name(self) -> builtins.str:
        result = self._values.get("name")
        assert result is not None, "Required property 'name' is missing"
        return result

    def __eq__(self, rhs: typing.Any) -> builtins.bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs: typing.Any) -> builtins.bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return "KeyVaultCertificateCertificatePolicyIssuerParameters(%s)" % ", ".join(
            k + "=" + repr(v) for k, v in self._values.items()
        )


@jsii.data_type(
    jsii_type="@cdktf/provider-azurerm.KeyVaultCertificateCertificatePolicyKeyProperties",
    jsii_struct_bases=[],
    name_mapping={
        "exportable": "exportable",
        "key_size": "keySize",
        "key_type": "keyType",
        "reuse_key": "reuseKey",
    },
)
class KeyVaultCertificateCertificatePolicyKeyProperties:
    def __init__(
        self,
        *,
        exportable: builtins.bool,
        key_size: jsii.Number,
        key_type: builtins.str,
        reuse_key: builtins.bool,
    ) -> None:
        """
        :param exportable: 
        :param key_size: 
        :param key_type: 
        :param reuse_key: 
        """
        self._values: typing.Dict[str, typing.Any] = {
            "exportable": exportable,
            "key_size": key_size,
            "key_type": key_type,
            "reuse_key": reuse_key,
        }

    @builtins.property
    def exportable(self) -> builtins.bool:
        result = self._values.get("exportable")
        assert result is not None, "Required property 'exportable' is missing"
        return result

    @builtins.property
    def key_size(self) -> jsii.Number:
        result = self._values.get("key_size")
        assert result is not None, "Required property 'key_size' is missing"
        return result

    @builtins.property
    def key_type(self) -> builtins.str:
        result = self._values.get("key_type")
        assert result is not None, "Required property 'key_type' is missing"
        return result

    @builtins.property
    def reuse_key(self) -> builtins.bool:
        result = self._values.get("reuse_key")
        assert result is not None, "Required property 'reuse_key' is missing"
        return result

    def __eq__(self, rhs: typing.Any) -> builtins.bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs: typing.Any) -> builtins.bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return "KeyVaultCertificateCertificatePolicyKeyProperties(%s)" % ", ".join(
            k + "=" + repr(v) for k, v in self._values.items()
        )


@jsii.data_type(
    jsii_type="@cdktf/provider-azurerm.KeyVaultCertificateCertificatePolicyLifetimeAction",
    jsii_struct_bases=[],
    name_mapping={"action": "action", "trigger": "trigger"},
)
class KeyVaultCertificateCertificatePolicyLifetimeAction:
    def __init__(
        self,
        *,
        action: typing.List["KeyVaultCertificateCertificatePolicyLifetimeActionAction"],
        trigger: typing.List["KeyVaultCertificateCertificatePolicyLifetimeActionTrigger"],
    ) -> None:
        """
        :param action: action block.
        :param trigger: trigger block.
        """
        self._values: typing.Dict[str, typing.Any] = {
            "action": action,
            "trigger": trigger,
        }

    @builtins.property
    def action(
        self,
    ) -> typing.List["KeyVaultCertificateCertificatePolicyLifetimeActionAction"]:
        """action block."""
        result = self._values.get("action")
        assert result is not None, "Required property 'action' is missing"
        return result

    @builtins.property
    def trigger(
        self,
    ) -> typing.List["KeyVaultCertificateCertificatePolicyLifetimeActionTrigger"]:
        """trigger block."""
        result = self._values.get("trigger")
        assert result is not None, "Required property 'trigger' is missing"
        return result

    def __eq__(self, rhs: typing.Any) -> builtins.bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs: typing.Any) -> builtins.bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return "KeyVaultCertificateCertificatePolicyLifetimeAction(%s)" % ", ".join(
            k + "=" + repr(v) for k, v in self._values.items()
        )


@jsii.data_type(
    jsii_type="@cdktf/provider-azurerm.KeyVaultCertificateCertificatePolicyLifetimeActionAction",
    jsii_struct_bases=[],
    name_mapping={"action_type": "actionType"},
)
class KeyVaultCertificateCertificatePolicyLifetimeActionAction:
    def __init__(self, *, action_type: builtins.str) -> None:
        """
        :param action_type: 
        """
        self._values: typing.Dict[str, typing.Any] = {
            "action_type": action_type,
        }

    @builtins.property
    def action_type(self) -> builtins.str:
        result = self._values.get("action_type")
        assert result is not None, "Required property 'action_type' is missing"
        return result

    def __eq__(self, rhs: typing.Any) -> builtins.bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs: typing.Any) -> builtins.bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return "KeyVaultCertificateCertificatePolicyLifetimeActionAction(%s)" % ", ".join(
            k + "=" + repr(v) for k, v in self._values.items()
        )


@jsii.data_type(
    jsii_type="@cdktf/provider-azurerm.KeyVaultCertificateCertificatePolicyLifetimeActionTrigger",
    jsii_struct_bases=[],
    name_mapping={
        "days_before_expiry": "daysBeforeExpiry",
        "lifetime_percentage": "lifetimePercentage",
    },
)
class KeyVaultCertificateCertificatePolicyLifetimeActionTrigger:
    def __init__(
        self,
        *,
        days_before_expiry: typing.Optional[jsii.Number] = None,
        lifetime_percentage: typing.Optional[jsii.Number] = None,
    ) -> None:
        """
        :param days_before_expiry: 
        :param lifetime_percentage: 
        """
        self._values: typing.Dict[str, typing.Any] = {}
        if days_before_expiry is not None:
            self._values["days_before_expiry"] = days_before_expiry
        if lifetime_percentage is not None:
            self._values["lifetime_percentage"] = lifetime_percentage

    @builtins.property
    def days_before_expiry(self) -> typing.Optional[jsii.Number]:
        result = self._values.get("days_before_expiry")
        return result

    @builtins.property
    def lifetime_percentage(self) -> typing.Optional[jsii.Number]:
        result = self._values.get("lifetime_percentage")
        return result

    def __eq__(self, rhs: typing.Any) -> builtins.bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs: typing.Any) -> builtins.bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return "KeyVaultCertificateCertificatePolicyLifetimeActionTrigger(%s)" % ", ".join(
            k + "=" + repr(v) for k, v in self._values.items()
        )


@jsii.data_type(
    jsii_type="@cdktf/provider-azurerm.KeyVaultCertificateCertificatePolicySecretProperties",
    jsii_struct_bases=[],
    name_mapping={"content_type": "contentType"},
)
class KeyVaultCertificateCertificatePolicySecretProperties:
    def __init__(self, *, content_type: builtins.str) -> None:
        """
        :param content_type: 
        """
        self._values: typing.Dict[str, typing.Any] = {
            "content_type": content_type,
        }

    @builtins.property
    def content_type(self) -> builtins.str:
        result = self._values.get("content_type")
        assert result is not None, "Required property 'content_type' is missing"
        return result

    def __eq__(self, rhs: typing.Any) -> builtins.bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs: typing.Any) -> builtins.bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return "KeyVaultCertificateCertificatePolicySecretProperties(%s)" % ", ".join(
            k + "=" + repr(v) for k, v in self._values.items()
        )


@jsii.data_type(
    jsii_type="@cdktf/provider-azurerm.KeyVaultCertificateCertificatePolicyX509CertificateProperties",
    jsii_struct_bases=[],
    name_mapping={
        "key_usage": "keyUsage",
        "subject": "subject",
        "validity_in_months": "validityInMonths",
        "extended_key_usage": "extendedKeyUsage",
        "subject_alternative_names": "subjectAlternativeNames",
    },
)
class KeyVaultCertificateCertificatePolicyX509CertificateProperties:
    def __init__(
        self,
        *,
        key_usage: typing.List[builtins.str],
        subject: builtins.str,
        validity_in_months: jsii.Number,
        extended_key_usage: typing.Optional[typing.List[builtins.str]] = None,
        subject_alternative_names: typing.Optional[typing.List["KeyVaultCertificateCertificatePolicyX509CertificatePropertiesSubjectAlternativeNames"]] = None,
    ) -> None:
        """
        :param key_usage: 
        :param subject: 
        :param validity_in_months: 
        :param extended_key_usage: 
        :param subject_alternative_names: subject_alternative_names block.
        """
        self._values: typing.Dict[str, typing.Any] = {
            "key_usage": key_usage,
            "subject": subject,
            "validity_in_months": validity_in_months,
        }
        if extended_key_usage is not None:
            self._values["extended_key_usage"] = extended_key_usage
        if subject_alternative_names is not None:
            self._values["subject_alternative_names"] = subject_alternative_names

    @builtins.property
    def key_usage(self) -> typing.List[builtins.str]:
        result = self._values.get("key_usage")
        assert result is not None, "Required property 'key_usage' is missing"
        return result

    @builtins.property
    def subject(self) -> builtins.str:
        result = self._values.get("subject")
        assert result is not None, "Required property 'subject' is missing"
        return result

    @builtins.property
    def validity_in_months(self) -> jsii.Number:
        result = self._values.get("validity_in_months")
        assert result is not None, "Required property 'validity_in_months' is missing"
        return result

    @builtins.property
    def extended_key_usage(self) -> typing.Optional[typing.List[builtins.str]]:
        result = self._values.get("extended_key_usage")
        return result

    @builtins.property
    def subject_alternative_names(
        self,
    ) -> typing.Optional[typing.List["KeyVaultCertificateCertificatePolicyX509CertificatePropertiesSubjectAlternativeNames"]]:
        """subject_alternative_names block."""
        result = self._values.get("subject_alternative_names")
        return result

    def __eq__(self, rhs: typing.Any) -> builtins.bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs: typing.Any) -> builtins.bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return "KeyVaultCertificateCertificatePolicyX509CertificateProperties(%s)" % ", ".join(
            k + "=" + repr(v) for k, v in self._values.items()
        )


@jsii.data_type(
    jsii_type="@cdktf/provider-azurerm.KeyVaultCertificateCertificatePolicyX509CertificatePropertiesSubjectAlternativeNames",
    jsii_struct_bases=[],
    name_mapping={"dns_names": "dnsNames", "emails": "emails", "upns": "upns"},
)
class KeyVaultCertificateCertificatePolicyX509CertificatePropertiesSubjectAlternativeNames:
    def __init__(
        self,
        *,
        dns_names: typing.Optional[typing.List[builtins.str]] = None,
        emails: typing.Optional[typing.List[builtins.str]] = None,
        upns: typing.Optional[typing.List[builtins.str]] = None,
    ) -> None:
        """
        :param dns_names: 
        :param emails: 
        :param upns: 
        """
        self._values: typing.Dict[str, typing.Any] = {}
        if dns_names is not None:
            self._values["dns_names"] = dns_names
        if emails is not None:
            self._values["emails"] = emails
        if upns is not None:
            self._values["upns"] = upns

    @builtins.property
    def dns_names(self) -> typing.Optional[typing.List[builtins.str]]:
        result = self._values.get("dns_names")
        return result

    @builtins.property
    def emails(self) -> typing.Optional[typing.List[builtins.str]]:
        result = self._values.get("emails")
        return result

    @builtins.property
    def upns(self) -> typing.Optional[typing.List[builtins.str]]:
        result = self._values.get("upns")
        return result

    def __eq__(self, rhs: typing.Any) -> builtins.bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs: typing.Any) -> builtins.bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return "KeyVaultCertificateCertificatePolicyX509CertificatePropertiesSubjectAlternativeNames(%s)" % ", ".join(
            k + "=" + repr(v) for k, v in self._values.items()
        )


@jsii.data_type(
    jsii_type="@cdktf/provider-azurerm.KeyVaultCertificateConfig",
    jsii_struct_bases=[cdktf.TerraformMetaArguments],
    name_mapping={
        "count": "count",
        "depends_on": "dependsOn",
        "lifecycle": "lifecycle",
        "provider": "provider",
        "certificate_policy": "certificatePolicy",
        "key_vault_id": "keyVaultId",
        "name": "name",
        "certificate": "certificate",
        "tags": "tags",
        "timeouts": "timeouts",
    },
)
class KeyVaultCertificateConfig(cdktf.TerraformMetaArguments):
    def __init__(
        self,
        *,
        count: typing.Optional[jsii.Number] = None,
        depends_on: typing.Optional[typing.List[cdktf.TerraformResource]] = None,
        lifecycle: typing.Optional[cdktf.TerraformResourceLifecycle] = None,
        provider: typing.Optional[cdktf.TerraformProvider] = None,
        certificate_policy: typing.List[KeyVaultCertificateCertificatePolicy],
        key_vault_id: builtins.str,
        name: builtins.str,
        certificate: typing.Optional[typing.List[KeyVaultCertificateCertificate]] = None,
        tags: typing.Optional[typing.Mapping[builtins.str, builtins.str]] = None,
        timeouts: typing.Optional["KeyVaultCertificateTimeouts"] = None,
    ) -> None:
        """
        :param count: 
        :param depends_on: 
        :param lifecycle: 
        :param provider: 
        :param certificate_policy: certificate_policy block.
        :param key_vault_id: 
        :param name: 
        :param certificate: certificate block.
        :param tags: 
        :param timeouts: timeouts block.
        """
        if isinstance(lifecycle, dict):
            lifecycle = cdktf.TerraformResourceLifecycle(**lifecycle)
        if isinstance(timeouts, dict):
            timeouts = KeyVaultCertificateTimeouts(**timeouts)
        self._values: typing.Dict[str, typing.Any] = {
            "certificate_policy": certificate_policy,
            "key_vault_id": key_vault_id,
            "name": name,
        }
        if count is not None:
            self._values["count"] = count
        if depends_on is not None:
            self._values["depends_on"] = depends_on
        if lifecycle is not None:
            self._values["lifecycle"] = lifecycle
        if provider is not None:
            self._values["provider"] = provider
        if certificate is not None:
            self._values["certificate"] = certificate
        if tags is not None:
            self._values["tags"] = tags
        if timeouts is not None:
            self._values["timeouts"] = timeouts

    @builtins.property
    def count(self) -> typing.Optional[jsii.Number]:
        """
        :stability: experimental
        """
        result = self._values.get("count")
        return result

    @builtins.property
    def depends_on(self) -> typing.Optional[typing.List[cdktf.TerraformResource]]:
        """
        :stability: experimental
        """
        result = self._values.get("depends_on")
        return result

    @builtins.property
    def lifecycle(self) -> typing.Optional[cdktf.TerraformResourceLifecycle]:
        """
        :stability: experimental
        """
        result = self._values.get("lifecycle")
        return result

    @builtins.property
    def provider(self) -> typing.Optional[cdktf.TerraformProvider]:
        """
        :stability: experimental
        """
        result = self._values.get("provider")
        return result

    @builtins.property
    def certificate_policy(self) -> typing.List[KeyVaultCertificateCertificatePolicy]:
        """certificate_policy block."""
        result = self._values.get("certificate_policy")
        assert result is not None, "Required property 'certificate_policy' is missing"
        return result

    @builtins.property
    def key_vault_id(self) -> builtins.str:
        result = self._values.get("key_vault_id")
        assert result is not None, "Required property 'key_vault_id' is missing"
        return result

    @builtins.property
    def name(self) -> builtins.str:
        result = self._values.get("name")
        assert result is not None, "Required property 'name' is missing"
        return result

    @builtins.property
    def certificate(
        self,
    ) -> typing.Optional[typing.List[KeyVaultCertificateCertificate]]:
        """certificate block."""
        result = self._values.get("certificate")
        return result

    @builtins.property
    def tags(self) -> typing.Optional[typing.Mapping[builtins.str, builtins.str]]:
        result = self._values.get("tags")
        return result

    @builtins.property
    def timeouts(self) -> typing.Optional["KeyVaultCertificateTimeouts"]:
        """timeouts block."""
        result = self._values.get("timeouts")
        return result

    def __eq__(self, rhs: typing.Any) -> builtins.bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs: typing.Any) -> builtins.bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return "KeyVaultCertificateConfig(%s)" % ", ".join(
            k + "=" + repr(v) for k, v in self._values.items()
        )


@jsii.data_type(
    jsii_type="@cdktf/provider-azurerm.KeyVaultCertificateTimeouts",
    jsii_struct_bases=[],
    name_mapping={"create": "create", "delete": "delete", "read": "read"},
)
class KeyVaultCertificateTimeouts:
    def __init__(
        self,
        *,
        create: typing.Optional[builtins.str] = None,
        delete: typing.Optional[builtins.str] = None,
        read: typing.Optional[builtins.str] = None,
    ) -> None:
        """
        :param create: 
        :param delete: 
        :param read: 
        """
        self._values: typing.Dict[str, typing.Any] = {}
        if create is not None:
            self._values["create"] = create
        if delete is not None:
            self._values["delete"] = delete
        if read is not None:
            self._values["read"] = read

    @builtins.property
    def create(self) -> typing.Optional[builtins.str]:
        result = self._values.get("create")
        return result

    @builtins.property
    def delete(self) -> typing.Optional[builtins.str]:
        result = self._values.get("delete")
        return result

    @builtins.property
    def read(self) -> typing.Optional[builtins.str]:
        result = self._values.get("read")
        return result

    def __eq__(self, rhs: typing.Any) -> builtins.bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs: typing.Any) -> builtins.bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return "KeyVaultCertificateTimeouts(%s)" % ", ".join(
            k + "=" + repr(v) for k, v in self._values.items()
        )


@jsii.data_type(
    jsii_type="@cdktf/provider-azurerm.KeyVaultConfig",
    jsii_struct_bases=[cdktf.TerraformMetaArguments],
    name_mapping={
        "count": "count",
        "depends_on": "dependsOn",
        "lifecycle": "lifecycle",
        "provider": "provider",
        "location": "location",
        "name": "name",
        "resource_group_name": "resourceGroupName",
        "sku_name": "skuName",
        "tenant_id": "tenantId",
        "access_policy": "accessPolicy",
        "enabled_for_deployment": "enabledForDeployment",
        "enabled_for_disk_encryption": "enabledForDiskEncryption",
        "enabled_for_template_deployment": "enabledForTemplateDeployment",
        "network_acls": "networkAcls",
        "purge_protection_enabled": "purgeProtectionEnabled",
        "soft_delete_enabled": "softDeleteEnabled",
        "tags": "tags",
        "timeouts": "timeouts",
    },
)
class KeyVaultConfig(cdktf.TerraformMetaArguments):
    def __init__(
        self,
        *,
        count: typing.Optional[jsii.Number] = None,
        depends_on: typing.Optional[typing.List[cdktf.TerraformResource]] = None,
        lifecycle: typing.Optional[cdktf.TerraformResourceLifecycle] = None,
        provider: typing.Optional[cdktf.TerraformProvider] = None,
        location: builtins.str,
        name: builtins.str,
        resource_group_name: builtins.str,
        sku_name: builtins.str,
        tenant_id: builtins.str,
        access_policy: typing.Optional[typing.List[KeyVaultAccessPolicy]] = None,
        enabled_for_deployment: typing.Optional[builtins.bool] = None,
        enabled_for_disk_encryption: typing.Optional[builtins.bool] = None,
        enabled_for_template_deployment: typing.Optional[builtins.bool] = None,
        network_acls: typing.Optional[typing.List["KeyVaultNetworkAcls"]] = None,
        purge_protection_enabled: typing.Optional[builtins.bool] = None,
        soft_delete_enabled: typing.Optional[builtins.bool] = None,
        tags: typing.Optional[typing.Mapping[builtins.str, builtins.str]] = None,
        timeouts: typing.Optional["KeyVaultTimeouts"] = None,
    ) -> None:
        """
        :param count: 
        :param depends_on: 
        :param lifecycle: 
        :param provider: 
        :param location: 
        :param name: 
        :param resource_group_name: 
        :param sku_name: 
        :param tenant_id: 
        :param access_policy: 
        :param enabled_for_deployment: 
        :param enabled_for_disk_encryption: 
        :param enabled_for_template_deployment: 
        :param network_acls: network_acls block.
        :param purge_protection_enabled: 
        :param soft_delete_enabled: 
        :param tags: 
        :param timeouts: timeouts block.
        """
        if isinstance(lifecycle, dict):
            lifecycle = cdktf.TerraformResourceLifecycle(**lifecycle)
        if isinstance(timeouts, dict):
            timeouts = KeyVaultTimeouts(**timeouts)
        self._values: typing.Dict[str, typing.Any] = {
            "location": location,
            "name": name,
            "resource_group_name": resource_group_name,
            "sku_name": sku_name,
            "tenant_id": tenant_id,
        }
        if count is not None:
            self._values["count"] = count
        if depends_on is not None:
            self._values["depends_on"] = depends_on
        if lifecycle is not None:
            self._values["lifecycle"] = lifecycle
        if provider is not None:
            self._values["provider"] = provider
        if access_policy is not None:
            self._values["access_policy"] = access_policy
        if enabled_for_deployment is not None:
            self._values["enabled_for_deployment"] = enabled_for_deployment
        if enabled_for_disk_encryption is not None:
            self._values["enabled_for_disk_encryption"] = enabled_for_disk_encryption
        if enabled_for_template_deployment is not None:
            self._values["enabled_for_template_deployment"] = enabled_for_template_deployment
        if network_acls is not None:
            self._values["network_acls"] = network_acls
        if purge_protection_enabled is not None:
            self._values["purge_protection_enabled"] = purge_protection_enabled
        if soft_delete_enabled is not None:
            self._values["soft_delete_enabled"] = soft_delete_enabled
        if tags is not None:
            self._values["tags"] = tags
        if timeouts is not None:
            self._values["timeouts"] = timeouts

    @builtins.property
    def count(self) -> typing.Optional[jsii.Number]:
        """
        :stability: experimental
        """
        result = self._values.get("count")
        return result

    @builtins.property
    def depends_on(self) -> typing.Optional[typing.List[cdktf.TerraformResource]]:
        """
        :stability: experimental
        """
        result = self._values.get("depends_on")
        return result

    @builtins.property
    def lifecycle(self) -> typing.Optional[cdktf.TerraformResourceLifecycle]:
        """
        :stability: experimental
        """
        result = self._values.get("lifecycle")
        return result

    @builtins.property
    def provider(self) -> typing.Optional[cdktf.TerraformProvider]:
        """
        :stability: experimental
        """
        result = self._values.get("provider")
        return result

    @builtins.property
    def location(self) -> builtins.str:
        result = self._values.get("location")
        assert result is not None, "Required property 'location' is missing"
        return result

    @builtins.property
    def name(self) -> builtins.str:
        result = self._values.get("name")
        assert result is not None, "Required property 'name' is missing"
        return result

    @builtins.property
    def resource_group_name(self) -> builtins.str:
        result = self._values.get("resource_group_name")
        assert result is not None, "Required property 'resource_group_name' is missing"
        return result

    @builtins.property
    def sku_name(self) -> builtins.str:
        result = self._values.get("sku_name")
        assert result is not None, "Required property 'sku_name' is missing"
        return result

    @builtins.property
    def tenant_id(self) -> builtins.str:
        result = self._values.get("tenant_id")
        assert result is not None, "Required property 'tenant_id' is missing"
        return result

    @builtins.property
    def access_policy(self) -> typing.Optional[typing.List[KeyVaultAccessPolicy]]:
        result = self._values.get("access_policy")
        return result

    @builtins.property
    def enabled_for_deployment(self) -> typing.Optional[builtins.bool]:
        result = self._values.get("enabled_for_deployment")
        return result

    @builtins.property
    def enabled_for_disk_encryption(self) -> typing.Optional[builtins.bool]:
        result = self._values.get("enabled_for_disk_encryption")
        return result

    @builtins.property
    def enabled_for_template_deployment(self) -> typing.Optional[builtins.bool]:
        result = self._values.get("enabled_for_template_deployment")
        return result

    @builtins.property
    def network_acls(self) -> typing.Optional[typing.List["KeyVaultNetworkAcls"]]:
        """network_acls block."""
        result = self._values.get("network_acls")
        return result

    @builtins.property
    def purge_protection_enabled(self) -> typing.Optional[builtins.bool]:
        result = self._values.get("purge_protection_enabled")
        return result

    @builtins.property
    def soft_delete_enabled(self) -> typing.Optional[builtins.bool]:
        result = self._values.get("soft_delete_enabled")
        return result

    @builtins.property
    def tags(self) -> typing.Optional[typing.Mapping[builtins.str, builtins.str]]:
        result = self._values.get("tags")
        return result

    @builtins.property
    def timeouts(self) -> typing.Optional["KeyVaultTimeouts"]:
        """timeouts block."""
        result = self._values.get("timeouts")
        return result

    def __eq__(self, rhs: typing.Any) -> builtins.bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs: typing.Any) -> builtins.bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return "KeyVaultConfig(%s)" % ", ".join(
            k + "=" + repr(v) for k, v in self._values.items()
        )


class KeyVaultKey(
    cdktf.TerraformResource,
    metaclass=jsii.JSIIMeta,
    jsii_type="@cdktf/provider-azurerm.KeyVaultKey",
):
    def __init__(
        self,
        scope: constructs.Construct,
        id: builtins.str,
        *,
        key_opts: typing.List[builtins.str],
        key_type: builtins.str,
        key_vault_id: builtins.str,
        name: builtins.str,
        curve: typing.Optional[builtins.str] = None,
        expiration_date: typing.Optional[builtins.str] = None,
        key_size: typing.Optional[jsii.Number] = None,
        not_before_date: typing.Optional[builtins.str] = None,
        tags: typing.Optional[typing.Mapping[builtins.str, builtins.str]] = None,
        timeouts: typing.Optional["KeyVaultKeyTimeouts"] = None,
        count: typing.Optional[jsii.Number] = None,
        depends_on: typing.Optional[typing.List[cdktf.TerraformResource]] = None,
        lifecycle: typing.Optional[cdktf.TerraformResourceLifecycle] = None,
        provider: typing.Optional[cdktf.TerraformProvider] = None,
    ) -> None:
        """
        :param scope: -
        :param id: -
        :param key_opts: 
        :param key_type: 
        :param key_vault_id: 
        :param name: 
        :param curve: 
        :param expiration_date: 
        :param key_size: 
        :param not_before_date: 
        :param tags: 
        :param timeouts: timeouts block.
        :param count: 
        :param depends_on: 
        :param lifecycle: 
        :param provider: 
        """
        config = KeyVaultKeyConfig(
            key_opts=key_opts,
            key_type=key_type,
            key_vault_id=key_vault_id,
            name=name,
            curve=curve,
            expiration_date=expiration_date,
            key_size=key_size,
            not_before_date=not_before_date,
            tags=tags,
            timeouts=timeouts,
            count=count,
            depends_on=depends_on,
            lifecycle=lifecycle,
            provider=provider,
        )

        jsii.create(KeyVaultKey, self, [scope, id, config])

    @jsii.member(jsii_name="synthesizeAttributes")
    def _synthesize_attributes(self) -> typing.Mapping[builtins.str, typing.Any]:
        return jsii.invoke(self, "synthesizeAttributes", [])

    @builtins.property # type: ignore
    @jsii.member(jsii_name="e")
    def e(self) -> builtins.str:
        return jsii.get(self, "e")

    @builtins.property # type: ignore
    @jsii.member(jsii_name="n")
    def n(self) -> builtins.str:
        return jsii.get(self, "n")

    @builtins.property # type: ignore
    @jsii.member(jsii_name="version")
    def version(self) -> builtins.str:
        return jsii.get(self, "version")

    @builtins.property # type: ignore
    @jsii.member(jsii_name="x")
    def x(self) -> builtins.str:
        return jsii.get(self, "x")

    @builtins.property # type: ignore
    @jsii.member(jsii_name="y")
    def y(self) -> builtins.str:
        return jsii.get(self, "y")

    @builtins.property # type: ignore
    @jsii.member(jsii_name="keyOpts")
    def key_opts(self) -> typing.List[builtins.str]:
        return jsii.get(self, "keyOpts")

    @key_opts.setter # type: ignore
    def key_opts(self, value: typing.List[builtins.str]) -> None:
        jsii.set(self, "keyOpts", value)

    @builtins.property # type: ignore
    @jsii.member(jsii_name="keyType")
    def key_type(self) -> builtins.str:
        return jsii.get(self, "keyType")

    @key_type.setter # type: ignore
    def key_type(self, value: builtins.str) -> None:
        jsii.set(self, "keyType", value)

    @builtins.property # type: ignore
    @jsii.member(jsii_name="keyVaultId")
    def key_vault_id(self) -> builtins.str:
        return jsii.get(self, "keyVaultId")

    @key_vault_id.setter # type: ignore
    def key_vault_id(self, value: builtins.str) -> None:
        jsii.set(self, "keyVaultId", value)

    @builtins.property # type: ignore
    @jsii.member(jsii_name="name")
    def name(self) -> builtins.str:
        return jsii.get(self, "name")

    @name.setter # type: ignore
    def name(self, value: builtins.str) -> None:
        jsii.set(self, "name", value)

    @builtins.property # type: ignore
    @jsii.member(jsii_name="curve")
    def curve(self) -> typing.Optional[builtins.str]:
        return jsii.get(self, "curve")

    @curve.setter # type: ignore
    def curve(self, value: typing.Optional[builtins.str]) -> None:
        jsii.set(self, "curve", value)

    @builtins.property # type: ignore
    @jsii.member(jsii_name="expirationDate")
    def expiration_date(self) -> typing.Optional[builtins.str]:
        return jsii.get(self, "expirationDate")

    @expiration_date.setter # type: ignore
    def expiration_date(self, value: typing.Optional[builtins.str]) -> None:
        jsii.set(self, "expirationDate", value)

    @builtins.property # type: ignore
    @jsii.member(jsii_name="id")
    def id(self) -> typing.Optional[builtins.str]:
        return jsii.get(self, "id")

    @id.setter # type: ignore
    def id(self, value: typing.Optional[builtins.str]) -> None:
        jsii.set(self, "id", value)

    @builtins.property # type: ignore
    @jsii.member(jsii_name="keySize")
    def key_size(self) -> typing.Optional[jsii.Number]:
        return jsii.get(self, "keySize")

    @key_size.setter # type: ignore
    def key_size(self, value: typing.Optional[jsii.Number]) -> None:
        jsii.set(self, "keySize", value)

    @builtins.property # type: ignore
    @jsii.member(jsii_name="notBeforeDate")
    def not_before_date(self) -> typing.Optional[builtins.str]:
        return jsii.get(self, "notBeforeDate")

    @not_before_date.setter # type: ignore
    def not_before_date(self, value: typing.Optional[builtins.str]) -> None:
        jsii.set(self, "notBeforeDate", value)

    @builtins.property # type: ignore
    @jsii.member(jsii_name="tags")
    def tags(self) -> typing.Optional[typing.Mapping[builtins.str, builtins.str]]:
        return jsii.get(self, "tags")

    @tags.setter # type: ignore
    def tags(
        self,
        value: typing.Optional[typing.Mapping[builtins.str, builtins.str]],
    ) -> None:
        jsii.set(self, "tags", value)

    @builtins.property # type: ignore
    @jsii.member(jsii_name="timeouts")
    def timeouts(self) -> typing.Optional["KeyVaultKeyTimeouts"]:
        return jsii.get(self, "timeouts")

    @timeouts.setter # type: ignore
    def timeouts(self, value: typing.Optional["KeyVaultKeyTimeouts"]) -> None:
        jsii.set(self, "timeouts", value)


@jsii.data_type(
    jsii_type="@cdktf/provider-azurerm.KeyVaultKeyConfig",
    jsii_struct_bases=[cdktf.TerraformMetaArguments],
    name_mapping={
        "count": "count",
        "depends_on": "dependsOn",
        "lifecycle": "lifecycle",
        "provider": "provider",
        "key_opts": "keyOpts",
        "key_type": "keyType",
        "key_vault_id": "keyVaultId",
        "name": "name",
        "curve": "curve",
        "expiration_date": "expirationDate",
        "key_size": "keySize",
        "not_before_date": "notBeforeDate",
        "tags": "tags",
        "timeouts": "timeouts",
    },
)
class KeyVaultKeyConfig(cdktf.TerraformMetaArguments):
    def __init__(
        self,
        *,
        count: typing.Optional[jsii.Number] = None,
        depends_on: typing.Optional[typing.List[cdktf.TerraformResource]] = None,
        lifecycle: typing.Optional[cdktf.TerraformResourceLifecycle] = None,
        provider: typing.Optional[cdktf.TerraformProvider] = None,
        key_opts: typing.List[builtins.str],
        key_type: builtins.str,
        key_vault_id: builtins.str,
        name: builtins.str,
        curve: typing.Optional[builtins.str] = None,
        expiration_date: typing.Optional[builtins.str] = None,
        key_size: typing.Optional[jsii.Number] = None,
        not_before_date: typing.Optional[builtins.str] = None,
        tags: typing.Optional[typing.Mapping[builtins.str, builtins.str]] = None,
        timeouts: typing.Optional["KeyVaultKeyTimeouts"] = None,
    ) -> None:
        """
        :param count: 
        :param depends_on: 
        :param lifecycle: 
        :param provider: 
        :param key_opts: 
        :param key_type: 
        :param key_vault_id: 
        :param name: 
        :param curve: 
        :param expiration_date: 
        :param key_size: 
        :param not_before_date: 
        :param tags: 
        :param timeouts: timeouts block.
        """
        if isinstance(lifecycle, dict):
            lifecycle = cdktf.TerraformResourceLifecycle(**lifecycle)
        if isinstance(timeouts, dict):
            timeouts = KeyVaultKeyTimeouts(**timeouts)
        self._values: typing.Dict[str, typing.Any] = {
            "key_opts": key_opts,
            "key_type": key_type,
            "key_vault_id": key_vault_id,
            "name": name,
        }
        if count is not None:
            self._values["count"] = count
        if depends_on is not None:
            self._values["depends_on"] = depends_on
        if lifecycle is not None:
            self._values["lifecycle"] = lifecycle
        if provider is not None:
            self._values["provider"] = provider
        if curve is not None:
            self._values["curve"] = curve
        if expiration_date is not None:
            self._values["expiration_date"] = expiration_date
        if key_size is not None:
            self._values["key_size"] = key_size
        if not_before_date is not None:
            self._values["not_before_date"] = not_before_date
        if tags is not None:
            self._values["tags"] = tags
        if timeouts is not None:
            self._values["timeouts"] = timeouts

    @builtins.property
    def count(self) -> typing.Optional[jsii.Number]:
        """
        :stability: experimental
        """
        result = self._values.get("count")
        return result

    @builtins.property
    def depends_on(self) -> typing.Optional[typing.List[cdktf.TerraformResource]]:
        """
        :stability: experimental
        """
        result = self._values.get("depends_on")
        return result

    @builtins.property
    def lifecycle(self) -> typing.Optional[cdktf.TerraformResourceLifecycle]:
        """
        :stability: experimental
        """
        result = self._values.get("lifecycle")
        return result

    @builtins.property
    def provider(self) -> typing.Optional[cdktf.TerraformProvider]:
        """
        :stability: experimental
        """
        result = self._values.get("provider")
        return result

    @builtins.property
    def key_opts(self) -> typing.List[builtins.str]:
        result = self._values.get("key_opts")
        assert result is not None, "Required property 'key_opts' is missing"
        return result

    @builtins.property
    def key_type(self) -> builtins.str:
        result = self._values.get("key_type")
        assert result is not None, "Required property 'key_type' is missing"
        return result

    @builtins.property
    def key_vault_id(self) -> builtins.str:
        result = self._values.get("key_vault_id")
        assert result is not None, "Required property 'key_vault_id' is missing"
        return result

    @builtins.property
    def name(self) -> builtins.str:
        result = self._values.get("name")
        assert result is not None, "Required property 'name' is missing"
        return result

    @builtins.property
    def curve(self) -> typing.Optional[builtins.str]:
        result = self._values.get("curve")
        return result

    @builtins.property
    def expiration_date(self) -> typing.Optional[builtins.str]:
        result = self._values.get("expiration_date")
        return result

    @builtins.property
    def key_size(self) -> typing.Optional[jsii.Number]:
        result = self._values.get("key_size")
        return result

    @builtins.property
    def not_before_date(self) -> typing.Optional[builtins.str]:
        result = self._values.get("not_before_date")
        return result

    @builtins.property
    def tags(self) -> typing.Optional[typing.Mapping[builtins.str, builtins.str]]:
        result = self._values.get("tags")
        return result

    @builtins.property
    def timeouts(self) -> typing.Optional["KeyVaultKeyTimeouts"]:
        """timeouts block."""
        result = self._values.get("timeouts")
        return result

    def __eq__(self, rhs: typing.Any) -> builtins.bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs: typing.Any) -> builtins.bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return "KeyVaultKeyConfig(%s)" % ", ".join(
            k + "=" + repr(v) for k, v in self._values.items()
        )


@jsii.data_type(
    jsii_type="@cdktf/provider-azurerm.KeyVaultKeyTimeouts",
    jsii_struct_bases=[],
    name_mapping={
        "create": "create",
        "delete": "delete",
        "read": "read",
        "update": "update",
    },
)
class KeyVaultKeyTimeouts:
    def __init__(
        self,
        *,
        create: typing.Optional[builtins.str] = None,
        delete: typing.Optional[builtins.str] = None,
        read: typing.Optional[builtins.str] = None,
        update: typing.Optional[builtins.str] = None,
    ) -> None:
        """
        :param create: 
        :param delete: 
        :param read: 
        :param update: 
        """
        self._values: typing.Dict[str, typing.Any] = {}
        if create is not None:
            self._values["create"] = create
        if delete is not None:
            self._values["delete"] = delete
        if read is not None:
            self._values["read"] = read
        if update is not None:
            self._values["update"] = update

    @builtins.property
    def create(self) -> typing.Optional[builtins.str]:
        result = self._values.get("create")
        return result

    @builtins.property
    def delete(self) -> typing.Optional[builtins.str]:
        result = self._values.get("delete")
        return result

    @builtins.property
    def read(self) -> typing.Optional[builtins.str]:
        result = self._values.get("read")
        return result

    @builtins.property
    def update(self) -> typing.Optional[builtins.str]:
        result = self._values.get("update")
        return result

    def __eq__(self, rhs: typing.Any) -> builtins.bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs: typing.Any) -> builtins.bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return "KeyVaultKeyTimeouts(%s)" % ", ".join(
            k + "=" + repr(v) for k, v in self._values.items()
        )


@jsii.data_type(
    jsii_type="@cdktf/provider-azurerm.KeyVaultNetworkAcls",
    jsii_struct_bases=[],
    name_mapping={
        "bypass": "bypass",
        "default_action": "defaultAction",
        "ip_rules": "ipRules",
        "virtual_network_subnet_ids": "virtualNetworkSubnetIds",
    },
)
class KeyVaultNetworkAcls:
    def __init__(
        self,
        *,
        bypass: builtins.str,
        default_action: builtins.str,
        ip_rules: typing.Optional[typing.List[builtins.str]] = None,
        virtual_network_subnet_ids: typing.Optional[typing.List[builtins.str]] = None,
    ) -> None:
        """
        :param bypass: 
        :param default_action: 
        :param ip_rules: 
        :param virtual_network_subnet_ids: 
        """
        self._values: typing.Dict[str, typing.Any] = {
            "bypass": bypass,
            "default_action": default_action,
        }
        if ip_rules is not None:
            self._values["ip_rules"] = ip_rules
        if virtual_network_subnet_ids is not None:
            self._values["virtual_network_subnet_ids"] = virtual_network_subnet_ids

    @builtins.property
    def bypass(self) -> builtins.str:
        result = self._values.get("bypass")
        assert result is not None, "Required property 'bypass' is missing"
        return result

    @builtins.property
    def default_action(self) -> builtins.str:
        result = self._values.get("default_action")
        assert result is not None, "Required property 'default_action' is missing"
        return result

    @builtins.property
    def ip_rules(self) -> typing.Optional[typing.List[builtins.str]]:
        result = self._values.get("ip_rules")
        return result

    @builtins.property
    def virtual_network_subnet_ids(self) -> typing.Optional[typing.List[builtins.str]]:
        result = self._values.get("virtual_network_subnet_ids")
        return result

    def __eq__(self, rhs: typing.Any) -> builtins.bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs: typing.Any) -> builtins.bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return "KeyVaultNetworkAcls(%s)" % ", ".join(
            k + "=" + repr(v) for k, v in self._values.items()
        )


class KeyVaultSecret(
    cdktf.TerraformResource,
    metaclass=jsii.JSIIMeta,
    jsii_type="@cdktf/provider-azurerm.KeyVaultSecret",
):
    def __init__(
        self,
        scope: constructs.Construct,
        id: builtins.str,
        *,
        key_vault_id: builtins.str,
        name: builtins.str,
        value: builtins.str,
        content_type: typing.Optional[builtins.str] = None,
        expiration_date: typing.Optional[builtins.str] = None,
        not_before_date: typing.Optional[builtins.str] = None,
        tags: typing.Optional[typing.Mapping[builtins.str, builtins.str]] = None,
        timeouts: typing.Optional["KeyVaultSecretTimeouts"] = None,
        count: typing.Optional[jsii.Number] = None,
        depends_on: typing.Optional[typing.List[cdktf.TerraformResource]] = None,
        lifecycle: typing.Optional[cdktf.TerraformResourceLifecycle] = None,
        provider: typing.Optional[cdktf.TerraformProvider] = None,
    ) -> None:
        """
        :param scope: -
        :param id: -
        :param key_vault_id: 
        :param name: 
        :param value: 
        :param content_type: 
        :param expiration_date: 
        :param not_before_date: 
        :param tags: 
        :param timeouts: timeouts block.
        :param count: 
        :param depends_on: 
        :param lifecycle: 
        :param provider: 
        """
        config = KeyVaultSecretConfig(
            key_vault_id=key_vault_id,
            name=name,
            value=value,
            content_type=content_type,
            expiration_date=expiration_date,
            not_before_date=not_before_date,
            tags=tags,
            timeouts=timeouts,
            count=count,
            depends_on=depends_on,
            lifecycle=lifecycle,
            provider=provider,
        )

        jsii.create(KeyVaultSecret, self, [scope, id, config])

    @jsii.member(jsii_name="synthesizeAttributes")
    def _synthesize_attributes(self) -> typing.Mapping[builtins.str, typing.Any]:
        return jsii.invoke(self, "synthesizeAttributes", [])

    @builtins.property # type: ignore
    @jsii.member(jsii_name="version")
    def version(self) -> builtins.str:
        return jsii.get(self, "version")

    @builtins.property # type: ignore
    @jsii.member(jsii_name="keyVaultId")
    def key_vault_id(self) -> builtins.str:
        return jsii.get(self, "keyVaultId")

    @key_vault_id.setter # type: ignore
    def key_vault_id(self, value: builtins.str) -> None:
        jsii.set(self, "keyVaultId", value)

    @builtins.property # type: ignore
    @jsii.member(jsii_name="name")
    def name(self) -> builtins.str:
        return jsii.get(self, "name")

    @name.setter # type: ignore
    def name(self, value: builtins.str) -> None:
        jsii.set(self, "name", value)

    @builtins.property # type: ignore
    @jsii.member(jsii_name="value")
    def value(self) -> builtins.str:
        return jsii.get(self, "value")

    @value.setter # type: ignore
    def value(self, value: builtins.str) -> None:
        jsii.set(self, "value", value)

    @builtins.property # type: ignore
    @jsii.member(jsii_name="contentType")
    def content_type(self) -> typing.Optional[builtins.str]:
        return jsii.get(self, "contentType")

    @content_type.setter # type: ignore
    def content_type(self, value: typing.Optional[builtins.str]) -> None:
        jsii.set(self, "contentType", value)

    @builtins.property # type: ignore
    @jsii.member(jsii_name="expirationDate")
    def expiration_date(self) -> typing.Optional[builtins.str]:
        return jsii.get(self, "expirationDate")

    @expiration_date.setter # type: ignore
    def expiration_date(self, value: typing.Optional[builtins.str]) -> None:
        jsii.set(self, "expirationDate", value)

    @builtins.property # type: ignore
    @jsii.member(jsii_name="id")
    def id(self) -> typing.Optional[builtins.str]:
        return jsii.get(self, "id")

    @id.setter # type: ignore
    def id(self, value: typing.Optional[builtins.str]) -> None:
        jsii.set(self, "id", value)

    @builtins.property # type: ignore
    @jsii.member(jsii_name="notBeforeDate")
    def not_before_date(self) -> typing.Optional[builtins.str]:
        return jsii.get(self, "notBeforeDate")

    @not_before_date.setter # type: ignore
    def not_before_date(self, value: typing.Optional[builtins.str]) -> None:
        jsii.set(self, "notBeforeDate", value)

    @builtins.property # type: ignore
    @jsii.member(jsii_name="tags")
    def tags(self) -> typing.Optional[typing.Mapping[builtins.str, builtins.str]]:
        return jsii.get(self, "tags")

    @tags.setter # type: ignore
    def tags(
        self,
        value: typing.Optional[typing.Mapping[builtins.str, builtins.str]],
    ) -> None:
        jsii.set(self, "tags", value)

    @builtins.property # type: ignore
    @jsii.member(jsii_name="timeouts")
    def timeouts(self) -> typing.Optional["KeyVaultSecretTimeouts"]:
        return jsii.get(self, "timeouts")

    @timeouts.setter # type: ignore
    def timeouts(self, value: typing.Optional["KeyVaultSecretTimeouts"]) -> None:
        jsii.set(self, "timeouts", value)


@jsii.data_type(
    jsii_type="@cdktf/provider-azurerm.KeyVaultSecretConfig",
    jsii_struct_bases=[cdktf.TerraformMetaArguments],
    name_mapping={
        "count": "count",
        "depends_on": "dependsOn",
        "lifecycle": "lifecycle",
        "provider": "provider",
        "key_vault_id": "keyVaultId",
        "name": "name",
        "value": "value",
        "content_type": "contentType",
        "expiration_date": "expirationDate",
        "not_before_date": "notBeforeDate",
        "tags": "tags",
        "timeouts": "timeouts",
    },
)
class KeyVaultSecretConfig(cdktf.TerraformMetaArguments):
    def __init__(
        self,
        *,
        count: typing.Optional[jsii.Number] = None,
        depends_on: typing.Optional[typing.List[cdktf.TerraformResource]] = None,
        lifecycle: typing.Optional[cdktf.TerraformResourceLifecycle] = None,
        provider: typing.Optional[cdktf.TerraformProvider] = None,
        key_vault_id: builtins.str,
        name: builtins.str,
        value: builtins.str,
        content_type: typing.Optional[builtins.str] = None,
        expiration_date: typing.Optional[builtins.str] = None,
        not_before_date: typing.Optional[builtins.str] = None,
        tags: typing.Optional[typing.Mapping[builtins.str, builtins.str]] = None,
        timeouts: typing.Optional["KeyVaultSecretTimeouts"] = None,
    ) -> None:
        """
        :param count: 
        :param depends_on: 
        :param lifecycle: 
        :param provider: 
        :param key_vault_id: 
        :param name: 
        :param value: 
        :param content_type: 
        :param expiration_date: 
        :param not_before_date: 
        :param tags: 
        :param timeouts: timeouts block.
        """
        if isinstance(lifecycle, dict):
            lifecycle = cdktf.TerraformResourceLifecycle(**lifecycle)
        if isinstance(timeouts, dict):
            timeouts = KeyVaultSecretTimeouts(**timeouts)
        self._values: typing.Dict[str, typing.Any] = {
            "key_vault_id": key_vault_id,
            "name": name,
            "value": value,
        }
        if count is not None:
            self._values["count"] = count
        if depends_on is not None:
            self._values["depends_on"] = depends_on
        if lifecycle is not None:
            self._values["lifecycle"] = lifecycle
        if provider is not None:
            self._values["provider"] = provider
        if content_type is not None:
            self._values["content_type"] = content_type
        if expiration_date is not None:
            self._values["expiration_date"] = expiration_date
        if not_before_date is not None:
            self._values["not_before_date"] = not_before_date
        if tags is not None:
            self._values["tags"] = tags
        if timeouts is not None:
            self._values["timeouts"] = timeouts

    @builtins.property
    def count(self) -> typing.Optional[jsii.Number]:
        """
        :stability: experimental
        """
        result = self._values.get("count")
        return result

    @builtins.property
    def depends_on(self) -> typing.Optional[typing.List[cdktf.TerraformResource]]:
        """
        :stability: experimental
        """
        result = self._values.get("depends_on")
        return result

    @builtins.property
    def lifecycle(self) -> typing.Optional[cdktf.TerraformResourceLifecycle]:
        """
        :stability: experimental
        """
        result = self._values.get("lifecycle")
        return result

    @builtins.property
    def provider(self) -> typing.Optional[cdktf.TerraformProvider]:
        """
        :stability: experimental
        """
        result = self._values.get("provider")
        return result

    @builtins.property
    def key_vault_id(self) -> builtins.str:
        result = self._values.get("key_vault_id")
        assert result is not None, "Required property 'key_vault_id' is missing"
        return result

    @builtins.property
    def name(self) -> builtins.str:
        result = self._values.get("name")
        assert result is not None, "Required property 'name' is missing"
        return result

    @builtins.property
    def value(self) -> builtins.str:
        result = self._values.get("value")
        assert result is not None, "Required property 'value' is missing"
        return result

    @builtins.property
    def content_type(self) -> typing.Optional[builtins.str]:
        result = self._values.get("content_type")
        return result

    @builtins.property
    def expiration_date(self) -> typing.Optional[builtins.str]:
        result = self._values.get("expiration_date")
        return result

    @builtins.property
    def not_before_date(self) -> typing.Optional[builtins.str]:
        result = self._values.get("not_before_date")
        return result

    @builtins.property
    def tags(self) -> typing.Optional[typing.Mapping[builtins.str, builtins.str]]:
        result = self._values.get("tags")
        return result

    @builtins.property
    def timeouts(self) -> typing.Optional["KeyVaultSecretTimeouts"]:
        """timeouts block."""
        result = self._values.get("timeouts")
        return result

    def __eq__(self, rhs: typing.Any) -> builtins.bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs: typing.Any) -> builtins.bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return "KeyVaultSecretConfig(%s)" % ", ".join(
            k + "=" + repr(v) for k, v in self._values.items()
        )


@jsii.data_type(
    jsii_type="@cdktf/provider-azurerm.KeyVaultSecretTimeouts",
    jsii_struct_bases=[],
    name_mapping={
        "create": "create",
        "delete": "delete",
        "read": "read",
        "update": "update",
    },
)
class KeyVaultSecretTimeouts:
    def __init__(
        self,
        *,
        create: typing.Optional[builtins.str] = None,
        delete: typing.Optional[builtins.str] = None,
        read: typing.Optional[builtins.str] = None,
        update: typing.Optional[builtins.str] = None,
    ) -> None:
        """
        :param create: 
        :param delete: 
        :param read: 
        :param update: 
        """
        self._values: typing.Dict[str, typing.Any] = {}
        if create is not None:
            self._values["create"] = create
        if delete is not None:
            self._values["delete"] = delete
        if read is not None:
            self._values["read"] = read
        if update is not None:
            self._values["update"] = update

    @builtins.property
    def create(self) -> typing.Optional[builtins.str]:
        result = self._values.get("create")
        return result

    @builtins.property
    def delete(self) -> typing.Optional[builtins.str]:
        result = self._values.get("delete")
        return result

    @builtins.property
    def read(self) -> typing.Optional[builtins.str]:
        result = self._values.get("read")
        return result

    @builtins.property
    def update(self) -> typing.Optional[builtins.str]:
        result = self._values.get("update")
        return result

    def __eq__(self, rhs: typing.Any) -> builtins.bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs: typing.Any) -> builtins.bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return "KeyVaultSecretTimeouts(%s)" % ", ".join(
            k + "=" + repr(v) for k, v in self._values.items()
        )


@jsii.data_type(
    jsii_type="@cdktf/provider-azurerm.KeyVaultTimeouts",
    jsii_struct_bases=[],
    name_mapping={
        "create": "create",
        "delete": "delete",
        "read": "read",
        "update": "update",
    },
)
class KeyVaultTimeouts:
    def __init__(
        self,
        *,
        create: typing.Optional[builtins.str] = None,
        delete: typing.Optional[builtins.str] = None,
        read: typing.Optional[builtins.str] = None,
        update: typing.Optional[builtins.str] = None,
    ) -> None:
        """
        :param create: 
        :param delete: 
        :param read: 
        :param update: 
        """
        self._values: typing.Dict[str, typing.Any] = {}
        if create is not None:
            self._values["create"] = create
        if delete is not None:
            self._values["delete"] = delete
        if read is not None:
            self._values["read"] = read
        if update is not None:
            self._values["update"] = update

    @builtins.property
    def create(self) -> typing.Optional[builtins.str]:
        result = self._values.get("create")
        return result

    @builtins.property
    def delete(self) -> typing.Optional[builtins.str]:
        result = self._values.get("delete")
        return result

    @builtins.property
    def read(self) -> typing.Optional[builtins.str]:
        result = self._values.get("read")
        return result

    @builtins.property
    def update(self) -> typing.Optional[builtins.str]:
        result = self._values.get("update")
        return result

    def __eq__(self, rhs: typing.Any) -> builtins.bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs: typing.Any) -> builtins.bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return "KeyVaultTimeouts(%s)" % ", ".join(
            k + "=" + repr(v) for k, v in self._values.items()
        )


class KubernetesCluster(
    cdktf.TerraformResource,
    metaclass=jsii.JSIIMeta,
    jsii_type="@cdktf/provider-azurerm.KubernetesCluster",
):
    def __init__(
        self,
        scope: constructs.Construct,
        id: builtins.str,
        *,
        default_node_pool: typing.List["KubernetesClusterDefaultNodePool"],
        dns_prefix: builtins.str,
        location: builtins.str,
        name: builtins.str,
        resource_group_name: builtins.str,
        service_principal: typing.List["KubernetesClusterServicePrincipal"],
        addon_profile: typing.Optional[typing.List["KubernetesClusterAddonProfile"]] = None,
        api_server_authorized_ip_ranges: typing.Optional[typing.List[builtins.str]] = None,
        enable_pod_security_policy: typing.Optional[builtins.bool] = None,
        identity: typing.Optional[typing.List["KubernetesClusterIdentity"]] = None,
        kubernetes_version: typing.Optional[builtins.str] = None,
        linux_profile: typing.Optional[typing.List["KubernetesClusterLinuxProfile"]] = None,
        network_profile: typing.Optional[typing.List["KubernetesClusterNetworkProfile"]] = None,
        node_resource_group: typing.Optional[builtins.str] = None,
        private_link_enabled: typing.Optional[builtins.bool] = None,
        role_based_access_control: typing.Optional[typing.List["KubernetesClusterRoleBasedAccessControl"]] = None,
        tags: typing.Optional[typing.Mapping[builtins.str, builtins.str]] = None,
        timeouts: typing.Optional["KubernetesClusterTimeouts"] = None,
        windows_profile: typing.Optional[typing.List["KubernetesClusterWindowsProfile"]] = None,
        count: typing.Optional[jsii.Number] = None,
        depends_on: typing.Optional[typing.List[cdktf.TerraformResource]] = None,
        lifecycle: typing.Optional[cdktf.TerraformResourceLifecycle] = None,
        provider: typing.Optional[cdktf.TerraformProvider] = None,
    ) -> None:
        """
        :param scope: -
        :param id: -
        :param default_node_pool: default_node_pool block.
        :param dns_prefix: 
        :param location: 
        :param name: 
        :param resource_group_name: 
        :param service_principal: service_principal block.
        :param addon_profile: addon_profile block.
        :param api_server_authorized_ip_ranges: 
        :param enable_pod_security_policy: 
        :param identity: identity block.
        :param kubernetes_version: 
        :param linux_profile: linux_profile block.
        :param network_profile: network_profile block.
        :param node_resource_group: 
        :param private_link_enabled: 
        :param role_based_access_control: role_based_access_control block.
        :param tags: 
        :param timeouts: timeouts block.
        :param windows_profile: windows_profile block.
        :param count: 
        :param depends_on: 
        :param lifecycle: 
        :param provider: 
        """
        config = KubernetesClusterConfig(
            default_node_pool=default_node_pool,
            dns_prefix=dns_prefix,
            location=location,
            name=name,
            resource_group_name=resource_group_name,
            service_principal=service_principal,
            addon_profile=addon_profile,
            api_server_authorized_ip_ranges=api_server_authorized_ip_ranges,
            enable_pod_security_policy=enable_pod_security_policy,
            identity=identity,
            kubernetes_version=kubernetes_version,
            linux_profile=linux_profile,
            network_profile=network_profile,
            node_resource_group=node_resource_group,
            private_link_enabled=private_link_enabled,
            role_based_access_control=role_based_access_control,
            tags=tags,
            timeouts=timeouts,
            windows_profile=windows_profile,
            count=count,
            depends_on=depends_on,
            lifecycle=lifecycle,
            provider=provider,
        )

        jsii.create(KubernetesCluster, self, [scope, id, config])

    @jsii.member(jsii_name="kubeAdminConfig")
    def kube_admin_config(
        self,
        index: builtins.str,
    ) -> "KubernetesClusterKubeAdminConfig":
        """
        :param index: -
        """
        return jsii.invoke(self, "kubeAdminConfig", [index])

    @jsii.member(jsii_name="kubeConfig")
    def kube_config(self, index: builtins.str) -> "KubernetesClusterKubeConfig":
        """
        :param index: -
        """
        return jsii.invoke(self, "kubeConfig", [index])

    @jsii.member(jsii_name="synthesizeAttributes")
    def _synthesize_attributes(self) -> typing.Mapping[builtins.str, typing.Any]:
        return jsii.invoke(self, "synthesizeAttributes", [])

    @builtins.property # type: ignore
    @jsii.member(jsii_name="fqdn")
    def fqdn(self) -> builtins.str:
        return jsii.get(self, "fqdn")

    @builtins.property # type: ignore
    @jsii.member(jsii_name="kubeAdminConfigRaw")
    def kube_admin_config_raw(self) -> builtins.str:
        return jsii.get(self, "kubeAdminConfigRaw")

    @builtins.property # type: ignore
    @jsii.member(jsii_name="kubeConfigRaw")
    def kube_config_raw(self) -> builtins.str:
        return jsii.get(self, "kubeConfigRaw")

    @builtins.property # type: ignore
    @jsii.member(jsii_name="privateFqdn")
    def private_fqdn(self) -> builtins.str:
        return jsii.get(self, "privateFqdn")

    @builtins.property # type: ignore
    @jsii.member(jsii_name="defaultNodePool")
    def default_node_pool(self) -> typing.List["KubernetesClusterDefaultNodePool"]:
        return jsii.get(self, "defaultNodePool")

    @default_node_pool.setter # type: ignore
    def default_node_pool(
        self,
        value: typing.List["KubernetesClusterDefaultNodePool"],
    ) -> None:
        jsii.set(self, "defaultNodePool", value)

    @builtins.property # type: ignore
    @jsii.member(jsii_name="dnsPrefix")
    def dns_prefix(self) -> builtins.str:
        return jsii.get(self, "dnsPrefix")

    @dns_prefix.setter # type: ignore
    def dns_prefix(self, value: builtins.str) -> None:
        jsii.set(self, "dnsPrefix", value)

    @builtins.property # type: ignore
    @jsii.member(jsii_name="location")
    def location(self) -> builtins.str:
        return jsii.get(self, "location")

    @location.setter # type: ignore
    def location(self, value: builtins.str) -> None:
        jsii.set(self, "location", value)

    @builtins.property # type: ignore
    @jsii.member(jsii_name="name")
    def name(self) -> builtins.str:
        return jsii.get(self, "name")

    @name.setter # type: ignore
    def name(self, value: builtins.str) -> None:
        jsii.set(self, "name", value)

    @builtins.property # type: ignore
    @jsii.member(jsii_name="resourceGroupName")
    def resource_group_name(self) -> builtins.str:
        return jsii.get(self, "resourceGroupName")

    @resource_group_name.setter # type: ignore
    def resource_group_name(self, value: builtins.str) -> None:
        jsii.set(self, "resourceGroupName", value)

    @builtins.property # type: ignore
    @jsii.member(jsii_name="servicePrincipal")
    def service_principal(self) -> typing.List["KubernetesClusterServicePrincipal"]:
        return jsii.get(self, "servicePrincipal")

    @service_principal.setter # type: ignore
    def service_principal(
        self,
        value: typing.List["KubernetesClusterServicePrincipal"],
    ) -> None:
        jsii.set(self, "servicePrincipal", value)

    @builtins.property # type: ignore
    @jsii.member(jsii_name="addonProfile")
    def addon_profile(
        self,
    ) -> typing.Optional[typing.List["KubernetesClusterAddonProfile"]]:
        return jsii.get(self, "addonProfile")

    @addon_profile.setter # type: ignore
    def addon_profile(
        self,
        value: typing.Optional[typing.List["KubernetesClusterAddonProfile"]],
    ) -> None:
        jsii.set(self, "addonProfile", value)

    @builtins.property # type: ignore
    @jsii.member(jsii_name="apiServerAuthorizedIpRanges")
    def api_server_authorized_ip_ranges(
        self,
    ) -> typing.Optional[typing.List[builtins.str]]:
        return jsii.get(self, "apiServerAuthorizedIpRanges")

    @api_server_authorized_ip_ranges.setter # type: ignore
    def api_server_authorized_ip_ranges(
        self,
        value: typing.Optional[typing.List[builtins.str]],
    ) -> None:
        jsii.set(self, "apiServerAuthorizedIpRanges", value)

    @builtins.property # type: ignore
    @jsii.member(jsii_name="enablePodSecurityPolicy")
    def enable_pod_security_policy(self) -> typing.Optional[builtins.bool]:
        return jsii.get(self, "enablePodSecurityPolicy")

    @enable_pod_security_policy.setter # type: ignore
    def enable_pod_security_policy(self, value: typing.Optional[builtins.bool]) -> None:
        jsii.set(self, "enablePodSecurityPolicy", value)

    @builtins.property # type: ignore
    @jsii.member(jsii_name="id")
    def id(self) -> typing.Optional[builtins.str]:
        return jsii.get(self, "id")

    @id.setter # type: ignore
    def id(self, value: typing.Optional[builtins.str]) -> None:
        jsii.set(self, "id", value)

    @builtins.property # type: ignore
    @jsii.member(jsii_name="identity")
    def identity(self) -> typing.Optional[typing.List["KubernetesClusterIdentity"]]:
        return jsii.get(self, "identity")

    @identity.setter # type: ignore
    def identity(
        self,
        value: typing.Optional[typing.List["KubernetesClusterIdentity"]],
    ) -> None:
        jsii.set(self, "identity", value)

    @builtins.property # type: ignore
    @jsii.member(jsii_name="kubernetesVersion")
    def kubernetes_version(self) -> typing.Optional[builtins.str]:
        return jsii.get(self, "kubernetesVersion")

    @kubernetes_version.setter # type: ignore
    def kubernetes_version(self, value: typing.Optional[builtins.str]) -> None:
        jsii.set(self, "kubernetesVersion", value)

    @builtins.property # type: ignore
    @jsii.member(jsii_name="linuxProfile")
    def linux_profile(
        self,
    ) -> typing.Optional[typing.List["KubernetesClusterLinuxProfile"]]:
        return jsii.get(self, "linuxProfile")

    @linux_profile.setter # type: ignore
    def linux_profile(
        self,
        value: typing.Optional[typing.List["KubernetesClusterLinuxProfile"]],
    ) -> None:
        jsii.set(self, "linuxProfile", value)

    @builtins.property # type: ignore
    @jsii.member(jsii_name="networkProfile")
    def network_profile(
        self,
    ) -> typing.Optional[typing.List["KubernetesClusterNetworkProfile"]]:
        return jsii.get(self, "networkProfile")

    @network_profile.setter # type: ignore
    def network_profile(
        self,
        value: typing.Optional[typing.List["KubernetesClusterNetworkProfile"]],
    ) -> None:
        jsii.set(self, "networkProfile", value)

    @builtins.property # type: ignore
    @jsii.member(jsii_name="nodeResourceGroup")
    def node_resource_group(self) -> typing.Optional[builtins.str]:
        return jsii.get(self, "nodeResourceGroup")

    @node_resource_group.setter # type: ignore
    def node_resource_group(self, value: typing.Optional[builtins.str]) -> None:
        jsii.set(self, "nodeResourceGroup", value)

    @builtins.property # type: ignore
    @jsii.member(jsii_name="privateLinkEnabled")
    def private_link_enabled(self) -> typing.Optional[builtins.bool]:
        return jsii.get(self, "privateLinkEnabled")

    @private_link_enabled.setter # type: ignore
    def private_link_enabled(self, value: typing.Optional[builtins.bool]) -> None:
        jsii.set(self, "privateLinkEnabled", value)

    @builtins.property # type: ignore
    @jsii.member(jsii_name="roleBasedAccessControl")
    def role_based_access_control(
        self,
    ) -> typing.Optional[typing.List["KubernetesClusterRoleBasedAccessControl"]]:
        return jsii.get(self, "roleBasedAccessControl")

    @role_based_access_control.setter # type: ignore
    def role_based_access_control(
        self,
        value: typing.Optional[typing.List["KubernetesClusterRoleBasedAccessControl"]],
    ) -> None:
        jsii.set(self, "roleBasedAccessControl", value)

    @builtins.property # type: ignore
    @jsii.member(jsii_name="tags")
    def tags(self) -> typing.Optional[typing.Mapping[builtins.str, builtins.str]]:
        return jsii.get(self, "tags")

    @tags.setter # type: ignore
    def tags(
        self,
        value: typing.Optional[typing.Mapping[builtins.str, builtins.str]],
    ) -> None:
        jsii.set(self, "tags", value)

    @builtins.property # type: ignore
    @jsii.member(jsii_name="timeouts")
    def timeouts(self) -> typing.Optional["KubernetesClusterTimeouts"]:
        return jsii.get(self, "timeouts")

    @timeouts.setter # type: ignore
    def timeouts(self, value: typing.Optional["KubernetesClusterTimeouts"]) -> None:
        jsii.set(self, "timeouts", value)

    @builtins.property # type: ignore
    @jsii.member(jsii_name="windowsProfile")
    def windows_profile(
        self,
    ) -> typing.Optional[typing.List["KubernetesClusterWindowsProfile"]]:
        return jsii.get(self, "windowsProfile")

    @windows_profile.setter # type: ignore
    def windows_profile(
        self,
        value: typing.Optional[typing.List["KubernetesClusterWindowsProfile"]],
    ) -> None:
        jsii.set(self, "windowsProfile", value)


@jsii.data_type(
    jsii_type="@cdktf/provider-azurerm.KubernetesClusterAddonProfile",
    jsii_struct_bases=[],
    name_mapping={
        "aci_connector_linux": "aciConnectorLinux",
        "azure_policy": "azurePolicy",
        "http_application_routing": "httpApplicationRouting",
        "kube_dashboard": "kubeDashboard",
        "oms_agent": "omsAgent",
    },
)
class KubernetesClusterAddonProfile:
    def __init__(
        self,
        *,
        aci_connector_linux: typing.Optional[typing.List["KubernetesClusterAddonProfileAciConnectorLinux"]] = None,
        azure_policy: typing.Optional[typing.List["KubernetesClusterAddonProfileAzurePolicy"]] = None,
        http_application_routing: typing.Optional[typing.List["KubernetesClusterAddonProfileHttpApplicationRouting"]] = None,
        kube_dashboard: typing.Optional[typing.List["KubernetesClusterAddonProfileKubeDashboard"]] = None,
        oms_agent: typing.Optional[typing.List["KubernetesClusterAddonProfileOmsAgent"]] = None,
    ) -> None:
        """
        :param aci_connector_linux: aci_connector_linux block.
        :param azure_policy: azure_policy block.
        :param http_application_routing: http_application_routing block.
        :param kube_dashboard: kube_dashboard block.
        :param oms_agent: oms_agent block.
        """
        self._values: typing.Dict[str, typing.Any] = {}
        if aci_connector_linux is not None:
            self._values["aci_connector_linux"] = aci_connector_linux
        if azure_policy is not None:
            self._values["azure_policy"] = azure_policy
        if http_application_routing is not None:
            self._values["http_application_routing"] = http_application_routing
        if kube_dashboard is not None:
            self._values["kube_dashboard"] = kube_dashboard
        if oms_agent is not None:
            self._values["oms_agent"] = oms_agent

    @builtins.property
    def aci_connector_linux(
        self,
    ) -> typing.Optional[typing.List["KubernetesClusterAddonProfileAciConnectorLinux"]]:
        """aci_connector_linux block."""
        result = self._values.get("aci_connector_linux")
        return result

    @builtins.property
    def azure_policy(
        self,
    ) -> typing.Optional[typing.List["KubernetesClusterAddonProfileAzurePolicy"]]:
        """azure_policy block."""
        result = self._values.get("azure_policy")
        return result

    @builtins.property
    def http_application_routing(
        self,
    ) -> typing.Optional[typing.List["KubernetesClusterAddonProfileHttpApplicationRouting"]]:
        """http_application_routing block."""
        result = self._values.get("http_application_routing")
        return result

    @builtins.property
    def kube_dashboard(
        self,
    ) -> typing.Optional[typing.List["KubernetesClusterAddonProfileKubeDashboard"]]:
        """kube_dashboard block."""
        result = self._values.get("kube_dashboard")
        return result

    @builtins.property
    def oms_agent(
        self,
    ) -> typing.Optional[typing.List["KubernetesClusterAddonProfileOmsAgent"]]:
        """oms_agent block."""
        result = self._values.get("oms_agent")
        return result

    def __eq__(self, rhs: typing.Any) -> builtins.bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs: typing.Any) -> builtins.bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return "KubernetesClusterAddonProfile(%s)" % ", ".join(
            k + "=" + repr(v) for k, v in self._values.items()
        )


@jsii.data_type(
    jsii_type="@cdktf/provider-azurerm.KubernetesClusterAddonProfileAciConnectorLinux",
    jsii_struct_bases=[],
    name_mapping={"enabled": "enabled", "subnet_name": "subnetName"},
)
class KubernetesClusterAddonProfileAciConnectorLinux:
    def __init__(
        self,
        *,
        enabled: builtins.bool,
        subnet_name: typing.Optional[builtins.str] = None,
    ) -> None:
        """
        :param enabled: 
        :param subnet_name: 
        """
        self._values: typing.Dict[str, typing.Any] = {
            "enabled": enabled,
        }
        if subnet_name is not None:
            self._values["subnet_name"] = subnet_name

    @builtins.property
    def enabled(self) -> builtins.bool:
        result = self._values.get("enabled")
        assert result is not None, "Required property 'enabled' is missing"
        return result

    @builtins.property
    def subnet_name(self) -> typing.Optional[builtins.str]:
        result = self._values.get("subnet_name")
        return result

    def __eq__(self, rhs: typing.Any) -> builtins.bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs: typing.Any) -> builtins.bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return "KubernetesClusterAddonProfileAciConnectorLinux(%s)" % ", ".join(
            k + "=" + repr(v) for k, v in self._values.items()
        )


@jsii.data_type(
    jsii_type="@cdktf/provider-azurerm.KubernetesClusterAddonProfileAzurePolicy",
    jsii_struct_bases=[],
    name_mapping={"enabled": "enabled"},
)
class KubernetesClusterAddonProfileAzurePolicy:
    def __init__(self, *, enabled: builtins.bool) -> None:
        """
        :param enabled: 
        """
        self._values: typing.Dict[str, typing.Any] = {
            "enabled": enabled,
        }

    @builtins.property
    def enabled(self) -> builtins.bool:
        result = self._values.get("enabled")
        assert result is not None, "Required property 'enabled' is missing"
        return result

    def __eq__(self, rhs: typing.Any) -> builtins.bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs: typing.Any) -> builtins.bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return "KubernetesClusterAddonProfileAzurePolicy(%s)" % ", ".join(
            k + "=" + repr(v) for k, v in self._values.items()
        )


@jsii.data_type(
    jsii_type="@cdktf/provider-azurerm.KubernetesClusterAddonProfileHttpApplicationRouting",
    jsii_struct_bases=[],
    name_mapping={"enabled": "enabled"},
)
class KubernetesClusterAddonProfileHttpApplicationRouting:
    def __init__(self, *, enabled: builtins.bool) -> None:
        """
        :param enabled: 
        """
        self._values: typing.Dict[str, typing.Any] = {
            "enabled": enabled,
        }

    @builtins.property
    def enabled(self) -> builtins.bool:
        result = self._values.get("enabled")
        assert result is not None, "Required property 'enabled' is missing"
        return result

    def __eq__(self, rhs: typing.Any) -> builtins.bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs: typing.Any) -> builtins.bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return "KubernetesClusterAddonProfileHttpApplicationRouting(%s)" % ", ".join(
            k + "=" + repr(v) for k, v in self._values.items()
        )


@jsii.data_type(
    jsii_type="@cdktf/provider-azurerm.KubernetesClusterAddonProfileKubeDashboard",
    jsii_struct_bases=[],
    name_mapping={"enabled": "enabled"},
)
class KubernetesClusterAddonProfileKubeDashboard:
    def __init__(self, *, enabled: builtins.bool) -> None:
        """
        :param enabled: 
        """
        self._values: typing.Dict[str, typing.Any] = {
            "enabled": enabled,
        }

    @builtins.property
    def enabled(self) -> builtins.bool:
        result = self._values.get("enabled")
        assert result is not None, "Required property 'enabled' is missing"
        return result

    def __eq__(self, rhs: typing.Any) -> builtins.bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs: typing.Any) -> builtins.bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return "KubernetesClusterAddonProfileKubeDashboard(%s)" % ", ".join(
            k + "=" + repr(v) for k, v in self._values.items()
        )


@jsii.data_type(
    jsii_type="@cdktf/provider-azurerm.KubernetesClusterAddonProfileOmsAgent",
    jsii_struct_bases=[],
    name_mapping={
        "enabled": "enabled",
        "log_analytics_workspace_id": "logAnalyticsWorkspaceId",
    },
)
class KubernetesClusterAddonProfileOmsAgent:
    def __init__(
        self,
        *,
        enabled: builtins.bool,
        log_analytics_workspace_id: typing.Optional[builtins.str] = None,
    ) -> None:
        """
        :param enabled: 
        :param log_analytics_workspace_id: 
        """
        self._values: typing.Dict[str, typing.Any] = {
            "enabled": enabled,
        }
        if log_analytics_workspace_id is not None:
            self._values["log_analytics_workspace_id"] = log_analytics_workspace_id

    @builtins.property
    def enabled(self) -> builtins.bool:
        result = self._values.get("enabled")
        assert result is not None, "Required property 'enabled' is missing"
        return result

    @builtins.property
    def log_analytics_workspace_id(self) -> typing.Optional[builtins.str]:
        result = self._values.get("log_analytics_workspace_id")
        return result

    def __eq__(self, rhs: typing.Any) -> builtins.bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs: typing.Any) -> builtins.bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return "KubernetesClusterAddonProfileOmsAgent(%s)" % ", ".join(
            k + "=" + repr(v) for k, v in self._values.items()
        )


@jsii.data_type(
    jsii_type="@cdktf/provider-azurerm.KubernetesClusterConfig",
    jsii_struct_bases=[cdktf.TerraformMetaArguments],
    name_mapping={
        "count": "count",
        "depends_on": "dependsOn",
        "lifecycle": "lifecycle",
        "provider": "provider",
        "default_node_pool": "defaultNodePool",
        "dns_prefix": "dnsPrefix",
        "location": "location",
        "name": "name",
        "resource_group_name": "resourceGroupName",
        "service_principal": "servicePrincipal",
        "addon_profile": "addonProfile",
        "api_server_authorized_ip_ranges": "apiServerAuthorizedIpRanges",
        "enable_pod_security_policy": "enablePodSecurityPolicy",
        "identity": "identity",
        "kubernetes_version": "kubernetesVersion",
        "linux_profile": "linuxProfile",
        "network_profile": "networkProfile",
        "node_resource_group": "nodeResourceGroup",
        "private_link_enabled": "privateLinkEnabled",
        "role_based_access_control": "roleBasedAccessControl",
        "tags": "tags",
        "timeouts": "timeouts",
        "windows_profile": "windowsProfile",
    },
)
class KubernetesClusterConfig(cdktf.TerraformMetaArguments):
    def __init__(
        self,
        *,
        count: typing.Optional[jsii.Number] = None,
        depends_on: typing.Optional[typing.List[cdktf.TerraformResource]] = None,
        lifecycle: typing.Optional[cdktf.TerraformResourceLifecycle] = None,
        provider: typing.Optional[cdktf.TerraformProvider] = None,
        default_node_pool: typing.List["KubernetesClusterDefaultNodePool"],
        dns_prefix: builtins.str,
        location: builtins.str,
        name: builtins.str,
        resource_group_name: builtins.str,
        service_principal: typing.List["KubernetesClusterServicePrincipal"],
        addon_profile: typing.Optional[typing.List[KubernetesClusterAddonProfile]] = None,
        api_server_authorized_ip_ranges: typing.Optional[typing.List[builtins.str]] = None,
        enable_pod_security_policy: typing.Optional[builtins.bool] = None,
        identity: typing.Optional[typing.List["KubernetesClusterIdentity"]] = None,
        kubernetes_version: typing.Optional[builtins.str] = None,
        linux_profile: typing.Optional[typing.List["KubernetesClusterLinuxProfile"]] = None,
        network_profile: typing.Optional[typing.List["KubernetesClusterNetworkProfile"]] = None,
        node_resource_group: typing.Optional[builtins.str] = None,
        private_link_enabled: typing.Optional[builtins.bool] = None,
        role_based_access_control: typing.Optional[typing.List["KubernetesClusterRoleBasedAccessControl"]] = None,
        tags: typing.Optional[typing.Mapping[builtins.str, builtins.str]] = None,
        timeouts: typing.Optional["KubernetesClusterTimeouts"] = None,
        windows_profile: typing.Optional[typing.List["KubernetesClusterWindowsProfile"]] = None,
    ) -> None:
        """
        :param count: 
        :param depends_on: 
        :param lifecycle: 
        :param provider: 
        :param default_node_pool: default_node_pool block.
        :param dns_prefix: 
        :param location: 
        :param name: 
        :param resource_group_name: 
        :param service_principal: service_principal block.
        :param addon_profile: addon_profile block.
        :param api_server_authorized_ip_ranges: 
        :param enable_pod_security_policy: 
        :param identity: identity block.
        :param kubernetes_version: 
        :param linux_profile: linux_profile block.
        :param network_profile: network_profile block.
        :param node_resource_group: 
        :param private_link_enabled: 
        :param role_based_access_control: role_based_access_control block.
        :param tags: 
        :param timeouts: timeouts block.
        :param windows_profile: windows_profile block.
        """
        if isinstance(lifecycle, dict):
            lifecycle = cdktf.TerraformResourceLifecycle(**lifecycle)
        if isinstance(timeouts, dict):
            timeouts = KubernetesClusterTimeouts(**timeouts)
        self._values: typing.Dict[str, typing.Any] = {
            "default_node_pool": default_node_pool,
            "dns_prefix": dns_prefix,
            "location": location,
            "name": name,
            "resource_group_name": resource_group_name,
            "service_principal": service_principal,
        }
        if count is not None:
            self._values["count"] = count
        if depends_on is not None:
            self._values["depends_on"] = depends_on
        if lifecycle is not None:
            self._values["lifecycle"] = lifecycle
        if provider is not None:
            self._values["provider"] = provider
        if addon_profile is not None:
            self._values["addon_profile"] = addon_profile
        if api_server_authorized_ip_ranges is not None:
            self._values["api_server_authorized_ip_ranges"] = api_server_authorized_ip_ranges
        if enable_pod_security_policy is not None:
            self._values["enable_pod_security_policy"] = enable_pod_security_policy
        if identity is not None:
            self._values["identity"] = identity
        if kubernetes_version is not None:
            self._values["kubernetes_version"] = kubernetes_version
        if linux_profile is not None:
            self._values["linux_profile"] = linux_profile
        if network_profile is not None:
            self._values["network_profile"] = network_profile
        if node_resource_group is not None:
            self._values["node_resource_group"] = node_resource_group
        if private_link_enabled is not None:
            self._values["private_link_enabled"] = private_link_enabled
        if role_based_access_control is not None:
            self._values["role_based_access_control"] = role_based_access_control
        if tags is not None:
            self._values["tags"] = tags
        if timeouts is not None:
            self._values["timeouts"] = timeouts
        if windows_profile is not None:
            self._values["windows_profile"] = windows_profile

    @builtins.property
    def count(self) -> typing.Optional[jsii.Number]:
        """
        :stability: experimental
        """
        result = self._values.get("count")
        return result

    @builtins.property
    def depends_on(self) -> typing.Optional[typing.List[cdktf.TerraformResource]]:
        """
        :stability: experimental
        """
        result = self._values.get("depends_on")
        return result

    @builtins.property
    def lifecycle(self) -> typing.Optional[cdktf.TerraformResourceLifecycle]:
        """
        :stability: experimental
        """
        result = self._values.get("lifecycle")
        return result

    @builtins.property
    def provider(self) -> typing.Optional[cdktf.TerraformProvider]:
        """
        :stability: experimental
        """
        result = self._values.get("provider")
        return result

    @builtins.property
    def default_node_pool(self) -> typing.List["KubernetesClusterDefaultNodePool"]:
        """default_node_pool block."""
        result = self._values.get("default_node_pool")
        assert result is not None, "Required property 'default_node_pool' is missing"
        return result

    @builtins.property
    def dns_prefix(self) -> builtins.str:
        result = self._values.get("dns_prefix")
        assert result is not None, "Required property 'dns_prefix' is missing"
        return result

    @builtins.property
    def location(self) -> builtins.str:
        result = self._values.get("location")
        assert result is not None, "Required property 'location' is missing"
        return result

    @builtins.property
    def name(self) -> builtins.str:
        result = self._values.get("name")
        assert result is not None, "Required property 'name' is missing"
        return result

    @builtins.property
    def resource_group_name(self) -> builtins.str:
        result = self._values.get("resource_group_name")
        assert result is not None, "Required property 'resource_group_name' is missing"
        return result

    @builtins.property
    def service_principal(self) -> typing.List["KubernetesClusterServicePrincipal"]:
        """service_principal block."""
        result = self._values.get("service_principal")
        assert result is not None, "Required property 'service_principal' is missing"
        return result

    @builtins.property
    def addon_profile(
        self,
    ) -> typing.Optional[typing.List[KubernetesClusterAddonProfile]]:
        """addon_profile block."""
        result = self._values.get("addon_profile")
        return result

    @builtins.property
    def api_server_authorized_ip_ranges(
        self,
    ) -> typing.Optional[typing.List[builtins.str]]:
        result = self._values.get("api_server_authorized_ip_ranges")
        return result

    @builtins.property
    def enable_pod_security_policy(self) -> typing.Optional[builtins.bool]:
        result = self._values.get("enable_pod_security_policy")
        return result

    @builtins.property
    def identity(self) -> typing.Optional[typing.List["KubernetesClusterIdentity"]]:
        """identity block."""
        result = self._values.get("identity")
        return result

    @builtins.property
    def kubernetes_version(self) -> typing.Optional[builtins.str]:
        result = self._values.get("kubernetes_version")
        return result

    @builtins.property
    def linux_profile(
        self,
    ) -> typing.Optional[typing.List["KubernetesClusterLinuxProfile"]]:
        """linux_profile block."""
        result = self._values.get("linux_profile")
        return result

    @builtins.property
    def network_profile(
        self,
    ) -> typing.Optional[typing.List["KubernetesClusterNetworkProfile"]]:
        """network_profile block."""
        result = self._values.get("network_profile")
        return result

    @builtins.property
    def node_resource_group(self) -> typing.Optional[builtins.str]:
        result = self._values.get("node_resource_group")
        return result

    @builtins.property
    def private_link_enabled(self) -> typing.Optional[builtins.bool]:
        result = self._values.get("private_link_enabled")
        return result

    @builtins.property
    def role_based_access_control(
        self,
    ) -> typing.Optional[typing.List["KubernetesClusterRoleBasedAccessControl"]]:
        """role_based_access_control block."""
        result = self._values.get("role_based_access_control")
        return result

    @builtins.property
    def tags(self) -> typing.Optional[typing.Mapping[builtins.str, builtins.str]]:
        result = self._values.get("tags")
        return result

    @builtins.property
    def timeouts(self) -> typing.Optional["KubernetesClusterTimeouts"]:
        """timeouts block."""
        result = self._values.get("timeouts")
        return result

    @builtins.property
    def windows_profile(
        self,
    ) -> typing.Optional[typing.List["KubernetesClusterWindowsProfile"]]:
        """windows_profile block."""
        result = self._values.get("windows_profile")
        return result

    def __eq__(self, rhs: typing.Any) -> builtins.bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs: typing.Any) -> builtins.bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return "KubernetesClusterConfig(%s)" % ", ".join(
            k + "=" + repr(v) for k, v in self._values.items()
        )


@jsii.data_type(
    jsii_type="@cdktf/provider-azurerm.KubernetesClusterDefaultNodePool",
    jsii_struct_bases=[],
    name_mapping={
        "name": "name",
        "vm_size": "vmSize",
        "availability_zones": "availabilityZones",
        "enable_auto_scaling": "enableAutoScaling",
        "enable_node_public_ip": "enableNodePublicIp",
        "max_count": "maxCount",
        "max_pods": "maxPods",
        "min_count": "minCount",
        "node_count": "nodeCount",
        "node_taints": "nodeTaints",
        "os_disk_size_gb": "osDiskSizeGb",
        "type": "type",
        "vnet_subnet_id": "vnetSubnetId",
    },
)
class KubernetesClusterDefaultNodePool:
    def __init__(
        self,
        *,
        name: builtins.str,
        vm_size: builtins.str,
        availability_zones: typing.Optional[typing.List[builtins.str]] = None,
        enable_auto_scaling: typing.Optional[builtins.bool] = None,
        enable_node_public_ip: typing.Optional[builtins.bool] = None,
        max_count: typing.Optional[jsii.Number] = None,
        max_pods: typing.Optional[jsii.Number] = None,
        min_count: typing.Optional[jsii.Number] = None,
        node_count: typing.Optional[jsii.Number] = None,
        node_taints: typing.Optional[typing.List[builtins.str]] = None,
        os_disk_size_gb: typing.Optional[jsii.Number] = None,
        type: typing.Optional[builtins.str] = None,
        vnet_subnet_id: typing.Optional[builtins.str] = None,
    ) -> None:
        """
        :param name: 
        :param vm_size: 
        :param availability_zones: 
        :param enable_auto_scaling: 
        :param enable_node_public_ip: 
        :param max_count: 
        :param max_pods: 
        :param min_count: 
        :param node_count: 
        :param node_taints: 
        :param os_disk_size_gb: 
        :param type: 
        :param vnet_subnet_id: 
        """
        self._values: typing.Dict[str, typing.Any] = {
            "name": name,
            "vm_size": vm_size,
        }
        if availability_zones is not None:
            self._values["availability_zones"] = availability_zones
        if enable_auto_scaling is not None:
            self._values["enable_auto_scaling"] = enable_auto_scaling
        if enable_node_public_ip is not None:
            self._values["enable_node_public_ip"] = enable_node_public_ip
        if max_count is not None:
            self._values["max_count"] = max_count
        if max_pods is not None:
            self._values["max_pods"] = max_pods
        if min_count is not None:
            self._values["min_count"] = min_count
        if node_count is not None:
            self._values["node_count"] = node_count
        if node_taints is not None:
            self._values["node_taints"] = node_taints
        if os_disk_size_gb is not None:
            self._values["os_disk_size_gb"] = os_disk_size_gb
        if type is not None:
            self._values["type"] = type
        if vnet_subnet_id is not None:
            self._values["vnet_subnet_id"] = vnet_subnet_id

    @builtins.property
    def name(self) -> builtins.str:
        result = self._values.get("name")
        assert result is not None, "Required property 'name' is missing"
        return result

    @builtins.property
    def vm_size(self) -> builtins.str:
        result = self._values.get("vm_size")
        assert result is not None, "Required property 'vm_size' is missing"
        return result

    @builtins.property
    def availability_zones(self) -> typing.Optional[typing.List[builtins.str]]:
        result = self._values.get("availability_zones")
        return result

    @builtins.property
    def enable_auto_scaling(self) -> typing.Optional[builtins.bool]:
        result = self._values.get("enable_auto_scaling")
        return result

    @builtins.property
    def enable_node_public_ip(self) -> typing.Optional[builtins.bool]:
        result = self._values.get("enable_node_public_ip")
        return result

    @builtins.property
    def max_count(self) -> typing.Optional[jsii.Number]:
        result = self._values.get("max_count")
        return result

    @builtins.property
    def max_pods(self) -> typing.Optional[jsii.Number]:
        result = self._values.get("max_pods")
        return result

    @builtins.property
    def min_count(self) -> typing.Optional[jsii.Number]:
        result = self._values.get("min_count")
        return result

    @builtins.property
    def node_count(self) -> typing.Optional[jsii.Number]:
        result = self._values.get("node_count")
        return result

    @builtins.property
    def node_taints(self) -> typing.Optional[typing.List[builtins.str]]:
        result = self._values.get("node_taints")
        return result

    @builtins.property
    def os_disk_size_gb(self) -> typing.Optional[jsii.Number]:
        result = self._values.get("os_disk_size_gb")
        return result

    @builtins.property
    def type(self) -> typing.Optional[builtins.str]:
        result = self._values.get("type")
        return result

    @builtins.property
    def vnet_subnet_id(self) -> typing.Optional[builtins.str]:
        result = self._values.get("vnet_subnet_id")
        return result

    def __eq__(self, rhs: typing.Any) -> builtins.bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs: typing.Any) -> builtins.bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return "KubernetesClusterDefaultNodePool(%s)" % ", ".join(
            k + "=" + repr(v) for k, v in self._values.items()
        )


@jsii.data_type(
    jsii_type="@cdktf/provider-azurerm.KubernetesClusterIdentity",
    jsii_struct_bases=[],
    name_mapping={"type": "type"},
)
class KubernetesClusterIdentity:
    def __init__(self, *, type: builtins.str) -> None:
        """
        :param type: 
        """
        self._values: typing.Dict[str, typing.Any] = {
            "type": type,
        }

    @builtins.property
    def type(self) -> builtins.str:
        result = self._values.get("type")
        assert result is not None, "Required property 'type' is missing"
        return result

    def __eq__(self, rhs: typing.Any) -> builtins.bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs: typing.Any) -> builtins.bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return "KubernetesClusterIdentity(%s)" % ", ".join(
            k + "=" + repr(v) for k, v in self._values.items()
        )


class KubernetesClusterKubeAdminConfig(
    cdktf.ComplexComputedList,
    metaclass=jsii.JSIIMeta,
    jsii_type="@cdktf/provider-azurerm.KubernetesClusterKubeAdminConfig",
):
    def __init__(
        self,
        terraform_resource: cdktf.ITerraformResource,
        terraform_attribute: builtins.str,
        index: builtins.str,
    ) -> None:
        """
        :param terraform_resource: -
        :param terraform_attribute: -
        :param index: -

        :stability: experimental
        """
        jsii.create(KubernetesClusterKubeAdminConfig, self, [terraform_resource, terraform_attribute, index])

    @builtins.property # type: ignore
    @jsii.member(jsii_name="clientCertificate")
    def client_certificate(self) -> builtins.str:
        return jsii.get(self, "clientCertificate")

    @builtins.property # type: ignore
    @jsii.member(jsii_name="clientKey")
    def client_key(self) -> builtins.str:
        return jsii.get(self, "clientKey")

    @builtins.property # type: ignore
    @jsii.member(jsii_name="clusterCaCertificate")
    def cluster_ca_certificate(self) -> builtins.str:
        return jsii.get(self, "clusterCaCertificate")

    @builtins.property # type: ignore
    @jsii.member(jsii_name="host")
    def host(self) -> builtins.str:
        return jsii.get(self, "host")

    @builtins.property # type: ignore
    @jsii.member(jsii_name="password")
    def password(self) -> builtins.str:
        return jsii.get(self, "password")

    @builtins.property # type: ignore
    @jsii.member(jsii_name="username")
    def username(self) -> builtins.str:
        return jsii.get(self, "username")


class KubernetesClusterKubeConfig(
    cdktf.ComplexComputedList,
    metaclass=jsii.JSIIMeta,
    jsii_type="@cdktf/provider-azurerm.KubernetesClusterKubeConfig",
):
    def __init__(
        self,
        terraform_resource: cdktf.ITerraformResource,
        terraform_attribute: builtins.str,
        index: builtins.str,
    ) -> None:
        """
        :param terraform_resource: -
        :param terraform_attribute: -
        :param index: -

        :stability: experimental
        """
        jsii.create(KubernetesClusterKubeConfig, self, [terraform_resource, terraform_attribute, index])

    @builtins.property # type: ignore
    @jsii.member(jsii_name="clientCertificate")
    def client_certificate(self) -> builtins.str:
        return jsii.get(self, "clientCertificate")

    @builtins.property # type: ignore
    @jsii.member(jsii_name="clientKey")
    def client_key(self) -> builtins.str:
        return jsii.get(self, "clientKey")

    @builtins.property # type: ignore
    @jsii.member(jsii_name="clusterCaCertificate")
    def cluster_ca_certificate(self) -> builtins.str:
        return jsii.get(self, "clusterCaCertificate")

    @builtins.property # type: ignore
    @jsii.member(jsii_name="host")
    def host(self) -> builtins.str:
        return jsii.get(self, "host")

    @builtins.property # type: ignore
    @jsii.member(jsii_name="password")
    def password(self) -> builtins.str:
        return jsii.get(self, "password")

    @builtins.property # type: ignore
    @jsii.member(jsii_name="username")
    def username(self) -> builtins.str:
        return jsii.get(self, "username")


@jsii.data_type(
    jsii_type="@cdktf/provider-azurerm.KubernetesClusterLinuxProfile",
    jsii_struct_bases=[],
    name_mapping={"admin_username": "adminUsername", "ssh_key": "sshKey"},
)
class KubernetesClusterLinuxProfile:
    def __init__(
        self,
        *,
        admin_username: builtins.str,
        ssh_key: typing.List["KubernetesClusterLinuxProfileSshKey"],
    ) -> None:
        """
        :param admin_username: 
        :param ssh_key: ssh_key block.
        """
        self._values: typing.Dict[str, typing.Any] = {
            "admin_username": admin_username,
            "ssh_key": ssh_key,
        }

    @builtins.property
    def admin_username(self) -> builtins.str:
        result = self._values.get("admin_username")
        assert result is not None, "Required property 'admin_username' is missing"
        return result

    @builtins.property
    def ssh_key(self) -> typing.List["KubernetesClusterLinuxProfileSshKey"]:
        """ssh_key block."""
        result = self._values.get("ssh_key")
        assert result is not None, "Required property 'ssh_key' is missing"
        return result

    def __eq__(self, rhs: typing.Any) -> builtins.bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs: typing.Any) -> builtins.bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return "KubernetesClusterLinuxProfile(%s)" % ", ".join(
            k + "=" + repr(v) for k, v in self._values.items()
        )


@jsii.data_type(
    jsii_type="@cdktf/provider-azurerm.KubernetesClusterLinuxProfileSshKey",
    jsii_struct_bases=[],
    name_mapping={"key_data": "keyData"},
)
class KubernetesClusterLinuxProfileSshKey:
    def __init__(self, *, key_data: builtins.str) -> None:
        """
        :param key_data: 
        """
        self._values: typing.Dict[str, typing.Any] = {
            "key_data": key_data,
        }

    @builtins.property
    def key_data(self) -> builtins.str:
        result = self._values.get("key_data")
        assert result is not None, "Required property 'key_data' is missing"
        return result

    def __eq__(self, rhs: typing.Any) -> builtins.bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs: typing.Any) -> builtins.bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return "KubernetesClusterLinuxProfileSshKey(%s)" % ", ".join(
            k + "=" + repr(v) for k, v in self._values.items()
        )


@jsii.data_type(
    jsii_type="@cdktf/provider-azurerm.KubernetesClusterNetworkProfile",
    jsii_struct_bases=[],
    name_mapping={
        "network_plugin": "networkPlugin",
        "dns_service_ip": "dnsServiceIp",
        "docker_bridge_cidr": "dockerBridgeCidr",
        "load_balancer_profile": "loadBalancerProfile",
        "load_balancer_sku": "loadBalancerSku",
        "network_policy": "networkPolicy",
        "pod_cidr": "podCidr",
        "service_cidr": "serviceCidr",
    },
)
class KubernetesClusterNetworkProfile:
    def __init__(
        self,
        *,
        network_plugin: builtins.str,
        dns_service_ip: typing.Optional[builtins.str] = None,
        docker_bridge_cidr: typing.Optional[builtins.str] = None,
        load_balancer_profile: typing.Optional[typing.List["KubernetesClusterNetworkProfileLoadBalancerProfile"]] = None,
        load_balancer_sku: typing.Optional[builtins.str] = None,
        network_policy: typing.Optional[builtins.str] = None,
        pod_cidr: typing.Optional[builtins.str] = None,
        service_cidr: typing.Optional[builtins.str] = None,
    ) -> None:
        """
        :param network_plugin: 
        :param dns_service_ip: 
        :param docker_bridge_cidr: 
        :param load_balancer_profile: load_balancer_profile block.
        :param load_balancer_sku: 
        :param network_policy: 
        :param pod_cidr: 
        :param service_cidr: 
        """
        self._values: typing.Dict[str, typing.Any] = {
            "network_plugin": network_plugin,
        }
        if dns_service_ip is not None:
            self._values["dns_service_ip"] = dns_service_ip
        if docker_bridge_cidr is not None:
            self._values["docker_bridge_cidr"] = docker_bridge_cidr
        if load_balancer_profile is not None:
            self._values["load_balancer_profile"] = load_balancer_profile
        if load_balancer_sku is not None:
            self._values["load_balancer_sku"] = load_balancer_sku
        if network_policy is not None:
            self._values["network_policy"] = network_policy
        if pod_cidr is not None:
            self._values["pod_cidr"] = pod_cidr
        if service_cidr is not None:
            self._values["service_cidr"] = service_cidr

    @builtins.property
    def network_plugin(self) -> builtins.str:
        result = self._values.get("network_plugin")
        assert result is not None, "Required property 'network_plugin' is missing"
        return result

    @builtins.property
    def dns_service_ip(self) -> typing.Optional[builtins.str]:
        result = self._values.get("dns_service_ip")
        return result

    @builtins.property
    def docker_bridge_cidr(self) -> typing.Optional[builtins.str]:
        result = self._values.get("docker_bridge_cidr")
        return result

    @builtins.property
    def load_balancer_profile(
        self,
    ) -> typing.Optional[typing.List["KubernetesClusterNetworkProfileLoadBalancerProfile"]]:
        """load_balancer_profile block."""
        result = self._values.get("load_balancer_profile")
        return result

    @builtins.property
    def load_balancer_sku(self) -> typing.Optional[builtins.str]:
        result = self._values.get("load_balancer_sku")
        return result

    @builtins.property
    def network_policy(self) -> typing.Optional[builtins.str]:
        result = self._values.get("network_policy")
        return result

    @builtins.property
    def pod_cidr(self) -> typing.Optional[builtins.str]:
        result = self._values.get("pod_cidr")
        return result

    @builtins.property
    def service_cidr(self) -> typing.Optional[builtins.str]:
        result = self._values.get("service_cidr")
        return result

    def __eq__(self, rhs: typing.Any) -> builtins.bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs: typing.Any) -> builtins.bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return "KubernetesClusterNetworkProfile(%s)" % ", ".join(
            k + "=" + repr(v) for k, v in self._values.items()
        )


@jsii.data_type(
    jsii_type="@cdktf/provider-azurerm.KubernetesClusterNetworkProfileLoadBalancerProfile",
    jsii_struct_bases=[],
    name_mapping={
        "managed_outbound_ip_count": "managedOutboundIpCount",
        "outbound_ip_address_ids": "outboundIpAddressIds",
        "outbound_ip_prefix_ids": "outboundIpPrefixIds",
    },
)
class KubernetesClusterNetworkProfileLoadBalancerProfile:
    def __init__(
        self,
        *,
        managed_outbound_ip_count: typing.Optional[jsii.Number] = None,
        outbound_ip_address_ids: typing.Optional[typing.List[builtins.str]] = None,
        outbound_ip_prefix_ids: typing.Optional[typing.List[builtins.str]] = None,
    ) -> None:
        """
        :param managed_outbound_ip_count: 
        :param outbound_ip_address_ids: 
        :param outbound_ip_prefix_ids: 
        """
        self._values: typing.Dict[str, typing.Any] = {}
        if managed_outbound_ip_count is not None:
            self._values["managed_outbound_ip_count"] = managed_outbound_ip_count
        if outbound_ip_address_ids is not None:
            self._values["outbound_ip_address_ids"] = outbound_ip_address_ids
        if outbound_ip_prefix_ids is not None:
            self._values["outbound_ip_prefix_ids"] = outbound_ip_prefix_ids

    @builtins.property
    def managed_outbound_ip_count(self) -> typing.Optional[jsii.Number]:
        result = self._values.get("managed_outbound_ip_count")
        return result

    @builtins.property
    def outbound_ip_address_ids(self) -> typing.Optional[typing.List[builtins.str]]:
        result = self._values.get("outbound_ip_address_ids")
        return result

    @builtins.property
    def outbound_ip_prefix_ids(self) -> typing.Optional[typing.List[builtins.str]]:
        result = self._values.get("outbound_ip_prefix_ids")
        return result

    def __eq__(self, rhs: typing.Any) -> builtins.bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs: typing.Any) -> builtins.bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return "KubernetesClusterNetworkProfileLoadBalancerProfile(%s)" % ", ".join(
            k + "=" + repr(v) for k, v in self._values.items()
        )


class KubernetesClusterNodePool(
    cdktf.TerraformResource,
    metaclass=jsii.JSIIMeta,
    jsii_type="@cdktf/provider-azurerm.KubernetesClusterNodePool",
):
    def __init__(
        self,
        scope: constructs.Construct,
        id: builtins.str,
        *,
        kubernetes_cluster_id: builtins.str,
        name: builtins.str,
        vm_size: builtins.str,
        availability_zones: typing.Optional[typing.List[builtins.str]] = None,
        enable_auto_scaling: typing.Optional[builtins.bool] = None,
        enable_node_public_ip: typing.Optional[builtins.bool] = None,
        max_count: typing.Optional[jsii.Number] = None,
        max_pods: typing.Optional[jsii.Number] = None,
        min_count: typing.Optional[jsii.Number] = None,
        node_count: typing.Optional[jsii.Number] = None,
        node_taints: typing.Optional[typing.List[builtins.str]] = None,
        os_disk_size_gb: typing.Optional[jsii.Number] = None,
        os_type: typing.Optional[builtins.str] = None,
        timeouts: typing.Optional["KubernetesClusterNodePoolTimeouts"] = None,
        vnet_subnet_id: typing.Optional[builtins.str] = None,
        count: typing.Optional[jsii.Number] = None,
        depends_on: typing.Optional[typing.List[cdktf.TerraformResource]] = None,
        lifecycle: typing.Optional[cdktf.TerraformResourceLifecycle] = None,
        provider: typing.Optional[cdktf.TerraformProvider] = None,
    ) -> None:
        """
        :param scope: -
        :param id: -
        :param kubernetes_cluster_id: 
        :param name: 
        :param vm_size: 
        :param availability_zones: 
        :param enable_auto_scaling: 
        :param enable_node_public_ip: 
        :param max_count: 
        :param max_pods: 
        :param min_count: 
        :param node_count: 
        :param node_taints: 
        :param os_disk_size_gb: 
        :param os_type: 
        :param timeouts: timeouts block.
        :param vnet_subnet_id: 
        :param count: 
        :param depends_on: 
        :param lifecycle: 
        :param provider: 
        """
        config = KubernetesClusterNodePoolConfig(
            kubernetes_cluster_id=kubernetes_cluster_id,
            name=name,
            vm_size=vm_size,
            availability_zones=availability_zones,
            enable_auto_scaling=enable_auto_scaling,
            enable_node_public_ip=enable_node_public_ip,
            max_count=max_count,
            max_pods=max_pods,
            min_count=min_count,
            node_count=node_count,
            node_taints=node_taints,
            os_disk_size_gb=os_disk_size_gb,
            os_type=os_type,
            timeouts=timeouts,
            vnet_subnet_id=vnet_subnet_id,
            count=count,
            depends_on=depends_on,
            lifecycle=lifecycle,
            provider=provider,
        )

        jsii.create(KubernetesClusterNodePool, self, [scope, id, config])

    @jsii.member(jsii_name="synthesizeAttributes")
    def _synthesize_attributes(self) -> typing.Mapping[builtins.str, typing.Any]:
        return jsii.invoke(self, "synthesizeAttributes", [])

    @builtins.property # type: ignore
    @jsii.member(jsii_name="kubernetesClusterId")
    def kubernetes_cluster_id(self) -> builtins.str:
        return jsii.get(self, "kubernetesClusterId")

    @kubernetes_cluster_id.setter # type: ignore
    def kubernetes_cluster_id(self, value: builtins.str) -> None:
        jsii.set(self, "kubernetesClusterId", value)

    @builtins.property # type: ignore
    @jsii.member(jsii_name="name")
    def name(self) -> builtins.str:
        return jsii.get(self, "name")

    @name.setter # type: ignore
    def name(self, value: builtins.str) -> None:
        jsii.set(self, "name", value)

    @builtins.property # type: ignore
    @jsii.member(jsii_name="vmSize")
    def vm_size(self) -> builtins.str:
        return jsii.get(self, "vmSize")

    @vm_size.setter # type: ignore
    def vm_size(self, value: builtins.str) -> None:
        jsii.set(self, "vmSize", value)

    @builtins.property # type: ignore
    @jsii.member(jsii_name="availabilityZones")
    def availability_zones(self) -> typing.Optional[typing.List[builtins.str]]:
        return jsii.get(self, "availabilityZones")

    @availability_zones.setter # type: ignore
    def availability_zones(
        self,
        value: typing.Optional[typing.List[builtins.str]],
    ) -> None:
        jsii.set(self, "availabilityZones", value)

    @builtins.property # type: ignore
    @jsii.member(jsii_name="enableAutoScaling")
    def enable_auto_scaling(self) -> typing.Optional[builtins.bool]:
        return jsii.get(self, "enableAutoScaling")

    @enable_auto_scaling.setter # type: ignore
    def enable_auto_scaling(self, value: typing.Optional[builtins.bool]) -> None:
        jsii.set(self, "enableAutoScaling", value)

    @builtins.property # type: ignore
    @jsii.member(jsii_name="enableNodePublicIp")
    def enable_node_public_ip(self) -> typing.Optional[builtins.bool]:
        return jsii.get(self, "enableNodePublicIp")

    @enable_node_public_ip.setter # type: ignore
    def enable_node_public_ip(self, value: typing.Optional[builtins.bool]) -> None:
        jsii.set(self, "enableNodePublicIp", value)

    @builtins.property # type: ignore
    @jsii.member(jsii_name="id")
    def id(self) -> typing.Optional[builtins.str]:
        return jsii.get(self, "id")

    @id.setter # type: ignore
    def id(self, value: typing.Optional[builtins.str]) -> None:
        jsii.set(self, "id", value)

    @builtins.property # type: ignore
    @jsii.member(jsii_name="maxCount")
    def max_count(self) -> typing.Optional[jsii.Number]:
        return jsii.get(self, "maxCount")

    @max_count.setter # type: ignore
    def max_count(self, value: typing.Optional[jsii.Number]) -> None:
        jsii.set(self, "maxCount", value)

    @builtins.property # type: ignore
    @jsii.member(jsii_name="maxPods")
    def max_pods(self) -> typing.Optional[jsii.Number]:
        return jsii.get(self, "maxPods")

    @max_pods.setter # type: ignore
    def max_pods(self, value: typing.Optional[jsii.Number]) -> None:
        jsii.set(self, "maxPods", value)

    @builtins.property # type: ignore
    @jsii.member(jsii_name="minCount")
    def min_count(self) -> typing.Optional[jsii.Number]:
        return jsii.get(self, "minCount")

    @min_count.setter # type: ignore
    def min_count(self, value: typing.Optional[jsii.Number]) -> None:
        jsii.set(self, "minCount", value)

    @builtins.property # type: ignore
    @jsii.member(jsii_name="nodeCount")
    def node_count(self) -> typing.Optional[jsii.Number]:
        return jsii.get(self, "nodeCount")

    @node_count.setter # type: ignore
    def node_count(self, value: typing.Optional[jsii.Number]) -> None:
        jsii.set(self, "nodeCount", value)

    @builtins.property # type: ignore
    @jsii.member(jsii_name="nodeTaints")
    def node_taints(self) -> typing.Optional[typing.List[builtins.str]]:
        return jsii.get(self, "nodeTaints")

    @node_taints.setter # type: ignore
    def node_taints(self, value: typing.Optional[typing.List[builtins.str]]) -> None:
        jsii.set(self, "nodeTaints", value)

    @builtins.property # type: ignore
    @jsii.member(jsii_name="osDiskSizeGb")
    def os_disk_size_gb(self) -> typing.Optional[jsii.Number]:
        return jsii.get(self, "osDiskSizeGb")

    @os_disk_size_gb.setter # type: ignore
    def os_disk_size_gb(self, value: typing.Optional[jsii.Number]) -> None:
        jsii.set(self, "osDiskSizeGb", value)

    @builtins.property # type: ignore
    @jsii.member(jsii_name="osType")
    def os_type(self) -> typing.Optional[builtins.str]:
        return jsii.get(self, "osType")

    @os_type.setter # type: ignore
    def os_type(self, value: typing.Optional[builtins.str]) -> None:
        jsii.set(self, "osType", value)

    @builtins.property # type: ignore
    @jsii.member(jsii_name="timeouts")
    def timeouts(self) -> typing.Optional["KubernetesClusterNodePoolTimeouts"]:
        return jsii.get(self, "timeouts")

    @timeouts.setter # type: ignore
    def timeouts(
        self,
        value: typing.Optional["KubernetesClusterNodePoolTimeouts"],
    ) -> None:
        jsii.set(self, "timeouts", value)

    @builtins.property # type: ignore
    @jsii.member(jsii_name="vnetSubnetId")
    def vnet_subnet_id(self) -> typing.Optional[builtins.str]:
        return jsii.get(self, "vnetSubnetId")

    @vnet_subnet_id.setter # type: ignore
    def vnet_subnet_id(self, value: typing.Optional[builtins.str]) -> None:
        jsii.set(self, "vnetSubnetId", value)


@jsii.data_type(
    jsii_type="@cdktf/provider-azurerm.KubernetesClusterNodePoolConfig",
    jsii_struct_bases=[cdktf.TerraformMetaArguments],
    name_mapping={
        "count": "count",
        "depends_on": "dependsOn",
        "lifecycle": "lifecycle",
        "provider": "provider",
        "kubernetes_cluster_id": "kubernetesClusterId",
        "name": "name",
        "vm_size": "vmSize",
        "availability_zones": "availabilityZones",
        "enable_auto_scaling": "enableAutoScaling",
        "enable_node_public_ip": "enableNodePublicIp",
        "max_count": "maxCount",
        "max_pods": "maxPods",
        "min_count": "minCount",
        "node_count": "nodeCount",
        "node_taints": "nodeTaints",
        "os_disk_size_gb": "osDiskSizeGb",
        "os_type": "osType",
        "timeouts": "timeouts",
        "vnet_subnet_id": "vnetSubnetId",
    },
)
class KubernetesClusterNodePoolConfig(cdktf.TerraformMetaArguments):
    def __init__(
        self,
        *,
        count: typing.Optional[jsii.Number] = None,
        depends_on: typing.Optional[typing.List[cdktf.TerraformResource]] = None,
        lifecycle: typing.Optional[cdktf.TerraformResourceLifecycle] = None,
        provider: typing.Optional[cdktf.TerraformProvider] = None,
        kubernetes_cluster_id: builtins.str,
        name: builtins.str,
        vm_size: builtins.str,
        availability_zones: typing.Optional[typing.List[builtins.str]] = None,
        enable_auto_scaling: typing.Optional[builtins.bool] = None,
        enable_node_public_ip: typing.Optional[builtins.bool] = None,
        max_count: typing.Optional[jsii.Number] = None,
        max_pods: typing.Optional[jsii.Number] = None,
        min_count: typing.Optional[jsii.Number] = None,
        node_count: typing.Optional[jsii.Number] = None,
        node_taints: typing.Optional[typing.List[builtins.str]] = None,
        os_disk_size_gb: typing.Optional[jsii.Number] = None,
        os_type: typing.Optional[builtins.str] = None,
        timeouts: typing.Optional["KubernetesClusterNodePoolTimeouts"] = None,
        vnet_subnet_id: typing.Optional[builtins.str] = None,
    ) -> None:
        """
        :param count: 
        :param depends_on: 
        :param lifecycle: 
        :param provider: 
        :param kubernetes_cluster_id: 
        :param name: 
        :param vm_size: 
        :param availability_zones: 
        :param enable_auto_scaling: 
        :param enable_node_public_ip: 
        :param max_count: 
        :param max_pods: 
        :param min_count: 
        :param node_count: 
        :param node_taints: 
        :param os_disk_size_gb: 
        :param os_type: 
        :param timeouts: timeouts block.
        :param vnet_subnet_id: 
        """
        if isinstance(lifecycle, dict):
            lifecycle = cdktf.TerraformResourceLifecycle(**lifecycle)
        if isinstance(timeouts, dict):
            timeouts = KubernetesClusterNodePoolTimeouts(**timeouts)
        self._values: typing.Dict[str, typing.Any] = {
            "kubernetes_cluster_id": kubernetes_cluster_id,
            "name": name,
            "vm_size": vm_size,
        }
        if count is not None:
            self._values["count"] = count
        if depends_on is not None:
            self._values["depends_on"] = depends_on
        if lifecycle is not None:
            self._values["lifecycle"] = lifecycle
        if provider is not None:
            self._values["provider"] = provider
        if availability_zones is not None:
            self._values["availability_zones"] = availability_zones
        if enable_auto_scaling is not None:
            self._values["enable_auto_scaling"] = enable_auto_scaling
        if enable_node_public_ip is not None:
            self._values["enable_node_public_ip"] = enable_node_public_ip
        if max_count is not None:
            self._values["max_count"] = max_count
        if max_pods is not None:
            self._values["max_pods"] = max_pods
        if min_count is not None:
            self._values["min_count"] = min_count
        if node_count is not None:
            self._values["node_count"] = node_count
        if node_taints is not None:
            self._values["node_taints"] = node_taints
        if os_disk_size_gb is not None:
            self._values["os_disk_size_gb"] = os_disk_size_gb
        if os_type is not None:
            self._values["os_type"] = os_type
        if timeouts is not None:
            self._values["timeouts"] = timeouts
        if vnet_subnet_id is not None:
            self._values["vnet_subnet_id"] = vnet_subnet_id

    @builtins.property
    def count(self) -> typing.Optional[jsii.Number]:
        """
        :stability: experimental
        """
        result = self._values.get("count")
        return result

    @builtins.property
    def depends_on(self) -> typing.Optional[typing.List[cdktf.TerraformResource]]:
        """
        :stability: experimental
        """
        result = self._values.get("depends_on")
        return result

    @builtins.property
    def lifecycle(self) -> typing.Optional[cdktf.TerraformResourceLifecycle]:
        """
        :stability: experimental
        """
        result = self._values.get("lifecycle")
        return result

    @builtins.property
    def provider(self) -> typing.Optional[cdktf.TerraformProvider]:
        """
        :stability: experimental
        """
        result = self._values.get("provider")
        return result

    @builtins.property
    def kubernetes_cluster_id(self) -> builtins.str:
        result = self._values.get("kubernetes_cluster_id")
        assert result is not None, "Required property 'kubernetes_cluster_id' is missing"
        return result

    @builtins.property
    def name(self) -> builtins.str:
        result = self._values.get("name")
        assert result is not None, "Required property 'name' is missing"
        return result

    @builtins.property
    def vm_size(self) -> builtins.str:
        result = self._values.get("vm_size")
        assert result is not None, "Required property 'vm_size' is missing"
        return result

    @builtins.property
    def availability_zones(self) -> typing.Optional[typing.List[builtins.str]]:
        result = self._values.get("availability_zones")
        return result

    @builtins.property
    def enable_auto_scaling(self) -> typing.Optional[builtins.bool]:
        result = self._values.get("enable_auto_scaling")
        return result

    @builtins.property
    def enable_node_public_ip(self) -> typing.Optional[builtins.bool]:
        result = self._values.get("enable_node_public_ip")
        return result

    @builtins.property
    def max_count(self) -> typing.Optional[jsii.Number]:
        result = self._values.get("max_count")
        return result

    @builtins.property
    def max_pods(self) -> typing.Optional[jsii.Number]:
        result = self._values.get("max_pods")
        return result

    @builtins.property
    def min_count(self) -> typing.Optional[jsii.Number]:
        result = self._values.get("min_count")
        return result

    @builtins.property
    def node_count(self) -> typing.Optional[jsii.Number]:
        result = self._values.get("node_count")
        return result

    @builtins.property
    def node_taints(self) -> typing.Optional[typing.List[builtins.str]]:
        result = self._values.get("node_taints")
        return result

    @builtins.property
    def os_disk_size_gb(self) -> typing.Optional[jsii.Number]:
        result = self._values.get("os_disk_size_gb")
        return result

    @builtins.property
    def os_type(self) -> typing.Optional[builtins.str]:
        result = self._values.get("os_type")
        return result

    @builtins.property
    def timeouts(self) -> typing.Optional["KubernetesClusterNodePoolTimeouts"]:
        """timeouts block."""
        result = self._values.get("timeouts")
        return result

    @builtins.property
    def vnet_subnet_id(self) -> typing.Optional[builtins.str]:
        result = self._values.get("vnet_subnet_id")
        return result

    def __eq__(self, rhs: typing.Any) -> builtins.bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs: typing.Any) -> builtins.bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return "KubernetesClusterNodePoolConfig(%s)" % ", ".join(
            k + "=" + repr(v) for k, v in self._values.items()
        )


@jsii.data_type(
    jsii_type="@cdktf/provider-azurerm.KubernetesClusterNodePoolTimeouts",
    jsii_struct_bases=[],
    name_mapping={
        "create": "create",
        "delete": "delete",
        "read": "read",
        "update": "update",
    },
)
class KubernetesClusterNodePoolTimeouts:
    def __init__(
        self,
        *,
        create: typing.Optional[builtins.str] = None,
        delete: typing.Optional[builtins.str] = None,
        read: typing.Optional[builtins.str] = None,
        update: typing.Optional[builtins.str] = None,
    ) -> None:
        """
        :param create: 
        :param delete: 
        :param read: 
        :param update: 
        """
        self._values: typing.Dict[str, typing.Any] = {}
        if create is not None:
            self._values["create"] = create
        if delete is not None:
            self._values["delete"] = delete
        if read is not None:
            self._values["read"] = read
        if update is not None:
            self._values["update"] = update

    @builtins.property
    def create(self) -> typing.Optional[builtins.str]:
        result = self._values.get("create")
        return result

    @builtins.property
    def delete(self) -> typing.Optional[builtins.str]:
        result = self._values.get("delete")
        return result

    @builtins.property
    def read(self) -> typing.Optional[builtins.str]:
        result = self._values.get("read")
        return result

    @builtins.property
    def update(self) -> typing.Optional[builtins.str]:
        result = self._values.get("update")
        return result

    def __eq__(self, rhs: typing.Any) -> builtins.bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs: typing.Any) -> builtins.bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return "KubernetesClusterNodePoolTimeouts(%s)" % ", ".join(
            k + "=" + repr(v) for k, v in self._values.items()
        )


@jsii.data_type(
    jsii_type="@cdktf/provider-azurerm.KubernetesClusterRoleBasedAccessControl",
    jsii_struct_bases=[],
    name_mapping={
        "enabled": "enabled",
        "azure_active_directory": "azureActiveDirectory",
    },
)
class KubernetesClusterRoleBasedAccessControl:
    def __init__(
        self,
        *,
        enabled: builtins.bool,
        azure_active_directory: typing.Optional[typing.List["KubernetesClusterRoleBasedAccessControlAzureActiveDirectory"]] = None,
    ) -> None:
        """
        :param enabled: 
        :param azure_active_directory: azure_active_directory block.
        """
        self._values: typing.Dict[str, typing.Any] = {
            "enabled": enabled,
        }
        if azure_active_directory is not None:
            self._values["azure_active_directory"] = azure_active_directory

    @builtins.property
    def enabled(self) -> builtins.bool:
        result = self._values.get("enabled")
        assert result is not None, "Required property 'enabled' is missing"
        return result

    @builtins.property
    def azure_active_directory(
        self,
    ) -> typing.Optional[typing.List["KubernetesClusterRoleBasedAccessControlAzureActiveDirectory"]]:
        """azure_active_directory block."""
        result = self._values.get("azure_active_directory")
        return result

    def __eq__(self, rhs: typing.Any) -> builtins.bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs: typing.Any) -> builtins.bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return "KubernetesClusterRoleBasedAccessControl(%s)" % ", ".join(
            k + "=" + repr(v) for k, v in self._values.items()
        )


@jsii.data_type(
    jsii_type="@cdktf/provider-azurerm.KubernetesClusterRoleBasedAccessControlAzureActiveDirectory",
    jsii_struct_bases=[],
    name_mapping={
        "client_app_id": "clientAppId",
        "server_app_id": "serverAppId",
        "server_app_secret": "serverAppSecret",
        "tenant_id": "tenantId",
    },
)
class KubernetesClusterRoleBasedAccessControlAzureActiveDirectory:
    def __init__(
        self,
        *,
        client_app_id: builtins.str,
        server_app_id: builtins.str,
        server_app_secret: builtins.str,
        tenant_id: typing.Optional[builtins.str] = None,
    ) -> None:
        """
        :param client_app_id: 
        :param server_app_id: 
        :param server_app_secret: 
        :param tenant_id: 
        """
        self._values: typing.Dict[str, typing.Any] = {
            "client_app_id": client_app_id,
            "server_app_id": server_app_id,
            "server_app_secret": server_app_secret,
        }
        if tenant_id is not None:
            self._values["tenant_id"] = tenant_id

    @builtins.property
    def client_app_id(self) -> builtins.str:
        result = self._values.get("client_app_id")
        assert result is not None, "Required property 'client_app_id' is missing"
        return result

    @builtins.property
    def server_app_id(self) -> builtins.str:
        result = self._values.get("server_app_id")
        assert result is not None, "Required property 'server_app_id' is missing"
        return result

    @builtins.property
    def server_app_secret(self) -> builtins.str:
        result = self._values.get("server_app_secret")
        assert result is not None, "Required property 'server_app_secret' is missing"
        return result

    @builtins.property
    def tenant_id(self) -> typing.Optional[builtins.str]:
        result = self._values.get("tenant_id")
        return result

    def __eq__(self, rhs: typing.Any) -> builtins.bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs: typing.Any) -> builtins.bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return "KubernetesClusterRoleBasedAccessControlAzureActiveDirectory(%s)" % ", ".join(
            k + "=" + repr(v) for k, v in self._values.items()
        )


@jsii.data_type(
    jsii_type="@cdktf/provider-azurerm.KubernetesClusterServicePrincipal",
    jsii_struct_bases=[],
    name_mapping={"client_id": "clientId", "client_secret": "clientSecret"},
)
class KubernetesClusterServicePrincipal:
    def __init__(self, *, client_id: builtins.str, client_secret: builtins.str) -> None:
        """
        :param client_id: 
        :param client_secret: 
        """
        self._values: typing.Dict[str, typing.Any] = {
            "client_id": client_id,
            "client_secret": client_secret,
        }

    @builtins.property
    def client_id(self) -> builtins.str:
        result = self._values.get("client_id")
        assert result is not None, "Required property 'client_id' is missing"
        return result

    @builtins.property
    def client_secret(self) -> builtins.str:
        result = self._values.get("client_secret")
        assert result is not None, "Required property 'client_secret' is missing"
        return result

    def __eq__(self, rhs: typing.Any) -> builtins.bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs: typing.Any) -> builtins.bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return "KubernetesClusterServicePrincipal(%s)" % ", ".join(
            k + "=" + repr(v) for k, v in self._values.items()
        )


@jsii.data_type(
    jsii_type="@cdktf/provider-azurerm.KubernetesClusterTimeouts",
    jsii_struct_bases=[],
    name_mapping={
        "create": "create",
        "delete": "delete",
        "read": "read",
        "update": "update",
    },
)
class KubernetesClusterTimeouts:
    def __init__(
        self,
        *,
        create: typing.Optional[builtins.str] = None,
        delete: typing.Optional[builtins.str] = None,
        read: typing.Optional[builtins.str] = None,
        update: typing.Optional[builtins.str] = None,
    ) -> None:
        """
        :param create: 
        :param delete: 
        :param read: 
        :param update: 
        """
        self._values: typing.Dict[str, typing.Any] = {}
        if create is not None:
            self._values["create"] = create
        if delete is not None:
            self._values["delete"] = delete
        if read is not None:
            self._values["read"] = read
        if update is not None:
            self._values["update"] = update

    @builtins.property
    def create(self) -> typing.Optional[builtins.str]:
        result = self._values.get("create")
        return result

    @builtins.property
    def delete(self) -> typing.Optional[builtins.str]:
        result = self._values.get("delete")
        return result

    @builtins.property
    def read(self) -> typing.Optional[builtins.str]:
        result = self._values.get("read")
        return result

    @builtins.property
    def update(self) -> typing.Optional[builtins.str]:
        result = self._values.get("update")
        return result

    def __eq__(self, rhs: typing.Any) -> builtins.bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs: typing.Any) -> builtins.bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return "KubernetesClusterTimeouts(%s)" % ", ".join(
            k + "=" + repr(v) for k, v in self._values.items()
        )


@jsii.data_type(
    jsii_type="@cdktf/provider-azurerm.KubernetesClusterWindowsProfile",
    jsii_struct_bases=[],
    name_mapping={
        "admin_username": "adminUsername",
        "admin_password": "adminPassword",
    },
)
class KubernetesClusterWindowsProfile:
    def __init__(
        self,
        *,
        admin_username: builtins.str,
        admin_password: typing.Optional[builtins.str] = None,
    ) -> None:
        """
        :param admin_username: 
        :param admin_password: 
        """
        self._values: typing.Dict[str, typing.Any] = {
            "admin_username": admin_username,
        }
        if admin_password is not None:
            self._values["admin_password"] = admin_password

    @builtins.property
    def admin_username(self) -> builtins.str:
        result = self._values.get("admin_username")
        assert result is not None, "Required property 'admin_username' is missing"
        return result

    @builtins.property
    def admin_password(self) -> typing.Optional[builtins.str]:
        result = self._values.get("admin_password")
        return result

    def __eq__(self, rhs: typing.Any) -> builtins.bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs: typing.Any) -> builtins.bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return "KubernetesClusterWindowsProfile(%s)" % ", ".join(
            k + "=" + repr(v) for k, v in self._values.items()
        )


class KustoCluster(
    cdktf.TerraformResource,
    metaclass=jsii.JSIIMeta,
    jsii_type="@cdktf/provider-azurerm.KustoCluster",
):
    def __init__(
        self,
        scope: constructs.Construct,
        id: builtins.str,
        *,
        location: builtins.str,
        name: builtins.str,
        resource_group_name: builtins.str,
        sku: typing.List["KustoClusterSku"],
        tags: typing.Optional[typing.Mapping[builtins.str, builtins.str]] = None,
        timeouts: typing.Optional["KustoClusterTimeouts"] = None,
        count: typing.Optional[jsii.Number] = None,
        depends_on: typing.Optional[typing.List[cdktf.TerraformResource]] = None,
        lifecycle: typing.Optional[cdktf.TerraformResourceLifecycle] = None,
        provider: typing.Optional[cdktf.TerraformProvider] = None,
    ) -> None:
        """
        :param scope: -
        :param id: -
        :param location: 
        :param name: 
        :param resource_group_name: 
        :param sku: sku block.
        :param tags: 
        :param timeouts: timeouts block.
        :param count: 
        :param depends_on: 
        :param lifecycle: 
        :param provider: 
        """
        config = KustoClusterConfig(
            location=location,
            name=name,
            resource_group_name=resource_group_name,
            sku=sku,
            tags=tags,
            timeouts=timeouts,
            count=count,
            depends_on=depends_on,
            lifecycle=lifecycle,
            provider=provider,
        )

        jsii.create(KustoCluster, self, [scope, id, config])

    @jsii.member(jsii_name="synthesizeAttributes")
    def _synthesize_attributes(self) -> typing.Mapping[builtins.str, typing.Any]:
        return jsii.invoke(self, "synthesizeAttributes", [])

    @builtins.property # type: ignore
    @jsii.member(jsii_name="dataIngestionUri")
    def data_ingestion_uri(self) -> builtins.str:
        return jsii.get(self, "dataIngestionUri")

    @builtins.property # type: ignore
    @jsii.member(jsii_name="uri")
    def uri(self) -> builtins.str:
        return jsii.get(self, "uri")

    @builtins.property # type: ignore
    @jsii.member(jsii_name="location")
    def location(self) -> builtins.str:
        return jsii.get(self, "location")

    @location.setter # type: ignore
    def location(self, value: builtins.str) -> None:
        jsii.set(self, "location", value)

    @builtins.property # type: ignore
    @jsii.member(jsii_name="name")
    def name(self) -> builtins.str:
        return jsii.get(self, "name")

    @name.setter # type: ignore
    def name(self, value: builtins.str) -> None:
        jsii.set(self, "name", value)

    @builtins.property # type: ignore
    @jsii.member(jsii_name="resourceGroupName")
    def resource_group_name(self) -> builtins.str:
        return jsii.get(self, "resourceGroupName")

    @resource_group_name.setter # type: ignore
    def resource_group_name(self, value: builtins.str) -> None:
        jsii.set(self, "resourceGroupName", value)

    @builtins.property # type: ignore
    @jsii.member(jsii_name="sku")
    def sku(self) -> typing.List["KustoClusterSku"]:
        return jsii.get(self, "sku")

    @sku.setter # type: ignore
    def sku(self, value: typing.List["KustoClusterSku"]) -> None:
        jsii.set(self, "sku", value)

    @builtins.property # type: ignore
    @jsii.member(jsii_name="id")
    def id(self) -> typing.Optional[builtins.str]:
        return jsii.get(self, "id")

    @id.setter # type: ignore
    def id(self, value: typing.Optional[builtins.str]) -> None:
        jsii.set(self, "id", value)

    @builtins.property # type: ignore
    @jsii.member(jsii_name="tags")
    def tags(self) -> typing.Optional[typing.Mapping[builtins.str, builtins.str]]:
        return jsii.get(self, "tags")

    @tags.setter # type: ignore
    def tags(
        self,
        value: typing.Optional[typing.Mapping[builtins.str, builtins.str]],
    ) -> None:
        jsii.set(self, "tags", value)

    @builtins.property # type: ignore
    @jsii.member(jsii_name="timeouts")
    def timeouts(self) -> typing.Optional["KustoClusterTimeouts"]:
        return jsii.get(self, "timeouts")

    @timeouts.setter # type: ignore
    def timeouts(self, value: typing.Optional["KustoClusterTimeouts"]) -> None:
        jsii.set(self, "timeouts", value)


@jsii.data_type(
    jsii_type="@cdktf/provider-azurerm.KustoClusterConfig",
    jsii_struct_bases=[cdktf.TerraformMetaArguments],
    name_mapping={
        "count": "count",
        "depends_on": "dependsOn",
        "lifecycle": "lifecycle",
        "provider": "provider",
        "location": "location",
        "name": "name",
        "resource_group_name": "resourceGroupName",
        "sku": "sku",
        "tags": "tags",
        "timeouts": "timeouts",
    },
)
class KustoClusterConfig(cdktf.TerraformMetaArguments):
    def __init__(
        self,
        *,
        count: typing.Optional[jsii.Number] = None,
        depends_on: typing.Optional[typing.List[cdktf.TerraformResource]] = None,
        lifecycle: typing.Optional[cdktf.TerraformResourceLifecycle] = None,
        provider: typing.Optional[cdktf.TerraformProvider] = None,
        location: builtins.str,
        name: builtins.str,
        resource_group_name: builtins.str,
        sku: typing.List["KustoClusterSku"],
        tags: typing.Optional[typing.Mapping[builtins.str, builtins.str]] = None,
        timeouts: typing.Optional["KustoClusterTimeouts"] = None,
    ) -> None:
        """
        :param count: 
        :param depends_on: 
        :param lifecycle: 
        :param provider: 
        :param location: 
        :param name: 
        :param resource_group_name: 
        :param sku: sku block.
        :param tags: 
        :param timeouts: timeouts block.
        """
        if isinstance(lifecycle, dict):
            lifecycle = cdktf.TerraformResourceLifecycle(**lifecycle)
        if isinstance(timeouts, dict):
            timeouts = KustoClusterTimeouts(**timeouts)
        self._values: typing.Dict[str, typing.Any] = {
            "location": location,
            "name": name,
            "resource_group_name": resource_group_name,
            "sku": sku,
        }
        if count is not None:
            self._values["count"] = count
        if depends_on is not None:
            self._values["depends_on"] = depends_on
        if lifecycle is not None:
            self._values["lifecycle"] = lifecycle
        if provider is not None:
            self._values["provider"] = provider
        if tags is not None:
            self._values["tags"] = tags
        if timeouts is not None:
            self._values["timeouts"] = timeouts

    @builtins.property
    def count(self) -> typing.Optional[jsii.Number]:
        """
        :stability: experimental
        """
        result = self._values.get("count")
        return result

    @builtins.property
    def depends_on(self) -> typing.Optional[typing.List[cdktf.TerraformResource]]:
        """
        :stability: experimental
        """
        result = self._values.get("depends_on")
        return result

    @builtins.property
    def lifecycle(self) -> typing.Optional[cdktf.TerraformResourceLifecycle]:
        """
        :stability: experimental
        """
        result = self._values.get("lifecycle")
        return result

    @builtins.property
    def provider(self) -> typing.Optional[cdktf.TerraformProvider]:
        """
        :stability: experimental
        """
        result = self._values.get("provider")
        return result

    @builtins.property
    def location(self) -> builtins.str:
        result = self._values.get("location")
        assert result is not None, "Required property 'location' is missing"
        return result

    @builtins.property
    def name(self) -> builtins.str:
        result = self._values.get("name")
        assert result is not None, "Required property 'name' is missing"
        return result

    @builtins.property
    def resource_group_name(self) -> builtins.str:
        result = self._values.get("resource_group_name")
        assert result is not None, "Required property 'resource_group_name' is missing"
        return result

    @builtins.property
    def sku(self) -> typing.List["KustoClusterSku"]:
        """sku block."""
        result = self._values.get("sku")
        assert result is not None, "Required property 'sku' is missing"
        return result

    @builtins.property
    def tags(self) -> typing.Optional[typing.Mapping[builtins.str, builtins.str]]:
        result = self._values.get("tags")
        return result

    @builtins.property
    def timeouts(self) -> typing.Optional["KustoClusterTimeouts"]:
        """timeouts block."""
        result = self._values.get("timeouts")
        return result

    def __eq__(self, rhs: typing.Any) -> builtins.bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs: typing.Any) -> builtins.bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return "KustoClusterConfig(%s)" % ", ".join(
            k + "=" + repr(v) for k, v in self._values.items()
        )


@jsii.data_type(
    jsii_type="@cdktf/provider-azurerm.KustoClusterSku",
    jsii_struct_bases=[],
    name_mapping={"capacity": "capacity", "name": "name"},
)
class KustoClusterSku:
    def __init__(self, *, capacity: jsii.Number, name: builtins.str) -> None:
        """
        :param capacity: 
        :param name: 
        """
        self._values: typing.Dict[str, typing.Any] = {
            "capacity": capacity,
            "name": name,
        }

    @builtins.property
    def capacity(self) -> jsii.Number:
        result = self._values.get("capacity")
        assert result is not None, "Required property 'capacity' is missing"
        return result

    @builtins.property
    def name(self) -> builtins.str:
        result = self._values.get("name")
        assert result is not None, "Required property 'name' is missing"
        return result

    def __eq__(self, rhs: typing.Any) -> builtins.bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs: typing.Any) -> builtins.bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return "KustoClusterSku(%s)" % ", ".join(
            k + "=" + repr(v) for k, v in self._values.items()
        )


@jsii.data_type(
    jsii_type="@cdktf/provider-azurerm.KustoClusterTimeouts",
    jsii_struct_bases=[],
    name_mapping={
        "create": "create",
        "delete": "delete",
        "read": "read",
        "update": "update",
    },
)
class KustoClusterTimeouts:
    def __init__(
        self,
        *,
        create: typing.Optional[builtins.str] = None,
        delete: typing.Optional[builtins.str] = None,
        read: typing.Optional[builtins.str] = None,
        update: typing.Optional[builtins.str] = None,
    ) -> None:
        """
        :param create: 
        :param delete: 
        :param read: 
        :param update: 
        """
        self._values: typing.Dict[str, typing.Any] = {}
        if create is not None:
            self._values["create"] = create
        if delete is not None:
            self._values["delete"] = delete
        if read is not None:
            self._values["read"] = read
        if update is not None:
            self._values["update"] = update

    @builtins.property
    def create(self) -> typing.Optional[builtins.str]:
        result = self._values.get("create")
        return result

    @builtins.property
    def delete(self) -> typing.Optional[builtins.str]:
        result = self._values.get("delete")
        return result

    @builtins.property
    def read(self) -> typing.Optional[builtins.str]:
        result = self._values.get("read")
        return result

    @builtins.property
    def update(self) -> typing.Optional[builtins.str]:
        result = self._values.get("update")
        return result

    def __eq__(self, rhs: typing.Any) -> builtins.bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs: typing.Any) -> builtins.bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return "KustoClusterTimeouts(%s)" % ", ".join(
            k + "=" + repr(v) for k, v in self._values.items()
        )


class KustoDatabase(
    cdktf.TerraformResource,
    metaclass=jsii.JSIIMeta,
    jsii_type="@cdktf/provider-azurerm.KustoDatabase",
):
    def __init__(
        self,
        scope: constructs.Construct,
        id: builtins.str,
        *,
        cluster_name: builtins.str,
        location: builtins.str,
        name: builtins.str,
        resource_group_name: builtins.str,
        hot_cache_period: typing.Optional[builtins.str] = None,
        soft_delete_period: typing.Optional[builtins.str] = None,
        timeouts: typing.Optional["KustoDatabaseTimeouts"] = None,
        count: typing.Optional[jsii.Number] = None,
        depends_on: typing.Optional[typing.List[cdktf.TerraformResource]] = None,
        lifecycle: typing.Optional[cdktf.TerraformResourceLifecycle] = None,
        provider: typing.Optional[cdktf.TerraformProvider] = None,
    ) -> None:
        """
        :param scope: -
        :param id: -
        :param cluster_name: 
        :param location: 
        :param name: 
        :param resource_group_name: 
        :param hot_cache_period: 
        :param soft_delete_period: 
        :param timeouts: timeouts block.
        :param count: 
        :param depends_on: 
        :param lifecycle: 
        :param provider: 
        """
        config = KustoDatabaseConfig(
            cluster_name=cluster_name,
            location=location,
            name=name,
            resource_group_name=resource_group_name,
            hot_cache_period=hot_cache_period,
            soft_delete_period=soft_delete_period,
            timeouts=timeouts,
            count=count,
            depends_on=depends_on,
            lifecycle=lifecycle,
            provider=provider,
        )

        jsii.create(KustoDatabase, self, [scope, id, config])

    @jsii.member(jsii_name="synthesizeAttributes")
    def _synthesize_attributes(self) -> typing.Mapping[builtins.str, typing.Any]:
        return jsii.invoke(self, "synthesizeAttributes", [])

    @builtins.property # type: ignore
    @jsii.member(jsii_name="size")
    def size(self) -> jsii.Number:
        return jsii.get(self, "size")

    @builtins.property # type: ignore
    @jsii.member(jsii_name="clusterName")
    def cluster_name(self) -> builtins.str:
        return jsii.get(self, "clusterName")

    @cluster_name.setter # type: ignore
    def cluster_name(self, value: builtins.str) -> None:
        jsii.set(self, "clusterName", value)

    @builtins.property # type: ignore
    @jsii.member(jsii_name="location")
    def location(self) -> builtins.str:
        return jsii.get(self, "location")

    @location.setter # type: ignore
    def location(self, value: builtins.str) -> None:
        jsii.set(self, "location", value)

    @builtins.property # type: ignore
    @jsii.member(jsii_name="name")
    def name(self) -> builtins.str:
        return jsii.get(self, "name")

    @name.setter # type: ignore
    def name(self, value: builtins.str) -> None:
        jsii.set(self, "name", value)

    @builtins.property # type: ignore
    @jsii.member(jsii_name="resourceGroupName")
    def resource_group_name(self) -> builtins.str:
        return jsii.get(self, "resourceGroupName")

    @resource_group_name.setter # type: ignore
    def resource_group_name(self, value: builtins.str) -> None:
        jsii.set(self, "resourceGroupName", value)

    @builtins.property # type: ignore
    @jsii.member(jsii_name="hotCachePeriod")
    def hot_cache_period(self) -> typing.Optional[builtins.str]:
        return jsii.get(self, "hotCachePeriod")

    @hot_cache_period.setter # type: ignore
    def hot_cache_period(self, value: typing.Optional[builtins.str]) -> None:
        jsii.set(self, "hotCachePeriod", value)

    @builtins.property # type: ignore
    @jsii.member(jsii_name="id")
    def id(self) -> typing.Optional[builtins.str]:
        return jsii.get(self, "id")

    @id.setter # type: ignore
    def id(self, value: typing.Optional[builtins.str]) -> None:
        jsii.set(self, "id", value)

    @builtins.property # type: ignore
    @jsii.member(jsii_name="softDeletePeriod")
    def soft_delete_period(self) -> typing.Optional[builtins.str]:
        return jsii.get(self, "softDeletePeriod")

    @soft_delete_period.setter # type: ignore
    def soft_delete_period(self, value: typing.Optional[builtins.str]) -> None:
        jsii.set(self, "softDeletePeriod", value)

    @builtins.property # type: ignore
    @jsii.member(jsii_name="timeouts")
    def timeouts(self) -> typing.Optional["KustoDatabaseTimeouts"]:
        return jsii.get(self, "timeouts")

    @timeouts.setter # type: ignore
    def timeouts(self, value: typing.Optional["KustoDatabaseTimeouts"]) -> None:
        jsii.set(self, "timeouts", value)


@jsii.data_type(
    jsii_type="@cdktf/provider-azurerm.KustoDatabaseConfig",
    jsii_struct_bases=[cdktf.TerraformMetaArguments],
    name_mapping={
        "count": "count",
        "depends_on": "dependsOn",
        "lifecycle": "lifecycle",
        "provider": "provider",
        "cluster_name": "clusterName",
        "location": "location",
        "name": "name",
        "resource_group_name": "resourceGroupName",
        "hot_cache_period": "hotCachePeriod",
        "soft_delete_period": "softDeletePeriod",
        "timeouts": "timeouts",
    },
)
class KustoDatabaseConfig(cdktf.TerraformMetaArguments):
    def __init__(
        self,
        *,
        count: typing.Optional[jsii.Number] = None,
        depends_on: typing.Optional[typing.List[cdktf.TerraformResource]] = None,
        lifecycle: typing.Optional[cdktf.TerraformResourceLifecycle] = None,
        provider: typing.Optional[cdktf.TerraformProvider] = None,
        cluster_name: builtins.str,
        location: builtins.str,
        name: builtins.str,
        resource_group_name: builtins.str,
        hot_cache_period: typing.Optional[builtins.str] = None,
        soft_delete_period: typing.Optional[builtins.str] = None,
        timeouts: typing.Optional["KustoDatabaseTimeouts"] = None,
    ) -> None:
        """
        :param count: 
        :param depends_on: 
        :param lifecycle: 
        :param provider: 
        :param cluster_name: 
        :param location: 
        :param name: 
        :param resource_group_name: 
        :param hot_cache_period: 
        :param soft_delete_period: 
        :param timeouts: timeouts block.
        """
        if isinstance(lifecycle, dict):
            lifecycle = cdktf.TerraformResourceLifecycle(**lifecycle)
        if isinstance(timeouts, dict):
            timeouts = KustoDatabaseTimeouts(**timeouts)
        self._values: typing.Dict[str, typing.Any] = {
            "cluster_name": cluster_name,
            "location": location,
            "name": name,
            "resource_group_name": resource_group_name,
        }
        if count is not None:
            self._values["count"] = count
        if depends_on is not None:
            self._values["depends_on"] = depends_on
        if lifecycle is not None:
            self._values["lifecycle"] = lifecycle
        if provider is not None:
            self._values["provider"] = provider
        if hot_cache_period is not None:
            self._values["hot_cache_period"] = hot_cache_period
        if soft_delete_period is not None:
            self._values["soft_delete_period"] = soft_delete_period
        if timeouts is not None:
            self._values["timeouts"] = timeouts

    @builtins.property
    def count(self) -> typing.Optional[jsii.Number]:
        """
        :stability: experimental
        """
        result = self._values.get("count")
        return result

    @builtins.property
    def depends_on(self) -> typing.Optional[typing.List[cdktf.TerraformResource]]:
        """
        :stability: experimental
        """
        result = self._values.get("depends_on")
        return result

    @builtins.property
    def lifecycle(self) -> typing.Optional[cdktf.TerraformResourceLifecycle]:
        """
        :stability: experimental
        """
        result = self._values.get("lifecycle")
        return result

    @builtins.property
    def provider(self) -> typing.Optional[cdktf.TerraformProvider]:
        """
        :stability: experimental
        """
        result = self._values.get("provider")
        return result

    @builtins.property
    def cluster_name(self) -> builtins.str:
        result = self._values.get("cluster_name")
        assert result is not None, "Required property 'cluster_name' is missing"
        return result

    @builtins.property
    def location(self) -> builtins.str:
        result = self._values.get("location")
        assert result is not None, "Required property 'location' is missing"
        return result

    @builtins.property
    def name(self) -> builtins.str:
        result = self._values.get("name")
        assert result is not None, "Required property 'name' is missing"
        return result

    @builtins.property
    def resource_group_name(self) -> builtins.str:
        result = self._values.get("resource_group_name")
        assert result is not None, "Required property 'resource_group_name' is missing"
        return result

    @builtins.property
    def hot_cache_period(self) -> typing.Optional[builtins.str]:
        result = self._values.get("hot_cache_period")
        return result

    @builtins.property
    def soft_delete_period(self) -> typing.Optional[builtins.str]:
        result = self._values.get("soft_delete_period")
        return result

    @builtins.property
    def timeouts(self) -> typing.Optional["KustoDatabaseTimeouts"]:
        """timeouts block."""
        result = self._values.get("timeouts")
        return result

    def __eq__(self, rhs: typing.Any) -> builtins.bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs: typing.Any) -> builtins.bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return "KustoDatabaseConfig(%s)" % ", ".join(
            k + "=" + repr(v) for k, v in self._values.items()
        )


class KustoDatabasePrincipal(
    cdktf.TerraformResource,
    metaclass=jsii.JSIIMeta,
    jsii_type="@cdktf/provider-azurerm.KustoDatabasePrincipal",
):
    def __init__(
        self,
        scope: constructs.Construct,
        id: builtins.str,
        *,
        client_id: builtins.str,
        cluster_name: builtins.str,
        database_name: builtins.str,
        object_id: builtins.str,
        resource_group_name: builtins.str,
        role: builtins.str,
        type: builtins.str,
        timeouts: typing.Optional["KustoDatabasePrincipalTimeouts"] = None,
        count: typing.Optional[jsii.Number] = None,
        depends_on: typing.Optional[typing.List[cdktf.TerraformResource]] = None,
        lifecycle: typing.Optional[cdktf.TerraformResourceLifecycle] = None,
        provider: typing.Optional[cdktf.TerraformProvider] = None,
    ) -> None:
        """
        :param scope: -
        :param id: -
        :param client_id: 
        :param cluster_name: 
        :param database_name: 
        :param object_id: 
        :param resource_group_name: 
        :param role: 
        :param type: 
        :param timeouts: timeouts block.
        :param count: 
        :param depends_on: 
        :param lifecycle: 
        :param provider: 
        """
        config = KustoDatabasePrincipalConfig(
            client_id=client_id,
            cluster_name=cluster_name,
            database_name=database_name,
            object_id=object_id,
            resource_group_name=resource_group_name,
            role=role,
            type=type,
            timeouts=timeouts,
            count=count,
            depends_on=depends_on,
            lifecycle=lifecycle,
            provider=provider,
        )

        jsii.create(KustoDatabasePrincipal, self, [scope, id, config])

    @jsii.member(jsii_name="synthesizeAttributes")
    def _synthesize_attributes(self) -> typing.Mapping[builtins.str, typing.Any]:
        return jsii.invoke(self, "synthesizeAttributes", [])

    @builtins.property # type: ignore
    @jsii.member(jsii_name="appId")
    def app_id(self) -> builtins.str:
        return jsii.get(self, "appId")

    @builtins.property # type: ignore
    @jsii.member(jsii_name="email")
    def email(self) -> builtins.str:
        return jsii.get(self, "email")

    @builtins.property # type: ignore
    @jsii.member(jsii_name="fullyQualifiedName")
    def fully_qualified_name(self) -> builtins.str:
        return jsii.get(self, "fullyQualifiedName")

    @builtins.property # type: ignore
    @jsii.member(jsii_name="name")
    def name(self) -> builtins.str:
        return jsii.get(self, "name")

    @builtins.property # type: ignore
    @jsii.member(jsii_name="clientId")
    def client_id(self) -> builtins.str:
        return jsii.get(self, "clientId")

    @client_id.setter # type: ignore
    def client_id(self, value: builtins.str) -> None:
        jsii.set(self, "clientId", value)

    @builtins.property # type: ignore
    @jsii.member(jsii_name="clusterName")
    def cluster_name(self) -> builtins.str:
        return jsii.get(self, "clusterName")

    @cluster_name.setter # type: ignore
    def cluster_name(self, value: builtins.str) -> None:
        jsii.set(self, "clusterName", value)

    @builtins.property # type: ignore
    @jsii.member(jsii_name="databaseName")
    def database_name(self) -> builtins.str:
        return jsii.get(self, "databaseName")

    @database_name.setter # type: ignore
    def database_name(self, value: builtins.str) -> None:
        jsii.set(self, "databaseName", value)

    @builtins.property # type: ignore
    @jsii.member(jsii_name="objectId")
    def object_id(self) -> builtins.str:
        return jsii.get(self, "objectId")

    @object_id.setter # type: ignore
    def object_id(self, value: builtins.str) -> None:
        jsii.set(self, "objectId", value)

    @builtins.property # type: ignore
    @jsii.member(jsii_name="resourceGroupName")
    def resource_group_name(self) -> builtins.str:
        return jsii.get(self, "resourceGroupName")

    @resource_group_name.setter # type: ignore
    def resource_group_name(self, value: builtins.str) -> None:
        jsii.set(self, "resourceGroupName", value)

    @builtins.property # type: ignore
    @jsii.member(jsii_name="role")
    def role(self) -> builtins.str:
        return jsii.get(self, "role")

    @role.setter # type: ignore
    def role(self, value: builtins.str) -> None:
        jsii.set(self, "role", value)

    @builtins.property # type: ignore
    @jsii.member(jsii_name="type")
    def type(self) -> builtins.str:
        return jsii.get(self, "type")

    @type.setter # type: ignore
    def type(self, value: builtins.str) -> None:
        jsii.set(self, "type", value)

    @builtins.property # type: ignore
    @jsii.member(jsii_name="id")
    def id(self) -> typing.Optional[builtins.str]:
        return jsii.get(self, "id")

    @id.setter # type: ignore
    def id(self, value: typing.Optional[builtins.str]) -> None:
        jsii.set(self, "id", value)

    @builtins.property # type: ignore
    @jsii.member(jsii_name="timeouts")
    def timeouts(self) -> typing.Optional["KustoDatabasePrincipalTimeouts"]:
        return jsii.get(self, "timeouts")

    @timeouts.setter # type: ignore
    def timeouts(
        self,
        value: typing.Optional["KustoDatabasePrincipalTimeouts"],
    ) -> None:
        jsii.set(self, "timeouts", value)


@jsii.data_type(
    jsii_type="@cdktf/provider-azurerm.KustoDatabasePrincipalConfig",
    jsii_struct_bases=[cdktf.TerraformMetaArguments],
    name_mapping={
        "count": "count",
        "depends_on": "dependsOn",
        "lifecycle": "lifecycle",
        "provider": "provider",
        "client_id": "clientId",
        "cluster_name": "clusterName",
        "database_name": "databaseName",
        "object_id": "objectId",
        "resource_group_name": "resourceGroupName",
        "role": "role",
        "type": "type",
        "timeouts": "timeouts",
    },
)
class KustoDatabasePrincipalConfig(cdktf.TerraformMetaArguments):
    def __init__(
        self,
        *,
        count: typing.Optional[jsii.Number] = None,
        depends_on: typing.Optional[typing.List[cdktf.TerraformResource]] = None,
        lifecycle: typing.Optional[cdktf.TerraformResourceLifecycle] = None,
        provider: typing.Optional[cdktf.TerraformProvider] = None,
        client_id: builtins.str,
        cluster_name: builtins.str,
        database_name: builtins.str,
        object_id: builtins.str,
        resource_group_name: builtins.str,
        role: builtins.str,
        type: builtins.str,
        timeouts: typing.Optional["KustoDatabasePrincipalTimeouts"] = None,
    ) -> None:
        """
        :param count: 
        :param depends_on: 
        :param lifecycle: 
        :param provider: 
        :param client_id: 
        :param cluster_name: 
        :param database_name: 
        :param object_id: 
        :param resource_group_name: 
        :param role: 
        :param type: 
        :param timeouts: timeouts block.
        """
        if isinstance(lifecycle, dict):
            lifecycle = cdktf.TerraformResourceLifecycle(**lifecycle)
        if isinstance(timeouts, dict):
            timeouts = KustoDatabasePrincipalTimeouts(**timeouts)
        self._values: typing.Dict[str, typing.Any] = {
            "client_id": client_id,
            "cluster_name": cluster_name,
            "database_name": database_name,
            "object_id": object_id,
            "resource_group_name": resource_group_name,
            "role": role,
            "type": type,
        }
        if count is not None:
            self._values["count"] = count
        if depends_on is not None:
            self._values["depends_on"] = depends_on
        if lifecycle is not None:
            self._values["lifecycle"] = lifecycle
        if provider is not None:
            self._values["provider"] = provider
        if timeouts is not None:
            self._values["timeouts"] = timeouts

    @builtins.property
    def count(self) -> typing.Optional[jsii.Number]:
        """
        :stability: experimental
        """
        result = self._values.get("count")
        return result

    @builtins.property
    def depends_on(self) -> typing.Optional[typing.List[cdktf.TerraformResource]]:
        """
        :stability: experimental
        """
        result = self._values.get("depends_on")
        return result

    @builtins.property
    def lifecycle(self) -> typing.Optional[cdktf.TerraformResourceLifecycle]:
        """
        :stability: experimental
        """
        result = self._values.get("lifecycle")
        return result

    @builtins.property
    def provider(self) -> typing.Optional[cdktf.TerraformProvider]:
        """
        :stability: experimental
        """
        result = self._values.get("provider")
        return result

    @builtins.property
    def client_id(self) -> builtins.str:
        result = self._values.get("client_id")
        assert result is not None, "Required property 'client_id' is missing"
        return result

    @builtins.property
    def cluster_name(self) -> builtins.str:
        result = self._values.get("cluster_name")
        assert result is not None, "Required property 'cluster_name' is missing"
        return result

    @builtins.property
    def database_name(self) -> builtins.str:
        result = self._values.get("database_name")
        assert result is not None, "Required property 'database_name' is missing"
        return result

    @builtins.property
    def object_id(self) -> builtins.str:
        result = self._values.get("object_id")
        assert result is not None, "Required property 'object_id' is missing"
        return result

    @builtins.property
    def resource_group_name(self) -> builtins.str:
        result = self._values.get("resource_group_name")
        assert result is not None, "Required property 'resource_group_name' is missing"
        return result

    @builtins.property
    def role(self) -> builtins.str:
        result = self._values.get("role")
        assert result is not None, "Required property 'role' is missing"
        return result

    @builtins.property
    def type(self) -> builtins.str:
        result = self._values.get("type")
        assert result is not None, "Required property 'type' is missing"
        return result

    @builtins.property
    def timeouts(self) -> typing.Optional["KustoDatabasePrincipalTimeouts"]:
        """timeouts block."""
        result = self._values.get("timeouts")
        return result

    def __eq__(self, rhs: typing.Any) -> builtins.bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs: typing.Any) -> builtins.bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return "KustoDatabasePrincipalConfig(%s)" % ", ".join(
            k + "=" + repr(v) for k, v in self._values.items()
        )


@jsii.data_type(
    jsii_type="@cdktf/provider-azurerm.KustoDatabasePrincipalTimeouts",
    jsii_struct_bases=[],
    name_mapping={
        "create": "create",
        "delete": "delete",
        "read": "read",
        "update": "update",
    },
)
class KustoDatabasePrincipalTimeouts:
    def __init__(
        self,
        *,
        create: typing.Optional[builtins.str] = None,
        delete: typing.Optional[builtins.str] = None,
        read: typing.Optional[builtins.str] = None,
        update: typing.Optional[builtins.str] = None,
    ) -> None:
        """
        :param create: 
        :param delete: 
        :param read: 
        :param update: 
        """
        self._values: typing.Dict[str, typing.Any] = {}
        if create is not None:
            self._values["create"] = create
        if delete is not None:
            self._values["delete"] = delete
        if read is not None:
            self._values["read"] = read
        if update is not None:
            self._values["update"] = update

    @builtins.property
    def create(self) -> typing.Optional[builtins.str]:
        result = self._values.get("create")
        return result

    @builtins.property
    def delete(self) -> typing.Optional[builtins.str]:
        result = self._values.get("delete")
        return result

    @builtins.property
    def read(self) -> typing.Optional[builtins.str]:
        result = self._values.get("read")
        return result

    @builtins.property
    def update(self) -> typing.Optional[builtins.str]:
        result = self._values.get("update")
        return result

    def __eq__(self, rhs: typing.Any) -> builtins.bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs: typing.Any) -> builtins.bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return "KustoDatabasePrincipalTimeouts(%s)" % ", ".join(
            k + "=" + repr(v) for k, v in self._values.items()
        )


@jsii.data_type(
    jsii_type="@cdktf/provider-azurerm.KustoDatabaseTimeouts",
    jsii_struct_bases=[],
    name_mapping={
        "create": "create",
        "delete": "delete",
        "read": "read",
        "update": "update",
    },
)
class KustoDatabaseTimeouts:
    def __init__(
        self,
        *,
        create: typing.Optional[builtins.str] = None,
        delete: typing.Optional[builtins.str] = None,
        read: typing.Optional[builtins.str] = None,
        update: typing.Optional[builtins.str] = None,
    ) -> None:
        """
        :param create: 
        :param delete: 
        :param read: 
        :param update: 
        """
        self._values: typing.Dict[str, typing.Any] = {}
        if create is not None:
            self._values["create"] = create
        if delete is not None:
            self._values["delete"] = delete
        if read is not None:
            self._values["read"] = read
        if update is not None:
            self._values["update"] = update

    @builtins.property
    def create(self) -> typing.Optional[builtins.str]:
        result = self._values.get("create")
        return result

    @builtins.property
    def delete(self) -> typing.Optional[builtins.str]:
        result = self._values.get("delete")
        return result

    @builtins.property
    def read(self) -> typing.Optional[builtins.str]:
        result = self._values.get("read")
        return result

    @builtins.property
    def update(self) -> typing.Optional[builtins.str]:
        result = self._values.get("update")
        return result

    def __eq__(self, rhs: typing.Any) -> builtins.bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs: typing.Any) -> builtins.bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return "KustoDatabaseTimeouts(%s)" % ", ".join(
            k + "=" + repr(v) for k, v in self._values.items()
        )


class KustoEventhubDataConnection(
    cdktf.TerraformResource,
    metaclass=jsii.JSIIMeta,
    jsii_type="@cdktf/provider-azurerm.KustoEventhubDataConnection",
):
    def __init__(
        self,
        scope: constructs.Construct,
        id: builtins.str,
        *,
        cluster_name: builtins.str,
        consumer_group: builtins.str,
        database_name: builtins.str,
        eventhub_id: builtins.str,
        location: builtins.str,
        name: builtins.str,
        resource_group_name: builtins.str,
        data_format: typing.Optional[builtins.str] = None,
        mapping_rule_name: typing.Optional[builtins.str] = None,
        table_name: typing.Optional[builtins.str] = None,
        timeouts: typing.Optional["KustoEventhubDataConnectionTimeouts"] = None,
        count: typing.Optional[jsii.Number] = None,
        depends_on: typing.Optional[typing.List[cdktf.TerraformResource]] = None,
        lifecycle: typing.Optional[cdktf.TerraformResourceLifecycle] = None,
        provider: typing.Optional[cdktf.TerraformProvider] = None,
    ) -> None:
        """
        :param scope: -
        :param id: -
        :param cluster_name: 
        :param consumer_group: 
        :param database_name: 
        :param eventhub_id: 
        :param location: 
        :param name: 
        :param resource_group_name: 
        :param data_format: 
        :param mapping_rule_name: 
        :param table_name: 
        :param timeouts: timeouts block.
        :param count: 
        :param depends_on: 
        :param lifecycle: 
        :param provider: 
        """
        config = KustoEventhubDataConnectionConfig(
            cluster_name=cluster_name,
            consumer_group=consumer_group,
            database_name=database_name,
            eventhub_id=eventhub_id,
            location=location,
            name=name,
            resource_group_name=resource_group_name,
            data_format=data_format,
            mapping_rule_name=mapping_rule_name,
            table_name=table_name,
            timeouts=timeouts,
            count=count,
            depends_on=depends_on,
            lifecycle=lifecycle,
            provider=provider,
        )

        jsii.create(KustoEventhubDataConnection, self, [scope, id, config])

    @jsii.member(jsii_name="synthesizeAttributes")
    def _synthesize_attributes(self) -> typing.Mapping[builtins.str, typing.Any]:
        return jsii.invoke(self, "synthesizeAttributes", [])

    @builtins.property # type: ignore
    @jsii.member(jsii_name="clusterName")
    def cluster_name(self) -> builtins.str:
        return jsii.get(self, "clusterName")

    @cluster_name.setter # type: ignore
    def cluster_name(self, value: builtins.str) -> None:
        jsii.set(self, "clusterName", value)

    @builtins.property # type: ignore
    @jsii.member(jsii_name="consumerGroup")
    def consumer_group(self) -> builtins.str:
        return jsii.get(self, "consumerGroup")

    @consumer_group.setter # type: ignore
    def consumer_group(self, value: builtins.str) -> None:
        jsii.set(self, "consumerGroup", value)

    @builtins.property # type: ignore
    @jsii.member(jsii_name="databaseName")
    def database_name(self) -> builtins.str:
        return jsii.get(self, "databaseName")

    @database_name.setter # type: ignore
    def database_name(self, value: builtins.str) -> None:
        jsii.set(self, "databaseName", value)

    @builtins.property # type: ignore
    @jsii.member(jsii_name="eventhubId")
    def eventhub_id(self) -> builtins.str:
        return jsii.get(self, "eventhubId")

    @eventhub_id.setter # type: ignore
    def eventhub_id(self, value: builtins.str) -> None:
        jsii.set(self, "eventhubId", value)

    @builtins.property # type: ignore
    @jsii.member(jsii_name="location")
    def location(self) -> builtins.str:
        return jsii.get(self, "location")

    @location.setter # type: ignore
    def location(self, value: builtins.str) -> None:
        jsii.set(self, "location", value)

    @builtins.property # type: ignore
    @jsii.member(jsii_name="name")
    def name(self) -> builtins.str:
        return jsii.get(self, "name")

    @name.setter # type: ignore
    def name(self, value: builtins.str) -> None:
        jsii.set(self, "name", value)

    @builtins.property # type: ignore
    @jsii.member(jsii_name="resourceGroupName")
    def resource_group_name(self) -> builtins.str:
        return jsii.get(self, "resourceGroupName")

    @resource_group_name.setter # type: ignore
    def resource_group_name(self, value: builtins.str) -> None:
        jsii.set(self, "resourceGroupName", value)

    @builtins.property # type: ignore
    @jsii.member(jsii_name="dataFormat")
    def data_format(self) -> typing.Optional[builtins.str]:
        return jsii.get(self, "dataFormat")

    @data_format.setter # type: ignore
    def data_format(self, value: typing.Optional[builtins.str]) -> None:
        jsii.set(self, "dataFormat", value)

    @builtins.property # type: ignore
    @jsii.member(jsii_name="id")
    def id(self) -> typing.Optional[builtins.str]:
        return jsii.get(self, "id")

    @id.setter # type: ignore
    def id(self, value: typing.Optional[builtins.str]) -> None:
        jsii.set(self, "id", value)

    @builtins.property # type: ignore
    @jsii.member(jsii_name="mappingRuleName")
    def mapping_rule_name(self) -> typing.Optional[builtins.str]:
        return jsii.get(self, "mappingRuleName")

    @mapping_rule_name.setter # type: ignore
    def mapping_rule_name(self, value: typing.Optional[builtins.str]) -> None:
        jsii.set(self, "mappingRuleName", value)

    @builtins.property # type: ignore
    @jsii.member(jsii_name="tableName")
    def table_name(self) -> typing.Optional[builtins.str]:
        return jsii.get(self, "tableName")

    @table_name.setter # type: ignore
    def table_name(self, value: typing.Optional[builtins.str]) -> None:
        jsii.set(self, "tableName", value)

    @builtins.property # type: ignore
    @jsii.member(jsii_name="timeouts")
    def timeouts(self) -> typing.Optional["KustoEventhubDataConnectionTimeouts"]:
        return jsii.get(self, "timeouts")

    @timeouts.setter # type: ignore
    def timeouts(
        self,
        value: typing.Optional["KustoEventhubDataConnectionTimeouts"],
    ) -> None:
        jsii.set(self, "timeouts", value)


@jsii.data_type(
    jsii_type="@cdktf/provider-azurerm.KustoEventhubDataConnectionConfig",
    jsii_struct_bases=[cdktf.TerraformMetaArguments],
    name_mapping={
        "count": "count",
        "depends_on": "dependsOn",
        "lifecycle": "lifecycle",
        "provider": "provider",
        "cluster_name": "clusterName",
        "consumer_group": "consumerGroup",
        "database_name": "databaseName",
        "eventhub_id": "eventhubId",
        "location": "location",
        "name": "name",
        "resource_group_name": "resourceGroupName",
        "data_format": "dataFormat",
        "mapping_rule_name": "mappingRuleName",
        "table_name": "tableName",
        "timeouts": "timeouts",
    },
)
class KustoEventhubDataConnectionConfig(cdktf.TerraformMetaArguments):
    def __init__(
        self,
        *,
        count: typing.Optional[jsii.Number] = None,
        depends_on: typing.Optional[typing.List[cdktf.TerraformResource]] = None,
        lifecycle: typing.Optional[cdktf.TerraformResourceLifecycle] = None,
        provider: typing.Optional[cdktf.TerraformProvider] = None,
        cluster_name: builtins.str,
        consumer_group: builtins.str,
        database_name: builtins.str,
        eventhub_id: builtins.str,
        location: builtins.str,
        name: builtins.str,
        resource_group_name: builtins.str,
        data_format: typing.Optional[builtins.str] = None,
        mapping_rule_name: typing.Optional[builtins.str] = None,
        table_name: typing.Optional[builtins.str] = None,
        timeouts: typing.Optional["KustoEventhubDataConnectionTimeouts"] = None,
    ) -> None:
        """
        :param count: 
        :param depends_on: 
        :param lifecycle: 
        :param provider: 
        :param cluster_name: 
        :param consumer_group: 
        :param database_name: 
        :param eventhub_id: 
        :param location: 
        :param name: 
        :param resource_group_name: 
        :param data_format: 
        :param mapping_rule_name: 
        :param table_name: 
        :param timeouts: timeouts block.
        """
        if isinstance(lifecycle, dict):
            lifecycle = cdktf.TerraformResourceLifecycle(**lifecycle)
        if isinstance(timeouts, dict):
            timeouts = KustoEventhubDataConnectionTimeouts(**timeouts)
        self._values: typing.Dict[str, typing.Any] = {
            "cluster_name": cluster_name,
            "consumer_group": consumer_group,
            "database_name": database_name,
            "eventhub_id": eventhub_id,
            "location": location,
            "name": name,
            "resource_group_name": resource_group_name,
        }
        if count is not None:
            self._values["count"] = count
        if depends_on is not None:
            self._values["depends_on"] = depends_on
        if lifecycle is not None:
            self._values["lifecycle"] = lifecycle
        if provider is not None:
            self._values["provider"] = provider
        if data_format is not None:
            self._values["data_format"] = data_format
        if mapping_rule_name is not None:
            self._values["mapping_rule_name"] = mapping_rule_name
        if table_name is not None:
            self._values["table_name"] = table_name
        if timeouts is not None:
            self._values["timeouts"] = timeouts

    @builtins.property
    def count(self) -> typing.Optional[jsii.Number]:
        """
        :stability: experimental
        """
        result = self._values.get("count")
        return result

    @builtins.property
    def depends_on(self) -> typing.Optional[typing.List[cdktf.TerraformResource]]:
        """
        :stability: experimental
        """
        result = self._values.get("depends_on")
        return result

    @builtins.property
    def lifecycle(self) -> typing.Optional[cdktf.TerraformResourceLifecycle]:
        """
        :stability: experimental
        """
        result = self._values.get("lifecycle")
        return result

    @builtins.property
    def provider(self) -> typing.Optional[cdktf.TerraformProvider]:
        """
        :stability: experimental
        """
        result = self._values.get("provider")
        return result

    @builtins.property
    def cluster_name(self) -> builtins.str:
        result = self._values.get("cluster_name")
        assert result is not None, "Required property 'cluster_name' is missing"
        return result

    @builtins.property
    def consumer_group(self) -> builtins.str:
        result = self._values.get("consumer_group")
        assert result is not None, "Required property 'consumer_group' is missing"
        return result

    @builtins.property
    def database_name(self) -> builtins.str:
        result = self._values.get("database_name")
        assert result is not None, "Required property 'database_name' is missing"
        return result

    @builtins.property
    def eventhub_id(self) -> builtins.str:
        result = self._values.get("eventhub_id")
        assert result is not None, "Required property 'eventhub_id' is missing"
        return result

    @builtins.property
    def location(self) -> builtins.str:
        result = self._values.get("location")
        assert result is not None, "Required property 'location' is missing"
        return result

    @builtins.property
    def name(self) -> builtins.str:
        result = self._values.get("name")
        assert result is not None, "Required property 'name' is missing"
        return result

    @builtins.property
    def resource_group_name(self) -> builtins.str:
        result = self._values.get("resource_group_name")
        assert result is not None, "Required property 'resource_group_name' is missing"
        return result

    @builtins.property
    def data_format(self) -> typing.Optional[builtins.str]:
        result = self._values.get("data_format")
        return result

    @builtins.property
    def mapping_rule_name(self) -> typing.Optional[builtins.str]:
        result = self._values.get("mapping_rule_name")
        return result

    @builtins.property
    def table_name(self) -> typing.Optional[builtins.str]:
        result = self._values.get("table_name")
        return result

    @builtins.property
    def timeouts(self) -> typing.Optional["KustoEventhubDataConnectionTimeouts"]:
        """timeouts block."""
        result = self._values.get("timeouts")
        return result

    def __eq__(self, rhs: typing.Any) -> builtins.bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs: typing.Any) -> builtins.bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return "KustoEventhubDataConnectionConfig(%s)" % ", ".join(
            k + "=" + repr(v) for k, v in self._values.items()
        )


@jsii.data_type(
    jsii_type="@cdktf/provider-azurerm.KustoEventhubDataConnectionTimeouts",
    jsii_struct_bases=[],
    name_mapping={
        "create": "create",
        "delete": "delete",
        "read": "read",
        "update": "update",
    },
)
class KustoEventhubDataConnectionTimeouts:
    def __init__(
        self,
        *,
        create: typing.Optional[builtins.str] = None,
        delete: typing.Optional[builtins.str] = None,
        read: typing.Optional[builtins.str] = None,
        update: typing.Optional[builtins.str] = None,
    ) -> None:
        """
        :param create: 
        :param delete: 
        :param read: 
        :param update: 
        """
        self._values: typing.Dict[str, typing.Any] = {}
        if create is not None:
            self._values["create"] = create
        if delete is not None:
            self._values["delete"] = delete
        if read is not None:
            self._values["read"] = read
        if update is not None:
            self._values["update"] = update

    @builtins.property
    def create(self) -> typing.Optional[builtins.str]:
        result = self._values.get("create")
        return result

    @builtins.property
    def delete(self) -> typing.Optional[builtins.str]:
        result = self._values.get("delete")
        return result

    @builtins.property
    def read(self) -> typing.Optional[builtins.str]:
        result = self._values.get("read")
        return result

    @builtins.property
    def update(self) -> typing.Optional[builtins.str]:
        result = self._values.get("update")
        return result

    def __eq__(self, rhs: typing.Any) -> builtins.bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs: typing.Any) -> builtins.bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return "KustoEventhubDataConnectionTimeouts(%s)" % ", ".join(
            k + "=" + repr(v) for k, v in self._values.items()
        )


class Lb(
    cdktf.TerraformResource,
    metaclass=jsii.JSIIMeta,
    jsii_type="@cdktf/provider-azurerm.Lb",
):
    def __init__(
        self,
        scope: constructs.Construct,
        id: builtins.str,
        *,
        location: builtins.str,
        name: builtins.str,
        resource_group_name: builtins.str,
        frontend_ip_configuration: typing.Optional[typing.List["LbFrontendIpConfiguration"]] = None,
        sku: typing.Optional[builtins.str] = None,
        tags: typing.Optional[typing.Mapping[builtins.str, builtins.str]] = None,
        timeouts: typing.Optional["LbTimeouts"] = None,
        count: typing.Optional[jsii.Number] = None,
        depends_on: typing.Optional[typing.List[cdktf.TerraformResource]] = None,
        lifecycle: typing.Optional[cdktf.TerraformResourceLifecycle] = None,
        provider: typing.Optional[cdktf.TerraformProvider] = None,
    ) -> None:
        """
        :param scope: -
        :param id: -
        :param location: 
        :param name: 
        :param resource_group_name: 
        :param frontend_ip_configuration: frontend_ip_configuration block.
        :param sku: 
        :param tags: 
        :param timeouts: timeouts block.
        :param count: 
        :param depends_on: 
        :param lifecycle: 
        :param provider: 
        """
        config = LbConfig(
            location=location,
            name=name,
            resource_group_name=resource_group_name,
            frontend_ip_configuration=frontend_ip_configuration,
            sku=sku,
            tags=tags,
            timeouts=timeouts,
            count=count,
            depends_on=depends_on,
            lifecycle=lifecycle,
            provider=provider,
        )

        jsii.create(Lb, self, [scope, id, config])

    @jsii.member(jsii_name="synthesizeAttributes")
    def _synthesize_attributes(self) -> typing.Mapping[builtins.str, typing.Any]:
        return jsii.invoke(self, "synthesizeAttributes", [])

    @builtins.property # type: ignore
    @jsii.member(jsii_name="privateIpAddress")
    def private_ip_address(self) -> builtins.str:
        return jsii.get(self, "privateIpAddress")

    @builtins.property # type: ignore
    @jsii.member(jsii_name="privateIpAddresses")
    def private_ip_addresses(self) -> typing.List[builtins.str]:
        return jsii.get(self, "privateIpAddresses")

    @builtins.property # type: ignore
    @jsii.member(jsii_name="location")
    def location(self) -> builtins.str:
        return jsii.get(self, "location")

    @location.setter # type: ignore
    def location(self, value: builtins.str) -> None:
        jsii.set(self, "location", value)

    @builtins.property # type: ignore
    @jsii.member(jsii_name="name")
    def name(self) -> builtins.str:
        return jsii.get(self, "name")

    @name.setter # type: ignore
    def name(self, value: builtins.str) -> None:
        jsii.set(self, "name", value)

    @builtins.property # type: ignore
    @jsii.member(jsii_name="resourceGroupName")
    def resource_group_name(self) -> builtins.str:
        return jsii.get(self, "resourceGroupName")

    @resource_group_name.setter # type: ignore
    def resource_group_name(self, value: builtins.str) -> None:
        jsii.set(self, "resourceGroupName", value)

    @builtins.property # type: ignore
    @jsii.member(jsii_name="frontendIpConfiguration")
    def frontend_ip_configuration(
        self,
    ) -> typing.Optional[typing.List["LbFrontendIpConfiguration"]]:
        return jsii.get(self, "frontendIpConfiguration")

    @frontend_ip_configuration.setter # type: ignore
    def frontend_ip_configuration(
        self,
        value: typing.Optional[typing.List["LbFrontendIpConfiguration"]],
    ) -> None:
        jsii.set(self, "frontendIpConfiguration", value)

    @builtins.property # type: ignore
    @jsii.member(jsii_name="id")
    def id(self) -> typing.Optional[builtins.str]:
        return jsii.get(self, "id")

    @id.setter # type: ignore
    def id(self, value: typing.Optional[builtins.str]) -> None:
        jsii.set(self, "id", value)

    @builtins.property # type: ignore
    @jsii.member(jsii_name="sku")
    def sku(self) -> typing.Optional[builtins.str]:
        return jsii.get(self, "sku")

    @sku.setter # type: ignore
    def sku(self, value: typing.Optional[builtins.str]) -> None:
        jsii.set(self, "sku", value)

    @builtins.property # type: ignore
    @jsii.member(jsii_name="tags")
    def tags(self) -> typing.Optional[typing.Mapping[builtins.str, builtins.str]]:
        return jsii.get(self, "tags")

    @tags.setter # type: ignore
    def tags(
        self,
        value: typing.Optional[typing.Mapping[builtins.str, builtins.str]],
    ) -> None:
        jsii.set(self, "tags", value)

    @builtins.property # type: ignore
    @jsii.member(jsii_name="timeouts")
    def timeouts(self) -> typing.Optional["LbTimeouts"]:
        return jsii.get(self, "timeouts")

    @timeouts.setter # type: ignore
    def timeouts(self, value: typing.Optional["LbTimeouts"]) -> None:
        jsii.set(self, "timeouts", value)


class LbBackendAddressPool(
    cdktf.TerraformResource,
    metaclass=jsii.JSIIMeta,
    jsii_type="@cdktf/provider-azurerm.LbBackendAddressPool",
):
    def __init__(
        self,
        scope: constructs.Construct,
        id: builtins.str,
        *,
        loadbalancer_id: builtins.str,
        name: builtins.str,
        resource_group_name: builtins.str,
        timeouts: typing.Optional["LbBackendAddressPoolTimeouts"] = None,
        count: typing.Optional[jsii.Number] = None,
        depends_on: typing.Optional[typing.List[cdktf.TerraformResource]] = None,
        lifecycle: typing.Optional[cdktf.TerraformResourceLifecycle] = None,
        provider: typing.Optional[cdktf.TerraformProvider] = None,
    ) -> None:
        """
        :param scope: -
        :param id: -
        :param loadbalancer_id: 
        :param name: 
        :param resource_group_name: 
        :param timeouts: timeouts block.
        :param count: 
        :param depends_on: 
        :param lifecycle: 
        :param provider: 
        """
        config = LbBackendAddressPoolConfig(
            loadbalancer_id=loadbalancer_id,
            name=name,
            resource_group_name=resource_group_name,
            timeouts=timeouts,
            count=count,
            depends_on=depends_on,
            lifecycle=lifecycle,
            provider=provider,
        )

        jsii.create(LbBackendAddressPool, self, [scope, id, config])

    @jsii.member(jsii_name="synthesizeAttributes")
    def _synthesize_attributes(self) -> typing.Mapping[builtins.str, typing.Any]:
        return jsii.invoke(self, "synthesizeAttributes", [])

    @builtins.property # type: ignore
    @jsii.member(jsii_name="backendIpConfigurations")
    def backend_ip_configurations(self) -> typing.List[builtins.str]:
        return jsii.get(self, "backendIpConfigurations")

    @builtins.property # type: ignore
    @jsii.member(jsii_name="loadBalancingRules")
    def load_balancing_rules(self) -> typing.List[builtins.str]:
        return jsii.get(self, "loadBalancingRules")

    @builtins.property # type: ignore
    @jsii.member(jsii_name="loadbalancerId")
    def loadbalancer_id(self) -> builtins.str:
        return jsii.get(self, "loadbalancerId")

    @loadbalancer_id.setter # type: ignore
    def loadbalancer_id(self, value: builtins.str) -> None:
        jsii.set(self, "loadbalancerId", value)

    @builtins.property # type: ignore
    @jsii.member(jsii_name="name")
    def name(self) -> builtins.str:
        return jsii.get(self, "name")

    @name.setter # type: ignore
    def name(self, value: builtins.str) -> None:
        jsii.set(self, "name", value)

    @builtins.property # type: ignore
    @jsii.member(jsii_name="resourceGroupName")
    def resource_group_name(self) -> builtins.str:
        return jsii.get(self, "resourceGroupName")

    @resource_group_name.setter # type: ignore
    def resource_group_name(self, value: builtins.str) -> None:
        jsii.set(self, "resourceGroupName", value)

    @builtins.property # type: ignore
    @jsii.member(jsii_name="id")
    def id(self) -> typing.Optional[builtins.str]:
        return jsii.get(self, "id")

    @id.setter # type: ignore
    def id(self, value: typing.Optional[builtins.str]) -> None:
        jsii.set(self, "id", value)

    @builtins.property # type: ignore
    @jsii.member(jsii_name="timeouts")
    def timeouts(self) -> typing.Optional["LbBackendAddressPoolTimeouts"]:
        return jsii.get(self, "timeouts")

    @timeouts.setter # type: ignore
    def timeouts(self, value: typing.Optional["LbBackendAddressPoolTimeouts"]) -> None:
        jsii.set(self, "timeouts", value)


@jsii.data_type(
    jsii_type="@cdktf/provider-azurerm.LbBackendAddressPoolConfig",
    jsii_struct_bases=[cdktf.TerraformMetaArguments],
    name_mapping={
        "count": "count",
        "depends_on": "dependsOn",
        "lifecycle": "lifecycle",
        "provider": "provider",
        "loadbalancer_id": "loadbalancerId",
        "name": "name",
        "resource_group_name": "resourceGroupName",
        "timeouts": "timeouts",
    },
)
class LbBackendAddressPoolConfig(cdktf.TerraformMetaArguments):
    def __init__(
        self,
        *,
        count: typing.Optional[jsii.Number] = None,
        depends_on: typing.Optional[typing.List[cdktf.TerraformResource]] = None,
        lifecycle: typing.Optional[cdktf.TerraformResourceLifecycle] = None,
        provider: typing.Optional[cdktf.TerraformProvider] = None,
        loadbalancer_id: builtins.str,
        name: builtins.str,
        resource_group_name: builtins.str,
        timeouts: typing.Optional["LbBackendAddressPoolTimeouts"] = None,
    ) -> None:
        """
        :param count: 
        :param depends_on: 
        :param lifecycle: 
        :param provider: 
        :param loadbalancer_id: 
        :param name: 
        :param resource_group_name: 
        :param timeouts: timeouts block.
        """
        if isinstance(lifecycle, dict):
            lifecycle = cdktf.TerraformResourceLifecycle(**lifecycle)
        if isinstance(timeouts, dict):
            timeouts = LbBackendAddressPoolTimeouts(**timeouts)
        self._values: typing.Dict[str, typing.Any] = {
            "loadbalancer_id": loadbalancer_id,
            "name": name,
            "resource_group_name": resource_group_name,
        }
        if count is not None:
            self._values["count"] = count
        if depends_on is not None:
            self._values["depends_on"] = depends_on
        if lifecycle is not None:
            self._values["lifecycle"] = lifecycle
        if provider is not None:
            self._values["provider"] = provider
        if timeouts is not None:
            self._values["timeouts"] = timeouts

    @builtins.property
    def count(self) -> typing.Optional[jsii.Number]:
        """
        :stability: experimental
        """
        result = self._values.get("count")
        return result

    @builtins.property
    def depends_on(self) -> typing.Optional[typing.List[cdktf.TerraformResource]]:
        """
        :stability: experimental
        """
        result = self._values.get("depends_on")
        return result

    @builtins.property
    def lifecycle(self) -> typing.Optional[cdktf.TerraformResourceLifecycle]:
        """
        :stability: experimental
        """
        result = self._values.get("lifecycle")
        return result

    @builtins.property
    def provider(self) -> typing.Optional[cdktf.TerraformProvider]:
        """
        :stability: experimental
        """
        result = self._values.get("provider")
        return result

    @builtins.property
    def loadbalancer_id(self) -> builtins.str:
        result = self._values.get("loadbalancer_id")
        assert result is not None, "Required property 'loadbalancer_id' is missing"
        return result

    @builtins.property
    def name(self) -> builtins.str:
        result = self._values.get("name")
        assert result is not None, "Required property 'name' is missing"
        return result

    @builtins.property
    def resource_group_name(self) -> builtins.str:
        result = self._values.get("resource_group_name")
        assert result is not None, "Required property 'resource_group_name' is missing"
        return result

    @builtins.property
    def timeouts(self) -> typing.Optional["LbBackendAddressPoolTimeouts"]:
        """timeouts block."""
        result = self._values.get("timeouts")
        return result

    def __eq__(self, rhs: typing.Any) -> builtins.bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs: typing.Any) -> builtins.bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return "LbBackendAddressPoolConfig(%s)" % ", ".join(
            k + "=" + repr(v) for k, v in self._values.items()
        )


@jsii.data_type(
    jsii_type="@cdktf/provider-azurerm.LbBackendAddressPoolTimeouts",
    jsii_struct_bases=[],
    name_mapping={
        "create": "create",
        "delete": "delete",
        "read": "read",
        "update": "update",
    },
)
class LbBackendAddressPoolTimeouts:
    def __init__(
        self,
        *,
        create: typing.Optional[builtins.str] = None,
        delete: typing.Optional[builtins.str] = None,
        read: typing.Optional[builtins.str] = None,
        update: typing.Optional[builtins.str] = None,
    ) -> None:
        """
        :param create: 
        :param delete: 
        :param read: 
        :param update: 
        """
        self._values: typing.Dict[str, typing.Any] = {}
        if create is not None:
            self._values["create"] = create
        if delete is not None:
            self._values["delete"] = delete
        if read is not None:
            self._values["read"] = read
        if update is not None:
            self._values["update"] = update

    @builtins.property
    def create(self) -> typing.Optional[builtins.str]:
        result = self._values.get("create")
        return result

    @builtins.property
    def delete(self) -> typing.Optional[builtins.str]:
        result = self._values.get("delete")
        return result

    @builtins.property
    def read(self) -> typing.Optional[builtins.str]:
        result = self._values.get("read")
        return result

    @builtins.property
    def update(self) -> typing.Optional[builtins.str]:
        result = self._values.get("update")
        return result

    def __eq__(self, rhs: typing.Any) -> builtins.bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs: typing.Any) -> builtins.bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return "LbBackendAddressPoolTimeouts(%s)" % ", ".join(
            k + "=" + repr(v) for k, v in self._values.items()
        )


@jsii.data_type(
    jsii_type="@cdktf/provider-azurerm.LbConfig",
    jsii_struct_bases=[cdktf.TerraformMetaArguments],
    name_mapping={
        "count": "count",
        "depends_on": "dependsOn",
        "lifecycle": "lifecycle",
        "provider": "provider",
        "location": "location",
        "name": "name",
        "resource_group_name": "resourceGroupName",
        "frontend_ip_configuration": "frontendIpConfiguration",
        "sku": "sku",
        "tags": "tags",
        "timeouts": "timeouts",
    },
)
class LbConfig(cdktf.TerraformMetaArguments):
    def __init__(
        self,
        *,
        count: typing.Optional[jsii.Number] = None,
        depends_on: typing.Optional[typing.List[cdktf.TerraformResource]] = None,
        lifecycle: typing.Optional[cdktf.TerraformResourceLifecycle] = None,
        provider: typing.Optional[cdktf.TerraformProvider] = None,
        location: builtins.str,
        name: builtins.str,
        resource_group_name: builtins.str,
        frontend_ip_configuration: typing.Optional[typing.List["LbFrontendIpConfiguration"]] = None,
        sku: typing.Optional[builtins.str] = None,
        tags: typing.Optional[typing.Mapping[builtins.str, builtins.str]] = None,
        timeouts: typing.Optional["LbTimeouts"] = None,
    ) -> None:
        """
        :param count: 
        :param depends_on: 
        :param lifecycle: 
        :param provider: 
        :param location: 
        :param name: 
        :param resource_group_name: 
        :param frontend_ip_configuration: frontend_ip_configuration block.
        :param sku: 
        :param tags: 
        :param timeouts: timeouts block.
        """
        if isinstance(lifecycle, dict):
            lifecycle = cdktf.TerraformResourceLifecycle(**lifecycle)
        if isinstance(timeouts, dict):
            timeouts = LbTimeouts(**timeouts)
        self._values: typing.Dict[str, typing.Any] = {
            "location": location,
            "name": name,
            "resource_group_name": resource_group_name,
        }
        if count is not None:
            self._values["count"] = count
        if depends_on is not None:
            self._values["depends_on"] = depends_on
        if lifecycle is not None:
            self._values["lifecycle"] = lifecycle
        if provider is not None:
            self._values["provider"] = provider
        if frontend_ip_configuration is not None:
            self._values["frontend_ip_configuration"] = frontend_ip_configuration
        if sku is not None:
            self._values["sku"] = sku
        if tags is not None:
            self._values["tags"] = tags
        if timeouts is not None:
            self._values["timeouts"] = timeouts

    @builtins.property
    def count(self) -> typing.Optional[jsii.Number]:
        """
        :stability: experimental
        """
        result = self._values.get("count")
        return result

    @builtins.property
    def depends_on(self) -> typing.Optional[typing.List[cdktf.TerraformResource]]:
        """
        :stability: experimental
        """
        result = self._values.get("depends_on")
        return result

    @builtins.property
    def lifecycle(self) -> typing.Optional[cdktf.TerraformResourceLifecycle]:
        """
        :stability: experimental
        """
        result = self._values.get("lifecycle")
        return result

    @builtins.property
    def provider(self) -> typing.Optional[cdktf.TerraformProvider]:
        """
        :stability: experimental
        """
        result = self._values.get("provider")
        return result

    @builtins.property
    def location(self) -> builtins.str:
        result = self._values.get("location")
        assert result is not None, "Required property 'location' is missing"
        return result

    @builtins.property
    def name(self) -> builtins.str:
        result = self._values.get("name")
        assert result is not None, "Required property 'name' is missing"
        return result

    @builtins.property
    def resource_group_name(self) -> builtins.str:
        result = self._values.get("resource_group_name")
        assert result is not None, "Required property 'resource_group_name' is missing"
        return result

    @builtins.property
    def frontend_ip_configuration(
        self,
    ) -> typing.Optional[typing.List["LbFrontendIpConfiguration"]]:
        """frontend_ip_configuration block."""
        result = self._values.get("frontend_ip_configuration")
        return result

    @builtins.property
    def sku(self) -> typing.Optional[builtins.str]:
        result = self._values.get("sku")
        return result

    @builtins.property
    def tags(self) -> typing.Optional[typing.Mapping[builtins.str, builtins.str]]:
        result = self._values.get("tags")
        return result

    @builtins.property
    def timeouts(self) -> typing.Optional["LbTimeouts"]:
        """timeouts block."""
        result = self._values.get("timeouts")
        return result

    def __eq__(self, rhs: typing.Any) -> builtins.bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs: typing.Any) -> builtins.bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return "LbConfig(%s)" % ", ".join(
            k + "=" + repr(v) for k, v in self._values.items()
        )


@jsii.data_type(
    jsii_type="@cdktf/provider-azurerm.LbFrontendIpConfiguration",
    jsii_struct_bases=[],
    name_mapping={
        "name": "name",
        "private_ip_address": "privateIpAddress",
        "private_ip_address_allocation": "privateIpAddressAllocation",
        "public_ip_address_id": "publicIpAddressId",
        "public_ip_prefix_id": "publicIpPrefixId",
        "subnet_id": "subnetId",
        "zones": "zones",
    },
)
class LbFrontendIpConfiguration:
    def __init__(
        self,
        *,
        name: builtins.str,
        private_ip_address: typing.Optional[builtins.str] = None,
        private_ip_address_allocation: typing.Optional[builtins.str] = None,
        public_ip_address_id: typing.Optional[builtins.str] = None,
        public_ip_prefix_id: typing.Optional[builtins.str] = None,
        subnet_id: typing.Optional[builtins.str] = None,
        zones: typing.Optional[typing.List[builtins.str]] = None,
    ) -> None:
        """
        :param name: 
        :param private_ip_address: 
        :param private_ip_address_allocation: 
        :param public_ip_address_id: 
        :param public_ip_prefix_id: 
        :param subnet_id: 
        :param zones: 
        """
        self._values: typing.Dict[str, typing.Any] = {
            "name": name,
        }
        if private_ip_address is not None:
            self._values["private_ip_address"] = private_ip_address
        if private_ip_address_allocation is not None:
            self._values["private_ip_address_allocation"] = private_ip_address_allocation
        if public_ip_address_id is not None:
            self._values["public_ip_address_id"] = public_ip_address_id
        if public_ip_prefix_id is not None:
            self._values["public_ip_prefix_id"] = public_ip_prefix_id
        if subnet_id is not None:
            self._values["subnet_id"] = subnet_id
        if zones is not None:
            self._values["zones"] = zones

    @builtins.property
    def name(self) -> builtins.str:
        result = self._values.get("name")
        assert result is not None, "Required property 'name' is missing"
        return result

    @builtins.property
    def private_ip_address(self) -> typing.Optional[builtins.str]:
        result = self._values.get("private_ip_address")
        return result

    @builtins.property
    def private_ip_address_allocation(self) -> typing.Optional[builtins.str]:
        result = self._values.get("private_ip_address_allocation")
        return result

    @builtins.property
    def public_ip_address_id(self) -> typing.Optional[builtins.str]:
        result = self._values.get("public_ip_address_id")
        return result

    @builtins.property
    def public_ip_prefix_id(self) -> typing.Optional[builtins.str]:
        result = self._values.get("public_ip_prefix_id")
        return result

    @builtins.property
    def subnet_id(self) -> typing.Optional[builtins.str]:
        result = self._values.get("subnet_id")
        return result

    @builtins.property
    def zones(self) -> typing.Optional[typing.List[builtins.str]]:
        result = self._values.get("zones")
        return result

    def __eq__(self, rhs: typing.Any) -> builtins.bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs: typing.Any) -> builtins.bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return "LbFrontendIpConfiguration(%s)" % ", ".join(
            k + "=" + repr(v) for k, v in self._values.items()
        )


class LbNatPool(
    cdktf.TerraformResource,
    metaclass=jsii.JSIIMeta,
    jsii_type="@cdktf/provider-azurerm.LbNatPool",
):
    def __init__(
        self,
        scope: constructs.Construct,
        id: builtins.str,
        *,
        backend_port: jsii.Number,
        frontend_ip_configuration_name: builtins.str,
        frontend_port_end: jsii.Number,
        frontend_port_start: jsii.Number,
        loadbalancer_id: builtins.str,
        name: builtins.str,
        protocol: builtins.str,
        resource_group_name: builtins.str,
        timeouts: typing.Optional["LbNatPoolTimeouts"] = None,
        count: typing.Optional[jsii.Number] = None,
        depends_on: typing.Optional[typing.List[cdktf.TerraformResource]] = None,
        lifecycle: typing.Optional[cdktf.TerraformResourceLifecycle] = None,
        provider: typing.Optional[cdktf.TerraformProvider] = None,
    ) -> None:
        """
        :param scope: -
        :param id: -
        :param backend_port: 
        :param frontend_ip_configuration_name: 
        :param frontend_port_end: 
        :param frontend_port_start: 
        :param loadbalancer_id: 
        :param name: 
        :param protocol: 
        :param resource_group_name: 
        :param timeouts: timeouts block.
        :param count: 
        :param depends_on: 
        :param lifecycle: 
        :param provider: 
        """
        config = LbNatPoolConfig(
            backend_port=backend_port,
            frontend_ip_configuration_name=frontend_ip_configuration_name,
            frontend_port_end=frontend_port_end,
            frontend_port_start=frontend_port_start,
            loadbalancer_id=loadbalancer_id,
            name=name,
            protocol=protocol,
            resource_group_name=resource_group_name,
            timeouts=timeouts,
            count=count,
            depends_on=depends_on,
            lifecycle=lifecycle,
            provider=provider,
        )

        jsii.create(LbNatPool, self, [scope, id, config])

    @jsii.member(jsii_name="synthesizeAttributes")
    def _synthesize_attributes(self) -> typing.Mapping[builtins.str, typing.Any]:
        return jsii.invoke(self, "synthesizeAttributes", [])

    @builtins.property # type: ignore
    @jsii.member(jsii_name="frontendIpConfigurationId")
    def frontend_ip_configuration_id(self) -> builtins.str:
        return jsii.get(self, "frontendIpConfigurationId")

    @builtins.property # type: ignore
    @jsii.member(jsii_name="backendPort")
    def backend_port(self) -> jsii.Number:
        return jsii.get(self, "backendPort")

    @backend_port.setter # type: ignore
    def backend_port(self, value: jsii.Number) -> None:
        jsii.set(self, "backendPort", value)

    @builtins.property # type: ignore
    @jsii.member(jsii_name="frontendIpConfigurationName")
    def frontend_ip_configuration_name(self) -> builtins.str:
        return jsii.get(self, "frontendIpConfigurationName")

    @frontend_ip_configuration_name.setter # type: ignore
    def frontend_ip_configuration_name(self, value: builtins.str) -> None:
        jsii.set(self, "frontendIpConfigurationName", value)

    @builtins.property # type: ignore
    @jsii.member(jsii_name="frontendPortEnd")
    def frontend_port_end(self) -> jsii.Number:
        return jsii.get(self, "frontendPortEnd")

    @frontend_port_end.setter # type: ignore
    def frontend_port_end(self, value: jsii.Number) -> None:
        jsii.set(self, "frontendPortEnd", value)

    @builtins.property # type: ignore
    @jsii.member(jsii_name="frontendPortStart")
    def frontend_port_start(self) -> jsii.Number:
        return jsii.get(self, "frontendPortStart")

    @frontend_port_start.setter # type: ignore
    def frontend_port_start(self, value: jsii.Number) -> None:
        jsii.set(self, "frontendPortStart", value)

    @builtins.property # type: ignore
    @jsii.member(jsii_name="loadbalancerId")
    def loadbalancer_id(self) -> builtins.str:
        return jsii.get(self, "loadbalancerId")

    @loadbalancer_id.setter # type: ignore
    def loadbalancer_id(self, value: builtins.str) -> None:
        jsii.set(self, "loadbalancerId", value)

    @builtins.property # type: ignore
    @jsii.member(jsii_name="name")
    def name(self) -> builtins.str:
        return jsii.get(self, "name")

    @name.setter # type: ignore
    def name(self, value: builtins.str) -> None:
        jsii.set(self, "name", value)

    @builtins.property # type: ignore
    @jsii.member(jsii_name="protocol")
    def protocol(self) -> builtins.str:
        return jsii.get(self, "protocol")

    @protocol.setter # type: ignore
    def protocol(self, value: builtins.str) -> None:
        jsii.set(self, "protocol", value)

    @builtins.property # type: ignore
    @jsii.member(jsii_name="resourceGroupName")
    def resource_group_name(self) -> builtins.str:
        return jsii.get(self, "resourceGroupName")

    @resource_group_name.setter # type: ignore
    def resource_group_name(self, value: builtins.str) -> None:
        jsii.set(self, "resourceGroupName", value)

    @builtins.property # type: ignore
    @jsii.member(jsii_name="id")
    def id(self) -> typing.Optional[builtins.str]:
        return jsii.get(self, "id")

    @id.setter # type: ignore
    def id(self, value: typing.Optional[builtins.str]) -> None:
        jsii.set(self, "id", value)

    @builtins.property # type: ignore
    @jsii.member(jsii_name="timeouts")
    def timeouts(self) -> typing.Optional["LbNatPoolTimeouts"]:
        return jsii.get(self, "timeouts")

    @timeouts.setter # type: ignore
    def timeouts(self, value: typing.Optional["LbNatPoolTimeouts"]) -> None:
        jsii.set(self, "timeouts", value)


@jsii.data_type(
    jsii_type="@cdktf/provider-azurerm.LbNatPoolConfig",
    jsii_struct_bases=[cdktf.TerraformMetaArguments],
    name_mapping={
        "count": "count",
        "depends_on": "dependsOn",
        "lifecycle": "lifecycle",
        "provider": "provider",
        "backend_port": "backendPort",
        "frontend_ip_configuration_name": "frontendIpConfigurationName",
        "frontend_port_end": "frontendPortEnd",
        "frontend_port_start": "frontendPortStart",
        "loadbalancer_id": "loadbalancerId",
        "name": "name",
        "protocol": "protocol",
        "resource_group_name": "resourceGroupName",
        "timeouts": "timeouts",
    },
)
class LbNatPoolConfig(cdktf.TerraformMetaArguments):
    def __init__(
        self,
        *,
        count: typing.Optional[jsii.Number] = None,
        depends_on: typing.Optional[typing.List[cdktf.TerraformResource]] = None,
        lifecycle: typing.Optional[cdktf.TerraformResourceLifecycle] = None,
        provider: typing.Optional[cdktf.TerraformProvider] = None,
        backend_port: jsii.Number,
        frontend_ip_configuration_name: builtins.str,
        frontend_port_end: jsii.Number,
        frontend_port_start: jsii.Number,
        loadbalancer_id: builtins.str,
        name: builtins.str,
        protocol: builtins.str,
        resource_group_name: builtins.str,
        timeouts: typing.Optional["LbNatPoolTimeouts"] = None,
    ) -> None:
        """
        :param count: 
        :param depends_on: 
        :param lifecycle: 
        :param provider: 
        :param backend_port: 
        :param frontend_ip_configuration_name: 
        :param frontend_port_end: 
        :param frontend_port_start: 
        :param loadbalancer_id: 
        :param name: 
        :param protocol: 
        :param resource_group_name: 
        :param timeouts: timeouts block.
        """
        if isinstance(lifecycle, dict):
            lifecycle = cdktf.TerraformResourceLifecycle(**lifecycle)
        if isinstance(timeouts, dict):
            timeouts = LbNatPoolTimeouts(**timeouts)
        self._values: typing.Dict[str, typing.Any] = {
            "backend_port": backend_port,
            "frontend_ip_configuration_name": frontend_ip_configuration_name,
            "frontend_port_end": frontend_port_end,
            "frontend_port_start": frontend_port_start,
            "loadbalancer_id": loadbalancer_id,
            "name": name,
            "protocol": protocol,
            "resource_group_name": resource_group_name,
        }
        if count is not None:
            self._values["count"] = count
        if depends_on is not None:
            self._values["depends_on"] = depends_on
        if lifecycle is not None:
            self._values["lifecycle"] = lifecycle
        if provider is not None:
            self._values["provider"] = provider
        if timeouts is not None:
            self._values["timeouts"] = timeouts

    @builtins.property
    def count(self) -> typing.Optional[jsii.Number]:
        """
        :stability: experimental
        """
        result = self._values.get("count")
        return result

    @builtins.property
    def depends_on(self) -> typing.Optional[typing.List[cdktf.TerraformResource]]:
        """
        :stability: experimental
        """
        result = self._values.get("depends_on")
        return result

    @builtins.property
    def lifecycle(self) -> typing.Optional[cdktf.TerraformResourceLifecycle]:
        """
        :stability: experimental
        """
        result = self._values.get("lifecycle")
        return result

    @builtins.property
    def provider(self) -> typing.Optional[cdktf.TerraformProvider]:
        """
        :stability: experimental
        """
        result = self._values.get("provider")
        return result

    @builtins.property
    def backend_port(self) -> jsii.Number:
        result = self._values.get("backend_port")
        assert result is not None, "Required property 'backend_port' is missing"
        return result

    @builtins.property
    def frontend_ip_configuration_name(self) -> builtins.str:
        result = self._values.get("frontend_ip_configuration_name")
        assert result is not None, "Required property 'frontend_ip_configuration_name' is missing"
        return result

    @builtins.property
    def frontend_port_end(self) -> jsii.Number:
        result = self._values.get("frontend_port_end")
        assert result is not None, "Required property 'frontend_port_end' is missing"
        return result

    @builtins.property
    def frontend_port_start(self) -> jsii.Number:
        result = self._values.get("frontend_port_start")
        assert result is not None, "Required property 'frontend_port_start' is missing"
        return result

    @builtins.property
    def loadbalancer_id(self) -> builtins.str:
        result = self._values.get("loadbalancer_id")
        assert result is not None, "Required property 'loadbalancer_id' is missing"
        return result

    @builtins.property
    def name(self) -> builtins.str:
        result = self._values.get("name")
        assert result is not None, "Required property 'name' is missing"
        return result

    @builtins.property
    def protocol(self) -> builtins.str:
        result = self._values.get("protocol")
        assert result is not None, "Required property 'protocol' is missing"
        return result

    @builtins.property
    def resource_group_name(self) -> builtins.str:
        result = self._values.get("resource_group_name")
        assert result is not None, "Required property 'resource_group_name' is missing"
        return result

    @builtins.property
    def timeouts(self) -> typing.Optional["LbNatPoolTimeouts"]:
        """timeouts block."""
        result = self._values.get("timeouts")
        return result

    def __eq__(self, rhs: typing.Any) -> builtins.bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs: typing.Any) -> builtins.bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return "LbNatPoolConfig(%s)" % ", ".join(
            k + "=" + repr(v) for k, v in self._values.items()
        )


@jsii.data_type(
    jsii_type="@cdktf/provider-azurerm.LbNatPoolTimeouts",
    jsii_struct_bases=[],
    name_mapping={
        "create": "create",
        "delete": "delete",
        "read": "read",
        "update": "update",
    },
)
class LbNatPoolTimeouts:
    def __init__(
        self,
        *,
        create: typing.Optional[builtins.str] = None,
        delete: typing.Optional[builtins.str] = None,
        read: typing.Optional[builtins.str] = None,
        update: typing.Optional[builtins.str] = None,
    ) -> None:
        """
        :param create: 
        :param delete: 
        :param read: 
        :param update: 
        """
        self._values: typing.Dict[str, typing.Any] = {}
        if create is not None:
            self._values["create"] = create
        if delete is not None:
            self._values["delete"] = delete
        if read is not None:
            self._values["read"] = read
        if update is not None:
            self._values["update"] = update

    @builtins.property
    def create(self) -> typing.Optional[builtins.str]:
        result = self._values.get("create")
        return result

    @builtins.property
    def delete(self) -> typing.Optional[builtins.str]:
        result = self._values.get("delete")
        return result

    @builtins.property
    def read(self) -> typing.Optional[builtins.str]:
        result = self._values.get("read")
        return result

    @builtins.property
    def update(self) -> typing.Optional[builtins.str]:
        result = self._values.get("update")
        return result

    def __eq__(self, rhs: typing.Any) -> builtins.bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs: typing.Any) -> builtins.bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return "LbNatPoolTimeouts(%s)" % ", ".join(
            k + "=" + repr(v) for k, v in self._values.items()
        )


class LbNatRule(
    cdktf.TerraformResource,
    metaclass=jsii.JSIIMeta,
    jsii_type="@cdktf/provider-azurerm.LbNatRule",
):
    def __init__(
        self,
        scope: constructs.Construct,
        id: builtins.str,
        *,
        backend_port: jsii.Number,
        frontend_ip_configuration_name: builtins.str,
        frontend_port: jsii.Number,
        loadbalancer_id: builtins.str,
        name: builtins.str,
        protocol: builtins.str,
        resource_group_name: builtins.str,
        enable_floating_ip: typing.Optional[builtins.bool] = None,
        enable_tcp_reset: typing.Optional[builtins.bool] = None,
        idle_timeout_in_minutes: typing.Optional[jsii.Number] = None,
        timeouts: typing.Optional["LbNatRuleTimeouts"] = None,
        count: typing.Optional[jsii.Number] = None,
        depends_on: typing.Optional[typing.List[cdktf.TerraformResource]] = None,
        lifecycle: typing.Optional[cdktf.TerraformResourceLifecycle] = None,
        provider: typing.Optional[cdktf.TerraformProvider] = None,
    ) -> None:
        """
        :param scope: -
        :param id: -
        :param backend_port: 
        :param frontend_ip_configuration_name: 
        :param frontend_port: 
        :param loadbalancer_id: 
        :param name: 
        :param protocol: 
        :param resource_group_name: 
        :param enable_floating_ip: 
        :param enable_tcp_reset: 
        :param idle_timeout_in_minutes: 
        :param timeouts: timeouts block.
        :param count: 
        :param depends_on: 
        :param lifecycle: 
        :param provider: 
        """
        config = LbNatRuleConfig(
            backend_port=backend_port,
            frontend_ip_configuration_name=frontend_ip_configuration_name,
            frontend_port=frontend_port,
            loadbalancer_id=loadbalancer_id,
            name=name,
            protocol=protocol,
            resource_group_name=resource_group_name,
            enable_floating_ip=enable_floating_ip,
            enable_tcp_reset=enable_tcp_reset,
            idle_timeout_in_minutes=idle_timeout_in_minutes,
            timeouts=timeouts,
            count=count,
            depends_on=depends_on,
            lifecycle=lifecycle,
            provider=provider,
        )

        jsii.create(LbNatRule, self, [scope, id, config])

    @jsii.member(jsii_name="synthesizeAttributes")
    def _synthesize_attributes(self) -> typing.Mapping[builtins.str, typing.Any]:
        return jsii.invoke(self, "synthesizeAttributes", [])

    @builtins.property # type: ignore
    @jsii.member(jsii_name="backendIpConfigurationId")
    def backend_ip_configuration_id(self) -> builtins.str:
        return jsii.get(self, "backendIpConfigurationId")

    @builtins.property # type: ignore
    @jsii.member(jsii_name="frontendIpConfigurationId")
    def frontend_ip_configuration_id(self) -> builtins.str:
        return jsii.get(self, "frontendIpConfigurationId")

    @builtins.property # type: ignore
    @jsii.member(jsii_name="backendPort")
    def backend_port(self) -> jsii.Number:
        return jsii.get(self, "backendPort")

    @backend_port.setter # type: ignore
    def backend_port(self, value: jsii.Number) -> None:
        jsii.set(self, "backendPort", value)

    @builtins.property # type: ignore
    @jsii.member(jsii_name="frontendIpConfigurationName")
    def frontend_ip_configuration_name(self) -> builtins.str:
        return jsii.get(self, "frontendIpConfigurationName")

    @frontend_ip_configuration_name.setter # type: ignore
    def frontend_ip_configuration_name(self, value: builtins.str) -> None:
        jsii.set(self, "frontendIpConfigurationName", value)

    @builtins.property # type: ignore
    @jsii.member(jsii_name="frontendPort")
    def frontend_port(self) -> jsii.Number:
        return jsii.get(self, "frontendPort")

    @frontend_port.setter # type: ignore
    def frontend_port(self, value: jsii.Number) -> None:
        jsii.set(self, "frontendPort", value)

    @builtins.property # type: ignore
    @jsii.member(jsii_name="loadbalancerId")
    def loadbalancer_id(self) -> builtins.str:
        return jsii.get(self, "loadbalancerId")

    @loadbalancer_id.setter # type: ignore
    def loadbalancer_id(self, value: builtins.str) -> None:
        jsii.set(self, "loadbalancerId", value)

    @builtins.property # type: ignore
    @jsii.member(jsii_name="name")
    def name(self) -> builtins.str:
        return jsii.get(self, "name")

    @name.setter # type: ignore
    def name(self, value: builtins.str) -> None:
        jsii.set(self, "name", value)

    @builtins.property # type: ignore
    @jsii.member(jsii_name="protocol")
    def protocol(self) -> builtins.str:
        return jsii.get(self, "protocol")

    @protocol.setter # type: ignore
    def protocol(self, value: builtins.str) -> None:
        jsii.set(self, "protocol", value)

    @builtins.property # type: ignore
    @jsii.member(jsii_name="resourceGroupName")
    def resource_group_name(self) -> builtins.str:
        return jsii.get(self, "resourceGroupName")

    @resource_group_name.setter # type: ignore
    def resource_group_name(self, value: builtins.str) -> None:
        jsii.set(self, "resourceGroupName", value)

    @builtins.property # type: ignore
    @jsii.member(jsii_name="enableFloatingIp")
    def enable_floating_ip(self) -> typing.Optional[builtins.bool]:
        return jsii.get(self, "enableFloatingIp")

    @enable_floating_ip.setter # type: ignore
    def enable_floating_ip(self, value: typing.Optional[builtins.bool]) -> None:
        jsii.set(self, "enableFloatingIp", value)

    @builtins.property # type: ignore
    @jsii.member(jsii_name="enableTcpReset")
    def enable_tcp_reset(self) -> typing.Optional[builtins.bool]:
        return jsii.get(self, "enableTcpReset")

    @enable_tcp_reset.setter # type: ignore
    def enable_tcp_reset(self, value: typing.Optional[builtins.bool]) -> None:
        jsii.set(self, "enableTcpReset", value)

    @builtins.property # type: ignore
    @jsii.member(jsii_name="id")
    def id(self) -> typing.Optional[builtins.str]:
        return jsii.get(self, "id")

    @id.setter # type: ignore
    def id(self, value: typing.Optional[builtins.str]) -> None:
        jsii.set(self, "id", value)

    @builtins.property # type: ignore
    @jsii.member(jsii_name="idleTimeoutInMinutes")
    def idle_timeout_in_minutes(self) -> typing.Optional[jsii.Number]:
        return jsii.get(self, "idleTimeoutInMinutes")

    @idle_timeout_in_minutes.setter # type: ignore
    def idle_timeout_in_minutes(self, value: typing.Optional[jsii.Number]) -> None:
        jsii.set(self, "idleTimeoutInMinutes", value)

    @builtins.property # type: ignore
    @jsii.member(jsii_name="timeouts")
    def timeouts(self) -> typing.Optional["LbNatRuleTimeouts"]:
        return jsii.get(self, "timeouts")

    @timeouts.setter # type: ignore
    def timeouts(self, value: typing.Optional["LbNatRuleTimeouts"]) -> None:
        jsii.set(self, "timeouts", value)


@jsii.data_type(
    jsii_type="@cdktf/provider-azurerm.LbNatRuleConfig",
    jsii_struct_bases=[cdktf.TerraformMetaArguments],
    name_mapping={
        "count": "count",
        "depends_on": "dependsOn",
        "lifecycle": "lifecycle",
        "provider": "provider",
        "backend_port": "backendPort",
        "frontend_ip_configuration_name": "frontendIpConfigurationName",
        "frontend_port": "frontendPort",
        "loadbalancer_id": "loadbalancerId",
        "name": "name",
        "protocol": "protocol",
        "resource_group_name": "resourceGroupName",
        "enable_floating_ip": "enableFloatingIp",
        "enable_tcp_reset": "enableTcpReset",
        "idle_timeout_in_minutes": "idleTimeoutInMinutes",
        "timeouts": "timeouts",
    },
)
class LbNatRuleConfig(cdktf.TerraformMetaArguments):
    def __init__(
        self,
        *,
        count: typing.Optional[jsii.Number] = None,
        depends_on: typing.Optional[typing.List[cdktf.TerraformResource]] = None,
        lifecycle: typing.Optional[cdktf.TerraformResourceLifecycle] = None,
        provider: typing.Optional[cdktf.TerraformProvider] = None,
        backend_port: jsii.Number,
        frontend_ip_configuration_name: builtins.str,
        frontend_port: jsii.Number,
        loadbalancer_id: builtins.str,
        name: builtins.str,
        protocol: builtins.str,
        resource_group_name: builtins.str,
        enable_floating_ip: typing.Optional[builtins.bool] = None,
        enable_tcp_reset: typing.Optional[builtins.bool] = None,
        idle_timeout_in_minutes: typing.Optional[jsii.Number] = None,
        timeouts: typing.Optional["LbNatRuleTimeouts"] = None,
    ) -> None:
        """
        :param count: 
        :param depends_on: 
        :param lifecycle: 
        :param provider: 
        :param backend_port: 
        :param frontend_ip_configuration_name: 
        :param frontend_port: 
        :param loadbalancer_id: 
        :param name: 
        :param protocol: 
        :param resource_group_name: 
        :param enable_floating_ip: 
        :param enable_tcp_reset: 
        :param idle_timeout_in_minutes: 
        :param timeouts: timeouts block.
        """
        if isinstance(lifecycle, dict):
            lifecycle = cdktf.TerraformResourceLifecycle(**lifecycle)
        if isinstance(timeouts, dict):
            timeouts = LbNatRuleTimeouts(**timeouts)
        self._values: typing.Dict[str, typing.Any] = {
            "backend_port": backend_port,
            "frontend_ip_configuration_name": frontend_ip_configuration_name,
            "frontend_port": frontend_port,
            "loadbalancer_id": loadbalancer_id,
            "name": name,
            "protocol": protocol,
            "resource_group_name": resource_group_name,
        }
        if count is not None:
            self._values["count"] = count
        if depends_on is not None:
            self._values["depends_on"] = depends_on
        if lifecycle is not None:
            self._values["lifecycle"] = lifecycle
        if provider is not None:
            self._values["provider"] = provider
        if enable_floating_ip is not None:
            self._values["enable_floating_ip"] = enable_floating_ip
        if enable_tcp_reset is not None:
            self._values["enable_tcp_reset"] = enable_tcp_reset
        if idle_timeout_in_minutes is not None:
            self._values["idle_timeout_in_minutes"] = idle_timeout_in_minutes
        if timeouts is not None:
            self._values["timeouts"] = timeouts

    @builtins.property
    def count(self) -> typing.Optional[jsii.Number]:
        """
        :stability: experimental
        """
        result = self._values.get("count")
        return result

    @builtins.property
    def depends_on(self) -> typing.Optional[typing.List[cdktf.TerraformResource]]:
        """
        :stability: experimental
        """
        result = self._values.get("depends_on")
        return result

    @builtins.property
    def lifecycle(self) -> typing.Optional[cdktf.TerraformResourceLifecycle]:
        """
        :stability: experimental
        """
        result = self._values.get("lifecycle")
        return result

    @builtins.property
    def provider(self) -> typing.Optional[cdktf.TerraformProvider]:
        """
        :stability: experimental
        """
        result = self._values.get("provider")
        return result

    @builtins.property
    def backend_port(self) -> jsii.Number:
        result = self._values.get("backend_port")
        assert result is not None, "Required property 'backend_port' is missing"
        return result

    @builtins.property
    def frontend_ip_configuration_name(self) -> builtins.str:
        result = self._values.get("frontend_ip_configuration_name")
        assert result is not None, "Required property 'frontend_ip_configuration_name' is missing"
        return result

    @builtins.property
    def frontend_port(self) -> jsii.Number:
        result = self._values.get("frontend_port")
        assert result is not None, "Required property 'frontend_port' is missing"
        return result

    @builtins.property
    def loadbalancer_id(self) -> builtins.str:
        result = self._values.get("loadbalancer_id")
        assert result is not None, "Required property 'loadbalancer_id' is missing"
        return result

    @builtins.property
    def name(self) -> builtins.str:
        result = self._values.get("name")
        assert result is not None, "Required property 'name' is missing"
        return result

    @builtins.property
    def protocol(self) -> builtins.str:
        result = self._values.get("protocol")
        assert result is not None, "Required property 'protocol' is missing"
        return result

    @builtins.property
    def resource_group_name(self) -> builtins.str:
        result = self._values.get("resource_group_name")
        assert result is not None, "Required property 'resource_group_name' is missing"
        return result

    @builtins.property
    def enable_floating_ip(self) -> typing.Optional[builtins.bool]:
        result = self._values.get("enable_floating_ip")
        return result

    @builtins.property
    def enable_tcp_reset(self) -> typing.Optional[builtins.bool]:
        result = self._values.get("enable_tcp_reset")
        return result

    @builtins.property
    def idle_timeout_in_minutes(self) -> typing.Optional[jsii.Number]:
        result = self._values.get("idle_timeout_in_minutes")
        return result

    @builtins.property
    def timeouts(self) -> typing.Optional["LbNatRuleTimeouts"]:
        """timeouts block."""
        result = self._values.get("timeouts")
        return result

    def __eq__(self, rhs: typing.Any) -> builtins.bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs: typing.Any) -> builtins.bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return "LbNatRuleConfig(%s)" % ", ".join(
            k + "=" + repr(v) for k, v in self._values.items()
        )


@jsii.data_type(
    jsii_type="@cdktf/provider-azurerm.LbNatRuleTimeouts",
    jsii_struct_bases=[],
    name_mapping={
        "create": "create",
        "delete": "delete",
        "read": "read",
        "update": "update",
    },
)
class LbNatRuleTimeouts:
    def __init__(
        self,
        *,
        create: typing.Optional[builtins.str] = None,
        delete: typing.Optional[builtins.str] = None,
        read: typing.Optional[builtins.str] = None,
        update: typing.Optional[builtins.str] = None,
    ) -> None:
        """
        :param create: 
        :param delete: 
        :param read: 
        :param update: 
        """
        self._values: typing.Dict[str, typing.Any] = {}
        if create is not None:
            self._values["create"] = create
        if delete is not None:
            self._values["delete"] = delete
        if read is not None:
            self._values["read"] = read
        if update is not None:
            self._values["update"] = update

    @builtins.property
    def create(self) -> typing.Optional[builtins.str]:
        result = self._values.get("create")
        return result

    @builtins.property
    def delete(self) -> typing.Optional[builtins.str]:
        result = self._values.get("delete")
        return result

    @builtins.property
    def read(self) -> typing.Optional[builtins.str]:
        result = self._values.get("read")
        return result

    @builtins.property
    def update(self) -> typing.Optional[builtins.str]:
        result = self._values.get("update")
        return result

    def __eq__(self, rhs: typing.Any) -> builtins.bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs: typing.Any) -> builtins.bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return "LbNatRuleTimeouts(%s)" % ", ".join(
            k + "=" + repr(v) for k, v in self._values.items()
        )


class LbOutboundRule(
    cdktf.TerraformResource,
    metaclass=jsii.JSIIMeta,
    jsii_type="@cdktf/provider-azurerm.LbOutboundRule",
):
    def __init__(
        self,
        scope: constructs.Construct,
        id: builtins.str,
        *,
        backend_address_pool_id: builtins.str,
        loadbalancer_id: builtins.str,
        name: builtins.str,
        protocol: builtins.str,
        resource_group_name: builtins.str,
        allocated_outbound_ports: typing.Optional[jsii.Number] = None,
        enable_tcp_reset: typing.Optional[builtins.bool] = None,
        frontend_ip_configuration: typing.Optional[typing.List["LbOutboundRuleFrontendIpConfiguration"]] = None,
        idle_timeout_in_minutes: typing.Optional[jsii.Number] = None,
        timeouts: typing.Optional["LbOutboundRuleTimeouts"] = None,
        count: typing.Optional[jsii.Number] = None,
        depends_on: typing.Optional[typing.List[cdktf.TerraformResource]] = None,
        lifecycle: typing.Optional[cdktf.TerraformResourceLifecycle] = None,
        provider: typing.Optional[cdktf.TerraformProvider] = None,
    ) -> None:
        """
        :param scope: -
        :param id: -
        :param backend_address_pool_id: 
        :param loadbalancer_id: 
        :param name: 
        :param protocol: 
        :param resource_group_name: 
        :param allocated_outbound_ports: 
        :param enable_tcp_reset: 
        :param frontend_ip_configuration: frontend_ip_configuration block.
        :param idle_timeout_in_minutes: 
        :param timeouts: timeouts block.
        :param count: 
        :param depends_on: 
        :param lifecycle: 
        :param provider: 
        """
        config = LbOutboundRuleConfig(
            backend_address_pool_id=backend_address_pool_id,
            loadbalancer_id=loadbalancer_id,
            name=name,
            protocol=protocol,
            resource_group_name=resource_group_name,
            allocated_outbound_ports=allocated_outbound_ports,
            enable_tcp_reset=enable_tcp_reset,
            frontend_ip_configuration=frontend_ip_configuration,
            idle_timeout_in_minutes=idle_timeout_in_minutes,
            timeouts=timeouts,
            count=count,
            depends_on=depends_on,
            lifecycle=lifecycle,
            provider=provider,
        )

        jsii.create(LbOutboundRule, self, [scope, id, config])

    @jsii.member(jsii_name="synthesizeAttributes")
    def _synthesize_attributes(self) -> typing.Mapping[builtins.str, typing.Any]:
        return jsii.invoke(self, "synthesizeAttributes", [])

    @builtins.property # type: ignore
    @jsii.member(jsii_name="backendAddressPoolId")
    def backend_address_pool_id(self) -> builtins.str:
        return jsii.get(self, "backendAddressPoolId")

    @backend_address_pool_id.setter # type: ignore
    def backend_address_pool_id(self, value: builtins.str) -> None:
        jsii.set(self, "backendAddressPoolId", value)

    @builtins.property # type: ignore
    @jsii.member(jsii_name="loadbalancerId")
    def loadbalancer_id(self) -> builtins.str:
        return jsii.get(self, "loadbalancerId")

    @loadbalancer_id.setter # type: ignore
    def loadbalancer_id(self, value: builtins.str) -> None:
        jsii.set(self, "loadbalancerId", value)

    @builtins.property # type: ignore
    @jsii.member(jsii_name="name")
    def name(self) -> builtins.str:
        return jsii.get(self, "name")

    @name.setter # type: ignore
    def name(self, value: builtins.str) -> None:
        jsii.set(self, "name", value)

    @builtins.property # type: ignore
    @jsii.member(jsii_name="protocol")
    def protocol(self) -> builtins.str:
        return jsii.get(self, "protocol")

    @protocol.setter # type: ignore
    def protocol(self, value: builtins.str) -> None:
        jsii.set(self, "protocol", value)

    @builtins.property # type: ignore
    @jsii.member(jsii_name="resourceGroupName")
    def resource_group_name(self) -> builtins.str:
        return jsii.get(self, "resourceGroupName")

    @resource_group_name.setter # type: ignore
    def resource_group_name(self, value: builtins.str) -> None:
        jsii.set(self, "resourceGroupName", value)

    @builtins.property # type: ignore
    @jsii.member(jsii_name="allocatedOutboundPorts")
    def allocated_outbound_ports(self) -> typing.Optional[jsii.Number]:
        return jsii.get(self, "allocatedOutboundPorts")

    @allocated_outbound_ports.setter # type: ignore
    def allocated_outbound_ports(self, value: typing.Optional[jsii.Number]) -> None:
        jsii.set(self, "allocatedOutboundPorts", value)

    @builtins.property # type: ignore
    @jsii.member(jsii_name="enableTcpReset")
    def enable_tcp_reset(self) -> typing.Optional[builtins.bool]:
        return jsii.get(self, "enableTcpReset")

    @enable_tcp_reset.setter # type: ignore
    def enable_tcp_reset(self, value: typing.Optional[builtins.bool]) -> None:
        jsii.set(self, "enableTcpReset", value)

    @builtins.property # type: ignore
    @jsii.member(jsii_name="frontendIpConfiguration")
    def frontend_ip_configuration(
        self,
    ) -> typing.Optional[typing.List["LbOutboundRuleFrontendIpConfiguration"]]:
        return jsii.get(self, "frontendIpConfiguration")

    @frontend_ip_configuration.setter # type: ignore
    def frontend_ip_configuration(
        self,
        value: typing.Optional[typing.List["LbOutboundRuleFrontendIpConfiguration"]],
    ) -> None:
        jsii.set(self, "frontendIpConfiguration", value)

    @builtins.property # type: ignore
    @jsii.member(jsii_name="id")
    def id(self) -> typing.Optional[builtins.str]:
        return jsii.get(self, "id")

    @id.setter # type: ignore
    def id(self, value: typing.Optional[builtins.str]) -> None:
        jsii.set(self, "id", value)

    @builtins.property # type: ignore
    @jsii.member(jsii_name="idleTimeoutInMinutes")
    def idle_timeout_in_minutes(self) -> typing.Optional[jsii.Number]:
        return jsii.get(self, "idleTimeoutInMinutes")

    @idle_timeout_in_minutes.setter # type: ignore
    def idle_timeout_in_minutes(self, value: typing.Optional[jsii.Number]) -> None:
        jsii.set(self, "idleTimeoutInMinutes", value)

    @builtins.property # type: ignore
    @jsii.member(jsii_name="timeouts")
    def timeouts(self) -> typing.Optional["LbOutboundRuleTimeouts"]:
        return jsii.get(self, "timeouts")

    @timeouts.setter # type: ignore
    def timeouts(self, value: typing.Optional["LbOutboundRuleTimeouts"]) -> None:
        jsii.set(self, "timeouts", value)


@jsii.data_type(
    jsii_type="@cdktf/provider-azurerm.LbOutboundRuleConfig",
    jsii_struct_bases=[cdktf.TerraformMetaArguments],
    name_mapping={
        "count": "count",
        "depends_on": "dependsOn",
        "lifecycle": "lifecycle",
        "provider": "provider",
        "backend_address_pool_id": "backendAddressPoolId",
        "loadbalancer_id": "loadbalancerId",
        "name": "name",
        "protocol": "protocol",
        "resource_group_name": "resourceGroupName",
        "allocated_outbound_ports": "allocatedOutboundPorts",
        "enable_tcp_reset": "enableTcpReset",
        "frontend_ip_configuration": "frontendIpConfiguration",
        "idle_timeout_in_minutes": "idleTimeoutInMinutes",
        "timeouts": "timeouts",
    },
)
class LbOutboundRuleConfig(cdktf.TerraformMetaArguments):
    def __init__(
        self,
        *,
        count: typing.Optional[jsii.Number] = None,
        depends_on: typing.Optional[typing.List[cdktf.TerraformResource]] = None,
        lifecycle: typing.Optional[cdktf.TerraformResourceLifecycle] = None,
        provider: typing.Optional[cdktf.TerraformProvider] = None,
        backend_address_pool_id: builtins.str,
        loadbalancer_id: builtins.str,
        name: builtins.str,
        protocol: builtins.str,
        resource_group_name: builtins.str,
        allocated_outbound_ports: typing.Optional[jsii.Number] = None,
        enable_tcp_reset: typing.Optional[builtins.bool] = None,
        frontend_ip_configuration: typing.Optional[typing.List["LbOutboundRuleFrontendIpConfiguration"]] = None,
        idle_timeout_in_minutes: typing.Optional[jsii.Number] = None,
        timeouts: typing.Optional["LbOutboundRuleTimeouts"] = None,
    ) -> None:
        """
        :param count: 
        :param depends_on: 
        :param lifecycle: 
        :param provider: 
        :param backend_address_pool_id: 
        :param loadbalancer_id: 
        :param name: 
        :param protocol: 
        :param resource_group_name: 
        :param allocated_outbound_ports: 
        :param enable_tcp_reset: 
        :param frontend_ip_configuration: frontend_ip_configuration block.
        :param idle_timeout_in_minutes: 
        :param timeouts: timeouts block.
        """
        if isinstance(lifecycle, dict):
            lifecycle = cdktf.TerraformResourceLifecycle(**lifecycle)
        if isinstance(timeouts, dict):
            timeouts = LbOutboundRuleTimeouts(**timeouts)
        self._values: typing.Dict[str, typing.Any] = {
            "backend_address_pool_id": backend_address_pool_id,
            "loadbalancer_id": loadbalancer_id,
            "name": name,
            "protocol": protocol,
            "resource_group_name": resource_group_name,
        }
        if count is not None:
            self._values["count"] = count
        if depends_on is not None:
            self._values["depends_on"] = depends_on
        if lifecycle is not None:
            self._values["lifecycle"] = lifecycle
        if provider is not None:
            self._values["provider"] = provider
        if allocated_outbound_ports is not None:
            self._values["allocated_outbound_ports"] = allocated_outbound_ports
        if enable_tcp_reset is not None:
            self._values["enable_tcp_reset"] = enable_tcp_reset
        if frontend_ip_configuration is not None:
            self._values["frontend_ip_configuration"] = frontend_ip_configuration
        if idle_timeout_in_minutes is not None:
            self._values["idle_timeout_in_minutes"] = idle_timeout_in_minutes
        if timeouts is not None:
            self._values["timeouts"] = timeouts

    @builtins.property
    def count(self) -> typing.Optional[jsii.Number]:
        """
        :stability: experimental
        """
        result = self._values.get("count")
        return result

    @builtins.property
    def depends_on(self) -> typing.Optional[typing.List[cdktf.TerraformResource]]:
        """
        :stability: experimental
        """
        result = self._values.get("depends_on")
        return result

    @builtins.property
    def lifecycle(self) -> typing.Optional[cdktf.TerraformResourceLifecycle]:
        """
        :stability: experimental
        """
        result = self._values.get("lifecycle")
        return result

    @builtins.property
    def provider(self) -> typing.Optional[cdktf.TerraformProvider]:
        """
        :stability: experimental
        """
        result = self._values.get("provider")
        return result

    @builtins.property
    def backend_address_pool_id(self) -> builtins.str:
        result = self._values.get("backend_address_pool_id")
        assert result is not None, "Required property 'backend_address_pool_id' is missing"
        return result

    @builtins.property
    def loadbalancer_id(self) -> builtins.str:
        result = self._values.get("loadbalancer_id")
        assert result is not None, "Required property 'loadbalancer_id' is missing"
        return result

    @builtins.property
    def name(self) -> builtins.str:
        result = self._values.get("name")
        assert result is not None, "Required property 'name' is missing"
        return result

    @builtins.property
    def protocol(self) -> builtins.str:
        result = self._values.get("protocol")
        assert result is not None, "Required property 'protocol' is missing"
        return result

    @builtins.property
    def resource_group_name(self) -> builtins.str:
        result = self._values.get("resource_group_name")
        assert result is not None, "Required property 'resource_group_name' is missing"
        return result

    @builtins.property
    def allocated_outbound_ports(self) -> typing.Optional[jsii.Number]:
        result = self._values.get("allocated_outbound_ports")
        return result

    @builtins.property
    def enable_tcp_reset(self) -> typing.Optional[builtins.bool]:
        result = self._values.get("enable_tcp_reset")
        return result

    @builtins.property
    def frontend_ip_configuration(
        self,
    ) -> typing.Optional[typing.List["LbOutboundRuleFrontendIpConfiguration"]]:
        """frontend_ip_configuration block."""
        result = self._values.get("frontend_ip_configuration")
        return result

    @builtins.property
    def idle_timeout_in_minutes(self) -> typing.Optional[jsii.Number]:
        result = self._values.get("idle_timeout_in_minutes")
        return result

    @builtins.property
    def timeouts(self) -> typing.Optional["LbOutboundRuleTimeouts"]:
        """timeouts block."""
        result = self._values.get("timeouts")
        return result

    def __eq__(self, rhs: typing.Any) -> builtins.bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs: typing.Any) -> builtins.bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return "LbOutboundRuleConfig(%s)" % ", ".join(
            k + "=" + repr(v) for k, v in self._values.items()
        )


@jsii.data_type(
    jsii_type="@cdktf/provider-azurerm.LbOutboundRuleFrontendIpConfiguration",
    jsii_struct_bases=[],
    name_mapping={"name": "name"},
)
class LbOutboundRuleFrontendIpConfiguration:
    def __init__(self, *, name: builtins.str) -> None:
        """
        :param name: 
        """
        self._values: typing.Dict[str, typing.Any] = {
            "name": name,
        }

    @builtins.property
    def name(self) -> builtins.str:
        result = self._values.get("name")
        assert result is not None, "Required property 'name' is missing"
        return result

    def __eq__(self, rhs: typing.Any) -> builtins.bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs: typing.Any) -> builtins.bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return "LbOutboundRuleFrontendIpConfiguration(%s)" % ", ".join(
            k + "=" + repr(v) for k, v in self._values.items()
        )


@jsii.data_type(
    jsii_type="@cdktf/provider-azurerm.LbOutboundRuleTimeouts",
    jsii_struct_bases=[],
    name_mapping={
        "create": "create",
        "delete": "delete",
        "read": "read",
        "update": "update",
    },
)
class LbOutboundRuleTimeouts:
    def __init__(
        self,
        *,
        create: typing.Optional[builtins.str] = None,
        delete: typing.Optional[builtins.str] = None,
        read: typing.Optional[builtins.str] = None,
        update: typing.Optional[builtins.str] = None,
    ) -> None:
        """
        :param create: 
        :param delete: 
        :param read: 
        :param update: 
        """
        self._values: typing.Dict[str, typing.Any] = {}
        if create is not None:
            self._values["create"] = create
        if delete is not None:
            self._values["delete"] = delete
        if read is not None:
            self._values["read"] = read
        if update is not None:
            self._values["update"] = update

    @builtins.property
    def create(self) -> typing.Optional[builtins.str]:
        result = self._values.get("create")
        return result

    @builtins.property
    def delete(self) -> typing.Optional[builtins.str]:
        result = self._values.get("delete")
        return result

    @builtins.property
    def read(self) -> typing.Optional[builtins.str]:
        result = self._values.get("read")
        return result

    @builtins.property
    def update(self) -> typing.Optional[builtins.str]:
        result = self._values.get("update")
        return result

    def __eq__(self, rhs: typing.Any) -> builtins.bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs: typing.Any) -> builtins.bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return "LbOutboundRuleTimeouts(%s)" % ", ".join(
            k + "=" + repr(v) for k, v in self._values.items()
        )


class LbProbe(
    cdktf.TerraformResource,
    metaclass=jsii.JSIIMeta,
    jsii_type="@cdktf/provider-azurerm.LbProbe",
):
    def __init__(
        self,
        scope: constructs.Construct,
        id: builtins.str,
        *,
        loadbalancer_id: builtins.str,
        name: builtins.str,
        port: jsii.Number,
        resource_group_name: builtins.str,
        interval_in_seconds: typing.Optional[jsii.Number] = None,
        number_of_probes: typing.Optional[jsii.Number] = None,
        protocol: typing.Optional[builtins.str] = None,
        request_path: typing.Optional[builtins.str] = None,
        timeouts: typing.Optional["LbProbeTimeouts"] = None,
        count: typing.Optional[jsii.Number] = None,
        depends_on: typing.Optional[typing.List[cdktf.TerraformResource]] = None,
        lifecycle: typing.Optional[cdktf.TerraformResourceLifecycle] = None,
        provider: typing.Optional[cdktf.TerraformProvider] = None,
    ) -> None:
        """
        :param scope: -
        :param id: -
        :param loadbalancer_id: 
        :param name: 
        :param port: 
        :param resource_group_name: 
        :param interval_in_seconds: 
        :param number_of_probes: 
        :param protocol: 
        :param request_path: 
        :param timeouts: timeouts block.
        :param count: 
        :param depends_on: 
        :param lifecycle: 
        :param provider: 
        """
        config = LbProbeConfig(
            loadbalancer_id=loadbalancer_id,
            name=name,
            port=port,
            resource_group_name=resource_group_name,
            interval_in_seconds=interval_in_seconds,
            number_of_probes=number_of_probes,
            protocol=protocol,
            request_path=request_path,
            timeouts=timeouts,
            count=count,
            depends_on=depends_on,
            lifecycle=lifecycle,
            provider=provider,
        )

        jsii.create(LbProbe, self, [scope, id, config])

    @jsii.member(jsii_name="synthesizeAttributes")
    def _synthesize_attributes(self) -> typing.Mapping[builtins.str, typing.Any]:
        return jsii.invoke(self, "synthesizeAttributes", [])

    @builtins.property # type: ignore
    @jsii.member(jsii_name="loadBalancerRules")
    def load_balancer_rules(self) -> typing.List[builtins.str]:
        return jsii.get(self, "loadBalancerRules")

    @builtins.property # type: ignore
    @jsii.member(jsii_name="loadbalancerId")
    def loadbalancer_id(self) -> builtins.str:
        return jsii.get(self, "loadbalancerId")

    @loadbalancer_id.setter # type: ignore
    def loadbalancer_id(self, value: builtins.str) -> None:
        jsii.set(self, "loadbalancerId", value)

    @builtins.property # type: ignore
    @jsii.member(jsii_name="name")
    def name(self) -> builtins.str:
        return jsii.get(self, "name")

    @name.setter # type: ignore
    def name(self, value: builtins.str) -> None:
        jsii.set(self, "name", value)

    @builtins.property # type: ignore
    @jsii.member(jsii_name="port")
    def port(self) -> jsii.Number:
        return jsii.get(self, "port")

    @port.setter # type: ignore
    def port(self, value: jsii.Number) -> None:
        jsii.set(self, "port", value)

    @builtins.property # type: ignore
    @jsii.member(jsii_name="resourceGroupName")
    def resource_group_name(self) -> builtins.str:
        return jsii.get(self, "resourceGroupName")

    @resource_group_name.setter # type: ignore
    def resource_group_name(self, value: builtins.str) -> None:
        jsii.set(self, "resourceGroupName", value)

    @builtins.property # type: ignore
    @jsii.member(jsii_name="id")
    def id(self) -> typing.Optional[builtins.str]:
        return jsii.get(self, "id")

    @id.setter # type: ignore
    def id(self, value: typing.Optional[builtins.str]) -> None:
        jsii.set(self, "id", value)

    @builtins.property # type: ignore
    @jsii.member(jsii_name="intervalInSeconds")
    def interval_in_seconds(self) -> typing.Optional[jsii.Number]:
        return jsii.get(self, "intervalInSeconds")

    @interval_in_seconds.setter # type: ignore
    def interval_in_seconds(self, value: typing.Optional[jsii.Number]) -> None:
        jsii.set(self, "intervalInSeconds", value)

    @builtins.property # type: ignore
    @jsii.member(jsii_name="numberOfProbes")
    def number_of_probes(self) -> typing.Optional[jsii.Number]:
        return jsii.get(self, "numberOfProbes")

    @number_of_probes.setter # type: ignore
    def number_of_probes(self, value: typing.Optional[jsii.Number]) -> None:
        jsii.set(self, "numberOfProbes", value)

    @builtins.property # type: ignore
    @jsii.member(jsii_name="protocol")
    def protocol(self) -> typing.Optional[builtins.str]:
        return jsii.get(self, "protocol")

    @protocol.setter # type: ignore
    def protocol(self, value: typing.Optional[builtins.str]) -> None:
        jsii.set(self, "protocol", value)

    @builtins.property # type: ignore
    @jsii.member(jsii_name="requestPath")
    def request_path(self) -> typing.Optional[builtins.str]:
        return jsii.get(self, "requestPath")

    @request_path.setter # type: ignore
    def request_path(self, value: typing.Optional[builtins.str]) -> None:
        jsii.set(self, "requestPath", value)

    @builtins.property # type: ignore
    @jsii.member(jsii_name="timeouts")
    def timeouts(self) -> typing.Optional["LbProbeTimeouts"]:
        return jsii.get(self, "timeouts")

    @timeouts.setter # type: ignore
    def timeouts(self, value: typing.Optional["LbProbeTimeouts"]) -> None:
        jsii.set(self, "timeouts", value)


@jsii.data_type(
    jsii_type="@cdktf/provider-azurerm.LbProbeConfig",
    jsii_struct_bases=[cdktf.TerraformMetaArguments],
    name_mapping={
        "count": "count",
        "depends_on": "dependsOn",
        "lifecycle": "lifecycle",
        "provider": "provider",
        "loadbalancer_id": "loadbalancerId",
        "name": "name",
        "port": "port",
        "resource_group_name": "resourceGroupName",
        "interval_in_seconds": "intervalInSeconds",
        "number_of_probes": "numberOfProbes",
        "protocol": "protocol",
        "request_path": "requestPath",
        "timeouts": "timeouts",
    },
)
class LbProbeConfig(cdktf.TerraformMetaArguments):
    def __init__(
        self,
        *,
        count: typing.Optional[jsii.Number] = None,
        depends_on: typing.Optional[typing.List[cdktf.TerraformResource]] = None,
        lifecycle: typing.Optional[cdktf.TerraformResourceLifecycle] = None,
        provider: typing.Optional[cdktf.TerraformProvider] = None,
        loadbalancer_id: builtins.str,
        name: builtins.str,
        port: jsii.Number,
        resource_group_name: builtins.str,
        interval_in_seconds: typing.Optional[jsii.Number] = None,
        number_of_probes: typing.Optional[jsii.Number] = None,
        protocol: typing.Optional[builtins.str] = None,
        request_path: typing.Optional[builtins.str] = None,
        timeouts: typing.Optional["LbProbeTimeouts"] = None,
    ) -> None:
        """
        :param count: 
        :param depends_on: 
        :param lifecycle: 
        :param provider: 
        :param loadbalancer_id: 
        :param name: 
        :param port: 
        :param resource_group_name: 
        :param interval_in_seconds: 
        :param number_of_probes: 
        :param protocol: 
        :param request_path: 
        :param timeouts: timeouts block.
        """
        if isinstance(lifecycle, dict):
            lifecycle = cdktf.TerraformResourceLifecycle(**lifecycle)
        if isinstance(timeouts, dict):
            timeouts = LbProbeTimeouts(**timeouts)
        self._values: typing.Dict[str, typing.Any] = {
            "loadbalancer_id": loadbalancer_id,
            "name": name,
            "port": port,
            "resource_group_name": resource_group_name,
        }
        if count is not None:
            self._values["count"] = count
        if depends_on is not None:
            self._values["depends_on"] = depends_on
        if lifecycle is not None:
            self._values["lifecycle"] = lifecycle
        if provider is not None:
            self._values["provider"] = provider
        if interval_in_seconds is not None:
            self._values["interval_in_seconds"] = interval_in_seconds
        if number_of_probes is not None:
            self._values["number_of_probes"] = number_of_probes
        if protocol is not None:
            self._values["protocol"] = protocol
        if request_path is not None:
            self._values["request_path"] = request_path
        if timeouts is not None:
            self._values["timeouts"] = timeouts

    @builtins.property
    def count(self) -> typing.Optional[jsii.Number]:
        """
        :stability: experimental
        """
        result = self._values.get("count")
        return result

    @builtins.property
    def depends_on(self) -> typing.Optional[typing.List[cdktf.TerraformResource]]:
        """
        :stability: experimental
        """
        result = self._values.get("depends_on")
        return result

    @builtins.property
    def lifecycle(self) -> typing.Optional[cdktf.TerraformResourceLifecycle]:
        """
        :stability: experimental
        """
        result = self._values.get("lifecycle")
        return result

    @builtins.property
    def provider(self) -> typing.Optional[cdktf.TerraformProvider]:
        """
        :stability: experimental
        """
        result = self._values.get("provider")
        return result

    @builtins.property
    def loadbalancer_id(self) -> builtins.str:
        result = self._values.get("loadbalancer_id")
        assert result is not None, "Required property 'loadbalancer_id' is missing"
        return result

    @builtins.property
    def name(self) -> builtins.str:
        result = self._values.get("name")
        assert result is not None, "Required property 'name' is missing"
        return result

    @builtins.property
    def port(self) -> jsii.Number:
        result = self._values.get("port")
        assert result is not None, "Required property 'port' is missing"
        return result

    @builtins.property
    def resource_group_name(self) -> builtins.str:
        result = self._values.get("resource_group_name")
        assert result is not None, "Required property 'resource_group_name' is missing"
        return result

    @builtins.property
    def interval_in_seconds(self) -> typing.Optional[jsii.Number]:
        result = self._values.get("interval_in_seconds")
        return result

    @builtins.property
    def number_of_probes(self) -> typing.Optional[jsii.Number]:
        result = self._values.get("number_of_probes")
        return result

    @builtins.property
    def protocol(self) -> typing.Optional[builtins.str]:
        result = self._values.get("protocol")
        return result

    @builtins.property
    def request_path(self) -> typing.Optional[builtins.str]:
        result = self._values.get("request_path")
        return result

    @builtins.property
    def timeouts(self) -> typing.Optional["LbProbeTimeouts"]:
        """timeouts block."""
        result = self._values.get("timeouts")
        return result

    def __eq__(self, rhs: typing.Any) -> builtins.bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs: typing.Any) -> builtins.bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return "LbProbeConfig(%s)" % ", ".join(
            k + "=" + repr(v) for k, v in self._values.items()
        )


@jsii.data_type(
    jsii_type="@cdktf/provider-azurerm.LbProbeTimeouts",
    jsii_struct_bases=[],
    name_mapping={
        "create": "create",
        "delete": "delete",
        "read": "read",
        "update": "update",
    },
)
class LbProbeTimeouts:
    def __init__(
        self,
        *,
        create: typing.Optional[builtins.str] = None,
        delete: typing.Optional[builtins.str] = None,
        read: typing.Optional[builtins.str] = None,
        update: typing.Optional[builtins.str] = None,
    ) -> None:
        """
        :param create: 
        :param delete: 
        :param read: 
        :param update: 
        """
        self._values: typing.Dict[str, typing.Any] = {}
        if create is not None:
            self._values["create"] = create
        if delete is not None:
            self._values["delete"] = delete
        if read is not None:
            self._values["read"] = read
        if update is not None:
            self._values["update"] = update

    @builtins.property
    def create(self) -> typing.Optional[builtins.str]:
        result = self._values.get("create")
        return result

    @builtins.property
    def delete(self) -> typing.Optional[builtins.str]:
        result = self._values.get("delete")
        return result

    @builtins.property
    def read(self) -> typing.Optional[builtins.str]:
        result = self._values.get("read")
        return result

    @builtins.property
    def update(self) -> typing.Optional[builtins.str]:
        result = self._values.get("update")
        return result

    def __eq__(self, rhs: typing.Any) -> builtins.bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs: typing.Any) -> builtins.bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return "LbProbeTimeouts(%s)" % ", ".join(
            k + "=" + repr(v) for k, v in self._values.items()
        )


class LbRule(
    cdktf.TerraformResource,
    metaclass=jsii.JSIIMeta,
    jsii_type="@cdktf/provider-azurerm.LbRule",
):
    def __init__(
        self,
        scope: constructs.Construct,
        id: builtins.str,
        *,
        backend_port: jsii.Number,
        frontend_ip_configuration_name: builtins.str,
        frontend_port: jsii.Number,
        loadbalancer_id: builtins.str,
        name: builtins.str,
        protocol: builtins.str,
        resource_group_name: builtins.str,
        backend_address_pool_id: typing.Optional[builtins.str] = None,
        disable_outbound_snat: typing.Optional[builtins.bool] = None,
        enable_floating_ip: typing.Optional[builtins.bool] = None,
        enable_tcp_reset: typing.Optional[builtins.bool] = None,
        idle_timeout_in_minutes: typing.Optional[jsii.Number] = None,
        load_distribution: typing.Optional[builtins.str] = None,
        probe_id: typing.Optional[builtins.str] = None,
        timeouts: typing.Optional["LbRuleTimeouts"] = None,
        count: typing.Optional[jsii.Number] = None,
        depends_on: typing.Optional[typing.List[cdktf.TerraformResource]] = None,
        lifecycle: typing.Optional[cdktf.TerraformResourceLifecycle] = None,
        provider: typing.Optional[cdktf.TerraformProvider] = None,
    ) -> None:
        """
        :param scope: -
        :param id: -
        :param backend_port: 
        :param frontend_ip_configuration_name: 
        :param frontend_port: 
        :param loadbalancer_id: 
        :param name: 
        :param protocol: 
        :param resource_group_name: 
        :param backend_address_pool_id: 
        :param disable_outbound_snat: 
        :param enable_floating_ip: 
        :param enable_tcp_reset: 
        :param idle_timeout_in_minutes: 
        :param load_distribution: 
        :param probe_id: 
        :param timeouts: timeouts block.
        :param count: 
        :param depends_on: 
        :param lifecycle: 
        :param provider: 
        """
        config = LbRuleConfig(
            backend_port=backend_port,
            frontend_ip_configuration_name=frontend_ip_configuration_name,
            frontend_port=frontend_port,
            loadbalancer_id=loadbalancer_id,
            name=name,
            protocol=protocol,
            resource_group_name=resource_group_name,
            backend_address_pool_id=backend_address_pool_id,
            disable_outbound_snat=disable_outbound_snat,
            enable_floating_ip=enable_floating_ip,
            enable_tcp_reset=enable_tcp_reset,
            idle_timeout_in_minutes=idle_timeout_in_minutes,
            load_distribution=load_distribution,
            probe_id=probe_id,
            timeouts=timeouts,
            count=count,
            depends_on=depends_on,
            lifecycle=lifecycle,
            provider=provider,
        )

        jsii.create(LbRule, self, [scope, id, config])

    @jsii.member(jsii_name="synthesizeAttributes")
    def _synthesize_attributes(self) -> typing.Mapping[builtins.str, typing.Any]:
        return jsii.invoke(self, "synthesizeAttributes", [])

    @builtins.property # type: ignore
    @jsii.member(jsii_name="frontendIpConfigurationId")
    def frontend_ip_configuration_id(self) -> builtins.str:
        return jsii.get(self, "frontendIpConfigurationId")

    @builtins.property # type: ignore
    @jsii.member(jsii_name="backendPort")
    def backend_port(self) -> jsii.Number:
        return jsii.get(self, "backendPort")

    @backend_port.setter # type: ignore
    def backend_port(self, value: jsii.Number) -> None:
        jsii.set(self, "backendPort", value)

    @builtins.property # type: ignore
    @jsii.member(jsii_name="frontendIpConfigurationName")
    def frontend_ip_configuration_name(self) -> builtins.str:
        return jsii.get(self, "frontendIpConfigurationName")

    @frontend_ip_configuration_name.setter # type: ignore
    def frontend_ip_configuration_name(self, value: builtins.str) -> None:
        jsii.set(self, "frontendIpConfigurationName", value)

    @builtins.property # type: ignore
    @jsii.member(jsii_name="frontendPort")
    def frontend_port(self) -> jsii.Number:
        return jsii.get(self, "frontendPort")

    @frontend_port.setter # type: ignore
    def frontend_port(self, value: jsii.Number) -> None:
        jsii.set(self, "frontendPort", value)

    @builtins.property # type: ignore
    @jsii.member(jsii_name="loadbalancerId")
    def loadbalancer_id(self) -> builtins.str:
        return jsii.get(self, "loadbalancerId")

    @loadbalancer_id.setter # type: ignore
    def loadbalancer_id(self, value: builtins.str) -> None:
        jsii.set(self, "loadbalancerId", value)

    @builtins.property # type: ignore
    @jsii.member(jsii_name="name")
    def name(self) -> builtins.str:
        return jsii.get(self, "name")

    @name.setter # type: ignore
    def name(self, value: builtins.str) -> None:
        jsii.set(self, "name", value)

    @builtins.property # type: ignore
    @jsii.member(jsii_name="protocol")
    def protocol(self) -> builtins.str:
        return jsii.get(self, "protocol")

    @protocol.setter # type: ignore
    def protocol(self, value: builtins.str) -> None:
        jsii.set(self, "protocol", value)

    @builtins.property # type: ignore
    @jsii.member(jsii_name="resourceGroupName")
    def resource_group_name(self) -> builtins.str:
        return jsii.get(self, "resourceGroupName")

    @resource_group_name.setter # type: ignore
    def resource_group_name(self, value: builtins.str) -> None:
        jsii.set(self, "resourceGroupName", value)

    @builtins.property # type: ignore
    @jsii.member(jsii_name="backendAddressPoolId")
    def backend_address_pool_id(self) -> typing.Optional[builtins.str]:
        return jsii.get(self, "backendAddressPoolId")

    @backend_address_pool_id.setter # type: ignore
    def backend_address_pool_id(self, value: typing.Optional[builtins.str]) -> None:
        jsii.set(self, "backendAddressPoolId", value)

    @builtins.property # type: ignore
    @jsii.member(jsii_name="disableOutboundSnat")
    def disable_outbound_snat(self) -> typing.Optional[builtins.bool]:
        return jsii.get(self, "disableOutboundSnat")

    @disable_outbound_snat.setter # type: ignore
    def disable_outbound_snat(self, value: typing.Optional[builtins.bool]) -> None:
        jsii.set(self, "disableOutboundSnat", value)

    @builtins.property # type: ignore
    @jsii.member(jsii_name="enableFloatingIp")
    def enable_floating_ip(self) -> typing.Optional[builtins.bool]:
        return jsii.get(self, "enableFloatingIp")

    @enable_floating_ip.setter # type: ignore
    def enable_floating_ip(self, value: typing.Optional[builtins.bool]) -> None:
        jsii.set(self, "enableFloatingIp", value)

    @builtins.property # type: ignore
    @jsii.member(jsii_name="enableTcpReset")
    def enable_tcp_reset(self) -> typing.Optional[builtins.bool]:
        return jsii.get(self, "enableTcpReset")

    @enable_tcp_reset.setter # type: ignore
    def enable_tcp_reset(self, value: typing.Optional[builtins.bool]) -> None:
        jsii.set(self, "enableTcpReset", value)

    @builtins.property # type: ignore
    @jsii.member(jsii_name="id")
    def id(self) -> typing.Optional[builtins.str]:
        return jsii.get(self, "id")

    @id.setter # type: ignore
    def id(self, value: typing.Optional[builtins.str]) -> None:
        jsii.set(self, "id", value)

    @builtins.property # type: ignore
    @jsii.member(jsii_name="idleTimeoutInMinutes")
    def idle_timeout_in_minutes(self) -> typing.Optional[jsii.Number]:
        return jsii.get(self, "idleTimeoutInMinutes")

    @idle_timeout_in_minutes.setter # type: ignore
    def idle_timeout_in_minutes(self, value: typing.Optional[jsii.Number]) -> None:
        jsii.set(self, "idleTimeoutInMinutes", value)

    @builtins.property # type: ignore
    @jsii.member(jsii_name="loadDistribution")
    def load_distribution(self) -> typing.Optional[builtins.str]:
        return jsii.get(self, "loadDistribution")

    @load_distribution.setter # type: ignore
    def load_distribution(self, value: typing.Optional[builtins.str]) -> None:
        jsii.set(self, "loadDistribution", value)

    @builtins.property # type: ignore
    @jsii.member(jsii_name="probeId")
    def probe_id(self) -> typing.Optional[builtins.str]:
        return jsii.get(self, "probeId")

    @probe_id.setter # type: ignore
    def probe_id(self, value: typing.Optional[builtins.str]) -> None:
        jsii.set(self, "probeId", value)

    @builtins.property # type: ignore
    @jsii.member(jsii_name="timeouts")
    def timeouts(self) -> typing.Optional["LbRuleTimeouts"]:
        return jsii.get(self, "timeouts")

    @timeouts.setter # type: ignore
    def timeouts(self, value: typing.Optional["LbRuleTimeouts"]) -> None:
        jsii.set(self, "timeouts", value)


@jsii.data_type(
    jsii_type="@cdktf/provider-azurerm.LbRuleConfig",
    jsii_struct_bases=[cdktf.TerraformMetaArguments],
    name_mapping={
        "count": "count",
        "depends_on": "dependsOn",
        "lifecycle": "lifecycle",
        "provider": "provider",
        "backend_port": "backendPort",
        "frontend_ip_configuration_name": "frontendIpConfigurationName",
        "frontend_port": "frontendPort",
        "loadbalancer_id": "loadbalancerId",
        "name": "name",
        "protocol": "protocol",
        "resource_group_name": "resourceGroupName",
        "backend_address_pool_id": "backendAddressPoolId",
        "disable_outbound_snat": "disableOutboundSnat",
        "enable_floating_ip": "enableFloatingIp",
        "enable_tcp_reset": "enableTcpReset",
        "idle_timeout_in_minutes": "idleTimeoutInMinutes",
        "load_distribution": "loadDistribution",
        "probe_id": "probeId",
        "timeouts": "timeouts",
    },
)
class LbRuleConfig(cdktf.TerraformMetaArguments):
    def __init__(
        self,
        *,
        count: typing.Optional[jsii.Number] = None,
        depends_on: typing.Optional[typing.List[cdktf.TerraformResource]] = None,
        lifecycle: typing.Optional[cdktf.TerraformResourceLifecycle] = None,
        provider: typing.Optional[cdktf.TerraformProvider] = None,
        backend_port: jsii.Number,
        frontend_ip_configuration_name: builtins.str,
        frontend_port: jsii.Number,
        loadbalancer_id: builtins.str,
        name: builtins.str,
        protocol: builtins.str,
        resource_group_name: builtins.str,
        backend_address_pool_id: typing.Optional[builtins.str] = None,
        disable_outbound_snat: typing.Optional[builtins.bool] = None,
        enable_floating_ip: typing.Optional[builtins.bool] = None,
        enable_tcp_reset: typing.Optional[builtins.bool] = None,
        idle_timeout_in_minutes: typing.Optional[jsii.Number] = None,
        load_distribution: typing.Optional[builtins.str] = None,
        probe_id: typing.Optional[builtins.str] = None,
        timeouts: typing.Optional["LbRuleTimeouts"] = None,
    ) -> None:
        """
        :param count: 
        :param depends_on: 
        :param lifecycle: 
        :param provider: 
        :param backend_port: 
        :param frontend_ip_configuration_name: 
        :param frontend_port: 
        :param loadbalancer_id: 
        :param name: 
        :param protocol: 
        :param resource_group_name: 
        :param backend_address_pool_id: 
        :param disable_outbound_snat: 
        :param enable_floating_ip: 
        :param enable_tcp_reset: 
        :param idle_timeout_in_minutes: 
        :param load_distribution: 
        :param probe_id: 
        :param timeouts: timeouts block.
        """
        if isinstance(lifecycle, dict):
            lifecycle = cdktf.TerraformResourceLifecycle(**lifecycle)
        if isinstance(timeouts, dict):
            timeouts = LbRuleTimeouts(**timeouts)
        self._values: typing.Dict[str, typing.Any] = {
            "backend_port": backend_port,
            "frontend_ip_configuration_name": frontend_ip_configuration_name,
            "frontend_port": frontend_port,
            "loadbalancer_id": loadbalancer_id,
            "name": name,
            "protocol": protocol,
            "resource_group_name": resource_group_name,
        }
        if count is not None:
            self._values["count"] = count
        if depends_on is not None:
            self._values["depends_on"] = depends_on
        if lifecycle is not None:
            self._values["lifecycle"] = lifecycle
        if provider is not None:
            self._values["provider"] = provider
        if backend_address_pool_id is not None:
            self._values["backend_address_pool_id"] = backend_address_pool_id
        if disable_outbound_snat is not None:
            self._values["disable_outbound_snat"] = disable_outbound_snat
        if enable_floating_ip is not None:
            self._values["enable_floating_ip"] = enable_floating_ip
        if enable_tcp_reset is not None:
            self._values["enable_tcp_reset"] = enable_tcp_reset
        if idle_timeout_in_minutes is not None:
            self._values["idle_timeout_in_minutes"] = idle_timeout_in_minutes
        if load_distribution is not None:
            self._values["load_distribution"] = load_distribution
        if probe_id is not None:
            self._values["probe_id"] = probe_id
        if timeouts is not None:
            self._values["timeouts"] = timeouts

    @builtins.property
    def count(self) -> typing.Optional[jsii.Number]:
        """
        :stability: experimental
        """
        result = self._values.get("count")
        return result

    @builtins.property
    def depends_on(self) -> typing.Optional[typing.List[cdktf.TerraformResource]]:
        """
        :stability: experimental
        """
        result = self._values.get("depends_on")
        return result

    @builtins.property
    def lifecycle(self) -> typing.Optional[cdktf.TerraformResourceLifecycle]:
        """
        :stability: experimental
        """
        result = self._values.get("lifecycle")
        return result

    @builtins.property
    def provider(self) -> typing.Optional[cdktf.TerraformProvider]:
        """
        :stability: experimental
        """
        result = self._values.get("provider")
        return result

    @builtins.property
    def backend_port(self) -> jsii.Number:
        result = self._values.get("backend_port")
        assert result is not None, "Required property 'backend_port' is missing"
        return result

    @builtins.property
    def frontend_ip_configuration_name(self) -> builtins.str:
        result = self._values.get("frontend_ip_configuration_name")
        assert result is not None, "Required property 'frontend_ip_configuration_name' is missing"
        return result

    @builtins.property
    def frontend_port(self) -> jsii.Number:
        result = self._values.get("frontend_port")
        assert result is not None, "Required property 'frontend_port' is missing"
        return result

    @builtins.property
    def loadbalancer_id(self) -> builtins.str:
        result = self._values.get("loadbalancer_id")
        assert result is not None, "Required property 'loadbalancer_id' is missing"
        return result

    @builtins.property
    def name(self) -> builtins.str:
        result = self._values.get("name")
        assert result is not None, "Required property 'name' is missing"
        return result

    @builtins.property
    def protocol(self) -> builtins.str:
        result = self._values.get("protocol")
        assert result is not None, "Required property 'protocol' is missing"
        return result

    @builtins.property
    def resource_group_name(self) -> builtins.str:
        result = self._values.get("resource_group_name")
        assert result is not None, "Required property 'resource_group_name' is missing"
        return result

    @builtins.property
    def backend_address_pool_id(self) -> typing.Optional[builtins.str]:
        result = self._values.get("backend_address_pool_id")
        return result

    @builtins.property
    def disable_outbound_snat(self) -> typing.Optional[builtins.bool]:
        result = self._values.get("disable_outbound_snat")
        return result

    @builtins.property
    def enable_floating_ip(self) -> typing.Optional[builtins.bool]:
        result = self._values.get("enable_floating_ip")
        return result

    @builtins.property
    def enable_tcp_reset(self) -> typing.Optional[builtins.bool]:
        result = self._values.get("enable_tcp_reset")
        return result

    @builtins.property
    def idle_timeout_in_minutes(self) -> typing.Optional[jsii.Number]:
        result = self._values.get("idle_timeout_in_minutes")
        return result

    @builtins.property
    def load_distribution(self) -> typing.Optional[builtins.str]:
        result = self._values.get("load_distribution")
        return result

    @builtins.property
    def probe_id(self) -> typing.Optional[builtins.str]:
        result = self._values.get("probe_id")
        return result

    @builtins.property
    def timeouts(self) -> typing.Optional["LbRuleTimeouts"]:
        """timeouts block."""
        result = self._values.get("timeouts")
        return result

    def __eq__(self, rhs: typing.Any) -> builtins.bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs: typing.Any) -> builtins.bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return "LbRuleConfig(%s)" % ", ".join(
            k + "=" + repr(v) for k, v in self._values.items()
        )


@jsii.data_type(
    jsii_type="@cdktf/provider-azurerm.LbRuleTimeouts",
    jsii_struct_bases=[],
    name_mapping={
        "create": "create",
        "delete": "delete",
        "read": "read",
        "update": "update",
    },
)
class LbRuleTimeouts:
    def __init__(
        self,
        *,
        create: typing.Optional[builtins.str] = None,
        delete: typing.Optional[builtins.str] = None,
        read: typing.Optional[builtins.str] = None,
        update: typing.Optional[builtins.str] = None,
    ) -> None:
        """
        :param create: 
        :param delete: 
        :param read: 
        :param update: 
        """
        self._values: typing.Dict[str, typing.Any] = {}
        if create is not None:
            self._values["create"] = create
        if delete is not None:
            self._values["delete"] = delete
        if read is not None:
            self._values["read"] = read
        if update is not None:
            self._values["update"] = update

    @builtins.property
    def create(self) -> typing.Optional[builtins.str]:
        result = self._values.get("create")
        return result

    @builtins.property
    def delete(self) -> typing.Optional[builtins.str]:
        result = self._values.get("delete")
        return result

    @builtins.property
    def read(self) -> typing.Optional[builtins.str]:
        result = self._values.get("read")
        return result

    @builtins.property
    def update(self) -> typing.Optional[builtins.str]:
        result = self._values.get("update")
        return result

    def __eq__(self, rhs: typing.Any) -> builtins.bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs: typing.Any) -> builtins.bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return "LbRuleTimeouts(%s)" % ", ".join(
            k + "=" + repr(v) for k, v in self._values.items()
        )


@jsii.data_type(
    jsii_type="@cdktf/provider-azurerm.LbTimeouts",
    jsii_struct_bases=[],
    name_mapping={
        "create": "create",
        "delete": "delete",
        "read": "read",
        "update": "update",
    },
)
class LbTimeouts:
    def __init__(
        self,
        *,
        create: typing.Optional[builtins.str] = None,
        delete: typing.Optional[builtins.str] = None,
        read: typing.Optional[builtins.str] = None,
        update: typing.Optional[builtins.str] = None,
    ) -> None:
        """
        :param create: 
        :param delete: 
        :param read: 
        :param update: 
        """
        self._values: typing.Dict[str, typing.Any] = {}
        if create is not None:
            self._values["create"] = create
        if delete is not None:
            self._values["delete"] = delete
        if read is not None:
            self._values["read"] = read
        if update is not None:
            self._values["update"] = update

    @builtins.property
    def create(self) -> typing.Optional[builtins.str]:
        result = self._values.get("create")
        return result

    @builtins.property
    def delete(self) -> typing.Optional[builtins.str]:
        result = self._values.get("delete")
        return result

    @builtins.property
    def read(self) -> typing.Optional[builtins.str]:
        result = self._values.get("read")
        return result

    @builtins.property
    def update(self) -> typing.Optional[builtins.str]:
        result = self._values.get("update")
        return result

    def __eq__(self, rhs: typing.Any) -> builtins.bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs: typing.Any) -> builtins.bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return "LbTimeouts(%s)" % ", ".join(
            k + "=" + repr(v) for k, v in self._values.items()
        )


class LinuxVirtualMachine(
    cdktf.TerraformResource,
    metaclass=jsii.JSIIMeta,
    jsii_type="@cdktf/provider-azurerm.LinuxVirtualMachine",
):
    def __init__(
        self,
        scope: constructs.Construct,
        id: builtins.str,
        *,
        admin_username: builtins.str,
        location: builtins.str,
        name: builtins.str,
        network_interface_ids: typing.List[builtins.str],
        os_disk: typing.List["LinuxVirtualMachineOsDisk"],
        resource_group_name: builtins.str,
        size: builtins.str,
        additional_capabilities: typing.Optional[typing.List["LinuxVirtualMachineAdditionalCapabilities"]] = None,
        admin_password: typing.Optional[builtins.str] = None,
        admin_ssh_key: typing.Optional[typing.List["LinuxVirtualMachineAdminSshKey"]] = None,
        allow_extension_operations: typing.Optional[builtins.bool] = None,
        availability_set_id: typing.Optional[builtins.str] = None,
        boot_diagnostics: typing.Optional[typing.List["LinuxVirtualMachineBootDiagnostics"]] = None,
        computer_name: typing.Optional[builtins.str] = None,
        custom_data: typing.Optional[builtins.str] = None,
        dedicated_host_id: typing.Optional[builtins.str] = None,
        disable_password_authentication: typing.Optional[builtins.bool] = None,
        eviction_policy: typing.Optional[builtins.str] = None,
        identity: typing.Optional[typing.List["LinuxVirtualMachineIdentity"]] = None,
        max_bid_price: typing.Optional[jsii.Number] = None,
        plan: typing.Optional[typing.List["LinuxVirtualMachinePlan"]] = None,
        priority: typing.Optional[builtins.str] = None,
        provision_vm_agent: typing.Optional[builtins.bool] = None,
        proximity_placement_group_id: typing.Optional[builtins.str] = None,
        secret: typing.Optional[typing.List["LinuxVirtualMachineSecret"]] = None,
        source_image_id: typing.Optional[builtins.str] = None,
        source_image_reference: typing.Optional[typing.List["LinuxVirtualMachineSourceImageReference"]] = None,
        tags: typing.Optional[typing.Mapping[builtins.str, builtins.str]] = None,
        timeouts: typing.Optional["LinuxVirtualMachineTimeouts"] = None,
        zone: typing.Optional[builtins.str] = None,
        count: typing.Optional[jsii.Number] = None,
        depends_on: typing.Optional[typing.List[cdktf.TerraformResource]] = None,
        lifecycle: typing.Optional[cdktf.TerraformResourceLifecycle] = None,
        provider: typing.Optional[cdktf.TerraformProvider] = None,
    ) -> None:
        """
        :param scope: -
        :param id: -
        :param admin_username: 
        :param location: 
        :param name: 
        :param network_interface_ids: 
        :param os_disk: os_disk block.
        :param resource_group_name: 
        :param size: 
        :param additional_capabilities: additional_capabilities block.
        :param admin_password: 
        :param admin_ssh_key: admin_ssh_key block.
        :param allow_extension_operations: 
        :param availability_set_id: 
        :param boot_diagnostics: boot_diagnostics block.
        :param computer_name: 
        :param custom_data: 
        :param dedicated_host_id: 
        :param disable_password_authentication: 
        :param eviction_policy: 
        :param identity: identity block.
        :param max_bid_price: 
        :param plan: plan block.
        :param priority: 
        :param provision_vm_agent: 
        :param proximity_placement_group_id: 
        :param secret: secret block.
        :param source_image_id: 
        :param source_image_reference: source_image_reference block.
        :param tags: 
        :param timeouts: timeouts block.
        :param zone: 
        :param count: 
        :param depends_on: 
        :param lifecycle: 
        :param provider: 
        """
        config = LinuxVirtualMachineConfig(
            admin_username=admin_username,
            location=location,
            name=name,
            network_interface_ids=network_interface_ids,
            os_disk=os_disk,
            resource_group_name=resource_group_name,
            size=size,
            additional_capabilities=additional_capabilities,
            admin_password=admin_password,
            admin_ssh_key=admin_ssh_key,
            allow_extension_operations=allow_extension_operations,
            availability_set_id=availability_set_id,
            boot_diagnostics=boot_diagnostics,
            computer_name=computer_name,
            custom_data=custom_data,
            dedicated_host_id=dedicated_host_id,
            disable_password_authentication=disable_password_authentication,
            eviction_policy=eviction_policy,
            identity=identity,
            max_bid_price=max_bid_price,
            plan=plan,
            priority=priority,
            provision_vm_agent=provision_vm_agent,
            proximity_placement_group_id=proximity_placement_group_id,
            secret=secret,
            source_image_id=source_image_id,
            source_image_reference=source_image_reference,
            tags=tags,
            timeouts=timeouts,
            zone=zone,
            count=count,
            depends_on=depends_on,
            lifecycle=lifecycle,
            provider=provider,
        )

        jsii.create(LinuxVirtualMachine, self, [scope, id, config])

    @jsii.member(jsii_name="synthesizeAttributes")
    def _synthesize_attributes(self) -> typing.Mapping[builtins.str, typing.Any]:
        return jsii.invoke(self, "synthesizeAttributes", [])

    @builtins.property # type: ignore
    @jsii.member(jsii_name="privateIpAddress")
    def private_ip_address(self) -> builtins.str:
        return jsii.get(self, "privateIpAddress")

    @builtins.property # type: ignore
    @jsii.member(jsii_name="privateIpAddresses")
    def private_ip_addresses(self) -> typing.List[builtins.str]:
        return jsii.get(self, "privateIpAddresses")

    @builtins.property # type: ignore
    @jsii.member(jsii_name="publicIpAddress")
    def public_ip_address(self) -> builtins.str:
        return jsii.get(self, "publicIpAddress")

    @builtins.property # type: ignore
    @jsii.member(jsii_name="publicIpAddresses")
    def public_ip_addresses(self) -> typing.List[builtins.str]:
        return jsii.get(self, "publicIpAddresses")

    @builtins.property # type: ignore
    @jsii.member(jsii_name="virtualMachineId")
    def virtual_machine_id(self) -> builtins.str:
        return jsii.get(self, "virtualMachineId")

    @builtins.property # type: ignore
    @jsii.member(jsii_name="adminUsername")
    def admin_username(self) -> builtins.str:
        return jsii.get(self, "adminUsername")

    @admin_username.setter # type: ignore
    def admin_username(self, value: builtins.str) -> None:
        jsii.set(self, "adminUsername", value)

    @builtins.property # type: ignore
    @jsii.member(jsii_name="location")
    def location(self) -> builtins.str:
        return jsii.get(self, "location")

    @location.setter # type: ignore
    def location(self, value: builtins.str) -> None:
        jsii.set(self, "location", value)

    @builtins.property # type: ignore
    @jsii.member(jsii_name="name")
    def name(self) -> builtins.str:
        return jsii.get(self, "name")

    @name.setter # type: ignore
    def name(self, value: builtins.str) -> None:
        jsii.set(self, "name", value)

    @builtins.property # type: ignore
    @jsii.member(jsii_name="networkInterfaceIds")
    def network_interface_ids(self) -> typing.List[builtins.str]:
        return jsii.get(self, "networkInterfaceIds")

    @network_interface_ids.setter # type: ignore
    def network_interface_ids(self, value: typing.List[builtins.str]) -> None:
        jsii.set(self, "networkInterfaceIds", value)

    @builtins.property # type: ignore
    @jsii.member(jsii_name="osDisk")
    def os_disk(self) -> typing.List["LinuxVirtualMachineOsDisk"]:
        return jsii.get(self, "osDisk")

    @os_disk.setter # type: ignore
    def os_disk(self, value: typing.List["LinuxVirtualMachineOsDisk"]) -> None:
        jsii.set(self, "osDisk", value)

    @builtins.property # type: ignore
    @jsii.member(jsii_name="resourceGroupName")
    def resource_group_name(self) -> builtins.str:
        return jsii.get(self, "resourceGroupName")

    @resource_group_name.setter # type: ignore
    def resource_group_name(self, value: builtins.str) -> None:
        jsii.set(self, "resourceGroupName", value)

    @builtins.property # type: ignore
    @jsii.member(jsii_name="size")
    def size(self) -> builtins.str:
        return jsii.get(self, "size")

    @size.setter # type: ignore
    def size(self, value: builtins.str) -> None:
        jsii.set(self, "size", value)

    @builtins.property # type: ignore
    @jsii.member(jsii_name="additionalCapabilities")
    def additional_capabilities(
        self,
    ) -> typing.Optional[typing.List["LinuxVirtualMachineAdditionalCapabilities"]]:
        return jsii.get(self, "additionalCapabilities")

    @additional_capabilities.setter # type: ignore
    def additional_capabilities(
        self,
        value: typing.Optional[typing.List["LinuxVirtualMachineAdditionalCapabilities"]],
    ) -> None:
        jsii.set(self, "additionalCapabilities", value)

    @builtins.property # type: ignore
    @jsii.member(jsii_name="adminPassword")
    def admin_password(self) -> typing.Optional[builtins.str]:
        return jsii.get(self, "adminPassword")

    @admin_password.setter # type: ignore
    def admin_password(self, value: typing.Optional[builtins.str]) -> None:
        jsii.set(self, "adminPassword", value)

    @builtins.property # type: ignore
    @jsii.member(jsii_name="adminSshKey")
    def admin_ssh_key(
        self,
    ) -> typing.Optional[typing.List["LinuxVirtualMachineAdminSshKey"]]:
        return jsii.get(self, "adminSshKey")

    @admin_ssh_key.setter # type: ignore
    def admin_ssh_key(
        self,
        value: typing.Optional[typing.List["LinuxVirtualMachineAdminSshKey"]],
    ) -> None:
        jsii.set(self, "adminSshKey", value)

    @builtins.property # type: ignore
    @jsii.member(jsii_name="allowExtensionOperations")
    def allow_extension_operations(self) -> typing.Optional[builtins.bool]:
        return jsii.get(self, "allowExtensionOperations")

    @allow_extension_operations.setter # type: ignore
    def allow_extension_operations(self, value: typing.Optional[builtins.bool]) -> None:
        jsii.set(self, "allowExtensionOperations", value)

    @builtins.property # type: ignore
    @jsii.member(jsii_name="availabilitySetId")
    def availability_set_id(self) -> typing.Optional[builtins.str]:
        return jsii.get(self, "availabilitySetId")

    @availability_set_id.setter # type: ignore
    def availability_set_id(self, value: typing.Optional[builtins.str]) -> None:
        jsii.set(self, "availabilitySetId", value)

    @builtins.property # type: ignore
    @jsii.member(jsii_name="bootDiagnostics")
    def boot_diagnostics(
        self,
    ) -> typing.Optional[typing.List["LinuxVirtualMachineBootDiagnostics"]]:
        return jsii.get(self, "bootDiagnostics")

    @boot_diagnostics.setter # type: ignore
    def boot_diagnostics(
        self,
        value: typing.Optional[typing.List["LinuxVirtualMachineBootDiagnostics"]],
    ) -> None:
        jsii.set(self, "bootDiagnostics", value)

    @builtins.property # type: ignore
    @jsii.member(jsii_name="computerName")
    def computer_name(self) -> typing.Optional[builtins.str]:
        return jsii.get(self, "computerName")

    @computer_name.setter # type: ignore
    def computer_name(self, value: typing.Optional[builtins.str]) -> None:
        jsii.set(self, "computerName", value)

    @builtins.property # type: ignore
    @jsii.member(jsii_name="customData")
    def custom_data(self) -> typing.Optional[builtins.str]:
        return jsii.get(self, "customData")

    @custom_data.setter # type: ignore
    def custom_data(self, value: typing.Optional[builtins.str]) -> None:
        jsii.set(self, "customData", value)

    @builtins.property # type: ignore
    @jsii.member(jsii_name="dedicatedHostId")
    def dedicated_host_id(self) -> typing.Optional[builtins.str]:
        return jsii.get(self, "dedicatedHostId")

    @dedicated_host_id.setter # type: ignore
    def dedicated_host_id(self, value: typing.Optional[builtins.str]) -> None:
        jsii.set(self, "dedicatedHostId", value)

    @builtins.property # type: ignore
    @jsii.member(jsii_name="disablePasswordAuthentication")
    def disable_password_authentication(self) -> typing.Optional[builtins.bool]:
        return jsii.get(self, "disablePasswordAuthentication")

    @disable_password_authentication.setter # type: ignore
    def disable_password_authentication(
        self,
        value: typing.Optional[builtins.bool],
    ) -> None:
        jsii.set(self, "disablePasswordAuthentication", value)

    @builtins.property # type: ignore
    @jsii.member(jsii_name="evictionPolicy")
    def eviction_policy(self) -> typing.Optional[builtins.str]:
        return jsii.get(self, "evictionPolicy")

    @eviction_policy.setter # type: ignore
    def eviction_policy(self, value: typing.Optional[builtins.str]) -> None:
        jsii.set(self, "evictionPolicy", value)

    @builtins.property # type: ignore
    @jsii.member(jsii_name="id")
    def id(self) -> typing.Optional[builtins.str]:
        return jsii.get(self, "id")

    @id.setter # type: ignore
    def id(self, value: typing.Optional[builtins.str]) -> None:
        jsii.set(self, "id", value)

    @builtins.property # type: ignore
    @jsii.member(jsii_name="identity")
    def identity(self) -> typing.Optional[typing.List["LinuxVirtualMachineIdentity"]]:
        return jsii.get(self, "identity")

    @identity.setter # type: ignore
    def identity(
        self,
        value: typing.Optional[typing.List["LinuxVirtualMachineIdentity"]],
    ) -> None:
        jsii.set(self, "identity", value)

    @builtins.property # type: ignore
    @jsii.member(jsii_name="maxBidPrice")
    def max_bid_price(self) -> typing.Optional[jsii.Number]:
        return jsii.get(self, "maxBidPrice")

    @max_bid_price.setter # type: ignore
    def max_bid_price(self, value: typing.Optional[jsii.Number]) -> None:
        jsii.set(self, "maxBidPrice", value)

    @builtins.property # type: ignore
    @jsii.member(jsii_name="plan")
    def plan(self) -> typing.Optional[typing.List["LinuxVirtualMachinePlan"]]:
        return jsii.get(self, "plan")

    @plan.setter # type: ignore
    def plan(
        self,
        value: typing.Optional[typing.List["LinuxVirtualMachinePlan"]],
    ) -> None:
        jsii.set(self, "plan", value)

    @builtins.property # type: ignore
    @jsii.member(jsii_name="priority")
    def priority(self) -> typing.Optional[builtins.str]:
        return jsii.get(self, "priority")

    @priority.setter # type: ignore
    def priority(self, value: typing.Optional[builtins.str]) -> None:
        jsii.set(self, "priority", value)

    @builtins.property # type: ignore
    @jsii.member(jsii_name="provisionVmAgent")
    def provision_vm_agent(self) -> typing.Optional[builtins.bool]:
        return jsii.get(self, "provisionVmAgent")

    @provision_vm_agent.setter # type: ignore
    def provision_vm_agent(self, value: typing.Optional[builtins.bool]) -> None:
        jsii.set(self, "provisionVmAgent", value)

    @builtins.property # type: ignore
    @jsii.member(jsii_name="proximityPlacementGroupId")
    def proximity_placement_group_id(self) -> typing.Optional[builtins.str]:
        return jsii.get(self, "proximityPlacementGroupId")

    @proximity_placement_group_id.setter # type: ignore
    def proximity_placement_group_id(
        self,
        value: typing.Optional[builtins.str],
    ) -> None:
        jsii.set(self, "proximityPlacementGroupId", value)

    @builtins.property # type: ignore
    @jsii.member(jsii_name="secret")
    def secret(self) -> typing.Optional[typing.List["LinuxVirtualMachineSecret"]]:
        return jsii.get(self, "secret")

    @secret.setter # type: ignore
    def secret(
        self,
        value: typing.Optional[typing.List["LinuxVirtualMachineSecret"]],
    ) -> None:
        jsii.set(self, "secret", value)

    @builtins.property # type: ignore
    @jsii.member(jsii_name="sourceImageId")
    def source_image_id(self) -> typing.Optional[builtins.str]:
        return jsii.get(self, "sourceImageId")

    @source_image_id.setter # type: ignore
    def source_image_id(self, value: typing.Optional[builtins.str]) -> None:
        jsii.set(self, "sourceImageId", value)

    @builtins.property # type: ignore
    @jsii.member(jsii_name="sourceImageReference")
    def source_image_reference(
        self,
    ) -> typing.Optional[typing.List["LinuxVirtualMachineSourceImageReference"]]:
        return jsii.get(self, "sourceImageReference")

    @source_image_reference.setter # type: ignore
    def source_image_reference(
        self,
        value: typing.Optional[typing.List["LinuxVirtualMachineSourceImageReference"]],
    ) -> None:
        jsii.set(self, "sourceImageReference", value)

    @builtins.property # type: ignore
    @jsii.member(jsii_name="tags")
    def tags(self) -> typing.Optional[typing.Mapping[builtins.str, builtins.str]]:
        return jsii.get(self, "tags")

    @tags.setter # type: ignore
    def tags(
        self,
        value: typing.Optional[typing.Mapping[builtins.str, builtins.str]],
    ) -> None:
        jsii.set(self, "tags", value)

    @builtins.property # type: ignore
    @jsii.member(jsii_name="timeouts")
    def timeouts(self) -> typing.Optional["LinuxVirtualMachineTimeouts"]:
        return jsii.get(self, "timeouts")

    @timeouts.setter # type: ignore
    def timeouts(self, value: typing.Optional["LinuxVirtualMachineTimeouts"]) -> None:
        jsii.set(self, "timeouts", value)

    @builtins.property # type: ignore
    @jsii.member(jsii_name="zone")
    def zone(self) -> typing.Optional[builtins.str]:
        return jsii.get(self, "zone")

    @zone.setter # type: ignore
    def zone(self, value: typing.Optional[builtins.str]) -> None:
        jsii.set(self, "zone", value)


@jsii.data_type(
    jsii_type="@cdktf/provider-azurerm.LinuxVirtualMachineAdditionalCapabilities",
    jsii_struct_bases=[],
    name_mapping={"ultra_ssd_enabled": "ultraSsdEnabled"},
)
class LinuxVirtualMachineAdditionalCapabilities:
    def __init__(
        self,
        *,
        ultra_ssd_enabled: typing.Optional[builtins.bool] = None,
    ) -> None:
        """
        :param ultra_ssd_enabled: 
        """
        self._values: typing.Dict[str, typing.Any] = {}
        if ultra_ssd_enabled is not None:
            self._values["ultra_ssd_enabled"] = ultra_ssd_enabled

    @builtins.property
    def ultra_ssd_enabled(self) -> typing.Optional[builtins.bool]:
        result = self._values.get("ultra_ssd_enabled")
        return result

    def __eq__(self, rhs: typing.Any) -> builtins.bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs: typing.Any) -> builtins.bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return "LinuxVirtualMachineAdditionalCapabilities(%s)" % ", ".join(
            k + "=" + repr(v) for k, v in self._values.items()
        )


@jsii.data_type(
    jsii_type="@cdktf/provider-azurerm.LinuxVirtualMachineAdminSshKey",
    jsii_struct_bases=[],
    name_mapping={"public_key": "publicKey", "username": "username"},
)
class LinuxVirtualMachineAdminSshKey:
    def __init__(self, *, public_key: builtins.str, username: builtins.str) -> None:
        """
        :param public_key: 
        :param username: 
        """
        self._values: typing.Dict[str, typing.Any] = {
            "public_key": public_key,
            "username": username,
        }

    @builtins.property
    def public_key(self) -> builtins.str:
        result = self._values.get("public_key")
        assert result is not None, "Required property 'public_key' is missing"
        return result

    @builtins.property
    def username(self) -> builtins.str:
        result = self._values.get("username")
        assert result is not None, "Required property 'username' is missing"
        return result

    def __eq__(self, rhs: typing.Any) -> builtins.bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs: typing.Any) -> builtins.bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return "LinuxVirtualMachineAdminSshKey(%s)" % ", ".join(
            k + "=" + repr(v) for k, v in self._values.items()
        )


@jsii.data_type(
    jsii_type="@cdktf/provider-azurerm.LinuxVirtualMachineBootDiagnostics",
    jsii_struct_bases=[],
    name_mapping={"storage_account_uri": "storageAccountUri"},
)
class LinuxVirtualMachineBootDiagnostics:
    def __init__(self, *, storage_account_uri: builtins.str) -> None:
        """
        :param storage_account_uri: 
        """
        self._values: typing.Dict[str, typing.Any] = {
            "storage_account_uri": storage_account_uri,
        }

    @builtins.property
    def storage_account_uri(self) -> builtins.str:
        result = self._values.get("storage_account_uri")
        assert result is not None, "Required property 'storage_account_uri' is missing"
        return result

    def __eq__(self, rhs: typing.Any) -> builtins.bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs: typing.Any) -> builtins.bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return "LinuxVirtualMachineBootDiagnostics(%s)" % ", ".join(
            k + "=" + repr(v) for k, v in self._values.items()
        )


@jsii.data_type(
    jsii_type="@cdktf/provider-azurerm.LinuxVirtualMachineConfig",
    jsii_struct_bases=[cdktf.TerraformMetaArguments],
    name_mapping={
        "count": "count",
        "depends_on": "dependsOn",
        "lifecycle": "lifecycle",
        "provider": "provider",
        "admin_username": "adminUsername",
        "location": "location",
        "name": "name",
        "network_interface_ids": "networkInterfaceIds",
        "os_disk": "osDisk",
        "resource_group_name": "resourceGroupName",
        "size": "size",
        "additional_capabilities": "additionalCapabilities",
        "admin_password": "adminPassword",
        "admin_ssh_key": "adminSshKey",
        "allow_extension_operations": "allowExtensionOperations",
        "availability_set_id": "availabilitySetId",
        "boot_diagnostics": "bootDiagnostics",
        "computer_name": "computerName",
        "custom_data": "customData",
        "dedicated_host_id": "dedicatedHostId",
        "disable_password_authentication": "disablePasswordAuthentication",
        "eviction_policy": "evictionPolicy",
        "identity": "identity",
        "max_bid_price": "maxBidPrice",
        "plan": "plan",
        "priority": "priority",
        "provision_vm_agent": "provisionVmAgent",
        "proximity_placement_group_id": "proximityPlacementGroupId",
        "secret": "secret",
        "source_image_id": "sourceImageId",
        "source_image_reference": "sourceImageReference",
        "tags": "tags",
        "timeouts": "timeouts",
        "zone": "zone",
    },
)
class LinuxVirtualMachineConfig(cdktf.TerraformMetaArguments):
    def __init__(
        self,
        *,
        count: typing.Optional[jsii.Number] = None,
        depends_on: typing.Optional[typing.List[cdktf.TerraformResource]] = None,
        lifecycle: typing.Optional[cdktf.TerraformResourceLifecycle] = None,
        provider: typing.Optional[cdktf.TerraformProvider] = None,
        admin_username: builtins.str,
        location: builtins.str,
        name: builtins.str,
        network_interface_ids: typing.List[builtins.str],
        os_disk: typing.List["LinuxVirtualMachineOsDisk"],
        resource_group_name: builtins.str,
        size: builtins.str,
        additional_capabilities: typing.Optional[typing.List[LinuxVirtualMachineAdditionalCapabilities]] = None,
        admin_password: typing.Optional[builtins.str] = None,
        admin_ssh_key: typing.Optional[typing.List[LinuxVirtualMachineAdminSshKey]] = None,
        allow_extension_operations: typing.Optional[builtins.bool] = None,
        availability_set_id: typing.Optional[builtins.str] = None,
        boot_diagnostics: typing.Optional[typing.List[LinuxVirtualMachineBootDiagnostics]] = None,
        computer_name: typing.Optional[builtins.str] = None,
        custom_data: typing.Optional[builtins.str] = None,
        dedicated_host_id: typing.Optional[builtins.str] = None,
        disable_password_authentication: typing.Optional[builtins.bool] = None,
        eviction_policy: typing.Optional[builtins.str] = None,
        identity: typing.Optional[typing.List["LinuxVirtualMachineIdentity"]] = None,
        max_bid_price: typing.Optional[jsii.Number] = None,
        plan: typing.Optional[typing.List["LinuxVirtualMachinePlan"]] = None,
        priority: typing.Optional[builtins.str] = None,
        provision_vm_agent: typing.Optional[builtins.bool] = None,
        proximity_placement_group_id: typing.Optional[builtins.str] = None,
        secret: typing.Optional[typing.List["LinuxVirtualMachineSecret"]] = None,
        source_image_id: typing.Optional[builtins.str] = None,
        source_image_reference: typing.Optional[typing.List["LinuxVirtualMachineSourceImageReference"]] = None,
        tags: typing.Optional[typing.Mapping[builtins.str, builtins.str]] = None,
        timeouts: typing.Optional["LinuxVirtualMachineTimeouts"] = None,
        zone: typing.Optional[builtins.str] = None,
    ) -> None:
        """
        :param count: 
        :param depends_on: 
        :param lifecycle: 
        :param provider: 
        :param admin_username: 
        :param location: 
        :param name: 
        :param network_interface_ids: 
        :param os_disk: os_disk block.
        :param resource_group_name: 
        :param size: 
        :param additional_capabilities: additional_capabilities block.
        :param admin_password: 
        :param admin_ssh_key: admin_ssh_key block.
        :param allow_extension_operations: 
        :param availability_set_id: 
        :param boot_diagnostics: boot_diagnostics block.
        :param computer_name: 
        :param custom_data: 
        :param dedicated_host_id: 
        :param disable_password_authentication: 
        :param eviction_policy: 
        :param identity: identity block.
        :param max_bid_price: 
        :param plan: plan block.
        :param priority: 
        :param provision_vm_agent: 
        :param proximity_placement_group_id: 
        :param secret: secret block.
        :param source_image_id: 
        :param source_image_reference: source_image_reference block.
        :param tags: 
        :param timeouts: timeouts block.
        :param zone: 
        """
        if isinstance(lifecycle, dict):
            lifecycle = cdktf.TerraformResourceLifecycle(**lifecycle)
        if isinstance(timeouts, dict):
            timeouts = LinuxVirtualMachineTimeouts(**timeouts)
        self._values: typing.Dict[str, typing.Any] = {
            "admin_username": admin_username,
            "location": location,
            "name": name,
            "network_interface_ids": network_interface_ids,
            "os_disk": os_disk,
            "resource_group_name": resource_group_name,
            "size": size,
        }
        if count is not None:
            self._values["count"] = count
        if depends_on is not None:
            self._values["depends_on"] = depends_on
        if lifecycle is not None:
            self._values["lifecycle"] = lifecycle
        if provider is not None:
            self._values["provider"] = provider
        if additional_capabilities is not None:
            self._values["additional_capabilities"] = additional_capabilities
        if admin_password is not None:
            self._values["admin_password"] = admin_password
        if admin_ssh_key is not None:
            self._values["admin_ssh_key"] = admin_ssh_key
        if allow_extension_operations is not None:
            self._values["allow_extension_operations"] = allow_extension_operations
        if availability_set_id is not None:
            self._values["availability_set_id"] = availability_set_id
        if boot_diagnostics is not None:
            self._values["boot_diagnostics"] = boot_diagnostics
        if computer_name is not None:
            self._values["computer_name"] = computer_name
        if custom_data is not None:
            self._values["custom_data"] = custom_data
        if dedicated_host_id is not None:
            self._values["dedicated_host_id"] = dedicated_host_id
        if disable_password_authentication is not None:
            self._values["disable_password_authentication"] = disable_password_authentication
        if eviction_policy is not None:
            self._values["eviction_policy"] = eviction_policy
        if identity is not None:
            self._values["identity"] = identity
        if max_bid_price is not None:
            self._values["max_bid_price"] = max_bid_price
        if plan is not None:
            self._values["plan"] = plan
        if priority is not None:
            self._values["priority"] = priority
        if provision_vm_agent is not None:
            self._values["provision_vm_agent"] = provision_vm_agent
        if proximity_placement_group_id is not None:
            self._values["proximity_placement_group_id"] = proximity_placement_group_id
        if secret is not None:
            self._values["secret"] = secret
        if source_image_id is not None:
            self._values["source_image_id"] = source_image_id
        if source_image_reference is not None:
            self._values["source_image_reference"] = source_image_reference
        if tags is not None:
            self._values["tags"] = tags
        if timeouts is not None:
            self._values["timeouts"] = timeouts
        if zone is not None:
            self._values["zone"] = zone

    @builtins.property
    def count(self) -> typing.Optional[jsii.Number]:
        """
        :stability: experimental
        """
        result = self._values.get("count")
        return result

    @builtins.property
    def depends_on(self) -> typing.Optional[typing.List[cdktf.TerraformResource]]:
        """
        :stability: experimental
        """
        result = self._values.get("depends_on")
        return result

    @builtins.property
    def lifecycle(self) -> typing.Optional[cdktf.TerraformResourceLifecycle]:
        """
        :stability: experimental
        """
        result = self._values.get("lifecycle")
        return result

    @builtins.property
    def provider(self) -> typing.Optional[cdktf.TerraformProvider]:
        """
        :stability: experimental
        """
        result = self._values.get("provider")
        return result

    @builtins.property
    def admin_username(self) -> builtins.str:
        result = self._values.get("admin_username")
        assert result is not None, "Required property 'admin_username' is missing"
        return result

    @builtins.property
    def location(self) -> builtins.str:
        result = self._values.get("location")
        assert result is not None, "Required property 'location' is missing"
        return result

    @builtins.property
    def name(self) -> builtins.str:
        result = self._values.get("name")
        assert result is not None, "Required property 'name' is missing"
        return result

    @builtins.property
    def network_interface_ids(self) -> typing.List[builtins.str]:
        result = self._values.get("network_interface_ids")
        assert result is not None, "Required property 'network_interface_ids' is missing"
        return result

    @builtins.property
    def os_disk(self) -> typing.List["LinuxVirtualMachineOsDisk"]:
        """os_disk block."""
        result = self._values.get("os_disk")
        assert result is not None, "Required property 'os_disk' is missing"
        return result

    @builtins.property
    def resource_group_name(self) -> builtins.str:
        result = self._values.get("resource_group_name")
        assert result is not None, "Required property 'resource_group_name' is missing"
        return result

    @builtins.property
    def size(self) -> builtins.str:
        result = self._values.get("size")
        assert result is not None, "Required property 'size' is missing"
        return result

    @builtins.property
    def additional_capabilities(
        self,
    ) -> typing.Optional[typing.List[LinuxVirtualMachineAdditionalCapabilities]]:
        """additional_capabilities block."""
        result = self._values.get("additional_capabilities")
        return result

    @builtins.property
    def admin_password(self) -> typing.Optional[builtins.str]:
        result = self._values.get("admin_password")
        return result

    @builtins.property
    def admin_ssh_key(
        self,
    ) -> typing.Optional[typing.List[LinuxVirtualMachineAdminSshKey]]:
        """admin_ssh_key block."""
        result = self._values.get("admin_ssh_key")
        return result

    @builtins.property
    def allow_extension_operations(self) -> typing.Optional[builtins.bool]:
        result = self._values.get("allow_extension_operations")
        return result

    @builtins.property
    def availability_set_id(self) -> typing.Optional[builtins.str]:
        result = self._values.get("availability_set_id")
        return result

    @builtins.property
    def boot_diagnostics(
        self,
    ) -> typing.Optional[typing.List[LinuxVirtualMachineBootDiagnostics]]:
        """boot_diagnostics block."""
        result = self._values.get("boot_diagnostics")
        return result

    @builtins.property
    def computer_name(self) -> typing.Optional[builtins.str]:
        result = self._values.get("computer_name")
        return result

    @builtins.property
    def custom_data(self) -> typing.Optional[builtins.str]:
        result = self._values.get("custom_data")
        return result

    @builtins.property
    def dedicated_host_id(self) -> typing.Optional[builtins.str]:
        result = self._values.get("dedicated_host_id")
        return result

    @builtins.property
    def disable_password_authentication(self) -> typing.Optional[builtins.bool]:
        result = self._values.get("disable_password_authentication")
        return result

    @builtins.property
    def eviction_policy(self) -> typing.Optional[builtins.str]:
        result = self._values.get("eviction_policy")
        return result

    @builtins.property
    def identity(self) -> typing.Optional[typing.List["LinuxVirtualMachineIdentity"]]:
        """identity block."""
        result = self._values.get("identity")
        return result

    @builtins.property
    def max_bid_price(self) -> typing.Optional[jsii.Number]:
        result = self._values.get("max_bid_price")
        return result

    @builtins.property
    def plan(self) -> typing.Optional[typing.List["LinuxVirtualMachinePlan"]]:
        """plan block."""
        result = self._values.get("plan")
        return result

    @builtins.property
    def priority(self) -> typing.Optional[builtins.str]:
        result = self._values.get("priority")
        return result

    @builtins.property
    def provision_vm_agent(self) -> typing.Optional[builtins.bool]:
        result = self._values.get("provision_vm_agent")
        return result

    @builtins.property
    def proximity_placement_group_id(self) -> typing.Optional[builtins.str]:
        result = self._values.get("proximity_placement_group_id")
        return result

    @builtins.property
    def secret(self) -> typing.Optional[typing.List["LinuxVirtualMachineSecret"]]:
        """secret block."""
        result = self._values.get("secret")
        return result

    @builtins.property
    def source_image_id(self) -> typing.Optional[builtins.str]:
        result = self._values.get("source_image_id")
        return result

    @builtins.property
    def source_image_reference(
        self,
    ) -> typing.Optional[typing.List["LinuxVirtualMachineSourceImageReference"]]:
        """source_image_reference block."""
        result = self._values.get("source_image_reference")
        return result

    @builtins.property
    def tags(self) -> typing.Optional[typing.Mapping[builtins.str, builtins.str]]:
        result = self._values.get("tags")
        return result

    @builtins.property
    def timeouts(self) -> typing.Optional["LinuxVirtualMachineTimeouts"]:
        """timeouts block."""
        result = self._values.get("timeouts")
        return result

    @builtins.property
    def zone(self) -> typing.Optional[builtins.str]:
        result = self._values.get("zone")
        return result

    def __eq__(self, rhs: typing.Any) -> builtins.bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs: typing.Any) -> builtins.bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return "LinuxVirtualMachineConfig(%s)" % ", ".join(
            k + "=" + repr(v) for k, v in self._values.items()
        )


@jsii.data_type(
    jsii_type="@cdktf/provider-azurerm.LinuxVirtualMachineIdentity",
    jsii_struct_bases=[],
    name_mapping={"type": "type", "identity_ids": "identityIds"},
)
class LinuxVirtualMachineIdentity:
    def __init__(
        self,
        *,
        type: builtins.str,
        identity_ids: typing.Optional[typing.List[builtins.str]] = None,
    ) -> None:
        """
        :param type: 
        :param identity_ids: 
        """
        self._values: typing.Dict[str, typing.Any] = {
            "type": type,
        }
        if identity_ids is not None:
            self._values["identity_ids"] = identity_ids

    @builtins.property
    def type(self) -> builtins.str:
        result = self._values.get("type")
        assert result is not None, "Required property 'type' is missing"
        return result

    @builtins.property
    def identity_ids(self) -> typing.Optional[typing.List[builtins.str]]:
        result = self._values.get("identity_ids")
        return result

    def __eq__(self, rhs: typing.Any) -> builtins.bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs: typing.Any) -> builtins.bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return "LinuxVirtualMachineIdentity(%s)" % ", ".join(
            k + "=" + repr(v) for k, v in self._values.items()
        )


@jsii.data_type(
    jsii_type="@cdktf/provider-azurerm.LinuxVirtualMachineOsDisk",
    jsii_struct_bases=[],
    name_mapping={
        "caching": "caching",
        "storage_account_type": "storageAccountType",
        "diff_disk_settings": "diffDiskSettings",
        "disk_encryption_set_id": "diskEncryptionSetId",
        "disk_size_gb": "diskSizeGb",
        "name": "name",
        "write_accelerator_enabled": "writeAcceleratorEnabled",
    },
)
class LinuxVirtualMachineOsDisk:
    def __init__(
        self,
        *,
        caching: builtins.str,
        storage_account_type: builtins.str,
        diff_disk_settings: typing.Optional[typing.List["LinuxVirtualMachineOsDiskDiffDiskSettings"]] = None,
        disk_encryption_set_id: typing.Optional[builtins.str] = None,
        disk_size_gb: typing.Optional[jsii.Number] = None,
        name: typing.Optional[builtins.str] = None,
        write_accelerator_enabled: typing.Optional[builtins.bool] = None,
    ) -> None:
        """
        :param caching: 
        :param storage_account_type: 
        :param diff_disk_settings: diff_disk_settings block.
        :param disk_encryption_set_id: 
        :param disk_size_gb: 
        :param name: 
        :param write_accelerator_enabled: 
        """
        self._values: typing.Dict[str, typing.Any] = {
            "caching": caching,
            "storage_account_type": storage_account_type,
        }
        if diff_disk_settings is not None:
            self._values["diff_disk_settings"] = diff_disk_settings
        if disk_encryption_set_id is not None:
            self._values["disk_encryption_set_id"] = disk_encryption_set_id
        if disk_size_gb is not None:
            self._values["disk_size_gb"] = disk_size_gb
        if name is not None:
            self._values["name"] = name
        if write_accelerator_enabled is not None:
            self._values["write_accelerator_enabled"] = write_accelerator_enabled

    @builtins.property
    def caching(self) -> builtins.str:
        result = self._values.get("caching")
        assert result is not None, "Required property 'caching' is missing"
        return result

    @builtins.property
    def storage_account_type(self) -> builtins.str:
        result = self._values.get("storage_account_type")
        assert result is not None, "Required property 'storage_account_type' is missing"
        return result

    @builtins.property
    def diff_disk_settings(
        self,
    ) -> typing.Optional[typing.List["LinuxVirtualMachineOsDiskDiffDiskSettings"]]:
        """diff_disk_settings block."""
        result = self._values.get("diff_disk_settings")
        return result

    @builtins.property
    def disk_encryption_set_id(self) -> typing.Optional[builtins.str]:
        result = self._values.get("disk_encryption_set_id")
        return result

    @builtins.property
    def disk_size_gb(self) -> typing.Optional[jsii.Number]:
        result = self._values.get("disk_size_gb")
        return result

    @builtins.property
    def name(self) -> typing.Optional[builtins.str]:
        result = self._values.get("name")
        return result

    @builtins.property
    def write_accelerator_enabled(self) -> typing.Optional[builtins.bool]:
        result = self._values.get("write_accelerator_enabled")
        return result

    def __eq__(self, rhs: typing.Any) -> builtins.bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs: typing.Any) -> builtins.bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return "LinuxVirtualMachineOsDisk(%s)" % ", ".join(
            k + "=" + repr(v) for k, v in self._values.items()
        )


@jsii.data_type(
    jsii_type="@cdktf/provider-azurerm.LinuxVirtualMachineOsDiskDiffDiskSettings",
    jsii_struct_bases=[],
    name_mapping={"option": "option"},
)
class LinuxVirtualMachineOsDiskDiffDiskSettings:
    def __init__(self, *, option: builtins.str) -> None:
        """
        :param option: 
        """
        self._values: typing.Dict[str, typing.Any] = {
            "option": option,
        }

    @builtins.property
    def option(self) -> builtins.str:
        result = self._values.get("option")
        assert result is not None, "Required property 'option' is missing"
        return result

    def __eq__(self, rhs: typing.Any) -> builtins.bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs: typing.Any) -> builtins.bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return "LinuxVirtualMachineOsDiskDiffDiskSettings(%s)" % ", ".join(
            k + "=" + repr(v) for k, v in self._values.items()
        )


@jsii.data_type(
    jsii_type="@cdktf/provider-azurerm.LinuxVirtualMachinePlan",
    jsii_struct_bases=[],
    name_mapping={"name": "name", "product": "product", "publisher": "publisher"},
)
class LinuxVirtualMachinePlan:
    def __init__(
        self,
        *,
        name: builtins.str,
        product: builtins.str,
        publisher: builtins.str,
    ) -> None:
        """
        :param name: 
        :param product: 
        :param publisher: 
        """
        self._values: typing.Dict[str, typing.Any] = {
            "name": name,
            "product": product,
            "publisher": publisher,
        }

    @builtins.property
    def name(self) -> builtins.str:
        result = self._values.get("name")
        assert result is not None, "Required property 'name' is missing"
        return result

    @builtins.property
    def product(self) -> builtins.str:
        result = self._values.get("product")
        assert result is not None, "Required property 'product' is missing"
        return result

    @builtins.property
    def publisher(self) -> builtins.str:
        result = self._values.get("publisher")
        assert result is not None, "Required property 'publisher' is missing"
        return result

    def __eq__(self, rhs: typing.Any) -> builtins.bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs: typing.Any) -> builtins.bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return "LinuxVirtualMachinePlan(%s)" % ", ".join(
            k + "=" + repr(v) for k, v in self._values.items()
        )


class LinuxVirtualMachineScaleSet(
    cdktf.TerraformResource,
    metaclass=jsii.JSIIMeta,
    jsii_type="@cdktf/provider-azurerm.LinuxVirtualMachineScaleSet",
):
    def __init__(
        self,
        scope: constructs.Construct,
        id: builtins.str,
        *,
        admin_username: builtins.str,
        instances: jsii.Number,
        location: builtins.str,
        name: builtins.str,
        network_interface: typing.List["LinuxVirtualMachineScaleSetNetworkInterface"],
        os_disk: typing.List["LinuxVirtualMachineScaleSetOsDisk"],
        resource_group_name: builtins.str,
        sku: builtins.str,
        additional_capabilities: typing.Optional[typing.List["LinuxVirtualMachineScaleSetAdditionalCapabilities"]] = None,
        admin_password: typing.Optional[builtins.str] = None,
        admin_ssh_key: typing.Optional[typing.List["LinuxVirtualMachineScaleSetAdminSshKey"]] = None,
        automatic_os_upgrade_policy: typing.Optional[typing.List["LinuxVirtualMachineScaleSetAutomaticOsUpgradePolicy"]] = None,
        boot_diagnostics: typing.Optional[typing.List["LinuxVirtualMachineScaleSetBootDiagnostics"]] = None,
        computer_name_prefix: typing.Optional[builtins.str] = None,
        custom_data: typing.Optional[builtins.str] = None,
        data_disk: typing.Optional[typing.List["LinuxVirtualMachineScaleSetDataDisk"]] = None,
        disable_password_authentication: typing.Optional[builtins.bool] = None,
        do_not_run_extensions_on_overprovisioned_machines: typing.Optional[builtins.bool] = None,
        eviction_policy: typing.Optional[builtins.str] = None,
        health_probe_id: typing.Optional[builtins.str] = None,
        identity: typing.Optional[typing.List["LinuxVirtualMachineScaleSetIdentity"]] = None,
        max_bid_price: typing.Optional[jsii.Number] = None,
        overprovision: typing.Optional[builtins.bool] = None,
        plan: typing.Optional[typing.List["LinuxVirtualMachineScaleSetPlan"]] = None,
        priority: typing.Optional[builtins.str] = None,
        provision_vm_agent: typing.Optional[builtins.bool] = None,
        proximity_placement_group_id: typing.Optional[builtins.str] = None,
        rolling_upgrade_policy: typing.Optional[typing.List["LinuxVirtualMachineScaleSetRollingUpgradePolicy"]] = None,
        secret: typing.Optional[typing.List["LinuxVirtualMachineScaleSetSecret"]] = None,
        single_placement_group: typing.Optional[builtins.bool] = None,
        source_image_id: typing.Optional[builtins.str] = None,
        source_image_reference: typing.Optional[typing.List["LinuxVirtualMachineScaleSetSourceImageReference"]] = None,
        tags: typing.Optional[typing.Mapping[builtins.str, builtins.str]] = None,
        timeouts: typing.Optional["LinuxVirtualMachineScaleSetTimeouts"] = None,
        upgrade_mode: typing.Optional[builtins.str] = None,
        zone_balance: typing.Optional[builtins.bool] = None,
        zones: typing.Optional[typing.List[builtins.str]] = None,
        count: typing.Optional[jsii.Number] = None,
        depends_on: typing.Optional[typing.List[cdktf.TerraformResource]] = None,
        lifecycle: typing.Optional[cdktf.TerraformResourceLifecycle] = None,
        provider: typing.Optional[cdktf.TerraformProvider] = None,
    ) -> None:
        """
        :param scope: -
        :param id: -
        :param admin_username: 
        :param instances: 
        :param location: 
        :param name: 
        :param network_interface: network_interface block.
        :param os_disk: os_disk block.
        :param resource_group_name: 
        :param sku: 
        :param additional_capabilities: additional_capabilities block.
        :param admin_password: 
        :param admin_ssh_key: admin_ssh_key block.
        :param automatic_os_upgrade_policy: automatic_os_upgrade_policy block.
        :param boot_diagnostics: boot_diagnostics block.
        :param computer_name_prefix: 
        :param custom_data: 
        :param data_disk: data_disk block.
        :param disable_password_authentication: 
        :param do_not_run_extensions_on_overprovisioned_machines: 
        :param eviction_policy: 
        :param health_probe_id: 
        :param identity: identity block.
        :param max_bid_price: 
        :param overprovision: 
        :param plan: plan block.
        :param priority: 
        :param provision_vm_agent: 
        :param proximity_placement_group_id: 
        :param rolling_upgrade_policy: rolling_upgrade_policy block.
        :param secret: secret block.
        :param single_placement_group: 
        :param source_image_id: 
        :param source_image_reference: source_image_reference block.
        :param tags: 
        :param timeouts: timeouts block.
        :param upgrade_mode: 
        :param zone_balance: 
        :param zones: 
        :param count: 
        :param depends_on: 
        :param lifecycle: 
        :param provider: 
        """
        config = LinuxVirtualMachineScaleSetConfig(
            admin_username=admin_username,
            instances=instances,
            location=location,
            name=name,
            network_interface=network_interface,
            os_disk=os_disk,
            resource_group_name=resource_group_name,
            sku=sku,
            additional_capabilities=additional_capabilities,
            admin_password=admin_password,
            admin_ssh_key=admin_ssh_key,
            automatic_os_upgrade_policy=automatic_os_upgrade_policy,
            boot_diagnostics=boot_diagnostics,
            computer_name_prefix=computer_name_prefix,
            custom_data=custom_data,
            data_disk=data_disk,
            disable_password_authentication=disable_password_authentication,
            do_not_run_extensions_on_overprovisioned_machines=do_not_run_extensions_on_overprovisioned_machines,
            eviction_policy=eviction_policy,
            health_probe_id=health_probe_id,
            identity=identity,
            max_bid_price=max_bid_price,
            overprovision=overprovision,
            plan=plan,
            priority=priority,
            provision_vm_agent=provision_vm_agent,
            proximity_placement_group_id=proximity_placement_group_id,
            rolling_upgrade_policy=rolling_upgrade_policy,
            secret=secret,
            single_placement_group=single_placement_group,
            source_image_id=source_image_id,
            source_image_reference=source_image_reference,
            tags=tags,
            timeouts=timeouts,
            upgrade_mode=upgrade_mode,
            zone_balance=zone_balance,
            zones=zones,
            count=count,
            depends_on=depends_on,
            lifecycle=lifecycle,
            provider=provider,
        )

        jsii.create(LinuxVirtualMachineScaleSet, self, [scope, id, config])

    @jsii.member(jsii_name="synthesizeAttributes")
    def _synthesize_attributes(self) -> typing.Mapping[builtins.str, typing.Any]:
        return jsii.invoke(self, "synthesizeAttributes", [])

    @builtins.property # type: ignore
    @jsii.member(jsii_name="uniqueId")
    def unique_id(self) -> builtins.str:
        return jsii.get(self, "uniqueId")

    @builtins.property # type: ignore
    @jsii.member(jsii_name="adminUsername")
    def admin_username(self) -> builtins.str:
        return jsii.get(self, "adminUsername")

    @admin_username.setter # type: ignore
    def admin_username(self, value: builtins.str) -> None:
        jsii.set(self, "adminUsername", value)

    @builtins.property # type: ignore
    @jsii.member(jsii_name="instances")
    def instances(self) -> jsii.Number:
        return jsii.get(self, "instances")

    @instances.setter # type: ignore
    def instances(self, value: jsii.Number) -> None:
        jsii.set(self, "instances", value)

    @builtins.property # type: ignore
    @jsii.member(jsii_name="location")
    def location(self) -> builtins.str:
        return jsii.get(self, "location")

    @location.setter # type: ignore
    def location(self, value: builtins.str) -> None:
        jsii.set(self, "location", value)

    @builtins.property # type: ignore
    @jsii.member(jsii_name="name")
    def name(self) -> builtins.str:
        return jsii.get(self, "name")

    @name.setter # type: ignore
    def name(self, value: builtins.str) -> None:
        jsii.set(self, "name", value)

    @builtins.property # type: ignore
    @jsii.member(jsii_name="networkInterface")
    def network_interface(
        self,
    ) -> typing.List["LinuxVirtualMachineScaleSetNetworkInterface"]:
        return jsii.get(self, "networkInterface")

    @network_interface.setter # type: ignore
    def network_interface(
        self,
        value: typing.List["LinuxVirtualMachineScaleSetNetworkInterface"],
    ) -> None:
        jsii.set(self, "networkInterface", value)

    @builtins.property # type: ignore
    @jsii.member(jsii_name="osDisk")
    def os_disk(self) -> typing.List["LinuxVirtualMachineScaleSetOsDisk"]:
        return jsii.get(self, "osDisk")

    @os_disk.setter # type: ignore
    def os_disk(self, value: typing.List["LinuxVirtualMachineScaleSetOsDisk"]) -> None:
        jsii.set(self, "osDisk", value)

    @builtins.property # type: ignore
    @jsii.member(jsii_name="resourceGroupName")
    def resource_group_name(self) -> builtins.str:
        return jsii.get(self, "resourceGroupName")

    @resource_group_name.setter # type: ignore
    def resource_group_name(self, value: builtins.str) -> None:
        jsii.set(self, "resourceGroupName", value)

    @builtins.property # type: ignore
    @jsii.member(jsii_name="sku")
    def sku(self) -> builtins.str:
        return jsii.get(self, "sku")

    @sku.setter # type: ignore
    def sku(self, value: builtins.str) -> None:
        jsii.set(self, "sku", value)

    @builtins.property # type: ignore
    @jsii.member(jsii_name="additionalCapabilities")
    def additional_capabilities(
        self,
    ) -> typing.Optional[typing.List["LinuxVirtualMachineScaleSetAdditionalCapabilities"]]:
        return jsii.get(self, "additionalCapabilities")

    @additional_capabilities.setter # type: ignore
    def additional_capabilities(
        self,
        value: typing.Optional[typing.List["LinuxVirtualMachineScaleSetAdditionalCapabilities"]],
    ) -> None:
        jsii.set(self, "additionalCapabilities", value)

    @builtins.property # type: ignore
    @jsii.member(jsii_name="adminPassword")
    def admin_password(self) -> typing.Optional[builtins.str]:
        return jsii.get(self, "adminPassword")

    @admin_password.setter # type: ignore
    def admin_password(self, value: typing.Optional[builtins.str]) -> None:
        jsii.set(self, "adminPassword", value)

    @builtins.property # type: ignore
    @jsii.member(jsii_name="adminSshKey")
    def admin_ssh_key(
        self,
    ) -> typing.Optional[typing.List["LinuxVirtualMachineScaleSetAdminSshKey"]]:
        return jsii.get(self, "adminSshKey")

    @admin_ssh_key.setter # type: ignore
    def admin_ssh_key(
        self,
        value: typing.Optional[typing.List["LinuxVirtualMachineScaleSetAdminSshKey"]],
    ) -> None:
        jsii.set(self, "adminSshKey", value)

    @builtins.property # type: ignore
    @jsii.member(jsii_name="automaticOsUpgradePolicy")
    def automatic_os_upgrade_policy(
        self,
    ) -> typing.Optional[typing.List["LinuxVirtualMachineScaleSetAutomaticOsUpgradePolicy"]]:
        return jsii.get(self, "automaticOsUpgradePolicy")

    @automatic_os_upgrade_policy.setter # type: ignore
    def automatic_os_upgrade_policy(
        self,
        value: typing.Optional[typing.List["LinuxVirtualMachineScaleSetAutomaticOsUpgradePolicy"]],
    ) -> None:
        jsii.set(self, "automaticOsUpgradePolicy", value)

    @builtins.property # type: ignore
    @jsii.member(jsii_name="bootDiagnostics")
    def boot_diagnostics(
        self,
    ) -> typing.Optional[typing.List["LinuxVirtualMachineScaleSetBootDiagnostics"]]:
        return jsii.get(self, "bootDiagnostics")

    @boot_diagnostics.setter # type: ignore
    def boot_diagnostics(
        self,
        value: typing.Optional[typing.List["LinuxVirtualMachineScaleSetBootDiagnostics"]],
    ) -> None:
        jsii.set(self, "bootDiagnostics", value)

    @builtins.property # type: ignore
    @jsii.member(jsii_name="computerNamePrefix")
    def computer_name_prefix(self) -> typing.Optional[builtins.str]:
        return jsii.get(self, "computerNamePrefix")

    @computer_name_prefix.setter # type: ignore
    def computer_name_prefix(self, value: typing.Optional[builtins.str]) -> None:
        jsii.set(self, "computerNamePrefix", value)

    @builtins.property # type: ignore
    @jsii.member(jsii_name="customData")
    def custom_data(self) -> typing.Optional[builtins.str]:
        return jsii.get(self, "customData")

    @custom_data.setter # type: ignore
    def custom_data(self, value: typing.Optional[builtins.str]) -> None:
        jsii.set(self, "customData", value)

    @builtins.property # type: ignore
    @jsii.member(jsii_name="dataDisk")
    def data_disk(
        self,
    ) -> typing.Optional[typing.List["LinuxVirtualMachineScaleSetDataDisk"]]:
        return jsii.get(self, "dataDisk")

    @data_disk.setter # type: ignore
    def data_disk(
        self,
        value: typing.Optional[typing.List["LinuxVirtualMachineScaleSetDataDisk"]],
    ) -> None:
        jsii.set(self, "dataDisk", value)

    @builtins.property # type: ignore
    @jsii.member(jsii_name="disablePasswordAuthentication")
    def disable_password_authentication(self) -> typing.Optional[builtins.bool]:
        return jsii.get(self, "disablePasswordAuthentication")

    @disable_password_authentication.setter # type: ignore
    def disable_password_authentication(
        self,
        value: typing.Optional[builtins.bool],
    ) -> None:
        jsii.set(self, "disablePasswordAuthentication", value)

    @builtins.property # type: ignore
    @jsii.member(jsii_name="doNotRunExtensionsOnOverprovisionedMachines")
    def do_not_run_extensions_on_overprovisioned_machines(
        self,
    ) -> typing.Optional[builtins.bool]:
        return jsii.get(self, "doNotRunExtensionsOnOverprovisionedMachines")

    @do_not_run_extensions_on_overprovisioned_machines.setter # type: ignore
    def do_not_run_extensions_on_overprovisioned_machines(
        self,
        value: typing.Optional[builtins.bool],
    ) -> None:
        jsii.set(self, "doNotRunExtensionsOnOverprovisionedMachines", value)

    @builtins.property # type: ignore
    @jsii.member(jsii_name="evictionPolicy")
    def eviction_policy(self) -> typing.Optional[builtins.str]:
        return jsii.get(self, "evictionPolicy")

    @eviction_policy.setter # type: ignore
    def eviction_policy(self, value: typing.Optional[builtins.str]) -> None:
        jsii.set(self, "evictionPolicy", value)

    @builtins.property # type: ignore
    @jsii.member(jsii_name="healthProbeId")
    def health_probe_id(self) -> typing.Optional[builtins.str]:
        return jsii.get(self, "healthProbeId")

    @health_probe_id.setter # type: ignore
    def health_probe_id(self, value: typing.Optional[builtins.str]) -> None:
        jsii.set(self, "healthProbeId", value)

    @builtins.property # type: ignore
    @jsii.member(jsii_name="id")
    def id(self) -> typing.Optional[builtins.str]:
        return jsii.get(self, "id")

    @id.setter # type: ignore
    def id(self, value: typing.Optional[builtins.str]) -> None:
        jsii.set(self, "id", value)

    @builtins.property # type: ignore
    @jsii.member(jsii_name="identity")
    def identity(
        self,
    ) -> typing.Optional[typing.List["LinuxVirtualMachineScaleSetIdentity"]]:
        return jsii.get(self, "identity")

    @identity.setter # type: ignore
    def identity(
        self,
        value: typing.Optional[typing.List["LinuxVirtualMachineScaleSetIdentity"]],
    ) -> None:
        jsii.set(self, "identity", value)

    @builtins.property # type: ignore
    @jsii.member(jsii_name="maxBidPrice")
    def max_bid_price(self) -> typing.Optional[jsii.Number]:
        return jsii.get(self, "maxBidPrice")

    @max_bid_price.setter # type: ignore
    def max_bid_price(self, value: typing.Optional[jsii.Number]) -> None:
        jsii.set(self, "maxBidPrice", value)

    @builtins.property # type: ignore
    @jsii.member(jsii_name="overprovision")
    def overprovision(self) -> typing.Optional[builtins.bool]:
        return jsii.get(self, "overprovision")

    @overprovision.setter # type: ignore
    def overprovision(self, value: typing.Optional[builtins.bool]) -> None:
        jsii.set(self, "overprovision", value)

    @builtins.property # type: ignore
    @jsii.member(jsii_name="plan")
    def plan(self) -> typing.Optional[typing.List["LinuxVirtualMachineScaleSetPlan"]]:
        return jsii.get(self, "plan")

    @plan.setter # type: ignore
    def plan(
        self,
        value: typing.Optional[typing.List["LinuxVirtualMachineScaleSetPlan"]],
    ) -> None:
        jsii.set(self, "plan", value)

    @builtins.property # type: ignore
    @jsii.member(jsii_name="priority")
    def priority(self) -> typing.Optional[builtins.str]:
        return jsii.get(self, "priority")

    @priority.setter # type: ignore
    def priority(self, value: typing.Optional[builtins.str]) -> None:
        jsii.set(self, "priority", value)

    @builtins.property # type: ignore
    @jsii.member(jsii_name="provisionVmAgent")
    def provision_vm_agent(self) -> typing.Optional[builtins.bool]:
        return jsii.get(self, "provisionVmAgent")

    @provision_vm_agent.setter # type: ignore
    def provision_vm_agent(self, value: typing.Optional[builtins.bool]) -> None:
        jsii.set(self, "provisionVmAgent", value)

    @builtins.property # type: ignore
    @jsii.member(jsii_name="proximityPlacementGroupId")
    def proximity_placement_group_id(self) -> typing.Optional[builtins.str]:
        return jsii.get(self, "proximityPlacementGroupId")

    @proximity_placement_group_id.setter # type: ignore
    def proximity_placement_group_id(
        self,
        value: typing.Optional[builtins.str],
    ) -> None:
        jsii.set(self, "proximityPlacementGroupId", value)

    @builtins.property # type: ignore
    @jsii.member(jsii_name="rollingUpgradePolicy")
    def rolling_upgrade_policy(
        self,
    ) -> typing.Optional[typing.List["LinuxVirtualMachineScaleSetRollingUpgradePolicy"]]:
        return jsii.get(self, "rollingUpgradePolicy")

    @rolling_upgrade_policy.setter # type: ignore
    def rolling_upgrade_policy(
        self,
        value: typing.Optional[typing.List["LinuxVirtualMachineScaleSetRollingUpgradePolicy"]],
    ) -> None:
        jsii.set(self, "rollingUpgradePolicy", value)

    @builtins.property # type: ignore
    @jsii.member(jsii_name="secret")
    def secret(
        self,
    ) -> typing.Optional[typing.List["LinuxVirtualMachineScaleSetSecret"]]:
        return jsii.get(self, "secret")

    @secret.setter # type: ignore
    def secret(
        self,
        value: typing.Optional[typing.List["LinuxVirtualMachineScaleSetSecret"]],
    ) -> None:
        jsii.set(self, "secret", value)

    @builtins.property # type: ignore
    @jsii.member(jsii_name="singlePlacementGroup")
    def single_placement_group(self) -> typing.Optional[builtins.bool]:
        return jsii.get(self, "singlePlacementGroup")

    @single_placement_group.setter # type: ignore
    def single_placement_group(self, value: typing.Optional[builtins.bool]) -> None:
        jsii.set(self, "singlePlacementGroup", value)

    @builtins.property # type: ignore
    @jsii.member(jsii_name="sourceImageId")
    def source_image_id(self) -> typing.Optional[builtins.str]:
        return jsii.get(self, "sourceImageId")

    @source_image_id.setter # type: ignore
    def source_image_id(self, value: typing.Optional[builtins.str]) -> None:
        jsii.set(self, "sourceImageId", value)

    @builtins.property # type: ignore
    @jsii.member(jsii_name="sourceImageReference")
    def source_image_reference(
        self,
    ) -> typing.Optional[typing.List["LinuxVirtualMachineScaleSetSourceImageReference"]]:
        return jsii.get(self, "sourceImageReference")

    @source_image_reference.setter # type: ignore
    def source_image_reference(
        self,
        value: typing.Optional[typing.List["LinuxVirtualMachineScaleSetSourceImageReference"]],
    ) -> None:
        jsii.set(self, "sourceImageReference", value)

    @builtins.property # type: ignore
    @jsii.member(jsii_name="tags")
    def tags(self) -> typing.Optional[typing.Mapping[builtins.str, builtins.str]]:
        return jsii.get(self, "tags")

    @tags.setter # type: ignore
    def tags(
        self,
        value: typing.Optional[typing.Mapping[builtins.str, builtins.str]],
    ) -> None:
        jsii.set(self, "tags", value)

    @builtins.property # type: ignore
    @jsii.member(jsii_name="timeouts")
    def timeouts(self) -> typing.Optional["LinuxVirtualMachineScaleSetTimeouts"]:
        return jsii.get(self, "timeouts")

    @timeouts.setter # type: ignore
    def timeouts(
        self,
        value: typing.Optional["LinuxVirtualMachineScaleSetTimeouts"],
    ) -> None:
        jsii.set(self, "timeouts", value)

    @builtins.property # type: ignore
    @jsii.member(jsii_name="upgradeMode")
    def upgrade_mode(self) -> typing.Optional[builtins.str]:
        return jsii.get(self, "upgradeMode")

    @upgrade_mode.setter # type: ignore
    def upgrade_mode(self, value: typing.Optional[builtins.str]) -> None:
        jsii.set(self, "upgradeMode", value)

    @builtins.property # type: ignore
    @jsii.member(jsii_name="zoneBalance")
    def zone_balance(self) -> typing.Optional[builtins.bool]:
        return jsii.get(self, "zoneBalance")

    @zone_balance.setter # type: ignore
    def zone_balance(self, value: typing.Optional[builtins.bool]) -> None:
        jsii.set(self, "zoneBalance", value)

    @builtins.property # type: ignore
    @jsii.member(jsii_name="zones")
    def zones(self) -> typing.Optional[typing.List[builtins.str]]:
        return jsii.get(self, "zones")

    @zones.setter # type: ignore
    def zones(self, value: typing.Optional[typing.List[builtins.str]]) -> None:
        jsii.set(self, "zones", value)


@jsii.data_type(
    jsii_type="@cdktf/provider-azurerm.LinuxVirtualMachineScaleSetAdditionalCapabilities",
    jsii_struct_bases=[],
    name_mapping={"ultra_ssd_enabled": "ultraSsdEnabled"},
)
class LinuxVirtualMachineScaleSetAdditionalCapabilities:
    def __init__(
        self,
        *,
        ultra_ssd_enabled: typing.Optional[builtins.bool] = None,
    ) -> None:
        """
        :param ultra_ssd_enabled: 
        """
        self._values: typing.Dict[str, typing.Any] = {}
        if ultra_ssd_enabled is not None:
            self._values["ultra_ssd_enabled"] = ultra_ssd_enabled

    @builtins.property
    def ultra_ssd_enabled(self) -> typing.Optional[builtins.bool]:
        result = self._values.get("ultra_ssd_enabled")
        return result

    def __eq__(self, rhs: typing.Any) -> builtins.bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs: typing.Any) -> builtins.bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return "LinuxVirtualMachineScaleSetAdditionalCapabilities(%s)" % ", ".join(
            k + "=" + repr(v) for k, v in self._values.items()
        )


@jsii.data_type(
    jsii_type="@cdktf/provider-azurerm.LinuxVirtualMachineScaleSetAdminSshKey",
    jsii_struct_bases=[],
    name_mapping={"public_key": "publicKey", "username": "username"},
)
class LinuxVirtualMachineScaleSetAdminSshKey:
    def __init__(self, *, public_key: builtins.str, username: builtins.str) -> None:
        """
        :param public_key: 
        :param username: 
        """
        self._values: typing.Dict[str, typing.Any] = {
            "public_key": public_key,
            "username": username,
        }

    @builtins.property
    def public_key(self) -> builtins.str:
        result = self._values.get("public_key")
        assert result is not None, "Required property 'public_key' is missing"
        return result

    @builtins.property
    def username(self) -> builtins.str:
        result = self._values.get("username")
        assert result is not None, "Required property 'username' is missing"
        return result

    def __eq__(self, rhs: typing.Any) -> builtins.bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs: typing.Any) -> builtins.bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return "LinuxVirtualMachineScaleSetAdminSshKey(%s)" % ", ".join(
            k + "=" + repr(v) for k, v in self._values.items()
        )


@jsii.data_type(
    jsii_type="@cdktf/provider-azurerm.LinuxVirtualMachineScaleSetAutomaticOsUpgradePolicy",
    jsii_struct_bases=[],
    name_mapping={
        "disable_automatic_rollback": "disableAutomaticRollback",
        "enable_automatic_os_upgrade": "enableAutomaticOsUpgrade",
    },
)
class LinuxVirtualMachineScaleSetAutomaticOsUpgradePolicy:
    def __init__(
        self,
        *,
        disable_automatic_rollback: builtins.bool,
        enable_automatic_os_upgrade: builtins.bool,
    ) -> None:
        """
        :param disable_automatic_rollback: 
        :param enable_automatic_os_upgrade: 
        """
        self._values: typing.Dict[str, typing.Any] = {
            "disable_automatic_rollback": disable_automatic_rollback,
            "enable_automatic_os_upgrade": enable_automatic_os_upgrade,
        }

    @builtins.property
    def disable_automatic_rollback(self) -> builtins.bool:
        result = self._values.get("disable_automatic_rollback")
        assert result is not None, "Required property 'disable_automatic_rollback' is missing"
        return result

    @builtins.property
    def enable_automatic_os_upgrade(self) -> builtins.bool:
        result = self._values.get("enable_automatic_os_upgrade")
        assert result is not None, "Required property 'enable_automatic_os_upgrade' is missing"
        return result

    def __eq__(self, rhs: typing.Any) -> builtins.bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs: typing.Any) -> builtins.bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return "LinuxVirtualMachineScaleSetAutomaticOsUpgradePolicy(%s)" % ", ".join(
            k + "=" + repr(v) for k, v in self._values.items()
        )


@jsii.data_type(
    jsii_type="@cdktf/provider-azurerm.LinuxVirtualMachineScaleSetBootDiagnostics",
    jsii_struct_bases=[],
    name_mapping={"storage_account_uri": "storageAccountUri"},
)
class LinuxVirtualMachineScaleSetBootDiagnostics:
    def __init__(self, *, storage_account_uri: builtins.str) -> None:
        """
        :param storage_account_uri: 
        """
        self._values: typing.Dict[str, typing.Any] = {
            "storage_account_uri": storage_account_uri,
        }

    @builtins.property
    def storage_account_uri(self) -> builtins.str:
        result = self._values.get("storage_account_uri")
        assert result is not None, "Required property 'storage_account_uri' is missing"
        return result

    def __eq__(self, rhs: typing.Any) -> builtins.bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs: typing.Any) -> builtins.bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return "LinuxVirtualMachineScaleSetBootDiagnostics(%s)" % ", ".join(
            k + "=" + repr(v) for k, v in self._values.items()
        )


@jsii.data_type(
    jsii_type="@cdktf/provider-azurerm.LinuxVirtualMachineScaleSetConfig",
    jsii_struct_bases=[cdktf.TerraformMetaArguments],
    name_mapping={
        "count": "count",
        "depends_on": "dependsOn",
        "lifecycle": "lifecycle",
        "provider": "provider",
        "admin_username": "adminUsername",
        "instances": "instances",
        "location": "location",
        "name": "name",
        "network_interface": "networkInterface",
        "os_disk": "osDisk",
        "resource_group_name": "resourceGroupName",
        "sku": "sku",
        "additional_capabilities": "additionalCapabilities",
        "admin_password": "adminPassword",
        "admin_ssh_key": "adminSshKey",
        "automatic_os_upgrade_policy": "automaticOsUpgradePolicy",
        "boot_diagnostics": "bootDiagnostics",
        "computer_name_prefix": "computerNamePrefix",
        "custom_data": "customData",
        "data_disk": "dataDisk",
        "disable_password_authentication": "disablePasswordAuthentication",
        "do_not_run_extensions_on_overprovisioned_machines": "doNotRunExtensionsOnOverprovisionedMachines",
        "eviction_policy": "evictionPolicy",
        "health_probe_id": "healthProbeId",
        "identity": "identity",
        "max_bid_price": "maxBidPrice",
        "overprovision": "overprovision",
        "plan": "plan",
        "priority": "priority",
        "provision_vm_agent": "provisionVmAgent",
        "proximity_placement_group_id": "proximityPlacementGroupId",
        "rolling_upgrade_policy": "rollingUpgradePolicy",
        "secret": "secret",
        "single_placement_group": "singlePlacementGroup",
        "source_image_id": "sourceImageId",
        "source_image_reference": "sourceImageReference",
        "tags": "tags",
        "timeouts": "timeouts",
        "upgrade_mode": "upgradeMode",
        "zone_balance": "zoneBalance",
        "zones": "zones",
    },
)
class LinuxVirtualMachineScaleSetConfig(cdktf.TerraformMetaArguments):
    def __init__(
        self,
        *,
        count: typing.Optional[jsii.Number] = None,
        depends_on: typing.Optional[typing.List[cdktf.TerraformResource]] = None,
        lifecycle: typing.Optional[cdktf.TerraformResourceLifecycle] = None,
        provider: typing.Optional[cdktf.TerraformProvider] = None,
        admin_username: builtins.str,
        instances: jsii.Number,
        location: builtins.str,
        name: builtins.str,
        network_interface: typing.List["LinuxVirtualMachineScaleSetNetworkInterface"],
        os_disk: typing.List["LinuxVirtualMachineScaleSetOsDisk"],
        resource_group_name: builtins.str,
        sku: builtins.str,
        additional_capabilities: typing.Optional[typing.List[LinuxVirtualMachineScaleSetAdditionalCapabilities]] = None,
        admin_password: typing.Optional[builtins.str] = None,
        admin_ssh_key: typing.Optional[typing.List[LinuxVirtualMachineScaleSetAdminSshKey]] = None,
        automatic_os_upgrade_policy: typing.Optional[typing.List[LinuxVirtualMachineScaleSetAutomaticOsUpgradePolicy]] = None,
        boot_diagnostics: typing.Optional[typing.List[LinuxVirtualMachineScaleSetBootDiagnostics]] = None,
        computer_name_prefix: typing.Optional[builtins.str] = None,
        custom_data: typing.Optional[builtins.str] = None,
        data_disk: typing.Optional[typing.List["LinuxVirtualMachineScaleSetDataDisk"]] = None,
        disable_password_authentication: typing.Optional[builtins.bool] = None,
        do_not_run_extensions_on_overprovisioned_machines: typing.Optional[builtins.bool] = None,
        eviction_policy: typing.Optional[builtins.str] = None,
        health_probe_id: typing.Optional[builtins.str] = None,
        identity: typing.Optional[typing.List["LinuxVirtualMachineScaleSetIdentity"]] = None,
        max_bid_price: typing.Optional[jsii.Number] = None,
        overprovision: typing.Optional[builtins.bool] = None,
        plan: typing.Optional[typing.List["LinuxVirtualMachineScaleSetPlan"]] = None,
        priority: typing.Optional[builtins.str] = None,
        provision_vm_agent: typing.Optional[builtins.bool] = None,
        proximity_placement_group_id: typing.Optional[builtins.str] = None,
        rolling_upgrade_policy: typing.Optional[typing.List["LinuxVirtualMachineScaleSetRollingUpgradePolicy"]] = None,
        secret: typing.Optional[typing.List["LinuxVirtualMachineScaleSetSecret"]] = None,
        single_placement_group: typing.Optional[builtins.bool] = None,
        source_image_id: typing.Optional[builtins.str] = None,
        source_image_reference: typing.Optional[typing.List["LinuxVirtualMachineScaleSetSourceImageReference"]] = None,
        tags: typing.Optional[typing.Mapping[builtins.str, builtins.str]] = None,
        timeouts: typing.Optional["LinuxVirtualMachineScaleSetTimeouts"] = None,
        upgrade_mode: typing.Optional[builtins.str] = None,
        zone_balance: typing.Optional[builtins.bool] = None,
        zones: typing.Optional[typing.List[builtins.str]] = None,
    ) -> None:
        """
        :param count: 
        :param depends_on: 
        :param lifecycle: 
        :param provider: 
        :param admin_username: 
        :param instances: 
        :param location: 
        :param name: 
        :param network_interface: network_interface block.
        :param os_disk: os_disk block.
        :param resource_group_name: 
        :param sku: 
        :param additional_capabilities: additional_capabilities block.
        :param admin_password: 
        :param admin_ssh_key: admin_ssh_key block.
        :param automatic_os_upgrade_policy: automatic_os_upgrade_policy block.
        :param boot_diagnostics: boot_diagnostics block.
        :param computer_name_prefix: 
        :param custom_data: 
        :param data_disk: data_disk block.
        :param disable_password_authentication: 
        :param do_not_run_extensions_on_overprovisioned_machines: 
        :param eviction_policy: 
        :param health_probe_id: 
        :param identity: identity block.
        :param max_bid_price: 
        :param overprovision: 
        :param plan: plan block.
        :param priority: 
        :param provision_vm_agent: 
        :param proximity_placement_group_id: 
        :param rolling_upgrade_policy: rolling_upgrade_policy block.
        :param secret: secret block.
        :param single_placement_group: 
        :param source_image_id: 
        :param source_image_reference: source_image_reference block.
        :param tags: 
        :param timeouts: timeouts block.
        :param upgrade_mode: 
        :param zone_balance: 
        :param zones: 
        """
        if isinstance(lifecycle, dict):
            lifecycle = cdktf.TerraformResourceLifecycle(**lifecycle)
        if isinstance(timeouts, dict):
            timeouts = LinuxVirtualMachineScaleSetTimeouts(**timeouts)
        self._values: typing.Dict[str, typing.Any] = {
            "admin_username": admin_username,
            "instances": instances,
            "location": location,
            "name": name,
            "network_interface": network_interface,
            "os_disk": os_disk,
            "resource_group_name": resource_group_name,
            "sku": sku,
        }
        if count is not None:
            self._values["count"] = count
        if depends_on is not None:
            self._values["depends_on"] = depends_on
        if lifecycle is not None:
            self._values["lifecycle"] = lifecycle
        if provider is not None:
            self._values["provider"] = provider
        if additional_capabilities is not None:
            self._values["additional_capabilities"] = additional_capabilities
        if admin_password is not None:
            self._values["admin_password"] = admin_password
        if admin_ssh_key is not None:
            self._values["admin_ssh_key"] = admin_ssh_key
        if automatic_os_upgrade_policy is not None:
            self._values["automatic_os_upgrade_policy"] = automatic_os_upgrade_policy
        if boot_diagnostics is not None:
            self._values["boot_diagnostics"] = boot_diagnostics
        if computer_name_prefix is not None:
            self._values["computer_name_prefix"] = computer_name_prefix
        if custom_data is not None:
            self._values["custom_data"] = custom_data
        if data_disk is not None:
            self._values["data_disk"] = data_disk
        if disable_password_authentication is not None:
            self._values["disable_password_authentication"] = disable_password_authentication
        if do_not_run_extensions_on_overprovisioned_machines is not None:
            self._values["do_not_run_extensions_on_overprovisioned_machines"] = do_not_run_extensions_on_overprovisioned_machines
        if eviction_policy is not None:
            self._values["eviction_policy"] = eviction_policy
        if health_probe_id is not None:
            self._values["health_probe_id"] = health_probe_id
        if identity is not None:
            self._values["identity"] = identity
        if max_bid_price is not None:
            self._values["max_bid_price"] = max_bid_price
        if overprovision is not None:
            self._values["overprovision"] = overprovision
        if plan is not None:
            self._values["plan"] = plan
        if priority is not None:
            self._values["priority"] = priority
        if provision_vm_agent is not None:
            self._values["provision_vm_agent"] = provision_vm_agent
        if proximity_placement_group_id is not None:
            self._values["proximity_placement_group_id"] = proximity_placement_group_id
        if rolling_upgrade_policy is not None:
            self._values["rolling_upgrade_policy"] = rolling_upgrade_policy
        if secret is not None:
            self._values["secret"] = secret
        if single_placement_group is not None:
            self._values["single_placement_group"] = single_placement_group
        if source_image_id is not None:
            self._values["source_image_id"] = source_image_id
        if source_image_reference is not None:
            self._values["source_image_reference"] = source_image_reference
        if tags is not None:
            self._values["tags"] = tags
        if timeouts is not None:
            self._values["timeouts"] = timeouts
        if upgrade_mode is not None:
            self._values["upgrade_mode"] = upgrade_mode
        if zone_balance is not None:
            self._values["zone_balance"] = zone_balance
        if zones is not None:
            self._values["zones"] = zones

    @builtins.property
    def count(self) -> typing.Optional[jsii.Number]:
        """
        :stability: experimental
        """
        result = self._values.get("count")
        return result

    @builtins.property
    def depends_on(self) -> typing.Optional[typing.List[cdktf.TerraformResource]]:
        """
        :stability: experimental
        """
        result = self._values.get("depends_on")
        return result

    @builtins.property
    def lifecycle(self) -> typing.Optional[cdktf.TerraformResourceLifecycle]:
        """
        :stability: experimental
        """
        result = self._values.get("lifecycle")
        return result

    @builtins.property
    def provider(self) -> typing.Optional[cdktf.TerraformProvider]:
        """
        :stability: experimental
        """
        result = self._values.get("provider")
        return result

    @builtins.property
    def admin_username(self) -> builtins.str:
        result = self._values.get("admin_username")
        assert result is not None, "Required property 'admin_username' is missing"
        return result

    @builtins.property
    def instances(self) -> jsii.Number:
        result = self._values.get("instances")
        assert result is not None, "Required property 'instances' is missing"
        return result

    @builtins.property
    def location(self) -> builtins.str:
        result = self._values.get("location")
        assert result is not None, "Required property 'location' is missing"
        return result

    @builtins.property
    def name(self) -> builtins.str:
        result = self._values.get("name")
        assert result is not None, "Required property 'name' is missing"
        return result

    @builtins.property
    def network_interface(
        self,
    ) -> typing.List["LinuxVirtualMachineScaleSetNetworkInterface"]:
        """network_interface block."""
        result = self._values.get("network_interface")
        assert result is not None, "Required property 'network_interface' is missing"
        return result

    @builtins.property
    def os_disk(self) -> typing.List["LinuxVirtualMachineScaleSetOsDisk"]:
        """os_disk block."""
        result = self._values.get("os_disk")
        assert result is not None, "Required property 'os_disk' is missing"
        return result

    @builtins.property
    def resource_group_name(self) -> builtins.str:
        result = self._values.get("resource_group_name")
        assert result is not None, "Required property 'resource_group_name' is missing"
        return result

    @builtins.property
    def sku(self) -> builtins.str:
        result = self._values.get("sku")
        assert result is not None, "Required property 'sku' is missing"
        return result

    @builtins.property
    def additional_capabilities(
        self,
    ) -> typing.Optional[typing.List[LinuxVirtualMachineScaleSetAdditionalCapabilities]]:
        """additional_capabilities block."""
        result = self._values.get("additional_capabilities")
        return result

    @builtins.property
    def admin_password(self) -> typing.Optional[builtins.str]:
        result = self._values.get("admin_password")
        return result

    @builtins.property
    def admin_ssh_key(
        self,
    ) -> typing.Optional[typing.List[LinuxVirtualMachineScaleSetAdminSshKey]]:
        """admin_ssh_key block."""
        result = self._values.get("admin_ssh_key")
        return result

    @builtins.property
    def automatic_os_upgrade_policy(
        self,
    ) -> typing.Optional[typing.List[LinuxVirtualMachineScaleSetAutomaticOsUpgradePolicy]]:
        """automatic_os_upgrade_policy block."""
        result = self._values.get("automatic_os_upgrade_policy")
        return result

    @builtins.property
    def boot_diagnostics(
        self,
    ) -> typing.Optional[typing.List[LinuxVirtualMachineScaleSetBootDiagnostics]]:
        """boot_diagnostics block."""
        result = self._values.get("boot_diagnostics")
        return result

    @builtins.property
    def computer_name_prefix(self) -> typing.Optional[builtins.str]:
        result = self._values.get("computer_name_prefix")
        return result

    @builtins.property
    def custom_data(self) -> typing.Optional[builtins.str]:
        result = self._values.get("custom_data")
        return result

    @builtins.property
    def data_disk(
        self,
    ) -> typing.Optional[typing.List["LinuxVirtualMachineScaleSetDataDisk"]]:
        """data_disk block."""
        result = self._values.get("data_disk")
        return result

    @builtins.property
    def disable_password_authentication(self) -> typing.Optional[builtins.bool]:
        result = self._values.get("disable_password_authentication")
        return result

    @builtins.property
    def do_not_run_extensions_on_overprovisioned_machines(
        self,
    ) -> typing.Optional[builtins.bool]:
        result = self._values.get("do_not_run_extensions_on_overprovisioned_machines")
        return result

    @builtins.property
    def eviction_policy(self) -> typing.Optional[builtins.str]:
        result = self._values.get("eviction_policy")
        return result

    @builtins.property
    def health_probe_id(self) -> typing.Optional[builtins.str]:
        result = self._values.get("health_probe_id")
        return result

    @builtins.property
    def identity(
        self,
    ) -> typing.Optional[typing.List["LinuxVirtualMachineScaleSetIdentity"]]:
        """identity block."""
        result = self._values.get("identity")
        return result

    @builtins.property
    def max_bid_price(self) -> typing.Optional[jsii.Number]:
        result = self._values.get("max_bid_price")
        return result

    @builtins.property
    def overprovision(self) -> typing.Optional[builtins.bool]:
        result = self._values.get("overprovision")
        return result

    @builtins.property
    def plan(self) -> typing.Optional[typing.List["LinuxVirtualMachineScaleSetPlan"]]:
        """plan block."""
        result = self._values.get("plan")
        return result

    @builtins.property
    def priority(self) -> typing.Optional[builtins.str]:
        result = self._values.get("priority")
        return result

    @builtins.property
    def provision_vm_agent(self) -> typing.Optional[builtins.bool]:
        result = self._values.get("provision_vm_agent")
        return result

    @builtins.property
    def proximity_placement_group_id(self) -> typing.Optional[builtins.str]:
        result = self._values.get("proximity_placement_group_id")
        return result

    @builtins.property
    def rolling_upgrade_policy(
        self,
    ) -> typing.Optional[typing.List["LinuxVirtualMachineScaleSetRollingUpgradePolicy"]]:
        """rolling_upgrade_policy block."""
        result = self._values.get("rolling_upgrade_policy")
        return result

    @builtins.property
    def secret(
        self,
    ) -> typing.Optional[typing.List["LinuxVirtualMachineScaleSetSecret"]]:
        """secret block."""
        result = self._values.get("secret")
        return result

    @builtins.property
    def single_placement_group(self) -> typing.Optional[builtins.bool]:
        result = self._values.get("single_placement_group")
        return result

    @builtins.property
    def source_image_id(self) -> typing.Optional[builtins.str]:
        result = self._values.get("source_image_id")
        return result

    @builtins.property
    def source_image_reference(
        self,
    ) -> typing.Optional[typing.List["LinuxVirtualMachineScaleSetSourceImageReference"]]:
        """source_image_reference block."""
        result = self._values.get("source_image_reference")
        return result

    @builtins.property
    def tags(self) -> typing.Optional[typing.Mapping[builtins.str, builtins.str]]:
        result = self._values.get("tags")
        return result

    @builtins.property
    def timeouts(self) -> typing.Optional["LinuxVirtualMachineScaleSetTimeouts"]:
        """timeouts block."""
        result = self._values.get("timeouts")
        return result

    @builtins.property
    def upgrade_mode(self) -> typing.Optional[builtins.str]:
        result = self._values.get("upgrade_mode")
        return result

    @builtins.property
    def zone_balance(self) -> typing.Optional[builtins.bool]:
        result = self._values.get("zone_balance")
        return result

    @builtins.property
    def zones(self) -> typing.Optional[typing.List[builtins.str]]:
        result = self._values.get("zones")
        return result

    def __eq__(self, rhs: typing.Any) -> builtins.bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs: typing.Any) -> builtins.bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return "LinuxVirtualMachineScaleSetConfig(%s)" % ", ".join(
            k + "=" + repr(v) for k, v in self._values.items()
        )


@jsii.data_type(
    jsii_type="@cdktf/provider-azurerm.LinuxVirtualMachineScaleSetDataDisk",
    jsii_struct_bases=[],
    name_mapping={
        "caching": "caching",
        "disk_size_gb": "diskSizeGb",
        "lun": "lun",
        "storage_account_type": "storageAccountType",
        "disk_encryption_set_id": "diskEncryptionSetId",
        "write_accelerator_enabled": "writeAcceleratorEnabled",
    },
)
class LinuxVirtualMachineScaleSetDataDisk:
    def __init__(
        self,
        *,
        caching: builtins.str,
        disk_size_gb: jsii.Number,
        lun: jsii.Number,
        storage_account_type: builtins.str,
        disk_encryption_set_id: typing.Optional[builtins.str] = None,
        write_accelerator_enabled: typing.Optional[builtins.bool] = None,
    ) -> None:
        """
        :param caching: 
        :param disk_size_gb: 
        :param lun: 
        :param storage_account_type: 
        :param disk_encryption_set_id: 
        :param write_accelerator_enabled: 
        """
        self._values: typing.Dict[str, typing.Any] = {
            "caching": caching,
            "disk_size_gb": disk_size_gb,
            "lun": lun,
            "storage_account_type": storage_account_type,
        }
        if disk_encryption_set_id is not None:
            self._values["disk_encryption_set_id"] = disk_encryption_set_id
        if write_accelerator_enabled is not None:
            self._values["write_accelerator_enabled"] = write_accelerator_enabled

    @builtins.property
    def caching(self) -> builtins.str:
        result = self._values.get("caching")
        assert result is not None, "Required property 'caching' is missing"
        return result

    @builtins.property
    def disk_size_gb(self) -> jsii.Number:
        result = self._values.get("disk_size_gb")
        assert result is not None, "Required property 'disk_size_gb' is missing"
        return result

    @builtins.property
    def lun(self) -> jsii.Number:
        result = self._values.get("lun")
        assert result is not None, "Required property 'lun' is missing"
        return result

    @builtins.property
    def storage_account_type(self) -> builtins.str:
        result = self._values.get("storage_account_type")
        assert result is not None, "Required property 'storage_account_type' is missing"
        return result

    @builtins.property
    def disk_encryption_set_id(self) -> typing.Optional[builtins.str]:
        result = self._values.get("disk_encryption_set_id")
        return result

    @builtins.property
    def write_accelerator_enabled(self) -> typing.Optional[builtins.bool]:
        result = self._values.get("write_accelerator_enabled")
        return result

    def __eq__(self, rhs: typing.Any) -> builtins.bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs: typing.Any) -> builtins.bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return "LinuxVirtualMachineScaleSetDataDisk(%s)" % ", ".join(
            k + "=" + repr(v) for k, v in self._values.items()
        )


@jsii.data_type(
    jsii_type="@cdktf/provider-azurerm.LinuxVirtualMachineScaleSetIdentity",
    jsii_struct_bases=[],
    name_mapping={"type": "type", "identity_ids": "identityIds"},
)
class LinuxVirtualMachineScaleSetIdentity:
    def __init__(
        self,
        *,
        type: builtins.str,
        identity_ids: typing.Optional[typing.List[builtins.str]] = None,
    ) -> None:
        """
        :param type: 
        :param identity_ids: 
        """
        self._values: typing.Dict[str, typing.Any] = {
            "type": type,
        }
        if identity_ids is not None:
            self._values["identity_ids"] = identity_ids

    @builtins.property
    def type(self) -> builtins.str:
        result = self._values.get("type")
        assert result is not None, "Required property 'type' is missing"
        return result

    @builtins.property
    def identity_ids(self) -> typing.Optional[typing.List[builtins.str]]:
        result = self._values.get("identity_ids")
        return result

    def __eq__(self, rhs: typing.Any) -> builtins.bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs: typing.Any) -> builtins.bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return "LinuxVirtualMachineScaleSetIdentity(%s)" % ", ".join(
            k + "=" + repr(v) for k, v in self._values.items()
        )


@jsii.data_type(
    jsii_type="@cdktf/provider-azurerm.LinuxVirtualMachineScaleSetNetworkInterface",
    jsii_struct_bases=[],
    name_mapping={
        "ip_configuration": "ipConfiguration",
        "name": "name",
        "dns_servers": "dnsServers",
        "enable_accelerated_networking": "enableAcceleratedNetworking",
        "enable_ip_forwarding": "enableIpForwarding",
        "network_security_group_id": "networkSecurityGroupId",
        "primary": "primary",
    },
)
class LinuxVirtualMachineScaleSetNetworkInterface:
    def __init__(
        self,
        *,
        ip_configuration: typing.List["LinuxVirtualMachineScaleSetNetworkInterfaceIpConfiguration"],
        name: builtins.str,
        dns_servers: typing.Optional[typing.List[builtins.str]] = None,
        enable_accelerated_networking: typing.Optional[builtins.bool] = None,
        enable_ip_forwarding: typing.Optional[builtins.bool] = None,
        network_security_group_id: typing.Optional[builtins.str] = None,
        primary: typing.Optional[builtins.bool] = None,
    ) -> None:
        """
        :param ip_configuration: ip_configuration block.
        :param name: 
        :param dns_servers: 
        :param enable_accelerated_networking: 
        :param enable_ip_forwarding: 
        :param network_security_group_id: 
        :param primary: 
        """
        self._values: typing.Dict[str, typing.Any] = {
            "ip_configuration": ip_configuration,
            "name": name,
        }
        if dns_servers is not None:
            self._values["dns_servers"] = dns_servers
        if enable_accelerated_networking is not None:
            self._values["enable_accelerated_networking"] = enable_accelerated_networking
        if enable_ip_forwarding is not None:
            self._values["enable_ip_forwarding"] = enable_ip_forwarding
        if network_security_group_id is not None:
            self._values["network_security_group_id"] = network_security_group_id
        if primary is not None:
            self._values["primary"] = primary

    @builtins.property
    def ip_configuration(
        self,
    ) -> typing.List["LinuxVirtualMachineScaleSetNetworkInterfaceIpConfiguration"]:
        """ip_configuration block."""
        result = self._values.get("ip_configuration")
        assert result is not None, "Required property 'ip_configuration' is missing"
        return result

    @builtins.property
    def name(self) -> builtins.str:
        result = self._values.get("name")
        assert result is not None, "Required property 'name' is missing"
        return result

    @builtins.property
    def dns_servers(self) -> typing.Optional[typing.List[builtins.str]]:
        result = self._values.get("dns_servers")
        return result

    @builtins.property
    def enable_accelerated_networking(self) -> typing.Optional[builtins.bool]:
        result = self._values.get("enable_accelerated_networking")
        return result

    @builtins.property
    def enable_ip_forwarding(self) -> typing.Optional[builtins.bool]:
        result = self._values.get("enable_ip_forwarding")
        return result

    @builtins.property
    def network_security_group_id(self) -> typing.Optional[builtins.str]:
        result = self._values.get("network_security_group_id")
        return result

    @builtins.property
    def primary(self) -> typing.Optional[builtins.bool]:
        result = self._values.get("primary")
        return result

    def __eq__(self, rhs: typing.Any) -> builtins.bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs: typing.Any) -> builtins.bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return "LinuxVirtualMachineScaleSetNetworkInterface(%s)" % ", ".join(
            k + "=" + repr(v) for k, v in self._values.items()
        )


@jsii.data_type(
    jsii_type="@cdktf/provider-azurerm.LinuxVirtualMachineScaleSetNetworkInterfaceIpConfiguration",
    jsii_struct_bases=[],
    name_mapping={
        "name": "name",
        "application_gateway_backend_address_pool_ids": "applicationGatewayBackendAddressPoolIds",
        "application_security_group_ids": "applicationSecurityGroupIds",
        "load_balancer_backend_address_pool_ids": "loadBalancerBackendAddressPoolIds",
        "load_balancer_inbound_nat_rules_ids": "loadBalancerInboundNatRulesIds",
        "primary": "primary",
        "public_ip_address": "publicIpAddress",
        "subnet_id": "subnetId",
        "version": "version",
    },
)
class LinuxVirtualMachineScaleSetNetworkInterfaceIpConfiguration:
    def __init__(
        self,
        *,
        name: builtins.str,
        application_gateway_backend_address_pool_ids: typing.Optional[typing.List[builtins.str]] = None,
        application_security_group_ids: typing.Optional[typing.List[builtins.str]] = None,
        load_balancer_backend_address_pool_ids: typing.Optional[typing.List[builtins.str]] = None,
        load_balancer_inbound_nat_rules_ids: typing.Optional[typing.List[builtins.str]] = None,
        primary: typing.Optional[builtins.bool] = None,
        public_ip_address: typing.Optional[typing.List["LinuxVirtualMachineScaleSetNetworkInterfaceIpConfigurationPublicIpAddress"]] = None,
        subnet_id: typing.Optional[builtins.str] = None,
        version: typing.Optional[builtins.str] = None,
    ) -> None:
        """
        :param name: 
        :param application_gateway_backend_address_pool_ids: 
        :param application_security_group_ids: 
        :param load_balancer_backend_address_pool_ids: 
        :param load_balancer_inbound_nat_rules_ids: 
        :param primary: 
        :param public_ip_address: public_ip_address block.
        :param subnet_id: 
        :param version: 
        """
        self._values: typing.Dict[str, typing.Any] = {
            "name": name,
        }
        if application_gateway_backend_address_pool_ids is not None:
            self._values["application_gateway_backend_address_pool_ids"] = application_gateway_backend_address_pool_ids
        if application_security_group_ids is not None:
            self._values["application_security_group_ids"] = application_security_group_ids
        if load_balancer_backend_address_pool_ids is not None:
            self._values["load_balancer_backend_address_pool_ids"] = load_balancer_backend_address_pool_ids
        if load_balancer_inbound_nat_rules_ids is not None:
            self._values["load_balancer_inbound_nat_rules_ids"] = load_balancer_inbound_nat_rules_ids
        if primary is not None:
            self._values["primary"] = primary
        if public_ip_address is not None:
            self._values["public_ip_address"] = public_ip_address
        if subnet_id is not None:
            self._values["subnet_id"] = subnet_id
        if version is not None:
            self._values["version"] = version

    @builtins.property
    def name(self) -> builtins.str:
        result = self._values.get("name")
        assert result is not None, "Required property 'name' is missing"
        return result

    @builtins.property
    def application_gateway_backend_address_pool_ids(
        self,
    ) -> typing.Optional[typing.List[builtins.str]]:
        result = self._values.get("application_gateway_backend_address_pool_ids")
        return result

    @builtins.property
    def application_security_group_ids(
        self,
    ) -> typing.Optional[typing.List[builtins.str]]:
        result = self._values.get("application_security_group_ids")
        return result

    @builtins.property
    def load_balancer_backend_address_pool_ids(
        self,
    ) -> typing.Optional[typing.List[builtins.str]]:
        result = self._values.get("load_balancer_backend_address_pool_ids")
        return result

    @builtins.property
    def load_balancer_inbound_nat_rules_ids(
        self,
    ) -> typing.Optional[typing.List[builtins.str]]:
        result = self._values.get("load_balancer_inbound_nat_rules_ids")
        return result

    @builtins.property
    def primary(self) -> typing.Optional[builtins.bool]:
        result = self._values.get("primary")
        return result

    @builtins.property
    def public_ip_address(
        self,
    ) -> typing.Optional[typing.List["LinuxVirtualMachineScaleSetNetworkInterfaceIpConfigurationPublicIpAddress"]]:
        """public_ip_address block."""
        result = self._values.get("public_ip_address")
        return result

    @builtins.property
    def subnet_id(self) -> typing.Optional[builtins.str]:
        result = self._values.get("subnet_id")
        return result

    @builtins.property
    def version(self) -> typing.Optional[builtins.str]:
        result = self._values.get("version")
        return result

    def __eq__(self, rhs: typing.Any) -> builtins.bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs: typing.Any) -> builtins.bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return "LinuxVirtualMachineScaleSetNetworkInterfaceIpConfiguration(%s)" % ", ".join(
            k + "=" + repr(v) for k, v in self._values.items()
        )


@jsii.data_type(
    jsii_type="@cdktf/provider-azurerm.LinuxVirtualMachineScaleSetNetworkInterfaceIpConfigurationPublicIpAddress",
    jsii_struct_bases=[],
    name_mapping={
        "name": "name",
        "domain_name_label": "domainNameLabel",
        "idle_timeout_in_minutes": "idleTimeoutInMinutes",
        "ip_tag": "ipTag",
        "public_ip_prefix_id": "publicIpPrefixId",
    },
)
class LinuxVirtualMachineScaleSetNetworkInterfaceIpConfigurationPublicIpAddress:
    def __init__(
        self,
        *,
        name: builtins.str,
        domain_name_label: typing.Optional[builtins.str] = None,
        idle_timeout_in_minutes: typing.Optional[jsii.Number] = None,
        ip_tag: typing.Optional[typing.List["LinuxVirtualMachineScaleSetNetworkInterfaceIpConfigurationPublicIpAddressIpTag"]] = None,
        public_ip_prefix_id: typing.Optional[builtins.str] = None,
    ) -> None:
        """
        :param name: 
        :param domain_name_label: 
        :param idle_timeout_in_minutes: 
        :param ip_tag: ip_tag block.
        :param public_ip_prefix_id: 
        """
        self._values: typing.Dict[str, typing.Any] = {
            "name": name,
        }
        if domain_name_label is not None:
            self._values["domain_name_label"] = domain_name_label
        if idle_timeout_in_minutes is not None:
            self._values["idle_timeout_in_minutes"] = idle_timeout_in_minutes
        if ip_tag is not None:
            self._values["ip_tag"] = ip_tag
        if public_ip_prefix_id is not None:
            self._values["public_ip_prefix_id"] = public_ip_prefix_id

    @builtins.property
    def name(self) -> builtins.str:
        result = self._values.get("name")
        assert result is not None, "Required property 'name' is missing"
        return result

    @builtins.property
    def domain_name_label(self) -> typing.Optional[builtins.str]:
        result = self._values.get("domain_name_label")
        return result

    @builtins.property
    def idle_timeout_in_minutes(self) -> typing.Optional[jsii.Number]:
        result = self._values.get("idle_timeout_in_minutes")
        return result

    @builtins.property
    def ip_tag(
        self,
    ) -> typing.Optional[typing.List["LinuxVirtualMachineScaleSetNetworkInterfaceIpConfigurationPublicIpAddressIpTag"]]:
        """ip_tag block."""
        result = self._values.get("ip_tag")
        return result

    @builtins.property
    def public_ip_prefix_id(self) -> typing.Optional[builtins.str]:
        result = self._values.get("public_ip_prefix_id")
        return result

    def __eq__(self, rhs: typing.Any) -> builtins.bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs: typing.Any) -> builtins.bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return "LinuxVirtualMachineScaleSetNetworkInterfaceIpConfigurationPublicIpAddress(%s)" % ", ".join(
            k + "=" + repr(v) for k, v in self._values.items()
        )


@jsii.data_type(
    jsii_type="@cdktf/provider-azurerm.LinuxVirtualMachineScaleSetNetworkInterfaceIpConfigurationPublicIpAddressIpTag",
    jsii_struct_bases=[],
    name_mapping={"tag": "tag", "type": "type"},
)
class LinuxVirtualMachineScaleSetNetworkInterfaceIpConfigurationPublicIpAddressIpTag:
    def __init__(self, *, tag: builtins.str, type: builtins.str) -> None:
        """
        :param tag: 
        :param type: 
        """
        self._values: typing.Dict[str, typing.Any] = {
            "tag": tag,
            "type": type,
        }

    @builtins.property
    def tag(self) -> builtins.str:
        result = self._values.get("tag")
        assert result is not None, "Required property 'tag' is missing"
        return result

    @builtins.property
    def type(self) -> builtins.str:
        result = self._values.get("type")
        assert result is not None, "Required property 'type' is missing"
        return result

    def __eq__(self, rhs: typing.Any) -> builtins.bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs: typing.Any) -> builtins.bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return "LinuxVirtualMachineScaleSetNetworkInterfaceIpConfigurationPublicIpAddressIpTag(%s)" % ", ".join(
            k + "=" + repr(v) for k, v in self._values.items()
        )


@jsii.data_type(
    jsii_type="@cdktf/provider-azurerm.LinuxVirtualMachineScaleSetOsDisk",
    jsii_struct_bases=[],
    name_mapping={
        "caching": "caching",
        "storage_account_type": "storageAccountType",
        "diff_disk_settings": "diffDiskSettings",
        "disk_encryption_set_id": "diskEncryptionSetId",
        "disk_size_gb": "diskSizeGb",
        "write_accelerator_enabled": "writeAcceleratorEnabled",
    },
)
class LinuxVirtualMachineScaleSetOsDisk:
    def __init__(
        self,
        *,
        caching: builtins.str,
        storage_account_type: builtins.str,
        diff_disk_settings: typing.Optional[typing.List["LinuxVirtualMachineScaleSetOsDiskDiffDiskSettings"]] = None,
        disk_encryption_set_id: typing.Optional[builtins.str] = None,
        disk_size_gb: typing.Optional[jsii.Number] = None,
        write_accelerator_enabled: typing.Optional[builtins.bool] = None,
    ) -> None:
        """
        :param caching: 
        :param storage_account_type: 
        :param diff_disk_settings: diff_disk_settings block.
        :param disk_encryption_set_id: 
        :param disk_size_gb: 
        :param write_accelerator_enabled: 
        """
        self._values: typing.Dict[str, typing.Any] = {
            "caching": caching,
            "storage_account_type": storage_account_type,
        }
        if diff_disk_settings is not None:
            self._values["diff_disk_settings"] = diff_disk_settings
        if disk_encryption_set_id is not None:
            self._values["disk_encryption_set_id"] = disk_encryption_set_id
        if disk_size_gb is not None:
            self._values["disk_size_gb"] = disk_size_gb
        if write_accelerator_enabled is not None:
            self._values["write_accelerator_enabled"] = write_accelerator_enabled

    @builtins.property
    def caching(self) -> builtins.str:
        result = self._values.get("caching")
        assert result is not None, "Required property 'caching' is missing"
        return result

    @builtins.property
    def storage_account_type(self) -> builtins.str:
        result = self._values.get("storage_account_type")
        assert result is not None, "Required property 'storage_account_type' is missing"
        return result

    @builtins.property
    def diff_disk_settings(
        self,
    ) -> typing.Optional[typing.List["LinuxVirtualMachineScaleSetOsDiskDiffDiskSettings"]]:
        """diff_disk_settings block."""
        result = self._values.get("diff_disk_settings")
        return result

    @builtins.property
    def disk_encryption_set_id(self) -> typing.Optional[builtins.str]:
        result = self._values.get("disk_encryption_set_id")
        return result

    @builtins.property
    def disk_size_gb(self) -> typing.Optional[jsii.Number]:
        result = self._values.get("disk_size_gb")
        return result

    @builtins.property
    def write_accelerator_enabled(self) -> typing.Optional[builtins.bool]:
        result = self._values.get("write_accelerator_enabled")
        return result

    def __eq__(self, rhs: typing.Any) -> builtins.bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs: typing.Any) -> builtins.bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return "LinuxVirtualMachineScaleSetOsDisk(%s)" % ", ".join(
            k + "=" + repr(v) for k, v in self._values.items()
        )


@jsii.data_type(
    jsii_type="@cdktf/provider-azurerm.LinuxVirtualMachineScaleSetOsDiskDiffDiskSettings",
    jsii_struct_bases=[],
    name_mapping={"option": "option"},
)
class LinuxVirtualMachineScaleSetOsDiskDiffDiskSettings:
    def __init__(self, *, option: builtins.str) -> None:
        """
        :param option: 
        """
        self._values: typing.Dict[str, typing.Any] = {
            "option": option,
        }

    @builtins.property
    def option(self) -> builtins.str:
        result = self._values.get("option")
        assert result is not None, "Required property 'option' is missing"
        return result

    def __eq__(self, rhs: typing.Any) -> builtins.bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs: typing.Any) -> builtins.bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return "LinuxVirtualMachineScaleSetOsDiskDiffDiskSettings(%s)" % ", ".join(
            k + "=" + repr(v) for k, v in self._values.items()
        )


@jsii.data_type(
    jsii_type="@cdktf/provider-azurerm.LinuxVirtualMachineScaleSetPlan",
    jsii_struct_bases=[],
    name_mapping={"name": "name", "product": "product", "publisher": "publisher"},
)
class LinuxVirtualMachineScaleSetPlan:
    def __init__(
        self,
        *,
        name: builtins.str,
        product: builtins.str,
        publisher: builtins.str,
    ) -> None:
        """
        :param name: 
        :param product: 
        :param publisher: 
        """
        self._values: typing.Dict[str, typing.Any] = {
            "name": name,
            "product": product,
            "publisher": publisher,
        }

    @builtins.property
    def name(self) -> builtins.str:
        result = self._values.get("name")
        assert result is not None, "Required property 'name' is missing"
        return result

    @builtins.property
    def product(self) -> builtins.str:
        result = self._values.get("product")
        assert result is not None, "Required property 'product' is missing"
        return result

    @builtins.property
    def publisher(self) -> builtins.str:
        result = self._values.get("publisher")
        assert result is not None, "Required property 'publisher' is missing"
        return result

    def __eq__(self, rhs: typing.Any) -> builtins.bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs: typing.Any) -> builtins.bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return "LinuxVirtualMachineScaleSetPlan(%s)" % ", ".join(
            k + "=" + repr(v) for k, v in self._values.items()
        )


@jsii.data_type(
    jsii_type="@cdktf/provider-azurerm.LinuxVirtualMachineScaleSetRollingUpgradePolicy",
    jsii_struct_bases=[],
    name_mapping={
        "max_batch_instance_percent": "maxBatchInstancePercent",
        "max_unhealthy_instance_percent": "maxUnhealthyInstancePercent",
        "max_unhealthy_upgraded_instance_percent": "maxUnhealthyUpgradedInstancePercent",
        "pause_time_between_batches": "pauseTimeBetweenBatches",
    },
)
class LinuxVirtualMachineScaleSetRollingUpgradePolicy:
    def __init__(
        self,
        *,
        max_batch_instance_percent: jsii.Number,
        max_unhealthy_instance_percent: jsii.Number,
        max_unhealthy_upgraded_instance_percent: jsii.Number,
        pause_time_between_batches: builtins.str,
    ) -> None:
        """
        :param max_batch_instance_percent: 
        :param max_unhealthy_instance_percent: 
        :param max_unhealthy_upgraded_instance_percent: 
        :param pause_time_between_batches: 
        """
        self._values: typing.Dict[str, typing.Any] = {
            "max_batch_instance_percent": max_batch_instance_percent,
            "max_unhealthy_instance_percent": max_unhealthy_instance_percent,
            "max_unhealthy_upgraded_instance_percent": max_unhealthy_upgraded_instance_percent,
            "pause_time_between_batches": pause_time_between_batches,
        }

    @builtins.property
    def max_batch_instance_percent(self) -> jsii.Number:
        result = self._values.get("max_batch_instance_percent")
        assert result is not None, "Required property 'max_batch_instance_percent' is missing"
        return result

    @builtins.property
    def max_unhealthy_instance_percent(self) -> jsii.Number:
        result = self._values.get("max_unhealthy_instance_percent")
        assert result is not None, "Required property 'max_unhealthy_instance_percent' is missing"
        return result

    @builtins.property
    def max_unhealthy_upgraded_instance_percent(self) -> jsii.Number:
        result = self._values.get("max_unhealthy_upgraded_instance_percent")
        assert result is not None, "Required property 'max_unhealthy_upgraded_instance_percent' is missing"
        return result

    @builtins.property
    def pause_time_between_batches(self) -> builtins.str:
        result = self._values.get("pause_time_between_batches")
        assert result is not None, "Required property 'pause_time_between_batches' is missing"
        return result

    def __eq__(self, rhs: typing.Any) -> builtins.bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs: typing.Any) -> builtins.bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return "LinuxVirtualMachineScaleSetRollingUpgradePolicy(%s)" % ", ".join(
            k + "=" + repr(v) for k, v in self._values.items()
        )


@jsii.data_type(
    jsii_type="@cdktf/provider-azurerm.LinuxVirtualMachineScaleSetSecret",
    jsii_struct_bases=[],
    name_mapping={"certificate": "certificate", "key_vault_id": "keyVaultId"},
)
class LinuxVirtualMachineScaleSetSecret:
    def __init__(
        self,
        *,
        certificate: typing.List["LinuxVirtualMachineScaleSetSecretCertificate"],
        key_vault_id: builtins.str,
    ) -> None:
        """
        :param certificate: certificate block.
        :param key_vault_id: 
        """
        self._values: typing.Dict[str, typing.Any] = {
            "certificate": certificate,
            "key_vault_id": key_vault_id,
        }

    @builtins.property
    def certificate(
        self,
    ) -> typing.List["LinuxVirtualMachineScaleSetSecretCertificate"]:
        """certificate block."""
        result = self._values.get("certificate")
        assert result is not None, "Required property 'certificate' is missing"
        return result

    @builtins.property
    def key_vault_id(self) -> builtins.str:
        result = self._values.get("key_vault_id")
        assert result is not None, "Required property 'key_vault_id' is missing"
        return result

    def __eq__(self, rhs: typing.Any) -> builtins.bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs: typing.Any) -> builtins.bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return "LinuxVirtualMachineScaleSetSecret(%s)" % ", ".join(
            k + "=" + repr(v) for k, v in self._values.items()
        )


@jsii.data_type(
    jsii_type="@cdktf/provider-azurerm.LinuxVirtualMachineScaleSetSecretCertificate",
    jsii_struct_bases=[],
    name_mapping={"url": "url"},
)
class LinuxVirtualMachineScaleSetSecretCertificate:
    def __init__(self, *, url: builtins.str) -> None:
        """
        :param url: 
        """
        self._values: typing.Dict[str, typing.Any] = {
            "url": url,
        }

    @builtins.property
    def url(self) -> builtins.str:
        result = self._values.get("url")
        assert result is not None, "Required property 'url' is missing"
        return result

    def __eq__(self, rhs: typing.Any) -> builtins.bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs: typing.Any) -> builtins.bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return "LinuxVirtualMachineScaleSetSecretCertificate(%s)" % ", ".join(
            k + "=" + repr(v) for k, v in self._values.items()
        )


@jsii.data_type(
    jsii_type="@cdktf/provider-azurerm.LinuxVirtualMachineScaleSetSourceImageReference",
    jsii_struct_bases=[],
    name_mapping={
        "offer": "offer",
        "publisher": "publisher",
        "sku": "sku",
        "version": "version",
    },
)
class LinuxVirtualMachineScaleSetSourceImageReference:
    def __init__(
        self,
        *,
        offer: builtins.str,
        publisher: builtins.str,
        sku: builtins.str,
        version: builtins.str,
    ) -> None:
        """
        :param offer: 
        :param publisher: 
        :param sku: 
        :param version: 
        """
        self._values: typing.Dict[str, typing.Any] = {
            "offer": offer,
            "publisher": publisher,
            "sku": sku,
            "version": version,
        }

    @builtins.property
    def offer(self) -> builtins.str:
        result = self._values.get("offer")
        assert result is not None, "Required property 'offer' is missing"
        return result

    @builtins.property
    def publisher(self) -> builtins.str:
        result = self._values.get("publisher")
        assert result is not None, "Required property 'publisher' is missing"
        return result

    @builtins.property
    def sku(self) -> builtins.str:
        result = self._values.get("sku")
        assert result is not None, "Required property 'sku' is missing"
        return result

    @builtins.property
    def version(self) -> builtins.str:
        result = self._values.get("version")
        assert result is not None, "Required property 'version' is missing"
        return result

    def __eq__(self, rhs: typing.Any) -> builtins.bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs: typing.Any) -> builtins.bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return "LinuxVirtualMachineScaleSetSourceImageReference(%s)" % ", ".join(
            k + "=" + repr(v) for k, v in self._values.items()
        )


@jsii.data_type(
    jsii_type="@cdktf/provider-azurerm.LinuxVirtualMachineScaleSetTimeouts",
    jsii_struct_bases=[],
    name_mapping={
        "create": "create",
        "delete": "delete",
        "read": "read",
        "update": "update",
    },
)
class LinuxVirtualMachineScaleSetTimeouts:
    def __init__(
        self,
        *,
        create: typing.Optional[builtins.str] = None,
        delete: typing.Optional[builtins.str] = None,
        read: typing.Optional[builtins.str] = None,
        update: typing.Optional[builtins.str] = None,
    ) -> None:
        """
        :param create: 
        :param delete: 
        :param read: 
        :param update: 
        """
        self._values: typing.Dict[str, typing.Any] = {}
        if create is not None:
            self._values["create"] = create
        if delete is not None:
            self._values["delete"] = delete
        if read is not None:
            self._values["read"] = read
        if update is not None:
            self._values["update"] = update

    @builtins.property
    def create(self) -> typing.Optional[builtins.str]:
        result = self._values.get("create")
        return result

    @builtins.property
    def delete(self) -> typing.Optional[builtins.str]:
        result = self._values.get("delete")
        return result

    @builtins.property
    def read(self) -> typing.Optional[builtins.str]:
        result = self._values.get("read")
        return result

    @builtins.property
    def update(self) -> typing.Optional[builtins.str]:
        result = self._values.get("update")
        return result

    def __eq__(self, rhs: typing.Any) -> builtins.bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs: typing.Any) -> builtins.bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return "LinuxVirtualMachineScaleSetTimeouts(%s)" % ", ".join(
            k + "=" + repr(v) for k, v in self._values.items()
        )


@jsii.data_type(
    jsii_type="@cdktf/provider-azurerm.LinuxVirtualMachineSecret",
    jsii_struct_bases=[],
    name_mapping={"certificate": "certificate", "key_vault_id": "keyVaultId"},
)
class LinuxVirtualMachineSecret:
    def __init__(
        self,
        *,
        certificate: typing.List["LinuxVirtualMachineSecretCertificate"],
        key_vault_id: builtins.str,
    ) -> None:
        """
        :param certificate: certificate block.
        :param key_vault_id: 
        """
        self._values: typing.Dict[str, typing.Any] = {
            "certificate": certificate,
            "key_vault_id": key_vault_id,
        }

    @builtins.property
    def certificate(self) -> typing.List["LinuxVirtualMachineSecretCertificate"]:
        """certificate block."""
        result = self._values.get("certificate")
        assert result is not None, "Required property 'certificate' is missing"
        return result

    @builtins.property
    def key_vault_id(self) -> builtins.str:
        result = self._values.get("key_vault_id")
        assert result is not None, "Required property 'key_vault_id' is missing"
        return result

    def __eq__(self, rhs: typing.Any) -> builtins.bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs: typing.Any) -> builtins.bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return "LinuxVirtualMachineSecret(%s)" % ", ".join(
            k + "=" + repr(v) for k, v in self._values.items()
        )


@jsii.data_type(
    jsii_type="@cdktf/provider-azurerm.LinuxVirtualMachineSecretCertificate",
    jsii_struct_bases=[],
    name_mapping={"url": "url"},
)
class LinuxVirtualMachineSecretCertificate:
    def __init__(self, *, url: builtins.str) -> None:
        """
        :param url: 
        """
        self._values: typing.Dict[str, typing.Any] = {
            "url": url,
        }

    @builtins.property
    def url(self) -> builtins.str:
        result = self._values.get("url")
        assert result is not None, "Required property 'url' is missing"
        return result

    def __eq__(self, rhs: typing.Any) -> builtins.bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs: typing.Any) -> builtins.bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return "LinuxVirtualMachineSecretCertificate(%s)" % ", ".join(
            k + "=" + repr(v) for k, v in self._values.items()
        )


@jsii.data_type(
    jsii_type="@cdktf/provider-azurerm.LinuxVirtualMachineSourceImageReference",
    jsii_struct_bases=[],
    name_mapping={
        "offer": "offer",
        "publisher": "publisher",
        "sku": "sku",
        "version": "version",
    },
)
class LinuxVirtualMachineSourceImageReference:
    def __init__(
        self,
        *,
        offer: builtins.str,
        publisher: builtins.str,
        sku: builtins.str,
        version: builtins.str,
    ) -> None:
        """
        :param offer: 
        :param publisher: 
        :param sku: 
        :param version: 
        """
        self._values: typing.Dict[str, typing.Any] = {
            "offer": offer,
            "publisher": publisher,
            "sku": sku,
            "version": version,
        }

    @builtins.property
    def offer(self) -> builtins.str:
        result = self._values.get("offer")
        assert result is not None, "Required property 'offer' is missing"
        return result

    @builtins.property
    def publisher(self) -> builtins.str:
        result = self._values.get("publisher")
        assert result is not None, "Required property 'publisher' is missing"
        return result

    @builtins.property
    def sku(self) -> builtins.str:
        result = self._values.get("sku")
        assert result is not None, "Required property 'sku' is missing"
        return result

    @builtins.property
    def version(self) -> builtins.str:
        result = self._values.get("version")
        assert result is not None, "Required property 'version' is missing"
        return result

    def __eq__(self, rhs: typing.Any) -> builtins.bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs: typing.Any) -> builtins.bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return "LinuxVirtualMachineSourceImageReference(%s)" % ", ".join(
            k + "=" + repr(v) for k, v in self._values.items()
        )


@jsii.data_type(
    jsii_type="@cdktf/provider-azurerm.LinuxVirtualMachineTimeouts",
    jsii_struct_bases=[],
    name_mapping={
        "create": "create",
        "delete": "delete",
        "read": "read",
        "update": "update",
    },
)
class LinuxVirtualMachineTimeouts:
    def __init__(
        self,
        *,
        create: typing.Optional[builtins.str] = None,
        delete: typing.Optional[builtins.str] = None,
        read: typing.Optional[builtins.str] = None,
        update: typing.Optional[builtins.str] = None,
    ) -> None:
        """
        :param create: 
        :param delete: 
        :param read: 
        :param update: 
        """
        self._values: typing.Dict[str, typing.Any] = {}
        if create is not None:
            self._values["create"] = create
        if delete is not None:
            self._values["delete"] = delete
        if read is not None:
            self._values["read"] = read
        if update is not None:
            self._values["update"] = update

    @builtins.property
    def create(self) -> typing.Optional[builtins.str]:
        result = self._values.get("create")
        return result

    @builtins.property
    def delete(self) -> typing.Optional[builtins.str]:
        result = self._values.get("delete")
        return result

    @builtins.property
    def read(self) -> typing.Optional[builtins.str]:
        result = self._values.get("read")
        return result

    @builtins.property
    def update(self) -> typing.Optional[builtins.str]:
        result = self._values.get("update")
        return result

    def __eq__(self, rhs: typing.Any) -> builtins.bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs: typing.Any) -> builtins.bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return "LinuxVirtualMachineTimeouts(%s)" % ", ".join(
            k + "=" + repr(v) for k, v in self._values.items()
        )


class LocalNetworkGateway(
    cdktf.TerraformResource,
    metaclass=jsii.JSIIMeta,
    jsii_type="@cdktf/provider-azurerm.LocalNetworkGateway",
):
    def __init__(
        self,
        scope: constructs.Construct,
        id: builtins.str,
        *,
        address_space: typing.List[builtins.str],
        gateway_address: builtins.str,
        location: builtins.str,
        name: builtins.str,
        resource_group_name: builtins.str,
        bgp_settings: typing.Optional[typing.List["LocalNetworkGatewayBgpSettings"]] = None,
        tags: typing.Optional[typing.Mapping[builtins.str, builtins.str]] = None,
        timeouts: typing.Optional["LocalNetworkGatewayTimeouts"] = None,
        count: typing.Optional[jsii.Number] = None,
        depends_on: typing.Optional[typing.List[cdktf.TerraformResource]] = None,
        lifecycle: typing.Optional[cdktf.TerraformResourceLifecycle] = None,
        provider: typing.Optional[cdktf.TerraformProvider] = None,
    ) -> None:
        """
        :param scope: -
        :param id: -
        :param address_space: 
        :param gateway_address: 
        :param location: 
        :param name: 
        :param resource_group_name: 
        :param bgp_settings: bgp_settings block.
        :param tags: 
        :param timeouts: timeouts block.
        :param count: 
        :param depends_on: 
        :param lifecycle: 
        :param provider: 
        """
        config = LocalNetworkGatewayConfig(
            address_space=address_space,
            gateway_address=gateway_address,
            location=location,
            name=name,
            resource_group_name=resource_group_name,
            bgp_settings=bgp_settings,
            tags=tags,
            timeouts=timeouts,
            count=count,
            depends_on=depends_on,
            lifecycle=lifecycle,
            provider=provider,
        )

        jsii.create(LocalNetworkGateway, self, [scope, id, config])

    @jsii.member(jsii_name="synthesizeAttributes")
    def _synthesize_attributes(self) -> typing.Mapping[builtins.str, typing.Any]:
        return jsii.invoke(self, "synthesizeAttributes", [])

    @builtins.property # type: ignore
    @jsii.member(jsii_name="addressSpace")
    def address_space(self) -> typing.List[builtins.str]:
        return jsii.get(self, "addressSpace")

    @address_space.setter # type: ignore
    def address_space(self, value: typing.List[builtins.str]) -> None:
        jsii.set(self, "addressSpace", value)

    @builtins.property # type: ignore
    @jsii.member(jsii_name="gatewayAddress")
    def gateway_address(self) -> builtins.str:
        return jsii.get(self, "gatewayAddress")

    @gateway_address.setter # type: ignore
    def gateway_address(self, value: builtins.str) -> None:
        jsii.set(self, "gatewayAddress", value)

    @builtins.property # type: ignore
    @jsii.member(jsii_name="location")
    def location(self) -> builtins.str:
        return jsii.get(self, "location")

    @location.setter # type: ignore
    def location(self, value: builtins.str) -> None:
        jsii.set(self, "location", value)

    @builtins.property # type: ignore
    @jsii.member(jsii_name="name")
    def name(self) -> builtins.str:
        return jsii.get(self, "name")

    @name.setter # type: ignore
    def name(self, value: builtins.str) -> None:
        jsii.set(self, "name", value)

    @builtins.property # type: ignore
    @jsii.member(jsii_name="resourceGroupName")
    def resource_group_name(self) -> builtins.str:
        return jsii.get(self, "resourceGroupName")

    @resource_group_name.setter # type: ignore
    def resource_group_name(self, value: builtins.str) -> None:
        jsii.set(self, "resourceGroupName", value)

    @builtins.property # type: ignore
    @jsii.member(jsii_name="bgpSettings")
    def bgp_settings(
        self,
    ) -> typing.Optional[typing.List["LocalNetworkGatewayBgpSettings"]]:
        return jsii.get(self, "bgpSettings")

    @bgp_settings.setter # type: ignore
    def bgp_settings(
        self,
        value: typing.Optional[typing.List["LocalNetworkGatewayBgpSettings"]],
    ) -> None:
        jsii.set(self, "bgpSettings", value)

    @builtins.property # type: ignore
    @jsii.member(jsii_name="id")
    def id(self) -> typing.Optional[builtins.str]:
        return jsii.get(self, "id")

    @id.setter # type: ignore
    def id(self, value: typing.Optional[builtins.str]) -> None:
        jsii.set(self, "id", value)

    @builtins.property # type: ignore
    @jsii.member(jsii_name="tags")
    def tags(self) -> typing.Optional[typing.Mapping[builtins.str, builtins.str]]:
        return jsii.get(self, "tags")

    @tags.setter # type: ignore
    def tags(
        self,
        value: typing.Optional[typing.Mapping[builtins.str, builtins.str]],
    ) -> None:
        jsii.set(self, "tags", value)

    @builtins.property # type: ignore
    @jsii.member(jsii_name="timeouts")
    def timeouts(self) -> typing.Optional["LocalNetworkGatewayTimeouts"]:
        return jsii.get(self, "timeouts")

    @timeouts.setter # type: ignore
    def timeouts(self, value: typing.Optional["LocalNetworkGatewayTimeouts"]) -> None:
        jsii.set(self, "timeouts", value)


@jsii.data_type(
    jsii_type="@cdktf/provider-azurerm.LocalNetworkGatewayBgpSettings",
    jsii_struct_bases=[],
    name_mapping={
        "asn": "asn",
        "bgp_peering_address": "bgpPeeringAddress",
        "peer_weight": "peerWeight",
    },
)
class LocalNetworkGatewayBgpSettings:
    def __init__(
        self,
        *,
        asn: jsii.Number,
        bgp_peering_address: builtins.str,
        peer_weight: typing.Optional[jsii.Number] = None,
    ) -> None:
        """
        :param asn: 
        :param bgp_peering_address: 
        :param peer_weight: 
        """
        self._values: typing.Dict[str, typing.Any] = {
            "asn": asn,
            "bgp_peering_address": bgp_peering_address,
        }
        if peer_weight is not None:
            self._values["peer_weight"] = peer_weight

    @builtins.property
    def asn(self) -> jsii.Number:
        result = self._values.get("asn")
        assert result is not None, "Required property 'asn' is missing"
        return result

    @builtins.property
    def bgp_peering_address(self) -> builtins.str:
        result = self._values.get("bgp_peering_address")
        assert result is not None, "Required property 'bgp_peering_address' is missing"
        return result

    @builtins.property
    def peer_weight(self) -> typing.Optional[jsii.Number]:
        result = self._values.get("peer_weight")
        return result

    def __eq__(self, rhs: typing.Any) -> builtins.bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs: typing.Any) -> builtins.bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return "LocalNetworkGatewayBgpSettings(%s)" % ", ".join(
            k + "=" + repr(v) for k, v in self._values.items()
        )


@jsii.data_type(
    jsii_type="@cdktf/provider-azurerm.LocalNetworkGatewayConfig",
    jsii_struct_bases=[cdktf.TerraformMetaArguments],
    name_mapping={
        "count": "count",
        "depends_on": "dependsOn",
        "lifecycle": "lifecycle",
        "provider": "provider",
        "address_space": "addressSpace",
        "gateway_address": "gatewayAddress",
        "location": "location",
        "name": "name",
        "resource_group_name": "resourceGroupName",
        "bgp_settings": "bgpSettings",
        "tags": "tags",
        "timeouts": "timeouts",
    },
)
class LocalNetworkGatewayConfig(cdktf.TerraformMetaArguments):
    def __init__(
        self,
        *,
        count: typing.Optional[jsii.Number] = None,
        depends_on: typing.Optional[typing.List[cdktf.TerraformResource]] = None,
        lifecycle: typing.Optional[cdktf.TerraformResourceLifecycle] = None,
        provider: typing.Optional[cdktf.TerraformProvider] = None,
        address_space: typing.List[builtins.str],
        gateway_address: builtins.str,
        location: builtins.str,
        name: builtins.str,
        resource_group_name: builtins.str,
        bgp_settings: typing.Optional[typing.List[LocalNetworkGatewayBgpSettings]] = None,
        tags: typing.Optional[typing.Mapping[builtins.str, builtins.str]] = None,
        timeouts: typing.Optional["LocalNetworkGatewayTimeouts"] = None,
    ) -> None:
        """
        :param count: 
        :param depends_on: 
        :param lifecycle: 
        :param provider: 
        :param address_space: 
        :param gateway_address: 
        :param location: 
        :param name: 
        :param resource_group_name: 
        :param bgp_settings: bgp_settings block.
        :param tags: 
        :param timeouts: timeouts block.
        """
        if isinstance(lifecycle, dict):
            lifecycle = cdktf.TerraformResourceLifecycle(**lifecycle)
        if isinstance(timeouts, dict):
            timeouts = LocalNetworkGatewayTimeouts(**timeouts)
        self._values: typing.Dict[str, typing.Any] = {
            "address_space": address_space,
            "gateway_address": gateway_address,
            "location": location,
            "name": name,
            "resource_group_name": resource_group_name,
        }
        if count is not None:
            self._values["count"] = count
        if depends_on is not None:
            self._values["depends_on"] = depends_on
        if lifecycle is not None:
            self._values["lifecycle"] = lifecycle
        if provider is not None:
            self._values["provider"] = provider
        if bgp_settings is not None:
            self._values["bgp_settings"] = bgp_settings
        if tags is not None:
            self._values["tags"] = tags
        if timeouts is not None:
            self._values["timeouts"] = timeouts

    @builtins.property
    def count(self) -> typing.Optional[jsii.Number]:
        """
        :stability: experimental
        """
        result = self._values.get("count")
        return result

    @builtins.property
    def depends_on(self) -> typing.Optional[typing.List[cdktf.TerraformResource]]:
        """
        :stability: experimental
        """
        result = self._values.get("depends_on")
        return result

    @builtins.property
    def lifecycle(self) -> typing.Optional[cdktf.TerraformResourceLifecycle]:
        """
        :stability: experimental
        """
        result = self._values.get("lifecycle")
        return result

    @builtins.property
    def provider(self) -> typing.Optional[cdktf.TerraformProvider]:
        """
        :stability: experimental
        """
        result = self._values.get("provider")
        return result

    @builtins.property
    def address_space(self) -> typing.List[builtins.str]:
        result = self._values.get("address_space")
        assert result is not None, "Required property 'address_space' is missing"
        return result

    @builtins.property
    def gateway_address(self) -> builtins.str:
        result = self._values.get("gateway_address")
        assert result is not None, "Required property 'gateway_address' is missing"
        return result

    @builtins.property
    def location(self) -> builtins.str:
        result = self._values.get("location")
        assert result is not None, "Required property 'location' is missing"
        return result

    @builtins.property
    def name(self) -> builtins.str:
        result = self._values.get("name")
        assert result is not None, "Required property 'name' is missing"
        return result

    @builtins.property
    def resource_group_name(self) -> builtins.str:
        result = self._values.get("resource_group_name")
        assert result is not None, "Required property 'resource_group_name' is missing"
        return result

    @builtins.property
    def bgp_settings(
        self,
    ) -> typing.Optional[typing.List[LocalNetworkGatewayBgpSettings]]:
        """bgp_settings block."""
        result = self._values.get("bgp_settings")
        return result

    @builtins.property
    def tags(self) -> typing.Optional[typing.Mapping[builtins.str, builtins.str]]:
        result = self._values.get("tags")
        return result

    @builtins.property
    def timeouts(self) -> typing.Optional["LocalNetworkGatewayTimeouts"]:
        """timeouts block."""
        result = self._values.get("timeouts")
        return result

    def __eq__(self, rhs: typing.Any) -> builtins.bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs: typing.Any) -> builtins.bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return "LocalNetworkGatewayConfig(%s)" % ", ".join(
            k + "=" + repr(v) for k, v in self._values.items()
        )


@jsii.data_type(
    jsii_type="@cdktf/provider-azurerm.LocalNetworkGatewayTimeouts",
    jsii_struct_bases=[],
    name_mapping={
        "create": "create",
        "delete": "delete",
        "read": "read",
        "update": "update",
    },
)
class LocalNetworkGatewayTimeouts:
    def __init__(
        self,
        *,
        create: typing.Optional[builtins.str] = None,
        delete: typing.Optional[builtins.str] = None,
        read: typing.Optional[builtins.str] = None,
        update: typing.Optional[builtins.str] = None,
    ) -> None:
        """
        :param create: 
        :param delete: 
        :param read: 
        :param update: 
        """
        self._values: typing.Dict[str, typing.Any] = {}
        if create is not None:
            self._values["create"] = create
        if delete is not None:
            self._values["delete"] = delete
        if read is not None:
            self._values["read"] = read
        if update is not None:
            self._values["update"] = update

    @builtins.property
    def create(self) -> typing.Optional[builtins.str]:
        result = self._values.get("create")
        return result

    @builtins.property
    def delete(self) -> typing.Optional[builtins.str]:
        result = self._values.get("delete")
        return result

    @builtins.property
    def read(self) -> typing.Optional[builtins.str]:
        result = self._values.get("read")
        return result

    @builtins.property
    def update(self) -> typing.Optional[builtins.str]:
        result = self._values.get("update")
        return result

    def __eq__(self, rhs: typing.Any) -> builtins.bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs: typing.Any) -> builtins.bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return "LocalNetworkGatewayTimeouts(%s)" % ", ".join(
            k + "=" + repr(v) for k, v in self._values.items()
        )


class LogAnalyticsLinkedService(
    cdktf.TerraformResource,
    metaclass=jsii.JSIIMeta,
    jsii_type="@cdktf/provider-azurerm.LogAnalyticsLinkedService",
):
    def __init__(
        self,
        scope: constructs.Construct,
        id: builtins.str,
        *,
        resource_group_name: builtins.str,
        resource_id: builtins.str,
        workspace_name: builtins.str,
        linked_service_name: typing.Optional[builtins.str] = None,
        tags: typing.Optional[typing.Mapping[builtins.str, builtins.str]] = None,
        timeouts: typing.Optional["LogAnalyticsLinkedServiceTimeouts"] = None,
        count: typing.Optional[jsii.Number] = None,
        depends_on: typing.Optional[typing.List[cdktf.TerraformResource]] = None,
        lifecycle: typing.Optional[cdktf.TerraformResourceLifecycle] = None,
        provider: typing.Optional[cdktf.TerraformProvider] = None,
    ) -> None:
        """
        :param scope: -
        :param id: -
        :param resource_group_name: 
        :param resource_id: 
        :param workspace_name: 
        :param linked_service_name: 
        :param tags: 
        :param timeouts: timeouts block.
        :param count: 
        :param depends_on: 
        :param lifecycle: 
        :param provider: 
        """
        config = LogAnalyticsLinkedServiceConfig(
            resource_group_name=resource_group_name,
            resource_id=resource_id,
            workspace_name=workspace_name,
            linked_service_name=linked_service_name,
            tags=tags,
            timeouts=timeouts,
            count=count,
            depends_on=depends_on,
            lifecycle=lifecycle,
            provider=provider,
        )

        jsii.create(LogAnalyticsLinkedService, self, [scope, id, config])

    @jsii.member(jsii_name="synthesizeAttributes")
    def _synthesize_attributes(self) -> typing.Mapping[builtins.str, typing.Any]:
        return jsii.invoke(self, "synthesizeAttributes", [])

    @builtins.property # type: ignore
    @jsii.member(jsii_name="name")
    def name(self) -> builtins.str:
        return jsii.get(self, "name")

    @builtins.property # type: ignore
    @jsii.member(jsii_name="resourceGroupName")
    def resource_group_name(self) -> builtins.str:
        return jsii.get(self, "resourceGroupName")

    @resource_group_name.setter # type: ignore
    def resource_group_name(self, value: builtins.str) -> None:
        jsii.set(self, "resourceGroupName", value)

    @builtins.property # type: ignore
    @jsii.member(jsii_name="resourceId")
    def resource_id(self) -> builtins.str:
        return jsii.get(self, "resourceId")

    @resource_id.setter # type: ignore
    def resource_id(self, value: builtins.str) -> None:
        jsii.set(self, "resourceId", value)

    @builtins.property # type: ignore
    @jsii.member(jsii_name="workspaceName")
    def workspace_name(self) -> builtins.str:
        return jsii.get(self, "workspaceName")

    @workspace_name.setter # type: ignore
    def workspace_name(self, value: builtins.str) -> None:
        jsii.set(self, "workspaceName", value)

    @builtins.property # type: ignore
    @jsii.member(jsii_name="id")
    def id(self) -> typing.Optional[builtins.str]:
        return jsii.get(self, "id")

    @id.setter # type: ignore
    def id(self, value: typing.Optional[builtins.str]) -> None:
        jsii.set(self, "id", value)

    @builtins.property # type: ignore
    @jsii.member(jsii_name="linkedServiceName")
    def linked_service_name(self) -> typing.Optional[builtins.str]:
        return jsii.get(self, "linkedServiceName")

    @linked_service_name.setter # type: ignore
    def linked_service_name(self, value: typing.Optional[builtins.str]) -> None:
        jsii.set(self, "linkedServiceName", value)

    @builtins.property # type: ignore
    @jsii.member(jsii_name="tags")
    def tags(self) -> typing.Optional[typing.Mapping[builtins.str, builtins.str]]:
        return jsii.get(self, "tags")

    @tags.setter # type: ignore
    def tags(
        self,
        value: typing.Optional[typing.Mapping[builtins.str, builtins.str]],
    ) -> None:
        jsii.set(self, "tags", value)

    @builtins.property # type: ignore
    @jsii.member(jsii_name="timeouts")
    def timeouts(self) -> typing.Optional["LogAnalyticsLinkedServiceTimeouts"]:
        return jsii.get(self, "timeouts")

    @timeouts.setter # type: ignore
    def timeouts(
        self,
        value: typing.Optional["LogAnalyticsLinkedServiceTimeouts"],
    ) -> None:
        jsii.set(self, "timeouts", value)


@jsii.data_type(
    jsii_type="@cdktf/provider-azurerm.LogAnalyticsLinkedServiceConfig",
    jsii_struct_bases=[cdktf.TerraformMetaArguments],
    name_mapping={
        "count": "count",
        "depends_on": "dependsOn",
        "lifecycle": "lifecycle",
        "provider": "provider",
        "resource_group_name": "resourceGroupName",
        "resource_id": "resourceId",
        "workspace_name": "workspaceName",
        "linked_service_name": "linkedServiceName",
        "tags": "tags",
        "timeouts": "timeouts",
    },
)
class LogAnalyticsLinkedServiceConfig(cdktf.TerraformMetaArguments):
    def __init__(
        self,
        *,
        count: typing.Optional[jsii.Number] = None,
        depends_on: typing.Optional[typing.List[cdktf.TerraformResource]] = None,
        lifecycle: typing.Optional[cdktf.TerraformResourceLifecycle] = None,
        provider: typing.Optional[cdktf.TerraformProvider] = None,
        resource_group_name: builtins.str,
        resource_id: builtins.str,
        workspace_name: builtins.str,
        linked_service_name: typing.Optional[builtins.str] = None,
        tags: typing.Optional[typing.Mapping[builtins.str, builtins.str]] = None,
        timeouts: typing.Optional["LogAnalyticsLinkedServiceTimeouts"] = None,
    ) -> None:
        """
        :param count: 
        :param depends_on: 
        :param lifecycle: 
        :param provider: 
        :param resource_group_name: 
        :param resource_id: 
        :param workspace_name: 
        :param linked_service_name: 
        :param tags: 
        :param timeouts: timeouts block.
        """
        if isinstance(lifecycle, dict):
            lifecycle = cdktf.TerraformResourceLifecycle(**lifecycle)
        if isinstance(timeouts, dict):
            timeouts = LogAnalyticsLinkedServiceTimeouts(**timeouts)
        self._values: typing.Dict[str, typing.Any] = {
            "resource_group_name": resource_group_name,
            "resource_id": resource_id,
            "workspace_name": workspace_name,
        }
        if count is not None:
            self._values["count"] = count
        if depends_on is not None:
            self._values["depends_on"] = depends_on
        if lifecycle is not None:
            self._values["lifecycle"] = lifecycle
        if provider is not None:
            self._values["provider"] = provider
        if linked_service_name is not None:
            self._values["linked_service_name"] = linked_service_name
        if tags is not None:
            self._values["tags"] = tags
        if timeouts is not None:
            self._values["timeouts"] = timeouts

    @builtins.property
    def count(self) -> typing.Optional[jsii.Number]:
        """
        :stability: experimental
        """
        result = self._values.get("count")
        return result

    @builtins.property
    def depends_on(self) -> typing.Optional[typing.List[cdktf.TerraformResource]]:
        """
        :stability: experimental
        """
        result = self._values.get("depends_on")
        return result

    @builtins.property
    def lifecycle(self) -> typing.Optional[cdktf.TerraformResourceLifecycle]:
        """
        :stability: experimental
        """
        result = self._values.get("lifecycle")
        return result

    @builtins.property
    def provider(self) -> typing.Optional[cdktf.TerraformProvider]:
        """
        :stability: experimental
        """
        result = self._values.get("provider")
        return result

    @builtins.property
    def resource_group_name(self) -> builtins.str:
        result = self._values.get("resource_group_name")
        assert result is not None, "Required property 'resource_group_name' is missing"
        return result

    @builtins.property
    def resource_id(self) -> builtins.str:
        result = self._values.get("resource_id")
        assert result is not None, "Required property 'resource_id' is missing"
        return result

    @builtins.property
    def workspace_name(self) -> builtins.str:
        result = self._values.get("workspace_name")
        assert result is not None, "Required property 'workspace_name' is missing"
        return result

    @builtins.property
    def linked_service_name(self) -> typing.Optional[builtins.str]:
        result = self._values.get("linked_service_name")
        return result

    @builtins.property
    def tags(self) -> typing.Optional[typing.Mapping[builtins.str, builtins.str]]:
        result = self._values.get("tags")
        return result

    @builtins.property
    def timeouts(self) -> typing.Optional["LogAnalyticsLinkedServiceTimeouts"]:
        """timeouts block."""
        result = self._values.get("timeouts")
        return result

    def __eq__(self, rhs: typing.Any) -> builtins.bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs: typing.Any) -> builtins.bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return "LogAnalyticsLinkedServiceConfig(%s)" % ", ".join(
            k + "=" + repr(v) for k, v in self._values.items()
        )


@jsii.data_type(
    jsii_type="@cdktf/provider-azurerm.LogAnalyticsLinkedServiceTimeouts",
    jsii_struct_bases=[],
    name_mapping={
        "create": "create",
        "delete": "delete",
        "read": "read",
        "update": "update",
    },
)
class LogAnalyticsLinkedServiceTimeouts:
    def __init__(
        self,
        *,
        create: typing.Optional[builtins.str] = None,
        delete: typing.Optional[builtins.str] = None,
        read: typing.Optional[builtins.str] = None,
        update: typing.Optional[builtins.str] = None,
    ) -> None:
        """
        :param create: 
        :param delete: 
        :param read: 
        :param update: 
        """
        self._values: typing.Dict[str, typing.Any] = {}
        if create is not None:
            self._values["create"] = create
        if delete is not None:
            self._values["delete"] = delete
        if read is not None:
            self._values["read"] = read
        if update is not None:
            self._values["update"] = update

    @builtins.property
    def create(self) -> typing.Optional[builtins.str]:
        result = self._values.get("create")
        return result

    @builtins.property
    def delete(self) -> typing.Optional[builtins.str]:
        result = self._values.get("delete")
        return result

    @builtins.property
    def read(self) -> typing.Optional[builtins.str]:
        result = self._values.get("read")
        return result

    @builtins.property
    def update(self) -> typing.Optional[builtins.str]:
        result = self._values.get("update")
        return result

    def __eq__(self, rhs: typing.Any) -> builtins.bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs: typing.Any) -> builtins.bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return "LogAnalyticsLinkedServiceTimeouts(%s)" % ", ".join(
            k + "=" + repr(v) for k, v in self._values.items()
        )


class LogAnalyticsSolution(
    cdktf.TerraformResource,
    metaclass=jsii.JSIIMeta,
    jsii_type="@cdktf/provider-azurerm.LogAnalyticsSolution",
):
    def __init__(
        self,
        scope: constructs.Construct,
        id: builtins.str,
        *,
        location: builtins.str,
        plan: typing.List["LogAnalyticsSolutionPlan"],
        resource_group_name: builtins.str,
        solution_name: builtins.str,
        workspace_name: builtins.str,
        workspace_resource_id: builtins.str,
        timeouts: typing.Optional["LogAnalyticsSolutionTimeouts"] = None,
        count: typing.Optional[jsii.Number] = None,
        depends_on: typing.Optional[typing.List[cdktf.TerraformResource]] = None,
        lifecycle: typing.Optional[cdktf.TerraformResourceLifecycle] = None,
        provider: typing.Optional[cdktf.TerraformProvider] = None,
    ) -> None:
        """
        :param scope: -
        :param id: -
        :param location: 
        :param plan: plan block.
        :param resource_group_name: 
        :param solution_name: 
        :param workspace_name: 
        :param workspace_resource_id: 
        :param timeouts: timeouts block.
        :param count: 
        :param depends_on: 
        :param lifecycle: 
        :param provider: 
        """
        config = LogAnalyticsSolutionConfig(
            location=location,
            plan=plan,
            resource_group_name=resource_group_name,
            solution_name=solution_name,
            workspace_name=workspace_name,
            workspace_resource_id=workspace_resource_id,
            timeouts=timeouts,
            count=count,
            depends_on=depends_on,
            lifecycle=lifecycle,
            provider=provider,
        )

        jsii.create(LogAnalyticsSolution, self, [scope, id, config])

    @jsii.member(jsii_name="synthesizeAttributes")
    def _synthesize_attributes(self) -> typing.Mapping[builtins.str, typing.Any]:
        return jsii.invoke(self, "synthesizeAttributes", [])

    @builtins.property # type: ignore
    @jsii.member(jsii_name="location")
    def location(self) -> builtins.str:
        return jsii.get(self, "location")

    @location.setter # type: ignore
    def location(self, value: builtins.str) -> None:
        jsii.set(self, "location", value)

    @builtins.property # type: ignore
    @jsii.member(jsii_name="plan")
    def plan(self) -> typing.List["LogAnalyticsSolutionPlan"]:
        return jsii.get(self, "plan")

    @plan.setter # type: ignore
    def plan(self, value: typing.List["LogAnalyticsSolutionPlan"]) -> None:
        jsii.set(self, "plan", value)

    @builtins.property # type: ignore
    @jsii.member(jsii_name="resourceGroupName")
    def resource_group_name(self) -> builtins.str:
        return jsii.get(self, "resourceGroupName")

    @resource_group_name.setter # type: ignore
    def resource_group_name(self, value: builtins.str) -> None:
        jsii.set(self, "resourceGroupName", value)

    @builtins.property # type: ignore
    @jsii.member(jsii_name="solutionName")
    def solution_name(self) -> builtins.str:
        return jsii.get(self, "solutionName")

    @solution_name.setter # type: ignore
    def solution_name(self, value: builtins.str) -> None:
        jsii.set(self, "solutionName", value)

    @builtins.property # type: ignore
    @jsii.member(jsii_name="workspaceName")
    def workspace_name(self) -> builtins.str:
        return jsii.get(self, "workspaceName")

    @workspace_name.setter # type: ignore
    def workspace_name(self, value: builtins.str) -> None:
        jsii.set(self, "workspaceName", value)

    @builtins.property # type: ignore
    @jsii.member(jsii_name="workspaceResourceId")
    def workspace_resource_id(self) -> builtins.str:
        return jsii.get(self, "workspaceResourceId")

    @workspace_resource_id.setter # type: ignore
    def workspace_resource_id(self, value: builtins.str) -> None:
        jsii.set(self, "workspaceResourceId", value)

    @builtins.property # type: ignore
    @jsii.member(jsii_name="id")
    def id(self) -> typing.Optional[builtins.str]:
        return jsii.get(self, "id")

    @id.setter # type: ignore
    def id(self, value: typing.Optional[builtins.str]) -> None:
        jsii.set(self, "id", value)

    @builtins.property # type: ignore
    @jsii.member(jsii_name="timeouts")
    def timeouts(self) -> typing.Optional["LogAnalyticsSolutionTimeouts"]:
        return jsii.get(self, "timeouts")

    @timeouts.setter # type: ignore
    def timeouts(self, value: typing.Optional["LogAnalyticsSolutionTimeouts"]) -> None:
        jsii.set(self, "timeouts", value)


@jsii.data_type(
    jsii_type="@cdktf/provider-azurerm.LogAnalyticsSolutionConfig",
    jsii_struct_bases=[cdktf.TerraformMetaArguments],
    name_mapping={
        "count": "count",
        "depends_on": "dependsOn",
        "lifecycle": "lifecycle",
        "provider": "provider",
        "location": "location",
        "plan": "plan",
        "resource_group_name": "resourceGroupName",
        "solution_name": "solutionName",
        "workspace_name": "workspaceName",
        "workspace_resource_id": "workspaceResourceId",
        "timeouts": "timeouts",
    },
)
class LogAnalyticsSolutionConfig(cdktf.TerraformMetaArguments):
    def __init__(
        self,
        *,
        count: typing.Optional[jsii.Number] = None,
        depends_on: typing.Optional[typing.List[cdktf.TerraformResource]] = None,
        lifecycle: typing.Optional[cdktf.TerraformResourceLifecycle] = None,
        provider: typing.Optional[cdktf.TerraformProvider] = None,
        location: builtins.str,
        plan: typing.List["LogAnalyticsSolutionPlan"],
        resource_group_name: builtins.str,
        solution_name: builtins.str,
        workspace_name: builtins.str,
        workspace_resource_id: builtins.str,
        timeouts: typing.Optional["LogAnalyticsSolutionTimeouts"] = None,
    ) -> None:
        """
        :param count: 
        :param depends_on: 
        :param lifecycle: 
        :param provider: 
        :param location: 
        :param plan: plan block.
        :param resource_group_name: 
        :param solution_name: 
        :param workspace_name: 
        :param workspace_resource_id: 
        :param timeouts: timeouts block.
        """
        if isinstance(lifecycle, dict):
            lifecycle = cdktf.TerraformResourceLifecycle(**lifecycle)
        if isinstance(timeouts, dict):
            timeouts = LogAnalyticsSolutionTimeouts(**timeouts)
        self._values: typing.Dict[str, typing.Any] = {
            "location": location,
            "plan": plan,
            "resource_group_name": resource_group_name,
            "solution_name": solution_name,
            "workspace_name": workspace_name,
            "workspace_resource_id": workspace_resource_id,
        }
        if count is not None:
            self._values["count"] = count
        if depends_on is not None:
            self._values["depends_on"] = depends_on
        if lifecycle is not None:
            self._values["lifecycle"] = lifecycle
        if provider is not None:
            self._values["provider"] = provider
        if timeouts is not None:
            self._values["timeouts"] = timeouts

    @builtins.property
    def count(self) -> typing.Optional[jsii.Number]:
        """
        :stability: experimental
        """
        result = self._values.get("count")
        return result

    @builtins.property
    def depends_on(self) -> typing.Optional[typing.List[cdktf.TerraformResource]]:
        """
        :stability: experimental
        """
        result = self._values.get("depends_on")
        return result

    @builtins.property
    def lifecycle(self) -> typing.Optional[cdktf.TerraformResourceLifecycle]:
        """
        :stability: experimental
        """
        result = self._values.get("lifecycle")
        return result

    @builtins.property
    def provider(self) -> typing.Optional[cdktf.TerraformProvider]:
        """
        :stability: experimental
        """
        result = self._values.get("provider")
        return result

    @builtins.property
    def location(self) -> builtins.str:
        result = self._values.get("location")
        assert result is not None, "Required property 'location' is missing"
        return result

    @builtins.property
    def plan(self) -> typing.List["LogAnalyticsSolutionPlan"]:
        """plan block."""
        result = self._values.get("plan")
        assert result is not None, "Required property 'plan' is missing"
        return result

    @builtins.property
    def resource_group_name(self) -> builtins.str:
        result = self._values.get("resource_group_name")
        assert result is not None, "Required property 'resource_group_name' is missing"
        return result

    @builtins.property
    def solution_name(self) -> builtins.str:
        result = self._values.get("solution_name")
        assert result is not None, "Required property 'solution_name' is missing"
        return result

    @builtins.property
    def workspace_name(self) -> builtins.str:
        result = self._values.get("workspace_name")
        assert result is not None, "Required property 'workspace_name' is missing"
        return result

    @builtins.property
    def workspace_resource_id(self) -> builtins.str:
        result = self._values.get("workspace_resource_id")
        assert result is not None, "Required property 'workspace_resource_id' is missing"
        return result

    @builtins.property
    def timeouts(self) -> typing.Optional["LogAnalyticsSolutionTimeouts"]:
        """timeouts block."""
        result = self._values.get("timeouts")
        return result

    def __eq__(self, rhs: typing.Any) -> builtins.bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs: typing.Any) -> builtins.bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return "LogAnalyticsSolutionConfig(%s)" % ", ".join(
            k + "=" + repr(v) for k, v in self._values.items()
        )


@jsii.data_type(
    jsii_type="@cdktf/provider-azurerm.LogAnalyticsSolutionPlan",
    jsii_struct_bases=[],
    name_mapping={
        "product": "product",
        "publisher": "publisher",
        "promotion_code": "promotionCode",
    },
)
class LogAnalyticsSolutionPlan:
    def __init__(
        self,
        *,
        product: builtins.str,
        publisher: builtins.str,
        promotion_code: typing.Optional[builtins.str] = None,
    ) -> None:
        """
        :param product: 
        :param publisher: 
        :param promotion_code: 
        """
        self._values: typing.Dict[str, typing.Any] = {
            "product": product,
            "publisher": publisher,
        }
        if promotion_code is not None:
            self._values["promotion_code"] = promotion_code

    @builtins.property
    def product(self) -> builtins.str:
        result = self._values.get("product")
        assert result is not None, "Required property 'product' is missing"
        return result

    @builtins.property
    def publisher(self) -> builtins.str:
        result = self._values.get("publisher")
        assert result is not None, "Required property 'publisher' is missing"
        return result

    @builtins.property
    def promotion_code(self) -> typing.Optional[builtins.str]:
        result = self._values.get("promotion_code")
        return result

    def __eq__(self, rhs: typing.Any) -> builtins.bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs: typing.Any) -> builtins.bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return "LogAnalyticsSolutionPlan(%s)" % ", ".join(
            k + "=" + repr(v) for k, v in self._values.items()
        )


@jsii.data_type(
    jsii_type="@cdktf/provider-azurerm.LogAnalyticsSolutionTimeouts",
    jsii_struct_bases=[],
    name_mapping={
        "create": "create",
        "delete": "delete",
        "read": "read",
        "update": "update",
    },
)
class LogAnalyticsSolutionTimeouts:
    def __init__(
        self,
        *,
        create: typing.Optional[builtins.str] = None,
        delete: typing.Optional[builtins.str] = None,
        read: typing.Optional[builtins.str] = None,
        update: typing.Optional[builtins.str] = None,
    ) -> None:
        """
        :param create: 
        :param delete: 
        :param read: 
        :param update: 
        """
        self._values: typing.Dict[str, typing.Any] = {}
        if create is not None:
            self._values["create"] = create
        if delete is not None:
            self._values["delete"] = delete
        if read is not None:
            self._values["read"] = read
        if update is not None:
            self._values["update"] = update

    @builtins.property
    def create(self) -> typing.Optional[builtins.str]:
        result = self._values.get("create")
        return result

    @builtins.property
    def delete(self) -> typing.Optional[builtins.str]:
        result = self._values.get("delete")
        return result

    @builtins.property
    def read(self) -> typing.Optional[builtins.str]:
        result = self._values.get("read")
        return result

    @builtins.property
    def update(self) -> typing.Optional[builtins.str]:
        result = self._values.get("update")
        return result

    def __eq__(self, rhs: typing.Any) -> builtins.bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs: typing.Any) -> builtins.bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return "LogAnalyticsSolutionTimeouts(%s)" % ", ".join(
            k + "=" + repr(v) for k, v in self._values.items()
        )


class LogAnalyticsWorkspace(
    cdktf.TerraformResource,
    metaclass=jsii.JSIIMeta,
    jsii_type="@cdktf/provider-azurerm.LogAnalyticsWorkspace",
):
    def __init__(
        self,
        scope: constructs.Construct,
        id: builtins.str,
        *,
        location: builtins.str,
        name: builtins.str,
        resource_group_name: builtins.str,
        sku: builtins.str,
        retention_in_days: typing.Optional[jsii.Number] = None,
        tags: typing.Optional[typing.Mapping[builtins.str, builtins.str]] = None,
        timeouts: typing.Optional["LogAnalyticsWorkspaceTimeouts"] = None,
        count: typing.Optional[jsii.Number] = None,
        depends_on: typing.Optional[typing.List[cdktf.TerraformResource]] = None,
        lifecycle: typing.Optional[cdktf.TerraformResourceLifecycle] = None,
        provider: typing.Optional[cdktf.TerraformProvider] = None,
    ) -> None:
        """
        :param scope: -
        :param id: -
        :param location: 
        :param name: 
        :param resource_group_name: 
        :param sku: 
        :param retention_in_days: 
        :param tags: 
        :param timeouts: timeouts block.
        :param count: 
        :param depends_on: 
        :param lifecycle: 
        :param provider: 
        """
        config = LogAnalyticsWorkspaceConfig(
            location=location,
            name=name,
            resource_group_name=resource_group_name,
            sku=sku,
            retention_in_days=retention_in_days,
            tags=tags,
            timeouts=timeouts,
            count=count,
            depends_on=depends_on,
            lifecycle=lifecycle,
            provider=provider,
        )

        jsii.create(LogAnalyticsWorkspace, self, [scope, id, config])

    @jsii.member(jsii_name="synthesizeAttributes")
    def _synthesize_attributes(self) -> typing.Mapping[builtins.str, typing.Any]:
        return jsii.invoke(self, "synthesizeAttributes", [])

    @builtins.property # type: ignore
    @jsii.member(jsii_name="portalUrl")
    def portal_url(self) -> builtins.str:
        return jsii.get(self, "portalUrl")

    @builtins.property # type: ignore
    @jsii.member(jsii_name="primarySharedKey")
    def primary_shared_key(self) -> builtins.str:
        return jsii.get(self, "primarySharedKey")

    @builtins.property # type: ignore
    @jsii.member(jsii_name="secondarySharedKey")
    def secondary_shared_key(self) -> builtins.str:
        return jsii.get(self, "secondarySharedKey")

    @builtins.property # type: ignore
    @jsii.member(jsii_name="workspaceId")
    def workspace_id(self) -> builtins.str:
        return jsii.get(self, "workspaceId")

    @builtins.property # type: ignore
    @jsii.member(jsii_name="location")
    def location(self) -> builtins.str:
        return jsii.get(self, "location")

    @location.setter # type: ignore
    def location(self, value: builtins.str) -> None:
        jsii.set(self, "location", value)

    @builtins.property # type: ignore
    @jsii.member(jsii_name="name")
    def name(self) -> builtins.str:
        return jsii.get(self, "name")

    @name.setter # type: ignore
    def name(self, value: builtins.str) -> None:
        jsii.set(self, "name", value)

    @builtins.property # type: ignore
    @jsii.member(jsii_name="resourceGroupName")
    def resource_group_name(self) -> builtins.str:
        return jsii.get(self, "resourceGroupName")

    @resource_group_name.setter # type: ignore
    def resource_group_name(self, value: builtins.str) -> None:
        jsii.set(self, "resourceGroupName", value)

    @builtins.property # type: ignore
    @jsii.member(jsii_name="sku")
    def sku(self) -> builtins.str:
        return jsii.get(self, "sku")

    @sku.setter # type: ignore
    def sku(self, value: builtins.str) -> None:
        jsii.set(self, "sku", value)

    @builtins.property # type: ignore
    @jsii.member(jsii_name="id")
    def id(self) -> typing.Optional[builtins.str]:
        return jsii.get(self, "id")

    @id.setter # type: ignore
    def id(self, value: typing.Optional[builtins.str]) -> None:
        jsii.set(self, "id", value)

    @builtins.property # type: ignore
    @jsii.member(jsii_name="retentionInDays")
    def retention_in_days(self) -> typing.Optional[jsii.Number]:
        return jsii.get(self, "retentionInDays")

    @retention_in_days.setter # type: ignore
    def retention_in_days(self, value: typing.Optional[jsii.Number]) -> None:
        jsii.set(self, "retentionInDays", value)

    @builtins.property # type: ignore
    @jsii.member(jsii_name="tags")
    def tags(self) -> typing.Optional[typing.Mapping[builtins.str, builtins.str]]:
        return jsii.get(self, "tags")

    @tags.setter # type: ignore
    def tags(
        self,
        value: typing.Optional[typing.Mapping[builtins.str, builtins.str]],
    ) -> None:
        jsii.set(self, "tags", value)

    @builtins.property # type: ignore
    @jsii.member(jsii_name="timeouts")
    def timeouts(self) -> typing.Optional["LogAnalyticsWorkspaceTimeouts"]:
        return jsii.get(self, "timeouts")

    @timeouts.setter # type: ignore
    def timeouts(self, value: typing.Optional["LogAnalyticsWorkspaceTimeouts"]) -> None:
        jsii.set(self, "timeouts", value)


@jsii.data_type(
    jsii_type="@cdktf/provider-azurerm.LogAnalyticsWorkspaceConfig",
    jsii_struct_bases=[cdktf.TerraformMetaArguments],
    name_mapping={
        "count": "count",
        "depends_on": "dependsOn",
        "lifecycle": "lifecycle",
        "provider": "provider",
        "location": "location",
        "name": "name",
        "resource_group_name": "resourceGroupName",
        "sku": "sku",
        "retention_in_days": "retentionInDays",
        "tags": "tags",
        "timeouts": "timeouts",
    },
)
class LogAnalyticsWorkspaceConfig(cdktf.TerraformMetaArguments):
    def __init__(
        self,
        *,
        count: typing.Optional[jsii.Number] = None,
        depends_on: typing.Optional[typing.List[cdktf.TerraformResource]] = None,
        lifecycle: typing.Optional[cdktf.TerraformResourceLifecycle] = None,
        provider: typing.Optional[cdktf.TerraformProvider] = None,
        location: builtins.str,
        name: builtins.str,
        resource_group_name: builtins.str,
        sku: builtins.str,
        retention_in_days: typing.Optional[jsii.Number] = None,
        tags: typing.Optional[typing.Mapping[builtins.str, builtins.str]] = None,
        timeouts: typing.Optional["LogAnalyticsWorkspaceTimeouts"] = None,
    ) -> None:
        """
        :param count: 
        :param depends_on: 
        :param lifecycle: 
        :param provider: 
        :param location: 
        :param name: 
        :param resource_group_name: 
        :param sku: 
        :param retention_in_days: 
        :param tags: 
        :param timeouts: timeouts block.
        """
        if isinstance(lifecycle, dict):
            lifecycle = cdktf.TerraformResourceLifecycle(**lifecycle)
        if isinstance(timeouts, dict):
            timeouts = LogAnalyticsWorkspaceTimeouts(**timeouts)
        self._values: typing.Dict[str, typing.Any] = {
            "location": location,
            "name": name,
            "resource_group_name": resource_group_name,
            "sku": sku,
        }
        if count is not None:
            self._values["count"] = count
        if depends_on is not None:
            self._values["depends_on"] = depends_on
        if lifecycle is not None:
            self._values["lifecycle"] = lifecycle
        if provider is not None:
            self._values["provider"] = provider
        if retention_in_days is not None:
            self._values["retention_in_days"] = retention_in_days
        if tags is not None:
            self._values["tags"] = tags
        if timeouts is not None:
            self._values["timeouts"] = timeouts

    @builtins.property
    def count(self) -> typing.Optional[jsii.Number]:
        """
        :stability: experimental
        """
        result = self._values.get("count")
        return result

    @builtins.property
    def depends_on(self) -> typing.Optional[typing.List[cdktf.TerraformResource]]:
        """
        :stability: experimental
        """
        result = self._values.get("depends_on")
        return result

    @builtins.property
    def lifecycle(self) -> typing.Optional[cdktf.TerraformResourceLifecycle]:
        """
        :stability: experimental
        """
        result = self._values.get("lifecycle")
        return result

    @builtins.property
    def provider(self) -> typing.Optional[cdktf.TerraformProvider]:
        """
        :stability: experimental
        """
        result = self._values.get("provider")
        return result

    @builtins.property
    def location(self) -> builtins.str:
        result = self._values.get("location")
        assert result is not None, "Required property 'location' is missing"
        return result

    @builtins.property
    def name(self) -> builtins.str:
        result = self._values.get("name")
        assert result is not None, "Required property 'name' is missing"
        return result

    @builtins.property
    def resource_group_name(self) -> builtins.str:
        result = self._values.get("resource_group_name")
        assert result is not None, "Required property 'resource_group_name' is missing"
        return result

    @builtins.property
    def sku(self) -> builtins.str:
        result = self._values.get("sku")
        assert result is not None, "Required property 'sku' is missing"
        return result

    @builtins.property
    def retention_in_days(self) -> typing.Optional[jsii.Number]:
        result = self._values.get("retention_in_days")
        return result

    @builtins.property
    def tags(self) -> typing.Optional[typing.Mapping[builtins.str, builtins.str]]:
        result = self._values.get("tags")
        return result

    @builtins.property
    def timeouts(self) -> typing.Optional["LogAnalyticsWorkspaceTimeouts"]:
        """timeouts block."""
        result = self._values.get("timeouts")
        return result

    def __eq__(self, rhs: typing.Any) -> builtins.bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs: typing.Any) -> builtins.bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return "LogAnalyticsWorkspaceConfig(%s)" % ", ".join(
            k + "=" + repr(v) for k, v in self._values.items()
        )


@jsii.data_type(
    jsii_type="@cdktf/provider-azurerm.LogAnalyticsWorkspaceTimeouts",
    jsii_struct_bases=[],
    name_mapping={
        "create": "create",
        "delete": "delete",
        "read": "read",
        "update": "update",
    },
)
class LogAnalyticsWorkspaceTimeouts:
    def __init__(
        self,
        *,
        create: typing.Optional[builtins.str] = None,
        delete: typing.Optional[builtins.str] = None,
        read: typing.Optional[builtins.str] = None,
        update: typing.Optional[builtins.str] = None,
    ) -> None:
        """
        :param create: 
        :param delete: 
        :param read: 
        :param update: 
        """
        self._values: typing.Dict[str, typing.Any] = {}
        if create is not None:
            self._values["create"] = create
        if delete is not None:
            self._values["delete"] = delete
        if read is not None:
            self._values["read"] = read
        if update is not None:
            self._values["update"] = update

    @builtins.property
    def create(self) -> typing.Optional[builtins.str]:
        result = self._values.get("create")
        return result

    @builtins.property
    def delete(self) -> typing.Optional[builtins.str]:
        result = self._values.get("delete")
        return result

    @builtins.property
    def read(self) -> typing.Optional[builtins.str]:
        result = self._values.get("read")
        return result

    @builtins.property
    def update(self) -> typing.Optional[builtins.str]:
        result = self._values.get("update")
        return result

    def __eq__(self, rhs: typing.Any) -> builtins.bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs: typing.Any) -> builtins.bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return "LogAnalyticsWorkspaceTimeouts(%s)" % ", ".join(
            k + "=" + repr(v) for k, v in self._values.items()
        )


class LogicAppActionCustom(
    cdktf.TerraformResource,
    metaclass=jsii.JSIIMeta,
    jsii_type="@cdktf/provider-azurerm.LogicAppActionCustom",
):
    def __init__(
        self,
        scope: constructs.Construct,
        id: builtins.str,
        *,
        body: builtins.str,
        logic_app_id: builtins.str,
        name: builtins.str,
        timeouts: typing.Optional["LogicAppActionCustomTimeouts"] = None,
        count: typing.Optional[jsii.Number] = None,
        depends_on: typing.Optional[typing.List[cdktf.TerraformResource]] = None,
        lifecycle: typing.Optional[cdktf.TerraformResourceLifecycle] = None,
        provider: typing.Optional[cdktf.TerraformProvider] = None,
    ) -> None:
        """
        :param scope: -
        :param id: -
        :param body: 
        :param logic_app_id: 
        :param name: 
        :param timeouts: timeouts block.
        :param count: 
        :param depends_on: 
        :param lifecycle: 
        :param provider: 
        """
        config = LogicAppActionCustomConfig(
            body=body,
            logic_app_id=logic_app_id,
            name=name,
            timeouts=timeouts,
            count=count,
            depends_on=depends_on,
            lifecycle=lifecycle,
            provider=provider,
        )

        jsii.create(LogicAppActionCustom, self, [scope, id, config])

    @jsii.member(jsii_name="synthesizeAttributes")
    def _synthesize_attributes(self) -> typing.Mapping[builtins.str, typing.Any]:
        return jsii.invoke(self, "synthesizeAttributes", [])

    @builtins.property # type: ignore
    @jsii.member(jsii_name="body")
    def body(self) -> builtins.str:
        return jsii.get(self, "body")

    @body.setter # type: ignore
    def body(self, value: builtins.str) -> None:
        jsii.set(self, "body", value)

    @builtins.property # type: ignore
    @jsii.member(jsii_name="logicAppId")
    def logic_app_id(self) -> builtins.str:
        return jsii.get(self, "logicAppId")

    @logic_app_id.setter # type: ignore
    def logic_app_id(self, value: builtins.str) -> None:
        jsii.set(self, "logicAppId", value)

    @builtins.property # type: ignore
    @jsii.member(jsii_name="name")
    def name(self) -> builtins.str:
        return jsii.get(self, "name")

    @name.setter # type: ignore
    def name(self, value: builtins.str) -> None:
        jsii.set(self, "name", value)

    @builtins.property # type: ignore
    @jsii.member(jsii_name="id")
    def id(self) -> typing.Optional[builtins.str]:
        return jsii.get(self, "id")

    @id.setter # type: ignore
    def id(self, value: typing.Optional[builtins.str]) -> None:
        jsii.set(self, "id", value)

    @builtins.property # type: ignore
    @jsii.member(jsii_name="timeouts")
    def timeouts(self) -> typing.Optional["LogicAppActionCustomTimeouts"]:
        return jsii.get(self, "timeouts")

    @timeouts.setter # type: ignore
    def timeouts(self, value: typing.Optional["LogicAppActionCustomTimeouts"]) -> None:
        jsii.set(self, "timeouts", value)


@jsii.data_type(
    jsii_type="@cdktf/provider-azurerm.LogicAppActionCustomConfig",
    jsii_struct_bases=[cdktf.TerraformMetaArguments],
    name_mapping={
        "count": "count",
        "depends_on": "dependsOn",
        "lifecycle": "lifecycle",
        "provider": "provider",
        "body": "body",
        "logic_app_id": "logicAppId",
        "name": "name",
        "timeouts": "timeouts",
    },
)
class LogicAppActionCustomConfig(cdktf.TerraformMetaArguments):
    def __init__(
        self,
        *,
        count: typing.Optional[jsii.Number] = None,
        depends_on: typing.Optional[typing.List[cdktf.TerraformResource]] = None,
        lifecycle: typing.Optional[cdktf.TerraformResourceLifecycle] = None,
        provider: typing.Optional[cdktf.TerraformProvider] = None,
        body: builtins.str,
        logic_app_id: builtins.str,
        name: builtins.str,
        timeouts: typing.Optional["LogicAppActionCustomTimeouts"] = None,
    ) -> None:
        """
        :param count: 
        :param depends_on: 
        :param lifecycle: 
        :param provider: 
        :param body: 
        :param logic_app_id: 
        :param name: 
        :param timeouts: timeouts block.
        """
        if isinstance(lifecycle, dict):
            lifecycle = cdktf.TerraformResourceLifecycle(**lifecycle)
        if isinstance(timeouts, dict):
            timeouts = LogicAppActionCustomTimeouts(**timeouts)
        self._values: typing.Dict[str, typing.Any] = {
            "body": body,
            "logic_app_id": logic_app_id,
            "name": name,
        }
        if count is not None:
            self._values["count"] = count
        if depends_on is not None:
            self._values["depends_on"] = depends_on
        if lifecycle is not None:
            self._values["lifecycle"] = lifecycle
        if provider is not None:
            self._values["provider"] = provider
        if timeouts is not None:
            self._values["timeouts"] = timeouts

    @builtins.property
    def count(self) -> typing.Optional[jsii.Number]:
        """
        :stability: experimental
        """
        result = self._values.get("count")
        return result

    @builtins.property
    def depends_on(self) -> typing.Optional[typing.List[cdktf.TerraformResource]]:
        """
        :stability: experimental
        """
        result = self._values.get("depends_on")
        return result

    @builtins.property
    def lifecycle(self) -> typing.Optional[cdktf.TerraformResourceLifecycle]:
        """
        :stability: experimental
        """
        result = self._values.get("lifecycle")
        return result

    @builtins.property
    def provider(self) -> typing.Optional[cdktf.TerraformProvider]:
        """
        :stability: experimental
        """
        result = self._values.get("provider")
        return result

    @builtins.property
    def body(self) -> builtins.str:
        result = self._values.get("body")
        assert result is not None, "Required property 'body' is missing"
        return result

    @builtins.property
    def logic_app_id(self) -> builtins.str:
        result = self._values.get("logic_app_id")
        assert result is not None, "Required property 'logic_app_id' is missing"
        return result

    @builtins.property
    def name(self) -> builtins.str:
        result = self._values.get("name")
        assert result is not None, "Required property 'name' is missing"
        return result

    @builtins.property
    def timeouts(self) -> typing.Optional["LogicAppActionCustomTimeouts"]:
        """timeouts block."""
        result = self._values.get("timeouts")
        return result

    def __eq__(self, rhs: typing.Any) -> builtins.bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs: typing.Any) -> builtins.bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return "LogicAppActionCustomConfig(%s)" % ", ".join(
            k + "=" + repr(v) for k, v in self._values.items()
        )


@jsii.data_type(
    jsii_type="@cdktf/provider-azurerm.LogicAppActionCustomTimeouts",
    jsii_struct_bases=[],
    name_mapping={
        "create": "create",
        "delete": "delete",
        "read": "read",
        "update": "update",
    },
)
class LogicAppActionCustomTimeouts:
    def __init__(
        self,
        *,
        create: typing.Optional[builtins.str] = None,
        delete: typing.Optional[builtins.str] = None,
        read: typing.Optional[builtins.str] = None,
        update: typing.Optional[builtins.str] = None,
    ) -> None:
        """
        :param create: 
        :param delete: 
        :param read: 
        :param update: 
        """
        self._values: typing.Dict[str, typing.Any] = {}
        if create is not None:
            self._values["create"] = create
        if delete is not None:
            self._values["delete"] = delete
        if read is not None:
            self._values["read"] = read
        if update is not None:
            self._values["update"] = update

    @builtins.property
    def create(self) -> typing.Optional[builtins.str]:
        result = self._values.get("create")
        return result

    @builtins.property
    def delete(self) -> typing.Optional[builtins.str]:
        result = self._values.get("delete")
        return result

    @builtins.property
    def read(self) -> typing.Optional[builtins.str]:
        result = self._values.get("read")
        return result

    @builtins.property
    def update(self) -> typing.Optional[builtins.str]:
        result = self._values.get("update")
        return result

    def __eq__(self, rhs: typing.Any) -> builtins.bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs: typing.Any) -> builtins.bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return "LogicAppActionCustomTimeouts(%s)" % ", ".join(
            k + "=" + repr(v) for k, v in self._values.items()
        )


class LogicAppActionHttp(
    cdktf.TerraformResource,
    metaclass=jsii.JSIIMeta,
    jsii_type="@cdktf/provider-azurerm.LogicAppActionHttp",
):
    def __init__(
        self,
        scope: constructs.Construct,
        id: builtins.str,
        *,
        logic_app_id: builtins.str,
        method: builtins.str,
        name: builtins.str,
        uri: builtins.str,
        body: typing.Optional[builtins.str] = None,
        headers: typing.Optional[typing.Mapping[builtins.str, builtins.str]] = None,
        timeouts: typing.Optional["LogicAppActionHttpTimeouts"] = None,
        count: typing.Optional[jsii.Number] = None,
        depends_on: typing.Optional[typing.List[cdktf.TerraformResource]] = None,
        lifecycle: typing.Optional[cdktf.TerraformResourceLifecycle] = None,
        provider: typing.Optional[cdktf.TerraformProvider] = None,
    ) -> None:
        """
        :param scope: -
        :param id: -
        :param logic_app_id: 
        :param method: 
        :param name: 
        :param uri: 
        :param body: 
        :param headers: 
        :param timeouts: timeouts block.
        :param count: 
        :param depends_on: 
        :param lifecycle: 
        :param provider: 
        """
        config = LogicAppActionHttpConfig(
            logic_app_id=logic_app_id,
            method=method,
            name=name,
            uri=uri,
            body=body,
            headers=headers,
            timeouts=timeouts,
            count=count,
            depends_on=depends_on,
            lifecycle=lifecycle,
            provider=provider,
        )

        jsii.create(LogicAppActionHttp, self, [scope, id, config])

    @jsii.member(jsii_name="synthesizeAttributes")
    def _synthesize_attributes(self) -> typing.Mapping[builtins.str, typing.Any]:
        return jsii.invoke(self, "synthesizeAttributes", [])

    @builtins.property # type: ignore
    @jsii.member(jsii_name="logicAppId")
    def logic_app_id(self) -> builtins.str:
        return jsii.get(self, "logicAppId")

    @logic_app_id.setter # type: ignore
    def logic_app_id(self, value: builtins.str) -> None:
        jsii.set(self, "logicAppId", value)

    @builtins.property # type: ignore
    @jsii.member(jsii_name="method")
    def method(self) -> builtins.str:
        return jsii.get(self, "method")

    @method.setter # type: ignore
    def method(self, value: builtins.str) -> None:
        jsii.set(self, "method", value)

    @builtins.property # type: ignore
    @jsii.member(jsii_name="name")
    def name(self) -> builtins.str:
        return jsii.get(self, "name")

    @name.setter # type: ignore
    def name(self, value: builtins.str) -> None:
        jsii.set(self, "name", value)

    @builtins.property # type: ignore
    @jsii.member(jsii_name="uri")
    def uri(self) -> builtins.str:
        return jsii.get(self, "uri")

    @uri.setter # type: ignore
    def uri(self, value: builtins.str) -> None:
        jsii.set(self, "uri", value)

    @builtins.property # type: ignore
    @jsii.member(jsii_name="body")
    def body(self) -> typing.Optional[builtins.str]:
        return jsii.get(self, "body")

    @body.setter # type: ignore
    def body(self, value: typing.Optional[builtins.str]) -> None:
        jsii.set(self, "body", value)

    @builtins.property # type: ignore
    @jsii.member(jsii_name="headers")
    def headers(self) -> typing.Optional[typing.Mapping[builtins.str, builtins.str]]:
        return jsii.get(self, "headers")

    @headers.setter # type: ignore
    def headers(
        self,
        value: typing.Optional[typing.Mapping[builtins.str, builtins.str]],
    ) -> None:
        jsii.set(self, "headers", value)

    @builtins.property # type: ignore
    @jsii.member(jsii_name="id")
    def id(self) -> typing.Optional[builtins.str]:
        return jsii.get(self, "id")

    @id.setter # type: ignore
    def id(self, value: typing.Optional[builtins.str]) -> None:
        jsii.set(self, "id", value)

    @builtins.property # type: ignore
    @jsii.member(jsii_name="timeouts")
    def timeouts(self) -> typing.Optional["LogicAppActionHttpTimeouts"]:
        return jsii.get(self, "timeouts")

    @timeouts.setter # type: ignore
    def timeouts(self, value: typing.Optional["LogicAppActionHttpTimeouts"]) -> None:
        jsii.set(self, "timeouts", value)


@jsii.data_type(
    jsii_type="@cdktf/provider-azurerm.LogicAppActionHttpConfig",
    jsii_struct_bases=[cdktf.TerraformMetaArguments],
    name_mapping={
        "count": "count",
        "depends_on": "dependsOn",
        "lifecycle": "lifecycle",
        "provider": "provider",
        "logic_app_id": "logicAppId",
        "method": "method",
        "name": "name",
        "uri": "uri",
        "body": "body",
        "headers": "headers",
        "timeouts": "timeouts",
    },
)
class LogicAppActionHttpConfig(cdktf.TerraformMetaArguments):
    def __init__(
        self,
        *,
        count: typing.Optional[jsii.Number] = None,
        depends_on: typing.Optional[typing.List[cdktf.TerraformResource]] = None,
        lifecycle: typing.Optional[cdktf.TerraformResourceLifecycle] = None,
        provider: typing.Optional[cdktf.TerraformProvider] = None,
        logic_app_id: builtins.str,
        method: builtins.str,
        name: builtins.str,
        uri: builtins.str,
        body: typing.Optional[builtins.str] = None,
        headers: typing.Optional[typing.Mapping[builtins.str, builtins.str]] = None,
        timeouts: typing.Optional["LogicAppActionHttpTimeouts"] = None,
    ) -> None:
        """
        :param count: 
        :param depends_on: 
        :param lifecycle: 
        :param provider: 
        :param logic_app_id: 
        :param method: 
        :param name: 
        :param uri: 
        :param body: 
        :param headers: 
        :param timeouts: timeouts block.
        """
        if isinstance(lifecycle, dict):
            lifecycle = cdktf.TerraformResourceLifecycle(**lifecycle)
        if isinstance(timeouts, dict):
            timeouts = LogicAppActionHttpTimeouts(**timeouts)
        self._values: typing.Dict[str, typing.Any] = {
            "logic_app_id": logic_app_id,
            "method": method,
            "name": name,
            "uri": uri,
        }
        if count is not None:
            self._values["count"] = count
        if depends_on is not None:
            self._values["depends_on"] = depends_on
        if lifecycle is not None:
            self._values["lifecycle"] = lifecycle
        if provider is not None:
            self._values["provider"] = provider
        if body is not None:
            self._values["body"] = body
        if headers is not None:
            self._values["headers"] = headers
        if timeouts is not None:
            self._values["timeouts"] = timeouts

    @builtins.property
    def count(self) -> typing.Optional[jsii.Number]:
        """
        :stability: experimental
        """
        result = self._values.get("count")
        return result

    @builtins.property
    def depends_on(self) -> typing.Optional[typing.List[cdktf.TerraformResource]]:
        """
        :stability: experimental
        """
        result = self._values.get("depends_on")
        return result

    @builtins.property
    def lifecycle(self) -> typing.Optional[cdktf.TerraformResourceLifecycle]:
        """
        :stability: experimental
        """
        result = self._values.get("lifecycle")
        return result

    @builtins.property
    def provider(self) -> typing.Optional[cdktf.TerraformProvider]:
        """
        :stability: experimental
        """
        result = self._values.get("provider")
        return result

    @builtins.property
    def logic_app_id(self) -> builtins.str:
        result = self._values.get("logic_app_id")
        assert result is not None, "Required property 'logic_app_id' is missing"
        return result

    @builtins.property
    def method(self) -> builtins.str:
        result = self._values.get("method")
        assert result is not None, "Required property 'method' is missing"
        return result

    @builtins.property
    def name(self) -> builtins.str:
        result = self._values.get("name")
        assert result is not None, "Required property 'name' is missing"
        return result

    @builtins.property
    def uri(self) -> builtins.str:
        result = self._values.get("uri")
        assert result is not None, "Required property 'uri' is missing"
        return result

    @builtins.property
    def body(self) -> typing.Optional[builtins.str]:
        result = self._values.get("body")
        return result

    @builtins.property
    def headers(self) -> typing.Optional[typing.Mapping[builtins.str, builtins.str]]:
        result = self._values.get("headers")
        return result

    @builtins.property
    def timeouts(self) -> typing.Optional["LogicAppActionHttpTimeouts"]:
        """timeouts block."""
        result = self._values.get("timeouts")
        return result

    def __eq__(self, rhs: typing.Any) -> builtins.bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs: typing.Any) -> builtins.bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return "LogicAppActionHttpConfig(%s)" % ", ".join(
            k + "=" + repr(v) for k, v in self._values.items()
        )


@jsii.data_type(
    jsii_type="@cdktf/provider-azurerm.LogicAppActionHttpTimeouts",
    jsii_struct_bases=[],
    name_mapping={
        "create": "create",
        "delete": "delete",
        "read": "read",
        "update": "update",
    },
)
class LogicAppActionHttpTimeouts:
    def __init__(
        self,
        *,
        create: typing.Optional[builtins.str] = None,
        delete: typing.Optional[builtins.str] = None,
        read: typing.Optional[builtins.str] = None,
        update: typing.Optional[builtins.str] = None,
    ) -> None:
        """
        :param create: 
        :param delete: 
        :param read: 
        :param update: 
        """
        self._values: typing.Dict[str, typing.Any] = {}
        if create is not None:
            self._values["create"] = create
        if delete is not None:
            self._values["delete"] = delete
        if read is not None:
            self._values["read"] = read
        if update is not None:
            self._values["update"] = update

    @builtins.property
    def create(self) -> typing.Optional[builtins.str]:
        result = self._values.get("create")
        return result

    @builtins.property
    def delete(self) -> typing.Optional[builtins.str]:
        result = self._values.get("delete")
        return result

    @builtins.property
    def read(self) -> typing.Optional[builtins.str]:
        result = self._values.get("read")
        return result

    @builtins.property
    def update(self) -> typing.Optional[builtins.str]:
        result = self._values.get("update")
        return result

    def __eq__(self, rhs: typing.Any) -> builtins.bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs: typing.Any) -> builtins.bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return "LogicAppActionHttpTimeouts(%s)" % ", ".join(
            k + "=" + repr(v) for k, v in self._values.items()
        )


class LogicAppTriggerCustom(
    cdktf.TerraformResource,
    metaclass=jsii.JSIIMeta,
    jsii_type="@cdktf/provider-azurerm.LogicAppTriggerCustom",
):
    def __init__(
        self,
        scope: constructs.Construct,
        id: builtins.str,
        *,
        body: builtins.str,
        logic_app_id: builtins.str,
        name: builtins.str,
        timeouts: typing.Optional["LogicAppTriggerCustomTimeouts"] = None,
        count: typing.Optional[jsii.Number] = None,
        depends_on: typing.Optional[typing.List[cdktf.TerraformResource]] = None,
        lifecycle: typing.Optional[cdktf.TerraformResourceLifecycle] = None,
        provider: typing.Optional[cdktf.TerraformProvider] = None,
    ) -> None:
        """
        :param scope: -
        :param id: -
        :param body: 
        :param logic_app_id: 
        :param name: 
        :param timeouts: timeouts block.
        :param count: 
        :param depends_on: 
        :param lifecycle: 
        :param provider: 
        """
        config = LogicAppTriggerCustomConfig(
            body=body,
            logic_app_id=logic_app_id,
            name=name,
            timeouts=timeouts,
            count=count,
            depends_on=depends_on,
            lifecycle=lifecycle,
            provider=provider,
        )

        jsii.create(LogicAppTriggerCustom, self, [scope, id, config])

    @jsii.member(jsii_name="synthesizeAttributes")
    def _synthesize_attributes(self) -> typing.Mapping[builtins.str, typing.Any]:
        return jsii.invoke(self, "synthesizeAttributes", [])

    @builtins.property # type: ignore
    @jsii.member(jsii_name="body")
    def body(self) -> builtins.str:
        return jsii.get(self, "body")

    @body.setter # type: ignore
    def body(self, value: builtins.str) -> None:
        jsii.set(self, "body", value)

    @builtins.property # type: ignore
    @jsii.member(jsii_name="logicAppId")
    def logic_app_id(self) -> builtins.str:
        return jsii.get(self, "logicAppId")

    @logic_app_id.setter # type: ignore
    def logic_app_id(self, value: builtins.str) -> None:
        jsii.set(self, "logicAppId", value)

    @builtins.property # type: ignore
    @jsii.member(jsii_name="name")
    def name(self) -> builtins.str:
        return jsii.get(self, "name")

    @name.setter # type: ignore
    def name(self, value: builtins.str) -> None:
        jsii.set(self, "name", value)

    @builtins.property # type: ignore
    @jsii.member(jsii_name="id")
    def id(self) -> typing.Optional[builtins.str]:
        return jsii.get(self, "id")

    @id.setter # type: ignore
    def id(self, value: typing.Optional[builtins.str]) -> None:
        jsii.set(self, "id", value)

    @builtins.property # type: ignore
    @jsii.member(jsii_name="timeouts")
    def timeouts(self) -> typing.Optional["LogicAppTriggerCustomTimeouts"]:
        return jsii.get(self, "timeouts")

    @timeouts.setter # type: ignore
    def timeouts(self, value: typing.Optional["LogicAppTriggerCustomTimeouts"]) -> None:
        jsii.set(self, "timeouts", value)


@jsii.data_type(
    jsii_type="@cdktf/provider-azurerm.LogicAppTriggerCustomConfig",
    jsii_struct_bases=[cdktf.TerraformMetaArguments],
    name_mapping={
        "count": "count",
        "depends_on": "dependsOn",
        "lifecycle": "lifecycle",
        "provider": "provider",
        "body": "body",
        "logic_app_id": "logicAppId",
        "name": "name",
        "timeouts": "timeouts",
    },
)
class LogicAppTriggerCustomConfig(cdktf.TerraformMetaArguments):
    def __init__(
        self,
        *,
        count: typing.Optional[jsii.Number] = None,
        depends_on: typing.Optional[typing.List[cdktf.TerraformResource]] = None,
        lifecycle: typing.Optional[cdktf.TerraformResourceLifecycle] = None,
        provider: typing.Optional[cdktf.TerraformProvider] = None,
        body: builtins.str,
        logic_app_id: builtins.str,
        name: builtins.str,
        timeouts: typing.Optional["LogicAppTriggerCustomTimeouts"] = None,
    ) -> None:
        """
        :param count: 
        :param depends_on: 
        :param lifecycle: 
        :param provider: 
        :param body: 
        :param logic_app_id: 
        :param name: 
        :param timeouts: timeouts block.
        """
        if isinstance(lifecycle, dict):
            lifecycle = cdktf.TerraformResourceLifecycle(**lifecycle)
        if isinstance(timeouts, dict):
            timeouts = LogicAppTriggerCustomTimeouts(**timeouts)
        self._values: typing.Dict[str, typing.Any] = {
            "body": body,
            "logic_app_id": logic_app_id,
            "name": name,
        }
        if count is not None:
            self._values["count"] = count
        if depends_on is not None:
            self._values["depends_on"] = depends_on
        if lifecycle is not None:
            self._values["lifecycle"] = lifecycle
        if provider is not None:
            self._values["provider"] = provider
        if timeouts is not None:
            self._values["timeouts"] = timeouts

    @builtins.property
    def count(self) -> typing.Optional[jsii.Number]:
        """
        :stability: experimental
        """
        result = self._values.get("count")
        return result

    @builtins.property
    def depends_on(self) -> typing.Optional[typing.List[cdktf.TerraformResource]]:
        """
        :stability: experimental
        """
        result = self._values.get("depends_on")
        return result

    @builtins.property
    def lifecycle(self) -> typing.Optional[cdktf.TerraformResourceLifecycle]:
        """
        :stability: experimental
        """
        result = self._values.get("lifecycle")
        return result

    @builtins.property
    def provider(self) -> typing.Optional[cdktf.TerraformProvider]:
        """
        :stability: experimental
        """
        result = self._values.get("provider")
        return result

    @builtins.property
    def body(self) -> builtins.str:
        result = self._values.get("body")
        assert result is not None, "Required property 'body' is missing"
        return result

    @builtins.property
    def logic_app_id(self) -> builtins.str:
        result = self._values.get("logic_app_id")
        assert result is not None, "Required property 'logic_app_id' is missing"
        return result

    @builtins.property
    def name(self) -> builtins.str:
        result = self._values.get("name")
        assert result is not None, "Required property 'name' is missing"
        return result

    @builtins.property
    def timeouts(self) -> typing.Optional["LogicAppTriggerCustomTimeouts"]:
        """timeouts block."""
        result = self._values.get("timeouts")
        return result

    def __eq__(self, rhs: typing.Any) -> builtins.bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs: typing.Any) -> builtins.bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return "LogicAppTriggerCustomConfig(%s)" % ", ".join(
            k + "=" + repr(v) for k, v in self._values.items()
        )


@jsii.data_type(
    jsii_type="@cdktf/provider-azurerm.LogicAppTriggerCustomTimeouts",
    jsii_struct_bases=[],
    name_mapping={
        "create": "create",
        "delete": "delete",
        "read": "read",
        "update": "update",
    },
)
class LogicAppTriggerCustomTimeouts:
    def __init__(
        self,
        *,
        create: typing.Optional[builtins.str] = None,
        delete: typing.Optional[builtins.str] = None,
        read: typing.Optional[builtins.str] = None,
        update: typing.Optional[builtins.str] = None,
    ) -> None:
        """
        :param create: 
        :param delete: 
        :param read: 
        :param update: 
        """
        self._values: typing.Dict[str, typing.Any] = {}
        if create is not None:
            self._values["create"] = create
        if delete is not None:
            self._values["delete"] = delete
        if read is not None:
            self._values["read"] = read
        if update is not None:
            self._values["update"] = update

    @builtins.property
    def create(self) -> typing.Optional[builtins.str]:
        result = self._values.get("create")
        return result

    @builtins.property
    def delete(self) -> typing.Optional[builtins.str]:
        result = self._values.get("delete")
        return result

    @builtins.property
    def read(self) -> typing.Optional[builtins.str]:
        result = self._values.get("read")
        return result

    @builtins.property
    def update(self) -> typing.Optional[builtins.str]:
        result = self._values.get("update")
        return result

    def __eq__(self, rhs: typing.Any) -> builtins.bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs: typing.Any) -> builtins.bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return "LogicAppTriggerCustomTimeouts(%s)" % ", ".join(
            k + "=" + repr(v) for k, v in self._values.items()
        )


class LogicAppTriggerHttpRequest(
    cdktf.TerraformResource,
    metaclass=jsii.JSIIMeta,
    jsii_type="@cdktf/provider-azurerm.LogicAppTriggerHttpRequest",
):
    def __init__(
        self,
        scope: constructs.Construct,
        id: builtins.str,
        *,
        logic_app_id: builtins.str,
        name: builtins.str,
        schema: builtins.str,
        method: typing.Optional[builtins.str] = None,
        relative_path: typing.Optional[builtins.str] = None,
        timeouts: typing.Optional["LogicAppTriggerHttpRequestTimeouts"] = None,
        count: typing.Optional[jsii.Number] = None,
        depends_on: typing.Optional[typing.List[cdktf.TerraformResource]] = None,
        lifecycle: typing.Optional[cdktf.TerraformResourceLifecycle] = None,
        provider: typing.Optional[cdktf.TerraformProvider] = None,
    ) -> None:
        """
        :param scope: -
        :param id: -
        :param logic_app_id: 
        :param name: 
        :param schema: 
        :param method: 
        :param relative_path: 
        :param timeouts: timeouts block.
        :param count: 
        :param depends_on: 
        :param lifecycle: 
        :param provider: 
        """
        config = LogicAppTriggerHttpRequestConfig(
            logic_app_id=logic_app_id,
            name=name,
            schema=schema,
            method=method,
            relative_path=relative_path,
            timeouts=timeouts,
            count=count,
            depends_on=depends_on,
            lifecycle=lifecycle,
            provider=provider,
        )

        jsii.create(LogicAppTriggerHttpRequest, self, [scope, id, config])

    @jsii.member(jsii_name="synthesizeAttributes")
    def _synthesize_attributes(self) -> typing.Mapping[builtins.str, typing.Any]:
        return jsii.invoke(self, "synthesizeAttributes", [])

    @builtins.property # type: ignore
    @jsii.member(jsii_name="logicAppId")
    def logic_app_id(self) -> builtins.str:
        return jsii.get(self, "logicAppId")

    @logic_app_id.setter # type: ignore
    def logic_app_id(self, value: builtins.str) -> None:
        jsii.set(self, "logicAppId", value)

    @builtins.property # type: ignore
    @jsii.member(jsii_name="name")
    def name(self) -> builtins.str:
        return jsii.get(self, "name")

    @name.setter # type: ignore
    def name(self, value: builtins.str) -> None:
        jsii.set(self, "name", value)

    @builtins.property # type: ignore
    @jsii.member(jsii_name="schema")
    def schema(self) -> builtins.str:
        return jsii.get(self, "schema")

    @schema.setter # type: ignore
    def schema(self, value: builtins.str) -> None:
        jsii.set(self, "schema", value)

    @builtins.property # type: ignore
    @jsii.member(jsii_name="id")
    def id(self) -> typing.Optional[builtins.str]:
        return jsii.get(self, "id")

    @id.setter # type: ignore
    def id(self, value: typing.Optional[builtins.str]) -> None:
        jsii.set(self, "id", value)

    @builtins.property # type: ignore
    @jsii.member(jsii_name="method")
    def method(self) -> typing.Optional[builtins.str]:
        return jsii.get(self, "method")

    @method.setter # type: ignore
    def method(self, value: typing.Optional[builtins.str]) -> None:
        jsii.set(self, "method", value)

    @builtins.property # type: ignore
    @jsii.member(jsii_name="relativePath")
    def relative_path(self) -> typing.Optional[builtins.str]:
        return jsii.get(self, "relativePath")

    @relative_path.setter # type: ignore
    def relative_path(self, value: typing.Optional[builtins.str]) -> None:
        jsii.set(self, "relativePath", value)

    @builtins.property # type: ignore
    @jsii.member(jsii_name="timeouts")
    def timeouts(self) -> typing.Optional["LogicAppTriggerHttpRequestTimeouts"]:
        return jsii.get(self, "timeouts")

    @timeouts.setter # type: ignore
    def timeouts(
        self,
        value: typing.Optional["LogicAppTriggerHttpRequestTimeouts"],
    ) -> None:
        jsii.set(self, "timeouts", value)


@jsii.data_type(
    jsii_type="@cdktf/provider-azurerm.LogicAppTriggerHttpRequestConfig",
    jsii_struct_bases=[cdktf.TerraformMetaArguments],
    name_mapping={
        "count": "count",
        "depends_on": "dependsOn",
        "lifecycle": "lifecycle",
        "provider": "provider",
        "logic_app_id": "logicAppId",
        "name": "name",
        "schema": "schema",
        "method": "method",
        "relative_path": "relativePath",
        "timeouts": "timeouts",
    },
)
class LogicAppTriggerHttpRequestConfig(cdktf.TerraformMetaArguments):
    def __init__(
        self,
        *,
        count: typing.Optional[jsii.Number] = None,
        depends_on: typing.Optional[typing.List[cdktf.TerraformResource]] = None,
        lifecycle: typing.Optional[cdktf.TerraformResourceLifecycle] = None,
        provider: typing.Optional[cdktf.TerraformProvider] = None,
        logic_app_id: builtins.str,
        name: builtins.str,
        schema: builtins.str,
        method: typing.Optional[builtins.str] = None,
        relative_path: typing.Optional[builtins.str] = None,
        timeouts: typing.Optional["LogicAppTriggerHttpRequestTimeouts"] = None,
    ) -> None:
        """
        :param count: 
        :param depends_on: 
        :param lifecycle: 
        :param provider: 
        :param logic_app_id: 
        :param name: 
        :param schema: 
        :param method: 
        :param relative_path: 
        :param timeouts: timeouts block.
        """
        if isinstance(lifecycle, dict):
            lifecycle = cdktf.TerraformResourceLifecycle(**lifecycle)
        if isinstance(timeouts, dict):
            timeouts = LogicAppTriggerHttpRequestTimeouts(**timeouts)
        self._values: typing.Dict[str, typing.Any] = {
            "logic_app_id": logic_app_id,
            "name": name,
            "schema": schema,
        }
        if count is not None:
            self._values["count"] = count
        if depends_on is not None:
            self._values["depends_on"] = depends_on
        if lifecycle is not None:
            self._values["lifecycle"] = lifecycle
        if provider is not None:
            self._values["provider"] = provider
        if method is not None:
            self._values["method"] = method
        if relative_path is not None:
            self._values["relative_path"] = relative_path
        if timeouts is not None:
            self._values["timeouts"] = timeouts

    @builtins.property
    def count(self) -> typing.Optional[jsii.Number]:
        """
        :stability: experimental
        """
        result = self._values.get("count")
        return result

    @builtins.property
    def depends_on(self) -> typing.Optional[typing.List[cdktf.TerraformResource]]:
        """
        :stability: experimental
        """
        result = self._values.get("depends_on")
        return result

    @builtins.property
    def lifecycle(self) -> typing.Optional[cdktf.TerraformResourceLifecycle]:
        """
        :stability: experimental
        """
        result = self._values.get("lifecycle")
        return result

    @builtins.property
    def provider(self) -> typing.Optional[cdktf.TerraformProvider]:
        """
        :stability: experimental
        """
        result = self._values.get("provider")
        return result

    @builtins.property
    def logic_app_id(self) -> builtins.str:
        result = self._values.get("logic_app_id")
        assert result is not None, "Required property 'logic_app_id' is missing"
        return result

    @builtins.property
    def name(self) -> builtins.str:
        result = self._values.get("name")
        assert result is not None, "Required property 'name' is missing"
        return result

    @builtins.property
    def schema(self) -> builtins.str:
        result = self._values.get("schema")
        assert result is not None, "Required property 'schema' is missing"
        return result

    @builtins.property
    def method(self) -> typing.Optional[builtins.str]:
        result = self._values.get("method")
        return result

    @builtins.property
    def relative_path(self) -> typing.Optional[builtins.str]:
        result = self._values.get("relative_path")
        return result

    @builtins.property
    def timeouts(self) -> typing.Optional["LogicAppTriggerHttpRequestTimeouts"]:
        """timeouts block."""
        result = self._values.get("timeouts")
        return result

    def __eq__(self, rhs: typing.Any) -> builtins.bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs: typing.Any) -> builtins.bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return "LogicAppTriggerHttpRequestConfig(%s)" % ", ".join(
            k + "=" + repr(v) for k, v in self._values.items()
        )


@jsii.data_type(
    jsii_type="@cdktf/provider-azurerm.LogicAppTriggerHttpRequestTimeouts",
    jsii_struct_bases=[],
    name_mapping={
        "create": "create",
        "delete": "delete",
        "read": "read",
        "update": "update",
    },
)
class LogicAppTriggerHttpRequestTimeouts:
    def __init__(
        self,
        *,
        create: typing.Optional[builtins.str] = None,
        delete: typing.Optional[builtins.str] = None,
        read: typing.Optional[builtins.str] = None,
        update: typing.Optional[builtins.str] = None,
    ) -> None:
        """
        :param create: 
        :param delete: 
        :param read: 
        :param update: 
        """
        self._values: typing.Dict[str, typing.Any] = {}
        if create is not None:
            self._values["create"] = create
        if delete is not None:
            self._values["delete"] = delete
        if read is not None:
            self._values["read"] = read
        if update is not None:
            self._values["update"] = update

    @builtins.property
    def create(self) -> typing.Optional[builtins.str]:
        result = self._values.get("create")
        return result

    @builtins.property
    def delete(self) -> typing.Optional[builtins.str]:
        result = self._values.get("delete")
        return result

    @builtins.property
    def read(self) -> typing.Optional[builtins.str]:
        result = self._values.get("read")
        return result

    @builtins.property
    def update(self) -> typing.Optional[builtins.str]:
        result = self._values.get("update")
        return result

    def __eq__(self, rhs: typing.Any) -> builtins.bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs: typing.Any) -> builtins.bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return "LogicAppTriggerHttpRequestTimeouts(%s)" % ", ".join(
            k + "=" + repr(v) for k, v in self._values.items()
        )


class LogicAppTriggerRecurrence(
    cdktf.TerraformResource,
    metaclass=jsii.JSIIMeta,
    jsii_type="@cdktf/provider-azurerm.LogicAppTriggerRecurrence",
):
    def __init__(
        self,
        scope: constructs.Construct,
        id: builtins.str,
        *,
        frequency: builtins.str,
        interval: jsii.Number,
        logic_app_id: builtins.str,
        name: builtins.str,
        start_time: typing.Optional[builtins.str] = None,
        timeouts: typing.Optional["LogicAppTriggerRecurrenceTimeouts"] = None,
        count: typing.Optional[jsii.Number] = None,
        depends_on: typing.Optional[typing.List[cdktf.TerraformResource]] = None,
        lifecycle: typing.Optional[cdktf.TerraformResourceLifecycle] = None,
        provider: typing.Optional[cdktf.TerraformProvider] = None,
    ) -> None:
        """
        :param scope: -
        :param id: -
        :param frequency: 
        :param interval: 
        :param logic_app_id: 
        :param name: 
        :param start_time: 
        :param timeouts: timeouts block.
        :param count: 
        :param depends_on: 
        :param lifecycle: 
        :param provider: 
        """
        config = LogicAppTriggerRecurrenceConfig(
            frequency=frequency,
            interval=interval,
            logic_app_id=logic_app_id,
            name=name,
            start_time=start_time,
            timeouts=timeouts,
            count=count,
            depends_on=depends_on,
            lifecycle=lifecycle,
            provider=provider,
        )

        jsii.create(LogicAppTriggerRecurrence, self, [scope, id, config])

    @jsii.member(jsii_name="synthesizeAttributes")
    def _synthesize_attributes(self) -> typing.Mapping[builtins.str, typing.Any]:
        return jsii.invoke(self, "synthesizeAttributes", [])

    @builtins.property # type: ignore
    @jsii.member(jsii_name="frequency")
    def frequency(self) -> builtins.str:
        return jsii.get(self, "frequency")

    @frequency.setter # type: ignore
    def frequency(self, value: builtins.str) -> None:
        jsii.set(self, "frequency", value)

    @builtins.property # type: ignore
    @jsii.member(jsii_name="interval")
    def interval(self) -> jsii.Number:
        return jsii.get(self, "interval")

    @interval.setter # type: ignore
    def interval(self, value: jsii.Number) -> None:
        jsii.set(self, "interval", value)

    @builtins.property # type: ignore
    @jsii.member(jsii_name="logicAppId")
    def logic_app_id(self) -> builtins.str:
        return jsii.get(self, "logicAppId")

    @logic_app_id.setter # type: ignore
    def logic_app_id(self, value: builtins.str) -> None:
        jsii.set(self, "logicAppId", value)

    @builtins.property # type: ignore
    @jsii.member(jsii_name="name")
    def name(self) -> builtins.str:
        return jsii.get(self, "name")

    @name.setter # type: ignore
    def name(self, value: builtins.str) -> None:
        jsii.set(self, "name", value)

    @builtins.property # type: ignore
    @jsii.member(jsii_name="id")
    def id(self) -> typing.Optional[builtins.str]:
        return jsii.get(self, "id")

    @id.setter # type: ignore
    def id(self, value: typing.Optional[builtins.str]) -> None:
        jsii.set(self, "id", value)

    @builtins.property # type: ignore
    @jsii.member(jsii_name="startTime")
    def start_time(self) -> typing.Optional[builtins.str]:
        return jsii.get(self, "startTime")

    @start_time.setter # type: ignore
    def start_time(self, value: typing.Optional[builtins.str]) -> None:
        jsii.set(self, "startTime", value)

    @builtins.property # type: ignore
    @jsii.member(jsii_name="timeouts")
    def timeouts(self) -> typing.Optional["LogicAppTriggerRecurrenceTimeouts"]:
        return jsii.get(self, "timeouts")

    @timeouts.setter # type: ignore
    def timeouts(
        self,
        value: typing.Optional["LogicAppTriggerRecurrenceTimeouts"],
    ) -> None:
        jsii.set(self, "timeouts", value)


@jsii.data_type(
    jsii_type="@cdktf/provider-azurerm.LogicAppTriggerRecurrenceConfig",
    jsii_struct_bases=[cdktf.TerraformMetaArguments],
    name_mapping={
        "count": "count",
        "depends_on": "dependsOn",
        "lifecycle": "lifecycle",
        "provider": "provider",
        "frequency": "frequency",
        "interval": "interval",
        "logic_app_id": "logicAppId",
        "name": "name",
        "start_time": "startTime",
        "timeouts": "timeouts",
    },
)
class LogicAppTriggerRecurrenceConfig(cdktf.TerraformMetaArguments):
    def __init__(
        self,
        *,
        count: typing.Optional[jsii.Number] = None,
        depends_on: typing.Optional[typing.List[cdktf.TerraformResource]] = None,
        lifecycle: typing.Optional[cdktf.TerraformResourceLifecycle] = None,
        provider: typing.Optional[cdktf.TerraformProvider] = None,
        frequency: builtins.str,
        interval: jsii.Number,
        logic_app_id: builtins.str,
        name: builtins.str,
        start_time: typing.Optional[builtins.str] = None,
        timeouts: typing.Optional["LogicAppTriggerRecurrenceTimeouts"] = None,
    ) -> None:
        """
        :param count: 
        :param depends_on: 
        :param lifecycle: 
        :param provider: 
        :param frequency: 
        :param interval: 
        :param logic_app_id: 
        :param name: 
        :param start_time: 
        :param timeouts: timeouts block.
        """
        if isinstance(lifecycle, dict):
            lifecycle = cdktf.TerraformResourceLifecycle(**lifecycle)
        if isinstance(timeouts, dict):
            timeouts = LogicAppTriggerRecurrenceTimeouts(**timeouts)
        self._values: typing.Dict[str, typing.Any] = {
            "frequency": frequency,
            "interval": interval,
            "logic_app_id": logic_app_id,
            "name": name,
        }
        if count is not None:
            self._values["count"] = count
        if depends_on is not None:
            self._values["depends_on"] = depends_on
        if lifecycle is not None:
            self._values["lifecycle"] = lifecycle
        if provider is not None:
            self._values["provider"] = provider
        if start_time is not None:
            self._values["start_time"] = start_time
        if timeouts is not None:
            self._values["timeouts"] = timeouts

    @builtins.property
    def count(self) -> typing.Optional[jsii.Number]:
        """
        :stability: experimental
        """
        result = self._values.get("count")
        return result

    @builtins.property
    def depends_on(self) -> typing.Optional[typing.List[cdktf.TerraformResource]]:
        """
        :stability: experimental
        """
        result = self._values.get("depends_on")
        return result

    @builtins.property
    def lifecycle(self) -> typing.Optional[cdktf.TerraformResourceLifecycle]:
        """
        :stability: experimental
        """
        result = self._values.get("lifecycle")
        return result

    @builtins.property
    def provider(self) -> typing.Optional[cdktf.TerraformProvider]:
        """
        :stability: experimental
        """
        result = self._values.get("provider")
        return result

    @builtins.property
    def frequency(self) -> builtins.str:
        result = self._values.get("frequency")
        assert result is not None, "Required property 'frequency' is missing"
        return result

    @builtins.property
    def interval(self) -> jsii.Number:
        result = self._values.get("interval")
        assert result is not None, "Required property 'interval' is missing"
        return result

    @builtins.property
    def logic_app_id(self) -> builtins.str:
        result = self._values.get("logic_app_id")
        assert result is not None, "Required property 'logic_app_id' is missing"
        return result

    @builtins.property
    def name(self) -> builtins.str:
        result = self._values.get("name")
        assert result is not None, "Required property 'name' is missing"
        return result

    @builtins.property
    def start_time(self) -> typing.Optional[builtins.str]:
        result = self._values.get("start_time")
        return result

    @builtins.property
    def timeouts(self) -> typing.Optional["LogicAppTriggerRecurrenceTimeouts"]:
        """timeouts block."""
        result = self._values.get("timeouts")
        return result

    def __eq__(self, rhs: typing.Any) -> builtins.bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs: typing.Any) -> builtins.bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return "LogicAppTriggerRecurrenceConfig(%s)" % ", ".join(
            k + "=" + repr(v) for k, v in self._values.items()
        )


@jsii.data_type(
    jsii_type="@cdktf/provider-azurerm.LogicAppTriggerRecurrenceTimeouts",
    jsii_struct_bases=[],
    name_mapping={
        "create": "create",
        "delete": "delete",
        "read": "read",
        "update": "update",
    },
)
class LogicAppTriggerRecurrenceTimeouts:
    def __init__(
        self,
        *,
        create: typing.Optional[builtins.str] = None,
        delete: typing.Optional[builtins.str] = None,
        read: typing.Optional[builtins.str] = None,
        update: typing.Optional[builtins.str] = None,
    ) -> None:
        """
        :param create: 
        :param delete: 
        :param read: 
        :param update: 
        """
        self._values: typing.Dict[str, typing.Any] = {}
        if create is not None:
            self._values["create"] = create
        if delete is not None:
            self._values["delete"] = delete
        if read is not None:
            self._values["read"] = read
        if update is not None:
            self._values["update"] = update

    @builtins.property
    def create(self) -> typing.Optional[builtins.str]:
        result = self._values.get("create")
        return result

    @builtins.property
    def delete(self) -> typing.Optional[builtins.str]:
        result = self._values.get("delete")
        return result

    @builtins.property
    def read(self) -> typing.Optional[builtins.str]:
        result = self._values.get("read")
        return result

    @builtins.property
    def update(self) -> typing.Optional[builtins.str]:
        result = self._values.get("update")
        return result

    def __eq__(self, rhs: typing.Any) -> builtins.bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs: typing.Any) -> builtins.bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return "LogicAppTriggerRecurrenceTimeouts(%s)" % ", ".join(
            k + "=" + repr(v) for k, v in self._values.items()
        )


class LogicAppWorkflow(
    cdktf.TerraformResource,
    metaclass=jsii.JSIIMeta,
    jsii_type="@cdktf/provider-azurerm.LogicAppWorkflow",
):
    def __init__(
        self,
        scope: constructs.Construct,
        id: builtins.str,
        *,
        location: builtins.str,
        name: builtins.str,
        resource_group_name: builtins.str,
        parameters: typing.Optional[typing.Mapping[builtins.str, builtins.str]] = None,
        tags: typing.Optional[typing.Mapping[builtins.str, builtins.str]] = None,
        timeouts: typing.Optional["LogicAppWorkflowTimeouts"] = None,
        workflow_schema: typing.Optional[builtins.str] = None,
        workflow_version: typing.Optional[builtins.str] = None,
        count: typing.Optional[jsii.Number] = None,
        depends_on: typing.Optional[typing.List[cdktf.TerraformResource]] = None,
        lifecycle: typing.Optional[cdktf.TerraformResourceLifecycle] = None,
        provider: typing.Optional[cdktf.TerraformProvider] = None,
    ) -> None:
        """
        :param scope: -
        :param id: -
        :param location: 
        :param name: 
        :param resource_group_name: 
        :param parameters: 
        :param tags: 
        :param timeouts: timeouts block.
        :param workflow_schema: 
        :param workflow_version: 
        :param count: 
        :param depends_on: 
        :param lifecycle: 
        :param provider: 
        """
        config = LogicAppWorkflowConfig(
            location=location,
            name=name,
            resource_group_name=resource_group_name,
            parameters=parameters,
            tags=tags,
            timeouts=timeouts,
            workflow_schema=workflow_schema,
            workflow_version=workflow_version,
            count=count,
            depends_on=depends_on,
            lifecycle=lifecycle,
            provider=provider,
        )

        jsii.create(LogicAppWorkflow, self, [scope, id, config])

    @jsii.member(jsii_name="synthesizeAttributes")
    def _synthesize_attributes(self) -> typing.Mapping[builtins.str, typing.Any]:
        return jsii.invoke(self, "synthesizeAttributes", [])

    @builtins.property # type: ignore
    @jsii.member(jsii_name="accessEndpoint")
    def access_endpoint(self) -> builtins.str:
        return jsii.get(self, "accessEndpoint")

    @builtins.property # type: ignore
    @jsii.member(jsii_name="location")
    def location(self) -> builtins.str:
        return jsii.get(self, "location")

    @location.setter # type: ignore
    def location(self, value: builtins.str) -> None:
        jsii.set(self, "location", value)

    @builtins.property # type: ignore
    @jsii.member(jsii_name="name")
    def name(self) -> builtins.str:
        return jsii.get(self, "name")

    @name.setter # type: ignore
    def name(self, value: builtins.str) -> None:
        jsii.set(self, "name", value)

    @builtins.property # type: ignore
    @jsii.member(jsii_name="resourceGroupName")
    def resource_group_name(self) -> builtins.str:
        return jsii.get(self, "resourceGroupName")

    @resource_group_name.setter # type: ignore
    def resource_group_name(self, value: builtins.str) -> None:
        jsii.set(self, "resourceGroupName", value)

    @builtins.property # type: ignore
    @jsii.member(jsii_name="id")
    def id(self) -> typing.Optional[builtins.str]:
        return jsii.get(self, "id")

    @id.setter # type: ignore
    def id(self, value: typing.Optional[builtins.str]) -> None:
        jsii.set(self, "id", value)

    @builtins.property # type: ignore
    @jsii.member(jsii_name="parameters")
    def parameters(self) -> typing.Optional[typing.Mapping[builtins.str, builtins.str]]:
        return jsii.get(self, "parameters")

    @parameters.setter # type: ignore
    def parameters(
        self,
        value: typing.Optional[typing.Mapping[builtins.str, builtins.str]],
    ) -> None:
        jsii.set(self, "parameters", value)

    @builtins.property # type: ignore
    @jsii.member(jsii_name="tags")
    def tags(self) -> typing.Optional[typing.Mapping[builtins.str, builtins.str]]:
        return jsii.get(self, "tags")

    @tags.setter # type: ignore
    def tags(
        self,
        value: typing.Optional[typing.Mapping[builtins.str, builtins.str]],
    ) -> None:
        jsii.set(self, "tags", value)

    @builtins.property # type: ignore
    @jsii.member(jsii_name="timeouts")
    def timeouts(self) -> typing.Optional["LogicAppWorkflowTimeouts"]:
        return jsii.get(self, "timeouts")

    @timeouts.setter # type: ignore
    def timeouts(self, value: typing.Optional["LogicAppWorkflowTimeouts"]) -> None:
        jsii.set(self, "timeouts", value)

    @builtins.property # type: ignore
    @jsii.member(jsii_name="workflowSchema")
    def workflow_schema(self) -> typing.Optional[builtins.str]:
        return jsii.get(self, "workflowSchema")

    @workflow_schema.setter # type: ignore
    def workflow_schema(self, value: typing.Optional[builtins.str]) -> None:
        jsii.set(self, "workflowSchema", value)

    @builtins.property # type: ignore
    @jsii.member(jsii_name="workflowVersion")
    def workflow_version(self) -> typing.Optional[builtins.str]:
        return jsii.get(self, "workflowVersion")

    @workflow_version.setter # type: ignore
    def workflow_version(self, value: typing.Optional[builtins.str]) -> None:
        jsii.set(self, "workflowVersion", value)


@jsii.data_type(
    jsii_type="@cdktf/provider-azurerm.LogicAppWorkflowConfig",
    jsii_struct_bases=[cdktf.TerraformMetaArguments],
    name_mapping={
        "count": "count",
        "depends_on": "dependsOn",
        "lifecycle": "lifecycle",
        "provider": "provider",
        "location": "location",
        "name": "name",
        "resource_group_name": "resourceGroupName",
        "parameters": "parameters",
        "tags": "tags",
        "timeouts": "timeouts",
        "workflow_schema": "workflowSchema",
        "workflow_version": "workflowVersion",
    },
)
class LogicAppWorkflowConfig(cdktf.TerraformMetaArguments):
    def __init__(
        self,
        *,
        count: typing.Optional[jsii.Number] = None,
        depends_on: typing.Optional[typing.List[cdktf.TerraformResource]] = None,
        lifecycle: typing.Optional[cdktf.TerraformResourceLifecycle] = None,
        provider: typing.Optional[cdktf.TerraformProvider] = None,
        location: builtins.str,
        name: builtins.str,
        resource_group_name: builtins.str,
        parameters: typing.Optional[typing.Mapping[builtins.str, builtins.str]] = None,
        tags: typing.Optional[typing.Mapping[builtins.str, builtins.str]] = None,
        timeouts: typing.Optional["LogicAppWorkflowTimeouts"] = None,
        workflow_schema: typing.Optional[builtins.str] = None,
        workflow_version: typing.Optional[builtins.str] = None,
    ) -> None:
        """
        :param count: 
        :param depends_on: 
        :param lifecycle: 
        :param provider: 
        :param location: 
        :param name: 
        :param resource_group_name: 
        :param parameters: 
        :param tags: 
        :param timeouts: timeouts block.
        :param workflow_schema: 
        :param workflow_version: 
        """
        if isinstance(lifecycle, dict):
            lifecycle = cdktf.TerraformResourceLifecycle(**lifecycle)
        if isinstance(timeouts, dict):
            timeouts = LogicAppWorkflowTimeouts(**timeouts)
        self._values: typing.Dict[str, typing.Any] = {
            "location": location,
            "name": name,
            "resource_group_name": resource_group_name,
        }
        if count is not None:
            self._values["count"] = count
        if depends_on is not None:
            self._values["depends_on"] = depends_on
        if lifecycle is not None:
            self._values["lifecycle"] = lifecycle
        if provider is not None:
            self._values["provider"] = provider
        if parameters is not None:
            self._values["parameters"] = parameters
        if tags is not None:
            self._values["tags"] = tags
        if timeouts is not None:
            self._values["timeouts"] = timeouts
        if workflow_schema is not None:
            self._values["workflow_schema"] = workflow_schema
        if workflow_version is not None:
            self._values["workflow_version"] = workflow_version

    @builtins.property
    def count(self) -> typing.Optional[jsii.Number]:
        """
        :stability: experimental
        """
        result = self._values.get("count")
        return result

    @builtins.property
    def depends_on(self) -> typing.Optional[typing.List[cdktf.TerraformResource]]:
        """
        :stability: experimental
        """
        result = self._values.get("depends_on")
        return result

    @builtins.property
    def lifecycle(self) -> typing.Optional[cdktf.TerraformResourceLifecycle]:
        """
        :stability: experimental
        """
        result = self._values.get("lifecycle")
        return result

    @builtins.property
    def provider(self) -> typing.Optional[cdktf.TerraformProvider]:
        """
        :stability: experimental
        """
        result = self._values.get("provider")
        return result

    @builtins.property
    def location(self) -> builtins.str:
        result = self._values.get("location")
        assert result is not None, "Required property 'location' is missing"
        return result

    @builtins.property
    def name(self) -> builtins.str:
        result = self._values.get("name")
        assert result is not None, "Required property 'name' is missing"
        return result

    @builtins.property
    def resource_group_name(self) -> builtins.str:
        result = self._values.get("resource_group_name")
        assert result is not None, "Required property 'resource_group_name' is missing"
        return result

    @builtins.property
    def parameters(self) -> typing.Optional[typing.Mapping[builtins.str, builtins.str]]:
        result = self._values.get("parameters")
        return result

    @builtins.property
    def tags(self) -> typing.Optional[typing.Mapping[builtins.str, builtins.str]]:
        result = self._values.get("tags")
        return result

    @builtins.property
    def timeouts(self) -> typing.Optional["LogicAppWorkflowTimeouts"]:
        """timeouts block."""
        result = self._values.get("timeouts")
        return result

    @builtins.property
    def workflow_schema(self) -> typing.Optional[builtins.str]:
        result = self._values.get("workflow_schema")
        return result

    @builtins.property
    def workflow_version(self) -> typing.Optional[builtins.str]:
        result = self._values.get("workflow_version")
        return result

    def __eq__(self, rhs: typing.Any) -> builtins.bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs: typing.Any) -> builtins.bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return "LogicAppWorkflowConfig(%s)" % ", ".join(
            k + "=" + repr(v) for k, v in self._values.items()
        )


@jsii.data_type(
    jsii_type="@cdktf/provider-azurerm.LogicAppWorkflowTimeouts",
    jsii_struct_bases=[],
    name_mapping={
        "create": "create",
        "delete": "delete",
        "read": "read",
        "update": "update",
    },
)
class LogicAppWorkflowTimeouts:
    def __init__(
        self,
        *,
        create: typing.Optional[builtins.str] = None,
        delete: typing.Optional[builtins.str] = None,
        read: typing.Optional[builtins.str] = None,
        update: typing.Optional[builtins.str] = None,
    ) -> None:
        """
        :param create: 
        :param delete: 
        :param read: 
        :param update: 
        """
        self._values: typing.Dict[str, typing.Any] = {}
        if create is not None:
            self._values["create"] = create
        if delete is not None:
            self._values["delete"] = delete
        if read is not None:
            self._values["read"] = read
        if update is not None:
            self._values["update"] = update

    @builtins.property
    def create(self) -> typing.Optional[builtins.str]:
        result = self._values.get("create")
        return result

    @builtins.property
    def delete(self) -> typing.Optional[builtins.str]:
        result = self._values.get("delete")
        return result

    @builtins.property
    def read(self) -> typing.Optional[builtins.str]:
        result = self._values.get("read")
        return result

    @builtins.property
    def update(self) -> typing.Optional[builtins.str]:
        result = self._values.get("update")
        return result

    def __eq__(self, rhs: typing.Any) -> builtins.bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs: typing.Any) -> builtins.bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return "LogicAppWorkflowTimeouts(%s)" % ", ".join(
            k + "=" + repr(v) for k, v in self._values.items()
        )


class ManagedDisk(
    cdktf.TerraformResource,
    metaclass=jsii.JSIIMeta,
    jsii_type="@cdktf/provider-azurerm.ManagedDisk",
):
    def __init__(
        self,
        scope: constructs.Construct,
        id: builtins.str,
        *,
        create_option: builtins.str,
        location: builtins.str,
        name: builtins.str,
        resource_group_name: builtins.str,
        storage_account_type: builtins.str,
        disk_encryption_set_id: typing.Optional[builtins.str] = None,
        disk_iops_read_write: typing.Optional[jsii.Number] = None,
        disk_mbps_read_write: typing.Optional[jsii.Number] = None,
        disk_size_gb: typing.Optional[jsii.Number] = None,
        encryption_settings: typing.Optional[typing.List["ManagedDiskEncryptionSettings"]] = None,
        image_reference_id: typing.Optional[builtins.str] = None,
        os_type: typing.Optional[builtins.str] = None,
        source_resource_id: typing.Optional[builtins.str] = None,
        source_uri: typing.Optional[builtins.str] = None,
        storage_account_id: typing.Optional[builtins.str] = None,
        tags: typing.Optional[typing.Mapping[builtins.str, builtins.str]] = None,
        timeouts: typing.Optional["ManagedDiskTimeouts"] = None,
        zones: typing.Optional[typing.List[builtins.str]] = None,
        count: typing.Optional[jsii.Number] = None,
        depends_on: typing.Optional[typing.List[cdktf.TerraformResource]] = None,
        lifecycle: typing.Optional[cdktf.TerraformResourceLifecycle] = None,
        provider: typing.Optional[cdktf.TerraformProvider] = None,
    ) -> None:
        """
        :param scope: -
        :param id: -
        :param create_option: 
        :param location: 
        :param name: 
        :param resource_group_name: 
        :param storage_account_type: 
        :param disk_encryption_set_id: 
        :param disk_iops_read_write: 
        :param disk_mbps_read_write: 
        :param disk_size_gb: 
        :param encryption_settings: encryption_settings block.
        :param image_reference_id: 
        :param os_type: 
        :param source_resource_id: 
        :param source_uri: 
        :param storage_account_id: 
        :param tags: 
        :param timeouts: timeouts block.
        :param zones: 
        :param count: 
        :param depends_on: 
        :param lifecycle: 
        :param provider: 
        """
        config = ManagedDiskConfig(
            create_option=create_option,
            location=location,
            name=name,
            resource_group_name=resource_group_name,
            storage_account_type=storage_account_type,
            disk_encryption_set_id=disk_encryption_set_id,
            disk_iops_read_write=disk_iops_read_write,
            disk_mbps_read_write=disk_mbps_read_write,
            disk_size_gb=disk_size_gb,
            encryption_settings=encryption_settings,
            image_reference_id=image_reference_id,
            os_type=os_type,
            source_resource_id=source_resource_id,
            source_uri=source_uri,
            storage_account_id=storage_account_id,
            tags=tags,
            timeouts=timeouts,
            zones=zones,
            count=count,
            depends_on=depends_on,
            lifecycle=lifecycle,
            provider=provider,
        )

        jsii.create(ManagedDisk, self, [scope, id, config])

    @jsii.member(jsii_name="synthesizeAttributes")
    def _synthesize_attributes(self) -> typing.Mapping[builtins.str, typing.Any]:
        return jsii.invoke(self, "synthesizeAttributes", [])

    @builtins.property # type: ignore
    @jsii.member(jsii_name="createOption")
    def create_option(self) -> builtins.str:
        return jsii.get(self, "createOption")

    @create_option.setter # type: ignore
    def create_option(self, value: builtins.str) -> None:
        jsii.set(self, "createOption", value)

    @builtins.property # type: ignore
    @jsii.member(jsii_name="location")
    def location(self) -> builtins.str:
        return jsii.get(self, "location")

    @location.setter # type: ignore
    def location(self, value: builtins.str) -> None:
        jsii.set(self, "location", value)

    @builtins.property # type: ignore
    @jsii.member(jsii_name="name")
    def name(self) -> builtins.str:
        return jsii.get(self, "name")

    @name.setter # type: ignore
    def name(self, value: builtins.str) -> None:
        jsii.set(self, "name", value)

    @builtins.property # type: ignore
    @jsii.member(jsii_name="resourceGroupName")
    def resource_group_name(self) -> builtins.str:
        return jsii.get(self, "resourceGroupName")

    @resource_group_name.setter # type: ignore
    def resource_group_name(self, value: builtins.str) -> None:
        jsii.set(self, "resourceGroupName", value)

    @builtins.property # type: ignore
    @jsii.member(jsii_name="storageAccountType")
    def storage_account_type(self) -> builtins.str:
        return jsii.get(self, "storageAccountType")

    @storage_account_type.setter # type: ignore
    def storage_account_type(self, value: builtins.str) -> None:
        jsii.set(self, "storageAccountType", value)

    @builtins.property # type: ignore
    @jsii.member(jsii_name="diskEncryptionSetId")
    def disk_encryption_set_id(self) -> typing.Optional[builtins.str]:
        return jsii.get(self, "diskEncryptionSetId")

    @disk_encryption_set_id.setter # type: ignore
    def disk_encryption_set_id(self, value: typing.Optional[builtins.str]) -> None:
        jsii.set(self, "diskEncryptionSetId", value)

    @builtins.property # type: ignore
    @jsii.member(jsii_name="diskIopsReadWrite")
    def disk_iops_read_write(self) -> typing.Optional[jsii.Number]:
        return jsii.get(self, "diskIopsReadWrite")

    @disk_iops_read_write.setter # type: ignore
    def disk_iops_read_write(self, value: typing.Optional[jsii.Number]) -> None:
        jsii.set(self, "diskIopsReadWrite", value)

    @builtins.property # type: ignore
    @jsii.member(jsii_name="diskMbpsReadWrite")
    def disk_mbps_read_write(self) -> typing.Optional[jsii.Number]:
        return jsii.get(self, "diskMbpsReadWrite")

    @disk_mbps_read_write.setter # type: ignore
    def disk_mbps_read_write(self, value: typing.Optional[jsii.Number]) -> None:
        jsii.set(self, "diskMbpsReadWrite", value)

    @builtins.property # type: ignore
    @jsii.member(jsii_name="diskSizeGb")
    def disk_size_gb(self) -> typing.Optional[jsii.Number]:
        return jsii.get(self, "diskSizeGb")

    @disk_size_gb.setter # type: ignore
    def disk_size_gb(self, value: typing.Optional[jsii.Number]) -> None:
        jsii.set(self, "diskSizeGb", value)

    @builtins.property # type: ignore
    @jsii.member(jsii_name="encryptionSettings")
    def encryption_settings(
        self,
    ) -> typing.Optional[typing.List["ManagedDiskEncryptionSettings"]]:
        return jsii.get(self, "encryptionSettings")

    @encryption_settings.setter # type: ignore
    def encryption_settings(
        self,
        value: typing.Optional[typing.List["ManagedDiskEncryptionSettings"]],
    ) -> None:
        jsii.set(self, "encryptionSettings", value)

    @builtins.property # type: ignore
    @jsii.member(jsii_name="id")
    def id(self) -> typing.Optional[builtins.str]:
        return jsii.get(self, "id")

    @id.setter # type: ignore
    def id(self, value: typing.Optional[builtins.str]) -> None:
        jsii.set(self, "id", value)

    @builtins.property # type: ignore
    @jsii.member(jsii_name="imageReferenceId")
    def image_reference_id(self) -> typing.Optional[builtins.str]:
        return jsii.get(self, "imageReferenceId")

    @image_reference_id.setter # type: ignore
    def image_reference_id(self, value: typing.Optional[builtins.str]) -> None:
        jsii.set(self, "imageReferenceId", value)

    @builtins.property # type: ignore
    @jsii.member(jsii_name="osType")
    def os_type(self) -> typing.Optional[builtins.str]:
        return jsii.get(self, "osType")

    @os_type.setter # type: ignore
    def os_type(self, value: typing.Optional[builtins.str]) -> None:
        jsii.set(self, "osType", value)

    @builtins.property # type: ignore
    @jsii.member(jsii_name="sourceResourceId")
    def source_resource_id(self) -> typing.Optional[builtins.str]:
        return jsii.get(self, "sourceResourceId")

    @source_resource_id.setter # type: ignore
    def source_resource_id(self, value: typing.Optional[builtins.str]) -> None:
        jsii.set(self, "sourceResourceId", value)

    @builtins.property # type: ignore
    @jsii.member(jsii_name="sourceUri")
    def source_uri(self) -> typing.Optional[builtins.str]:
        return jsii.get(self, "sourceUri")

    @source_uri.setter # type: ignore
    def source_uri(self, value: typing.Optional[builtins.str]) -> None:
        jsii.set(self, "sourceUri", value)

    @builtins.property # type: ignore
    @jsii.member(jsii_name="storageAccountId")
    def storage_account_id(self) -> typing.Optional[builtins.str]:
        return jsii.get(self, "storageAccountId")

    @storage_account_id.setter # type: ignore
    def storage_account_id(self, value: typing.Optional[builtins.str]) -> None:
        jsii.set(self, "storageAccountId", value)

    @builtins.property # type: ignore
    @jsii.member(jsii_name="tags")
    def tags(self) -> typing.Optional[typing.Mapping[builtins.str, builtins.str]]:
        return jsii.get(self, "tags")

    @tags.setter # type: ignore
    def tags(
        self,
        value: typing.Optional[typing.Mapping[builtins.str, builtins.str]],
    ) -> None:
        jsii.set(self, "tags", value)

    @builtins.property # type: ignore
    @jsii.member(jsii_name="timeouts")
    def timeouts(self) -> typing.Optional["ManagedDiskTimeouts"]:
        return jsii.get(self, "timeouts")

    @timeouts.setter # type: ignore
    def timeouts(self, value: typing.Optional["ManagedDiskTimeouts"]) -> None:
        jsii.set(self, "timeouts", value)

    @builtins.property # type: ignore
    @jsii.member(jsii_name="zones")
    def zones(self) -> typing.Optional[typing.List[builtins.str]]:
        return jsii.get(self, "zones")

    @zones.setter # type: ignore
    def zones(self, value: typing.Optional[typing.List[builtins.str]]) -> None:
        jsii.set(self, "zones", value)


@jsii.data_type(
    jsii_type="@cdktf/provider-azurerm.ManagedDiskConfig",
    jsii_struct_bases=[cdktf.TerraformMetaArguments],
    name_mapping={
        "count": "count",
        "depends_on": "dependsOn",
        "lifecycle": "lifecycle",
        "provider": "provider",
        "create_option": "createOption",
        "location": "location",
        "name": "name",
        "resource_group_name": "resourceGroupName",
        "storage_account_type": "storageAccountType",
        "disk_encryption_set_id": "diskEncryptionSetId",
        "disk_iops_read_write": "diskIopsReadWrite",
        "disk_mbps_read_write": "diskMbpsReadWrite",
        "disk_size_gb": "diskSizeGb",
        "encryption_settings": "encryptionSettings",
        "image_reference_id": "imageReferenceId",
        "os_type": "osType",
        "source_resource_id": "sourceResourceId",
        "source_uri": "sourceUri",
        "storage_account_id": "storageAccountId",
        "tags": "tags",
        "timeouts": "timeouts",
        "zones": "zones",
    },
)
class ManagedDiskConfig(cdktf.TerraformMetaArguments):
    def __init__(
        self,
        *,
        count: typing.Optional[jsii.Number] = None,
        depends_on: typing.Optional[typing.List[cdktf.TerraformResource]] = None,
        lifecycle: typing.Optional[cdktf.TerraformResourceLifecycle] = None,
        provider: typing.Optional[cdktf.TerraformProvider] = None,
        create_option: builtins.str,
        location: builtins.str,
        name: builtins.str,
        resource_group_name: builtins.str,
        storage_account_type: builtins.str,
        disk_encryption_set_id: typing.Optional[builtins.str] = None,
        disk_iops_read_write: typing.Optional[jsii.Number] = None,
        disk_mbps_read_write: typing.Optional[jsii.Number] = None,
        disk_size_gb: typing.Optional[jsii.Number] = None,
        encryption_settings: typing.Optional[typing.List["ManagedDiskEncryptionSettings"]] = None,
        image_reference_id: typing.Optional[builtins.str] = None,
        os_type: typing.Optional[builtins.str] = None,
        source_resource_id: typing.Optional[builtins.str] = None,
        source_uri: typing.Optional[builtins.str] = None,
        storage_account_id: typing.Optional[builtins.str] = None,
        tags: typing.Optional[typing.Mapping[builtins.str, builtins.str]] = None,
        timeouts: typing.Optional["ManagedDiskTimeouts"] = None,
        zones: typing.Optional[typing.List[builtins.str]] = None,
    ) -> None:
        """
        :param count: 
        :param depends_on: 
        :param lifecycle: 
        :param provider: 
        :param create_option: 
        :param location: 
        :param name: 
        :param resource_group_name: 
        :param storage_account_type: 
        :param disk_encryption_set_id: 
        :param disk_iops_read_write: 
        :param disk_mbps_read_write: 
        :param disk_size_gb: 
        :param encryption_settings: encryption_settings block.
        :param image_reference_id: 
        :param os_type: 
        :param source_resource_id: 
        :param source_uri: 
        :param storage_account_id: 
        :param tags: 
        :param timeouts: timeouts block.
        :param zones: 
        """
        if isinstance(lifecycle, dict):
            lifecycle = cdktf.TerraformResourceLifecycle(**lifecycle)
        if isinstance(timeouts, dict):
            timeouts = ManagedDiskTimeouts(**timeouts)
        self._values: typing.Dict[str, typing.Any] = {
            "create_option": create_option,
            "location": location,
            "name": name,
            "resource_group_name": resource_group_name,
            "storage_account_type": storage_account_type,
        }
        if count is not None:
            self._values["count"] = count
        if depends_on is not None:
            self._values["depends_on"] = depends_on
        if lifecycle is not None:
            self._values["lifecycle"] = lifecycle
        if provider is not None:
            self._values["provider"] = provider
        if disk_encryption_set_id is not None:
            self._values["disk_encryption_set_id"] = disk_encryption_set_id
        if disk_iops_read_write is not None:
            self._values["disk_iops_read_write"] = disk_iops_read_write
        if disk_mbps_read_write is not None:
            self._values["disk_mbps_read_write"] = disk_mbps_read_write
        if disk_size_gb is not None:
            self._values["disk_size_gb"] = disk_size_gb
        if encryption_settings is not None:
            self._values["encryption_settings"] = encryption_settings
        if image_reference_id is not None:
            self._values["image_reference_id"] = image_reference_id
        if os_type is not None:
            self._values["os_type"] = os_type
        if source_resource_id is not None:
            self._values["source_resource_id"] = source_resource_id
        if source_uri is not None:
            self._values["source_uri"] = source_uri
        if storage_account_id is not None:
            self._values["storage_account_id"] = storage_account_id
        if tags is not None:
            self._values["tags"] = tags
        if timeouts is not None:
            self._values["timeouts"] = timeouts
        if zones is not None:
            self._values["zones"] = zones

    @builtins.property
    def count(self) -> typing.Optional[jsii.Number]:
        """
        :stability: experimental
        """
        result = self._values.get("count")
        return result

    @builtins.property
    def depends_on(self) -> typing.Optional[typing.List[cdktf.TerraformResource]]:
        """
        :stability: experimental
        """
        result = self._values.get("depends_on")
        return result

    @builtins.property
    def lifecycle(self) -> typing.Optional[cdktf.TerraformResourceLifecycle]:
        """
        :stability: experimental
        """
        result = self._values.get("lifecycle")
        return result

    @builtins.property
    def provider(self) -> typing.Optional[cdktf.TerraformProvider]:
        """
        :stability: experimental
        """
        result = self._values.get("provider")
        return result

    @builtins.property
    def create_option(self) -> builtins.str:
        result = self._values.get("create_option")
        assert result is not None, "Required property 'create_option' is missing"
        return result

    @builtins.property
    def location(self) -> builtins.str:
        result = self._values.get("location")
        assert result is not None, "Required property 'location' is missing"
        return result

    @builtins.property
    def name(self) -> builtins.str:
        result = self._values.get("name")
        assert result is not None, "Required property 'name' is missing"
        return result

    @builtins.property
    def resource_group_name(self) -> builtins.str:
        result = self._values.get("resource_group_name")
        assert result is not None, "Required property 'resource_group_name' is missing"
        return result

    @builtins.property
    def storage_account_type(self) -> builtins.str:
        result = self._values.get("storage_account_type")
        assert result is not None, "Required property 'storage_account_type' is missing"
        return result

    @builtins.property
    def disk_encryption_set_id(self) -> typing.Optional[builtins.str]:
        result = self._values.get("disk_encryption_set_id")
        return result

    @builtins.property
    def disk_iops_read_write(self) -> typing.Optional[jsii.Number]:
        result = self._values.get("disk_iops_read_write")
        return result

    @builtins.property
    def disk_mbps_read_write(self) -> typing.Optional[jsii.Number]:
        result = self._values.get("disk_mbps_read_write")
        return result

    @builtins.property
    def disk_size_gb(self) -> typing.Optional[jsii.Number]:
        result = self._values.get("disk_size_gb")
        return result

    @builtins.property
    def encryption_settings(
        self,
    ) -> typing.Optional[typing.List["ManagedDiskEncryptionSettings"]]:
        """encryption_settings block."""
        result = self._values.get("encryption_settings")
        return result

    @builtins.property
    def image_reference_id(self) -> typing.Optional[builtins.str]:
        result = self._values.get("image_reference_id")
        return result

    @builtins.property
    def os_type(self) -> typing.Optional[builtins.str]:
        result = self._values.get("os_type")
        return result

    @builtins.property
    def source_resource_id(self) -> typing.Optional[builtins.str]:
        result = self._values.get("source_resource_id")
        return result

    @builtins.property
    def source_uri(self) -> typing.Optional[builtins.str]:
        result = self._values.get("source_uri")
        return result

    @builtins.property
    def storage_account_id(self) -> typing.Optional[builtins.str]:
        result = self._values.get("storage_account_id")
        return result

    @builtins.property
    def tags(self) -> typing.Optional[typing.Mapping[builtins.str, builtins.str]]:
        result = self._values.get("tags")
        return result

    @builtins.property
    def timeouts(self) -> typing.Optional["ManagedDiskTimeouts"]:
        """timeouts block."""
        result = self._values.get("timeouts")
        return result

    @builtins.property
    def zones(self) -> typing.Optional[typing.List[builtins.str]]:
        result = self._values.get("zones")
        return result

    def __eq__(self, rhs: typing.Any) -> builtins.bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs: typing.Any) -> builtins.bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return "ManagedDiskConfig(%s)" % ", ".join(
            k + "=" + repr(v) for k, v in self._values.items()
        )


@jsii.data_type(
    jsii_type="@cdktf/provider-azurerm.ManagedDiskEncryptionSettings",
    jsii_struct_bases=[],
    name_mapping={
        "enabled": "enabled",
        "disk_encryption_key": "diskEncryptionKey",
        "key_encryption_key": "keyEncryptionKey",
    },
)
class ManagedDiskEncryptionSettings:
    def __init__(
        self,
        *,
        enabled: builtins.bool,
        disk_encryption_key: typing.Optional[typing.List["ManagedDiskEncryptionSettingsDiskEncryptionKey"]] = None,
        key_encryption_key: typing.Optional[typing.List["ManagedDiskEncryptionSettingsKeyEncryptionKey"]] = None,
    ) -> None:
        """
        :param enabled: 
        :param disk_encryption_key: disk_encryption_key block.
        :param key_encryption_key: key_encryption_key block.
        """
        self._values: typing.Dict[str, typing.Any] = {
            "enabled": enabled,
        }
        if disk_encryption_key is not None:
            self._values["disk_encryption_key"] = disk_encryption_key
        if key_encryption_key is not None:
            self._values["key_encryption_key"] = key_encryption_key

    @builtins.property
    def enabled(self) -> builtins.bool:
        result = self._values.get("enabled")
        assert result is not None, "Required property 'enabled' is missing"
        return result

    @builtins.property
    def disk_encryption_key(
        self,
    ) -> typing.Optional[typing.List["ManagedDiskEncryptionSettingsDiskEncryptionKey"]]:
        """disk_encryption_key block."""
        result = self._values.get("disk_encryption_key")
        return result

    @builtins.property
    def key_encryption_key(
        self,
    ) -> typing.Optional[typing.List["ManagedDiskEncryptionSettingsKeyEncryptionKey"]]:
        """key_encryption_key block."""
        result = self._values.get("key_encryption_key")
        return result

    def __eq__(self, rhs: typing.Any) -> builtins.bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs: typing.Any) -> builtins.bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return "ManagedDiskEncryptionSettings(%s)" % ", ".join(
            k + "=" + repr(v) for k, v in self._values.items()
        )


@jsii.data_type(
    jsii_type="@cdktf/provider-azurerm.ManagedDiskEncryptionSettingsDiskEncryptionKey",
    jsii_struct_bases=[],
    name_mapping={"secret_url": "secretUrl", "source_vault_id": "sourceVaultId"},
)
class ManagedDiskEncryptionSettingsDiskEncryptionKey:
    def __init__(
        self,
        *,
        secret_url: builtins.str,
        source_vault_id: builtins.str,
    ) -> None:
        """
        :param secret_url: 
        :param source_vault_id: 
        """
        self._values: typing.Dict[str, typing.Any] = {
            "secret_url": secret_url,
            "source_vault_id": source_vault_id,
        }

    @builtins.property
    def secret_url(self) -> builtins.str:
        result = self._values.get("secret_url")
        assert result is not None, "Required property 'secret_url' is missing"
        return result

    @builtins.property
    def source_vault_id(self) -> builtins.str:
        result = self._values.get("source_vault_id")
        assert result is not None, "Required property 'source_vault_id' is missing"
        return result

    def __eq__(self, rhs: typing.Any) -> builtins.bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs: typing.Any) -> builtins.bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return "ManagedDiskEncryptionSettingsDiskEncryptionKey(%s)" % ", ".join(
            k + "=" + repr(v) for k, v in self._values.items()
        )


@jsii.data_type(
    jsii_type="@cdktf/provider-azurerm.ManagedDiskEncryptionSettingsKeyEncryptionKey",
    jsii_struct_bases=[],
    name_mapping={"key_url": "keyUrl", "source_vault_id": "sourceVaultId"},
)
class ManagedDiskEncryptionSettingsKeyEncryptionKey:
    def __init__(self, *, key_url: builtins.str, source_vault_id: builtins.str) -> None:
        """
        :param key_url: 
        :param source_vault_id: 
        """
        self._values: typing.Dict[str, typing.Any] = {
            "key_url": key_url,
            "source_vault_id": source_vault_id,
        }

    @builtins.property
    def key_url(self) -> builtins.str:
        result = self._values.get("key_url")
        assert result is not None, "Required property 'key_url' is missing"
        return result

    @builtins.property
    def source_vault_id(self) -> builtins.str:
        result = self._values.get("source_vault_id")
        assert result is not None, "Required property 'source_vault_id' is missing"
        return result

    def __eq__(self, rhs: typing.Any) -> builtins.bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs: typing.Any) -> builtins.bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return "ManagedDiskEncryptionSettingsKeyEncryptionKey(%s)" % ", ".join(
            k + "=" + repr(v) for k, v in self._values.items()
        )


@jsii.data_type(
    jsii_type="@cdktf/provider-azurerm.ManagedDiskTimeouts",
    jsii_struct_bases=[],
    name_mapping={
        "create": "create",
        "delete": "delete",
        "read": "read",
        "update": "update",
    },
)
class ManagedDiskTimeouts:
    def __init__(
        self,
        *,
        create: typing.Optional[builtins.str] = None,
        delete: typing.Optional[builtins.str] = None,
        read: typing.Optional[builtins.str] = None,
        update: typing.Optional[builtins.str] = None,
    ) -> None:
        """
        :param create: 
        :param delete: 
        :param read: 
        :param update: 
        """
        self._values: typing.Dict[str, typing.Any] = {}
        if create is not None:
            self._values["create"] = create
        if delete is not None:
            self._values["delete"] = delete
        if read is not None:
            self._values["read"] = read
        if update is not None:
            self._values["update"] = update

    @builtins.property
    def create(self) -> typing.Optional[builtins.str]:
        result = self._values.get("create")
        return result

    @builtins.property
    def delete(self) -> typing.Optional[builtins.str]:
        result = self._values.get("delete")
        return result

    @builtins.property
    def read(self) -> typing.Optional[builtins.str]:
        result = self._values.get("read")
        return result

    @builtins.property
    def update(self) -> typing.Optional[builtins.str]:
        result = self._values.get("update")
        return result

    def __eq__(self, rhs: typing.Any) -> builtins.bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs: typing.Any) -> builtins.bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return "ManagedDiskTimeouts(%s)" % ", ".join(
            k + "=" + repr(v) for k, v in self._values.items()
        )


class ManagementGroup(
    cdktf.TerraformResource,
    metaclass=jsii.JSIIMeta,
    jsii_type="@cdktf/provider-azurerm.ManagementGroup",
):
    def __init__(
        self,
        scope: constructs.Construct,
        id: builtins.str,
        *,
        display_name: typing.Optional[builtins.str] = None,
        group_id: typing.Optional[builtins.str] = None,
        parent_management_group_id: typing.Optional[builtins.str] = None,
        subscription_ids: typing.Optional[typing.List[builtins.str]] = None,
        timeouts: typing.Optional["ManagementGroupTimeouts"] = None,
        count: typing.Optional[jsii.Number] = None,
        depends_on: typing.Optional[typing.List[cdktf.TerraformResource]] = None,
        lifecycle: typing.Optional[cdktf.TerraformResourceLifecycle] = None,
        provider: typing.Optional[cdktf.TerraformProvider] = None,
    ) -> None:
        """
        :param scope: -
        :param id: -
        :param display_name: 
        :param group_id: 
        :param parent_management_group_id: 
        :param subscription_ids: 
        :param timeouts: timeouts block.
        :param count: 
        :param depends_on: 
        :param lifecycle: 
        :param provider: 
        """
        config = ManagementGroupConfig(
            display_name=display_name,
            group_id=group_id,
            parent_management_group_id=parent_management_group_id,
            subscription_ids=subscription_ids,
            timeouts=timeouts,
            count=count,
            depends_on=depends_on,
            lifecycle=lifecycle,
            provider=provider,
        )

        jsii.create(ManagementGroup, self, [scope, id, config])

    @jsii.member(jsii_name="synthesizeAttributes")
    def _synthesize_attributes(self) -> typing.Mapping[builtins.str, typing.Any]:
        return jsii.invoke(self, "synthesizeAttributes", [])

    @builtins.property # type: ignore
    @jsii.member(jsii_name="displayName")
    def display_name(self) -> typing.Optional[builtins.str]:
        return jsii.get(self, "displayName")

    @display_name.setter # type: ignore
    def display_name(self, value: typing.Optional[builtins.str]) -> None:
        jsii.set(self, "displayName", value)

    @builtins.property # type: ignore
    @jsii.member(jsii_name="groupId")
    def group_id(self) -> typing.Optional[builtins.str]:
        return jsii.get(self, "groupId")

    @group_id.setter # type: ignore
    def group_id(self, value: typing.Optional[builtins.str]) -> None:
        jsii.set(self, "groupId", value)

    @builtins.property # type: ignore
    @jsii.member(jsii_name="id")
    def id(self) -> typing.Optional[builtins.str]:
        return jsii.get(self, "id")

    @id.setter # type: ignore
    def id(self, value: typing.Optional[builtins.str]) -> None:
        jsii.set(self, "id", value)

    @builtins.property # type: ignore
    @jsii.member(jsii_name="parentManagementGroupId")
    def parent_management_group_id(self) -> typing.Optional[builtins.str]:
        return jsii.get(self, "parentManagementGroupId")

    @parent_management_group_id.setter # type: ignore
    def parent_management_group_id(self, value: typing.Optional[builtins.str]) -> None:
        jsii.set(self, "parentManagementGroupId", value)

    @builtins.property # type: ignore
    @jsii.member(jsii_name="subscriptionIds")
    def subscription_ids(self) -> typing.Optional[typing.List[builtins.str]]:
        return jsii.get(self, "subscriptionIds")

    @subscription_ids.setter # type: ignore
    def subscription_ids(
        self,
        value: typing.Optional[typing.List[builtins.str]],
    ) -> None:
        jsii.set(self, "subscriptionIds", value)

    @builtins.property # type: ignore
    @jsii.member(jsii_name="timeouts")
    def timeouts(self) -> typing.Optional["ManagementGroupTimeouts"]:
        return jsii.get(self, "timeouts")

    @timeouts.setter # type: ignore
    def timeouts(self, value: typing.Optional["ManagementGroupTimeouts"]) -> None:
        jsii.set(self, "timeouts", value)


@jsii.data_type(
    jsii_type="@cdktf/provider-azurerm.ManagementGroupConfig",
    jsii_struct_bases=[cdktf.TerraformMetaArguments],
    name_mapping={
        "count": "count",
        "depends_on": "dependsOn",
        "lifecycle": "lifecycle",
        "provider": "provider",
        "display_name": "displayName",
        "group_id": "groupId",
        "parent_management_group_id": "parentManagementGroupId",
        "subscription_ids": "subscriptionIds",
        "timeouts": "timeouts",
    },
)
class ManagementGroupConfig(cdktf.TerraformMetaArguments):
    def __init__(
        self,
        *,
        count: typing.Optional[jsii.Number] = None,
        depends_on: typing.Optional[typing.List[cdktf.TerraformResource]] = None,
        lifecycle: typing.Optional[cdktf.TerraformResourceLifecycle] = None,
        provider: typing.Optional[cdktf.TerraformProvider] = None,
        display_name: typing.Optional[builtins.str] = None,
        group_id: typing.Optional[builtins.str] = None,
        parent_management_group_id: typing.Optional[builtins.str] = None,
        subscription_ids: typing.Optional[typing.List[builtins.str]] = None,
        timeouts: typing.Optional["ManagementGroupTimeouts"] = None,
    ) -> None:
        """
        :param count: 
        :param depends_on: 
        :param lifecycle: 
        :param provider: 
        :param display_name: 
        :param group_id: 
        :param parent_management_group_id: 
        :param subscription_ids: 
        :param timeouts: timeouts block.
        """
        if isinstance(lifecycle, dict):
            lifecycle = cdktf.TerraformResourceLifecycle(**lifecycle)
        if isinstance(timeouts, dict):
            timeouts = ManagementGroupTimeouts(**timeouts)
        self._values: typing.Dict[str, typing.Any] = {}
        if count is not None:
            self._values["count"] = count
        if depends_on is not None:
            self._values["depends_on"] = depends_on
        if lifecycle is not None:
            self._values["lifecycle"] = lifecycle
        if provider is not None:
            self._values["provider"] = provider
        if display_name is not None:
            self._values["display_name"] = display_name
        if group_id is not None:
            self._values["group_id"] = group_id
        if parent_management_group_id is not None:
            self._values["parent_management_group_id"] = parent_management_group_id
        if subscription_ids is not None:
            self._values["subscription_ids"] = subscription_ids
        if timeouts is not None:
            self._values["timeouts"] = timeouts

    @builtins.property
    def count(self) -> typing.Optional[jsii.Number]:
        """
        :stability: experimental
        """
        result = self._values.get("count")
        return result

    @builtins.property
    def depends_on(self) -> typing.Optional[typing.List[cdktf.TerraformResource]]:
        """
        :stability: experimental
        """
        result = self._values.get("depends_on")
        return result

    @builtins.property
    def lifecycle(self) -> typing.Optional[cdktf.TerraformResourceLifecycle]:
        """
        :stability: experimental
        """
        result = self._values.get("lifecycle")
        return result

    @builtins.property
    def provider(self) -> typing.Optional[cdktf.TerraformProvider]:
        """
        :stability: experimental
        """
        result = self._values.get("provider")
        return result

    @builtins.property
    def display_name(self) -> typing.Optional[builtins.str]:
        result = self._values.get("display_name")
        return result

    @builtins.property
    def group_id(self) -> typing.Optional[builtins.str]:
        result = self._values.get("group_id")
        return result

    @builtins.property
    def parent_management_group_id(self) -> typing.Optional[builtins.str]:
        result = self._values.get("parent_management_group_id")
        return result

    @builtins.property
    def subscription_ids(self) -> typing.Optional[typing.List[builtins.str]]:
        result = self._values.get("subscription_ids")
        return result

    @builtins.property
    def timeouts(self) -> typing.Optional["ManagementGroupTimeouts"]:
        """timeouts block."""
        result = self._values.get("timeouts")
        return result

    def __eq__(self, rhs: typing.Any) -> builtins.bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs: typing.Any) -> builtins.bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return "ManagementGroupConfig(%s)" % ", ".join(
            k + "=" + repr(v) for k, v in self._values.items()
        )


@jsii.data_type(
    jsii_type="@cdktf/provider-azurerm.ManagementGroupTimeouts",
    jsii_struct_bases=[],
    name_mapping={
        "create": "create",
        "delete": "delete",
        "read": "read",
        "update": "update",
    },
)
class ManagementGroupTimeouts:
    def __init__(
        self,
        *,
        create: typing.Optional[builtins.str] = None,
        delete: typing.Optional[builtins.str] = None,
        read: typing.Optional[builtins.str] = None,
        update: typing.Optional[builtins.str] = None,
    ) -> None:
        """
        :param create: 
        :param delete: 
        :param read: 
        :param update: 
        """
        self._values: typing.Dict[str, typing.Any] = {}
        if create is not None:
            self._values["create"] = create
        if delete is not None:
            self._values["delete"] = delete
        if read is not None:
            self._values["read"] = read
        if update is not None:
            self._values["update"] = update

    @builtins.property
    def create(self) -> typing.Optional[builtins.str]:
        result = self._values.get("create")
        return result

    @builtins.property
    def delete(self) -> typing.Optional[builtins.str]:
        result = self._values.get("delete")
        return result

    @builtins.property
    def read(self) -> typing.Optional[builtins.str]:
        result = self._values.get("read")
        return result

    @builtins.property
    def update(self) -> typing.Optional[builtins.str]:
        result = self._values.get("update")
        return result

    def __eq__(self, rhs: typing.Any) -> builtins.bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs: typing.Any) -> builtins.bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return "ManagementGroupTimeouts(%s)" % ", ".join(
            k + "=" + repr(v) for k, v in self._values.items()
        )


class ManagementLock(
    cdktf.TerraformResource,
    metaclass=jsii.JSIIMeta,
    jsii_type="@cdktf/provider-azurerm.ManagementLock",
):
    def __init__(
        self,
        scope_: constructs.Construct,
        id: builtins.str,
        *,
        lock_level: builtins.str,
        name: builtins.str,
        scope: builtins.str,
        notes: typing.Optional[builtins.str] = None,
        timeouts: typing.Optional["ManagementLockTimeouts"] = None,
        count: typing.Optional[jsii.Number] = None,
        depends_on: typing.Optional[typing.List[cdktf.TerraformResource]] = None,
        lifecycle: typing.Optional[cdktf.TerraformResourceLifecycle] = None,
        provider: typing.Optional[cdktf.TerraformProvider] = None,
    ) -> None:
        """
        :param scope_: -
        :param id: -
        :param lock_level: 
        :param name: 
        :param scope: 
        :param notes: 
        :param timeouts: timeouts block.
        :param count: 
        :param depends_on: 
        :param lifecycle: 
        :param provider: 
        """
        config = ManagementLockConfig(
            lock_level=lock_level,
            name=name,
            scope=scope,
            notes=notes,
            timeouts=timeouts,
            count=count,
            depends_on=depends_on,
            lifecycle=lifecycle,
            provider=provider,
        )

        jsii.create(ManagementLock, self, [scope_, id, config])

    @jsii.member(jsii_name="synthesizeAttributes")
    def _synthesize_attributes(self) -> typing.Mapping[builtins.str, typing.Any]:
        return jsii.invoke(self, "synthesizeAttributes", [])

    @builtins.property # type: ignore
    @jsii.member(jsii_name="lockLevel")
    def lock_level(self) -> builtins.str:
        return jsii.get(self, "lockLevel")

    @lock_level.setter # type: ignore
    def lock_level(self, value: builtins.str) -> None:
        jsii.set(self, "lockLevel", value)

    @builtins.property # type: ignore
    @jsii.member(jsii_name="name")
    def name(self) -> builtins.str:
        return jsii.get(self, "name")

    @name.setter # type: ignore
    def name(self, value: builtins.str) -> None:
        jsii.set(self, "name", value)

    @builtins.property # type: ignore
    @jsii.member(jsii_name="scope")
    def scope(self) -> builtins.str:
        return jsii.get(self, "scope")

    @scope.setter # type: ignore
    def scope(self, value: builtins.str) -> None:
        jsii.set(self, "scope", value)

    @builtins.property # type: ignore
    @jsii.member(jsii_name="id")
    def id(self) -> typing.Optional[builtins.str]:
        return jsii.get(self, "id")

    @id.setter # type: ignore
    def id(self, value: typing.Optional[builtins.str]) -> None:
        jsii.set(self, "id", value)

    @builtins.property # type: ignore
    @jsii.member(jsii_name="notes")
    def notes(self) -> typing.Optional[builtins.str]:
        return jsii.get(self, "notes")

    @notes.setter # type: ignore
    def notes(self, value: typing.Optional[builtins.str]) -> None:
        jsii.set(self, "notes", value)

    @builtins.property # type: ignore
    @jsii.member(jsii_name="timeouts")
    def timeouts(self) -> typing.Optional["ManagementLockTimeouts"]:
        return jsii.get(self, "timeouts")

    @timeouts.setter # type: ignore
    def timeouts(self, value: typing.Optional["ManagementLockTimeouts"]) -> None:
        jsii.set(self, "timeouts", value)


@jsii.data_type(
    jsii_type="@cdktf/provider-azurerm.ManagementLockConfig",
    jsii_struct_bases=[cdktf.TerraformMetaArguments],
    name_mapping={
        "count": "count",
        "depends_on": "dependsOn",
        "lifecycle": "lifecycle",
        "provider": "provider",
        "lock_level": "lockLevel",
        "name": "name",
        "scope": "scope",
        "notes": "notes",
        "timeouts": "timeouts",
    },
)
class ManagementLockConfig(cdktf.TerraformMetaArguments):
    def __init__(
        self,
        *,
        count: typing.Optional[jsii.Number] = None,
        depends_on: typing.Optional[typing.List[cdktf.TerraformResource]] = None,
        lifecycle: typing.Optional[cdktf.TerraformResourceLifecycle] = None,
        provider: typing.Optional[cdktf.TerraformProvider] = None,
        lock_level: builtins.str,
        name: builtins.str,
        scope: builtins.str,
        notes: typing.Optional[builtins.str] = None,
        timeouts: typing.Optional["ManagementLockTimeouts"] = None,
    ) -> None:
        """
        :param count: 
        :param depends_on: 
        :param lifecycle: 
        :param provider: 
        :param lock_level: 
        :param name: 
        :param scope: 
        :param notes: 
        :param timeouts: timeouts block.
        """
        if isinstance(lifecycle, dict):
            lifecycle = cdktf.TerraformResourceLifecycle(**lifecycle)
        if isinstance(timeouts, dict):
            timeouts = ManagementLockTimeouts(**timeouts)
        self._values: typing.Dict[str, typing.Any] = {
            "lock_level": lock_level,
            "name": name,
            "scope": scope,
        }
        if count is not None:
            self._values["count"] = count
        if depends_on is not None:
            self._values["depends_on"] = depends_on
        if lifecycle is not None:
            self._values["lifecycle"] = lifecycle
        if provider is not None:
            self._values["provider"] = provider
        if notes is not None:
            self._values["notes"] = notes
        if timeouts is not None:
            self._values["timeouts"] = timeouts

    @builtins.property
    def count(self) -> typing.Optional[jsii.Number]:
        """
        :stability: experimental
        """
        result = self._values.get("count")
        return result

    @builtins.property
    def depends_on(self) -> typing.Optional[typing.List[cdktf.TerraformResource]]:
        """
        :stability: experimental
        """
        result = self._values.get("depends_on")
        return result

    @builtins.property
    def lifecycle(self) -> typing.Optional[cdktf.TerraformResourceLifecycle]:
        """
        :stability: experimental
        """
        result = self._values.get("lifecycle")
        return result

    @builtins.property
    def provider(self) -> typing.Optional[cdktf.TerraformProvider]:
        """
        :stability: experimental
        """
        result = self._values.get("provider")
        return result

    @builtins.property
    def lock_level(self) -> builtins.str:
        result = self._values.get("lock_level")
        assert result is not None, "Required property 'lock_level' is missing"
        return result

    @builtins.property
    def name(self) -> builtins.str:
        result = self._values.get("name")
        assert result is not None, "Required property 'name' is missing"
        return result

    @builtins.property
    def scope(self) -> builtins.str:
        result = self._values.get("scope")
        assert result is not None, "Required property 'scope' is missing"
        return result

    @builtins.property
    def notes(self) -> typing.Optional[builtins.str]:
        result = self._values.get("notes")
        return result

    @builtins.property
    def timeouts(self) -> typing.Optional["ManagementLockTimeouts"]:
        """timeouts block."""
        result = self._values.get("timeouts")
        return result

    def __eq__(self, rhs: typing.Any) -> builtins.bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs: typing.Any) -> builtins.bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return "ManagementLockConfig(%s)" % ", ".join(
            k + "=" + repr(v) for k, v in self._values.items()
        )


@jsii.data_type(
    jsii_type="@cdktf/provider-azurerm.ManagementLockTimeouts",
    jsii_struct_bases=[],
    name_mapping={
        "create": "create",
        "delete": "delete",
        "read": "read",
        "update": "update",
    },
)
class ManagementLockTimeouts:
    def __init__(
        self,
        *,
        create: typing.Optional[builtins.str] = None,
        delete: typing.Optional[builtins.str] = None,
        read: typing.Optional[builtins.str] = None,
        update: typing.Optional[builtins.str] = None,
    ) -> None:
        """
        :param create: 
        :param delete: 
        :param read: 
        :param update: 
        """
        self._values: typing.Dict[str, typing.Any] = {}
        if create is not None:
            self._values["create"] = create
        if delete is not None:
            self._values["delete"] = delete
        if read is not None:
            self._values["read"] = read
        if update is not None:
            self._values["update"] = update

    @builtins.property
    def create(self) -> typing.Optional[builtins.str]:
        result = self._values.get("create")
        return result

    @builtins.property
    def delete(self) -> typing.Optional[builtins.str]:
        result = self._values.get("delete")
        return result

    @builtins.property
    def read(self) -> typing.Optional[builtins.str]:
        result = self._values.get("read")
        return result

    @builtins.property
    def update(self) -> typing.Optional[builtins.str]:
        result = self._values.get("update")
        return result

    def __eq__(self, rhs: typing.Any) -> builtins.bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs: typing.Any) -> builtins.bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return "ManagementLockTimeouts(%s)" % ", ".join(
            k + "=" + repr(v) for k, v in self._values.items()
        )


class MapsAccount(
    cdktf.TerraformResource,
    metaclass=jsii.JSIIMeta,
    jsii_type="@cdktf/provider-azurerm.MapsAccount",
):
    def __init__(
        self,
        scope: constructs.Construct,
        id: builtins.str,
        *,
        name: builtins.str,
        resource_group_name: builtins.str,
        sku_name: builtins.str,
        tags: typing.Optional[typing.Mapping[builtins.str, builtins.str]] = None,
        timeouts: typing.Optional["MapsAccountTimeouts"] = None,
        count: typing.Optional[jsii.Number] = None,
        depends_on: typing.Optional[typing.List[cdktf.TerraformResource]] = None,
        lifecycle: typing.Optional[cdktf.TerraformResourceLifecycle] = None,
        provider: typing.Optional[cdktf.TerraformProvider] = None,
    ) -> None:
        """
        :param scope: -
        :param id: -
        :param name: 
        :param resource_group_name: 
        :param sku_name: 
        :param tags: 
        :param timeouts: timeouts block.
        :param count: 
        :param depends_on: 
        :param lifecycle: 
        :param provider: 
        """
        config = MapsAccountConfig(
            name=name,
            resource_group_name=resource_group_name,
            sku_name=sku_name,
            tags=tags,
            timeouts=timeouts,
            count=count,
            depends_on=depends_on,
            lifecycle=lifecycle,
            provider=provider,
        )

        jsii.create(MapsAccount, self, [scope, id, config])

    @jsii.member(jsii_name="synthesizeAttributes")
    def _synthesize_attributes(self) -> typing.Mapping[builtins.str, typing.Any]:
        return jsii.invoke(self, "synthesizeAttributes", [])

    @builtins.property # type: ignore
    @jsii.member(jsii_name="primaryAccessKey")
    def primary_access_key(self) -> builtins.str:
        return jsii.get(self, "primaryAccessKey")

    @builtins.property # type: ignore
    @jsii.member(jsii_name="secondaryAccessKey")
    def secondary_access_key(self) -> builtins.str:
        return jsii.get(self, "secondaryAccessKey")

    @builtins.property # type: ignore
    @jsii.member(jsii_name="xMsClientId")
    def x_ms_client_id(self) -> builtins.str:
        return jsii.get(self, "xMsClientId")

    @builtins.property # type: ignore
    @jsii.member(jsii_name="name")
    def name(self) -> builtins.str:
        return jsii.get(self, "name")

    @name.setter # type: ignore
    def name(self, value: builtins.str) -> None:
        jsii.set(self, "name", value)

    @builtins.property # type: ignore
    @jsii.member(jsii_name="resourceGroupName")
    def resource_group_name(self) -> builtins.str:
        return jsii.get(self, "resourceGroupName")

    @resource_group_name.setter # type: ignore
    def resource_group_name(self, value: builtins.str) -> None:
        jsii.set(self, "resourceGroupName", value)

    @builtins.property # type: ignore
    @jsii.member(jsii_name="skuName")
    def sku_name(self) -> builtins.str:
        return jsii.get(self, "skuName")

    @sku_name.setter # type: ignore
    def sku_name(self, value: builtins.str) -> None:
        jsii.set(self, "skuName", value)

    @builtins.property # type: ignore
    @jsii.member(jsii_name="id")
    def id(self) -> typing.Optional[builtins.str]:
        return jsii.get(self, "id")

    @id.setter # type: ignore
    def id(self, value: typing.Optional[builtins.str]) -> None:
        jsii.set(self, "id", value)

    @builtins.property # type: ignore
    @jsii.member(jsii_name="tags")
    def tags(self) -> typing.Optional[typing.Mapping[builtins.str, builtins.str]]:
        return jsii.get(self, "tags")

    @tags.setter # type: ignore
    def tags(
        self,
        value: typing.Optional[typing.Mapping[builtins.str, builtins.str]],
    ) -> None:
        jsii.set(self, "tags", value)

    @builtins.property # type: ignore
    @jsii.member(jsii_name="timeouts")
    def timeouts(self) -> typing.Optional["MapsAccountTimeouts"]:
        return jsii.get(self, "timeouts")

    @timeouts.setter # type: ignore
    def timeouts(self, value: typing.Optional["MapsAccountTimeouts"]) -> None:
        jsii.set(self, "timeouts", value)


@jsii.data_type(
    jsii_type="@cdktf/provider-azurerm.MapsAccountConfig",
    jsii_struct_bases=[cdktf.TerraformMetaArguments],
    name_mapping={
        "count": "count",
        "depends_on": "dependsOn",
        "lifecycle": "lifecycle",
        "provider": "provider",
        "name": "name",
        "resource_group_name": "resourceGroupName",
        "sku_name": "skuName",
        "tags": "tags",
        "timeouts": "timeouts",
    },
)
class MapsAccountConfig(cdktf.TerraformMetaArguments):
    def __init__(
        self,
        *,
        count: typing.Optional[jsii.Number] = None,
        depends_on: typing.Optional[typing.List[cdktf.TerraformResource]] = None,
        lifecycle: typing.Optional[cdktf.TerraformResourceLifecycle] = None,
        provider: typing.Optional[cdktf.TerraformProvider] = None,
        name: builtins.str,
        resource_group_name: builtins.str,
        sku_name: builtins.str,
        tags: typing.Optional[typing.Mapping[builtins.str, builtins.str]] = None,
        timeouts: typing.Optional["MapsAccountTimeouts"] = None,
    ) -> None:
        """
        :param count: 
        :param depends_on: 
        :param lifecycle: 
        :param provider: 
        :param name: 
        :param resource_group_name: 
        :param sku_name: 
        :param tags: 
        :param timeouts: timeouts block.
        """
        if isinstance(lifecycle, dict):
            lifecycle = cdktf.TerraformResourceLifecycle(**lifecycle)
        if isinstance(timeouts, dict):
            timeouts = MapsAccountTimeouts(**timeouts)
        self._values: typing.Dict[str, typing.Any] = {
            "name": name,
            "resource_group_name": resource_group_name,
            "sku_name": sku_name,
        }
        if count is not None:
            self._values["count"] = count
        if depends_on is not None:
            self._values["depends_on"] = depends_on
        if lifecycle is not None:
            self._values["lifecycle"] = lifecycle
        if provider is not None:
            self._values["provider"] = provider
        if tags is not None:
            self._values["tags"] = tags
        if timeouts is not None:
            self._values["timeouts"] = timeouts

    @builtins.property
    def count(self) -> typing.Optional[jsii.Number]:
        """
        :stability: experimental
        """
        result = self._values.get("count")
        return result

    @builtins.property
    def depends_on(self) -> typing.Optional[typing.List[cdktf.TerraformResource]]:
        """
        :stability: experimental
        """
        result = self._values.get("depends_on")
        return result

    @builtins.property
    def lifecycle(self) -> typing.Optional[cdktf.TerraformResourceLifecycle]:
        """
        :stability: experimental
        """
        result = self._values.get("lifecycle")
        return result

    @builtins.property
    def provider(self) -> typing.Optional[cdktf.TerraformProvider]:
        """
        :stability: experimental
        """
        result = self._values.get("provider")
        return result

    @builtins.property
    def name(self) -> builtins.str:
        result = self._values.get("name")
        assert result is not None, "Required property 'name' is missing"
        return result

    @builtins.property
    def resource_group_name(self) -> builtins.str:
        result = self._values.get("resource_group_name")
        assert result is not None, "Required property 'resource_group_name' is missing"
        return result

    @builtins.property
    def sku_name(self) -> builtins.str:
        result = self._values.get("sku_name")
        assert result is not None, "Required property 'sku_name' is missing"
        return result

    @builtins.property
    def tags(self) -> typing.Optional[typing.Mapping[builtins.str, builtins.str]]:
        result = self._values.get("tags")
        return result

    @builtins.property
    def timeouts(self) -> typing.Optional["MapsAccountTimeouts"]:
        """timeouts block."""
        result = self._values.get("timeouts")
        return result

    def __eq__(self, rhs: typing.Any) -> builtins.bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs: typing.Any) -> builtins.bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return "MapsAccountConfig(%s)" % ", ".join(
            k + "=" + repr(v) for k, v in self._values.items()
        )


@jsii.data_type(
    jsii_type="@cdktf/provider-azurerm.MapsAccountTimeouts",
    jsii_struct_bases=[],
    name_mapping={
        "create": "create",
        "delete": "delete",
        "read": "read",
        "update": "update",
    },
)
class MapsAccountTimeouts:
    def __init__(
        self,
        *,
        create: typing.Optional[builtins.str] = None,
        delete: typing.Optional[builtins.str] = None,
        read: typing.Optional[builtins.str] = None,
        update: typing.Optional[builtins.str] = None,
    ) -> None:
        """
        :param create: 
        :param delete: 
        :param read: 
        :param update: 
        """
        self._values: typing.Dict[str, typing.Any] = {}
        if create is not None:
            self._values["create"] = create
        if delete is not None:
            self._values["delete"] = delete
        if read is not None:
            self._values["read"] = read
        if update is not None:
            self._values["update"] = update

    @builtins.property
    def create(self) -> typing.Optional[builtins.str]:
        result = self._values.get("create")
        return result

    @builtins.property
    def delete(self) -> typing.Optional[builtins.str]:
        result = self._values.get("delete")
        return result

    @builtins.property
    def read(self) -> typing.Optional[builtins.str]:
        result = self._values.get("read")
        return result

    @builtins.property
    def update(self) -> typing.Optional[builtins.str]:
        result = self._values.get("update")
        return result

    def __eq__(self, rhs: typing.Any) -> builtins.bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs: typing.Any) -> builtins.bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return "MapsAccountTimeouts(%s)" % ", ".join(
            k + "=" + repr(v) for k, v in self._values.items()
        )


class MariadbConfiguration(
    cdktf.TerraformResource,
    metaclass=jsii.JSIIMeta,
    jsii_type="@cdktf/provider-azurerm.MariadbConfiguration",
):
    def __init__(
        self,
        scope: constructs.Construct,
        id: builtins.str,
        *,
        name: builtins.str,
        resource_group_name: builtins.str,
        server_name: builtins.str,
        value: builtins.str,
        timeouts: typing.Optional["MariadbConfigurationTimeouts"] = None,
        count: typing.Optional[jsii.Number] = None,
        depends_on: typing.Optional[typing.List[cdktf.TerraformResource]] = None,
        lifecycle: typing.Optional[cdktf.TerraformResourceLifecycle] = None,
        provider: typing.Optional[cdktf.TerraformProvider] = None,
    ) -> None:
        """
        :param scope: -
        :param id: -
        :param name: 
        :param resource_group_name: 
        :param server_name: 
        :param value: 
        :param timeouts: timeouts block.
        :param count: 
        :param depends_on: 
        :param lifecycle: 
        :param provider: 
        """
        config = MariadbConfigurationConfig(
            name=name,
            resource_group_name=resource_group_name,
            server_name=server_name,
            value=value,
            timeouts=timeouts,
            count=count,
            depends_on=depends_on,
            lifecycle=lifecycle,
            provider=provider,
        )

        jsii.create(MariadbConfiguration, self, [scope, id, config])

    @jsii.member(jsii_name="synthesizeAttributes")
    def _synthesize_attributes(self) -> typing.Mapping[builtins.str, typing.Any]:
        return jsii.invoke(self, "synthesizeAttributes", [])

    @builtins.property # type: ignore
    @jsii.member(jsii_name="name")
    def name(self) -> builtins.str:
        return jsii.get(self, "name")

    @name.setter # type: ignore
    def name(self, value: builtins.str) -> None:
        jsii.set(self, "name", value)

    @builtins.property # type: ignore
    @jsii.member(jsii_name="resourceGroupName")
    def resource_group_name(self) -> builtins.str:
        return jsii.get(self, "resourceGroupName")

    @resource_group_name.setter # type: ignore
    def resource_group_name(self, value: builtins.str) -> None:
        jsii.set(self, "resourceGroupName", value)

    @builtins.property # type: ignore
    @jsii.member(jsii_name="serverName")
    def server_name(self) -> builtins.str:
        return jsii.get(self, "serverName")

    @server_name.setter # type: ignore
    def server_name(self, value: builtins.str) -> None:
        jsii.set(self, "serverName", value)

    @builtins.property # type: ignore
    @jsii.member(jsii_name="value")
    def value(self) -> builtins.str:
        return jsii.get(self, "value")

    @value.setter # type: ignore
    def value(self, value: builtins.str) -> None:
        jsii.set(self, "value", value)

    @builtins.property # type: ignore
    @jsii.member(jsii_name="id")
    def id(self) -> typing.Optional[builtins.str]:
        return jsii.get(self, "id")

    @id.setter # type: ignore
    def id(self, value: typing.Optional[builtins.str]) -> None:
        jsii.set(self, "id", value)

    @builtins.property # type: ignore
    @jsii.member(jsii_name="timeouts")
    def timeouts(self) -> typing.Optional["MariadbConfigurationTimeouts"]:
        return jsii.get(self, "timeouts")

    @timeouts.setter # type: ignore
    def timeouts(self, value: typing.Optional["MariadbConfigurationTimeouts"]) -> None:
        jsii.set(self, "timeouts", value)


@jsii.data_type(
    jsii_type="@cdktf/provider-azurerm.MariadbConfigurationConfig",
    jsii_struct_bases=[cdktf.TerraformMetaArguments],
    name_mapping={
        "count": "count",
        "depends_on": "dependsOn",
        "lifecycle": "lifecycle",
        "provider": "provider",
        "name": "name",
        "resource_group_name": "resourceGroupName",
        "server_name": "serverName",
        "value": "value",
        "timeouts": "timeouts",
    },
)
class MariadbConfigurationConfig(cdktf.TerraformMetaArguments):
    def __init__(
        self,
        *,
        count: typing.Optional[jsii.Number] = None,
        depends_on: typing.Optional[typing.List[cdktf.TerraformResource]] = None,
        lifecycle: typing.Optional[cdktf.TerraformResourceLifecycle] = None,
        provider: typing.Optional[cdktf.TerraformProvider] = None,
        name: builtins.str,
        resource_group_name: builtins.str,
        server_name: builtins.str,
        value: builtins.str,
        timeouts: typing.Optional["MariadbConfigurationTimeouts"] = None,
    ) -> None:
        """
        :param count: 
        :param depends_on: 
        :param lifecycle: 
        :param provider: 
        :param name: 
        :param resource_group_name: 
        :param server_name: 
        :param value: 
        :param timeouts: timeouts block.
        """
        if isinstance(lifecycle, dict):
            lifecycle = cdktf.TerraformResourceLifecycle(**lifecycle)
        if isinstance(timeouts, dict):
            timeouts = MariadbConfigurationTimeouts(**timeouts)
        self._values: typing.Dict[str, typing.Any] = {
            "name": name,
            "resource_group_name": resource_group_name,
            "server_name": server_name,
            "value": value,
        }
        if count is not None:
            self._values["count"] = count
        if depends_on is not None:
            self._values["depends_on"] = depends_on
        if lifecycle is not None:
            self._values["lifecycle"] = lifecycle
        if provider is not None:
            self._values["provider"] = provider
        if timeouts is not None:
            self._values["timeouts"] = timeouts

    @builtins.property
    def count(self) -> typing.Optional[jsii.Number]:
        """
        :stability: experimental
        """
        result = self._values.get("count")
        return result

    @builtins.property
    def depends_on(self) -> typing.Optional[typing.List[cdktf.TerraformResource]]:
        """
        :stability: experimental
        """
        result = self._values.get("depends_on")
        return result

    @builtins.property
    def lifecycle(self) -> typing.Optional[cdktf.TerraformResourceLifecycle]:
        """
        :stability: experimental
        """
        result = self._values.get("lifecycle")
        return result

    @builtins.property
    def provider(self) -> typing.Optional[cdktf.TerraformProvider]:
        """
        :stability: experimental
        """
        result = self._values.get("provider")
        return result

    @builtins.property
    def name(self) -> builtins.str:
        result = self._values.get("name")
        assert result is not None, "Required property 'name' is missing"
        return result

    @builtins.property
    def resource_group_name(self) -> builtins.str:
        result = self._values.get("resource_group_name")
        assert result is not None, "Required property 'resource_group_name' is missing"
        return result

    @builtins.property
    def server_name(self) -> builtins.str:
        result = self._values.get("server_name")
        assert result is not None, "Required property 'server_name' is missing"
        return result

    @builtins.property
    def value(self) -> builtins.str:
        result = self._values.get("value")
        assert result is not None, "Required property 'value' is missing"
        return result

    @builtins.property
    def timeouts(self) -> typing.Optional["MariadbConfigurationTimeouts"]:
        """timeouts block."""
        result = self._values.get("timeouts")
        return result

    def __eq__(self, rhs: typing.Any) -> builtins.bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs: typing.Any) -> builtins.bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return "MariadbConfigurationConfig(%s)" % ", ".join(
            k + "=" + repr(v) for k, v in self._values.items()
        )


@jsii.data_type(
    jsii_type="@cdktf/provider-azurerm.MariadbConfigurationTimeouts",
    jsii_struct_bases=[],
    name_mapping={
        "create": "create",
        "delete": "delete",
        "read": "read",
        "update": "update",
    },
)
class MariadbConfigurationTimeouts:
    def __init__(
        self,
        *,
        create: typing.Optional[builtins.str] = None,
        delete: typing.Optional[builtins.str] = None,
        read: typing.Optional[builtins.str] = None,
        update: typing.Optional[builtins.str] = None,
    ) -> None:
        """
        :param create: 
        :param delete: 
        :param read: 
        :param update: 
        """
        self._values: typing.Dict[str, typing.Any] = {}
        if create is not None:
            self._values["create"] = create
        if delete is not None:
            self._values["delete"] = delete
        if read is not None:
            self._values["read"] = read
        if update is not None:
            self._values["update"] = update

    @builtins.property
    def create(self) -> typing.Optional[builtins.str]:
        result = self._values.get("create")
        return result

    @builtins.property
    def delete(self) -> typing.Optional[builtins.str]:
        result = self._values.get("delete")
        return result

    @builtins.property
    def read(self) -> typing.Optional[builtins.str]:
        result = self._values.get("read")
        return result

    @builtins.property
    def update(self) -> typing.Optional[builtins.str]:
        result = self._values.get("update")
        return result

    def __eq__(self, rhs: typing.Any) -> builtins.bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs: typing.Any) -> builtins.bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return "MariadbConfigurationTimeouts(%s)" % ", ".join(
            k + "=" + repr(v) for k, v in self._values.items()
        )


class MariadbDatabase(
    cdktf.TerraformResource,
    metaclass=jsii.JSIIMeta,
    jsii_type="@cdktf/provider-azurerm.MariadbDatabase",
):
    def __init__(
        self,
        scope: constructs.Construct,
        id: builtins.str,
        *,
        charset: builtins.str,
        collation: builtins.str,
        name: builtins.str,
        resource_group_name: builtins.str,
        server_name: builtins.str,
        timeouts: typing.Optional["MariadbDatabaseTimeouts"] = None,
        count: typing.Optional[jsii.Number] = None,
        depends_on: typing.Optional[typing.List[cdktf.TerraformResource]] = None,
        lifecycle: typing.Optional[cdktf.TerraformResourceLifecycle] = None,
        provider: typing.Optional[cdktf.TerraformProvider] = None,
    ) -> None:
        """
        :param scope: -
        :param id: -
        :param charset: 
        :param collation: 
        :param name: 
        :param resource_group_name: 
        :param server_name: 
        :param timeouts: timeouts block.
        :param count: 
        :param depends_on: 
        :param lifecycle: 
        :param provider: 
        """
        config = MariadbDatabaseConfig(
            charset=charset,
            collation=collation,
            name=name,
            resource_group_name=resource_group_name,
            server_name=server_name,
            timeouts=timeouts,
            count=count,
            depends_on=depends_on,
            lifecycle=lifecycle,
            provider=provider,
        )

        jsii.create(MariadbDatabase, self, [scope, id, config])

    @jsii.member(jsii_name="synthesizeAttributes")
    def _synthesize_attributes(self) -> typing.Mapping[builtins.str, typing.Any]:
        return jsii.invoke(self, "synthesizeAttributes", [])

    @builtins.property # type: ignore
    @jsii.member(jsii_name="charset")
    def charset(self) -> builtins.str:
        return jsii.get(self, "charset")

    @charset.setter # type: ignore
    def charset(self, value: builtins.str) -> None:
        jsii.set(self, "charset", value)

    @builtins.property # type: ignore
    @jsii.member(jsii_name="collation")
    def collation(self) -> builtins.str:
        return jsii.get(self, "collation")

    @collation.setter # type: ignore
    def collation(self, value: builtins.str) -> None:
        jsii.set(self, "collation", value)

    @builtins.property # type: ignore
    @jsii.member(jsii_name="name")
    def name(self) -> builtins.str:
        return jsii.get(self, "name")

    @name.setter # type: ignore
    def name(self, value: builtins.str) -> None:
        jsii.set(self, "name", value)

    @builtins.property # type: ignore
    @jsii.member(jsii_name="resourceGroupName")
    def resource_group_name(self) -> builtins.str:
        return jsii.get(self, "resourceGroupName")

    @resource_group_name.setter # type: ignore
    def resource_group_name(self, value: builtins.str) -> None:
        jsii.set(self, "resourceGroupName", value)

    @builtins.property # type: ignore
    @jsii.member(jsii_name="serverName")
    def server_name(self) -> builtins.str:
        return jsii.get(self, "serverName")

    @server_name.setter # type: ignore
    def server_name(self, value: builtins.str) -> None:
        jsii.set(self, "serverName", value)

    @builtins.property # type: ignore
    @jsii.member(jsii_name="id")
    def id(self) -> typing.Optional[builtins.str]:
        return jsii.get(self, "id")

    @id.setter # type: ignore
    def id(self, value: typing.Optional[builtins.str]) -> None:
        jsii.set(self, "id", value)

    @builtins.property # type: ignore
    @jsii.member(jsii_name="timeouts")
    def timeouts(self) -> typing.Optional["MariadbDatabaseTimeouts"]:
        return jsii.get(self, "timeouts")

    @timeouts.setter # type: ignore
    def timeouts(self, value: typing.Optional["MariadbDatabaseTimeouts"]) -> None:
        jsii.set(self, "timeouts", value)


@jsii.data_type(
    jsii_type="@cdktf/provider-azurerm.MariadbDatabaseConfig",
    jsii_struct_bases=[cdktf.TerraformMetaArguments],
    name_mapping={
        "count": "count",
        "depends_on": "dependsOn",
        "lifecycle": "lifecycle",
        "provider": "provider",
        "charset": "charset",
        "collation": "collation",
        "name": "name",
        "resource_group_name": "resourceGroupName",
        "server_name": "serverName",
        "timeouts": "timeouts",
    },
)
class MariadbDatabaseConfig(cdktf.TerraformMetaArguments):
    def __init__(
        self,
        *,
        count: typing.Optional[jsii.Number] = None,
        depends_on: typing.Optional[typing.List[cdktf.TerraformResource]] = None,
        lifecycle: typing.Optional[cdktf.TerraformResourceLifecycle] = None,
        provider: typing.Optional[cdktf.TerraformProvider] = None,
        charset: builtins.str,
        collation: builtins.str,
        name: builtins.str,
        resource_group_name: builtins.str,
        server_name: builtins.str,
        timeouts: typing.Optional["MariadbDatabaseTimeouts"] = None,
    ) -> None:
        """
        :param count: 
        :param depends_on: 
        :param lifecycle: 
        :param provider: 
        :param charset: 
        :param collation: 
        :param name: 
        :param resource_group_name: 
        :param server_name: 
        :param timeouts: timeouts block.
        """
        if isinstance(lifecycle, dict):
            lifecycle = cdktf.TerraformResourceLifecycle(**lifecycle)
        if isinstance(timeouts, dict):
            timeouts = MariadbDatabaseTimeouts(**timeouts)
        self._values: typing.Dict[str, typing.Any] = {
            "charset": charset,
            "collation": collation,
            "name": name,
            "resource_group_name": resource_group_name,
            "server_name": server_name,
        }
        if count is not None:
            self._values["count"] = count
        if depends_on is not None:
            self._values["depends_on"] = depends_on
        if lifecycle is not None:
            self._values["lifecycle"] = lifecycle
        if provider is not None:
            self._values["provider"] = provider
        if timeouts is not None:
            self._values["timeouts"] = timeouts

    @builtins.property
    def count(self) -> typing.Optional[jsii.Number]:
        """
        :stability: experimental
        """
        result = self._values.get("count")
        return result

    @builtins.property
    def depends_on(self) -> typing.Optional[typing.List[cdktf.TerraformResource]]:
        """
        :stability: experimental
        """
        result = self._values.get("depends_on")
        return result

    @builtins.property
    def lifecycle(self) -> typing.Optional[cdktf.TerraformResourceLifecycle]:
        """
        :stability: experimental
        """
        result = self._values.get("lifecycle")
        return result

    @builtins.property
    def provider(self) -> typing.Optional[cdktf.TerraformProvider]:
        """
        :stability: experimental
        """
        result = self._values.get("provider")
        return result

    @builtins.property
    def charset(self) -> builtins.str:
        result = self._values.get("charset")
        assert result is not None, "Required property 'charset' is missing"
        return result

    @builtins.property
    def collation(self) -> builtins.str:
        result = self._values.get("collation")
        assert result is not None, "Required property 'collation' is missing"
        return result

    @builtins.property
    def name(self) -> builtins.str:
        result = self._values.get("name")
        assert result is not None, "Required property 'name' is missing"
        return result

    @builtins.property
    def resource_group_name(self) -> builtins.str:
        result = self._values.get("resource_group_name")
        assert result is not None, "Required property 'resource_group_name' is missing"
        return result

    @builtins.property
    def server_name(self) -> builtins.str:
        result = self._values.get("server_name")
        assert result is not None, "Required property 'server_name' is missing"
        return result

    @builtins.property
    def timeouts(self) -> typing.Optional["MariadbDatabaseTimeouts"]:
        """timeouts block."""
        result = self._values.get("timeouts")
        return result

    def __eq__(self, rhs: typing.Any) -> builtins.bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs: typing.Any) -> builtins.bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return "MariadbDatabaseConfig(%s)" % ", ".join(
            k + "=" + repr(v) for k, v in self._values.items()
        )


@jsii.data_type(
    jsii_type="@cdktf/provider-azurerm.MariadbDatabaseTimeouts",
    jsii_struct_bases=[],
    name_mapping={
        "create": "create",
        "delete": "delete",
        "read": "read",
        "update": "update",
    },
)
class MariadbDatabaseTimeouts:
    def __init__(
        self,
        *,
        create: typing.Optional[builtins.str] = None,
        delete: typing.Optional[builtins.str] = None,
        read: typing.Optional[builtins.str] = None,
        update: typing.Optional[builtins.str] = None,
    ) -> None:
        """
        :param create: 
        :param delete: 
        :param read: 
        :param update: 
        """
        self._values: typing.Dict[str, typing.Any] = {}
        if create is not None:
            self._values["create"] = create
        if delete is not None:
            self._values["delete"] = delete
        if read is not None:
            self._values["read"] = read
        if update is not None:
            self._values["update"] = update

    @builtins.property
    def create(self) -> typing.Optional[builtins.str]:
        result = self._values.get("create")
        return result

    @builtins.property
    def delete(self) -> typing.Optional[builtins.str]:
        result = self._values.get("delete")
        return result

    @builtins.property
    def read(self) -> typing.Optional[builtins.str]:
        result = self._values.get("read")
        return result

    @builtins.property
    def update(self) -> typing.Optional[builtins.str]:
        result = self._values.get("update")
        return result

    def __eq__(self, rhs: typing.Any) -> builtins.bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs: typing.Any) -> builtins.bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return "MariadbDatabaseTimeouts(%s)" % ", ".join(
            k + "=" + repr(v) for k, v in self._values.items()
        )


class MariadbFirewallRule(
    cdktf.TerraformResource,
    metaclass=jsii.JSIIMeta,
    jsii_type="@cdktf/provider-azurerm.MariadbFirewallRule",
):
    def __init__(
        self,
        scope: constructs.Construct,
        id: builtins.str,
        *,
        end_ip_address: builtins.str,
        name: builtins.str,
        resource_group_name: builtins.str,
        server_name: builtins.str,
        start_ip_address: builtins.str,
        timeouts: typing.Optional["MariadbFirewallRuleTimeouts"] = None,
        count: typing.Optional[jsii.Number] = None,
        depends_on: typing.Optional[typing.List[cdktf.TerraformResource]] = None,
        lifecycle: typing.Optional[cdktf.TerraformResourceLifecycle] = None,
        provider: typing.Optional[cdktf.TerraformProvider] = None,
    ) -> None:
        """
        :param scope: -
        :param id: -
        :param end_ip_address: 
        :param name: 
        :param resource_group_name: 
        :param server_name: 
        :param start_ip_address: 
        :param timeouts: timeouts block.
        :param count: 
        :param depends_on: 
        :param lifecycle: 
        :param provider: 
        """
        config = MariadbFirewallRuleConfig(
            end_ip_address=end_ip_address,
            name=name,
            resource_group_name=resource_group_name,
            server_name=server_name,
            start_ip_address=start_ip_address,
            timeouts=timeouts,
            count=count,
            depends_on=depends_on,
            lifecycle=lifecycle,
            provider=provider,
        )

        jsii.create(MariadbFirewallRule, self, [scope, id, config])

    @jsii.member(jsii_name="synthesizeAttributes")
    def _synthesize_attributes(self) -> typing.Mapping[builtins.str, typing.Any]:
        return jsii.invoke(self, "synthesizeAttributes", [])

    @builtins.property # type: ignore
    @jsii.member(jsii_name="endIpAddress")
    def end_ip_address(self) -> builtins.str:
        return jsii.get(self, "endIpAddress")

    @end_ip_address.setter # type: ignore
    def end_ip_address(self, value: builtins.str) -> None:
        jsii.set(self, "endIpAddress", value)

    @builtins.property # type: ignore
    @jsii.member(jsii_name="name")
    def name(self) -> builtins.str:
        return jsii.get(self, "name")

    @name.setter # type: ignore
    def name(self, value: builtins.str) -> None:
        jsii.set(self, "name", value)

    @builtins.property # type: ignore
    @jsii.member(jsii_name="resourceGroupName")
    def resource_group_name(self) -> builtins.str:
        return jsii.get(self, "resourceGroupName")

    @resource_group_name.setter # type: ignore
    def resource_group_name(self, value: builtins.str) -> None:
        jsii.set(self, "resourceGroupName", value)

    @builtins.property # type: ignore
    @jsii.member(jsii_name="serverName")
    def server_name(self) -> builtins.str:
        return jsii.get(self, "serverName")

    @server_name.setter # type: ignore
    def server_name(self, value: builtins.str) -> None:
        jsii.set(self, "serverName", value)

    @builtins.property # type: ignore
    @jsii.member(jsii_name="startIpAddress")
    def start_ip_address(self) -> builtins.str:
        return jsii.get(self, "startIpAddress")

    @start_ip_address.setter # type: ignore
    def start_ip_address(self, value: builtins.str) -> None:
        jsii.set(self, "startIpAddress", value)

    @builtins.property # type: ignore
    @jsii.member(jsii_name="id")
    def id(self) -> typing.Optional[builtins.str]:
        return jsii.get(self, "id")

    @id.setter # type: ignore
    def id(self, value: typing.Optional[builtins.str]) -> None:
        jsii.set(self, "id", value)

    @builtins.property # type: ignore
    @jsii.member(jsii_name="timeouts")
    def timeouts(self) -> typing.Optional["MariadbFirewallRuleTimeouts"]:
        return jsii.get(self, "timeouts")

    @timeouts.setter # type: ignore
    def timeouts(self, value: typing.Optional["MariadbFirewallRuleTimeouts"]) -> None:
        jsii.set(self, "timeouts", value)


@jsii.data_type(
    jsii_type="@cdktf/provider-azurerm.MariadbFirewallRuleConfig",
    jsii_struct_bases=[cdktf.TerraformMetaArguments],
    name_mapping={
        "count": "count",
        "depends_on": "dependsOn",
        "lifecycle": "lifecycle",
        "provider": "provider",
        "end_ip_address": "endIpAddress",
        "name": "name",
        "resource_group_name": "resourceGroupName",
        "server_name": "serverName",
        "start_ip_address": "startIpAddress",
        "timeouts": "timeouts",
    },
)
class MariadbFirewallRuleConfig(cdktf.TerraformMetaArguments):
    def __init__(
        self,
        *,
        count: typing.Optional[jsii.Number] = None,
        depends_on: typing.Optional[typing.List[cdktf.TerraformResource]] = None,
        lifecycle: typing.Optional[cdktf.TerraformResourceLifecycle] = None,
        provider: typing.Optional[cdktf.TerraformProvider] = None,
        end_ip_address: builtins.str,
        name: builtins.str,
        resource_group_name: builtins.str,
        server_name: builtins.str,
        start_ip_address: builtins.str,
        timeouts: typing.Optional["MariadbFirewallRuleTimeouts"] = None,
    ) -> None:
        """
        :param count: 
        :param depends_on: 
        :param lifecycle: 
        :param provider: 
        :param end_ip_address: 
        :param name: 
        :param resource_group_name: 
        :param server_name: 
        :param start_ip_address: 
        :param timeouts: timeouts block.
        """
        if isinstance(lifecycle, dict):
            lifecycle = cdktf.TerraformResourceLifecycle(**lifecycle)
        if isinstance(timeouts, dict):
            timeouts = MariadbFirewallRuleTimeouts(**timeouts)
        self._values: typing.Dict[str, typing.Any] = {
            "end_ip_address": end_ip_address,
            "name": name,
            "resource_group_name": resource_group_name,
            "server_name": server_name,
            "start_ip_address": start_ip_address,
        }
        if count is not None:
            self._values["count"] = count
        if depends_on is not None:
            self._values["depends_on"] = depends_on
        if lifecycle is not None:
            self._values["lifecycle"] = lifecycle
        if provider is not None:
            self._values["provider"] = provider
        if timeouts is not None:
            self._values["timeouts"] = timeouts

    @builtins.property
    def count(self) -> typing.Optional[jsii.Number]:
        """
        :stability: experimental
        """
        result = self._values.get("count")
        return result

    @builtins.property
    def depends_on(self) -> typing.Optional[typing.List[cdktf.TerraformResource]]:
        """
        :stability: experimental
        """
        result = self._values.get("depends_on")
        return result

    @builtins.property
    def lifecycle(self) -> typing.Optional[cdktf.TerraformResourceLifecycle]:
        """
        :stability: experimental
        """
        result = self._values.get("lifecycle")
        return result

    @builtins.property
    def provider(self) -> typing.Optional[cdktf.TerraformProvider]:
        """
        :stability: experimental
        """
        result = self._values.get("provider")
        return result

    @builtins.property
    def end_ip_address(self) -> builtins.str:
        result = self._values.get("end_ip_address")
        assert result is not None, "Required property 'end_ip_address' is missing"
        return result

    @builtins.property
    def name(self) -> builtins.str:
        result = self._values.get("name")
        assert result is not None, "Required property 'name' is missing"
        return result

    @builtins.property
    def resource_group_name(self) -> builtins.str:
        result = self._values.get("resource_group_name")
        assert result is not None, "Required property 'resource_group_name' is missing"
        return result

    @builtins.property
    def server_name(self) -> builtins.str:
        result = self._values.get("server_name")
        assert result is not None, "Required property 'server_name' is missing"
        return result

    @builtins.property
    def start_ip_address(self) -> builtins.str:
        result = self._values.get("start_ip_address")
        assert result is not None, "Required property 'start_ip_address' is missing"
        return result

    @builtins.property
    def timeouts(self) -> typing.Optional["MariadbFirewallRuleTimeouts"]:
        """timeouts block."""
        result = self._values.get("timeouts")
        return result

    def __eq__(self, rhs: typing.Any) -> builtins.bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs: typing.Any) -> builtins.bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return "MariadbFirewallRuleConfig(%s)" % ", ".join(
            k + "=" + repr(v) for k, v in self._values.items()
        )


@jsii.data_type(
    jsii_type="@cdktf/provider-azurerm.MariadbFirewallRuleTimeouts",
    jsii_struct_bases=[],
    name_mapping={
        "create": "create",
        "delete": "delete",
        "read": "read",
        "update": "update",
    },
)
class MariadbFirewallRuleTimeouts:
    def __init__(
        self,
        *,
        create: typing.Optional[builtins.str] = None,
        delete: typing.Optional[builtins.str] = None,
        read: typing.Optional[builtins.str] = None,
        update: typing.Optional[builtins.str] = None,
    ) -> None:
        """
        :param create: 
        :param delete: 
        :param read: 
        :param update: 
        """
        self._values: typing.Dict[str, typing.Any] = {}
        if create is not None:
            self._values["create"] = create
        if delete is not None:
            self._values["delete"] = delete
        if read is not None:
            self._values["read"] = read
        if update is not None:
            self._values["update"] = update

    @builtins.property
    def create(self) -> typing.Optional[builtins.str]:
        result = self._values.get("create")
        return result

    @builtins.property
    def delete(self) -> typing.Optional[builtins.str]:
        result = self._values.get("delete")
        return result

    @builtins.property
    def read(self) -> typing.Optional[builtins.str]:
        result = self._values.get("read")
        return result

    @builtins.property
    def update(self) -> typing.Optional[builtins.str]:
        result = self._values.get("update")
        return result

    def __eq__(self, rhs: typing.Any) -> builtins.bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs: typing.Any) -> builtins.bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return "MariadbFirewallRuleTimeouts(%s)" % ", ".join(
            k + "=" + repr(v) for k, v in self._values.items()
        )


class MariadbServer(
    cdktf.TerraformResource,
    metaclass=jsii.JSIIMeta,
    jsii_type="@cdktf/provider-azurerm.MariadbServer",
):
    def __init__(
        self,
        scope: constructs.Construct,
        id: builtins.str,
        *,
        administrator_login: builtins.str,
        administrator_login_password: builtins.str,
        location: builtins.str,
        name: builtins.str,
        resource_group_name: builtins.str,
        sku_name: builtins.str,
        ssl_enforcement: builtins.str,
        storage_profile: typing.List["MariadbServerStorageProfile"],
        version: builtins.str,
        tags: typing.Optional[typing.Mapping[builtins.str, builtins.str]] = None,
        timeouts: typing.Optional["MariadbServerTimeouts"] = None,
        count: typing.Optional[jsii.Number] = None,
        depends_on: typing.Optional[typing.List[cdktf.TerraformResource]] = None,
        lifecycle: typing.Optional[cdktf.TerraformResourceLifecycle] = None,
        provider: typing.Optional[cdktf.TerraformProvider] = None,
    ) -> None:
        """
        :param scope: -
        :param id: -
        :param administrator_login: 
        :param administrator_login_password: 
        :param location: 
        :param name: 
        :param resource_group_name: 
        :param sku_name: 
        :param ssl_enforcement: 
        :param storage_profile: storage_profile block.
        :param version: 
        :param tags: 
        :param timeouts: timeouts block.
        :param count: 
        :param depends_on: 
        :param lifecycle: 
        :param provider: 
        """
        config = MariadbServerConfig(
            administrator_login=administrator_login,
            administrator_login_password=administrator_login_password,
            location=location,
            name=name,
            resource_group_name=resource_group_name,
            sku_name=sku_name,
            ssl_enforcement=ssl_enforcement,
            storage_profile=storage_profile,
            version=version,
            tags=tags,
            timeouts=timeouts,
            count=count,
            depends_on=depends_on,
            lifecycle=lifecycle,
            provider=provider,
        )

        jsii.create(MariadbServer, self, [scope, id, config])

    @jsii.member(jsii_name="synthesizeAttributes")
    def _synthesize_attributes(self) -> typing.Mapping[builtins.str, typing.Any]:
        return jsii.invoke(self, "synthesizeAttributes", [])

    @builtins.property # type: ignore
    @jsii.member(jsii_name="fqdn")
    def fqdn(self) -> builtins.str:
        return jsii.get(self, "fqdn")

    @builtins.property # type: ignore
    @jsii.member(jsii_name="administratorLogin")
    def administrator_login(self) -> builtins.str:
        return jsii.get(self, "administratorLogin")

    @administrator_login.setter # type: ignore
    def administrator_login(self, value: builtins.str) -> None:
        jsii.set(self, "administratorLogin", value)

    @builtins.property # type: ignore
    @jsii.member(jsii_name="administratorLoginPassword")
    def administrator_login_password(self) -> builtins.str:
        return jsii.get(self, "administratorLoginPassword")

    @administrator_login_password.setter # type: ignore
    def administrator_login_password(self, value: builtins.str) -> None:
        jsii.set(self, "administratorLoginPassword", value)

    @builtins.property # type: ignore
    @jsii.member(jsii_name="location")
    def location(self) -> builtins.str:
        return jsii.get(self, "location")

    @location.setter # type: ignore
    def location(self, value: builtins.str) -> None:
        jsii.set(self, "location", value)

    @builtins.property # type: ignore
    @jsii.member(jsii_name="name")
    def name(self) -> builtins.str:
        return jsii.get(self, "name")

    @name.setter # type: ignore
    def name(self, value: builtins.str) -> None:
        jsii.set(self, "name", value)

    @builtins.property # type: ignore
    @jsii.member(jsii_name="resourceGroupName")
    def resource_group_name(self) -> builtins.str:
        return jsii.get(self, "resourceGroupName")

    @resource_group_name.setter # type: ignore
    def resource_group_name(self, value: builtins.str) -> None:
        jsii.set(self, "resourceGroupName", value)

    @builtins.property # type: ignore
    @jsii.member(jsii_name="skuName")
    def sku_name(self) -> builtins.str:
        return jsii.get(self, "skuName")

    @sku_name.setter # type: ignore
    def sku_name(self, value: builtins.str) -> None:
        jsii.set(self, "skuName", value)

    @builtins.property # type: ignore
    @jsii.member(jsii_name="sslEnforcement")
    def ssl_enforcement(self) -> builtins.str:
        return jsii.get(self, "sslEnforcement")

    @ssl_enforcement.setter # type: ignore
    def ssl_enforcement(self, value: builtins.str) -> None:
        jsii.set(self, "sslEnforcement", value)

    @builtins.property # type: ignore
    @jsii.member(jsii_name="storageProfile")
    def storage_profile(self) -> typing.List["MariadbServerStorageProfile"]:
        return jsii.get(self, "storageProfile")

    @storage_profile.setter # type: ignore
    def storage_profile(
        self,
        value: typing.List["MariadbServerStorageProfile"],
    ) -> None:
        jsii.set(self, "storageProfile", value)

    @builtins.property # type: ignore
    @jsii.member(jsii_name="version")
    def version(self) -> builtins.str:
        return jsii.get(self, "version")

    @version.setter # type: ignore
    def version(self, value: builtins.str) -> None:
        jsii.set(self, "version", value)

    @builtins.property # type: ignore
    @jsii.member(jsii_name="id")
    def id(self) -> typing.Optional[builtins.str]:
        return jsii.get(self, "id")

    @id.setter # type: ignore
    def id(self, value: typing.Optional[builtins.str]) -> None:
        jsii.set(self, "id", value)

    @builtins.property # type: ignore
    @jsii.member(jsii_name="tags")
    def tags(self) -> typing.Optional[typing.Mapping[builtins.str, builtins.str]]:
        return jsii.get(self, "tags")

    @tags.setter # type: ignore
    def tags(
        self,
        value: typing.Optional[typing.Mapping[builtins.str, builtins.str]],
    ) -> None:
        jsii.set(self, "tags", value)

    @builtins.property # type: ignore
    @jsii.member(jsii_name="timeouts")
    def timeouts(self) -> typing.Optional["MariadbServerTimeouts"]:
        return jsii.get(self, "timeouts")

    @timeouts.setter # type: ignore
    def timeouts(self, value: typing.Optional["MariadbServerTimeouts"]) -> None:
        jsii.set(self, "timeouts", value)


@jsii.data_type(
    jsii_type="@cdktf/provider-azurerm.MariadbServerConfig",
    jsii_struct_bases=[cdktf.TerraformMetaArguments],
    name_mapping={
        "count": "count",
        "depends_on": "dependsOn",
        "lifecycle": "lifecycle",
        "provider": "provider",
        "administrator_login": "administratorLogin",
        "administrator_login_password": "administratorLoginPassword",
        "location": "location",
        "name": "name",
        "resource_group_name": "resourceGroupName",
        "sku_name": "skuName",
        "ssl_enforcement": "sslEnforcement",
        "storage_profile": "storageProfile",
        "version": "version",
        "tags": "tags",
        "timeouts": "timeouts",
    },
)
class MariadbServerConfig(cdktf.TerraformMetaArguments):
    def __init__(
        self,
        *,
        count: typing.Optional[jsii.Number] = None,
        depends_on: typing.Optional[typing.List[cdktf.TerraformResource]] = None,
        lifecycle: typing.Optional[cdktf.TerraformResourceLifecycle] = None,
        provider: typing.Optional[cdktf.TerraformProvider] = None,
        administrator_login: builtins.str,
        administrator_login_password: builtins.str,
        location: builtins.str,
        name: builtins.str,
        resource_group_name: builtins.str,
        sku_name: builtins.str,
        ssl_enforcement: builtins.str,
        storage_profile: typing.List["MariadbServerStorageProfile"],
        version: builtins.str,
        tags: typing.Optional[typing.Mapping[builtins.str, builtins.str]] = None,
        timeouts: typing.Optional["MariadbServerTimeouts"] = None,
    ) -> None:
        """
        :param count: 
        :param depends_on: 
        :param lifecycle: 
        :param provider: 
        :param administrator_login: 
        :param administrator_login_password: 
        :param location: 
        :param name: 
        :param resource_group_name: 
        :param sku_name: 
        :param ssl_enforcement: 
        :param storage_profile: storage_profile block.
        :param version: 
        :param tags: 
        :param timeouts: timeouts block.
        """
        if isinstance(lifecycle, dict):
            lifecycle = cdktf.TerraformResourceLifecycle(**lifecycle)
        if isinstance(timeouts, dict):
            timeouts = MariadbServerTimeouts(**timeouts)
        self._values: typing.Dict[str, typing.Any] = {
            "administrator_login": administrator_login,
            "administrator_login_password": administrator_login_password,
            "location": location,
            "name": name,
            "resource_group_name": resource_group_name,
            "sku_name": sku_name,
            "ssl_enforcement": ssl_enforcement,
            "storage_profile": storage_profile,
            "version": version,
        }
        if count is not None:
            self._values["count"] = count
        if depends_on is not None:
            self._values["depends_on"] = depends_on
        if lifecycle is not None:
            self._values["lifecycle"] = lifecycle
        if provider is not None:
            self._values["provider"] = provider
        if tags is not None:
            self._values["tags"] = tags
        if timeouts is not None:
            self._values["timeouts"] = timeouts

    @builtins.property
    def count(self) -> typing.Optional[jsii.Number]:
        """
        :stability: experimental
        """
        result = self._values.get("count")
        return result

    @builtins.property
    def depends_on(self) -> typing.Optional[typing.List[cdktf.TerraformResource]]:
        """
        :stability: experimental
        """
        result = self._values.get("depends_on")
        return result

    @builtins.property
    def lifecycle(self) -> typing.Optional[cdktf.TerraformResourceLifecycle]:
        """
        :stability: experimental
        """
        result = self._values.get("lifecycle")
        return result

    @builtins.property
    def provider(self) -> typing.Optional[cdktf.TerraformProvider]:
        """
        :stability: experimental
        """
        result = self._values.get("provider")
        return result

    @builtins.property
    def administrator_login(self) -> builtins.str:
        result = self._values.get("administrator_login")
        assert result is not None, "Required property 'administrator_login' is missing"
        return result

    @builtins.property
    def administrator_login_password(self) -> builtins.str:
        result = self._values.get("administrator_login_password")
        assert result is not None, "Required property 'administrator_login_password' is missing"
        return result

    @builtins.property
    def location(self) -> builtins.str:
        result = self._values.get("location")
        assert result is not None, "Required property 'location' is missing"
        return result

    @builtins.property
    def name(self) -> builtins.str:
        result = self._values.get("name")
        assert result is not None, "Required property 'name' is missing"
        return result

    @builtins.property
    def resource_group_name(self) -> builtins.str:
        result = self._values.get("resource_group_name")
        assert result is not None, "Required property 'resource_group_name' is missing"
        return result

    @builtins.property
    def sku_name(self) -> builtins.str:
        result = self._values.get("sku_name")
        assert result is not None, "Required property 'sku_name' is missing"
        return result

    @builtins.property
    def ssl_enforcement(self) -> builtins.str:
        result = self._values.get("ssl_enforcement")
        assert result is not None, "Required property 'ssl_enforcement' is missing"
        return result

    @builtins.property
    def storage_profile(self) -> typing.List["MariadbServerStorageProfile"]:
        """storage_profile block."""
        result = self._values.get("storage_profile")
        assert result is not None, "Required property 'storage_profile' is missing"
        return result

    @builtins.property
    def version(self) -> builtins.str:
        result = self._values.get("version")
        assert result is not None, "Required property 'version' is missing"
        return result

    @builtins.property
    def tags(self) -> typing.Optional[typing.Mapping[builtins.str, builtins.str]]:
        result = self._values.get("tags")
        return result

    @builtins.property
    def timeouts(self) -> typing.Optional["MariadbServerTimeouts"]:
        """timeouts block."""
        result = self._values.get("timeouts")
        return result

    def __eq__(self, rhs: typing.Any) -> builtins.bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs: typing.Any) -> builtins.bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return "MariadbServerConfig(%s)" % ", ".join(
            k + "=" + repr(v) for k, v in self._values.items()
        )


@jsii.data_type(
    jsii_type="@cdktf/provider-azurerm.MariadbServerStorageProfile",
    jsii_struct_bases=[],
    name_mapping={
        "storage_mb": "storageMb",
        "auto_grow": "autoGrow",
        "backup_retention_days": "backupRetentionDays",
        "geo_redundant_backup": "geoRedundantBackup",
    },
)
class MariadbServerStorageProfile:
    def __init__(
        self,
        *,
        storage_mb: jsii.Number,
        auto_grow: typing.Optional[builtins.str] = None,
        backup_retention_days: typing.Optional[jsii.Number] = None,
        geo_redundant_backup: typing.Optional[builtins.str] = None,
    ) -> None:
        """
        :param storage_mb: 
        :param auto_grow: 
        :param backup_retention_days: 
        :param geo_redundant_backup: 
        """
        self._values: typing.Dict[str, typing.Any] = {
            "storage_mb": storage_mb,
        }
        if auto_grow is not None:
            self._values["auto_grow"] = auto_grow
        if backup_retention_days is not None:
            self._values["backup_retention_days"] = backup_retention_days
        if geo_redundant_backup is not None:
            self._values["geo_redundant_backup"] = geo_redundant_backup

    @builtins.property
    def storage_mb(self) -> jsii.Number:
        result = self._values.get("storage_mb")
        assert result is not None, "Required property 'storage_mb' is missing"
        return result

    @builtins.property
    def auto_grow(self) -> typing.Optional[builtins.str]:
        result = self._values.get("auto_grow")
        return result

    @builtins.property
    def backup_retention_days(self) -> typing.Optional[jsii.Number]:
        result = self._values.get("backup_retention_days")
        return result

    @builtins.property
    def geo_redundant_backup(self) -> typing.Optional[builtins.str]:
        result = self._values.get("geo_redundant_backup")
        return result

    def __eq__(self, rhs: typing.Any) -> builtins.bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs: typing.Any) -> builtins.bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return "MariadbServerStorageProfile(%s)" % ", ".join(
            k + "=" + repr(v) for k, v in self._values.items()
        )


@jsii.data_type(
    jsii_type="@cdktf/provider-azurerm.MariadbServerTimeouts",
    jsii_struct_bases=[],
    name_mapping={
        "create": "create",
        "delete": "delete",
        "read": "read",
        "update": "update",
    },
)
class MariadbServerTimeouts:
    def __init__(
        self,
        *,
        create: typing.Optional[builtins.str] = None,
        delete: typing.Optional[builtins.str] = None,
        read: typing.Optional[builtins.str] = None,
        update: typing.Optional[builtins.str] = None,
    ) -> None:
        """
        :param create: 
        :param delete: 
        :param read: 
        :param update: 
        """
        self._values: typing.Dict[str, typing.Any] = {}
        if create is not None:
            self._values["create"] = create
        if delete is not None:
            self._values["delete"] = delete
        if read is not None:
            self._values["read"] = read
        if update is not None:
            self._values["update"] = update

    @builtins.property
    def create(self) -> typing.Optional[builtins.str]:
        result = self._values.get("create")
        return result

    @builtins.property
    def delete(self) -> typing.Optional[builtins.str]:
        result = self._values.get("delete")
        return result

    @builtins.property
    def read(self) -> typing.Optional[builtins.str]:
        result = self._values.get("read")
        return result

    @builtins.property
    def update(self) -> typing.Optional[builtins.str]:
        result = self._values.get("update")
        return result

    def __eq__(self, rhs: typing.Any) -> builtins.bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs: typing.Any) -> builtins.bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return "MariadbServerTimeouts(%s)" % ", ".join(
            k + "=" + repr(v) for k, v in self._values.items()
        )


class MariadbVirtualNetworkRule(
    cdktf.TerraformResource,
    metaclass=jsii.JSIIMeta,
    jsii_type="@cdktf/provider-azurerm.MariadbVirtualNetworkRule",
):
    def __init__(
        self,
        scope: constructs.Construct,
        id: builtins.str,
        *,
        name: builtins.str,
        resource_group_name: builtins.str,
        server_name: builtins.str,
        subnet_id: builtins.str,
        timeouts: typing.Optional["MariadbVirtualNetworkRuleTimeouts"] = None,
        count: typing.Optional[jsii.Number] = None,
        depends_on: typing.Optional[typing.List[cdktf.TerraformResource]] = None,
        lifecycle: typing.Optional[cdktf.TerraformResourceLifecycle] = None,
        provider: typing.Optional[cdktf.TerraformProvider] = None,
    ) -> None:
        """
        :param scope: -
        :param id: -
        :param name: 
        :param resource_group_name: 
        :param server_name: 
        :param subnet_id: 
        :param timeouts: timeouts block.
        :param count: 
        :param depends_on: 
        :param lifecycle: 
        :param provider: 
        """
        config = MariadbVirtualNetworkRuleConfig(
            name=name,
            resource_group_name=resource_group_name,
            server_name=server_name,
            subnet_id=subnet_id,
            timeouts=timeouts,
            count=count,
            depends_on=depends_on,
            lifecycle=lifecycle,
            provider=provider,
        )

        jsii.create(MariadbVirtualNetworkRule, self, [scope, id, config])

    @jsii.member(jsii_name="synthesizeAttributes")
    def _synthesize_attributes(self) -> typing.Mapping[builtins.str, typing.Any]:
        return jsii.invoke(self, "synthesizeAttributes", [])

    @builtins.property # type: ignore
    @jsii.member(jsii_name="name")
    def name(self) -> builtins.str:
        return jsii.get(self, "name")

    @name.setter # type: ignore
    def name(self, value: builtins.str) -> None:
        jsii.set(self, "name", value)

    @builtins.property # type: ignore
    @jsii.member(jsii_name="resourceGroupName")
    def resource_group_name(self) -> builtins.str:
        return jsii.get(self, "resourceGroupName")

    @resource_group_name.setter # type: ignore
    def resource_group_name(self, value: builtins.str) -> None:
        jsii.set(self, "resourceGroupName", value)

    @builtins.property # type: ignore
    @jsii.member(jsii_name="serverName")
    def server_name(self) -> builtins.str:
        return jsii.get(self, "serverName")

    @server_name.setter # type: ignore
    def server_name(self, value: builtins.str) -> None:
        jsii.set(self, "serverName", value)

    @builtins.property # type: ignore
    @jsii.member(jsii_name="subnetId")
    def subnet_id(self) -> builtins.str:
        return jsii.get(self, "subnetId")

    @subnet_id.setter # type: ignore
    def subnet_id(self, value: builtins.str) -> None:
        jsii.set(self, "subnetId", value)

    @builtins.property # type: ignore
    @jsii.member(jsii_name="id")
    def id(self) -> typing.Optional[builtins.str]:
        return jsii.get(self, "id")

    @id.setter # type: ignore
    def id(self, value: typing.Optional[builtins.str]) -> None:
        jsii.set(self, "id", value)

    @builtins.property # type: ignore
    @jsii.member(jsii_name="timeouts")
    def timeouts(self) -> typing.Optional["MariadbVirtualNetworkRuleTimeouts"]:
        return jsii.get(self, "timeouts")

    @timeouts.setter # type: ignore
    def timeouts(
        self,
        value: typing.Optional["MariadbVirtualNetworkRuleTimeouts"],
    ) -> None:
        jsii.set(self, "timeouts", value)


@jsii.data_type(
    jsii_type="@cdktf/provider-azurerm.MariadbVirtualNetworkRuleConfig",
    jsii_struct_bases=[cdktf.TerraformMetaArguments],
    name_mapping={
        "count": "count",
        "depends_on": "dependsOn",
        "lifecycle": "lifecycle",
        "provider": "provider",
        "name": "name",
        "resource_group_name": "resourceGroupName",
        "server_name": "serverName",
        "subnet_id": "subnetId",
        "timeouts": "timeouts",
    },
)
class MariadbVirtualNetworkRuleConfig(cdktf.TerraformMetaArguments):
    def __init__(
        self,
        *,
        count: typing.Optional[jsii.Number] = None,
        depends_on: typing.Optional[typing.List[cdktf.TerraformResource]] = None,
        lifecycle: typing.Optional[cdktf.TerraformResourceLifecycle] = None,
        provider: typing.Optional[cdktf.TerraformProvider] = None,
        name: builtins.str,
        resource_group_name: builtins.str,
        server_name: builtins.str,
        subnet_id: builtins.str,
        timeouts: typing.Optional["MariadbVirtualNetworkRuleTimeouts"] = None,
    ) -> None:
        """
        :param count: 
        :param depends_on: 
        :param lifecycle: 
        :param provider: 
        :param name: 
        :param resource_group_name: 
        :param server_name: 
        :param subnet_id: 
        :param timeouts: timeouts block.
        """
        if isinstance(lifecycle, dict):
            lifecycle = cdktf.TerraformResourceLifecycle(**lifecycle)
        if isinstance(timeouts, dict):
            timeouts = MariadbVirtualNetworkRuleTimeouts(**timeouts)
        self._values: typing.Dict[str, typing.Any] = {
            "name": name,
            "resource_group_name": resource_group_name,
            "server_name": server_name,
            "subnet_id": subnet_id,
        }
        if count is not None:
            self._values["count"] = count
        if depends_on is not None:
            self._values["depends_on"] = depends_on
        if lifecycle is not None:
            self._values["lifecycle"] = lifecycle
        if provider is not None:
            self._values["provider"] = provider
        if timeouts is not None:
            self._values["timeouts"] = timeouts

    @builtins.property
    def count(self) -> typing.Optional[jsii.Number]:
        """
        :stability: experimental
        """
        result = self._values.get("count")
        return result

    @builtins.property
    def depends_on(self) -> typing.Optional[typing.List[cdktf.TerraformResource]]:
        """
        :stability: experimental
        """
        result = self._values.get("depends_on")
        return result

    @builtins.property
    def lifecycle(self) -> typing.Optional[cdktf.TerraformResourceLifecycle]:
        """
        :stability: experimental
        """
        result = self._values.get("lifecycle")
        return result

    @builtins.property
    def provider(self) -> typing.Optional[cdktf.TerraformProvider]:
        """
        :stability: experimental
        """
        result = self._values.get("provider")
        return result

    @builtins.property
    def name(self) -> builtins.str:
        result = self._values.get("name")
        assert result is not None, "Required property 'name' is missing"
        return result

    @builtins.property
    def resource_group_name(self) -> builtins.str:
        result = self._values.get("resource_group_name")
        assert result is not None, "Required property 'resource_group_name' is missing"
        return result

    @builtins.property
    def server_name(self) -> builtins.str:
        result = self._values.get("server_name")
        assert result is not None, "Required property 'server_name' is missing"
        return result

    @builtins.property
    def subnet_id(self) -> builtins.str:
        result = self._values.get("subnet_id")
        assert result is not None, "Required property 'subnet_id' is missing"
        return result

    @builtins.property
    def timeouts(self) -> typing.Optional["MariadbVirtualNetworkRuleTimeouts"]:
        """timeouts block."""
        result = self._values.get("timeouts")
        return result

    def __eq__(self, rhs: typing.Any) -> builtins.bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs: typing.Any) -> builtins.bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return "MariadbVirtualNetworkRuleConfig(%s)" % ", ".join(
            k + "=" + repr(v) for k, v in self._values.items()
        )


@jsii.data_type(
    jsii_type="@cdktf/provider-azurerm.MariadbVirtualNetworkRuleTimeouts",
    jsii_struct_bases=[],
    name_mapping={
        "create": "create",
        "delete": "delete",
        "read": "read",
        "update": "update",
    },
)
class MariadbVirtualNetworkRuleTimeouts:
    def __init__(
        self,
        *,
        create: typing.Optional[builtins.str] = None,
        delete: typing.Optional[builtins.str] = None,
        read: typing.Optional[builtins.str] = None,
        update: typing.Optional[builtins.str] = None,
    ) -> None:
        """
        :param create: 
        :param delete: 
        :param read: 
        :param update: 
        """
        self._values: typing.Dict[str, typing.Any] = {}
        if create is not None:
            self._values["create"] = create
        if delete is not None:
            self._values["delete"] = delete
        if read is not None:
            self._values["read"] = read
        if update is not None:
            self._values["update"] = update

    @builtins.property
    def create(self) -> typing.Optional[builtins.str]:
        result = self._values.get("create")
        return result

    @builtins.property
    def delete(self) -> typing.Optional[builtins.str]:
        result = self._values.get("delete")
        return result

    @builtins.property
    def read(self) -> typing.Optional[builtins.str]:
        result = self._values.get("read")
        return result

    @builtins.property
    def update(self) -> typing.Optional[builtins.str]:
        result = self._values.get("update")
        return result

    def __eq__(self, rhs: typing.Any) -> builtins.bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs: typing.Any) -> builtins.bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return "MariadbVirtualNetworkRuleTimeouts(%s)" % ", ".join(
            k + "=" + repr(v) for k, v in self._values.items()
        )


class MarketplaceAgreement(
    cdktf.TerraformResource,
    metaclass=jsii.JSIIMeta,
    jsii_type="@cdktf/provider-azurerm.MarketplaceAgreement",
):
    def __init__(
        self,
        scope: constructs.Construct,
        id: builtins.str,
        *,
        offer: builtins.str,
        plan: builtins.str,
        publisher: builtins.str,
        timeouts: typing.Optional["MarketplaceAgreementTimeouts"] = None,
        count: typing.Optional[jsii.Number] = None,
        depends_on: typing.Optional[typing.List[cdktf.TerraformResource]] = None,
        lifecycle: typing.Optional[cdktf.TerraformResourceLifecycle] = None,
        provider: typing.Optional[cdktf.TerraformProvider] = None,
    ) -> None:
        """
        :param scope: -
        :param id: -
        :param offer: 
        :param plan: 
        :param publisher: 
        :param timeouts: timeouts block.
        :param count: 
        :param depends_on: 
        :param lifecycle: 
        :param provider: 
        """
        config = MarketplaceAgreementConfig(
            offer=offer,
            plan=plan,
            publisher=publisher,
            timeouts=timeouts,
            count=count,
            depends_on=depends_on,
            lifecycle=lifecycle,
            provider=provider,
        )

        jsii.create(MarketplaceAgreement, self, [scope, id, config])

    @jsii.member(jsii_name="synthesizeAttributes")
    def _synthesize_attributes(self) -> typing.Mapping[builtins.str, typing.Any]:
        return jsii.invoke(self, "synthesizeAttributes", [])

    @builtins.property # type: ignore
    @jsii.member(jsii_name="licenseTextLink")
    def license_text_link(self) -> builtins.str:
        return jsii.get(self, "licenseTextLink")

    @builtins.property # type: ignore
    @jsii.member(jsii_name="privacyPolicyLink")
    def privacy_policy_link(self) -> builtins.str:
        return jsii.get(self, "privacyPolicyLink")

    @builtins.property # type: ignore
    @jsii.member(jsii_name="offer")
    def offer(self) -> builtins.str:
        return jsii.get(self, "offer")

    @offer.setter # type: ignore
    def offer(self, value: builtins.str) -> None:
        jsii.set(self, "offer", value)

    @builtins.property # type: ignore
    @jsii.member(jsii_name="plan")
    def plan(self) -> builtins.str:
        return jsii.get(self, "plan")

    @plan.setter # type: ignore
    def plan(self, value: builtins.str) -> None:
        jsii.set(self, "plan", value)

    @builtins.property # type: ignore
    @jsii.member(jsii_name="publisher")
    def publisher(self) -> builtins.str:
        return jsii.get(self, "publisher")

    @publisher.setter # type: ignore
    def publisher(self, value: builtins.str) -> None:
        jsii.set(self, "publisher", value)

    @builtins.property # type: ignore
    @jsii.member(jsii_name="id")
    def id(self) -> typing.Optional[builtins.str]:
        return jsii.get(self, "id")

    @id.setter # type: ignore
    def id(self, value: typing.Optional[builtins.str]) -> None:
        jsii.set(self, "id", value)

    @builtins.property # type: ignore
    @jsii.member(jsii_name="timeouts")
    def timeouts(self) -> typing.Optional["MarketplaceAgreementTimeouts"]:
        return jsii.get(self, "timeouts")

    @timeouts.setter # type: ignore
    def timeouts(self, value: typing.Optional["MarketplaceAgreementTimeouts"]) -> None:
        jsii.set(self, "timeouts", value)


@jsii.data_type(
    jsii_type="@cdktf/provider-azurerm.MarketplaceAgreementConfig",
    jsii_struct_bases=[cdktf.TerraformMetaArguments],
    name_mapping={
        "count": "count",
        "depends_on": "dependsOn",
        "lifecycle": "lifecycle",
        "provider": "provider",
        "offer": "offer",
        "plan": "plan",
        "publisher": "publisher",
        "timeouts": "timeouts",
    },
)
class MarketplaceAgreementConfig(cdktf.TerraformMetaArguments):
    def __init__(
        self,
        *,
        count: typing.Optional[jsii.Number] = None,
        depends_on: typing.Optional[typing.List[cdktf.TerraformResource]] = None,
        lifecycle: typing.Optional[cdktf.TerraformResourceLifecycle] = None,
        provider: typing.Optional[cdktf.TerraformProvider] = None,
        offer: builtins.str,
        plan: builtins.str,
        publisher: builtins.str,
        timeouts: typing.Optional["MarketplaceAgreementTimeouts"] = None,
    ) -> None:
        """
        :param count: 
        :param depends_on: 
        :param lifecycle: 
        :param provider: 
        :param offer: 
        :param plan: 
        :param publisher: 
        :param timeouts: timeouts block.
        """
        if isinstance(lifecycle, dict):
            lifecycle = cdktf.TerraformResourceLifecycle(**lifecycle)
        if isinstance(timeouts, dict):
            timeouts = MarketplaceAgreementTimeouts(**timeouts)
        self._values: typing.Dict[str, typing.Any] = {
            "offer": offer,
            "plan": plan,
            "publisher": publisher,
        }
        if count is not None:
            self._values["count"] = count
        if depends_on is not None:
            self._values["depends_on"] = depends_on
        if lifecycle is not None:
            self._values["lifecycle"] = lifecycle
        if provider is not None:
            self._values["provider"] = provider
        if timeouts is not None:
            self._values["timeouts"] = timeouts

    @builtins.property
    def count(self) -> typing.Optional[jsii.Number]:
        """
        :stability: experimental
        """
        result = self._values.get("count")
        return result

    @builtins.property
    def depends_on(self) -> typing.Optional[typing.List[cdktf.TerraformResource]]:
        """
        :stability: experimental
        """
        result = self._values.get("depends_on")
        return result

    @builtins.property
    def lifecycle(self) -> typing.Optional[cdktf.TerraformResourceLifecycle]:
        """
        :stability: experimental
        """
        result = self._values.get("lifecycle")
        return result

    @builtins.property
    def provider(self) -> typing.Optional[cdktf.TerraformProvider]:
        """
        :stability: experimental
        """
        result = self._values.get("provider")
        return result

    @builtins.property
    def offer(self) -> builtins.str:
        result = self._values.get("offer")
        assert result is not None, "Required property 'offer' is missing"
        return result

    @builtins.property
    def plan(self) -> builtins.str:
        result = self._values.get("plan")
        assert result is not None, "Required property 'plan' is missing"
        return result

    @builtins.property
    def publisher(self) -> builtins.str:
        result = self._values.get("publisher")
        assert result is not None, "Required property 'publisher' is missing"
        return result

    @builtins.property
    def timeouts(self) -> typing.Optional["MarketplaceAgreementTimeouts"]:
        """timeouts block."""
        result = self._values.get("timeouts")
        return result

    def __eq__(self, rhs: typing.Any) -> builtins.bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs: typing.Any) -> builtins.bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return "MarketplaceAgreementConfig(%s)" % ", ".join(
            k + "=" + repr(v) for k, v in self._values.items()
        )


@jsii.data_type(
    jsii_type="@cdktf/provider-azurerm.MarketplaceAgreementTimeouts",
    jsii_struct_bases=[],
    name_mapping={
        "create": "create",
        "delete": "delete",
        "read": "read",
        "update": "update",
    },
)
class MarketplaceAgreementTimeouts:
    def __init__(
        self,
        *,
        create: typing.Optional[builtins.str] = None,
        delete: typing.Optional[builtins.str] = None,
        read: typing.Optional[builtins.str] = None,
        update: typing.Optional[builtins.str] = None,
    ) -> None:
        """
        :param create: 
        :param delete: 
        :param read: 
        :param update: 
        """
        self._values: typing.Dict[str, typing.Any] = {}
        if create is not None:
            self._values["create"] = create
        if delete is not None:
            self._values["delete"] = delete
        if read is not None:
            self._values["read"] = read
        if update is not None:
            self._values["update"] = update

    @builtins.property
    def create(self) -> typing.Optional[builtins.str]:
        result = self._values.get("create")
        return result

    @builtins.property
    def delete(self) -> typing.Optional[builtins.str]:
        result = self._values.get("delete")
        return result

    @builtins.property
    def read(self) -> typing.Optional[builtins.str]:
        result = self._values.get("read")
        return result

    @builtins.property
    def update(self) -> typing.Optional[builtins.str]:
        result = self._values.get("update")
        return result

    def __eq__(self, rhs: typing.Any) -> builtins.bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs: typing.Any) -> builtins.bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return "MarketplaceAgreementTimeouts(%s)" % ", ".join(
            k + "=" + repr(v) for k, v in self._values.items()
        )


class MediaServicesAccount(
    cdktf.TerraformResource,
    metaclass=jsii.JSIIMeta,
    jsii_type="@cdktf/provider-azurerm.MediaServicesAccount",
):
    def __init__(
        self,
        scope: constructs.Construct,
        id: builtins.str,
        *,
        location: builtins.str,
        name: builtins.str,
        resource_group_name: builtins.str,
        storage_account: typing.List["MediaServicesAccountStorageAccount"],
        timeouts: typing.Optional["MediaServicesAccountTimeouts"] = None,
        count: typing.Optional[jsii.Number] = None,
        depends_on: typing.Optional[typing.List[cdktf.TerraformResource]] = None,
        lifecycle: typing.Optional[cdktf.TerraformResourceLifecycle] = None,
        provider: typing.Optional[cdktf.TerraformProvider] = None,
    ) -> None:
        """
        :param scope: -
        :param id: -
        :param location: 
        :param name: 
        :param resource_group_name: 
        :param storage_account: storage_account block.
        :param timeouts: timeouts block.
        :param count: 
        :param depends_on: 
        :param lifecycle: 
        :param provider: 
        """
        config = MediaServicesAccountConfig(
            location=location,
            name=name,
            resource_group_name=resource_group_name,
            storage_account=storage_account,
            timeouts=timeouts,
            count=count,
            depends_on=depends_on,
            lifecycle=lifecycle,
            provider=provider,
        )

        jsii.create(MediaServicesAccount, self, [scope, id, config])

    @jsii.member(jsii_name="synthesizeAttributes")
    def _synthesize_attributes(self) -> typing.Mapping[builtins.str, typing.Any]:
        return jsii.invoke(self, "synthesizeAttributes", [])

    @builtins.property # type: ignore
    @jsii.member(jsii_name="location")
    def location(self) -> builtins.str:
        return jsii.get(self, "location")

    @location.setter # type: ignore
    def location(self, value: builtins.str) -> None:
        jsii.set(self, "location", value)

    @builtins.property # type: ignore
    @jsii.member(jsii_name="name")
    def name(self) -> builtins.str:
        return jsii.get(self, "name")

    @name.setter # type: ignore
    def name(self, value: builtins.str) -> None:
        jsii.set(self, "name", value)

    @builtins.property # type: ignore
    @jsii.member(jsii_name="resourceGroupName")
    def resource_group_name(self) -> builtins.str:
        return jsii.get(self, "resourceGroupName")

    @resource_group_name.setter # type: ignore
    def resource_group_name(self, value: builtins.str) -> None:
        jsii.set(self, "resourceGroupName", value)

    @builtins.property # type: ignore
    @jsii.member(jsii_name="storageAccount")
    def storage_account(self) -> typing.List["MediaServicesAccountStorageAccount"]:
        return jsii.get(self, "storageAccount")

    @storage_account.setter # type: ignore
    def storage_account(
        self,
        value: typing.List["MediaServicesAccountStorageAccount"],
    ) -> None:
        jsii.set(self, "storageAccount", value)

    @builtins.property # type: ignore
    @jsii.member(jsii_name="id")
    def id(self) -> typing.Optional[builtins.str]:
        return jsii.get(self, "id")

    @id.setter # type: ignore
    def id(self, value: typing.Optional[builtins.str]) -> None:
        jsii.set(self, "id", value)

    @builtins.property # type: ignore
    @jsii.member(jsii_name="timeouts")
    def timeouts(self) -> typing.Optional["MediaServicesAccountTimeouts"]:
        return jsii.get(self, "timeouts")

    @timeouts.setter # type: ignore
    def timeouts(self, value: typing.Optional["MediaServicesAccountTimeouts"]) -> None:
        jsii.set(self, "timeouts", value)


@jsii.data_type(
    jsii_type="@cdktf/provider-azurerm.MediaServicesAccountConfig",
    jsii_struct_bases=[cdktf.TerraformMetaArguments],
    name_mapping={
        "count": "count",
        "depends_on": "dependsOn",
        "lifecycle": "lifecycle",
        "provider": "provider",
        "location": "location",
        "name": "name",
        "resource_group_name": "resourceGroupName",
        "storage_account": "storageAccount",
        "timeouts": "timeouts",
    },
)
class MediaServicesAccountConfig(cdktf.TerraformMetaArguments):
    def __init__(
        self,
        *,
        count: typing.Optional[jsii.Number] = None,
        depends_on: typing.Optional[typing.List[cdktf.TerraformResource]] = None,
        lifecycle: typing.Optional[cdktf.TerraformResourceLifecycle] = None,
        provider: typing.Optional[cdktf.TerraformProvider] = None,
        location: builtins.str,
        name: builtins.str,
        resource_group_name: builtins.str,
        storage_account: typing.List["MediaServicesAccountStorageAccount"],
        timeouts: typing.Optional["MediaServicesAccountTimeouts"] = None,
    ) -> None:
        """
        :param count: 
        :param depends_on: 
        :param lifecycle: 
        :param provider: 
        :param location: 
        :param name: 
        :param resource_group_name: 
        :param storage_account: storage_account block.
        :param timeouts: timeouts block.
        """
        if isinstance(lifecycle, dict):
            lifecycle = cdktf.TerraformResourceLifecycle(**lifecycle)
        if isinstance(timeouts, dict):
            timeouts = MediaServicesAccountTimeouts(**timeouts)
        self._values: typing.Dict[str, typing.Any] = {
            "location": location,
            "name": name,
            "resource_group_name": resource_group_name,
            "storage_account": storage_account,
        }
        if count is not None:
            self._values["count"] = count
        if depends_on is not None:
            self._values["depends_on"] = depends_on
        if lifecycle is not None:
            self._values["lifecycle"] = lifecycle
        if provider is not None:
            self._values["provider"] = provider
        if timeouts is not None:
            self._values["timeouts"] = timeouts

    @builtins.property
    def count(self) -> typing.Optional[jsii.Number]:
        """
        :stability: experimental
        """
        result = self._values.get("count")
        return result

    @builtins.property
    def depends_on(self) -> typing.Optional[typing.List[cdktf.TerraformResource]]:
        """
        :stability: experimental
        """
        result = self._values.get("depends_on")
        return result

    @builtins.property
    def lifecycle(self) -> typing.Optional[cdktf.TerraformResourceLifecycle]:
        """
        :stability: experimental
        """
        result = self._values.get("lifecycle")
        return result

    @builtins.property
    def provider(self) -> typing.Optional[cdktf.TerraformProvider]:
        """
        :stability: experimental
        """
        result = self._values.get("provider")
        return result

    @builtins.property
    def location(self) -> builtins.str:
        result = self._values.get("location")
        assert result is not None, "Required property 'location' is missing"
        return result

    @builtins.property
    def name(self) -> builtins.str:
        result = self._values.get("name")
        assert result is not None, "Required property 'name' is missing"
        return result

    @builtins.property
    def resource_group_name(self) -> builtins.str:
        result = self._values.get("resource_group_name")
        assert result is not None, "Required property 'resource_group_name' is missing"
        return result

    @builtins.property
    def storage_account(self) -> typing.List["MediaServicesAccountStorageAccount"]:
        """storage_account block."""
        result = self._values.get("storage_account")
        assert result is not None, "Required property 'storage_account' is missing"
        return result

    @builtins.property
    def timeouts(self) -> typing.Optional["MediaServicesAccountTimeouts"]:
        """timeouts block."""
        result = self._values.get("timeouts")
        return result

    def __eq__(self, rhs: typing.Any) -> builtins.bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs: typing.Any) -> builtins.bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return "MediaServicesAccountConfig(%s)" % ", ".join(
            k + "=" + repr(v) for k, v in self._values.items()
        )


@jsii.data_type(
    jsii_type="@cdktf/provider-azurerm.MediaServicesAccountStorageAccount",
    jsii_struct_bases=[],
    name_mapping={"id": "id", "is_primary": "isPrimary"},
)
class MediaServicesAccountStorageAccount:
    def __init__(
        self,
        *,
        id: builtins.str,
        is_primary: typing.Optional[builtins.bool] = None,
    ) -> None:
        """
        :param id: 
        :param is_primary: 
        """
        self._values: typing.Dict[str, typing.Any] = {
            "id": id,
        }
        if is_primary is not None:
            self._values["is_primary"] = is_primary

    @builtins.property
    def id(self) -> builtins.str:
        result = self._values.get("id")
        assert result is not None, "Required property 'id' is missing"
        return result

    @builtins.property
    def is_primary(self) -> typing.Optional[builtins.bool]:
        result = self._values.get("is_primary")
        return result

    def __eq__(self, rhs: typing.Any) -> builtins.bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs: typing.Any) -> builtins.bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return "MediaServicesAccountStorageAccount(%s)" % ", ".join(
            k + "=" + repr(v) for k, v in self._values.items()
        )


@jsii.data_type(
    jsii_type="@cdktf/provider-azurerm.MediaServicesAccountTimeouts",
    jsii_struct_bases=[],
    name_mapping={
        "create": "create",
        "delete": "delete",
        "read": "read",
        "update": "update",
    },
)
class MediaServicesAccountTimeouts:
    def __init__(
        self,
        *,
        create: typing.Optional[builtins.str] = None,
        delete: typing.Optional[builtins.str] = None,
        read: typing.Optional[builtins.str] = None,
        update: typing.Optional[builtins.str] = None,
    ) -> None:
        """
        :param create: 
        :param delete: 
        :param read: 
        :param update: 
        """
        self._values: typing.Dict[str, typing.Any] = {}
        if create is not None:
            self._values["create"] = create
        if delete is not None:
            self._values["delete"] = delete
        if read is not None:
            self._values["read"] = read
        if update is not None:
            self._values["update"] = update

    @builtins.property
    def create(self) -> typing.Optional[builtins.str]:
        result = self._values.get("create")
        return result

    @builtins.property
    def delete(self) -> typing.Optional[builtins.str]:
        result = self._values.get("delete")
        return result

    @builtins.property
    def read(self) -> typing.Optional[builtins.str]:
        result = self._values.get("read")
        return result

    @builtins.property
    def update(self) -> typing.Optional[builtins.str]:
        result = self._values.get("update")
        return result

    def __eq__(self, rhs: typing.Any) -> builtins.bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs: typing.Any) -> builtins.bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return "MediaServicesAccountTimeouts(%s)" % ", ".join(
            k + "=" + repr(v) for k, v in self._values.items()
        )


class MonitorActionGroup(
    cdktf.TerraformResource,
    metaclass=jsii.JSIIMeta,
    jsii_type="@cdktf/provider-azurerm.MonitorActionGroup",
):
    def __init__(
        self,
        scope: constructs.Construct,
        id: builtins.str,
        *,
        name: builtins.str,
        resource_group_name: builtins.str,
        short_name: builtins.str,
        arm_role_receiver: typing.Optional[typing.List["MonitorActionGroupArmRoleReceiver"]] = None,
        automation_runbook_receiver: typing.Optional[typing.List["MonitorActionGroupAutomationRunbookReceiver"]] = None,
        azure_app_push_receiver: typing.Optional[typing.List["MonitorActionGroupAzureAppPushReceiver"]] = None,
        azure_function_receiver: typing.Optional[typing.List["MonitorActionGroupAzureFunctionReceiver"]] = None,
        email_receiver: typing.Optional[typing.List["MonitorActionGroupEmailReceiver"]] = None,
        enabled: typing.Optional[builtins.bool] = None,
        itsm_receiver: typing.Optional[typing.List["MonitorActionGroupItsmReceiver"]] = None,
        logic_app_receiver: typing.Optional[typing.List["MonitorActionGroupLogicAppReceiver"]] = None,
        sms_receiver: typing.Optional[typing.List["MonitorActionGroupSmsReceiver"]] = None,
        tags: typing.Optional[typing.Mapping[builtins.str, builtins.str]] = None,
        timeouts: typing.Optional["MonitorActionGroupTimeouts"] = None,
        voice_receiver: typing.Optional[typing.List["MonitorActionGroupVoiceReceiver"]] = None,
        webhook_receiver: typing.Optional[typing.List["MonitorActionGroupWebhookReceiver"]] = None,
        count: typing.Optional[jsii.Number] = None,
        depends_on: typing.Optional[typing.List[cdktf.TerraformResource]] = None,
        lifecycle: typing.Optional[cdktf.TerraformResourceLifecycle] = None,
        provider: typing.Optional[cdktf.TerraformProvider] = None,
    ) -> None:
        """
        :param scope: -
        :param id: -
        :param name: 
        :param resource_group_name: 
        :param short_name: 
        :param arm_role_receiver: arm_role_receiver block.
        :param automation_runbook_receiver: automation_runbook_receiver block.
        :param azure_app_push_receiver: azure_app_push_receiver block.
        :param azure_function_receiver: azure_function_receiver block.
        :param email_receiver: email_receiver block.
        :param enabled: 
        :param itsm_receiver: itsm_receiver block.
        :param logic_app_receiver: logic_app_receiver block.
        :param sms_receiver: sms_receiver block.
        :param tags: 
        :param timeouts: timeouts block.
        :param voice_receiver: voice_receiver block.
        :param webhook_receiver: webhook_receiver block.
        :param count: 
        :param depends_on: 
        :param lifecycle: 
        :param provider: 
        """
        config = MonitorActionGroupConfig(
            name=name,
            resource_group_name=resource_group_name,
            short_name=short_name,
            arm_role_receiver=arm_role_receiver,
            automation_runbook_receiver=automation_runbook_receiver,
            azure_app_push_receiver=azure_app_push_receiver,
            azure_function_receiver=azure_function_receiver,
            email_receiver=email_receiver,
            enabled=enabled,
            itsm_receiver=itsm_receiver,
            logic_app_receiver=logic_app_receiver,
            sms_receiver=sms_receiver,
            tags=tags,
            timeouts=timeouts,
            voice_receiver=voice_receiver,
            webhook_receiver=webhook_receiver,
            count=count,
            depends_on=depends_on,
            lifecycle=lifecycle,
            provider=provider,
        )

        jsii.create(MonitorActionGroup, self, [scope, id, config])

    @jsii.member(jsii_name="synthesizeAttributes")
    def _synthesize_attributes(self) -> typing.Mapping[builtins.str, typing.Any]:
        return jsii.invoke(self, "synthesizeAttributes", [])

    @builtins.property # type: ignore
    @jsii.member(jsii_name="name")
    def name(self) -> builtins.str:
        return jsii.get(self, "name")

    @name.setter # type: ignore
    def name(self, value: builtins.str) -> None:
        jsii.set(self, "name", value)

    @builtins.property # type: ignore
    @jsii.member(jsii_name="resourceGroupName")
    def resource_group_name(self) -> builtins.str:
        return jsii.get(self, "resourceGroupName")

    @resource_group_name.setter # type: ignore
    def resource_group_name(self, value: builtins.str) -> None:
        jsii.set(self, "resourceGroupName", value)

    @builtins.property # type: ignore
    @jsii.member(jsii_name="shortName")
    def short_name(self) -> builtins.str:
        return jsii.get(self, "shortName")

    @short_name.setter # type: ignore
    def short_name(self, value: builtins.str) -> None:
        jsii.set(self, "shortName", value)

    @builtins.property # type: ignore
    @jsii.member(jsii_name="armRoleReceiver")
    def arm_role_receiver(
        self,
    ) -> typing.Optional[typing.List["MonitorActionGroupArmRoleReceiver"]]:
        return jsii.get(self, "armRoleReceiver")

    @arm_role_receiver.setter # type: ignore
    def arm_role_receiver(
        self,
        value: typing.Optional[typing.List["MonitorActionGroupArmRoleReceiver"]],
    ) -> None:
        jsii.set(self, "armRoleReceiver", value)

    @builtins.property # type: ignore
    @jsii.member(jsii_name="automationRunbookReceiver")
    def automation_runbook_receiver(
        self,
    ) -> typing.Optional[typing.List["MonitorActionGroupAutomationRunbookReceiver"]]:
        return jsii.get(self, "automationRunbookReceiver")

    @automation_runbook_receiver.setter # type: ignore
    def automation_runbook_receiver(
        self,
        value: typing.Optional[typing.List["MonitorActionGroupAutomationRunbookReceiver"]],
    ) -> None:
        jsii.set(self, "automationRunbookReceiver", value)

    @builtins.property # type: ignore
    @jsii.member(jsii_name="azureAppPushReceiver")
    def azure_app_push_receiver(
        self,
    ) -> typing.Optional[typing.List["MonitorActionGroupAzureAppPushReceiver"]]:
        return jsii.get(self, "azureAppPushReceiver")

    @azure_app_push_receiver.setter # type: ignore
    def azure_app_push_receiver(
        self,
        value: typing.Optional[typing.List["MonitorActionGroupAzureAppPushReceiver"]],
    ) -> None:
        jsii.set(self, "azureAppPushReceiver", value)

    @builtins.property # type: ignore
    @jsii.member(jsii_name="azureFunctionReceiver")
    def azure_function_receiver(
        self,
    ) -> typing.Optional[typing.List["MonitorActionGroupAzureFunctionReceiver"]]:
        return jsii.get(self, "azureFunctionReceiver")

    @azure_function_receiver.setter # type: ignore
    def azure_function_receiver(
        self,
        value: typing.Optional[typing.List["MonitorActionGroupAzureFunctionReceiver"]],
    ) -> None:
        jsii.set(self, "azureFunctionReceiver", value)

    @builtins.property # type: ignore
    @jsii.member(jsii_name="emailReceiver")
    def email_receiver(
        self,
    ) -> typing.Optional[typing.List["MonitorActionGroupEmailReceiver"]]:
        return jsii.get(self, "emailReceiver")

    @email_receiver.setter # type: ignore
    def email_receiver(
        self,
        value: typing.Optional[typing.List["MonitorActionGroupEmailReceiver"]],
    ) -> None:
        jsii.set(self, "emailReceiver", value)

    @builtins.property # type: ignore
    @jsii.member(jsii_name="enabled")
    def enabled(self) -> typing.Optional[builtins.bool]:
        return jsii.get(self, "enabled")

    @enabled.setter # type: ignore
    def enabled(self, value: typing.Optional[builtins.bool]) -> None:
        jsii.set(self, "enabled", value)

    @builtins.property # type: ignore
    @jsii.member(jsii_name="id")
    def id(self) -> typing.Optional[builtins.str]:
        return jsii.get(self, "id")

    @id.setter # type: ignore
    def id(self, value: typing.Optional[builtins.str]) -> None:
        jsii.set(self, "id", value)

    @builtins.property # type: ignore
    @jsii.member(jsii_name="itsmReceiver")
    def itsm_receiver(
        self,
    ) -> typing.Optional[typing.List["MonitorActionGroupItsmReceiver"]]:
        return jsii.get(self, "itsmReceiver")

    @itsm_receiver.setter # type: ignore
    def itsm_receiver(
        self,
        value: typing.Optional[typing.List["MonitorActionGroupItsmReceiver"]],
    ) -> None:
        jsii.set(self, "itsmReceiver", value)

    @builtins.property # type: ignore
    @jsii.member(jsii_name="logicAppReceiver")
    def logic_app_receiver(
        self,
    ) -> typing.Optional[typing.List["MonitorActionGroupLogicAppReceiver"]]:
        return jsii.get(self, "logicAppReceiver")

    @logic_app_receiver.setter # type: ignore
    def logic_app_receiver(
        self,
        value: typing.Optional[typing.List["MonitorActionGroupLogicAppReceiver"]],
    ) -> None:
        jsii.set(self, "logicAppReceiver", value)

    @builtins.property # type: ignore
    @jsii.member(jsii_name="smsReceiver")
    def sms_receiver(
        self,
    ) -> typing.Optional[typing.List["MonitorActionGroupSmsReceiver"]]:
        return jsii.get(self, "smsReceiver")

    @sms_receiver.setter # type: ignore
    def sms_receiver(
        self,
        value: typing.Optional[typing.List["MonitorActionGroupSmsReceiver"]],
    ) -> None:
        jsii.set(self, "smsReceiver", value)

    @builtins.property # type: ignore
    @jsii.member(jsii_name="tags")
    def tags(self) -> typing.Optional[typing.Mapping[builtins.str, builtins.str]]:
        return jsii.get(self, "tags")

    @tags.setter # type: ignore
    def tags(
        self,
        value: typing.Optional[typing.Mapping[builtins.str, builtins.str]],
    ) -> None:
        jsii.set(self, "tags", value)

    @builtins.property # type: ignore
    @jsii.member(jsii_name="timeouts")
    def timeouts(self) -> typing.Optional["MonitorActionGroupTimeouts"]:
        return jsii.get(self, "timeouts")

    @timeouts.setter # type: ignore
    def timeouts(self, value: typing.Optional["MonitorActionGroupTimeouts"]) -> None:
        jsii.set(self, "timeouts", value)

    @builtins.property # type: ignore
    @jsii.member(jsii_name="voiceReceiver")
    def voice_receiver(
        self,
    ) -> typing.Optional[typing.List["MonitorActionGroupVoiceReceiver"]]:
        return jsii.get(self, "voiceReceiver")

    @voice_receiver.setter # type: ignore
    def voice_receiver(
        self,
        value: typing.Optional[typing.List["MonitorActionGroupVoiceReceiver"]],
    ) -> None:
        jsii.set(self, "voiceReceiver", value)

    @builtins.property # type: ignore
    @jsii.member(jsii_name="webhookReceiver")
    def webhook_receiver(
        self,
    ) -> typing.Optional[typing.List["MonitorActionGroupWebhookReceiver"]]:
        return jsii.get(self, "webhookReceiver")

    @webhook_receiver.setter # type: ignore
    def webhook_receiver(
        self,
        value: typing.Optional[typing.List["MonitorActionGroupWebhookReceiver"]],
    ) -> None:
        jsii.set(self, "webhookReceiver", value)


@jsii.data_type(
    jsii_type="@cdktf/provider-azurerm.MonitorActionGroupArmRoleReceiver",
    jsii_struct_bases=[],
    name_mapping={
        "name": "name",
        "role_id": "roleId",
        "use_common_alert_schema": "useCommonAlertSchema",
    },
)
class MonitorActionGroupArmRoleReceiver:
    def __init__(
        self,
        *,
        name: builtins.str,
        role_id: builtins.str,
        use_common_alert_schema: typing.Optional[builtins.bool] = None,
    ) -> None:
        """
        :param name: 
        :param role_id: 
        :param use_common_alert_schema: 
        """
        self._values: typing.Dict[str, typing.Any] = {
            "name": name,
            "role_id": role_id,
        }
        if use_common_alert_schema is not None:
            self._values["use_common_alert_schema"] = use_common_alert_schema

    @builtins.property
    def name(self) -> builtins.str:
        result = self._values.get("name")
        assert result is not None, "Required property 'name' is missing"
        return result

    @builtins.property
    def role_id(self) -> builtins.str:
        result = self._values.get("role_id")
        assert result is not None, "Required property 'role_id' is missing"
        return result

    @builtins.property
    def use_common_alert_schema(self) -> typing.Optional[builtins.bool]:
        result = self._values.get("use_common_alert_schema")
        return result

    def __eq__(self, rhs: typing.Any) -> builtins.bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs: typing.Any) -> builtins.bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return "MonitorActionGroupArmRoleReceiver(%s)" % ", ".join(
            k + "=" + repr(v) for k, v in self._values.items()
        )


@jsii.data_type(
    jsii_type="@cdktf/provider-azurerm.MonitorActionGroupAutomationRunbookReceiver",
    jsii_struct_bases=[],
    name_mapping={
        "automation_account_id": "automationAccountId",
        "is_global_runbook": "isGlobalRunbook",
        "name": "name",
        "runbook_name": "runbookName",
        "service_uri": "serviceUri",
        "webhook_resource_id": "webhookResourceId",
        "use_common_alert_schema": "useCommonAlertSchema",
    },
)
class MonitorActionGroupAutomationRunbookReceiver:
    def __init__(
        self,
        *,
        automation_account_id: builtins.str,
        is_global_runbook: builtins.bool,
        name: builtins.str,
        runbook_name: builtins.str,
        service_uri: builtins.str,
        webhook_resource_id: builtins.str,
        use_common_alert_schema: typing.Optional[builtins.bool] = None,
    ) -> None:
        """
        :param automation_account_id: 
        :param is_global_runbook: 
        :param name: 
        :param runbook_name: 
        :param service_uri: 
        :param webhook_resource_id: 
        :param use_common_alert_schema: 
        """
        self._values: typing.Dict[str, typing.Any] = {
            "automation_account_id": automation_account_id,
            "is_global_runbook": is_global_runbook,
            "name": name,
            "runbook_name": runbook_name,
            "service_uri": service_uri,
            "webhook_resource_id": webhook_resource_id,
        }
        if use_common_alert_schema is not None:
            self._values["use_common_alert_schema"] = use_common_alert_schema

    @builtins.property
    def automation_account_id(self) -> builtins.str:
        result = self._values.get("automation_account_id")
        assert result is not None, "Required property 'automation_account_id' is missing"
        return result

    @builtins.property
    def is_global_runbook(self) -> builtins.bool:
        result = self._values.get("is_global_runbook")
        assert result is not None, "Required property 'is_global_runbook' is missing"
        return result

    @builtins.property
    def name(self) -> builtins.str:
        result = self._values.get("name")
        assert result is not None, "Required property 'name' is missing"
        return result

    @builtins.property
    def runbook_name(self) -> builtins.str:
        result = self._values.get("runbook_name")
        assert result is not None, "Required property 'runbook_name' is missing"
        return result

    @builtins.property
    def service_uri(self) -> builtins.str:
        result = self._values.get("service_uri")
        assert result is not None, "Required property 'service_uri' is missing"
        return result

    @builtins.property
    def webhook_resource_id(self) -> builtins.str:
        result = self._values.get("webhook_resource_id")
        assert result is not None, "Required property 'webhook_resource_id' is missing"
        return result

    @builtins.property
    def use_common_alert_schema(self) -> typing.Optional[builtins.bool]:
        result = self._values.get("use_common_alert_schema")
        return result

    def __eq__(self, rhs: typing.Any) -> builtins.bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs: typing.Any) -> builtins.bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return "MonitorActionGroupAutomationRunbookReceiver(%s)" % ", ".join(
            k + "=" + repr(v) for k, v in self._values.items()
        )


@jsii.data_type(
    jsii_type="@cdktf/provider-azurerm.MonitorActionGroupAzureAppPushReceiver",
    jsii_struct_bases=[],
    name_mapping={"email_address": "emailAddress", "name": "name"},
)
class MonitorActionGroupAzureAppPushReceiver:
    def __init__(self, *, email_address: builtins.str, name: builtins.str) -> None:
        """
        :param email_address: 
        :param name: 
        """
        self._values: typing.Dict[str, typing.Any] = {
            "email_address": email_address,
            "name": name,
        }

    @builtins.property
    def email_address(self) -> builtins.str:
        result = self._values.get("email_address")
        assert result is not None, "Required property 'email_address' is missing"
        return result

    @builtins.property
    def name(self) -> builtins.str:
        result = self._values.get("name")
        assert result is not None, "Required property 'name' is missing"
        return result

    def __eq__(self, rhs: typing.Any) -> builtins.bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs: typing.Any) -> builtins.bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return "MonitorActionGroupAzureAppPushReceiver(%s)" % ", ".join(
            k + "=" + repr(v) for k, v in self._values.items()
        )


@jsii.data_type(
    jsii_type="@cdktf/provider-azurerm.MonitorActionGroupAzureFunctionReceiver",
    jsii_struct_bases=[],
    name_mapping={
        "function_app_resource_id": "functionAppResourceId",
        "function_name": "functionName",
        "http_trigger_url": "httpTriggerUrl",
        "name": "name",
        "use_common_alert_schema": "useCommonAlertSchema",
    },
)
class MonitorActionGroupAzureFunctionReceiver:
    def __init__(
        self,
        *,
        function_app_resource_id: builtins.str,
        function_name: builtins.str,
        http_trigger_url: builtins.str,
        name: builtins.str,
        use_common_alert_schema: typing.Optional[builtins.bool] = None,
    ) -> None:
        """
        :param function_app_resource_id: 
        :param function_name: 
        :param http_trigger_url: 
        :param name: 
        :param use_common_alert_schema: 
        """
        self._values: typing.Dict[str, typing.Any] = {
            "function_app_resource_id": function_app_resource_id,
            "function_name": function_name,
            "http_trigger_url": http_trigger_url,
            "name": name,
        }
        if use_common_alert_schema is not None:
            self._values["use_common_alert_schema"] = use_common_alert_schema

    @builtins.property
    def function_app_resource_id(self) -> builtins.str:
        result = self._values.get("function_app_resource_id")
        assert result is not None, "Required property 'function_app_resource_id' is missing"
        return result

    @builtins.property
    def function_name(self) -> builtins.str:
        result = self._values.get("function_name")
        assert result is not None, "Required property 'function_name' is missing"
        return result

    @builtins.property
    def http_trigger_url(self) -> builtins.str:
        result = self._values.get("http_trigger_url")
        assert result is not None, "Required property 'http_trigger_url' is missing"
        return result

    @builtins.property
    def name(self) -> builtins.str:
        result = self._values.get("name")
        assert result is not None, "Required property 'name' is missing"
        return result

    @builtins.property
    def use_common_alert_schema(self) -> typing.Optional[builtins.bool]:
        result = self._values.get("use_common_alert_schema")
        return result

    def __eq__(self, rhs: typing.Any) -> builtins.bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs: typing.Any) -> builtins.bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return "MonitorActionGroupAzureFunctionReceiver(%s)" % ", ".join(
            k + "=" + repr(v) for k, v in self._values.items()
        )


@jsii.data_type(
    jsii_type="@cdktf/provider-azurerm.MonitorActionGroupConfig",
    jsii_struct_bases=[cdktf.TerraformMetaArguments],
    name_mapping={
        "count": "count",
        "depends_on": "dependsOn",
        "lifecycle": "lifecycle",
        "provider": "provider",
        "name": "name",
        "resource_group_name": "resourceGroupName",
        "short_name": "shortName",
        "arm_role_receiver": "armRoleReceiver",
        "automation_runbook_receiver": "automationRunbookReceiver",
        "azure_app_push_receiver": "azureAppPushReceiver",
        "azure_function_receiver": "azureFunctionReceiver",
        "email_receiver": "emailReceiver",
        "enabled": "enabled",
        "itsm_receiver": "itsmReceiver",
        "logic_app_receiver": "logicAppReceiver",
        "sms_receiver": "smsReceiver",
        "tags": "tags",
        "timeouts": "timeouts",
        "voice_receiver": "voiceReceiver",
        "webhook_receiver": "webhookReceiver",
    },
)
class MonitorActionGroupConfig(cdktf.TerraformMetaArguments):
    def __init__(
        self,
        *,
        count: typing.Optional[jsii.Number] = None,
        depends_on: typing.Optional[typing.List[cdktf.TerraformResource]] = None,
        lifecycle: typing.Optional[cdktf.TerraformResourceLifecycle] = None,
        provider: typing.Optional[cdktf.TerraformProvider] = None,
        name: builtins.str,
        resource_group_name: builtins.str,
        short_name: builtins.str,
        arm_role_receiver: typing.Optional[typing.List[MonitorActionGroupArmRoleReceiver]] = None,
        automation_runbook_receiver: typing.Optional[typing.List[MonitorActionGroupAutomationRunbookReceiver]] = None,
        azure_app_push_receiver: typing.Optional[typing.List[MonitorActionGroupAzureAppPushReceiver]] = None,
        azure_function_receiver: typing.Optional[typing.List[MonitorActionGroupAzureFunctionReceiver]] = None,
        email_receiver: typing.Optional[typing.List["MonitorActionGroupEmailReceiver"]] = None,
        enabled: typing.Optional[builtins.bool] = None,
        itsm_receiver: typing.Optional[typing.List["MonitorActionGroupItsmReceiver"]] = None,
        logic_app_receiver: typing.Optional[typing.List["MonitorActionGroupLogicAppReceiver"]] = None,
        sms_receiver: typing.Optional[typing.List["MonitorActionGroupSmsReceiver"]] = None,
        tags: typing.Optional[typing.Mapping[builtins.str, builtins.str]] = None,
        timeouts: typing.Optional["MonitorActionGroupTimeouts"] = None,
        voice_receiver: typing.Optional[typing.List["MonitorActionGroupVoiceReceiver"]] = None,
        webhook_receiver: typing.Optional[typing.List["MonitorActionGroupWebhookReceiver"]] = None,
    ) -> None:
        """
        :param count: 
        :param depends_on: 
        :param lifecycle: 
        :param provider: 
        :param name: 
        :param resource_group_name: 
        :param short_name: 
        :param arm_role_receiver: arm_role_receiver block.
        :param automation_runbook_receiver: automation_runbook_receiver block.
        :param azure_app_push_receiver: azure_app_push_receiver block.
        :param azure_function_receiver: azure_function_receiver block.
        :param email_receiver: email_receiver block.
        :param enabled: 
        :param itsm_receiver: itsm_receiver block.
        :param logic_app_receiver: logic_app_receiver block.
        :param sms_receiver: sms_receiver block.
        :param tags: 
        :param timeouts: timeouts block.
        :param voice_receiver: voice_receiver block.
        :param webhook_receiver: webhook_receiver block.
        """
        if isinstance(lifecycle, dict):
            lifecycle = cdktf.TerraformResourceLifecycle(**lifecycle)
        if isinstance(timeouts, dict):
            timeouts = MonitorActionGroupTimeouts(**timeouts)
        self._values: typing.Dict[str, typing.Any] = {
            "name": name,
            "resource_group_name": resource_group_name,
            "short_name": short_name,
        }
        if count is not None:
            self._values["count"] = count
        if depends_on is not None:
            self._values["depends_on"] = depends_on
        if lifecycle is not None:
            self._values["lifecycle"] = lifecycle
        if provider is not None:
            self._values["provider"] = provider
        if arm_role_receiver is not None:
            self._values["arm_role_receiver"] = arm_role_receiver
        if automation_runbook_receiver is not None:
            self._values["automation_runbook_receiver"] = automation_runbook_receiver
        if azure_app_push_receiver is not None:
            self._values["azure_app_push_receiver"] = azure_app_push_receiver
        if azure_function_receiver is not None:
            self._values["azure_function_receiver"] = azure_function_receiver
        if email_receiver is not None:
            self._values["email_receiver"] = email_receiver
        if enabled is not None:
            self._values["enabled"] = enabled
        if itsm_receiver is not None:
            self._values["itsm_receiver"] = itsm_receiver
        if logic_app_receiver is not None:
            self._values["logic_app_receiver"] = logic_app_receiver
        if sms_receiver is not None:
            self._values["sms_receiver"] = sms_receiver
        if tags is not None:
            self._values["tags"] = tags
        if timeouts is not None:
            self._values["timeouts"] = timeouts
        if voice_receiver is not None:
            self._values["voice_receiver"] = voice_receiver
        if webhook_receiver is not None:
            self._values["webhook_receiver"] = webhook_receiver

    @builtins.property
    def count(self) -> typing.Optional[jsii.Number]:
        """
        :stability: experimental
        """
        result = self._values.get("count")
        return result

    @builtins.property
    def depends_on(self) -> typing.Optional[typing.List[cdktf.TerraformResource]]:
        """
        :stability: experimental
        """
        result = self._values.get("depends_on")
        return result

    @builtins.property
    def lifecycle(self) -> typing.Optional[cdktf.TerraformResourceLifecycle]:
        """
        :stability: experimental
        """
        result = self._values.get("lifecycle")
        return result

    @builtins.property
    def provider(self) -> typing.Optional[cdktf.TerraformProvider]:
        """
        :stability: experimental
        """
        result = self._values.get("provider")
        return result

    @builtins.property
    def name(self) -> builtins.str:
        result = self._values.get("name")
        assert result is not None, "Required property 'name' is missing"
        return result

    @builtins.property
    def resource_group_name(self) -> builtins.str:
        result = self._values.get("resource_group_name")
        assert result is not None, "Required property 'resource_group_name' is missing"
        return result

    @builtins.property
    def short_name(self) -> builtins.str:
        result = self._values.get("short_name")
        assert result is not None, "Required property 'short_name' is missing"
        return result

    @builtins.property
    def arm_role_receiver(
        self,
    ) -> typing.Optional[typing.List[MonitorActionGroupArmRoleReceiver]]:
        """arm_role_receiver block."""
        result = self._values.get("arm_role_receiver")
        return result

    @builtins.property
    def automation_runbook_receiver(
        self,
    ) -> typing.Optional[typing.List[MonitorActionGroupAutomationRunbookReceiver]]:
        """automation_runbook_receiver block."""
        result = self._values.get("automation_runbook_receiver")
        return result

    @builtins.property
    def azure_app_push_receiver(
        self,
    ) -> typing.Optional[typing.List[MonitorActionGroupAzureAppPushReceiver]]:
        """azure_app_push_receiver block."""
        result = self._values.get("azure_app_push_receiver")
        return result

    @builtins.property
    def azure_function_receiver(
        self,
    ) -> typing.Optional[typing.List[MonitorActionGroupAzureFunctionReceiver]]:
        """azure_function_receiver block."""
        result = self._values.get("azure_function_receiver")
        return result

    @builtins.property
    def email_receiver(
        self,
    ) -> typing.Optional[typing.List["MonitorActionGroupEmailReceiver"]]:
        """email_receiver block."""
        result = self._values.get("email_receiver")
        return result

    @builtins.property
    def enabled(self) -> typing.Optional[builtins.bool]:
        result = self._values.get("enabled")
        return result

    @builtins.property
    def itsm_receiver(
        self,
    ) -> typing.Optional[typing.List["MonitorActionGroupItsmReceiver"]]:
        """itsm_receiver block."""
        result = self._values.get("itsm_receiver")
        return result

    @builtins.property
    def logic_app_receiver(
        self,
    ) -> typing.Optional[typing.List["MonitorActionGroupLogicAppReceiver"]]:
        """logic_app_receiver block."""
        result = self._values.get("logic_app_receiver")
        return result

    @builtins.property
    def sms_receiver(
        self,
    ) -> typing.Optional[typing.List["MonitorActionGroupSmsReceiver"]]:
        """sms_receiver block."""
        result = self._values.get("sms_receiver")
        return result

    @builtins.property
    def tags(self) -> typing.Optional[typing.Mapping[builtins.str, builtins.str]]:
        result = self._values.get("tags")
        return result

    @builtins.property
    def timeouts(self) -> typing.Optional["MonitorActionGroupTimeouts"]:
        """timeouts block."""
        result = self._values.get("timeouts")
        return result

    @builtins.property
    def voice_receiver(
        self,
    ) -> typing.Optional[typing.List["MonitorActionGroupVoiceReceiver"]]:
        """voice_receiver block."""
        result = self._values.get("voice_receiver")
        return result

    @builtins.property
    def webhook_receiver(
        self,
    ) -> typing.Optional[typing.List["MonitorActionGroupWebhookReceiver"]]:
        """webhook_receiver block."""
        result = self._values.get("webhook_receiver")
        return result

    def __eq__(self, rhs: typing.Any) -> builtins.bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs: typing.Any) -> builtins.bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return "MonitorActionGroupConfig(%s)" % ", ".join(
            k + "=" + repr(v) for k, v in self._values.items()
        )


@jsii.data_type(
    jsii_type="@cdktf/provider-azurerm.MonitorActionGroupEmailReceiver",
    jsii_struct_bases=[],
    name_mapping={
        "email_address": "emailAddress",
        "name": "name",
        "use_common_alert_schema": "useCommonAlertSchema",
    },
)
class MonitorActionGroupEmailReceiver:
    def __init__(
        self,
        *,
        email_address: builtins.str,
        name: builtins.str,
        use_common_alert_schema: typing.Optional[builtins.bool] = None,
    ) -> None:
        """
        :param email_address: 
        :param name: 
        :param use_common_alert_schema: 
        """
        self._values: typing.Dict[str, typing.Any] = {
            "email_address": email_address,
            "name": name,
        }
        if use_common_alert_schema is not None:
            self._values["use_common_alert_schema"] = use_common_alert_schema

    @builtins.property
    def email_address(self) -> builtins.str:
        result = self._values.get("email_address")
        assert result is not None, "Required property 'email_address' is missing"
        return result

    @builtins.property
    def name(self) -> builtins.str:
        result = self._values.get("name")
        assert result is not None, "Required property 'name' is missing"
        return result

    @builtins.property
    def use_common_alert_schema(self) -> typing.Optional[builtins.bool]:
        result = self._values.get("use_common_alert_schema")
        return result

    def __eq__(self, rhs: typing.Any) -> builtins.bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs: typing.Any) -> builtins.bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return "MonitorActionGroupEmailReceiver(%s)" % ", ".join(
            k + "=" + repr(v) for k, v in self._values.items()
        )


@jsii.data_type(
    jsii_type="@cdktf/provider-azurerm.MonitorActionGroupItsmReceiver",
    jsii_struct_bases=[],
    name_mapping={
        "connection_id": "connectionId",
        "name": "name",
        "region": "region",
        "ticket_configuration": "ticketConfiguration",
        "workspace_id": "workspaceId",
    },
)
class MonitorActionGroupItsmReceiver:
    def __init__(
        self,
        *,
        connection_id: builtins.str,
        name: builtins.str,
        region: builtins.str,
        ticket_configuration: builtins.str,
        workspace_id: builtins.str,
    ) -> None:
        """
        :param connection_id: 
        :param name: 
        :param region: 
        :param ticket_configuration: 
        :param workspace_id: 
        """
        self._values: typing.Dict[str, typing.Any] = {
            "connection_id": connection_id,
            "name": name,
            "region": region,
            "ticket_configuration": ticket_configuration,
            "workspace_id": workspace_id,
        }

    @builtins.property
    def connection_id(self) -> builtins.str:
        result = self._values.get("connection_id")
        assert result is not None, "Required property 'connection_id' is missing"
        return result

    @builtins.property
    def name(self) -> builtins.str:
        result = self._values.get("name")
        assert result is not None, "Required property 'name' is missing"
        return result

    @builtins.property
    def region(self) -> builtins.str:
        result = self._values.get("region")
        assert result is not None, "Required property 'region' is missing"
        return result

    @builtins.property
    def ticket_configuration(self) -> builtins.str:
        result = self._values.get("ticket_configuration")
        assert result is not None, "Required property 'ticket_configuration' is missing"
        return result

    @builtins.property
    def workspace_id(self) -> builtins.str:
        result = self._values.get("workspace_id")
        assert result is not None, "Required property 'workspace_id' is missing"
        return result

    def __eq__(self, rhs: typing.Any) -> builtins.bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs: typing.Any) -> builtins.bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return "MonitorActionGroupItsmReceiver(%s)" % ", ".join(
            k + "=" + repr(v) for k, v in self._values.items()
        )


@jsii.data_type(
    jsii_type="@cdktf/provider-azurerm.MonitorActionGroupLogicAppReceiver",
    jsii_struct_bases=[],
    name_mapping={
        "callback_url": "callbackUrl",
        "name": "name",
        "resource_id": "resourceId",
        "use_common_alert_schema": "useCommonAlertSchema",
    },
)
class MonitorActionGroupLogicAppReceiver:
    def __init__(
        self,
        *,
        callback_url: builtins.str,
        name: builtins.str,
        resource_id: builtins.str,
        use_common_alert_schema: typing.Optional[builtins.bool] = None,
    ) -> None:
        """
        :param callback_url: 
        :param name: 
        :param resource_id: 
        :param use_common_alert_schema: 
        """
        self._values: typing.Dict[str, typing.Any] = {
            "callback_url": callback_url,
            "name": name,
            "resource_id": resource_id,
        }
        if use_common_alert_schema is not None:
            self._values["use_common_alert_schema"] = use_common_alert_schema

    @builtins.property
    def callback_url(self) -> builtins.str:
        result = self._values.get("callback_url")
        assert result is not None, "Required property 'callback_url' is missing"
        return result

    @builtins.property
    def name(self) -> builtins.str:
        result = self._values.get("name")
        assert result is not None, "Required property 'name' is missing"
        return result

    @builtins.property
    def resource_id(self) -> builtins.str:
        result = self._values.get("resource_id")
        assert result is not None, "Required property 'resource_id' is missing"
        return result

    @builtins.property
    def use_common_alert_schema(self) -> typing.Optional[builtins.bool]:
        result = self._values.get("use_common_alert_schema")
        return result

    def __eq__(self, rhs: typing.Any) -> builtins.bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs: typing.Any) -> builtins.bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return "MonitorActionGroupLogicAppReceiver(%s)" % ", ".join(
            k + "=" + repr(v) for k, v in self._values.items()
        )


@jsii.data_type(
    jsii_type="@cdktf/provider-azurerm.MonitorActionGroupSmsReceiver",
    jsii_struct_bases=[],
    name_mapping={
        "country_code": "countryCode",
        "name": "name",
        "phone_number": "phoneNumber",
    },
)
class MonitorActionGroupSmsReceiver:
    def __init__(
        self,
        *,
        country_code: builtins.str,
        name: builtins.str,
        phone_number: builtins.str,
    ) -> None:
        """
        :param country_code: 
        :param name: 
        :param phone_number: 
        """
        self._values: typing.Dict[str, typing.Any] = {
            "country_code": country_code,
            "name": name,
            "phone_number": phone_number,
        }

    @builtins.property
    def country_code(self) -> builtins.str:
        result = self._values.get("country_code")
        assert result is not None, "Required property 'country_code' is missing"
        return result

    @builtins.property
    def name(self) -> builtins.str:
        result = self._values.get("name")
        assert result is not None, "Required property 'name' is missing"
        return result

    @builtins.property
    def phone_number(self) -> builtins.str:
        result = self._values.get("phone_number")
        assert result is not None, "Required property 'phone_number' is missing"
        return result

    def __eq__(self, rhs: typing.Any) -> builtins.bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs: typing.Any) -> builtins.bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return "MonitorActionGroupSmsReceiver(%s)" % ", ".join(
            k + "=" + repr(v) for k, v in self._values.items()
        )


@jsii.data_type(
    jsii_type="@cdktf/provider-azurerm.MonitorActionGroupTimeouts",
    jsii_struct_bases=[],
    name_mapping={
        "create": "create",
        "delete": "delete",
        "read": "read",
        "update": "update",
    },
)
class MonitorActionGroupTimeouts:
    def __init__(
        self,
        *,
        create: typing.Optional[builtins.str] = None,
        delete: typing.Optional[builtins.str] = None,
        read: typing.Optional[builtins.str] = None,
        update: typing.Optional[builtins.str] = None,
    ) -> None:
        """
        :param create: 
        :param delete: 
        :param read: 
        :param update: 
        """
        self._values: typing.Dict[str, typing.Any] = {}
        if create is not None:
            self._values["create"] = create
        if delete is not None:
            self._values["delete"] = delete
        if read is not None:
            self._values["read"] = read
        if update is not None:
            self._values["update"] = update

    @builtins.property
    def create(self) -> typing.Optional[builtins.str]:
        result = self._values.get("create")
        return result

    @builtins.property
    def delete(self) -> typing.Optional[builtins.str]:
        result = self._values.get("delete")
        return result

    @builtins.property
    def read(self) -> typing.Optional[builtins.str]:
        result = self._values.get("read")
        return result

    @builtins.property
    def update(self) -> typing.Optional[builtins.str]:
        result = self._values.get("update")
        return result

    def __eq__(self, rhs: typing.Any) -> builtins.bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs: typing.Any) -> builtins.bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return "MonitorActionGroupTimeouts(%s)" % ", ".join(
            k + "=" + repr(v) for k, v in self._values.items()
        )


@jsii.data_type(
    jsii_type="@cdktf/provider-azurerm.MonitorActionGroupVoiceReceiver",
    jsii_struct_bases=[],
    name_mapping={
        "country_code": "countryCode",
        "name": "name",
        "phone_number": "phoneNumber",
    },
)
class MonitorActionGroupVoiceReceiver:
    def __init__(
        self,
        *,
        country_code: builtins.str,
        name: builtins.str,
        phone_number: builtins.str,
    ) -> None:
        """
        :param country_code: 
        :param name: 
        :param phone_number: 
        """
        self._values: typing.Dict[str, typing.Any] = {
            "country_code": country_code,
            "name": name,
            "phone_number": phone_number,
        }

    @builtins.property
    def country_code(self) -> builtins.str:
        result = self._values.get("country_code")
        assert result is not None, "Required property 'country_code' is missing"
        return result

    @builtins.property
    def name(self) -> builtins.str:
        result = self._values.get("name")
        assert result is not None, "Required property 'name' is missing"
        return result

    @builtins.property
    def phone_number(self) -> builtins.str:
        result = self._values.get("phone_number")
        assert result is not None, "Required property 'phone_number' is missing"
        return result

    def __eq__(self, rhs: typing.Any) -> builtins.bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs: typing.Any) -> builtins.bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return "MonitorActionGroupVoiceReceiver(%s)" % ", ".join(
            k + "=" + repr(v) for k, v in self._values.items()
        )


@jsii.data_type(
    jsii_type="@cdktf/provider-azurerm.MonitorActionGroupWebhookReceiver",
    jsii_struct_bases=[],
    name_mapping={
        "name": "name",
        "service_uri": "serviceUri",
        "use_common_alert_schema": "useCommonAlertSchema",
    },
)
class MonitorActionGroupWebhookReceiver:
    def __init__(
        self,
        *,
        name: builtins.str,
        service_uri: builtins.str,
        use_common_alert_schema: typing.Optional[builtins.bool] = None,
    ) -> None:
        """
        :param name: 
        :param service_uri: 
        :param use_common_alert_schema: 
        """
        self._values: typing.Dict[str, typing.Any] = {
            "name": name,
            "service_uri": service_uri,
        }
        if use_common_alert_schema is not None:
            self._values["use_common_alert_schema"] = use_common_alert_schema

    @builtins.property
    def name(self) -> builtins.str:
        result = self._values.get("name")
        assert result is not None, "Required property 'name' is missing"
        return result

    @builtins.property
    def service_uri(self) -> builtins.str:
        result = self._values.get("service_uri")
        assert result is not None, "Required property 'service_uri' is missing"
        return result

    @builtins.property
    def use_common_alert_schema(self) -> typing.Optional[builtins.bool]:
        result = self._values.get("use_common_alert_schema")
        return result

    def __eq__(self, rhs: typing.Any) -> builtins.bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs: typing.Any) -> builtins.bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return "MonitorActionGroupWebhookReceiver(%s)" % ", ".join(
            k + "=" + repr(v) for k, v in self._values.items()
        )


class MonitorActivityLogAlert(
    cdktf.TerraformResource,
    metaclass=jsii.JSIIMeta,
    jsii_type="@cdktf/provider-azurerm.MonitorActivityLogAlert",
):
    def __init__(
        self,
        scope: constructs.Construct,
        id: builtins.str,
        *,
        criteria: typing.List["MonitorActivityLogAlertCriteria"],
        name: builtins.str,
        resource_group_name: builtins.str,
        scopes: typing.List[builtins.str],
        action: typing.Optional[typing.List["MonitorActivityLogAlertAction"]] = None,
        description: typing.Optional[builtins.str] = None,
        enabled: typing.Optional[builtins.bool] = None,
        tags: typing.Optional[typing.Mapping[builtins.str, builtins.str]] = None,
        timeouts: typing.Optional["MonitorActivityLogAlertTimeouts"] = None,
        count: typing.Optional[jsii.Number] = None,
        depends_on: typing.Optional[typing.List[cdktf.TerraformResource]] = None,
        lifecycle: typing.Optional[cdktf.TerraformResourceLifecycle] = None,
        provider: typing.Optional[cdktf.TerraformProvider] = None,
    ) -> None:
        """
        :param scope: -
        :param id: -
        :param criteria: criteria block.
        :param name: 
        :param resource_group_name: 
        :param scopes: 
        :param action: action block.
        :param description: 
        :param enabled: 
        :param tags: 
        :param timeouts: timeouts block.
        :param count: 
        :param depends_on: 
        :param lifecycle: 
        :param provider: 
        """
        config = MonitorActivityLogAlertConfig(
            criteria=criteria,
            name=name,
            resource_group_name=resource_group_name,
            scopes=scopes,
            action=action,
            description=description,
            enabled=enabled,
            tags=tags,
            timeouts=timeouts,
            count=count,
            depends_on=depends_on,
            lifecycle=lifecycle,
            provider=provider,
        )

        jsii.create(MonitorActivityLogAlert, self, [scope, id, config])

    @jsii.member(jsii_name="synthesizeAttributes")
    def _synthesize_attributes(self) -> typing.Mapping[builtins.str, typing.Any]:
        return jsii.invoke(self, "synthesizeAttributes", [])

    @builtins.property # type: ignore
    @jsii.member(jsii_name="criteria")
    def criteria(self) -> typing.List["MonitorActivityLogAlertCriteria"]:
        return jsii.get(self, "criteria")

    @criteria.setter # type: ignore
    def criteria(self, value: typing.List["MonitorActivityLogAlertCriteria"]) -> None:
        jsii.set(self, "criteria", value)

    @builtins.property # type: ignore
    @jsii.member(jsii_name="name")
    def name(self) -> builtins.str:
        return jsii.get(self, "name")

    @name.setter # type: ignore
    def name(self, value: builtins.str) -> None:
        jsii.set(self, "name", value)

    @builtins.property # type: ignore
    @jsii.member(jsii_name="resourceGroupName")
    def resource_group_name(self) -> builtins.str:
        return jsii.get(self, "resourceGroupName")

    @resource_group_name.setter # type: ignore
    def resource_group_name(self, value: builtins.str) -> None:
        jsii.set(self, "resourceGroupName", value)

    @builtins.property # type: ignore
    @jsii.member(jsii_name="scopes")
    def scopes(self) -> typing.List[builtins.str]:
        return jsii.get(self, "scopes")

    @scopes.setter # type: ignore
    def scopes(self, value: typing.List[builtins.str]) -> None:
        jsii.set(self, "scopes", value)

    @builtins.property # type: ignore
    @jsii.member(jsii_name="action")
    def action(self) -> typing.Optional[typing.List["MonitorActivityLogAlertAction"]]:
        return jsii.get(self, "action")

    @action.setter # type: ignore
    def action(
        self,
        value: typing.Optional[typing.List["MonitorActivityLogAlertAction"]],
    ) -> None:
        jsii.set(self, "action", value)

    @builtins.property # type: ignore
    @jsii.member(jsii_name="description")
    def description(self) -> typing.Optional[builtins.str]:
        return jsii.get(self, "description")

    @description.setter # type: ignore
    def description(self, value: typing.Optional[builtins.str]) -> None:
        jsii.set(self, "description", value)

    @builtins.property # type: ignore
    @jsii.member(jsii_name="enabled")
    def enabled(self) -> typing.Optional[builtins.bool]:
        return jsii.get(self, "enabled")

    @enabled.setter # type: ignore
    def enabled(self, value: typing.Optional[builtins.bool]) -> None:
        jsii.set(self, "enabled", value)

    @builtins.property # type: ignore
    @jsii.member(jsii_name="id")
    def id(self) -> typing.Optional[builtins.str]:
        return jsii.get(self, "id")

    @id.setter # type: ignore
    def id(self, value: typing.Optional[builtins.str]) -> None:
        jsii.set(self, "id", value)

    @builtins.property # type: ignore
    @jsii.member(jsii_name="tags")
    def tags(self) -> typing.Optional[typing.Mapping[builtins.str, builtins.str]]:
        return jsii.get(self, "tags")

    @tags.setter # type: ignore
    def tags(
        self,
        value: typing.Optional[typing.Mapping[builtins.str, builtins.str]],
    ) -> None:
        jsii.set(self, "tags", value)

    @builtins.property # type: ignore
    @jsii.member(jsii_name="timeouts")
    def timeouts(self) -> typing.Optional["MonitorActivityLogAlertTimeouts"]:
        return jsii.get(self, "timeouts")

    @timeouts.setter # type: ignore
    def timeouts(
        self,
        value: typing.Optional["MonitorActivityLogAlertTimeouts"],
    ) -> None:
        jsii.set(self, "timeouts", value)


@jsii.data_type(
    jsii_type="@cdktf/provider-azurerm.MonitorActivityLogAlertAction",
    jsii_struct_bases=[],
    name_mapping={
        "action_group_id": "actionGroupId",
        "webhook_properties": "webhookProperties",
    },
)
class MonitorActivityLogAlertAction:
    def __init__(
        self,
        *,
        action_group_id: builtins.str,
        webhook_properties: typing.Optional[typing.Mapping[builtins.str, builtins.str]] = None,
    ) -> None:
        """
        :param action_group_id: 
        :param webhook_properties: 
        """
        self._values: typing.Dict[str, typing.Any] = {
            "action_group_id": action_group_id,
        }
        if webhook_properties is not None:
            self._values["webhook_properties"] = webhook_properties

    @builtins.property
    def action_group_id(self) -> builtins.str:
        result = self._values.get("action_group_id")
        assert result is not None, "Required property 'action_group_id' is missing"
        return result

    @builtins.property
    def webhook_properties(
        self,
    ) -> typing.Optional[typing.Mapping[builtins.str, builtins.str]]:
        result = self._values.get("webhook_properties")
        return result

    def __eq__(self, rhs: typing.Any) -> builtins.bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs: typing.Any) -> builtins.bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return "MonitorActivityLogAlertAction(%s)" % ", ".join(
            k + "=" + repr(v) for k, v in self._values.items()
        )


@jsii.data_type(
    jsii_type="@cdktf/provider-azurerm.MonitorActivityLogAlertConfig",
    jsii_struct_bases=[cdktf.TerraformMetaArguments],
    name_mapping={
        "count": "count",
        "depends_on": "dependsOn",
        "lifecycle": "lifecycle",
        "provider": "provider",
        "criteria": "criteria",
        "name": "name",
        "resource_group_name": "resourceGroupName",
        "scopes": "scopes",
        "action": "action",
        "description": "description",
        "enabled": "enabled",
        "tags": "tags",
        "timeouts": "timeouts",
    },
)
class MonitorActivityLogAlertConfig(cdktf.TerraformMetaArguments):
    def __init__(
        self,
        *,
        count: typing.Optional[jsii.Number] = None,
        depends_on: typing.Optional[typing.List[cdktf.TerraformResource]] = None,
        lifecycle: typing.Optional[cdktf.TerraformResourceLifecycle] = None,
        provider: typing.Optional[cdktf.TerraformProvider] = None,
        criteria: typing.List["MonitorActivityLogAlertCriteria"],
        name: builtins.str,
        resource_group_name: builtins.str,
        scopes: typing.List[builtins.str],
        action: typing.Optional[typing.List[MonitorActivityLogAlertAction]] = None,
        description: typing.Optional[builtins.str] = None,
        enabled: typing.Optional[builtins.bool] = None,
        tags: typing.Optional[typing.Mapping[builtins.str, builtins.str]] = None,
        timeouts: typing.Optional["MonitorActivityLogAlertTimeouts"] = None,
    ) -> None:
        """
        :param count: 
        :param depends_on: 
        :param lifecycle: 
        :param provider: 
        :param criteria: criteria block.
        :param name: 
        :param resource_group_name: 
        :param scopes: 
        :param action: action block.
        :param description: 
        :param enabled: 
        :param tags: 
        :param timeouts: timeouts block.
        """
        if isinstance(lifecycle, dict):
            lifecycle = cdktf.TerraformResourceLifecycle(**lifecycle)
        if isinstance(timeouts, dict):
            timeouts = MonitorActivityLogAlertTimeouts(**timeouts)
        self._values: typing.Dict[str, typing.Any] = {
            "criteria": criteria,
            "name": name,
            "resource_group_name": resource_group_name,
            "scopes": scopes,
        }
        if count is not None:
            self._values["count"] = count
        if depends_on is not None:
            self._values["depends_on"] = depends_on
        if lifecycle is not None:
            self._values["lifecycle"] = lifecycle
        if provider is not None:
            self._values["provider"] = provider
        if action is not None:
            self._values["action"] = action
        if description is not None:
            self._values["description"] = description
        if enabled is not None:
            self._values["enabled"] = enabled
        if tags is not None:
            self._values["tags"] = tags
        if timeouts is not None:
            self._values["timeouts"] = timeouts

    @builtins.property
    def count(self) -> typing.Optional[jsii.Number]:
        """
        :stability: experimental
        """
        result = self._values.get("count")
        return result

    @builtins.property
    def depends_on(self) -> typing.Optional[typing.List[cdktf.TerraformResource]]:
        """
        :stability: experimental
        """
        result = self._values.get("depends_on")
        return result

    @builtins.property
    def lifecycle(self) -> typing.Optional[cdktf.TerraformResourceLifecycle]:
        """
        :stability: experimental
        """
        result = self._values.get("lifecycle")
        return result

    @builtins.property
    def provider(self) -> typing.Optional[cdktf.TerraformProvider]:
        """
        :stability: experimental
        """
        result = self._values.get("provider")
        return result

    @builtins.property
    def criteria(self) -> typing.List["MonitorActivityLogAlertCriteria"]:
        """criteria block."""
        result = self._values.get("criteria")
        assert result is not None, "Required property 'criteria' is missing"
        return result

    @builtins.property
    def name(self) -> builtins.str:
        result = self._values.get("name")
        assert result is not None, "Required property 'name' is missing"
        return result

    @builtins.property
    def resource_group_name(self) -> builtins.str:
        result = self._values.get("resource_group_name")
        assert result is not None, "Required property 'resource_group_name' is missing"
        return result

    @builtins.property
    def scopes(self) -> typing.List[builtins.str]:
        result = self._values.get("scopes")
        assert result is not None, "Required property 'scopes' is missing"
        return result

    @builtins.property
    def action(self) -> typing.Optional[typing.List[MonitorActivityLogAlertAction]]:
        """action block."""
        result = self._values.get("action")
        return result

    @builtins.property
    def description(self) -> typing.Optional[builtins.str]:
        result = self._values.get("description")
        return result

    @builtins.property
    def enabled(self) -> typing.Optional[builtins.bool]:
        result = self._values.get("enabled")
        return result

    @builtins.property
    def tags(self) -> typing.Optional[typing.Mapping[builtins.str, builtins.str]]:
        result = self._values.get("tags")
        return result

    @builtins.property
    def timeouts(self) -> typing.Optional["MonitorActivityLogAlertTimeouts"]:
        """timeouts block."""
        result = self._values.get("timeouts")
        return result

    def __eq__(self, rhs: typing.Any) -> builtins.bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs: typing.Any) -> builtins.bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return "MonitorActivityLogAlertConfig(%s)" % ", ".join(
            k + "=" + repr(v) for k, v in self._values.items()
        )


@jsii.data_type(
    jsii_type="@cdktf/provider-azurerm.MonitorActivityLogAlertCriteria",
    jsii_struct_bases=[],
    name_mapping={
        "category": "category",
        "caller": "caller",
        "level": "level",
        "operation_name": "operationName",
        "resource_group": "resourceGroup",
        "resource_id": "resourceId",
        "resource_provider": "resourceProvider",
        "resource_type": "resourceType",
        "status": "status",
        "sub_status": "subStatus",
    },
)
class MonitorActivityLogAlertCriteria:
    def __init__(
        self,
        *,
        category: builtins.str,
        caller: typing.Optional[builtins.str] = None,
        level: typing.Optional[builtins.str] = None,
        operation_name: typing.Optional[builtins.str] = None,
        resource_group: typing.Optional[builtins.str] = None,
        resource_id: typing.Optional[builtins.str] = None,
        resource_provider: typing.Optional[builtins.str] = None,
        resource_type: typing.Optional[builtins.str] = None,
        status: typing.Optional[builtins.str] = None,
        sub_status: typing.Optional[builtins.str] = None,
    ) -> None:
        """
        :param category: 
        :param caller: 
        :param level: 
        :param operation_name: 
        :param resource_group: 
        :param resource_id: 
        :param resource_provider: 
        :param resource_type: 
        :param status: 
        :param sub_status: 
        """
        self._values: typing.Dict[str, typing.Any] = {
            "category": category,
        }
        if caller is not None:
            self._values["caller"] = caller
        if level is not None:
            self._values["level"] = level
        if operation_name is not None:
            self._values["operation_name"] = operation_name
        if resource_group is not None:
            self._values["resource_group"] = resource_group
        if resource_id is not None:
            self._values["resource_id"] = resource_id
        if resource_provider is not None:
            self._values["resource_provider"] = resource_provider
        if resource_type is not None:
            self._values["resource_type"] = resource_type
        if status is not None:
            self._values["status"] = status
        if sub_status is not None:
            self._values["sub_status"] = sub_status

    @builtins.property
    def category(self) -> builtins.str:
        result = self._values.get("category")
        assert result is not None, "Required property 'category' is missing"
        return result

    @builtins.property
    def caller(self) -> typing.Optional[builtins.str]:
        result = self._values.get("caller")
        return result

    @builtins.property
    def level(self) -> typing.Optional[builtins.str]:
        result = self._values.get("level")
        return result

    @builtins.property
    def operation_name(self) -> typing.Optional[builtins.str]:
        result = self._values.get("operation_name")
        return result

    @builtins.property
    def resource_group(self) -> typing.Optional[builtins.str]:
        result = self._values.get("resource_group")
        return result

    @builtins.property
    def resource_id(self) -> typing.Optional[builtins.str]:
        result = self._values.get("resource_id")
        return result

    @builtins.property
    def resource_provider(self) -> typing.Optional[builtins.str]:
        result = self._values.get("resource_provider")
        return result

    @builtins.property
    def resource_type(self) -> typing.Optional[builtins.str]:
        result = self._values.get("resource_type")
        return result

    @builtins.property
    def status(self) -> typing.Optional[builtins.str]:
        result = self._values.get("status")
        return result

    @builtins.property
    def sub_status(self) -> typing.Optional[builtins.str]:
        result = self._values.get("sub_status")
        return result

    def __eq__(self, rhs: typing.Any) -> builtins.bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs: typing.Any) -> builtins.bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return "MonitorActivityLogAlertCriteria(%s)" % ", ".join(
            k + "=" + repr(v) for k, v in self._values.items()
        )


@jsii.data_type(
    jsii_type="@cdktf/provider-azurerm.MonitorActivityLogAlertTimeouts",
    jsii_struct_bases=[],
    name_mapping={
        "create": "create",
        "delete": "delete",
        "read": "read",
        "update": "update",
    },
)
class MonitorActivityLogAlertTimeouts:
    def __init__(
        self,
        *,
        create: typing.Optional[builtins.str] = None,
        delete: typing.Optional[builtins.str] = None,
        read: typing.Optional[builtins.str] = None,
        update: typing.Optional[builtins.str] = None,
    ) -> None:
        """
        :param create: 
        :param delete: 
        :param read: 
        :param update: 
        """
        self._values: typing.Dict[str, typing.Any] = {}
        if create is not None:
            self._values["create"] = create
        if delete is not None:
            self._values["delete"] = delete
        if read is not None:
            self._values["read"] = read
        if update is not None:
            self._values["update"] = update

    @builtins.property
    def create(self) -> typing.Optional[builtins.str]:
        result = self._values.get("create")
        return result

    @builtins.property
    def delete(self) -> typing.Optional[builtins.str]:
        result = self._values.get("delete")
        return result

    @builtins.property
    def read(self) -> typing.Optional[builtins.str]:
        result = self._values.get("read")
        return result

    @builtins.property
    def update(self) -> typing.Optional[builtins.str]:
        result = self._values.get("update")
        return result

    def __eq__(self, rhs: typing.Any) -> builtins.bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs: typing.Any) -> builtins.bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return "MonitorActivityLogAlertTimeouts(%s)" % ", ".join(
            k + "=" + repr(v) for k, v in self._values.items()
        )


class MonitorAutoscaleSetting(
    cdktf.TerraformResource,
    metaclass=jsii.JSIIMeta,
    jsii_type="@cdktf/provider-azurerm.MonitorAutoscaleSetting",
):
    def __init__(
        self,
        scope: constructs.Construct,
        id: builtins.str,
        *,
        location: builtins.str,
        name: builtins.str,
        profile: typing.List["MonitorAutoscaleSettingProfile"],
        resource_group_name: builtins.str,
        target_resource_id: builtins.str,
        enabled: typing.Optional[builtins.bool] = None,
        notification: typing.Optional[typing.List["MonitorAutoscaleSettingNotification"]] = None,
        tags: typing.Optional[typing.Mapping[builtins.str, builtins.str]] = None,
        timeouts: typing.Optional["MonitorAutoscaleSettingTimeouts"] = None,
        count: typing.Optional[jsii.Number] = None,
        depends_on: typing.Optional[typing.List[cdktf.TerraformResource]] = None,
        lifecycle: typing.Optional[cdktf.TerraformResourceLifecycle] = None,
        provider: typing.Optional[cdktf.TerraformProvider] = None,
    ) -> None:
        """
        :param scope: -
        :param id: -
        :param location: 
        :param name: 
        :param profile: profile block.
        :param resource_group_name: 
        :param target_resource_id: 
        :param enabled: 
        :param notification: notification block.
        :param tags: 
        :param timeouts: timeouts block.
        :param count: 
        :param depends_on: 
        :param lifecycle: 
        :param provider: 
        """
        config = MonitorAutoscaleSettingConfig(
            location=location,
            name=name,
            profile=profile,
            resource_group_name=resource_group_name,
            target_resource_id=target_resource_id,
            enabled=enabled,
            notification=notification,
            tags=tags,
            timeouts=timeouts,
            count=count,
            depends_on=depends_on,
            lifecycle=lifecycle,
            provider=provider,
        )

        jsii.create(MonitorAutoscaleSetting, self, [scope, id, config])

    @jsii.member(jsii_name="synthesizeAttributes")
    def _synthesize_attributes(self) -> typing.Mapping[builtins.str, typing.Any]:
        return jsii.invoke(self, "synthesizeAttributes", [])

    @builtins.property # type: ignore
    @jsii.member(jsii_name="location")
    def location(self) -> builtins.str:
        return jsii.get(self, "location")

    @location.setter # type: ignore
    def location(self, value: builtins.str) -> None:
        jsii.set(self, "location", value)

    @builtins.property # type: ignore
    @jsii.member(jsii_name="name")
    def name(self) -> builtins.str:
        return jsii.get(self, "name")

    @name.setter # type: ignore
    def name(self, value: builtins.str) -> None:
        jsii.set(self, "name", value)

    @builtins.property # type: ignore
    @jsii.member(jsii_name="profile")
    def profile(self) -> typing.List["MonitorAutoscaleSettingProfile"]:
        return jsii.get(self, "profile")

    @profile.setter # type: ignore
    def profile(self, value: typing.List["MonitorAutoscaleSettingProfile"]) -> None:
        jsii.set(self, "profile", value)

    @builtins.property # type: ignore
    @jsii.member(jsii_name="resourceGroupName")
    def resource_group_name(self) -> builtins.str:
        return jsii.get(self, "resourceGroupName")

    @resource_group_name.setter # type: ignore
    def resource_group_name(self, value: builtins.str) -> None:
        jsii.set(self, "resourceGroupName", value)

    @builtins.property # type: ignore
    @jsii.member(jsii_name="targetResourceId")
    def target_resource_id(self) -> builtins.str:
        return jsii.get(self, "targetResourceId")

    @target_resource_id.setter # type: ignore
    def target_resource_id(self, value: builtins.str) -> None:
        jsii.set(self, "targetResourceId", value)

    @builtins.property # type: ignore
    @jsii.member(jsii_name="enabled")
    def enabled(self) -> typing.Optional[builtins.bool]:
        return jsii.get(self, "enabled")

    @enabled.setter # type: ignore
    def enabled(self, value: typing.Optional[builtins.bool]) -> None:
        jsii.set(self, "enabled", value)

    @builtins.property # type: ignore
    @jsii.member(jsii_name="id")
    def id(self) -> typing.Optional[builtins.str]:
        return jsii.get(self, "id")

    @id.setter # type: ignore
    def id(self, value: typing.Optional[builtins.str]) -> None:
        jsii.set(self, "id", value)

    @builtins.property # type: ignore
    @jsii.member(jsii_name="notification")
    def notification(
        self,
    ) -> typing.Optional[typing.List["MonitorAutoscaleSettingNotification"]]:
        return jsii.get(self, "notification")

    @notification.setter # type: ignore
    def notification(
        self,
        value: typing.Optional[typing.List["MonitorAutoscaleSettingNotification"]],
    ) -> None:
        jsii.set(self, "notification", value)

    @builtins.property # type: ignore
    @jsii.member(jsii_name="tags")
    def tags(self) -> typing.Optional[typing.Mapping[builtins.str, builtins.str]]:
        return jsii.get(self, "tags")

    @tags.setter # type: ignore
    def tags(
        self,
        value: typing.Optional[typing.Mapping[builtins.str, builtins.str]],
    ) -> None:
        jsii.set(self, "tags", value)

    @builtins.property # type: ignore
    @jsii.member(jsii_name="timeouts")
    def timeouts(self) -> typing.Optional["MonitorAutoscaleSettingTimeouts"]:
        return jsii.get(self, "timeouts")

    @timeouts.setter # type: ignore
    def timeouts(
        self,
        value: typing.Optional["MonitorAutoscaleSettingTimeouts"],
    ) -> None:
        jsii.set(self, "timeouts", value)


@jsii.data_type(
    jsii_type="@cdktf/provider-azurerm.MonitorAutoscaleSettingConfig",
    jsii_struct_bases=[cdktf.TerraformMetaArguments],
    name_mapping={
        "count": "count",
        "depends_on": "dependsOn",
        "lifecycle": "lifecycle",
        "provider": "provider",
        "location": "location",
        "name": "name",
        "profile": "profile",
        "resource_group_name": "resourceGroupName",
        "target_resource_id": "targetResourceId",
        "enabled": "enabled",
        "notification": "notification",
        "tags": "tags",
        "timeouts": "timeouts",
    },
)
class MonitorAutoscaleSettingConfig(cdktf.TerraformMetaArguments):
    def __init__(
        self,
        *,
        count: typing.Optional[jsii.Number] = None,
        depends_on: typing.Optional[typing.List[cdktf.TerraformResource]] = None,
        lifecycle: typing.Optional[cdktf.TerraformResourceLifecycle] = None,
        provider: typing.Optional[cdktf.TerraformProvider] = None,
        location: builtins.str,
        name: builtins.str,
        profile: typing.List["MonitorAutoscaleSettingProfile"],
        resource_group_name: builtins.str,
        target_resource_id: builtins.str,
        enabled: typing.Optional[builtins.bool] = None,
        notification: typing.Optional[typing.List["MonitorAutoscaleSettingNotification"]] = None,
        tags: typing.Optional[typing.Mapping[builtins.str, builtins.str]] = None,
        timeouts: typing.Optional["MonitorAutoscaleSettingTimeouts"] = None,
    ) -> None:
        """
        :param count: 
        :param depends_on: 
        :param lifecycle: 
        :param provider: 
        :param location: 
        :param name: 
        :param profile: profile block.
        :param resource_group_name: 
        :param target_resource_id: 
        :param enabled: 
        :param notification: notification block.
        :param tags: 
        :param timeouts: timeouts block.
        """
        if isinstance(lifecycle, dict):
            lifecycle = cdktf.TerraformResourceLifecycle(**lifecycle)
        if isinstance(timeouts, dict):
            timeouts = MonitorAutoscaleSettingTimeouts(**timeouts)
        self._values: typing.Dict[str, typing.Any] = {
            "location": location,
            "name": name,
            "profile": profile,
            "resource_group_name": resource_group_name,
            "target_resource_id": target_resource_id,
        }
        if count is not None:
            self._values["count"] = count
        if depends_on is not None:
            self._values["depends_on"] = depends_on
        if lifecycle is not None:
            self._values["lifecycle"] = lifecycle
        if provider is not None:
            self._values["provider"] = provider
        if enabled is not None:
            self._values["enabled"] = enabled
        if notification is not None:
            self._values["notification"] = notification
        if tags is not None:
            self._values["tags"] = tags
        if timeouts is not None:
            self._values["timeouts"] = timeouts

    @builtins.property
    def count(self) -> typing.Optional[jsii.Number]:
        """
        :stability: experimental
        """
        result = self._values.get("count")
        return result

    @builtins.property
    def depends_on(self) -> typing.Optional[typing.List[cdktf.TerraformResource]]:
        """
        :stability: experimental
        """
        result = self._values.get("depends_on")
        return result

    @builtins.property
    def lifecycle(self) -> typing.Optional[cdktf.TerraformResourceLifecycle]:
        """
        :stability: experimental
        """
        result = self._values.get("lifecycle")
        return result

    @builtins.property
    def provider(self) -> typing.Optional[cdktf.TerraformProvider]:
        """
        :stability: experimental
        """
        result = self._values.get("provider")
        return result

    @builtins.property
    def location(self) -> builtins.str:
        result = self._values.get("location")
        assert result is not None, "Required property 'location' is missing"
        return result

    @builtins.property
    def name(self) -> builtins.str:
        result = self._values.get("name")
        assert result is not None, "Required property 'name' is missing"
        return result

    @builtins.property
    def profile(self) -> typing.List["MonitorAutoscaleSettingProfile"]:
        """profile block."""
        result = self._values.get("profile")
        assert result is not None, "Required property 'profile' is missing"
        return result

    @builtins.property
    def resource_group_name(self) -> builtins.str:
        result = self._values.get("resource_group_name")
        assert result is not None, "Required property 'resource_group_name' is missing"
        return result

    @builtins.property
    def target_resource_id(self) -> builtins.str:
        result = self._values.get("target_resource_id")
        assert result is not None, "Required property 'target_resource_id' is missing"
        return result

    @builtins.property
    def enabled(self) -> typing.Optional[builtins.bool]:
        result = self._values.get("enabled")
        return result

    @builtins.property
    def notification(
        self,
    ) -> typing.Optional[typing.List["MonitorAutoscaleSettingNotification"]]:
        """notification block."""
        result = self._values.get("notification")
        return result

    @builtins.property
    def tags(self) -> typing.Optional[typing.Mapping[builtins.str, builtins.str]]:
        result = self._values.get("tags")
        return result

    @builtins.property
    def timeouts(self) -> typing.Optional["MonitorAutoscaleSettingTimeouts"]:
        """timeouts block."""
        result = self._values.get("timeouts")
        return result

    def __eq__(self, rhs: typing.Any) -> builtins.bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs: typing.Any) -> builtins.bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return "MonitorAutoscaleSettingConfig(%s)" % ", ".join(
            k + "=" + repr(v) for k, v in self._values.items()
        )


@jsii.data_type(
    jsii_type="@cdktf/provider-azurerm.MonitorAutoscaleSettingNotification",
    jsii_struct_bases=[],
    name_mapping={"email": "email", "webhook": "webhook"},
)
class MonitorAutoscaleSettingNotification:
    def __init__(
        self,
        *,
        email: typing.Optional[typing.List["MonitorAutoscaleSettingNotificationEmail"]] = None,
        webhook: typing.Optional[typing.List["MonitorAutoscaleSettingNotificationWebhook"]] = None,
    ) -> None:
        """
        :param email: email block.
        :param webhook: webhook block.
        """
        self._values: typing.Dict[str, typing.Any] = {}
        if email is not None:
            self._values["email"] = email
        if webhook is not None:
            self._values["webhook"] = webhook

    @builtins.property
    def email(
        self,
    ) -> typing.Optional[typing.List["MonitorAutoscaleSettingNotificationEmail"]]:
        """email block."""
        result = self._values.get("email")
        return result

    @builtins.property
    def webhook(
        self,
    ) -> typing.Optional[typing.List["MonitorAutoscaleSettingNotificationWebhook"]]:
        """webhook block."""
        result = self._values.get("webhook")
        return result

    def __eq__(self, rhs: typing.Any) -> builtins.bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs: typing.Any) -> builtins.bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return "MonitorAutoscaleSettingNotification(%s)" % ", ".join(
            k + "=" + repr(v) for k, v in self._values.items()
        )


@jsii.data_type(
    jsii_type="@cdktf/provider-azurerm.MonitorAutoscaleSettingNotificationEmail",
    jsii_struct_bases=[],
    name_mapping={
        "custom_emails": "customEmails",
        "send_to_subscription_administrator": "sendToSubscriptionAdministrator",
        "send_to_subscription_co_administrator": "sendToSubscriptionCoAdministrator",
    },
)
class MonitorAutoscaleSettingNotificationEmail:
    def __init__(
        self,
        *,
        custom_emails: typing.Optional[typing.List[builtins.str]] = None,
        send_to_subscription_administrator: typing.Optional[builtins.bool] = None,
        send_to_subscription_co_administrator: typing.Optional[builtins.bool] = None,
    ) -> None:
        """
        :param custom_emails: 
        :param send_to_subscription_administrator: 
        :param send_to_subscription_co_administrator: 
        """
        self._values: typing.Dict[str, typing.Any] = {}
        if custom_emails is not None:
            self._values["custom_emails"] = custom_emails
        if send_to_subscription_administrator is not None:
            self._values["send_to_subscription_administrator"] = send_to_subscription_administrator
        if send_to_subscription_co_administrator is not None:
            self._values["send_to_subscription_co_administrator"] = send_to_subscription_co_administrator

    @builtins.property
    def custom_emails(self) -> typing.Optional[typing.List[builtins.str]]:
        result = self._values.get("custom_emails")
        return result

    @builtins.property
    def send_to_subscription_administrator(self) -> typing.Optional[builtins.bool]:
        result = self._values.get("send_to_subscription_administrator")
        return result

    @builtins.property
    def send_to_subscription_co_administrator(self) -> typing.Optional[builtins.bool]:
        result = self._values.get("send_to_subscription_co_administrator")
        return result

    def __eq__(self, rhs: typing.Any) -> builtins.bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs: typing.Any) -> builtins.bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return "MonitorAutoscaleSettingNotificationEmail(%s)" % ", ".join(
            k + "=" + repr(v) for k, v in self._values.items()
        )


@jsii.data_type(
    jsii_type="@cdktf/provider-azurerm.MonitorAutoscaleSettingNotificationWebhook",
    jsii_struct_bases=[],
    name_mapping={"service_uri": "serviceUri", "properties": "properties"},
)
class MonitorAutoscaleSettingNotificationWebhook:
    def __init__(
        self,
        *,
        service_uri: builtins.str,
        properties: typing.Optional[typing.Mapping[builtins.str, builtins.str]] = None,
    ) -> None:
        """
        :param service_uri: 
        :param properties: 
        """
        self._values: typing.Dict[str, typing.Any] = {
            "service_uri": service_uri,
        }
        if properties is not None:
            self._values["properties"] = properties

    @builtins.property
    def service_uri(self) -> builtins.str:
        result = self._values.get("service_uri")
        assert result is not None, "Required property 'service_uri' is missing"
        return result

    @builtins.property
    def properties(self) -> typing.Optional[typing.Mapping[builtins.str, builtins.str]]:
        result = self._values.get("properties")
        return result

    def __eq__(self, rhs: typing.Any) -> builtins.bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs: typing.Any) -> builtins.bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return "MonitorAutoscaleSettingNotificationWebhook(%s)" % ", ".join(
            k + "=" + repr(v) for k, v in self._values.items()
        )


@jsii.data_type(
    jsii_type="@cdktf/provider-azurerm.MonitorAutoscaleSettingProfile",
    jsii_struct_bases=[],
    name_mapping={
        "capacity": "capacity",
        "name": "name",
        "fixed_date": "fixedDate",
        "recurrence": "recurrence",
        "rule": "rule",
    },
)
class MonitorAutoscaleSettingProfile:
    def __init__(
        self,
        *,
        capacity: typing.List["MonitorAutoscaleSettingProfileCapacity"],
        name: builtins.str,
        fixed_date: typing.Optional[typing.List["MonitorAutoscaleSettingProfileFixedDate"]] = None,
        recurrence: typing.Optional[typing.List["MonitorAutoscaleSettingProfileRecurrence"]] = None,
        rule: typing.Optional[typing.List["MonitorAutoscaleSettingProfileRule"]] = None,
    ) -> None:
        """
        :param capacity: capacity block.
        :param name: 
        :param fixed_date: fixed_date block.
        :param recurrence: recurrence block.
        :param rule: rule block.
        """
        self._values: typing.Dict[str, typing.Any] = {
            "capacity": capacity,
            "name": name,
        }
        if fixed_date is not None:
            self._values["fixed_date"] = fixed_date
        if recurrence is not None:
            self._values["recurrence"] = recurrence
        if rule is not None:
            self._values["rule"] = rule

    @builtins.property
    def capacity(self) -> typing.List["MonitorAutoscaleSettingProfileCapacity"]:
        """capacity block."""
        result = self._values.get("capacity")
        assert result is not None, "Required property 'capacity' is missing"
        return result

    @builtins.property
    def name(self) -> builtins.str:
        result = self._values.get("name")
        assert result is not None, "Required property 'name' is missing"
        return result

    @builtins.property
    def fixed_date(
        self,
    ) -> typing.Optional[typing.List["MonitorAutoscaleSettingProfileFixedDate"]]:
        """fixed_date block."""
        result = self._values.get("fixed_date")
        return result

    @builtins.property
    def recurrence(
        self,
    ) -> typing.Optional[typing.List["MonitorAutoscaleSettingProfileRecurrence"]]:
        """recurrence block."""
        result = self._values.get("recurrence")
        return result

    @builtins.property
    def rule(
        self,
    ) -> typing.Optional[typing.List["MonitorAutoscaleSettingProfileRule"]]:
        """rule block."""
        result = self._values.get("rule")
        return result

    def __eq__(self, rhs: typing.Any) -> builtins.bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs: typing.Any) -> builtins.bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return "MonitorAutoscaleSettingProfile(%s)" % ", ".join(
            k + "=" + repr(v) for k, v in self._values.items()
        )


@jsii.data_type(
    jsii_type="@cdktf/provider-azurerm.MonitorAutoscaleSettingProfileCapacity",
    jsii_struct_bases=[],
    name_mapping={"default": "default", "maximum": "maximum", "minimum": "minimum"},
)
class MonitorAutoscaleSettingProfileCapacity:
    def __init__(
        self,
        *,
        default: jsii.Number,
        maximum: jsii.Number,
        minimum: jsii.Number,
    ) -> None:
        """
        :param default: 
        :param maximum: 
        :param minimum: 
        """
        self._values: typing.Dict[str, typing.Any] = {
            "default": default,
            "maximum": maximum,
            "minimum": minimum,
        }

    @builtins.property
    def default(self) -> jsii.Number:
        result = self._values.get("default")
        assert result is not None, "Required property 'default' is missing"
        return result

    @builtins.property
    def maximum(self) -> jsii.Number:
        result = self._values.get("maximum")
        assert result is not None, "Required property 'maximum' is missing"
        return result

    @builtins.property
    def minimum(self) -> jsii.Number:
        result = self._values.get("minimum")
        assert result is not None, "Required property 'minimum' is missing"
        return result

    def __eq__(self, rhs: typing.Any) -> builtins.bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs: typing.Any) -> builtins.bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return "MonitorAutoscaleSettingProfileCapacity(%s)" % ", ".join(
            k + "=" + repr(v) for k, v in self._values.items()
        )


@jsii.data_type(
    jsii_type="@cdktf/provider-azurerm.MonitorAutoscaleSettingProfileFixedDate",
    jsii_struct_bases=[],
    name_mapping={"end": "end", "start": "start", "timezone": "timezone"},
)
class MonitorAutoscaleSettingProfileFixedDate:
    def __init__(
        self,
        *,
        end: builtins.str,
        start: builtins.str,
        timezone: typing.Optional[builtins.str] = None,
    ) -> None:
        """
        :param end: 
        :param start: 
        :param timezone: 
        """
        self._values: typing.Dict[str, typing.Any] = {
            "end": end,
            "start": start,
        }
        if timezone is not None:
            self._values["timezone"] = timezone

    @builtins.property
    def end(self) -> builtins.str:
        result = self._values.get("end")
        assert result is not None, "Required property 'end' is missing"
        return result

    @builtins.property
    def start(self) -> builtins.str:
        result = self._values.get("start")
        assert result is not None, "Required property 'start' is missing"
        return result

    @builtins.property
    def timezone(self) -> typing.Optional[builtins.str]:
        result = self._values.get("timezone")
        return result

    def __eq__(self, rhs: typing.Any) -> builtins.bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs: typing.Any) -> builtins.bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return "MonitorAutoscaleSettingProfileFixedDate(%s)" % ", ".join(
            k + "=" + repr(v) for k, v in self._values.items()
        )


@jsii.data_type(
    jsii_type="@cdktf/provider-azurerm.MonitorAutoscaleSettingProfileRecurrence",
    jsii_struct_bases=[],
    name_mapping={
        "days": "days",
        "hours": "hours",
        "minutes": "minutes",
        "timezone": "timezone",
    },
)
class MonitorAutoscaleSettingProfileRecurrence:
    def __init__(
        self,
        *,
        days: typing.List[builtins.str],
        hours: typing.List[jsii.Number],
        minutes: typing.List[jsii.Number],
        timezone: typing.Optional[builtins.str] = None,
    ) -> None:
        """
        :param days: 
        :param hours: 
        :param minutes: 
        :param timezone: 
        """
        self._values: typing.Dict[str, typing.Any] = {
            "days": days,
            "hours": hours,
            "minutes": minutes,
        }
        if timezone is not None:
            self._values["timezone"] = timezone

    @builtins.property
    def days(self) -> typing.List[builtins.str]:
        result = self._values.get("days")
        assert result is not None, "Required property 'days' is missing"
        return result

    @builtins.property
    def hours(self) -> typing.List[jsii.Number]:
        result = self._values.get("hours")
        assert result is not None, "Required property 'hours' is missing"
        return result

    @builtins.property
    def minutes(self) -> typing.List[jsii.Number]:
        result = self._values.get("minutes")
        assert result is not None, "Required property 'minutes' is missing"
        return result

    @builtins.property
    def timezone(self) -> typing.Optional[builtins.str]:
        result = self._values.get("timezone")
        return result

    def __eq__(self, rhs: typing.Any) -> builtins.bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs: typing.Any) -> builtins.bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return "MonitorAutoscaleSettingProfileRecurrence(%s)" % ", ".join(
            k + "=" + repr(v) for k, v in self._values.items()
        )


@jsii.data_type(
    jsii_type="@cdktf/provider-azurerm.MonitorAutoscaleSettingProfileRule",
    jsii_struct_bases=[],
    name_mapping={"metric_trigger": "metricTrigger", "scale_action": "scaleAction"},
)
class MonitorAutoscaleSettingProfileRule:
    def __init__(
        self,
        *,
        metric_trigger: typing.List["MonitorAutoscaleSettingProfileRuleMetricTrigger"],
        scale_action: typing.List["MonitorAutoscaleSettingProfileRuleScaleAction"],
    ) -> None:
        """
        :param metric_trigger: metric_trigger block.
        :param scale_action: scale_action block.
        """
        self._values: typing.Dict[str, typing.Any] = {
            "metric_trigger": metric_trigger,
            "scale_action": scale_action,
        }

    @builtins.property
    def metric_trigger(
        self,
    ) -> typing.List["MonitorAutoscaleSettingProfileRuleMetricTrigger"]:
        """metric_trigger block."""
        result = self._values.get("metric_trigger")
        assert result is not None, "Required property 'metric_trigger' is missing"
        return result

    @builtins.property
    def scale_action(
        self,
    ) -> typing.List["MonitorAutoscaleSettingProfileRuleScaleAction"]:
        """scale_action block."""
        result = self._values.get("scale_action")
        assert result is not None, "Required property 'scale_action' is missing"
        return result

    def __eq__(self, rhs: typing.Any) -> builtins.bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs: typing.Any) -> builtins.bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return "MonitorAutoscaleSettingProfileRule(%s)" % ", ".join(
            k + "=" + repr(v) for k, v in self._values.items()
        )


@jsii.data_type(
    jsii_type="@cdktf/provider-azurerm.MonitorAutoscaleSettingProfileRuleMetricTrigger",
    jsii_struct_bases=[],
    name_mapping={
        "metric_name": "metricName",
        "metric_resource_id": "metricResourceId",
        "operator": "operator",
        "statistic": "statistic",
        "threshold": "threshold",
        "time_aggregation": "timeAggregation",
        "time_grain": "timeGrain",
        "time_window": "timeWindow",
    },
)
class MonitorAutoscaleSettingProfileRuleMetricTrigger:
    def __init__(
        self,
        *,
        metric_name: builtins.str,
        metric_resource_id: builtins.str,
        operator: builtins.str,
        statistic: builtins.str,
        threshold: jsii.Number,
        time_aggregation: builtins.str,
        time_grain: builtins.str,
        time_window: builtins.str,
    ) -> None:
        """
        :param metric_name: 
        :param metric_resource_id: 
        :param operator: 
        :param statistic: 
        :param threshold: 
        :param time_aggregation: 
        :param time_grain: 
        :param time_window: 
        """
        self._values: typing.Dict[str, typing.Any] = {
            "metric_name": metric_name,
            "metric_resource_id": metric_resource_id,
            "operator": operator,
            "statistic": statistic,
            "threshold": threshold,
            "time_aggregation": time_aggregation,
            "time_grain": time_grain,
            "time_window": time_window,
        }

    @builtins.property
    def metric_name(self) -> builtins.str:
        result = self._values.get("metric_name")
        assert result is not None, "Required property 'metric_name' is missing"
        return result

    @builtins.property
    def metric_resource_id(self) -> builtins.str:
        result = self._values.get("metric_resource_id")
        assert result is not None, "Required property 'metric_resource_id' is missing"
        return result

    @builtins.property
    def operator(self) -> builtins.str:
        result = self._values.get("operator")
        assert result is not None, "Required property 'operator' is missing"
        return result

    @builtins.property
    def statistic(self) -> builtins.str:
        result = self._values.get("statistic")
        assert result is not None, "Required property 'statistic' is missing"
        return result

    @builtins.property
    def threshold(self) -> jsii.Number:
        result = self._values.get("threshold")
        assert result is not None, "Required property 'threshold' is missing"
        return result

    @builtins.property
    def time_aggregation(self) -> builtins.str:
        result = self._values.get("time_aggregation")
        assert result is not None, "Required property 'time_aggregation' is missing"
        return result

    @builtins.property
    def time_grain(self) -> builtins.str:
        result = self._values.get("time_grain")
        assert result is not None, "Required property 'time_grain' is missing"
        return result

    @builtins.property
    def time_window(self) -> builtins.str:
        result = self._values.get("time_window")
        assert result is not None, "Required property 'time_window' is missing"
        return result

    def __eq__(self, rhs: typing.Any) -> builtins.bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs: typing.Any) -> builtins.bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return "MonitorAutoscaleSettingProfileRuleMetricTrigger(%s)" % ", ".join(
            k + "=" + repr(v) for k, v in self._values.items()
        )


@jsii.data_type(
    jsii_type="@cdktf/provider-azurerm.MonitorAutoscaleSettingProfileRuleScaleAction",
    jsii_struct_bases=[],
    name_mapping={
        "cooldown": "cooldown",
        "direction": "direction",
        "type": "type",
        "value": "value",
    },
)
class MonitorAutoscaleSettingProfileRuleScaleAction:
    def __init__(
        self,
        *,
        cooldown: builtins.str,
        direction: builtins.str,
        type: builtins.str,
        value: jsii.Number,
    ) -> None:
        """
        :param cooldown: 
        :param direction: 
        :param type: 
        :param value: 
        """
        self._values: typing.Dict[str, typing.Any] = {
            "cooldown": cooldown,
            "direction": direction,
            "type": type,
            "value": value,
        }

    @builtins.property
    def cooldown(self) -> builtins.str:
        result = self._values.get("cooldown")
        assert result is not None, "Required property 'cooldown' is missing"
        return result

    @builtins.property
    def direction(self) -> builtins.str:
        result = self._values.get("direction")
        assert result is not None, "Required property 'direction' is missing"
        return result

    @builtins.property
    def type(self) -> builtins.str:
        result = self._values.get("type")
        assert result is not None, "Required property 'type' is missing"
        return result

    @builtins.property
    def value(self) -> jsii.Number:
        result = self._values.get("value")
        assert result is not None, "Required property 'value' is missing"
        return result

    def __eq__(self, rhs: typing.Any) -> builtins.bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs: typing.Any) -> builtins.bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return "MonitorAutoscaleSettingProfileRuleScaleAction(%s)" % ", ".join(
            k + "=" + repr(v) for k, v in self._values.items()
        )


@jsii.data_type(
    jsii_type="@cdktf/provider-azurerm.MonitorAutoscaleSettingTimeouts",
    jsii_struct_bases=[],
    name_mapping={
        "create": "create",
        "delete": "delete",
        "read": "read",
        "update": "update",
    },
)
class MonitorAutoscaleSettingTimeouts:
    def __init__(
        self,
        *,
        create: typing.Optional[builtins.str] = None,
        delete: typing.Optional[builtins.str] = None,
        read: typing.Optional[builtins.str] = None,
        update: typing.Optional[builtins.str] = None,
    ) -> None:
        """
        :param create: 
        :param delete: 
        :param read: 
        :param update: 
        """
        self._values: typing.Dict[str, typing.Any] = {}
        if create is not None:
            self._values["create"] = create
        if delete is not None:
            self._values["delete"] = delete
        if read is not None:
            self._values["read"] = read
        if update is not None:
            self._values["update"] = update

    @builtins.property
    def create(self) -> typing.Optional[builtins.str]:
        result = self._values.get("create")
        return result

    @builtins.property
    def delete(self) -> typing.Optional[builtins.str]:
        result = self._values.get("delete")
        return result

    @builtins.property
    def read(self) -> typing.Optional[builtins.str]:
        result = self._values.get("read")
        return result

    @builtins.property
    def update(self) -> typing.Optional[builtins.str]:
        result = self._values.get("update")
        return result

    def __eq__(self, rhs: typing.Any) -> builtins.bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs: typing.Any) -> builtins.bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return "MonitorAutoscaleSettingTimeouts(%s)" % ", ".join(
            k + "=" + repr(v) for k, v in self._values.items()
        )


class MonitorDiagnosticSetting(
    cdktf.TerraformResource,
    metaclass=jsii.JSIIMeta,
    jsii_type="@cdktf/provider-azurerm.MonitorDiagnosticSetting",
):
    def __init__(
        self,
        scope: constructs.Construct,
        id: builtins.str,
        *,
        name: builtins.str,
        target_resource_id: builtins.str,
        eventhub_authorization_rule_id: typing.Optional[builtins.str] = None,
        eventhub_name: typing.Optional[builtins.str] = None,
        log: typing.Optional[typing.List["MonitorDiagnosticSettingLog"]] = None,
        log_analytics_destination_type: typing.Optional[builtins.str] = None,
        log_analytics_workspace_id: typing.Optional[builtins.str] = None,
        metric: typing.Optional[typing.List["MonitorDiagnosticSettingMetric"]] = None,
        storage_account_id: typing.Optional[builtins.str] = None,
        timeouts: typing.Optional["MonitorDiagnosticSettingTimeouts"] = None,
        count: typing.Optional[jsii.Number] = None,
        depends_on: typing.Optional[typing.List[cdktf.TerraformResource]] = None,
        lifecycle: typing.Optional[cdktf.TerraformResourceLifecycle] = None,
        provider: typing.Optional[cdktf.TerraformProvider] = None,
    ) -> None:
        """
        :param scope: -
        :param id: -
        :param name: 
        :param target_resource_id: 
        :param eventhub_authorization_rule_id: 
        :param eventhub_name: 
        :param log: log block.
        :param log_analytics_destination_type: 
        :param log_analytics_workspace_id: 
        :param metric: metric block.
        :param storage_account_id: 
        :param timeouts: timeouts block.
        :param count: 
        :param depends_on: 
        :param lifecycle: 
        :param provider: 
        """
        config = MonitorDiagnosticSettingConfig(
            name=name,
            target_resource_id=target_resource_id,
            eventhub_authorization_rule_id=eventhub_authorization_rule_id,
            eventhub_name=eventhub_name,
            log=log,
            log_analytics_destination_type=log_analytics_destination_type,
            log_analytics_workspace_id=log_analytics_workspace_id,
            metric=metric,
            storage_account_id=storage_account_id,
            timeouts=timeouts,
            count=count,
            depends_on=depends_on,
            lifecycle=lifecycle,
            provider=provider,
        )

        jsii.create(MonitorDiagnosticSetting, self, [scope, id, config])

    @jsii.member(jsii_name="synthesizeAttributes")
    def _synthesize_attributes(self) -> typing.Mapping[builtins.str, typing.Any]:
        return jsii.invoke(self, "synthesizeAttributes", [])

    @builtins.property # type: ignore
    @jsii.member(jsii_name="name")
    def name(self) -> builtins.str:
        return jsii.get(self, "name")

    @name.setter # type: ignore
    def name(self, value: builtins.str) -> None:
        jsii.set(self, "name", value)

    @builtins.property # type: ignore
    @jsii.member(jsii_name="targetResourceId")
    def target_resource_id(self) -> builtins.str:
        return jsii.get(self, "targetResourceId")

    @target_resource_id.setter # type: ignore
    def target_resource_id(self, value: builtins.str) -> None:
        jsii.set(self, "targetResourceId", value)

    @builtins.property # type: ignore
    @jsii.member(jsii_name="eventhubAuthorizationRuleId")
    def eventhub_authorization_rule_id(self) -> typing.Optional[builtins.str]:
        return jsii.get(self, "eventhubAuthorizationRuleId")

    @eventhub_authorization_rule_id.setter # type: ignore
    def eventhub_authorization_rule_id(
        self,
        value: typing.Optional[builtins.str],
    ) -> None:
        jsii.set(self, "eventhubAuthorizationRuleId", value)

    @builtins.property # type: ignore
    @jsii.member(jsii_name="eventhubName")
    def eventhub_name(self) -> typing.Optional[builtins.str]:
        return jsii.get(self, "eventhubName")

    @eventhub_name.setter # type: ignore
    def eventhub_name(self, value: typing.Optional[builtins.str]) -> None:
        jsii.set(self, "eventhubName", value)

    @builtins.property # type: ignore
    @jsii.member(jsii_name="id")
    def id(self) -> typing.Optional[builtins.str]:
        return jsii.get(self, "id")

    @id.setter # type: ignore
    def id(self, value: typing.Optional[builtins.str]) -> None:
        jsii.set(self, "id", value)

    @builtins.property # type: ignore
    @jsii.member(jsii_name="log")
    def log(self) -> typing.Optional[typing.List["MonitorDiagnosticSettingLog"]]:
        return jsii.get(self, "log")

    @log.setter # type: ignore
    def log(
        self,
        value: typing.Optional[typing.List["MonitorDiagnosticSettingLog"]],
    ) -> None:
        jsii.set(self, "log", value)

    @builtins.property # type: ignore
    @jsii.member(jsii_name="logAnalyticsDestinationType")
    def log_analytics_destination_type(self) -> typing.Optional[builtins.str]:
        return jsii.get(self, "logAnalyticsDestinationType")

    @log_analytics_destination_type.setter # type: ignore
    def log_analytics_destination_type(
        self,
        value: typing.Optional[builtins.str],
    ) -> None:
        jsii.set(self, "logAnalyticsDestinationType", value)

    @builtins.property # type: ignore
    @jsii.member(jsii_name="logAnalyticsWorkspaceId")
    def log_analytics_workspace_id(self) -> typing.Optional[builtins.str]:
        return jsii.get(self, "logAnalyticsWorkspaceId")

    @log_analytics_workspace_id.setter # type: ignore
    def log_analytics_workspace_id(self, value: typing.Optional[builtins.str]) -> None:
        jsii.set(self, "logAnalyticsWorkspaceId", value)

    @builtins.property # type: ignore
    @jsii.member(jsii_name="metric")
    def metric(self) -> typing.Optional[typing.List["MonitorDiagnosticSettingMetric"]]:
        return jsii.get(self, "metric")

    @metric.setter # type: ignore
    def metric(
        self,
        value: typing.Optional[typing.List["MonitorDiagnosticSettingMetric"]],
    ) -> None:
        jsii.set(self, "metric", value)

    @builtins.property # type: ignore
    @jsii.member(jsii_name="storageAccountId")
    def storage_account_id(self) -> typing.Optional[builtins.str]:
        return jsii.get(self, "storageAccountId")

    @storage_account_id.setter # type: ignore
    def storage_account_id(self, value: typing.Optional[builtins.str]) -> None:
        jsii.set(self, "storageAccountId", value)

    @builtins.property # type: ignore
    @jsii.member(jsii_name="timeouts")
    def timeouts(self) -> typing.Optional["MonitorDiagnosticSettingTimeouts"]:
        return jsii.get(self, "timeouts")

    @timeouts.setter # type: ignore
    def timeouts(
        self,
        value: typing.Optional["MonitorDiagnosticSettingTimeouts"],
    ) -> None:
        jsii.set(self, "timeouts", value)


@jsii.data_type(
    jsii_type="@cdktf/provider-azurerm.MonitorDiagnosticSettingConfig",
    jsii_struct_bases=[cdktf.TerraformMetaArguments],
    name_mapping={
        "count": "count",
        "depends_on": "dependsOn",
        "lifecycle": "lifecycle",
        "provider": "provider",
        "name": "name",
        "target_resource_id": "targetResourceId",
        "eventhub_authorization_rule_id": "eventhubAuthorizationRuleId",
        "eventhub_name": "eventhubName",
        "log": "log",
        "log_analytics_destination_type": "logAnalyticsDestinationType",
        "log_analytics_workspace_id": "logAnalyticsWorkspaceId",
        "metric": "metric",
        "storage_account_id": "storageAccountId",
        "timeouts": "timeouts",
    },
)
class MonitorDiagnosticSettingConfig(cdktf.TerraformMetaArguments):
    def __init__(
        self,
        *,
        count: typing.Optional[jsii.Number] = None,
        depends_on: typing.Optional[typing.List[cdktf.TerraformResource]] = None,
        lifecycle: typing.Optional[cdktf.TerraformResourceLifecycle] = None,
        provider: typing.Optional[cdktf.TerraformProvider] = None,
        name: builtins.str,
        target_resource_id: builtins.str,
        eventhub_authorization_rule_id: typing.Optional[builtins.str] = None,
        eventhub_name: typing.Optional[builtins.str] = None,
        log: typing.Optional[typing.List["MonitorDiagnosticSettingLog"]] = None,
        log_analytics_destination_type: typing.Optional[builtins.str] = None,
        log_analytics_workspace_id: typing.Optional[builtins.str] = None,
        metric: typing.Optional[typing.List["MonitorDiagnosticSettingMetric"]] = None,
        storage_account_id: typing.Optional[builtins.str] = None,
        timeouts: typing.Optional["MonitorDiagnosticSettingTimeouts"] = None,
    ) -> None:
        """
        :param count: 
        :param depends_on: 
        :param lifecycle: 
        :param provider: 
        :param name: 
        :param target_resource_id: 
        :param eventhub_authorization_rule_id: 
        :param eventhub_name: 
        :param log: log block.
        :param log_analytics_destination_type: 
        :param log_analytics_workspace_id: 
        :param metric: metric block.
        :param storage_account_id: 
        :param timeouts: timeouts block.
        """
        if isinstance(lifecycle, dict):
            lifecycle = cdktf.TerraformResourceLifecycle(**lifecycle)
        if isinstance(timeouts, dict):
            timeouts = MonitorDiagnosticSettingTimeouts(**timeouts)
        self._values: typing.Dict[str, typing.Any] = {
            "name": name,
            "target_resource_id": target_resource_id,
        }
        if count is not None:
            self._values["count"] = count
        if depends_on is not None:
            self._values["depends_on"] = depends_on
        if lifecycle is not None:
            self._values["lifecycle"] = lifecycle
        if provider is not None:
            self._values["provider"] = provider
        if eventhub_authorization_rule_id is not None:
            self._values["eventhub_authorization_rule_id"] = eventhub_authorization_rule_id
        if eventhub_name is not None:
            self._values["eventhub_name"] = eventhub_name
        if log is not None:
            self._values["log"] = log
        if log_analytics_destination_type is not None:
            self._values["log_analytics_destination_type"] = log_analytics_destination_type
        if log_analytics_workspace_id is not None:
            self._values["log_analytics_workspace_id"] = log_analytics_workspace_id
        if metric is not None:
            self._values["metric"] = metric
        if storage_account_id is not None:
            self._values["storage_account_id"] = storage_account_id
        if timeouts is not None:
            self._values["timeouts"] = timeouts

    @builtins.property
    def count(self) -> typing.Optional[jsii.Number]:
        """
        :stability: experimental
        """
        result = self._values.get("count")
        return result

    @builtins.property
    def depends_on(self) -> typing.Optional[typing.List[cdktf.TerraformResource]]:
        """
        :stability: experimental
        """
        result = self._values.get("depends_on")
        return result

    @builtins.property
    def lifecycle(self) -> typing.Optional[cdktf.TerraformResourceLifecycle]:
        """
        :stability: experimental
        """
        result = self._values.get("lifecycle")
        return result

    @builtins.property
    def provider(self) -> typing.Optional[cdktf.TerraformProvider]:
        """
        :stability: experimental
        """
        result = self._values.get("provider")
        return result

    @builtins.property
    def name(self) -> builtins.str:
        result = self._values.get("name")
        assert result is not None, "Required property 'name' is missing"
        return result

    @builtins.property
    def target_resource_id(self) -> builtins.str:
        result = self._values.get("target_resource_id")
        assert result is not None, "Required property 'target_resource_id' is missing"
        return result

    @builtins.property
    def eventhub_authorization_rule_id(self) -> typing.Optional[builtins.str]:
        result = self._values.get("eventhub_authorization_rule_id")
        return result

    @builtins.property
    def eventhub_name(self) -> typing.Optional[builtins.str]:
        result = self._values.get("eventhub_name")
        return result

    @builtins.property
    def log(self) -> typing.Optional[typing.List["MonitorDiagnosticSettingLog"]]:
        """log block."""
        result = self._values.get("log")
        return result

    @builtins.property
    def log_analytics_destination_type(self) -> typing.Optional[builtins.str]:
        result = self._values.get("log_analytics_destination_type")
        return result

    @builtins.property
    def log_analytics_workspace_id(self) -> typing.Optional[builtins.str]:
        result = self._values.get("log_analytics_workspace_id")
        return result

    @builtins.property
    def metric(self) -> typing.Optional[typing.List["MonitorDiagnosticSettingMetric"]]:
        """metric block."""
        result = self._values.get("metric")
        return result

    @builtins.property
    def storage_account_id(self) -> typing.Optional[builtins.str]:
        result = self._values.get("storage_account_id")
        return result

    @builtins.property
    def timeouts(self) -> typing.Optional["MonitorDiagnosticSettingTimeouts"]:
        """timeouts block."""
        result = self._values.get("timeouts")
        return result

    def __eq__(self, rhs: typing.Any) -> builtins.bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs: typing.Any) -> builtins.bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return "MonitorDiagnosticSettingConfig(%s)" % ", ".join(
            k + "=" + repr(v) for k, v in self._values.items()
        )


@jsii.data_type(
    jsii_type="@cdktf/provider-azurerm.MonitorDiagnosticSettingLog",
    jsii_struct_bases=[],
    name_mapping={
        "category": "category",
        "retention_policy": "retentionPolicy",
        "enabled": "enabled",
    },
)
class MonitorDiagnosticSettingLog:
    def __init__(
        self,
        *,
        category: builtins.str,
        retention_policy: typing.List["MonitorDiagnosticSettingLogRetentionPolicy"],
        enabled: typing.Optional[builtins.bool] = None,
    ) -> None:
        """
        :param category: 
        :param retention_policy: retention_policy block.
        :param enabled: 
        """
        self._values: typing.Dict[str, typing.Any] = {
            "category": category,
            "retention_policy": retention_policy,
        }
        if enabled is not None:
            self._values["enabled"] = enabled

    @builtins.property
    def category(self) -> builtins.str:
        result = self._values.get("category")
        assert result is not None, "Required property 'category' is missing"
        return result

    @builtins.property
    def retention_policy(
        self,
    ) -> typing.List["MonitorDiagnosticSettingLogRetentionPolicy"]:
        """retention_policy block."""
        result = self._values.get("retention_policy")
        assert result is not None, "Required property 'retention_policy' is missing"
        return result

    @builtins.property
    def enabled(self) -> typing.Optional[builtins.bool]:
        result = self._values.get("enabled")
        return result

    def __eq__(self, rhs: typing.Any) -> builtins.bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs: typing.Any) -> builtins.bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return "MonitorDiagnosticSettingLog(%s)" % ", ".join(
            k + "=" + repr(v) for k, v in self._values.items()
        )


@jsii.data_type(
    jsii_type="@cdktf/provider-azurerm.MonitorDiagnosticSettingLogRetentionPolicy",
    jsii_struct_bases=[],
    name_mapping={"enabled": "enabled", "days": "days"},
)
class MonitorDiagnosticSettingLogRetentionPolicy:
    def __init__(
        self,
        *,
        enabled: builtins.bool,
        days: typing.Optional[jsii.Number] = None,
    ) -> None:
        """
        :param enabled: 
        :param days: 
        """
        self._values: typing.Dict[str, typing.Any] = {
            "enabled": enabled,
        }
        if days is not None:
            self._values["days"] = days

    @builtins.property
    def enabled(self) -> builtins.bool:
        result = self._values.get("enabled")
        assert result is not None, "Required property 'enabled' is missing"
        return result

    @builtins.property
    def days(self) -> typing.Optional[jsii.Number]:
        result = self._values.get("days")
        return result

    def __eq__(self, rhs: typing.Any) -> builtins.bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs: typing.Any) -> builtins.bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return "MonitorDiagnosticSettingLogRetentionPolicy(%s)" % ", ".join(
            k + "=" + repr(v) for k, v in self._values.items()
        )


@jsii.data_type(
    jsii_type="@cdktf/provider-azurerm.MonitorDiagnosticSettingMetric",
    jsii_struct_bases=[],
    name_mapping={
        "category": "category",
        "retention_policy": "retentionPolicy",
        "enabled": "enabled",
    },
)
class MonitorDiagnosticSettingMetric:
    def __init__(
        self,
        *,
        category: builtins.str,
        retention_policy: typing.List["MonitorDiagnosticSettingMetricRetentionPolicy"],
        enabled: typing.Optional[builtins.bool] = None,
    ) -> None:
        """
        :param category: 
        :param retention_policy: retention_policy block.
        :param enabled: 
        """
        self._values: typing.Dict[str, typing.Any] = {
            "category": category,
            "retention_policy": retention_policy,
        }
        if enabled is not None:
            self._values["enabled"] = enabled

    @builtins.property
    def category(self) -> builtins.str:
        result = self._values.get("category")
        assert result is not None, "Required property 'category' is missing"
        return result

    @builtins.property
    def retention_policy(
        self,
    ) -> typing.List["MonitorDiagnosticSettingMetricRetentionPolicy"]:
        """retention_policy block."""
        result = self._values.get("retention_policy")
        assert result is not None, "Required property 'retention_policy' is missing"
        return result

    @builtins.property
    def enabled(self) -> typing.Optional[builtins.bool]:
        result = self._values.get("enabled")
        return result

    def __eq__(self, rhs: typing.Any) -> builtins.bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs: typing.Any) -> builtins.bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return "MonitorDiagnosticSettingMetric(%s)" % ", ".join(
            k + "=" + repr(v) for k, v in self._values.items()
        )


@jsii.data_type(
    jsii_type="@cdktf/provider-azurerm.MonitorDiagnosticSettingMetricRetentionPolicy",
    jsii_struct_bases=[],
    name_mapping={"enabled": "enabled", "days": "days"},
)
class MonitorDiagnosticSettingMetricRetentionPolicy:
    def __init__(
        self,
        *,
        enabled: builtins.bool,
        days: typing.Optional[jsii.Number] = None,
    ) -> None:
        """
        :param enabled: 
        :param days: 
        """
        self._values: typing.Dict[str, typing.Any] = {
            "enabled": enabled,
        }
        if days is not None:
            self._values["days"] = days

    @builtins.property
    def enabled(self) -> builtins.bool:
        result = self._values.get("enabled")
        assert result is not None, "Required property 'enabled' is missing"
        return result

    @builtins.property
    def days(self) -> typing.Optional[jsii.Number]:
        result = self._values.get("days")
        return result

    def __eq__(self, rhs: typing.Any) -> builtins.bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs: typing.Any) -> builtins.bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return "MonitorDiagnosticSettingMetricRetentionPolicy(%s)" % ", ".join(
            k + "=" + repr(v) for k, v in self._values.items()
        )


@jsii.data_type(
    jsii_type="@cdktf/provider-azurerm.MonitorDiagnosticSettingTimeouts",
    jsii_struct_bases=[],
    name_mapping={
        "create": "create",
        "delete": "delete",
        "read": "read",
        "update": "update",
    },
)
class MonitorDiagnosticSettingTimeouts:
    def __init__(
        self,
        *,
        create: typing.Optional[builtins.str] = None,
        delete: typing.Optional[builtins.str] = None,
        read: typing.Optional[builtins.str] = None,
        update: typing.Optional[builtins.str] = None,
    ) -> None:
        """
        :param create: 
        :param delete: 
        :param read: 
        :param update: 
        """
        self._values: typing.Dict[str, typing.Any] = {}
        if create is not None:
            self._values["create"] = create
        if delete is not None:
            self._values["delete"] = delete
        if read is not None:
            self._values["read"] = read
        if update is not None:
            self._values["update"] = update

    @builtins.property
    def create(self) -> typing.Optional[builtins.str]:
        result = self._values.get("create")
        return result

    @builtins.property
    def delete(self) -> typing.Optional[builtins.str]:
        result = self._values.get("delete")
        return result

    @builtins.property
    def read(self) -> typing.Optional[builtins.str]:
        result = self._values.get("read")
        return result

    @builtins.property
    def update(self) -> typing.Optional[builtins.str]:
        result = self._values.get("update")
        return result

    def __eq__(self, rhs: typing.Any) -> builtins.bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs: typing.Any) -> builtins.bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return "MonitorDiagnosticSettingTimeouts(%s)" % ", ".join(
            k + "=" + repr(v) for k, v in self._values.items()
        )


class MonitorLogProfile(
    cdktf.TerraformResource,
    metaclass=jsii.JSIIMeta,
    jsii_type="@cdktf/provider-azurerm.MonitorLogProfile",
):
    def __init__(
        self,
        scope: constructs.Construct,
        id: builtins.str,
        *,
        categories: typing.List[builtins.str],
        locations: typing.List[builtins.str],
        name: builtins.str,
        retention_policy: typing.List["MonitorLogProfileRetentionPolicy"],
        servicebus_rule_id: typing.Optional[builtins.str] = None,
        storage_account_id: typing.Optional[builtins.str] = None,
        timeouts: typing.Optional["MonitorLogProfileTimeouts"] = None,
        count: typing.Optional[jsii.Number] = None,
        depends_on: typing.Optional[typing.List[cdktf.TerraformResource]] = None,
        lifecycle: typing.Optional[cdktf.TerraformResourceLifecycle] = None,
        provider: typing.Optional[cdktf.TerraformProvider] = None,
    ) -> None:
        """
        :param scope: -
        :param id: -
        :param categories: 
        :param locations: 
        :param name: 
        :param retention_policy: retention_policy block.
        :param servicebus_rule_id: 
        :param storage_account_id: 
        :param timeouts: timeouts block.
        :param count: 
        :param depends_on: 
        :param lifecycle: 
        :param provider: 
        """
        config = MonitorLogProfileConfig(
            categories=categories,
            locations=locations,
            name=name,
            retention_policy=retention_policy,
            servicebus_rule_id=servicebus_rule_id,
            storage_account_id=storage_account_id,
            timeouts=timeouts,
            count=count,
            depends_on=depends_on,
            lifecycle=lifecycle,
            provider=provider,
        )

        jsii.create(MonitorLogProfile, self, [scope, id, config])

    @jsii.member(jsii_name="synthesizeAttributes")
    def _synthesize_attributes(self) -> typing.Mapping[builtins.str, typing.Any]:
        return jsii.invoke(self, "synthesizeAttributes", [])

    @builtins.property # type: ignore
    @jsii.member(jsii_name="categories")
    def categories(self) -> typing.List[builtins.str]:
        return jsii.get(self, "categories")

    @categories.setter # type: ignore
    def categories(self, value: typing.List[builtins.str]) -> None:
        jsii.set(self, "categories", value)

    @builtins.property # type: ignore
    @jsii.member(jsii_name="locations")
    def locations(self) -> typing.List[builtins.str]:
        return jsii.get(self, "locations")

    @locations.setter # type: ignore
    def locations(self, value: typing.List[builtins.str]) -> None:
        jsii.set(self, "locations", value)

    @builtins.property # type: ignore
    @jsii.member(jsii_name="name")
    def name(self) -> builtins.str:
        return jsii.get(self, "name")

    @name.setter # type: ignore
    def name(self, value: builtins.str) -> None:
        jsii.set(self, "name", value)

    @builtins.property # type: ignore
    @jsii.member(jsii_name="retentionPolicy")
    def retention_policy(self) -> typing.List["MonitorLogProfileRetentionPolicy"]:
        return jsii.get(self, "retentionPolicy")

    @retention_policy.setter # type: ignore
    def retention_policy(
        self,
        value: typing.List["MonitorLogProfileRetentionPolicy"],
    ) -> None:
        jsii.set(self, "retentionPolicy", value)

    @builtins.property # type: ignore
    @jsii.member(jsii_name="id")
    def id(self) -> typing.Optional[builtins.str]:
        return jsii.get(self, "id")

    @id.setter # type: ignore
    def id(self, value: typing.Optional[builtins.str]) -> None:
        jsii.set(self, "id", value)

    @builtins.property # type: ignore
    @jsii.member(jsii_name="servicebusRuleId")
    def servicebus_rule_id(self) -> typing.Optional[builtins.str]:
        return jsii.get(self, "servicebusRuleId")

    @servicebus_rule_id.setter # type: ignore
    def servicebus_rule_id(self, value: typing.Optional[builtins.str]) -> None:
        jsii.set(self, "servicebusRuleId", value)

    @builtins.property # type: ignore
    @jsii.member(jsii_name="storageAccountId")
    def storage_account_id(self) -> typing.Optional[builtins.str]:
        return jsii.get(self, "storageAccountId")

    @storage_account_id.setter # type: ignore
    def storage_account_id(self, value: typing.Optional[builtins.str]) -> None:
        jsii.set(self, "storageAccountId", value)

    @builtins.property # type: ignore
    @jsii.member(jsii_name="timeouts")
    def timeouts(self) -> typing.Optional["MonitorLogProfileTimeouts"]:
        return jsii.get(self, "timeouts")

    @timeouts.setter # type: ignore
    def timeouts(self, value: typing.Optional["MonitorLogProfileTimeouts"]) -> None:
        jsii.set(self, "timeouts", value)


@jsii.data_type(
    jsii_type="@cdktf/provider-azurerm.MonitorLogProfileConfig",
    jsii_struct_bases=[cdktf.TerraformMetaArguments],
    name_mapping={
        "count": "count",
        "depends_on": "dependsOn",
        "lifecycle": "lifecycle",
        "provider": "provider",
        "categories": "categories",
        "locations": "locations",
        "name": "name",
        "retention_policy": "retentionPolicy",
        "servicebus_rule_id": "servicebusRuleId",
        "storage_account_id": "storageAccountId",
        "timeouts": "timeouts",
    },
)
class MonitorLogProfileConfig(cdktf.TerraformMetaArguments):
    def __init__(
        self,
        *,
        count: typing.Optional[jsii.Number] = None,
        depends_on: typing.Optional[typing.List[cdktf.TerraformResource]] = None,
        lifecycle: typing.Optional[cdktf.TerraformResourceLifecycle] = None,
        provider: typing.Optional[cdktf.TerraformProvider] = None,
        categories: typing.List[builtins.str],
        locations: typing.List[builtins.str],
        name: builtins.str,
        retention_policy: typing.List["MonitorLogProfileRetentionPolicy"],
        servicebus_rule_id: typing.Optional[builtins.str] = None,
        storage_account_id: typing.Optional[builtins.str] = None,
        timeouts: typing.Optional["MonitorLogProfileTimeouts"] = None,
    ) -> None:
        """
        :param count: 
        :param depends_on: 
        :param lifecycle: 
        :param provider: 
        :param categories: 
        :param locations: 
        :param name: 
        :param retention_policy: retention_policy block.
        :param servicebus_rule_id: 
        :param storage_account_id: 
        :param timeouts: timeouts block.
        """
        if isinstance(lifecycle, dict):
            lifecycle = cdktf.TerraformResourceLifecycle(**lifecycle)
        if isinstance(timeouts, dict):
            timeouts = MonitorLogProfileTimeouts(**timeouts)
        self._values: typing.Dict[str, typing.Any] = {
            "categories": categories,
            "locations": locations,
            "name": name,
            "retention_policy": retention_policy,
        }
        if count is not None:
            self._values["count"] = count
        if depends_on is not None:
            self._values["depends_on"] = depends_on
        if lifecycle is not None:
            self._values["lifecycle"] = lifecycle
        if provider is not None:
            self._values["provider"] = provider
        if servicebus_rule_id is not None:
            self._values["servicebus_rule_id"] = servicebus_rule_id
        if storage_account_id is not None:
            self._values["storage_account_id"] = storage_account_id
        if timeouts is not None:
            self._values["timeouts"] = timeouts

    @builtins.property
    def count(self) -> typing.Optional[jsii.Number]:
        """
        :stability: experimental
        """
        result = self._values.get("count")
        return result

    @builtins.property
    def depends_on(self) -> typing.Optional[typing.List[cdktf.TerraformResource]]:
        """
        :stability: experimental
        """
        result = self._values.get("depends_on")
        return result

    @builtins.property
    def lifecycle(self) -> typing.Optional[cdktf.TerraformResourceLifecycle]:
        """
        :stability: experimental
        """
        result = self._values.get("lifecycle")
        return result

    @builtins.property
    def provider(self) -> typing.Optional[cdktf.TerraformProvider]:
        """
        :stability: experimental
        """
        result = self._values.get("provider")
        return result

    @builtins.property
    def categories(self) -> typing.List[builtins.str]:
        result = self._values.get("categories")
        assert result is not None, "Required property 'categories' is missing"
        return result

    @builtins.property
    def locations(self) -> typing.List[builtins.str]:
        result = self._values.get("locations")
        assert result is not None, "Required property 'locations' is missing"
        return result

    @builtins.property
    def name(self) -> builtins.str:
        result = self._values.get("name")
        assert result is not None, "Required property 'name' is missing"
        return result

    @builtins.property
    def retention_policy(self) -> typing.List["MonitorLogProfileRetentionPolicy"]:
        """retention_policy block."""
        result = self._values.get("retention_policy")
        assert result is not None, "Required property 'retention_policy' is missing"
        return result

    @builtins.property
    def servicebus_rule_id(self) -> typing.Optional[builtins.str]:
        result = self._values.get("servicebus_rule_id")
        return result

    @builtins.property
    def storage_account_id(self) -> typing.Optional[builtins.str]:
        result = self._values.get("storage_account_id")
        return result

    @builtins.property
    def timeouts(self) -> typing.Optional["MonitorLogProfileTimeouts"]:
        """timeouts block."""
        result = self._values.get("timeouts")
        return result

    def __eq__(self, rhs: typing.Any) -> builtins.bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs: typing.Any) -> builtins.bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return "MonitorLogProfileConfig(%s)" % ", ".join(
            k + "=" + repr(v) for k, v in self._values.items()
        )


@jsii.data_type(
    jsii_type="@cdktf/provider-azurerm.MonitorLogProfileRetentionPolicy",
    jsii_struct_bases=[],
    name_mapping={"enabled": "enabled", "days": "days"},
)
class MonitorLogProfileRetentionPolicy:
    def __init__(
        self,
        *,
        enabled: builtins.bool,
        days: typing.Optional[jsii.Number] = None,
    ) -> None:
        """
        :param enabled: 
        :param days: 
        """
        self._values: typing.Dict[str, typing.Any] = {
            "enabled": enabled,
        }
        if days is not None:
            self._values["days"] = days

    @builtins.property
    def enabled(self) -> builtins.bool:
        result = self._values.get("enabled")
        assert result is not None, "Required property 'enabled' is missing"
        return result

    @builtins.property
    def days(self) -> typing.Optional[jsii.Number]:
        result = self._values.get("days")
        return result

    def __eq__(self, rhs: typing.Any) -> builtins.bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs: typing.Any) -> builtins.bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return "MonitorLogProfileRetentionPolicy(%s)" % ", ".join(
            k + "=" + repr(v) for k, v in self._values.items()
        )


@jsii.data_type(
    jsii_type="@cdktf/provider-azurerm.MonitorLogProfileTimeouts",
    jsii_struct_bases=[],
    name_mapping={
        "create": "create",
        "delete": "delete",
        "read": "read",
        "update": "update",
    },
)
class MonitorLogProfileTimeouts:
    def __init__(
        self,
        *,
        create: typing.Optional[builtins.str] = None,
        delete: typing.Optional[builtins.str] = None,
        read: typing.Optional[builtins.str] = None,
        update: typing.Optional[builtins.str] = None,
    ) -> None:
        """
        :param create: 
        :param delete: 
        :param read: 
        :param update: 
        """
        self._values: typing.Dict[str, typing.Any] = {}
        if create is not None:
            self._values["create"] = create
        if delete is not None:
            self._values["delete"] = delete
        if read is not None:
            self._values["read"] = read
        if update is not None:
            self._values["update"] = update

    @builtins.property
    def create(self) -> typing.Optional[builtins.str]:
        result = self._values.get("create")
        return result

    @builtins.property
    def delete(self) -> typing.Optional[builtins.str]:
        result = self._values.get("delete")
        return result

    @builtins.property
    def read(self) -> typing.Optional[builtins.str]:
        result = self._values.get("read")
        return result

    @builtins.property
    def update(self) -> typing.Optional[builtins.str]:
        result = self._values.get("update")
        return result

    def __eq__(self, rhs: typing.Any) -> builtins.bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs: typing.Any) -> builtins.bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return "MonitorLogProfileTimeouts(%s)" % ", ".join(
            k + "=" + repr(v) for k, v in self._values.items()
        )


class MonitorMetricAlert(
    cdktf.TerraformResource,
    metaclass=jsii.JSIIMeta,
    jsii_type="@cdktf/provider-azurerm.MonitorMetricAlert",
):
    def __init__(
        self,
        scope: constructs.Construct,
        id: builtins.str,
        *,
        criteria: typing.List["MonitorMetricAlertCriteria"],
        name: builtins.str,
        resource_group_name: builtins.str,
        scopes: typing.List[builtins.str],
        action: typing.Optional[typing.List["MonitorMetricAlertAction"]] = None,
        auto_mitigate: typing.Optional[builtins.bool] = None,
        description: typing.Optional[builtins.str] = None,
        enabled: typing.Optional[builtins.bool] = None,
        frequency: typing.Optional[builtins.str] = None,
        severity: typing.Optional[jsii.Number] = None,
        tags: typing.Optional[typing.Mapping[builtins.str, builtins.str]] = None,
        timeouts: typing.Optional["MonitorMetricAlertTimeouts"] = None,
        window_size: typing.Optional[builtins.str] = None,
        count: typing.Optional[jsii.Number] = None,
        depends_on: typing.Optional[typing.List[cdktf.TerraformResource]] = None,
        lifecycle: typing.Optional[cdktf.TerraformResourceLifecycle] = None,
        provider: typing.Optional[cdktf.TerraformProvider] = None,
    ) -> None:
        """
        :param scope: -
        :param id: -
        :param criteria: criteria block.
        :param name: 
        :param resource_group_name: 
        :param scopes: 
        :param action: action block.
        :param auto_mitigate: 
        :param description: 
        :param enabled: 
        :param frequency: 
        :param severity: 
        :param tags: 
        :param timeouts: timeouts block.
        :param window_size: 
        :param count: 
        :param depends_on: 
        :param lifecycle: 
        :param provider: 
        """
        config = MonitorMetricAlertConfig(
            criteria=criteria,
            name=name,
            resource_group_name=resource_group_name,
            scopes=scopes,
            action=action,
            auto_mitigate=auto_mitigate,
            description=description,
            enabled=enabled,
            frequency=frequency,
            severity=severity,
            tags=tags,
            timeouts=timeouts,
            window_size=window_size,
            count=count,
            depends_on=depends_on,
            lifecycle=lifecycle,
            provider=provider,
        )

        jsii.create(MonitorMetricAlert, self, [scope, id, config])

    @jsii.member(jsii_name="synthesizeAttributes")
    def _synthesize_attributes(self) -> typing.Mapping[builtins.str, typing.Any]:
        return jsii.invoke(self, "synthesizeAttributes", [])

    @builtins.property # type: ignore
    @jsii.member(jsii_name="criteria")
    def criteria(self) -> typing.List["MonitorMetricAlertCriteria"]:
        return jsii.get(self, "criteria")

    @criteria.setter # type: ignore
    def criteria(self, value: typing.List["MonitorMetricAlertCriteria"]) -> None:
        jsii.set(self, "criteria", value)

    @builtins.property # type: ignore
    @jsii.member(jsii_name="name")
    def name(self) -> builtins.str:
        return jsii.get(self, "name")

    @name.setter # type: ignore
    def name(self, value: builtins.str) -> None:
        jsii.set(self, "name", value)

    @builtins.property # type: ignore
    @jsii.member(jsii_name="resourceGroupName")
    def resource_group_name(self) -> builtins.str:
        return jsii.get(self, "resourceGroupName")

    @resource_group_name.setter # type: ignore
    def resource_group_name(self, value: builtins.str) -> None:
        jsii.set(self, "resourceGroupName", value)

    @builtins.property # type: ignore
    @jsii.member(jsii_name="scopes")
    def scopes(self) -> typing.List[builtins.str]:
        return jsii.get(self, "scopes")

    @scopes.setter # type: ignore
    def scopes(self, value: typing.List[builtins.str]) -> None:
        jsii.set(self, "scopes", value)

    @builtins.property # type: ignore
    @jsii.member(jsii_name="action")
    def action(self) -> typing.Optional[typing.List["MonitorMetricAlertAction"]]:
        return jsii.get(self, "action")

    @action.setter # type: ignore
    def action(
        self,
        value: typing.Optional[typing.List["MonitorMetricAlertAction"]],
    ) -> None:
        jsii.set(self, "action", value)

    @builtins.property # type: ignore
    @jsii.member(jsii_name="autoMitigate")
    def auto_mitigate(self) -> typing.Optional[builtins.bool]:
        return jsii.get(self, "autoMitigate")

    @auto_mitigate.setter # type: ignore
    def auto_mitigate(self, value: typing.Optional[builtins.bool]) -> None:
        jsii.set(self, "autoMitigate", value)

    @builtins.property # type: ignore
    @jsii.member(jsii_name="description")
    def description(self) -> typing.Optional[builtins.str]:
        return jsii.get(self, "description")

    @description.setter # type: ignore
    def description(self, value: typing.Optional[builtins.str]) -> None:
        jsii.set(self, "description", value)

    @builtins.property # type: ignore
    @jsii.member(jsii_name="enabled")
    def enabled(self) -> typing.Optional[builtins.bool]:
        return jsii.get(self, "enabled")

    @enabled.setter # type: ignore
    def enabled(self, value: typing.Optional[builtins.bool]) -> None:
        jsii.set(self, "enabled", value)

    @builtins.property # type: ignore
    @jsii.member(jsii_name="frequency")
    def frequency(self) -> typing.Optional[builtins.str]:
        return jsii.get(self, "frequency")

    @frequency.setter # type: ignore
    def frequency(self, value: typing.Optional[builtins.str]) -> None:
        jsii.set(self, "frequency", value)

    @builtins.property # type: ignore
    @jsii.member(jsii_name="id")
    def id(self) -> typing.Optional[builtins.str]:
        return jsii.get(self, "id")

    @id.setter # type: ignore
    def id(self, value: typing.Optional[builtins.str]) -> None:
        jsii.set(self, "id", value)

    @builtins.property # type: ignore
    @jsii.member(jsii_name="severity")
    def severity(self) -> typing.Optional[jsii.Number]:
        return jsii.get(self, "severity")

    @severity.setter # type: ignore
    def severity(self, value: typing.Optional[jsii.Number]) -> None:
        jsii.set(self, "severity", value)

    @builtins.property # type: ignore
    @jsii.member(jsii_name="tags")
    def tags(self) -> typing.Optional[typing.Mapping[builtins.str, builtins.str]]:
        return jsii.get(self, "tags")

    @tags.setter # type: ignore
    def tags(
        self,
        value: typing.Optional[typing.Mapping[builtins.str, builtins.str]],
    ) -> None:
        jsii.set(self, "tags", value)

    @builtins.property # type: ignore
    @jsii.member(jsii_name="timeouts")
    def timeouts(self) -> typing.Optional["MonitorMetricAlertTimeouts"]:
        return jsii.get(self, "timeouts")

    @timeouts.setter # type: ignore
    def timeouts(self, value: typing.Optional["MonitorMetricAlertTimeouts"]) -> None:
        jsii.set(self, "timeouts", value)

    @builtins.property # type: ignore
    @jsii.member(jsii_name="windowSize")
    def window_size(self) -> typing.Optional[builtins.str]:
        return jsii.get(self, "windowSize")

    @window_size.setter # type: ignore
    def window_size(self, value: typing.Optional[builtins.str]) -> None:
        jsii.set(self, "windowSize", value)


@jsii.data_type(
    jsii_type="@cdktf/provider-azurerm.MonitorMetricAlertAction",
    jsii_struct_bases=[],
    name_mapping={
        "action_group_id": "actionGroupId",
        "webhook_properties": "webhookProperties",
    },
)
class MonitorMetricAlertAction:
    def __init__(
        self,
        *,
        action_group_id: builtins.str,
        webhook_properties: typing.Optional[typing.Mapping[builtins.str, builtins.str]] = None,
    ) -> None:
        """
        :param action_group_id: 
        :param webhook_properties: 
        """
        self._values: typing.Dict[str, typing.Any] = {
            "action_group_id": action_group_id,
        }
        if webhook_properties is not None:
            self._values["webhook_properties"] = webhook_properties

    @builtins.property
    def action_group_id(self) -> builtins.str:
        result = self._values.get("action_group_id")
        assert result is not None, "Required property 'action_group_id' is missing"
        return result

    @builtins.property
    def webhook_properties(
        self,
    ) -> typing.Optional[typing.Mapping[builtins.str, builtins.str]]:
        result = self._values.get("webhook_properties")
        return result

    def __eq__(self, rhs: typing.Any) -> builtins.bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs: typing.Any) -> builtins.bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return "MonitorMetricAlertAction(%s)" % ", ".join(
            k + "=" + repr(v) for k, v in self._values.items()
        )


@jsii.data_type(
    jsii_type="@cdktf/provider-azurerm.MonitorMetricAlertConfig",
    jsii_struct_bases=[cdktf.TerraformMetaArguments],
    name_mapping={
        "count": "count",
        "depends_on": "dependsOn",
        "lifecycle": "lifecycle",
        "provider": "provider",
        "criteria": "criteria",
        "name": "name",
        "resource_group_name": "resourceGroupName",
        "scopes": "scopes",
        "action": "action",
        "auto_mitigate": "autoMitigate",
        "description": "description",
        "enabled": "enabled",
        "frequency": "frequency",
        "severity": "severity",
        "tags": "tags",
        "timeouts": "timeouts",
        "window_size": "windowSize",
    },
)
class MonitorMetricAlertConfig(cdktf.TerraformMetaArguments):
    def __init__(
        self,
        *,
        count: typing.Optional[jsii.Number] = None,
        depends_on: typing.Optional[typing.List[cdktf.TerraformResource]] = None,
        lifecycle: typing.Optional[cdktf.TerraformResourceLifecycle] = None,
        provider: typing.Optional[cdktf.TerraformProvider] = None,
        criteria: typing.List["MonitorMetricAlertCriteria"],
        name: builtins.str,
        resource_group_name: builtins.str,
        scopes: typing.List[builtins.str],
        action: typing.Optional[typing.List[MonitorMetricAlertAction]] = None,
        auto_mitigate: typing.Optional[builtins.bool] = None,
        description: typing.Optional[builtins.str] = None,
        enabled: typing.Optional[builtins.bool] = None,
        frequency: typing.Optional[builtins.str] = None,
        severity: typing.Optional[jsii.Number] = None,
        tags: typing.Optional[typing.Mapping[builtins.str, builtins.str]] = None,
        timeouts: typing.Optional["MonitorMetricAlertTimeouts"] = None,
        window_size: typing.Optional[builtins.str] = None,
    ) -> None:
        """
        :param count: 
        :param depends_on: 
        :param lifecycle: 
        :param provider: 
        :param criteria: criteria block.
        :param name: 
        :param resource_group_name: 
        :param scopes: 
        :param action: action block.
        :param auto_mitigate: 
        :param description: 
        :param enabled: 
        :param frequency: 
        :param severity: 
        :param tags: 
        :param timeouts: timeouts block.
        :param window_size: 
        """
        if isinstance(lifecycle, dict):
            lifecycle = cdktf.TerraformResourceLifecycle(**lifecycle)
        if isinstance(timeouts, dict):
            timeouts = MonitorMetricAlertTimeouts(**timeouts)
        self._values: typing.Dict[str, typing.Any] = {
            "criteria": criteria,
            "name": name,
            "resource_group_name": resource_group_name,
            "scopes": scopes,
        }
        if count is not None:
            self._values["count"] = count
        if depends_on is not None:
            self._values["depends_on"] = depends_on
        if lifecycle is not None:
            self._values["lifecycle"] = lifecycle
        if provider is not None:
            self._values["provider"] = provider
        if action is not None:
            self._values["action"] = action
        if auto_mitigate is not None:
            self._values["auto_mitigate"] = auto_mitigate
        if description is not None:
            self._values["description"] = description
        if enabled is not None:
            self._values["enabled"] = enabled
        if frequency is not None:
            self._values["frequency"] = frequency
        if severity is not None:
            self._values["severity"] = severity
        if tags is not None:
            self._values["tags"] = tags
        if timeouts is not None:
            self._values["timeouts"] = timeouts
        if window_size is not None:
            self._values["window_size"] = window_size

    @builtins.property
    def count(self) -> typing.Optional[jsii.Number]:
        """
        :stability: experimental
        """
        result = self._values.get("count")
        return result

    @builtins.property
    def depends_on(self) -> typing.Optional[typing.List[cdktf.TerraformResource]]:
        """
        :stability: experimental
        """
        result = self._values.get("depends_on")
        return result

    @builtins.property
    def lifecycle(self) -> typing.Optional[cdktf.TerraformResourceLifecycle]:
        """
        :stability: experimental
        """
        result = self._values.get("lifecycle")
        return result

    @builtins.property
    def provider(self) -> typing.Optional[cdktf.TerraformProvider]:
        """
        :stability: experimental
        """
        result = self._values.get("provider")
        return result

    @builtins.property
    def criteria(self) -> typing.List["MonitorMetricAlertCriteria"]:
        """criteria block."""
        result = self._values.get("criteria")
        assert result is not None, "Required property 'criteria' is missing"
        return result

    @builtins.property
    def name(self) -> builtins.str:
        result = self._values.get("name")
        assert result is not None, "Required property 'name' is missing"
        return result

    @builtins.property
    def resource_group_name(self) -> builtins.str:
        result = self._values.get("resource_group_name")
        assert result is not None, "Required property 'resource_group_name' is missing"
        return result

    @builtins.property
    def scopes(self) -> typing.List[builtins.str]:
        result = self._values.get("scopes")
        assert result is not None, "Required property 'scopes' is missing"
        return result

    @builtins.property
    def action(self) -> typing.Optional[typing.List[MonitorMetricAlertAction]]:
        """action block."""
        result = self._values.get("action")
        return result

    @builtins.property
    def auto_mitigate(self) -> typing.Optional[builtins.bool]:
        result = self._values.get("auto_mitigate")
        return result

    @builtins.property
    def description(self) -> typing.Optional[builtins.str]:
        result = self._values.get("description")
        return result

    @builtins.property
    def enabled(self) -> typing.Optional[builtins.bool]:
        result = self._values.get("enabled")
        return result

    @builtins.property
    def frequency(self) -> typing.Optional[builtins.str]:
        result = self._values.get("frequency")
        return result

    @builtins.property
    def severity(self) -> typing.Optional[jsii.Number]:
        result = self._values.get("severity")
        return result

    @builtins.property
    def tags(self) -> typing.Optional[typing.Mapping[builtins.str, builtins.str]]:
        result = self._values.get("tags")
        return result

    @builtins.property
    def timeouts(self) -> typing.Optional["MonitorMetricAlertTimeouts"]:
        """timeouts block."""
        result = self._values.get("timeouts")
        return result

    @builtins.property
    def window_size(self) -> typing.Optional[builtins.str]:
        result = self._values.get("window_size")
        return result

    def __eq__(self, rhs: typing.Any) -> builtins.bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs: typing.Any) -> builtins.bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return "MonitorMetricAlertConfig(%s)" % ", ".join(
            k + "=" + repr(v) for k, v in self._values.items()
        )


@jsii.data_type(
    jsii_type="@cdktf/provider-azurerm.MonitorMetricAlertCriteria",
    jsii_struct_bases=[],
    name_mapping={
        "aggregation": "aggregation",
        "metric_name": "metricName",
        "metric_namespace": "metricNamespace",
        "operator": "operator",
        "threshold": "threshold",
        "dimension": "dimension",
    },
)
class MonitorMetricAlertCriteria:
    def __init__(
        self,
        *,
        aggregation: builtins.str,
        metric_name: builtins.str,
        metric_namespace: builtins.str,
        operator: builtins.str,
        threshold: jsii.Number,
        dimension: typing.Optional[typing.List["MonitorMetricAlertCriteriaDimension"]] = None,
    ) -> None:
        """
        :param aggregation: 
        :param metric_name: 
        :param metric_namespace: 
        :param operator: 
        :param threshold: 
        :param dimension: dimension block.
        """
        self._values: typing.Dict[str, typing.Any] = {
            "aggregation": aggregation,
            "metric_name": metric_name,
            "metric_namespace": metric_namespace,
            "operator": operator,
            "threshold": threshold,
        }
        if dimension is not None:
            self._values["dimension"] = dimension

    @builtins.property
    def aggregation(self) -> builtins.str:
        result = self._values.get("aggregation")
        assert result is not None, "Required property 'aggregation' is missing"
        return result

    @builtins.property
    def metric_name(self) -> builtins.str:
        result = self._values.get("metric_name")
        assert result is not None, "Required property 'metric_name' is missing"
        return result

    @builtins.property
    def metric_namespace(self) -> builtins.str:
        result = self._values.get("metric_namespace")
        assert result is not None, "Required property 'metric_namespace' is missing"
        return result

    @builtins.property
    def operator(self) -> builtins.str:
        result = self._values.get("operator")
        assert result is not None, "Required property 'operator' is missing"
        return result

    @builtins.property
    def threshold(self) -> jsii.Number:
        result = self._values.get("threshold")
        assert result is not None, "Required property 'threshold' is missing"
        return result

    @builtins.property
    def dimension(
        self,
    ) -> typing.Optional[typing.List["MonitorMetricAlertCriteriaDimension"]]:
        """dimension block."""
        result = self._values.get("dimension")
        return result

    def __eq__(self, rhs: typing.Any) -> builtins.bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs: typing.Any) -> builtins.bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return "MonitorMetricAlertCriteria(%s)" % ", ".join(
            k + "=" + repr(v) for k, v in self._values.items()
        )


@jsii.data_type(
    jsii_type="@cdktf/provider-azurerm.MonitorMetricAlertCriteriaDimension",
    jsii_struct_bases=[],
    name_mapping={"name": "name", "operator": "operator", "values": "values"},
)
class MonitorMetricAlertCriteriaDimension:
    def __init__(
        self,
        *,
        name: builtins.str,
        operator: builtins.str,
        values: typing.List[builtins.str],
    ) -> None:
        """
        :param name: 
        :param operator: 
        :param values: 
        """
        self._values: typing.Dict[str, typing.Any] = {
            "name": name,
            "operator": operator,
            "values": values,
        }

    @builtins.property
    def name(self) -> builtins.str:
        result = self._values.get("name")
        assert result is not None, "Required property 'name' is missing"
        return result

    @builtins.property
    def operator(self) -> builtins.str:
        result = self._values.get("operator")
        assert result is not None, "Required property 'operator' is missing"
        return result

    @builtins.property
    def values(self) -> typing.List[builtins.str]:
        result = self._values.get("values")
        assert result is not None, "Required property 'values' is missing"
        return result

    def __eq__(self, rhs: typing.Any) -> builtins.bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs: typing.Any) -> builtins.bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return "MonitorMetricAlertCriteriaDimension(%s)" % ", ".join(
            k + "=" + repr(v) for k, v in self._values.items()
        )


@jsii.data_type(
    jsii_type="@cdktf/provider-azurerm.MonitorMetricAlertTimeouts",
    jsii_struct_bases=[],
    name_mapping={
        "create": "create",
        "delete": "delete",
        "read": "read",
        "update": "update",
    },
)
class MonitorMetricAlertTimeouts:
    def __init__(
        self,
        *,
        create: typing.Optional[builtins.str] = None,
        delete: typing.Optional[builtins.str] = None,
        read: typing.Optional[builtins.str] = None,
        update: typing.Optional[builtins.str] = None,
    ) -> None:
        """
        :param create: 
        :param delete: 
        :param read: 
        :param update: 
        """
        self._values: typing.Dict[str, typing.Any] = {}
        if create is not None:
            self._values["create"] = create
        if delete is not None:
            self._values["delete"] = delete
        if read is not None:
            self._values["read"] = read
        if update is not None:
            self._values["update"] = update

    @builtins.property
    def create(self) -> typing.Optional[builtins.str]:
        result = self._values.get("create")
        return result

    @builtins.property
    def delete(self) -> typing.Optional[builtins.str]:
        result = self._values.get("delete")
        return result

    @builtins.property
    def read(self) -> typing.Optional[builtins.str]:
        result = self._values.get("read")
        return result

    @builtins.property
    def update(self) -> typing.Optional[builtins.str]:
        result = self._values.get("update")
        return result

    def __eq__(self, rhs: typing.Any) -> builtins.bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs: typing.Any) -> builtins.bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return "MonitorMetricAlertTimeouts(%s)" % ", ".join(
            k + "=" + repr(v) for k, v in self._values.items()
        )


class MssqlDatabaseVulnerabilityAssessmentRuleBaseline(
    cdktf.TerraformResource,
    metaclass=jsii.JSIIMeta,
    jsii_type="@cdktf/provider-azurerm.MssqlDatabaseVulnerabilityAssessmentRuleBaseline",
):
    def __init__(
        self,
        scope: constructs.Construct,
        id: builtins.str,
        *,
        baseline_result: typing.List["MssqlDatabaseVulnerabilityAssessmentRuleBaselineBaselineResult"],
        database_name: builtins.str,
        rule_id: builtins.str,
        server_vulnerability_assessment_id: builtins.str,
        baseline_name: typing.Optional[builtins.str] = None,
        timeouts: typing.Optional["MssqlDatabaseVulnerabilityAssessmentRuleBaselineTimeouts"] = None,
        count: typing.Optional[jsii.Number] = None,
        depends_on: typing.Optional[typing.List[cdktf.TerraformResource]] = None,
        lifecycle: typing.Optional[cdktf.TerraformResourceLifecycle] = None,
        provider: typing.Optional[cdktf.TerraformProvider] = None,
    ) -> None:
        """
        :param scope: -
        :param id: -
        :param baseline_result: baseline_result block.
        :param database_name: 
        :param rule_id: 
        :param server_vulnerability_assessment_id: 
        :param baseline_name: 
        :param timeouts: timeouts block.
        :param count: 
        :param depends_on: 
        :param lifecycle: 
        :param provider: 
        """
        config = MssqlDatabaseVulnerabilityAssessmentRuleBaselineConfig(
            baseline_result=baseline_result,
            database_name=database_name,
            rule_id=rule_id,
            server_vulnerability_assessment_id=server_vulnerability_assessment_id,
            baseline_name=baseline_name,
            timeouts=timeouts,
            count=count,
            depends_on=depends_on,
            lifecycle=lifecycle,
            provider=provider,
        )

        jsii.create(MssqlDatabaseVulnerabilityAssessmentRuleBaseline, self, [scope, id, config])

    @jsii.member(jsii_name="synthesizeAttributes")
    def _synthesize_attributes(self) -> typing.Mapping[builtins.str, typing.Any]:
        return jsii.invoke(self, "synthesizeAttributes", [])

    @builtins.property # type: ignore
    @jsii.member(jsii_name="baselineResult")
    def baseline_result(
        self,
    ) -> typing.List["MssqlDatabaseVulnerabilityAssessmentRuleBaselineBaselineResult"]:
        return jsii.get(self, "baselineResult")

    @baseline_result.setter # type: ignore
    def baseline_result(
        self,
        value: typing.List["MssqlDatabaseVulnerabilityAssessmentRuleBaselineBaselineResult"],
    ) -> None:
        jsii.set(self, "baselineResult", value)

    @builtins.property # type: ignore
    @jsii.member(jsii_name="databaseName")
    def database_name(self) -> builtins.str:
        return jsii.get(self, "databaseName")

    @database_name.setter # type: ignore
    def database_name(self, value: builtins.str) -> None:
        jsii.set(self, "databaseName", value)

    @builtins.property # type: ignore
    @jsii.member(jsii_name="ruleId")
    def rule_id(self) -> builtins.str:
        return jsii.get(self, "ruleId")

    @rule_id.setter # type: ignore
    def rule_id(self, value: builtins.str) -> None:
        jsii.set(self, "ruleId", value)

    @builtins.property # type: ignore
    @jsii.member(jsii_name="serverVulnerabilityAssessmentId")
    def server_vulnerability_assessment_id(self) -> builtins.str:
        return jsii.get(self, "serverVulnerabilityAssessmentId")

    @server_vulnerability_assessment_id.setter # type: ignore
    def server_vulnerability_assessment_id(self, value: builtins.str) -> None:
        jsii.set(self, "serverVulnerabilityAssessmentId", value)

    @builtins.property # type: ignore
    @jsii.member(jsii_name="baselineName")
    def baseline_name(self) -> typing.Optional[builtins.str]:
        return jsii.get(self, "baselineName")

    @baseline_name.setter # type: ignore
    def baseline_name(self, value: typing.Optional[builtins.str]) -> None:
        jsii.set(self, "baselineName", value)

    @builtins.property # type: ignore
    @jsii.member(jsii_name="id")
    def id(self) -> typing.Optional[builtins.str]:
        return jsii.get(self, "id")

    @id.setter # type: ignore
    def id(self, value: typing.Optional[builtins.str]) -> None:
        jsii.set(self, "id", value)

    @builtins.property # type: ignore
    @jsii.member(jsii_name="timeouts")
    def timeouts(
        self,
    ) -> typing.Optional["MssqlDatabaseVulnerabilityAssessmentRuleBaselineTimeouts"]:
        return jsii.get(self, "timeouts")

    @timeouts.setter # type: ignore
    def timeouts(
        self,
        value: typing.Optional["MssqlDatabaseVulnerabilityAssessmentRuleBaselineTimeouts"],
    ) -> None:
        jsii.set(self, "timeouts", value)


@jsii.data_type(
    jsii_type="@cdktf/provider-azurerm.MssqlDatabaseVulnerabilityAssessmentRuleBaselineBaselineResult",
    jsii_struct_bases=[],
    name_mapping={"result": "result"},
)
class MssqlDatabaseVulnerabilityAssessmentRuleBaselineBaselineResult:
    def __init__(self, *, result: typing.List[builtins.str]) -> None:
        """
        :param result: 
        """
        self._values: typing.Dict[str, typing.Any] = {
            "result": result,
        }

    @builtins.property
    def result(self) -> typing.List[builtins.str]:
        result = self._values.get("result")
        assert result is not None, "Required property 'result' is missing"
        return result

    def __eq__(self, rhs: typing.Any) -> builtins.bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs: typing.Any) -> builtins.bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return "MssqlDatabaseVulnerabilityAssessmentRuleBaselineBaselineResult(%s)" % ", ".join(
            k + "=" + repr(v) for k, v in self._values.items()
        )


@jsii.data_type(
    jsii_type="@cdktf/provider-azurerm.MssqlDatabaseVulnerabilityAssessmentRuleBaselineConfig",
    jsii_struct_bases=[cdktf.TerraformMetaArguments],
    name_mapping={
        "count": "count",
        "depends_on": "dependsOn",
        "lifecycle": "lifecycle",
        "provider": "provider",
        "baseline_result": "baselineResult",
        "database_name": "databaseName",
        "rule_id": "ruleId",
        "server_vulnerability_assessment_id": "serverVulnerabilityAssessmentId",
        "baseline_name": "baselineName",
        "timeouts": "timeouts",
    },
)
class MssqlDatabaseVulnerabilityAssessmentRuleBaselineConfig(
    cdktf.TerraformMetaArguments,
):
    def __init__(
        self,
        *,
        count: typing.Optional[jsii.Number] = None,
        depends_on: typing.Optional[typing.List[cdktf.TerraformResource]] = None,
        lifecycle: typing.Optional[cdktf.TerraformResourceLifecycle] = None,
        provider: typing.Optional[cdktf.TerraformProvider] = None,
        baseline_result: typing.List[MssqlDatabaseVulnerabilityAssessmentRuleBaselineBaselineResult],
        database_name: builtins.str,
        rule_id: builtins.str,
        server_vulnerability_assessment_id: builtins.str,
        baseline_name: typing.Optional[builtins.str] = None,
        timeouts: typing.Optional["MssqlDatabaseVulnerabilityAssessmentRuleBaselineTimeouts"] = None,
    ) -> None:
        """
        :param count: 
        :param depends_on: 
        :param lifecycle: 
        :param provider: 
        :param baseline_result: baseline_result block.
        :param database_name: 
        :param rule_id: 
        :param server_vulnerability_assessment_id: 
        :param baseline_name: 
        :param timeouts: timeouts block.
        """
        if isinstance(lifecycle, dict):
            lifecycle = cdktf.TerraformResourceLifecycle(**lifecycle)
        if isinstance(timeouts, dict):
            timeouts = MssqlDatabaseVulnerabilityAssessmentRuleBaselineTimeouts(**timeouts)
        self._values: typing.Dict[str, typing.Any] = {
            "baseline_result": baseline_result,
            "database_name": database_name,
            "rule_id": rule_id,
            "server_vulnerability_assessment_id": server_vulnerability_assessment_id,
        }
        if count is not None:
            self._values["count"] = count
        if depends_on is not None:
            self._values["depends_on"] = depends_on
        if lifecycle is not None:
            self._values["lifecycle"] = lifecycle
        if provider is not None:
            self._values["provider"] = provider
        if baseline_name is not None:
            self._values["baseline_name"] = baseline_name
        if timeouts is not None:
            self._values["timeouts"] = timeouts

    @builtins.property
    def count(self) -> typing.Optional[jsii.Number]:
        """
        :stability: experimental
        """
        result = self._values.get("count")
        return result

    @builtins.property
    def depends_on(self) -> typing.Optional[typing.List[cdktf.TerraformResource]]:
        """
        :stability: experimental
        """
        result = self._values.get("depends_on")
        return result

    @builtins.property
    def lifecycle(self) -> typing.Optional[cdktf.TerraformResourceLifecycle]:
        """
        :stability: experimental
        """
        result = self._values.get("lifecycle")
        return result

    @builtins.property
    def provider(self) -> typing.Optional[cdktf.TerraformProvider]:
        """
        :stability: experimental
        """
        result = self._values.get("provider")
        return result

    @builtins.property
    def baseline_result(
        self,
    ) -> typing.List[MssqlDatabaseVulnerabilityAssessmentRuleBaselineBaselineResult]:
        """baseline_result block."""
        result = self._values.get("baseline_result")
        assert result is not None, "Required property 'baseline_result' is missing"
        return result

    @builtins.property
    def database_name(self) -> builtins.str:
        result = self._values.get("database_name")
        assert result is not None, "Required property 'database_name' is missing"
        return result

    @builtins.property
    def rule_id(self) -> builtins.str:
        result = self._values.get("rule_id")
        assert result is not None, "Required property 'rule_id' is missing"
        return result

    @builtins.property
    def server_vulnerability_assessment_id(self) -> builtins.str:
        result = self._values.get("server_vulnerability_assessment_id")
        assert result is not None, "Required property 'server_vulnerability_assessment_id' is missing"
        return result

    @builtins.property
    def baseline_name(self) -> typing.Optional[builtins.str]:
        result = self._values.get("baseline_name")
        return result

    @builtins.property
    def timeouts(
        self,
    ) -> typing.Optional["MssqlDatabaseVulnerabilityAssessmentRuleBaselineTimeouts"]:
        """timeouts block."""
        result = self._values.get("timeouts")
        return result

    def __eq__(self, rhs: typing.Any) -> builtins.bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs: typing.Any) -> builtins.bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return "MssqlDatabaseVulnerabilityAssessmentRuleBaselineConfig(%s)" % ", ".join(
            k + "=" + repr(v) for k, v in self._values.items()
        )


@jsii.data_type(
    jsii_type="@cdktf/provider-azurerm.MssqlDatabaseVulnerabilityAssessmentRuleBaselineTimeouts",
    jsii_struct_bases=[],
    name_mapping={
        "create": "create",
        "delete": "delete",
        "read": "read",
        "update": "update",
    },
)
class MssqlDatabaseVulnerabilityAssessmentRuleBaselineTimeouts:
    def __init__(
        self,
        *,
        create: typing.Optional[builtins.str] = None,
        delete: typing.Optional[builtins.str] = None,
        read: typing.Optional[builtins.str] = None,
        update: typing.Optional[builtins.str] = None,
    ) -> None:
        """
        :param create: 
        :param delete: 
        :param read: 
        :param update: 
        """
        self._values: typing.Dict[str, typing.Any] = {}
        if create is not None:
            self._values["create"] = create
        if delete is not None:
            self._values["delete"] = delete
        if read is not None:
            self._values["read"] = read
        if update is not None:
            self._values["update"] = update

    @builtins.property
    def create(self) -> typing.Optional[builtins.str]:
        result = self._values.get("create")
        return result

    @builtins.property
    def delete(self) -> typing.Optional[builtins.str]:
        result = self._values.get("delete")
        return result

    @builtins.property
    def read(self) -> typing.Optional[builtins.str]:
        result = self._values.get("read")
        return result

    @builtins.property
    def update(self) -> typing.Optional[builtins.str]:
        result = self._values.get("update")
        return result

    def __eq__(self, rhs: typing.Any) -> builtins.bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs: typing.Any) -> builtins.bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return "MssqlDatabaseVulnerabilityAssessmentRuleBaselineTimeouts(%s)" % ", ".join(
            k + "=" + repr(v) for k, v in self._values.items()
        )


class MssqlElasticpool(
    cdktf.TerraformResource,
    metaclass=jsii.JSIIMeta,
    jsii_type="@cdktf/provider-azurerm.MssqlElasticpool",
):
    def __init__(
        self,
        scope: constructs.Construct,
        id: builtins.str,
        *,
        location: builtins.str,
        name: builtins.str,
        per_database_settings: typing.List["MssqlElasticpoolPerDatabaseSettings"],
        resource_group_name: builtins.str,
        server_name: builtins.str,
        sku: typing.List["MssqlElasticpoolSku"],
        max_size_bytes: typing.Optional[jsii.Number] = None,
        max_size_gb: typing.Optional[jsii.Number] = None,
        tags: typing.Optional[typing.Mapping[builtins.str, builtins.str]] = None,
        timeouts: typing.Optional["MssqlElasticpoolTimeouts"] = None,
        zone_redundant: typing.Optional[builtins.bool] = None,
        count: typing.Optional[jsii.Number] = None,
        depends_on: typing.Optional[typing.List[cdktf.TerraformResource]] = None,
        lifecycle: typing.Optional[cdktf.TerraformResourceLifecycle] = None,
        provider: typing.Optional[cdktf.TerraformProvider] = None,
    ) -> None:
        """
        :param scope: -
        :param id: -
        :param location: 
        :param name: 
        :param per_database_settings: per_database_settings block.
        :param resource_group_name: 
        :param server_name: 
        :param sku: sku block.
        :param max_size_bytes: 
        :param max_size_gb: 
        :param tags: 
        :param timeouts: timeouts block.
        :param zone_redundant: 
        :param count: 
        :param depends_on: 
        :param lifecycle: 
        :param provider: 
        """
        config = MssqlElasticpoolConfig(
            location=location,
            name=name,
            per_database_settings=per_database_settings,
            resource_group_name=resource_group_name,
            server_name=server_name,
            sku=sku,
            max_size_bytes=max_size_bytes,
            max_size_gb=max_size_gb,
            tags=tags,
            timeouts=timeouts,
            zone_redundant=zone_redundant,
            count=count,
            depends_on=depends_on,
            lifecycle=lifecycle,
            provider=provider,
        )

        jsii.create(MssqlElasticpool, self, [scope, id, config])

    @jsii.member(jsii_name="synthesizeAttributes")
    def _synthesize_attributes(self) -> typing.Mapping[builtins.str, typing.Any]:
        return jsii.invoke(self, "synthesizeAttributes", [])

    @builtins.property # type: ignore
    @jsii.member(jsii_name="location")
    def location(self) -> builtins.str:
        return jsii.get(self, "location")

    @location.setter # type: ignore
    def location(self, value: builtins.str) -> None:
        jsii.set(self, "location", value)

    @builtins.property # type: ignore
    @jsii.member(jsii_name="name")
    def name(self) -> builtins.str:
        return jsii.get(self, "name")

    @name.setter # type: ignore
    def name(self, value: builtins.str) -> None:
        jsii.set(self, "name", value)

    @builtins.property # type: ignore
    @jsii.member(jsii_name="perDatabaseSettings")
    def per_database_settings(
        self,
    ) -> typing.List["MssqlElasticpoolPerDatabaseSettings"]:
        return jsii.get(self, "perDatabaseSettings")

    @per_database_settings.setter # type: ignore
    def per_database_settings(
        self,
        value: typing.List["MssqlElasticpoolPerDatabaseSettings"],
    ) -> None:
        jsii.set(self, "perDatabaseSettings", value)

    @builtins.property # type: ignore
    @jsii.member(jsii_name="resourceGroupName")
    def resource_group_name(self) -> builtins.str:
        return jsii.get(self, "resourceGroupName")

    @resource_group_name.setter # type: ignore
    def resource_group_name(self, value: builtins.str) -> None:
        jsii.set(self, "resourceGroupName", value)

    @builtins.property # type: ignore
    @jsii.member(jsii_name="serverName")
    def server_name(self) -> builtins.str:
        return jsii.get(self, "serverName")

    @server_name.setter # type: ignore
    def server_name(self, value: builtins.str) -> None:
        jsii.set(self, "serverName", value)

    @builtins.property # type: ignore
    @jsii.member(jsii_name="sku")
    def sku(self) -> typing.List["MssqlElasticpoolSku"]:
        return jsii.get(self, "sku")

    @sku.setter # type: ignore
    def sku(self, value: typing.List["MssqlElasticpoolSku"]) -> None:
        jsii.set(self, "sku", value)

    @builtins.property # type: ignore
    @jsii.member(jsii_name="id")
    def id(self) -> typing.Optional[builtins.str]:
        return jsii.get(self, "id")

    @id.setter # type: ignore
    def id(self, value: typing.Optional[builtins.str]) -> None:
        jsii.set(self, "id", value)

    @builtins.property # type: ignore
    @jsii.member(jsii_name="maxSizeBytes")
    def max_size_bytes(self) -> typing.Optional[jsii.Number]:
        return jsii.get(self, "maxSizeBytes")

    @max_size_bytes.setter # type: ignore
    def max_size_bytes(self, value: typing.Optional[jsii.Number]) -> None:
        jsii.set(self, "maxSizeBytes", value)

    @builtins.property # type: ignore
    @jsii.member(jsii_name="maxSizeGb")
    def max_size_gb(self) -> typing.Optional[jsii.Number]:
        return jsii.get(self, "maxSizeGb")

    @max_size_gb.setter # type: ignore
    def max_size_gb(self, value: typing.Optional[jsii.Number]) -> None:
        jsii.set(self, "maxSizeGb", value)

    @builtins.property # type: ignore
    @jsii.member(jsii_name="tags")
    def tags(self) -> typing.Optional[typing.Mapping[builtins.str, builtins.str]]:
        return jsii.get(self, "tags")

    @tags.setter # type: ignore
    def tags(
        self,
        value: typing.Optional[typing.Mapping[builtins.str, builtins.str]],
    ) -> None:
        jsii.set(self, "tags", value)

    @builtins.property # type: ignore
    @jsii.member(jsii_name="timeouts")
    def timeouts(self) -> typing.Optional["MssqlElasticpoolTimeouts"]:
        return jsii.get(self, "timeouts")

    @timeouts.setter # type: ignore
    def timeouts(self, value: typing.Optional["MssqlElasticpoolTimeouts"]) -> None:
        jsii.set(self, "timeouts", value)

    @builtins.property # type: ignore
    @jsii.member(jsii_name="zoneRedundant")
    def zone_redundant(self) -> typing.Optional[builtins.bool]:
        return jsii.get(self, "zoneRedundant")

    @zone_redundant.setter # type: ignore
    def zone_redundant(self, value: typing.Optional[builtins.bool]) -> None:
        jsii.set(self, "zoneRedundant", value)


@jsii.data_type(
    jsii_type="@cdktf/provider-azurerm.MssqlElasticpoolConfig",
    jsii_struct_bases=[cdktf.TerraformMetaArguments],
    name_mapping={
        "count": "count",
        "depends_on": "dependsOn",
        "lifecycle": "lifecycle",
        "provider": "provider",
        "location": "location",
        "name": "name",
        "per_database_settings": "perDatabaseSettings",
        "resource_group_name": "resourceGroupName",
        "server_name": "serverName",
        "sku": "sku",
        "max_size_bytes": "maxSizeBytes",
        "max_size_gb": "maxSizeGb",
        "tags": "tags",
        "timeouts": "timeouts",
        "zone_redundant": "zoneRedundant",
    },
)
class MssqlElasticpoolConfig(cdktf.TerraformMetaArguments):
    def __init__(
        self,
        *,
        count: typing.Optional[jsii.Number] = None,
        depends_on: typing.Optional[typing.List[cdktf.TerraformResource]] = None,
        lifecycle: typing.Optional[cdktf.TerraformResourceLifecycle] = None,
        provider: typing.Optional[cdktf.TerraformProvider] = None,
        location: builtins.str,
        name: builtins.str,
        per_database_settings: typing.List["MssqlElasticpoolPerDatabaseSettings"],
        resource_group_name: builtins.str,
        server_name: builtins.str,
        sku: typing.List["MssqlElasticpoolSku"],
        max_size_bytes: typing.Optional[jsii.Number] = None,
        max_size_gb: typing.Optional[jsii.Number] = None,
        tags: typing.Optional[typing.Mapping[builtins.str, builtins.str]] = None,
        timeouts: typing.Optional["MssqlElasticpoolTimeouts"] = None,
        zone_redundant: typing.Optional[builtins.bool] = None,
    ) -> None:
        """
        :param count: 
        :param depends_on: 
        :param lifecycle: 
        :param provider: 
        :param location: 
        :param name: 
        :param per_database_settings: per_database_settings block.
        :param resource_group_name: 
        :param server_name: 
        :param sku: sku block.
        :param max_size_bytes: 
        :param max_size_gb: 
        :param tags: 
        :param timeouts: timeouts block.
        :param zone_redundant: 
        """
        if isinstance(lifecycle, dict):
            lifecycle = cdktf.TerraformResourceLifecycle(**lifecycle)
        if isinstance(timeouts, dict):
            timeouts = MssqlElasticpoolTimeouts(**timeouts)
        self._values: typing.Dict[str, typing.Any] = {
            "location": location,
            "name": name,
            "per_database_settings": per_database_settings,
            "resource_group_name": resource_group_name,
            "server_name": server_name,
            "sku": sku,
        }
        if count is not None:
            self._values["count"] = count
        if depends_on is not None:
            self._values["depends_on"] = depends_on
        if lifecycle is not None:
            self._values["lifecycle"] = lifecycle
        if provider is not None:
            self._values["provider"] = provider
        if max_size_bytes is not None:
            self._values["max_size_bytes"] = max_size_bytes
        if max_size_gb is not None:
            self._values["max_size_gb"] = max_size_gb
        if tags is not None:
            self._values["tags"] = tags
        if timeouts is not None:
            self._values["timeouts"] = timeouts
        if zone_redundant is not None:
            self._values["zone_redundant"] = zone_redundant

    @builtins.property
    def count(self) -> typing.Optional[jsii.Number]:
        """
        :stability: experimental
        """
        result = self._values.get("count")
        return result

    @builtins.property
    def depends_on(self) -> typing.Optional[typing.List[cdktf.TerraformResource]]:
        """
        :stability: experimental
        """
        result = self._values.get("depends_on")
        return result

    @builtins.property
    def lifecycle(self) -> typing.Optional[cdktf.TerraformResourceLifecycle]:
        """
        :stability: experimental
        """
        result = self._values.get("lifecycle")
        return result

    @builtins.property
    def provider(self) -> typing.Optional[cdktf.TerraformProvider]:
        """
        :stability: experimental
        """
        result = self._values.get("provider")
        return result

    @builtins.property
    def location(self) -> builtins.str:
        result = self._values.get("location")
        assert result is not None, "Required property 'location' is missing"
        return result

    @builtins.property
    def name(self) -> builtins.str:
        result = self._values.get("name")
        assert result is not None, "Required property 'name' is missing"
        return result

    @builtins.property
    def per_database_settings(
        self,
    ) -> typing.List["MssqlElasticpoolPerDatabaseSettings"]:
        """per_database_settings block."""
        result = self._values.get("per_database_settings")
        assert result is not None, "Required property 'per_database_settings' is missing"
        return result

    @builtins.property
    def resource_group_name(self) -> builtins.str:
        result = self._values.get("resource_group_name")
        assert result is not None, "Required property 'resource_group_name' is missing"
        return result

    @builtins.property
    def server_name(self) -> builtins.str:
        result = self._values.get("server_name")
        assert result is not None, "Required property 'server_name' is missing"
        return result

    @builtins.property
    def sku(self) -> typing.List["MssqlElasticpoolSku"]:
        """sku block."""
        result = self._values.get("sku")
        assert result is not None, "Required property 'sku' is missing"
        return result

    @builtins.property
    def max_size_bytes(self) -> typing.Optional[jsii.Number]:
        result = self._values.get("max_size_bytes")
        return result

    @builtins.property
    def max_size_gb(self) -> typing.Optional[jsii.Number]:
        result = self._values.get("max_size_gb")
        return result

    @builtins.property
    def tags(self) -> typing.Optional[typing.Mapping[builtins.str, builtins.str]]:
        result = self._values.get("tags")
        return result

    @builtins.property
    def timeouts(self) -> typing.Optional["MssqlElasticpoolTimeouts"]:
        """timeouts block."""
        result = self._values.get("timeouts")
        return result

    @builtins.property
    def zone_redundant(self) -> typing.Optional[builtins.bool]:
        result = self._values.get("zone_redundant")
        return result

    def __eq__(self, rhs: typing.Any) -> builtins.bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs: typing.Any) -> builtins.bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return "MssqlElasticpoolConfig(%s)" % ", ".join(
            k + "=" + repr(v) for k, v in self._values.items()
        )


@jsii.data_type(
    jsii_type="@cdktf/provider-azurerm.MssqlElasticpoolPerDatabaseSettings",
    jsii_struct_bases=[],
    name_mapping={"max_capacity": "maxCapacity", "min_capacity": "minCapacity"},
)
class MssqlElasticpoolPerDatabaseSettings:
    def __init__(self, *, max_capacity: jsii.Number, min_capacity: jsii.Number) -> None:
        """
        :param max_capacity: 
        :param min_capacity: 
        """
        self._values: typing.Dict[str, typing.Any] = {
            "max_capacity": max_capacity,
            "min_capacity": min_capacity,
        }

    @builtins.property
    def max_capacity(self) -> jsii.Number:
        result = self._values.get("max_capacity")
        assert result is not None, "Required property 'max_capacity' is missing"
        return result

    @builtins.property
    def min_capacity(self) -> jsii.Number:
        result = self._values.get("min_capacity")
        assert result is not None, "Required property 'min_capacity' is missing"
        return result

    def __eq__(self, rhs: typing.Any) -> builtins.bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs: typing.Any) -> builtins.bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return "MssqlElasticpoolPerDatabaseSettings(%s)" % ", ".join(
            k + "=" + repr(v) for k, v in self._values.items()
        )


@jsii.data_type(
    jsii_type="@cdktf/provider-azurerm.MssqlElasticpoolSku",
    jsii_struct_bases=[],
    name_mapping={
        "capacity": "capacity",
        "name": "name",
        "tier": "tier",
        "family": "family",
    },
)
class MssqlElasticpoolSku:
    def __init__(
        self,
        *,
        capacity: jsii.Number,
        name: builtins.str,
        tier: builtins.str,
        family: typing.Optional[builtins.str] = None,
    ) -> None:
        """
        :param capacity: 
        :param name: 
        :param tier: 
        :param family: 
        """
        self._values: typing.Dict[str, typing.Any] = {
            "capacity": capacity,
            "name": name,
            "tier": tier,
        }
        if family is not None:
            self._values["family"] = family

    @builtins.property
    def capacity(self) -> jsii.Number:
        result = self._values.get("capacity")
        assert result is not None, "Required property 'capacity' is missing"
        return result

    @builtins.property
    def name(self) -> builtins.str:
        result = self._values.get("name")
        assert result is not None, "Required property 'name' is missing"
        return result

    @builtins.property
    def tier(self) -> builtins.str:
        result = self._values.get("tier")
        assert result is not None, "Required property 'tier' is missing"
        return result

    @builtins.property
    def family(self) -> typing.Optional[builtins.str]:
        result = self._values.get("family")
        return result

    def __eq__(self, rhs: typing.Any) -> builtins.bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs: typing.Any) -> builtins.bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return "MssqlElasticpoolSku(%s)" % ", ".join(
            k + "=" + repr(v) for k, v in self._values.items()
        )


@jsii.data_type(
    jsii_type="@cdktf/provider-azurerm.MssqlElasticpoolTimeouts",
    jsii_struct_bases=[],
    name_mapping={
        "create": "create",
        "delete": "delete",
        "read": "read",
        "update": "update",
    },
)
class MssqlElasticpoolTimeouts:
    def __init__(
        self,
        *,
        create: typing.Optional[builtins.str] = None,
        delete: typing.Optional[builtins.str] = None,
        read: typing.Optional[builtins.str] = None,
        update: typing.Optional[builtins.str] = None,
    ) -> None:
        """
        :param create: 
        :param delete: 
        :param read: 
        :param update: 
        """
        self._values: typing.Dict[str, typing.Any] = {}
        if create is not None:
            self._values["create"] = create
        if delete is not None:
            self._values["delete"] = delete
        if read is not None:
            self._values["read"] = read
        if update is not None:
            self._values["update"] = update

    @builtins.property
    def create(self) -> typing.Optional[builtins.str]:
        result = self._values.get("create")
        return result

    @builtins.property
    def delete(self) -> typing.Optional[builtins.str]:
        result = self._values.get("delete")
        return result

    @builtins.property
    def read(self) -> typing.Optional[builtins.str]:
        result = self._values.get("read")
        return result

    @builtins.property
    def update(self) -> typing.Optional[builtins.str]:
        result = self._values.get("update")
        return result

    def __eq__(self, rhs: typing.Any) -> builtins.bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs: typing.Any) -> builtins.bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return "MssqlElasticpoolTimeouts(%s)" % ", ".join(
            k + "=" + repr(v) for k, v in self._values.items()
        )


class MssqlServerSecurityAlertPolicy(
    cdktf.TerraformResource,
    metaclass=jsii.JSIIMeta,
    jsii_type="@cdktf/provider-azurerm.MssqlServerSecurityAlertPolicy",
):
    def __init__(
        self,
        scope: constructs.Construct,
        id: builtins.str,
        *,
        resource_group_name: builtins.str,
        server_name: builtins.str,
        state: builtins.str,
        disabled_alerts: typing.Optional[typing.List[builtins.str]] = None,
        email_account_admins: typing.Optional[builtins.bool] = None,
        email_addresses: typing.Optional[typing.List[builtins.str]] = None,
        retention_days: typing.Optional[jsii.Number] = None,
        storage_account_access_key: typing.Optional[builtins.str] = None,
        storage_endpoint: typing.Optional[builtins.str] = None,
        timeouts: typing.Optional["MssqlServerSecurityAlertPolicyTimeouts"] = None,
        count: typing.Optional[jsii.Number] = None,
        depends_on: typing.Optional[typing.List[cdktf.TerraformResource]] = None,
        lifecycle: typing.Optional[cdktf.TerraformResourceLifecycle] = None,
        provider: typing.Optional[cdktf.TerraformProvider] = None,
    ) -> None:
        """
        :param scope: -
        :param id: -
        :param resource_group_name: 
        :param server_name: 
        :param state: 
        :param disabled_alerts: 
        :param email_account_admins: 
        :param email_addresses: 
        :param retention_days: 
        :param storage_account_access_key: 
        :param storage_endpoint: 
        :param timeouts: timeouts block.
        :param count: 
        :param depends_on: 
        :param lifecycle: 
        :param provider: 
        """
        config = MssqlServerSecurityAlertPolicyConfig(
            resource_group_name=resource_group_name,
            server_name=server_name,
            state=state,
            disabled_alerts=disabled_alerts,
            email_account_admins=email_account_admins,
            email_addresses=email_addresses,
            retention_days=retention_days,
            storage_account_access_key=storage_account_access_key,
            storage_endpoint=storage_endpoint,
            timeouts=timeouts,
            count=count,
            depends_on=depends_on,
            lifecycle=lifecycle,
            provider=provider,
        )

        jsii.create(MssqlServerSecurityAlertPolicy, self, [scope, id, config])

    @jsii.member(jsii_name="synthesizeAttributes")
    def _synthesize_attributes(self) -> typing.Mapping[builtins.str, typing.Any]:
        return jsii.invoke(self, "synthesizeAttributes", [])

    @builtins.property # type: ignore
    @jsii.member(jsii_name="resourceGroupName")
    def resource_group_name(self) -> builtins.str:
        return jsii.get(self, "resourceGroupName")

    @resource_group_name.setter # type: ignore
    def resource_group_name(self, value: builtins.str) -> None:
        jsii.set(self, "resourceGroupName", value)

    @builtins.property # type: ignore
    @jsii.member(jsii_name="serverName")
    def server_name(self) -> builtins.str:
        return jsii.get(self, "serverName")

    @server_name.setter # type: ignore
    def server_name(self, value: builtins.str) -> None:
        jsii.set(self, "serverName", value)

    @builtins.property # type: ignore
    @jsii.member(jsii_name="state")
    def state(self) -> builtins.str:
        return jsii.get(self, "state")

    @state.setter # type: ignore
    def state(self, value: builtins.str) -> None:
        jsii.set(self, "state", value)

    @builtins.property # type: ignore
    @jsii.member(jsii_name="disabledAlerts")
    def disabled_alerts(self) -> typing.Optional[typing.List[builtins.str]]:
        return jsii.get(self, "disabledAlerts")

    @disabled_alerts.setter # type: ignore
    def disabled_alerts(
        self,
        value: typing.Optional[typing.List[builtins.str]],
    ) -> None:
        jsii.set(self, "disabledAlerts", value)

    @builtins.property # type: ignore
    @jsii.member(jsii_name="emailAccountAdmins")
    def email_account_admins(self) -> typing.Optional[builtins.bool]:
        return jsii.get(self, "emailAccountAdmins")

    @email_account_admins.setter # type: ignore
    def email_account_admins(self, value: typing.Optional[builtins.bool]) -> None:
        jsii.set(self, "emailAccountAdmins", value)

    @builtins.property # type: ignore
    @jsii.member(jsii_name="emailAddresses")
    def email_addresses(self) -> typing.Optional[typing.List[builtins.str]]:
        return jsii.get(self, "emailAddresses")

    @email_addresses.setter # type: ignore
    def email_addresses(
        self,
        value: typing.Optional[typing.List[builtins.str]],
    ) -> None:
        jsii.set(self, "emailAddresses", value)

    @builtins.property # type: ignore
    @jsii.member(jsii_name="id")
    def id(self) -> typing.Optional[builtins.str]:
        return jsii.get(self, "id")

    @id.setter # type: ignore
    def id(self, value: typing.Optional[builtins.str]) -> None:
        jsii.set(self, "id", value)

    @builtins.property # type: ignore
    @jsii.member(jsii_name="retentionDays")
    def retention_days(self) -> typing.Optional[jsii.Number]:
        return jsii.get(self, "retentionDays")

    @retention_days.setter # type: ignore
    def retention_days(self, value: typing.Optional[jsii.Number]) -> None:
        jsii.set(self, "retentionDays", value)

    @builtins.property # type: ignore
    @jsii.member(jsii_name="storageAccountAccessKey")
    def storage_account_access_key(self) -> typing.Optional[builtins.str]:
        return jsii.get(self, "storageAccountAccessKey")

    @storage_account_access_key.setter # type: ignore
    def storage_account_access_key(self, value: typing.Optional[builtins.str]) -> None:
        jsii.set(self, "storageAccountAccessKey", value)

    @builtins.property # type: ignore
    @jsii.member(jsii_name="storageEndpoint")
    def storage_endpoint(self) -> typing.Optional[builtins.str]:
        return jsii.get(self, "storageEndpoint")

    @storage_endpoint.setter # type: ignore
    def storage_endpoint(self, value: typing.Optional[builtins.str]) -> None:
        jsii.set(self, "storageEndpoint", value)

    @builtins.property # type: ignore
    @jsii.member(jsii_name="timeouts")
    def timeouts(self) -> typing.Optional["MssqlServerSecurityAlertPolicyTimeouts"]:
        return jsii.get(self, "timeouts")

    @timeouts.setter # type: ignore
    def timeouts(
        self,
        value: typing.Optional["MssqlServerSecurityAlertPolicyTimeouts"],
    ) -> None:
        jsii.set(self, "timeouts", value)


@jsii.data_type(
    jsii_type="@cdktf/provider-azurerm.MssqlServerSecurityAlertPolicyConfig",
    jsii_struct_bases=[cdktf.TerraformMetaArguments],
    name_mapping={
        "count": "count",
        "depends_on": "dependsOn",
        "lifecycle": "lifecycle",
        "provider": "provider",
        "resource_group_name": "resourceGroupName",
        "server_name": "serverName",
        "state": "state",
        "disabled_alerts": "disabledAlerts",
        "email_account_admins": "emailAccountAdmins",
        "email_addresses": "emailAddresses",
        "retention_days": "retentionDays",
        "storage_account_access_key": "storageAccountAccessKey",
        "storage_endpoint": "storageEndpoint",
        "timeouts": "timeouts",
    },
)
class MssqlServerSecurityAlertPolicyConfig(cdktf.TerraformMetaArguments):
    def __init__(
        self,
        *,
        count: typing.Optional[jsii.Number] = None,
        depends_on: typing.Optional[typing.List[cdktf.TerraformResource]] = None,
        lifecycle: typing.Optional[cdktf.TerraformResourceLifecycle] = None,
        provider: typing.Optional[cdktf.TerraformProvider] = None,
        resource_group_name: builtins.str,
        server_name: builtins.str,
        state: builtins.str,
        disabled_alerts: typing.Optional[typing.List[builtins.str]] = None,
        email_account_admins: typing.Optional[builtins.bool] = None,
        email_addresses: typing.Optional[typing.List[builtins.str]] = None,
        retention_days: typing.Optional[jsii.Number] = None,
        storage_account_access_key: typing.Optional[builtins.str] = None,
        storage_endpoint: typing.Optional[builtins.str] = None,
        timeouts: typing.Optional["MssqlServerSecurityAlertPolicyTimeouts"] = None,
    ) -> None:
        """
        :param count: 
        :param depends_on: 
        :param lifecycle: 
        :param provider: 
        :param resource_group_name: 
        :param server_name: 
        :param state: 
        :param disabled_alerts: 
        :param email_account_admins: 
        :param email_addresses: 
        :param retention_days: 
        :param storage_account_access_key: 
        :param storage_endpoint: 
        :param timeouts: timeouts block.
        """
        if isinstance(lifecycle, dict):
            lifecycle = cdktf.TerraformResourceLifecycle(**lifecycle)
        if isinstance(timeouts, dict):
            timeouts = MssqlServerSecurityAlertPolicyTimeouts(**timeouts)
        self._values: typing.Dict[str, typing.Any] = {
            "resource_group_name": resource_group_name,
            "server_name": server_name,
            "state": state,
        }
        if count is not None:
            self._values["count"] = count
        if depends_on is not None:
            self._values["depends_on"] = depends_on
        if lifecycle is not None:
            self._values["lifecycle"] = lifecycle
        if provider is not None:
            self._values["provider"] = provider
        if disabled_alerts is not None:
            self._values["disabled_alerts"] = disabled_alerts
        if email_account_admins is not None:
            self._values["email_account_admins"] = email_account_admins
        if email_addresses is not None:
            self._values["email_addresses"] = email_addresses
        if retention_days is not None:
            self._values["retention_days"] = retention_days
        if storage_account_access_key is not None:
            self._values["storage_account_access_key"] = storage_account_access_key
        if storage_endpoint is not None:
            self._values["storage_endpoint"] = storage_endpoint
        if timeouts is not None:
            self._values["timeouts"] = timeouts

    @builtins.property
    def count(self) -> typing.Optional[jsii.Number]:
        """
        :stability: experimental
        """
        result = self._values.get("count")
        return result

    @builtins.property
    def depends_on(self) -> typing.Optional[typing.List[cdktf.TerraformResource]]:
        """
        :stability: experimental
        """
        result = self._values.get("depends_on")
        return result

    @builtins.property
    def lifecycle(self) -> typing.Optional[cdktf.TerraformResourceLifecycle]:
        """
        :stability: experimental
        """
        result = self._values.get("lifecycle")
        return result

    @builtins.property
    def provider(self) -> typing.Optional[cdktf.TerraformProvider]:
        """
        :stability: experimental
        """
        result = self._values.get("provider")
        return result

    @builtins.property
    def resource_group_name(self) -> builtins.str:
        result = self._values.get("resource_group_name")
        assert result is not None, "Required property 'resource_group_name' is missing"
        return result

    @builtins.property
    def server_name(self) -> builtins.str:
        result = self._values.get("server_name")
        assert result is not None, "Required property 'server_name' is missing"
        return result

    @builtins.property
    def state(self) -> builtins.str:
        result = self._values.get("state")
        assert result is not None, "Required property 'state' is missing"
        return result

    @builtins.property
    def disabled_alerts(self) -> typing.Optional[typing.List[builtins.str]]:
        result = self._values.get("disabled_alerts")
        return result

    @builtins.property
    def email_account_admins(self) -> typing.Optional[builtins.bool]:
        result = self._values.get("email_account_admins")
        return result

    @builtins.property
    def email_addresses(self) -> typing.Optional[typing.List[builtins.str]]:
        result = self._values.get("email_addresses")
        return result

    @builtins.property
    def retention_days(self) -> typing.Optional[jsii.Number]:
        result = self._values.get("retention_days")
        return result

    @builtins.property
    def storage_account_access_key(self) -> typing.Optional[builtins.str]:
        result = self._values.get("storage_account_access_key")
        return result

    @builtins.property
    def storage_endpoint(self) -> typing.Optional[builtins.str]:
        result = self._values.get("storage_endpoint")
        return result

    @builtins.property
    def timeouts(self) -> typing.Optional["MssqlServerSecurityAlertPolicyTimeouts"]:
        """timeouts block."""
        result = self._values.get("timeouts")
        return result

    def __eq__(self, rhs: typing.Any) -> builtins.bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs: typing.Any) -> builtins.bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return "MssqlServerSecurityAlertPolicyConfig(%s)" % ", ".join(
            k + "=" + repr(v) for k, v in self._values.items()
        )


@jsii.data_type(
    jsii_type="@cdktf/provider-azurerm.MssqlServerSecurityAlertPolicyTimeouts",
    jsii_struct_bases=[],
    name_mapping={
        "create": "create",
        "delete": "delete",
        "read": "read",
        "update": "update",
    },
)
class MssqlServerSecurityAlertPolicyTimeouts:
    def __init__(
        self,
        *,
        create: typing.Optional[builtins.str] = None,
        delete: typing.Optional[builtins.str] = None,
        read: typing.Optional[builtins.str] = None,
        update: typing.Optional[builtins.str] = None,
    ) -> None:
        """
        :param create: 
        :param delete: 
        :param read: 
        :param update: 
        """
        self._values: typing.Dict[str, typing.Any] = {}
        if create is not None:
            self._values["create"] = create
        if delete is not None:
            self._values["delete"] = delete
        if read is not None:
            self._values["read"] = read
        if update is not None:
            self._values["update"] = update

    @builtins.property
    def create(self) -> typing.Optional[builtins.str]:
        result = self._values.get("create")
        return result

    @builtins.property
    def delete(self) -> typing.Optional[builtins.str]:
        result = self._values.get("delete")
        return result

    @builtins.property
    def read(self) -> typing.Optional[builtins.str]:
        result = self._values.get("read")
        return result

    @builtins.property
    def update(self) -> typing.Optional[builtins.str]:
        result = self._values.get("update")
        return result

    def __eq__(self, rhs: typing.Any) -> builtins.bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs: typing.Any) -> builtins.bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return "MssqlServerSecurityAlertPolicyTimeouts(%s)" % ", ".join(
            k + "=" + repr(v) for k, v in self._values.items()
        )


class MssqlServerVulnerabilityAssessment(
    cdktf.TerraformResource,
    metaclass=jsii.JSIIMeta,
    jsii_type="@cdktf/provider-azurerm.MssqlServerVulnerabilityAssessment",
):
    def __init__(
        self,
        scope: constructs.Construct,
        id: builtins.str,
        *,
        server_security_alert_policy_id: builtins.str,
        storage_container_path: builtins.str,
        recurring_scans: typing.Optional[typing.List["MssqlServerVulnerabilityAssessmentRecurringScans"]] = None,
        storage_account_access_key: typing.Optional[builtins.str] = None,
        storage_container_sas_key: typing.Optional[builtins.str] = None,
        timeouts: typing.Optional["MssqlServerVulnerabilityAssessmentTimeouts"] = None,
        count: typing.Optional[jsii.Number] = None,
        depends_on: typing.Optional[typing.List[cdktf.TerraformResource]] = None,
        lifecycle: typing.Optional[cdktf.TerraformResourceLifecycle] = None,
        provider: typing.Optional[cdktf.TerraformProvider] = None,
    ) -> None:
        """
        :param scope: -
        :param id: -
        :param server_security_alert_policy_id: 
        :param storage_container_path: 
        :param recurring_scans: recurring_scans block.
        :param storage_account_access_key: 
        :param storage_container_sas_key: 
        :param timeouts: timeouts block.
        :param count: 
        :param depends_on: 
        :param lifecycle: 
        :param provider: 
        """
        config = MssqlServerVulnerabilityAssessmentConfig(
            server_security_alert_policy_id=server_security_alert_policy_id,
            storage_container_path=storage_container_path,
            recurring_scans=recurring_scans,
            storage_account_access_key=storage_account_access_key,
            storage_container_sas_key=storage_container_sas_key,
            timeouts=timeouts,
            count=count,
            depends_on=depends_on,
            lifecycle=lifecycle,
            provider=provider,
        )

        jsii.create(MssqlServerVulnerabilityAssessment, self, [scope, id, config])

    @jsii.member(jsii_name="synthesizeAttributes")
    def _synthesize_attributes(self) -> typing.Mapping[builtins.str, typing.Any]:
        return jsii.invoke(self, "synthesizeAttributes", [])

    @builtins.property # type: ignore
    @jsii.member(jsii_name="serverSecurityAlertPolicyId")
    def server_security_alert_policy_id(self) -> builtins.str:
        return jsii.get(self, "serverSecurityAlertPolicyId")

    @server_security_alert_policy_id.setter # type: ignore
    def server_security_alert_policy_id(self, value: builtins.str) -> None:
        jsii.set(self, "serverSecurityAlertPolicyId", value)

    @builtins.property # type: ignore
    @jsii.member(jsii_name="storageContainerPath")
    def storage_container_path(self) -> builtins.str:
        return jsii.get(self, "storageContainerPath")

    @storage_container_path.setter # type: ignore
    def storage_container_path(self, value: builtins.str) -> None:
        jsii.set(self, "storageContainerPath", value)

    @builtins.property # type: ignore
    @jsii.member(jsii_name="id")
    def id(self) -> typing.Optional[builtins.str]:
        return jsii.get(self, "id")

    @id.setter # type: ignore
    def id(self, value: typing.Optional[builtins.str]) -> None:
        jsii.set(self, "id", value)

    @builtins.property # type: ignore
    @jsii.member(jsii_name="recurringScans")
    def recurring_scans(
        self,
    ) -> typing.Optional[typing.List["MssqlServerVulnerabilityAssessmentRecurringScans"]]:
        return jsii.get(self, "recurringScans")

    @recurring_scans.setter # type: ignore
    def recurring_scans(
        self,
        value: typing.Optional[typing.List["MssqlServerVulnerabilityAssessmentRecurringScans"]],
    ) -> None:
        jsii.set(self, "recurringScans", value)

    @builtins.property # type: ignore
    @jsii.member(jsii_name="storageAccountAccessKey")
    def storage_account_access_key(self) -> typing.Optional[builtins.str]:
        return jsii.get(self, "storageAccountAccessKey")

    @storage_account_access_key.setter # type: ignore
    def storage_account_access_key(self, value: typing.Optional[builtins.str]) -> None:
        jsii.set(self, "storageAccountAccessKey", value)

    @builtins.property # type: ignore
    @jsii.member(jsii_name="storageContainerSasKey")
    def storage_container_sas_key(self) -> typing.Optional[builtins.str]:
        return jsii.get(self, "storageContainerSasKey")

    @storage_container_sas_key.setter # type: ignore
    def storage_container_sas_key(self, value: typing.Optional[builtins.str]) -> None:
        jsii.set(self, "storageContainerSasKey", value)

    @builtins.property # type: ignore
    @jsii.member(jsii_name="timeouts")
    def timeouts(self) -> typing.Optional["MssqlServerVulnerabilityAssessmentTimeouts"]:
        return jsii.get(self, "timeouts")

    @timeouts.setter # type: ignore
    def timeouts(
        self,
        value: typing.Optional["MssqlServerVulnerabilityAssessmentTimeouts"],
    ) -> None:
        jsii.set(self, "timeouts", value)


@jsii.data_type(
    jsii_type="@cdktf/provider-azurerm.MssqlServerVulnerabilityAssessmentConfig",
    jsii_struct_bases=[cdktf.TerraformMetaArguments],
    name_mapping={
        "count": "count",
        "depends_on": "dependsOn",
        "lifecycle": "lifecycle",
        "provider": "provider",
        "server_security_alert_policy_id": "serverSecurityAlertPolicyId",
        "storage_container_path": "storageContainerPath",
        "recurring_scans": "recurringScans",
        "storage_account_access_key": "storageAccountAccessKey",
        "storage_container_sas_key": "storageContainerSasKey",
        "timeouts": "timeouts",
    },
)
class MssqlServerVulnerabilityAssessmentConfig(cdktf.TerraformMetaArguments):
    def __init__(
        self,
        *,
        count: typing.Optional[jsii.Number] = None,
        depends_on: typing.Optional[typing.List[cdktf.TerraformResource]] = None,
        lifecycle: typing.Optional[cdktf.TerraformResourceLifecycle] = None,
        provider: typing.Optional[cdktf.TerraformProvider] = None,
        server_security_alert_policy_id: builtins.str,
        storage_container_path: builtins.str,
        recurring_scans: typing.Optional[typing.List["MssqlServerVulnerabilityAssessmentRecurringScans"]] = None,
        storage_account_access_key: typing.Optional[builtins.str] = None,
        storage_container_sas_key: typing.Optional[builtins.str] = None,
        timeouts: typing.Optional["MssqlServerVulnerabilityAssessmentTimeouts"] = None,
    ) -> None:
        """
        :param count: 
        :param depends_on: 
        :param lifecycle: 
        :param provider: 
        :param server_security_alert_policy_id: 
        :param storage_container_path: 
        :param recurring_scans: recurring_scans block.
        :param storage_account_access_key: 
        :param storage_container_sas_key: 
        :param timeouts: timeouts block.
        """
        if isinstance(lifecycle, dict):
            lifecycle = cdktf.TerraformResourceLifecycle(**lifecycle)
        if isinstance(timeouts, dict):
            timeouts = MssqlServerVulnerabilityAssessmentTimeouts(**timeouts)
        self._values: typing.Dict[str, typing.Any] = {
            "server_security_alert_policy_id": server_security_alert_policy_id,
            "storage_container_path": storage_container_path,
        }
        if count is not None:
            self._values["count"] = count
        if depends_on is not None:
            self._values["depends_on"] = depends_on
        if lifecycle is not None:
            self._values["lifecycle"] = lifecycle
        if provider is not None:
            self._values["provider"] = provider
        if recurring_scans is not None:
            self._values["recurring_scans"] = recurring_scans
        if storage_account_access_key is not None:
            self._values["storage_account_access_key"] = storage_account_access_key
        if storage_container_sas_key is not None:
            self._values["storage_container_sas_key"] = storage_container_sas_key
        if timeouts is not None:
            self._values["timeouts"] = timeouts

    @builtins.property
    def count(self) -> typing.Optional[jsii.Number]:
        """
        :stability: experimental
        """
        result = self._values.get("count")
        return result

    @builtins.property
    def depends_on(self) -> typing.Optional[typing.List[cdktf.TerraformResource]]:
        """
        :stability: experimental
        """
        result = self._values.get("depends_on")
        return result

    @builtins.property
    def lifecycle(self) -> typing.Optional[cdktf.TerraformResourceLifecycle]:
        """
        :stability: experimental
        """
        result = self._values.get("lifecycle")
        return result

    @builtins.property
    def provider(self) -> typing.Optional[cdktf.TerraformProvider]:
        """
        :stability: experimental
        """
        result = self._values.get("provider")
        return result

    @builtins.property
    def server_security_alert_policy_id(self) -> builtins.str:
        result = self._values.get("server_security_alert_policy_id")
        assert result is not None, "Required property 'server_security_alert_policy_id' is missing"
        return result

    @builtins.property
    def storage_container_path(self) -> builtins.str:
        result = self._values.get("storage_container_path")
        assert result is not None, "Required property 'storage_container_path' is missing"
        return result

    @builtins.property
    def recurring_scans(
        self,
    ) -> typing.Optional[typing.List["MssqlServerVulnerabilityAssessmentRecurringScans"]]:
        """recurring_scans block."""
        result = self._values.get("recurring_scans")
        return result

    @builtins.property
    def storage_account_access_key(self) -> typing.Optional[builtins.str]:
        result = self._values.get("storage_account_access_key")
        return result

    @builtins.property
    def storage_container_sas_key(self) -> typing.Optional[builtins.str]:
        result = self._values.get("storage_container_sas_key")
        return result

    @builtins.property
    def timeouts(self) -> typing.Optional["MssqlServerVulnerabilityAssessmentTimeouts"]:
        """timeouts block."""
        result = self._values.get("timeouts")
        return result

    def __eq__(self, rhs: typing.Any) -> builtins.bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs: typing.Any) -> builtins.bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return "MssqlServerVulnerabilityAssessmentConfig(%s)" % ", ".join(
            k + "=" + repr(v) for k, v in self._values.items()
        )


@jsii.data_type(
    jsii_type="@cdktf/provider-azurerm.MssqlServerVulnerabilityAssessmentRecurringScans",
    jsii_struct_bases=[],
    name_mapping={
        "emails": "emails",
        "email_subscription_admins": "emailSubscriptionAdmins",
        "enabled": "enabled",
    },
)
class MssqlServerVulnerabilityAssessmentRecurringScans:
    def __init__(
        self,
        *,
        emails: typing.Optional[typing.List[builtins.str]] = None,
        email_subscription_admins: typing.Optional[builtins.bool] = None,
        enabled: typing.Optional[builtins.bool] = None,
    ) -> None:
        """
        :param emails: 
        :param email_subscription_admins: 
        :param enabled: 
        """
        self._values: typing.Dict[str, typing.Any] = {}
        if emails is not None:
            self._values["emails"] = emails
        if email_subscription_admins is not None:
            self._values["email_subscription_admins"] = email_subscription_admins
        if enabled is not None:
            self._values["enabled"] = enabled

    @builtins.property
    def emails(self) -> typing.Optional[typing.List[builtins.str]]:
        result = self._values.get("emails")
        return result

    @builtins.property
    def email_subscription_admins(self) -> typing.Optional[builtins.bool]:
        result = self._values.get("email_subscription_admins")
        return result

    @builtins.property
    def enabled(self) -> typing.Optional[builtins.bool]:
        result = self._values.get("enabled")
        return result

    def __eq__(self, rhs: typing.Any) -> builtins.bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs: typing.Any) -> builtins.bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return "MssqlServerVulnerabilityAssessmentRecurringScans(%s)" % ", ".join(
            k + "=" + repr(v) for k, v in self._values.items()
        )


@jsii.data_type(
    jsii_type="@cdktf/provider-azurerm.MssqlServerVulnerabilityAssessmentTimeouts",
    jsii_struct_bases=[],
    name_mapping={
        "create": "create",
        "delete": "delete",
        "read": "read",
        "update": "update",
    },
)
class MssqlServerVulnerabilityAssessmentTimeouts:
    def __init__(
        self,
        *,
        create: typing.Optional[builtins.str] = None,
        delete: typing.Optional[builtins.str] = None,
        read: typing.Optional[builtins.str] = None,
        update: typing.Optional[builtins.str] = None,
    ) -> None:
        """
        :param create: 
        :param delete: 
        :param read: 
        :param update: 
        """
        self._values: typing.Dict[str, typing.Any] = {}
        if create is not None:
            self._values["create"] = create
        if delete is not None:
            self._values["delete"] = delete
        if read is not None:
            self._values["read"] = read
        if update is not None:
            self._values["update"] = update

    @builtins.property
    def create(self) -> typing.Optional[builtins.str]:
        result = self._values.get("create")
        return result

    @builtins.property
    def delete(self) -> typing.Optional[builtins.str]:
        result = self._values.get("delete")
        return result

    @builtins.property
    def read(self) -> typing.Optional[builtins.str]:
        result = self._values.get("read")
        return result

    @builtins.property
    def update(self) -> typing.Optional[builtins.str]:
        result = self._values.get("update")
        return result

    def __eq__(self, rhs: typing.Any) -> builtins.bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs: typing.Any) -> builtins.bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return "MssqlServerVulnerabilityAssessmentTimeouts(%s)" % ", ".join(
            k + "=" + repr(v) for k, v in self._values.items()
        )


class MysqlConfiguration(
    cdktf.TerraformResource,
    metaclass=jsii.JSIIMeta,
    jsii_type="@cdktf/provider-azurerm.MysqlConfiguration",
):
    def __init__(
        self,
        scope: constructs.Construct,
        id: builtins.str,
        *,
        name: builtins.str,
        resource_group_name: builtins.str,
        server_name: builtins.str,
        value: builtins.str,
        timeouts: typing.Optional["MysqlConfigurationTimeouts"] = None,
        count: typing.Optional[jsii.Number] = None,
        depends_on: typing.Optional[typing.List[cdktf.TerraformResource]] = None,
        lifecycle: typing.Optional[cdktf.TerraformResourceLifecycle] = None,
        provider: typing.Optional[cdktf.TerraformProvider] = None,
    ) -> None:
        """
        :param scope: -
        :param id: -
        :param name: 
        :param resource_group_name: 
        :param server_name: 
        :param value: 
        :param timeouts: timeouts block.
        :param count: 
        :param depends_on: 
        :param lifecycle: 
        :param provider: 
        """
        config = MysqlConfigurationConfig(
            name=name,
            resource_group_name=resource_group_name,
            server_name=server_name,
            value=value,
            timeouts=timeouts,
            count=count,
            depends_on=depends_on,
            lifecycle=lifecycle,
            provider=provider,
        )

        jsii.create(MysqlConfiguration, self, [scope, id, config])

    @jsii.member(jsii_name="synthesizeAttributes")
    def _synthesize_attributes(self) -> typing.Mapping[builtins.str, typing.Any]:
        return jsii.invoke(self, "synthesizeAttributes", [])

    @builtins.property # type: ignore
    @jsii.member(jsii_name="name")
    def name(self) -> builtins.str:
        return jsii.get(self, "name")

    @name.setter # type: ignore
    def name(self, value: builtins.str) -> None:
        jsii.set(self, "name", value)

    @builtins.property # type: ignore
    @jsii.member(jsii_name="resourceGroupName")
    def resource_group_name(self) -> builtins.str:
        return jsii.get(self, "resourceGroupName")

    @resource_group_name.setter # type: ignore
    def resource_group_name(self, value: builtins.str) -> None:
        jsii.set(self, "resourceGroupName", value)

    @builtins.property # type: ignore
    @jsii.member(jsii_name="serverName")
    def server_name(self) -> builtins.str:
        return jsii.get(self, "serverName")

    @server_name.setter # type: ignore
    def server_name(self, value: builtins.str) -> None:
        jsii.set(self, "serverName", value)

    @builtins.property # type: ignore
    @jsii.member(jsii_name="value")
    def value(self) -> builtins.str:
        return jsii.get(self, "value")

    @value.setter # type: ignore
    def value(self, value: builtins.str) -> None:
        jsii.set(self, "value", value)

    @builtins.property # type: ignore
    @jsii.member(jsii_name="id")
    def id(self) -> typing.Optional[builtins.str]:
        return jsii.get(self, "id")

    @id.setter # type: ignore
    def id(self, value: typing.Optional[builtins.str]) -> None:
        jsii.set(self, "id", value)

    @builtins.property # type: ignore
    @jsii.member(jsii_name="timeouts")
    def timeouts(self) -> typing.Optional["MysqlConfigurationTimeouts"]:
        return jsii.get(self, "timeouts")

    @timeouts.setter # type: ignore
    def timeouts(self, value: typing.Optional["MysqlConfigurationTimeouts"]) -> None:
        jsii.set(self, "timeouts", value)


@jsii.data_type(
    jsii_type="@cdktf/provider-azurerm.MysqlConfigurationConfig",
    jsii_struct_bases=[cdktf.TerraformMetaArguments],
    name_mapping={
        "count": "count",
        "depends_on": "dependsOn",
        "lifecycle": "lifecycle",
        "provider": "provider",
        "name": "name",
        "resource_group_name": "resourceGroupName",
        "server_name": "serverName",
        "value": "value",
        "timeouts": "timeouts",
    },
)
class MysqlConfigurationConfig(cdktf.TerraformMetaArguments):
    def __init__(
        self,
        *,
        count: typing.Optional[jsii.Number] = None,
        depends_on: typing.Optional[typing.List[cdktf.TerraformResource]] = None,
        lifecycle: typing.Optional[cdktf.TerraformResourceLifecycle] = None,
        provider: typing.Optional[cdktf.TerraformProvider] = None,
        name: builtins.str,
        resource_group_name: builtins.str,
        server_name: builtins.str,
        value: builtins.str,
        timeouts: typing.Optional["MysqlConfigurationTimeouts"] = None,
    ) -> None:
        """
        :param count: 
        :param depends_on: 
        :param lifecycle: 
        :param provider: 
        :param name: 
        :param resource_group_name: 
        :param server_name: 
        :param value: 
        :param timeouts: timeouts block.
        """
        if isinstance(lifecycle, dict):
            lifecycle = cdktf.TerraformResourceLifecycle(**lifecycle)
        if isinstance(timeouts, dict):
            timeouts = MysqlConfigurationTimeouts(**timeouts)
        self._values: typing.Dict[str, typing.Any] = {
            "name": name,
            "resource_group_name": resource_group_name,
            "server_name": server_name,
            "value": value,
        }
        if count is not None:
            self._values["count"] = count
        if depends_on is not None:
            self._values["depends_on"] = depends_on
        if lifecycle is not None:
            self._values["lifecycle"] = lifecycle
        if provider is not None:
            self._values["provider"] = provider
        if timeouts is not None:
            self._values["timeouts"] = timeouts

    @builtins.property
    def count(self) -> typing.Optional[jsii.Number]:
        """
        :stability: experimental
        """
        result = self._values.get("count")
        return result

    @builtins.property
    def depends_on(self) -> typing.Optional[typing.List[cdktf.TerraformResource]]:
        """
        :stability: experimental
        """
        result = self._values.get("depends_on")
        return result

    @builtins.property
    def lifecycle(self) -> typing.Optional[cdktf.TerraformResourceLifecycle]:
        """
        :stability: experimental
        """
        result = self._values.get("lifecycle")
        return result

    @builtins.property
    def provider(self) -> typing.Optional[cdktf.TerraformProvider]:
        """
        :stability: experimental
        """
        result = self._values.get("provider")
        return result

    @builtins.property
    def name(self) -> builtins.str:
        result = self._values.get("name")
        assert result is not None, "Required property 'name' is missing"
        return result

    @builtins.property
    def resource_group_name(self) -> builtins.str:
        result = self._values.get("resource_group_name")
        assert result is not None, "Required property 'resource_group_name' is missing"
        return result

    @builtins.property
    def server_name(self) -> builtins.str:
        result = self._values.get("server_name")
        assert result is not None, "Required property 'server_name' is missing"
        return result

    @builtins.property
    def value(self) -> builtins.str:
        result = self._values.get("value")
        assert result is not None, "Required property 'value' is missing"
        return result

    @builtins.property
    def timeouts(self) -> typing.Optional["MysqlConfigurationTimeouts"]:
        """timeouts block."""
        result = self._values.get("timeouts")
        return result

    def __eq__(self, rhs: typing.Any) -> builtins.bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs: typing.Any) -> builtins.bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return "MysqlConfigurationConfig(%s)" % ", ".join(
            k + "=" + repr(v) for k, v in self._values.items()
        )


@jsii.data_type(
    jsii_type="@cdktf/provider-azurerm.MysqlConfigurationTimeouts",
    jsii_struct_bases=[],
    name_mapping={
        "create": "create",
        "delete": "delete",
        "read": "read",
        "update": "update",
    },
)
class MysqlConfigurationTimeouts:
    def __init__(
        self,
        *,
        create: typing.Optional[builtins.str] = None,
        delete: typing.Optional[builtins.str] = None,
        read: typing.Optional[builtins.str] = None,
        update: typing.Optional[builtins.str] = None,
    ) -> None:
        """
        :param create: 
        :param delete: 
        :param read: 
        :param update: 
        """
        self._values: typing.Dict[str, typing.Any] = {}
        if create is not None:
            self._values["create"] = create
        if delete is not None:
            self._values["delete"] = delete
        if read is not None:
            self._values["read"] = read
        if update is not None:
            self._values["update"] = update

    @builtins.property
    def create(self) -> typing.Optional[builtins.str]:
        result = self._values.get("create")
        return result

    @builtins.property
    def delete(self) -> typing.Optional[builtins.str]:
        result = self._values.get("delete")
        return result

    @builtins.property
    def read(self) -> typing.Optional[builtins.str]:
        result = self._values.get("read")
        return result

    @builtins.property
    def update(self) -> typing.Optional[builtins.str]:
        result = self._values.get("update")
        return result

    def __eq__(self, rhs: typing.Any) -> builtins.bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs: typing.Any) -> builtins.bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return "MysqlConfigurationTimeouts(%s)" % ", ".join(
            k + "=" + repr(v) for k, v in self._values.items()
        )


class MysqlDatabase(
    cdktf.TerraformResource,
    metaclass=jsii.JSIIMeta,
    jsii_type="@cdktf/provider-azurerm.MysqlDatabase",
):
    def __init__(
        self,
        scope: constructs.Construct,
        id: builtins.str,
        *,
        charset: builtins.str,
        collation: builtins.str,
        name: builtins.str,
        resource_group_name: builtins.str,
        server_name: builtins.str,
        timeouts: typing.Optional["MysqlDatabaseTimeouts"] = None,
        count: typing.Optional[jsii.Number] = None,
        depends_on: typing.Optional[typing.List[cdktf.TerraformResource]] = None,
        lifecycle: typing.Optional[cdktf.TerraformResourceLifecycle] = None,
        provider: typing.Optional[cdktf.TerraformProvider] = None,
    ) -> None:
        """
        :param scope: -
        :param id: -
        :param charset: 
        :param collation: 
        :param name: 
        :param resource_group_name: 
        :param server_name: 
        :param timeouts: timeouts block.
        :param count: 
        :param depends_on: 
        :param lifecycle: 
        :param provider: 
        """
        config = MysqlDatabaseConfig(
            charset=charset,
            collation=collation,
            name=name,
            resource_group_name=resource_group_name,
            server_name=server_name,
            timeouts=timeouts,
            count=count,
            depends_on=depends_on,
            lifecycle=lifecycle,
            provider=provider,
        )

        jsii.create(MysqlDatabase, self, [scope, id, config])

    @jsii.member(jsii_name="synthesizeAttributes")
    def _synthesize_attributes(self) -> typing.Mapping[builtins.str, typing.Any]:
        return jsii.invoke(self, "synthesizeAttributes", [])

    @builtins.property # type: ignore
    @jsii.member(jsii_name="charset")
    def charset(self) -> builtins.str:
        return jsii.get(self, "charset")

    @charset.setter # type: ignore
    def charset(self, value: builtins.str) -> None:
        jsii.set(self, "charset", value)

    @builtins.property # type: ignore
    @jsii.member(jsii_name="collation")
    def collation(self) -> builtins.str:
        return jsii.get(self, "collation")

    @collation.setter # type: ignore
    def collation(self, value: builtins.str) -> None:
        jsii.set(self, "collation", value)

    @builtins.property # type: ignore
    @jsii.member(jsii_name="name")
    def name(self) -> builtins.str:
        return jsii.get(self, "name")

    @name.setter # type: ignore
    def name(self, value: builtins.str) -> None:
        jsii.set(self, "name", value)

    @builtins.property # type: ignore
    @jsii.member(jsii_name="resourceGroupName")
    def resource_group_name(self) -> builtins.str:
        return jsii.get(self, "resourceGroupName")

    @resource_group_name.setter # type: ignore
    def resource_group_name(self, value: builtins.str) -> None:
        jsii.set(self, "resourceGroupName", value)

    @builtins.property # type: ignore
    @jsii.member(jsii_name="serverName")
    def server_name(self) -> builtins.str:
        return jsii.get(self, "serverName")

    @server_name.setter # type: ignore
    def server_name(self, value: builtins.str) -> None:
        jsii.set(self, "serverName", value)

    @builtins.property # type: ignore
    @jsii.member(jsii_name="id")
    def id(self) -> typing.Optional[builtins.str]:
        return jsii.get(self, "id")

    @id.setter # type: ignore
    def id(self, value: typing.Optional[builtins.str]) -> None:
        jsii.set(self, "id", value)

    @builtins.property # type: ignore
    @jsii.member(jsii_name="timeouts")
    def timeouts(self) -> typing.Optional["MysqlDatabaseTimeouts"]:
        return jsii.get(self, "timeouts")

    @timeouts.setter # type: ignore
    def timeouts(self, value: typing.Optional["MysqlDatabaseTimeouts"]) -> None:
        jsii.set(self, "timeouts", value)


@jsii.data_type(
    jsii_type="@cdktf/provider-azurerm.MysqlDatabaseConfig",
    jsii_struct_bases=[cdktf.TerraformMetaArguments],
    name_mapping={
        "count": "count",
        "depends_on": "dependsOn",
        "lifecycle": "lifecycle",
        "provider": "provider",
        "charset": "charset",
        "collation": "collation",
        "name": "name",
        "resource_group_name": "resourceGroupName",
        "server_name": "serverName",
        "timeouts": "timeouts",
    },
)
class MysqlDatabaseConfig(cdktf.TerraformMetaArguments):
    def __init__(
        self,
        *,
        count: typing.Optional[jsii.Number] = None,
        depends_on: typing.Optional[typing.List[cdktf.TerraformResource]] = None,
        lifecycle: typing.Optional[cdktf.TerraformResourceLifecycle] = None,
        provider: typing.Optional[cdktf.TerraformProvider] = None,
        charset: builtins.str,
        collation: builtins.str,
        name: builtins.str,
        resource_group_name: builtins.str,
        server_name: builtins.str,
        timeouts: typing.Optional["MysqlDatabaseTimeouts"] = None,
    ) -> None:
        """
        :param count: 
        :param depends_on: 
        :param lifecycle: 
        :param provider: 
        :param charset: 
        :param collation: 
        :param name: 
        :param resource_group_name: 
        :param server_name: 
        :param timeouts: timeouts block.
        """
        if isinstance(lifecycle, dict):
            lifecycle = cdktf.TerraformResourceLifecycle(**lifecycle)
        if isinstance(timeouts, dict):
            timeouts = MysqlDatabaseTimeouts(**timeouts)
        self._values: typing.Dict[str, typing.Any] = {
            "charset": charset,
            "collation": collation,
            "name": name,
            "resource_group_name": resource_group_name,
            "server_name": server_name,
        }
        if count is not None:
            self._values["count"] = count
        if depends_on is not None:
            self._values["depends_on"] = depends_on
        if lifecycle is not None:
            self._values["lifecycle"] = lifecycle
        if provider is not None:
            self._values["provider"] = provider
        if timeouts is not None:
            self._values["timeouts"] = timeouts

    @builtins.property
    def count(self) -> typing.Optional[jsii.Number]:
        """
        :stability: experimental
        """
        result = self._values.get("count")
        return result

    @builtins.property
    def depends_on(self) -> typing.Optional[typing.List[cdktf.TerraformResource]]:
        """
        :stability: experimental
        """
        result = self._values.get("depends_on")
        return result

    @builtins.property
    def lifecycle(self) -> typing.Optional[cdktf.TerraformResourceLifecycle]:
        """
        :stability: experimental
        """
        result = self._values.get("lifecycle")
        return result

    @builtins.property
    def provider(self) -> typing.Optional[cdktf.TerraformProvider]:
        """
        :stability: experimental
        """
        result = self._values.get("provider")
        return result

    @builtins.property
    def charset(self) -> builtins.str:
        result = self._values.get("charset")
        assert result is not None, "Required property 'charset' is missing"
        return result

    @builtins.property
    def collation(self) -> builtins.str:
        result = self._values.get("collation")
        assert result is not None, "Required property 'collation' is missing"
        return result

    @builtins.property
    def name(self) -> builtins.str:
        result = self._values.get("name")
        assert result is not None, "Required property 'name' is missing"
        return result

    @builtins.property
    def resource_group_name(self) -> builtins.str:
        result = self._values.get("resource_group_name")
        assert result is not None, "Required property 'resource_group_name' is missing"
        return result

    @builtins.property
    def server_name(self) -> builtins.str:
        result = self._values.get("server_name")
        assert result is not None, "Required property 'server_name' is missing"
        return result

    @builtins.property
    def timeouts(self) -> typing.Optional["MysqlDatabaseTimeouts"]:
        """timeouts block."""
        result = self._values.get("timeouts")
        return result

    def __eq__(self, rhs: typing.Any) -> builtins.bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs: typing.Any) -> builtins.bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return "MysqlDatabaseConfig(%s)" % ", ".join(
            k + "=" + repr(v) for k, v in self._values.items()
        )


@jsii.data_type(
    jsii_type="@cdktf/provider-azurerm.MysqlDatabaseTimeouts",
    jsii_struct_bases=[],
    name_mapping={
        "create": "create",
        "delete": "delete",
        "read": "read",
        "update": "update",
    },
)
class MysqlDatabaseTimeouts:
    def __init__(
        self,
        *,
        create: typing.Optional[builtins.str] = None,
        delete: typing.Optional[builtins.str] = None,
        read: typing.Optional[builtins.str] = None,
        update: typing.Optional[builtins.str] = None,
    ) -> None:
        """
        :param create: 
        :param delete: 
        :param read: 
        :param update: 
        """
        self._values: typing.Dict[str, typing.Any] = {}
        if create is not None:
            self._values["create"] = create
        if delete is not None:
            self._values["delete"] = delete
        if read is not None:
            self._values["read"] = read
        if update is not None:
            self._values["update"] = update

    @builtins.property
    def create(self) -> typing.Optional[builtins.str]:
        result = self._values.get("create")
        return result

    @builtins.property
    def delete(self) -> typing.Optional[builtins.str]:
        result = self._values.get("delete")
        return result

    @builtins.property
    def read(self) -> typing.Optional[builtins.str]:
        result = self._values.get("read")
        return result

    @builtins.property
    def update(self) -> typing.Optional[builtins.str]:
        result = self._values.get("update")
        return result

    def __eq__(self, rhs: typing.Any) -> builtins.bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs: typing.Any) -> builtins.bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return "MysqlDatabaseTimeouts(%s)" % ", ".join(
            k + "=" + repr(v) for k, v in self._values.items()
        )


class MysqlFirewallRule(
    cdktf.TerraformResource,
    metaclass=jsii.JSIIMeta,
    jsii_type="@cdktf/provider-azurerm.MysqlFirewallRule",
):
    def __init__(
        self,
        scope: constructs.Construct,
        id: builtins.str,
        *,
        end_ip_address: builtins.str,
        name: builtins.str,
        resource_group_name: builtins.str,
        server_name: builtins.str,
        start_ip_address: builtins.str,
        timeouts: typing.Optional["MysqlFirewallRuleTimeouts"] = None,
        count: typing.Optional[jsii.Number] = None,
        depends_on: typing.Optional[typing.List[cdktf.TerraformResource]] = None,
        lifecycle: typing.Optional[cdktf.TerraformResourceLifecycle] = None,
        provider: typing.Optional[cdktf.TerraformProvider] = None,
    ) -> None:
        """
        :param scope: -
        :param id: -
        :param end_ip_address: 
        :param name: 
        :param resource_group_name: 
        :param server_name: 
        :param start_ip_address: 
        :param timeouts: timeouts block.
        :param count: 
        :param depends_on: 
        :param lifecycle: 
        :param provider: 
        """
        config = MysqlFirewallRuleConfig(
            end_ip_address=end_ip_address,
            name=name,
            resource_group_name=resource_group_name,
            server_name=server_name,
            start_ip_address=start_ip_address,
            timeouts=timeouts,
            count=count,
            depends_on=depends_on,
            lifecycle=lifecycle,
            provider=provider,
        )

        jsii.create(MysqlFirewallRule, self, [scope, id, config])

    @jsii.member(jsii_name="synthesizeAttributes")
    def _synthesize_attributes(self) -> typing.Mapping[builtins.str, typing.Any]:
        return jsii.invoke(self, "synthesizeAttributes", [])

    @builtins.property # type: ignore
    @jsii.member(jsii_name="endIpAddress")
    def end_ip_address(self) -> builtins.str:
        return jsii.get(self, "endIpAddress")

    @end_ip_address.setter # type: ignore
    def end_ip_address(self, value: builtins.str) -> None:
        jsii.set(self, "endIpAddress", value)

    @builtins.property # type: ignore
    @jsii.member(jsii_name="name")
    def name(self) -> builtins.str:
        return jsii.get(self, "name")

    @name.setter # type: ignore
    def name(self, value: builtins.str) -> None:
        jsii.set(self, "name", value)

    @builtins.property # type: ignore
    @jsii.member(jsii_name="resourceGroupName")
    def resource_group_name(self) -> builtins.str:
        return jsii.get(self, "resourceGroupName")

    @resource_group_name.setter # type: ignore
    def resource_group_name(self, value: builtins.str) -> None:
        jsii.set(self, "resourceGroupName", value)

    @builtins.property # type: ignore
    @jsii.member(jsii_name="serverName")
    def server_name(self) -> builtins.str:
        return jsii.get(self, "serverName")

    @server_name.setter # type: ignore
    def server_name(self, value: builtins.str) -> None:
        jsii.set(self, "serverName", value)

    @builtins.property # type: ignore
    @jsii.member(jsii_name="startIpAddress")
    def start_ip_address(self) -> builtins.str:
        return jsii.get(self, "startIpAddress")

    @start_ip_address.setter # type: ignore
    def start_ip_address(self, value: builtins.str) -> None:
        jsii.set(self, "startIpAddress", value)

    @builtins.property # type: ignore
    @jsii.member(jsii_name="id")
    def id(self) -> typing.Optional[builtins.str]:
        return jsii.get(self, "id")

    @id.setter # type: ignore
    def id(self, value: typing.Optional[builtins.str]) -> None:
        jsii.set(self, "id", value)

    @builtins.property # type: ignore
    @jsii.member(jsii_name="timeouts")
    def timeouts(self) -> typing.Optional["MysqlFirewallRuleTimeouts"]:
        return jsii.get(self, "timeouts")

    @timeouts.setter # type: ignore
    def timeouts(self, value: typing.Optional["MysqlFirewallRuleTimeouts"]) -> None:
        jsii.set(self, "timeouts", value)


@jsii.data_type(
    jsii_type="@cdktf/provider-azurerm.MysqlFirewallRuleConfig",
    jsii_struct_bases=[cdktf.TerraformMetaArguments],
    name_mapping={
        "count": "count",
        "depends_on": "dependsOn",
        "lifecycle": "lifecycle",
        "provider": "provider",
        "end_ip_address": "endIpAddress",
        "name": "name",
        "resource_group_name": "resourceGroupName",
        "server_name": "serverName",
        "start_ip_address": "startIpAddress",
        "timeouts": "timeouts",
    },
)
class MysqlFirewallRuleConfig(cdktf.TerraformMetaArguments):
    def __init__(
        self,
        *,
        count: typing.Optional[jsii.Number] = None,
        depends_on: typing.Optional[typing.List[cdktf.TerraformResource]] = None,
        lifecycle: typing.Optional[cdktf.TerraformResourceLifecycle] = None,
        provider: typing.Optional[cdktf.TerraformProvider] = None,
        end_ip_address: builtins.str,
        name: builtins.str,
        resource_group_name: builtins.str,
        server_name: builtins.str,
        start_ip_address: builtins.str,
        timeouts: typing.Optional["MysqlFirewallRuleTimeouts"] = None,
    ) -> None:
        """
        :param count: 
        :param depends_on: 
        :param lifecycle: 
        :param provider: 
        :param end_ip_address: 
        :param name: 
        :param resource_group_name: 
        :param server_name: 
        :param start_ip_address: 
        :param timeouts: timeouts block.
        """
        if isinstance(lifecycle, dict):
            lifecycle = cdktf.TerraformResourceLifecycle(**lifecycle)
        if isinstance(timeouts, dict):
            timeouts = MysqlFirewallRuleTimeouts(**timeouts)
        self._values: typing.Dict[str, typing.Any] = {
            "end_ip_address": end_ip_address,
            "name": name,
            "resource_group_name": resource_group_name,
            "server_name": server_name,
            "start_ip_address": start_ip_address,
        }
        if count is not None:
            self._values["count"] = count
        if depends_on is not None:
            self._values["depends_on"] = depends_on
        if lifecycle is not None:
            self._values["lifecycle"] = lifecycle
        if provider is not None:
            self._values["provider"] = provider
        if timeouts is not None:
            self._values["timeouts"] = timeouts

    @builtins.property
    def count(self) -> typing.Optional[jsii.Number]:
        """
        :stability: experimental
        """
        result = self._values.get("count")
        return result

    @builtins.property
    def depends_on(self) -> typing.Optional[typing.List[cdktf.TerraformResource]]:
        """
        :stability: experimental
        """
        result = self._values.get("depends_on")
        return result

    @builtins.property
    def lifecycle(self) -> typing.Optional[cdktf.TerraformResourceLifecycle]:
        """
        :stability: experimental
        """
        result = self._values.get("lifecycle")
        return result

    @builtins.property
    def provider(self) -> typing.Optional[cdktf.TerraformProvider]:
        """
        :stability: experimental
        """
        result = self._values.get("provider")
        return result

    @builtins.property
    def end_ip_address(self) -> builtins.str:
        result = self._values.get("end_ip_address")
        assert result is not None, "Required property 'end_ip_address' is missing"
        return result

    @builtins.property
    def name(self) -> builtins.str:
        result = self._values.get("name")
        assert result is not None, "Required property 'name' is missing"
        return result

    @builtins.property
    def resource_group_name(self) -> builtins.str:
        result = self._values.get("resource_group_name")
        assert result is not None, "Required property 'resource_group_name' is missing"
        return result

    @builtins.property
    def server_name(self) -> builtins.str:
        result = self._values.get("server_name")
        assert result is not None, "Required property 'server_name' is missing"
        return result

    @builtins.property
    def start_ip_address(self) -> builtins.str:
        result = self._values.get("start_ip_address")
        assert result is not None, "Required property 'start_ip_address' is missing"
        return result

    @builtins.property
    def timeouts(self) -> typing.Optional["MysqlFirewallRuleTimeouts"]:
        """timeouts block."""
        result = self._values.get("timeouts")
        return result

    def __eq__(self, rhs: typing.Any) -> builtins.bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs: typing.Any) -> builtins.bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return "MysqlFirewallRuleConfig(%s)" % ", ".join(
            k + "=" + repr(v) for k, v in self._values.items()
        )


@jsii.data_type(
    jsii_type="@cdktf/provider-azurerm.MysqlFirewallRuleTimeouts",
    jsii_struct_bases=[],
    name_mapping={
        "create": "create",
        "delete": "delete",
        "read": "read",
        "update": "update",
    },
)
class MysqlFirewallRuleTimeouts:
    def __init__(
        self,
        *,
        create: typing.Optional[builtins.str] = None,
        delete: typing.Optional[builtins.str] = None,
        read: typing.Optional[builtins.str] = None,
        update: typing.Optional[builtins.str] = None,
    ) -> None:
        """
        :param create: 
        :param delete: 
        :param read: 
        :param update: 
        """
        self._values: typing.Dict[str, typing.Any] = {}
        if create is not None:
            self._values["create"] = create
        if delete is not None:
            self._values["delete"] = delete
        if read is not None:
            self._values["read"] = read
        if update is not None:
            self._values["update"] = update

    @builtins.property
    def create(self) -> typing.Optional[builtins.str]:
        result = self._values.get("create")
        return result

    @builtins.property
    def delete(self) -> typing.Optional[builtins.str]:
        result = self._values.get("delete")
        return result

    @builtins.property
    def read(self) -> typing.Optional[builtins.str]:
        result = self._values.get("read")
        return result

    @builtins.property
    def update(self) -> typing.Optional[builtins.str]:
        result = self._values.get("update")
        return result

    def __eq__(self, rhs: typing.Any) -> builtins.bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs: typing.Any) -> builtins.bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return "MysqlFirewallRuleTimeouts(%s)" % ", ".join(
            k + "=" + repr(v) for k, v in self._values.items()
        )


class MysqlServer(
    cdktf.TerraformResource,
    metaclass=jsii.JSIIMeta,
    jsii_type="@cdktf/provider-azurerm.MysqlServer",
):
    def __init__(
        self,
        scope: constructs.Construct,
        id: builtins.str,
        *,
        administrator_login: builtins.str,
        administrator_login_password: builtins.str,
        location: builtins.str,
        name: builtins.str,
        resource_group_name: builtins.str,
        sku_name: builtins.str,
        ssl_enforcement: builtins.str,
        storage_profile: typing.List["MysqlServerStorageProfile"],
        version: builtins.str,
        tags: typing.Optional[typing.Mapping[builtins.str, builtins.str]] = None,
        timeouts: typing.Optional["MysqlServerTimeouts"] = None,
        count: typing.Optional[jsii.Number] = None,
        depends_on: typing.Optional[typing.List[cdktf.TerraformResource]] = None,
        lifecycle: typing.Optional[cdktf.TerraformResourceLifecycle] = None,
        provider: typing.Optional[cdktf.TerraformProvider] = None,
    ) -> None:
        """
        :param scope: -
        :param id: -
        :param administrator_login: 
        :param administrator_login_password: 
        :param location: 
        :param name: 
        :param resource_group_name: 
        :param sku_name: 
        :param ssl_enforcement: 
        :param storage_profile: storage_profile block.
        :param version: 
        :param tags: 
        :param timeouts: timeouts block.
        :param count: 
        :param depends_on: 
        :param lifecycle: 
        :param provider: 
        """
        config = MysqlServerConfig(
            administrator_login=administrator_login,
            administrator_login_password=administrator_login_password,
            location=location,
            name=name,
            resource_group_name=resource_group_name,
            sku_name=sku_name,
            ssl_enforcement=ssl_enforcement,
            storage_profile=storage_profile,
            version=version,
            tags=tags,
            timeouts=timeouts,
            count=count,
            depends_on=depends_on,
            lifecycle=lifecycle,
            provider=provider,
        )

        jsii.create(MysqlServer, self, [scope, id, config])

    @jsii.member(jsii_name="synthesizeAttributes")
    def _synthesize_attributes(self) -> typing.Mapping[builtins.str, typing.Any]:
        return jsii.invoke(self, "synthesizeAttributes", [])

    @builtins.property # type: ignore
    @jsii.member(jsii_name="fqdn")
    def fqdn(self) -> builtins.str:
        return jsii.get(self, "fqdn")

    @builtins.property # type: ignore
    @jsii.member(jsii_name="administratorLogin")
    def administrator_login(self) -> builtins.str:
        return jsii.get(self, "administratorLogin")

    @administrator_login.setter # type: ignore
    def administrator_login(self, value: builtins.str) -> None:
        jsii.set(self, "administratorLogin", value)

    @builtins.property # type: ignore
    @jsii.member(jsii_name="administratorLoginPassword")
    def administrator_login_password(self) -> builtins.str:
        return jsii.get(self, "administratorLoginPassword")

    @administrator_login_password.setter # type: ignore
    def administrator_login_password(self, value: builtins.str) -> None:
        jsii.set(self, "administratorLoginPassword", value)

    @builtins.property # type: ignore
    @jsii.member(jsii_name="location")
    def location(self) -> builtins.str:
        return jsii.get(self, "location")

    @location.setter # type: ignore
    def location(self, value: builtins.str) -> None:
        jsii.set(self, "location", value)

    @builtins.property # type: ignore
    @jsii.member(jsii_name="name")
    def name(self) -> builtins.str:
        return jsii.get(self, "name")

    @name.setter # type: ignore
    def name(self, value: builtins.str) -> None:
        jsii.set(self, "name", value)

    @builtins.property # type: ignore
    @jsii.member(jsii_name="resourceGroupName")
    def resource_group_name(self) -> builtins.str:
        return jsii.get(self, "resourceGroupName")

    @resource_group_name.setter # type: ignore
    def resource_group_name(self, value: builtins.str) -> None:
        jsii.set(self, "resourceGroupName", value)

    @builtins.property # type: ignore
    @jsii.member(jsii_name="skuName")
    def sku_name(self) -> builtins.str:
        return jsii.get(self, "skuName")

    @sku_name.setter # type: ignore
    def sku_name(self, value: builtins.str) -> None:
        jsii.set(self, "skuName", value)

    @builtins.property # type: ignore
    @jsii.member(jsii_name="sslEnforcement")
    def ssl_enforcement(self) -> builtins.str:
        return jsii.get(self, "sslEnforcement")

    @ssl_enforcement.setter # type: ignore
    def ssl_enforcement(self, value: builtins.str) -> None:
        jsii.set(self, "sslEnforcement", value)

    @builtins.property # type: ignore
    @jsii.member(jsii_name="storageProfile")
    def storage_profile(self) -> typing.List["MysqlServerStorageProfile"]:
        return jsii.get(self, "storageProfile")

    @storage_profile.setter # type: ignore
    def storage_profile(self, value: typing.List["MysqlServerStorageProfile"]) -> None:
        jsii.set(self, "storageProfile", value)

    @builtins.property # type: ignore
    @jsii.member(jsii_name="version")
    def version(self) -> builtins.str:
        return jsii.get(self, "version")

    @version.setter # type: ignore
    def version(self, value: builtins.str) -> None:
        jsii.set(self, "version", value)

    @builtins.property # type: ignore
    @jsii.member(jsii_name="id")
    def id(self) -> typing.Optional[builtins.str]:
        return jsii.get(self, "id")

    @id.setter # type: ignore
    def id(self, value: typing.Optional[builtins.str]) -> None:
        jsii.set(self, "id", value)

    @builtins.property # type: ignore
    @jsii.member(jsii_name="tags")
    def tags(self) -> typing.Optional[typing.Mapping[builtins.str, builtins.str]]:
        return jsii.get(self, "tags")

    @tags.setter # type: ignore
    def tags(
        self,
        value: typing.Optional[typing.Mapping[builtins.str, builtins.str]],
    ) -> None:
        jsii.set(self, "tags", value)

    @builtins.property # type: ignore
    @jsii.member(jsii_name="timeouts")
    def timeouts(self) -> typing.Optional["MysqlServerTimeouts"]:
        return jsii.get(self, "timeouts")

    @timeouts.setter # type: ignore
    def timeouts(self, value: typing.Optional["MysqlServerTimeouts"]) -> None:
        jsii.set(self, "timeouts", value)


@jsii.data_type(
    jsii_type="@cdktf/provider-azurerm.MysqlServerConfig",
    jsii_struct_bases=[cdktf.TerraformMetaArguments],
    name_mapping={
        "count": "count",
        "depends_on": "dependsOn",
        "lifecycle": "lifecycle",
        "provider": "provider",
        "administrator_login": "administratorLogin",
        "administrator_login_password": "administratorLoginPassword",
        "location": "location",
        "name": "name",
        "resource_group_name": "resourceGroupName",
        "sku_name": "skuName",
        "ssl_enforcement": "sslEnforcement",
        "storage_profile": "storageProfile",
        "version": "version",
        "tags": "tags",
        "timeouts": "timeouts",
    },
)
class MysqlServerConfig(cdktf.TerraformMetaArguments):
    def __init__(
        self,
        *,
        count: typing.Optional[jsii.Number] = None,
        depends_on: typing.Optional[typing.List[cdktf.TerraformResource]] = None,
        lifecycle: typing.Optional[cdktf.TerraformResourceLifecycle] = None,
        provider: typing.Optional[cdktf.TerraformProvider] = None,
        administrator_login: builtins.str,
        administrator_login_password: builtins.str,
        location: builtins.str,
        name: builtins.str,
        resource_group_name: builtins.str,
        sku_name: builtins.str,
        ssl_enforcement: builtins.str,
        storage_profile: typing.List["MysqlServerStorageProfile"],
        version: builtins.str,
        tags: typing.Optional[typing.Mapping[builtins.str, builtins.str]] = None,
        timeouts: typing.Optional["MysqlServerTimeouts"] = None,
    ) -> None:
        """
        :param count: 
        :param depends_on: 
        :param lifecycle: 
        :param provider: 
        :param administrator_login: 
        :param administrator_login_password: 
        :param location: 
        :param name: 
        :param resource_group_name: 
        :param sku_name: 
        :param ssl_enforcement: 
        :param storage_profile: storage_profile block.
        :param version: 
        :param tags: 
        :param timeouts: timeouts block.
        """
        if isinstance(lifecycle, dict):
            lifecycle = cdktf.TerraformResourceLifecycle(**lifecycle)
        if isinstance(timeouts, dict):
            timeouts = MysqlServerTimeouts(**timeouts)
        self._values: typing.Dict[str, typing.Any] = {
            "administrator_login": administrator_login,
            "administrator_login_password": administrator_login_password,
            "location": location,
            "name": name,
            "resource_group_name": resource_group_name,
            "sku_name": sku_name,
            "ssl_enforcement": ssl_enforcement,
            "storage_profile": storage_profile,
            "version": version,
        }
        if count is not None:
            self._values["count"] = count
        if depends_on is not None:
            self._values["depends_on"] = depends_on
        if lifecycle is not None:
            self._values["lifecycle"] = lifecycle
        if provider is not None:
            self._values["provider"] = provider
        if tags is not None:
            self._values["tags"] = tags
        if timeouts is not None:
            self._values["timeouts"] = timeouts

    @builtins.property
    def count(self) -> typing.Optional[jsii.Number]:
        """
        :stability: experimental
        """
        result = self._values.get("count")
        return result

    @builtins.property
    def depends_on(self) -> typing.Optional[typing.List[cdktf.TerraformResource]]:
        """
        :stability: experimental
        """
        result = self._values.get("depends_on")
        return result

    @builtins.property
    def lifecycle(self) -> typing.Optional[cdktf.TerraformResourceLifecycle]:
        """
        :stability: experimental
        """
        result = self._values.get("lifecycle")
        return result

    @builtins.property
    def provider(self) -> typing.Optional[cdktf.TerraformProvider]:
        """
        :stability: experimental
        """
        result = self._values.get("provider")
        return result

    @builtins.property
    def administrator_login(self) -> builtins.str:
        result = self._values.get("administrator_login")
        assert result is not None, "Required property 'administrator_login' is missing"
        return result

    @builtins.property
    def administrator_login_password(self) -> builtins.str:
        result = self._values.get("administrator_login_password")
        assert result is not None, "Required property 'administrator_login_password' is missing"
        return result

    @builtins.property
    def location(self) -> builtins.str:
        result = self._values.get("location")
        assert result is not None, "Required property 'location' is missing"
        return result

    @builtins.property
    def name(self) -> builtins.str:
        result = self._values.get("name")
        assert result is not None, "Required property 'name' is missing"
        return result

    @builtins.property
    def resource_group_name(self) -> builtins.str:
        result = self._values.get("resource_group_name")
        assert result is not None, "Required property 'resource_group_name' is missing"
        return result

    @builtins.property
    def sku_name(self) -> builtins.str:
        result = self._values.get("sku_name")
        assert result is not None, "Required property 'sku_name' is missing"
        return result

    @builtins.property
    def ssl_enforcement(self) -> builtins.str:
        result = self._values.get("ssl_enforcement")
        assert result is not None, "Required property 'ssl_enforcement' is missing"
        return result

    @builtins.property
    def storage_profile(self) -> typing.List["MysqlServerStorageProfile"]:
        """storage_profile block."""
        result = self._values.get("storage_profile")
        assert result is not None, "Required property 'storage_profile' is missing"
        return result

    @builtins.property
    def version(self) -> builtins.str:
        result = self._values.get("version")
        assert result is not None, "Required property 'version' is missing"
        return result

    @builtins.property
    def tags(self) -> typing.Optional[typing.Mapping[builtins.str, builtins.str]]:
        result = self._values.get("tags")
        return result

    @builtins.property
    def timeouts(self) -> typing.Optional["MysqlServerTimeouts"]:
        """timeouts block."""
        result = self._values.get("timeouts")
        return result

    def __eq__(self, rhs: typing.Any) -> builtins.bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs: typing.Any) -> builtins.bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return "MysqlServerConfig(%s)" % ", ".join(
            k + "=" + repr(v) for k, v in self._values.items()
        )


@jsii.data_type(
    jsii_type="@cdktf/provider-azurerm.MysqlServerStorageProfile",
    jsii_struct_bases=[],
    name_mapping={
        "storage_mb": "storageMb",
        "auto_grow": "autoGrow",
        "backup_retention_days": "backupRetentionDays",
        "geo_redundant_backup": "geoRedundantBackup",
    },
)
class MysqlServerStorageProfile:
    def __init__(
        self,
        *,
        storage_mb: jsii.Number,
        auto_grow: typing.Optional[builtins.str] = None,
        backup_retention_days: typing.Optional[jsii.Number] = None,
        geo_redundant_backup: typing.Optional[builtins.str] = None,
    ) -> None:
        """
        :param storage_mb: 
        :param auto_grow: 
        :param backup_retention_days: 
        :param geo_redundant_backup: 
        """
        self._values: typing.Dict[str, typing.Any] = {
            "storage_mb": storage_mb,
        }
        if auto_grow is not None:
            self._values["auto_grow"] = auto_grow
        if backup_retention_days is not None:
            self._values["backup_retention_days"] = backup_retention_days
        if geo_redundant_backup is not None:
            self._values["geo_redundant_backup"] = geo_redundant_backup

    @builtins.property
    def storage_mb(self) -> jsii.Number:
        result = self._values.get("storage_mb")
        assert result is not None, "Required property 'storage_mb' is missing"
        return result

    @builtins.property
    def auto_grow(self) -> typing.Optional[builtins.str]:
        result = self._values.get("auto_grow")
        return result

    @builtins.property
    def backup_retention_days(self) -> typing.Optional[jsii.Number]:
        result = self._values.get("backup_retention_days")
        return result

    @builtins.property
    def geo_redundant_backup(self) -> typing.Optional[builtins.str]:
        result = self._values.get("geo_redundant_backup")
        return result

    def __eq__(self, rhs: typing.Any) -> builtins.bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs: typing.Any) -> builtins.bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return "MysqlServerStorageProfile(%s)" % ", ".join(
            k + "=" + repr(v) for k, v in self._values.items()
        )


@jsii.data_type(
    jsii_type="@cdktf/provider-azurerm.MysqlServerTimeouts",
    jsii_struct_bases=[],
    name_mapping={
        "create": "create",
        "delete": "delete",
        "read": "read",
        "update": "update",
    },
)
class MysqlServerTimeouts:
    def __init__(
        self,
        *,
        create: typing.Optional[builtins.str] = None,
        delete: typing.Optional[builtins.str] = None,
        read: typing.Optional[builtins.str] = None,
        update: typing.Optional[builtins.str] = None,
    ) -> None:
        """
        :param create: 
        :param delete: 
        :param read: 
        :param update: 
        """
        self._values: typing.Dict[str, typing.Any] = {}
        if create is not None:
            self._values["create"] = create
        if delete is not None:
            self._values["delete"] = delete
        if read is not None:
            self._values["read"] = read
        if update is not None:
            self._values["update"] = update

    @builtins.property
    def create(self) -> typing.Optional[builtins.str]:
        result = self._values.get("create")
        return result

    @builtins.property
    def delete(self) -> typing.Optional[builtins.str]:
        result = self._values.get("delete")
        return result

    @builtins.property
    def read(self) -> typing.Optional[builtins.str]:
        result = self._values.get("read")
        return result

    @builtins.property
    def update(self) -> typing.Optional[builtins.str]:
        result = self._values.get("update")
        return result

    def __eq__(self, rhs: typing.Any) -> builtins.bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs: typing.Any) -> builtins.bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return "MysqlServerTimeouts(%s)" % ", ".join(
            k + "=" + repr(v) for k, v in self._values.items()
        )


class MysqlVirtualNetworkRule(
    cdktf.TerraformResource,
    metaclass=jsii.JSIIMeta,
    jsii_type="@cdktf/provider-azurerm.MysqlVirtualNetworkRule",
):
    def __init__(
        self,
        scope: constructs.Construct,
        id: builtins.str,
        *,
        name: builtins.str,
        resource_group_name: builtins.str,
        server_name: builtins.str,
        subnet_id: builtins.str,
        timeouts: typing.Optional["MysqlVirtualNetworkRuleTimeouts"] = None,
        count: typing.Optional[jsii.Number] = None,
        depends_on: typing.Optional[typing.List[cdktf.TerraformResource]] = None,
        lifecycle: typing.Optional[cdktf.TerraformResourceLifecycle] = None,
        provider: typing.Optional[cdktf.TerraformProvider] = None,
    ) -> None:
        """
        :param scope: -
        :param id: -
        :param name: 
        :param resource_group_name: 
        :param server_name: 
        :param subnet_id: 
        :param timeouts: timeouts block.
        :param count: 
        :param depends_on: 
        :param lifecycle: 
        :param provider: 
        """
        config = MysqlVirtualNetworkRuleConfig(
            name=name,
            resource_group_name=resource_group_name,
            server_name=server_name,
            subnet_id=subnet_id,
            timeouts=timeouts,
            count=count,
            depends_on=depends_on,
            lifecycle=lifecycle,
            provider=provider,
        )

        jsii.create(MysqlVirtualNetworkRule, self, [scope, id, config])

    @jsii.member(jsii_name="synthesizeAttributes")
    def _synthesize_attributes(self) -> typing.Mapping[builtins.str, typing.Any]:
        return jsii.invoke(self, "synthesizeAttributes", [])

    @builtins.property # type: ignore
    @jsii.member(jsii_name="name")
    def name(self) -> builtins.str:
        return jsii.get(self, "name")

    @name.setter # type: ignore
    def name(self, value: builtins.str) -> None:
        jsii.set(self, "name", value)

    @builtins.property # type: ignore
    @jsii.member(jsii_name="resourceGroupName")
    def resource_group_name(self) -> builtins.str:
        return jsii.get(self, "resourceGroupName")

    @resource_group_name.setter # type: ignore
    def resource_group_name(self, value: builtins.str) -> None:
        jsii.set(self, "resourceGroupName", value)

    @builtins.property # type: ignore
    @jsii.member(jsii_name="serverName")
    def server_name(self) -> builtins.str:
        return jsii.get(self, "serverName")

    @server_name.setter # type: ignore
    def server_name(self, value: builtins.str) -> None:
        jsii.set(self, "serverName", value)

    @builtins.property # type: ignore
    @jsii.member(jsii_name="subnetId")
    def subnet_id(self) -> builtins.str:
        return jsii.get(self, "subnetId")

    @subnet_id.setter # type: ignore
    def subnet_id(self, value: builtins.str) -> None:
        jsii.set(self, "subnetId", value)

    @builtins.property # type: ignore
    @jsii.member(jsii_name="id")
    def id(self) -> typing.Optional[builtins.str]:
        return jsii.get(self, "id")

    @id.setter # type: ignore
    def id(self, value: typing.Optional[builtins.str]) -> None:
        jsii.set(self, "id", value)

    @builtins.property # type: ignore
    @jsii.member(jsii_name="timeouts")
    def timeouts(self) -> typing.Optional["MysqlVirtualNetworkRuleTimeouts"]:
        return jsii.get(self, "timeouts")

    @timeouts.setter # type: ignore
    def timeouts(
        self,
        value: typing.Optional["MysqlVirtualNetworkRuleTimeouts"],
    ) -> None:
        jsii.set(self, "timeouts", value)


@jsii.data_type(
    jsii_type="@cdktf/provider-azurerm.MysqlVirtualNetworkRuleConfig",
    jsii_struct_bases=[cdktf.TerraformMetaArguments],
    name_mapping={
        "count": "count",
        "depends_on": "dependsOn",
        "lifecycle": "lifecycle",
        "provider": "provider",
        "name": "name",
        "resource_group_name": "resourceGroupName",
        "server_name": "serverName",
        "subnet_id": "subnetId",
        "timeouts": "timeouts",
    },
)
class MysqlVirtualNetworkRuleConfig(cdktf.TerraformMetaArguments):
    def __init__(
        self,
        *,
        count: typing.Optional[jsii.Number] = None,
        depends_on: typing.Optional[typing.List[cdktf.TerraformResource]] = None,
        lifecycle: typing.Optional[cdktf.TerraformResourceLifecycle] = None,
        provider: typing.Optional[cdktf.TerraformProvider] = None,
        name: builtins.str,
        resource_group_name: builtins.str,
        server_name: builtins.str,
        subnet_id: builtins.str,
        timeouts: typing.Optional["MysqlVirtualNetworkRuleTimeouts"] = None,
    ) -> None:
        """
        :param count: 
        :param depends_on: 
        :param lifecycle: 
        :param provider: 
        :param name: 
        :param resource_group_name: 
        :param server_name: 
        :param subnet_id: 
        :param timeouts: timeouts block.
        """
        if isinstance(lifecycle, dict):
            lifecycle = cdktf.TerraformResourceLifecycle(**lifecycle)
        if isinstance(timeouts, dict):
            timeouts = MysqlVirtualNetworkRuleTimeouts(**timeouts)
        self._values: typing.Dict[str, typing.Any] = {
            "name": name,
            "resource_group_name": resource_group_name,
            "server_name": server_name,
            "subnet_id": subnet_id,
        }
        if count is not None:
            self._values["count"] = count
        if depends_on is not None:
            self._values["depends_on"] = depends_on
        if lifecycle is not None:
            self._values["lifecycle"] = lifecycle
        if provider is not None:
            self._values["provider"] = provider
        if timeouts is not None:
            self._values["timeouts"] = timeouts

    @builtins.property
    def count(self) -> typing.Optional[jsii.Number]:
        """
        :stability: experimental
        """
        result = self._values.get("count")
        return result

    @builtins.property
    def depends_on(self) -> typing.Optional[typing.List[cdktf.TerraformResource]]:
        """
        :stability: experimental
        """
        result = self._values.get("depends_on")
        return result

    @builtins.property
    def lifecycle(self) -> typing.Optional[cdktf.TerraformResourceLifecycle]:
        """
        :stability: experimental
        """
        result = self._values.get("lifecycle")
        return result

    @builtins.property
    def provider(self) -> typing.Optional[cdktf.TerraformProvider]:
        """
        :stability: experimental
        """
        result = self._values.get("provider")
        return result

    @builtins.property
    def name(self) -> builtins.str:
        result = self._values.get("name")
        assert result is not None, "Required property 'name' is missing"
        return result

    @builtins.property
    def resource_group_name(self) -> builtins.str:
        result = self._values.get("resource_group_name")
        assert result is not None, "Required property 'resource_group_name' is missing"
        return result

    @builtins.property
    def server_name(self) -> builtins.str:
        result = self._values.get("server_name")
        assert result is not None, "Required property 'server_name' is missing"
        return result

    @builtins.property
    def subnet_id(self) -> builtins.str:
        result = self._values.get("subnet_id")
        assert result is not None, "Required property 'subnet_id' is missing"
        return result

    @builtins.property
    def timeouts(self) -> typing.Optional["MysqlVirtualNetworkRuleTimeouts"]:
        """timeouts block."""
        result = self._values.get("timeouts")
        return result

    def __eq__(self, rhs: typing.Any) -> builtins.bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs: typing.Any) -> builtins.bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return "MysqlVirtualNetworkRuleConfig(%s)" % ", ".join(
            k + "=" + repr(v) for k, v in self._values.items()
        )


@jsii.data_type(
    jsii_type="@cdktf/provider-azurerm.MysqlVirtualNetworkRuleTimeouts",
    jsii_struct_bases=[],
    name_mapping={
        "create": "create",
        "delete": "delete",
        "read": "read",
        "update": "update",
    },
)
class MysqlVirtualNetworkRuleTimeouts:
    def __init__(
        self,
        *,
        create: typing.Optional[builtins.str] = None,
        delete: typing.Optional[builtins.str] = None,
        read: typing.Optional[builtins.str] = None,
        update: typing.Optional[builtins.str] = None,
    ) -> None:
        """
        :param create: 
        :param delete: 
        :param read: 
        :param update: 
        """
        self._values: typing.Dict[str, typing.Any] = {}
        if create is not None:
            self._values["create"] = create
        if delete is not None:
            self._values["delete"] = delete
        if read is not None:
            self._values["read"] = read
        if update is not None:
            self._values["update"] = update

    @builtins.property
    def create(self) -> typing.Optional[builtins.str]:
        result = self._values.get("create")
        return result

    @builtins.property
    def delete(self) -> typing.Optional[builtins.str]:
        result = self._values.get("delete")
        return result

    @builtins.property
    def read(self) -> typing.Optional[builtins.str]:
        result = self._values.get("read")
        return result

    @builtins.property
    def update(self) -> typing.Optional[builtins.str]:
        result = self._values.get("update")
        return result

    def __eq__(self, rhs: typing.Any) -> builtins.bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs: typing.Any) -> builtins.bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return "MysqlVirtualNetworkRuleTimeouts(%s)" % ", ".join(
            k + "=" + repr(v) for k, v in self._values.items()
        )


class NatGateway(
    cdktf.TerraformResource,
    metaclass=jsii.JSIIMeta,
    jsii_type="@cdktf/provider-azurerm.NatGateway",
):
    def __init__(
        self,
        scope: constructs.Construct,
        id: builtins.str,
        *,
        location: builtins.str,
        name: builtins.str,
        resource_group_name: builtins.str,
        idle_timeout_in_minutes: typing.Optional[jsii.Number] = None,
        public_ip_address_ids: typing.Optional[typing.List[builtins.str]] = None,
        public_ip_prefix_ids: typing.Optional[typing.List[builtins.str]] = None,
        sku_name: typing.Optional[builtins.str] = None,
        tags: typing.Optional[typing.Mapping[builtins.str, builtins.str]] = None,
        timeouts: typing.Optional["NatGatewayTimeouts"] = None,
        zones: typing.Optional[typing.List[builtins.str]] = None,
        count: typing.Optional[jsii.Number] = None,
        depends_on: typing.Optional[typing.List[cdktf.TerraformResource]] = None,
        lifecycle: typing.Optional[cdktf.TerraformResourceLifecycle] = None,
        provider: typing.Optional[cdktf.TerraformProvider] = None,
    ) -> None:
        """
        :param scope: -
        :param id: -
        :param location: 
        :param name: 
        :param resource_group_name: 
        :param idle_timeout_in_minutes: 
        :param public_ip_address_ids: 
        :param public_ip_prefix_ids: 
        :param sku_name: 
        :param tags: 
        :param timeouts: timeouts block.
        :param zones: 
        :param count: 
        :param depends_on: 
        :param lifecycle: 
        :param provider: 
        """
        config = NatGatewayConfig(
            location=location,
            name=name,
            resource_group_name=resource_group_name,
            idle_timeout_in_minutes=idle_timeout_in_minutes,
            public_ip_address_ids=public_ip_address_ids,
            public_ip_prefix_ids=public_ip_prefix_ids,
            sku_name=sku_name,
            tags=tags,
            timeouts=timeouts,
            zones=zones,
            count=count,
            depends_on=depends_on,
            lifecycle=lifecycle,
            provider=provider,
        )

        jsii.create(NatGateway, self, [scope, id, config])

    @jsii.member(jsii_name="synthesizeAttributes")
    def _synthesize_attributes(self) -> typing.Mapping[builtins.str, typing.Any]:
        return jsii.invoke(self, "synthesizeAttributes", [])

    @builtins.property # type: ignore
    @jsii.member(jsii_name="resourceGuid")
    def resource_guid(self) -> builtins.str:
        return jsii.get(self, "resourceGuid")

    @builtins.property # type: ignore
    @jsii.member(jsii_name="location")
    def location(self) -> builtins.str:
        return jsii.get(self, "location")

    @location.setter # type: ignore
    def location(self, value: builtins.str) -> None:
        jsii.set(self, "location", value)

    @builtins.property # type: ignore
    @jsii.member(jsii_name="name")
    def name(self) -> builtins.str:
        return jsii.get(self, "name")

    @name.setter # type: ignore
    def name(self, value: builtins.str) -> None:
        jsii.set(self, "name", value)

    @builtins.property # type: ignore
    @jsii.member(jsii_name="resourceGroupName")
    def resource_group_name(self) -> builtins.str:
        return jsii.get(self, "resourceGroupName")

    @resource_group_name.setter # type: ignore
    def resource_group_name(self, value: builtins.str) -> None:
        jsii.set(self, "resourceGroupName", value)

    @builtins.property # type: ignore
    @jsii.member(jsii_name="id")
    def id(self) -> typing.Optional[builtins.str]:
        return jsii.get(self, "id")

    @id.setter # type: ignore
    def id(self, value: typing.Optional[builtins.str]) -> None:
        jsii.set(self, "id", value)

    @builtins.property # type: ignore
    @jsii.member(jsii_name="idleTimeoutInMinutes")
    def idle_timeout_in_minutes(self) -> typing.Optional[jsii.Number]:
        return jsii.get(self, "idleTimeoutInMinutes")

    @idle_timeout_in_minutes.setter # type: ignore
    def idle_timeout_in_minutes(self, value: typing.Optional[jsii.Number]) -> None:
        jsii.set(self, "idleTimeoutInMinutes", value)

    @builtins.property # type: ignore
    @jsii.member(jsii_name="publicIpAddressIds")
    def public_ip_address_ids(self) -> typing.Optional[typing.List[builtins.str]]:
        return jsii.get(self, "publicIpAddressIds")

    @public_ip_address_ids.setter # type: ignore
    def public_ip_address_ids(
        self,
        value: typing.Optional[typing.List[builtins.str]],
    ) -> None:
        jsii.set(self, "publicIpAddressIds", value)

    @builtins.property # type: ignore
    @jsii.member(jsii_name="publicIpPrefixIds")
    def public_ip_prefix_ids(self) -> typing.Optional[typing.List[builtins.str]]:
        return jsii.get(self, "publicIpPrefixIds")

    @public_ip_prefix_ids.setter # type: ignore
    def public_ip_prefix_ids(
        self,
        value: typing.Optional[typing.List[builtins.str]],
    ) -> None:
        jsii.set(self, "publicIpPrefixIds", value)

    @builtins.property # type: ignore
    @jsii.member(jsii_name="skuName")
    def sku_name(self) -> typing.Optional[builtins.str]:
        return jsii.get(self, "skuName")

    @sku_name.setter # type: ignore
    def sku_name(self, value: typing.Optional[builtins.str]) -> None:
        jsii.set(self, "skuName", value)

    @builtins.property # type: ignore
    @jsii.member(jsii_name="tags")
    def tags(self) -> typing.Optional[typing.Mapping[builtins.str, builtins.str]]:
        return jsii.get(self, "tags")

    @tags.setter # type: ignore
    def tags(
        self,
        value: typing.Optional[typing.Mapping[builtins.str, builtins.str]],
    ) -> None:
        jsii.set(self, "tags", value)

    @builtins.property # type: ignore
    @jsii.member(jsii_name="timeouts")
    def timeouts(self) -> typing.Optional["NatGatewayTimeouts"]:
        return jsii.get(self, "timeouts")

    @timeouts.setter # type: ignore
    def timeouts(self, value: typing.Optional["NatGatewayTimeouts"]) -> None:
        jsii.set(self, "timeouts", value)

    @builtins.property # type: ignore
    @jsii.member(jsii_name="zones")
    def zones(self) -> typing.Optional[typing.List[builtins.str]]:
        return jsii.get(self, "zones")

    @zones.setter # type: ignore
    def zones(self, value: typing.Optional[typing.List[builtins.str]]) -> None:
        jsii.set(self, "zones", value)


@jsii.data_type(
    jsii_type="@cdktf/provider-azurerm.NatGatewayConfig",
    jsii_struct_bases=[cdktf.TerraformMetaArguments],
    name_mapping={
        "count": "count",
        "depends_on": "dependsOn",
        "lifecycle": "lifecycle",
        "provider": "provider",
        "location": "location",
        "name": "name",
        "resource_group_name": "resourceGroupName",
        "idle_timeout_in_minutes": "idleTimeoutInMinutes",
        "public_ip_address_ids": "publicIpAddressIds",
        "public_ip_prefix_ids": "publicIpPrefixIds",
        "sku_name": "skuName",
        "tags": "tags",
        "timeouts": "timeouts",
        "zones": "zones",
    },
)
class NatGatewayConfig(cdktf.TerraformMetaArguments):
    def __init__(
        self,
        *,
        count: typing.Optional[jsii.Number] = None,
        depends_on: typing.Optional[typing.List[cdktf.TerraformResource]] = None,
        lifecycle: typing.Optional[cdktf.TerraformResourceLifecycle] = None,
        provider: typing.Optional[cdktf.TerraformProvider] = None,
        location: builtins.str,
        name: builtins.str,
        resource_group_name: builtins.str,
        idle_timeout_in_minutes: typing.Optional[jsii.Number] = None,
        public_ip_address_ids: typing.Optional[typing.List[builtins.str]] = None,
        public_ip_prefix_ids: typing.Optional[typing.List[builtins.str]] = None,
        sku_name: typing.Optional[builtins.str] = None,
        tags: typing.Optional[typing.Mapping[builtins.str, builtins.str]] = None,
        timeouts: typing.Optional["NatGatewayTimeouts"] = None,
        zones: typing.Optional[typing.List[builtins.str]] = None,
    ) -> None:
        """
        :param count: 
        :param depends_on: 
        :param lifecycle: 
        :param provider: 
        :param location: 
        :param name: 
        :param resource_group_name: 
        :param idle_timeout_in_minutes: 
        :param public_ip_address_ids: 
        :param public_ip_prefix_ids: 
        :param sku_name: 
        :param tags: 
        :param timeouts: timeouts block.
        :param zones: 
        """
        if isinstance(lifecycle, dict):
            lifecycle = cdktf.TerraformResourceLifecycle(**lifecycle)
        if isinstance(timeouts, dict):
            timeouts = NatGatewayTimeouts(**timeouts)
        self._values: typing.Dict[str, typing.Any] = {
            "location": location,
            "name": name,
            "resource_group_name": resource_group_name,
        }
        if count is not None:
            self._values["count"] = count
        if depends_on is not None:
            self._values["depends_on"] = depends_on
        if lifecycle is not None:
            self._values["lifecycle"] = lifecycle
        if provider is not None:
            self._values["provider"] = provider
        if idle_timeout_in_minutes is not None:
            self._values["idle_timeout_in_minutes"] = idle_timeout_in_minutes
        if public_ip_address_ids is not None:
            self._values["public_ip_address_ids"] = public_ip_address_ids
        if public_ip_prefix_ids is not None:
            self._values["public_ip_prefix_ids"] = public_ip_prefix_ids
        if sku_name is not None:
            self._values["sku_name"] = sku_name
        if tags is not None:
            self._values["tags"] = tags
        if timeouts is not None:
            self._values["timeouts"] = timeouts
        if zones is not None:
            self._values["zones"] = zones

    @builtins.property
    def count(self) -> typing.Optional[jsii.Number]:
        """
        :stability: experimental
        """
        result = self._values.get("count")
        return result

    @builtins.property
    def depends_on(self) -> typing.Optional[typing.List[cdktf.TerraformResource]]:
        """
        :stability: experimental
        """
        result = self._values.get("depends_on")
        return result

    @builtins.property
    def lifecycle(self) -> typing.Optional[cdktf.TerraformResourceLifecycle]:
        """
        :stability: experimental
        """
        result = self._values.get("lifecycle")
        return result

    @builtins.property
    def provider(self) -> typing.Optional[cdktf.TerraformProvider]:
        """
        :stability: experimental
        """
        result = self._values.get("provider")
        return result

    @builtins.property
    def location(self) -> builtins.str:
        result = self._values.get("location")
        assert result is not None, "Required property 'location' is missing"
        return result

    @builtins.property
    def name(self) -> builtins.str:
        result = self._values.get("name")
        assert result is not None, "Required property 'name' is missing"
        return result

    @builtins.property
    def resource_group_name(self) -> builtins.str:
        result = self._values.get("resource_group_name")
        assert result is not None, "Required property 'resource_group_name' is missing"
        return result

    @builtins.property
    def idle_timeout_in_minutes(self) -> typing.Optional[jsii.Number]:
        result = self._values.get("idle_timeout_in_minutes")
        return result

    @builtins.property
    def public_ip_address_ids(self) -> typing.Optional[typing.List[builtins.str]]:
        result = self._values.get("public_ip_address_ids")
        return result

    @builtins.property
    def public_ip_prefix_ids(self) -> typing.Optional[typing.List[builtins.str]]:
        result = self._values.get("public_ip_prefix_ids")
        return result

    @builtins.property
    def sku_name(self) -> typing.Optional[builtins.str]:
        result = self._values.get("sku_name")
        return result

    @builtins.property
    def tags(self) -> typing.Optional[typing.Mapping[builtins.str, builtins.str]]:
        result = self._values.get("tags")
        return result

    @builtins.property
    def timeouts(self) -> typing.Optional["NatGatewayTimeouts"]:
        """timeouts block."""
        result = self._values.get("timeouts")
        return result

    @builtins.property
    def zones(self) -> typing.Optional[typing.List[builtins.str]]:
        result = self._values.get("zones")
        return result

    def __eq__(self, rhs: typing.Any) -> builtins.bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs: typing.Any) -> builtins.bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return "NatGatewayConfig(%s)" % ", ".join(
            k + "=" + repr(v) for k, v in self._values.items()
        )


@jsii.data_type(
    jsii_type="@cdktf/provider-azurerm.NatGatewayTimeouts",
    jsii_struct_bases=[],
    name_mapping={
        "create": "create",
        "delete": "delete",
        "read": "read",
        "update": "update",
    },
)
class NatGatewayTimeouts:
    def __init__(
        self,
        *,
        create: typing.Optional[builtins.str] = None,
        delete: typing.Optional[builtins.str] = None,
        read: typing.Optional[builtins.str] = None,
        update: typing.Optional[builtins.str] = None,
    ) -> None:
        """
        :param create: 
        :param delete: 
        :param read: 
        :param update: 
        """
        self._values: typing.Dict[str, typing.Any] = {}
        if create is not None:
            self._values["create"] = create
        if delete is not None:
            self._values["delete"] = delete
        if read is not None:
            self._values["read"] = read
        if update is not None:
            self._values["update"] = update

    @builtins.property
    def create(self) -> typing.Optional[builtins.str]:
        result = self._values.get("create")
        return result

    @builtins.property
    def delete(self) -> typing.Optional[builtins.str]:
        result = self._values.get("delete")
        return result

    @builtins.property
    def read(self) -> typing.Optional[builtins.str]:
        result = self._values.get("read")
        return result

    @builtins.property
    def update(self) -> typing.Optional[builtins.str]:
        result = self._values.get("update")
        return result

    def __eq__(self, rhs: typing.Any) -> builtins.bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs: typing.Any) -> builtins.bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return "NatGatewayTimeouts(%s)" % ", ".join(
            k + "=" + repr(v) for k, v in self._values.items()
        )


class NetappAccount(
    cdktf.TerraformResource,
    metaclass=jsii.JSIIMeta,
    jsii_type="@cdktf/provider-azurerm.NetappAccount",
):
    def __init__(
        self,
        scope: constructs.Construct,
        id: builtins.str,
        *,
        location: builtins.str,
        name: builtins.str,
        resource_group_name: builtins.str,
        active_directory: typing.Optional[typing.List["NetappAccountActiveDirectory"]] = None,
        timeouts: typing.Optional["NetappAccountTimeouts"] = None,
        count: typing.Optional[jsii.Number] = None,
        depends_on: typing.Optional[typing.List[cdktf.TerraformResource]] = None,
        lifecycle: typing.Optional[cdktf.TerraformResourceLifecycle] = None,
        provider: typing.Optional[cdktf.TerraformProvider] = None,
    ) -> None:
        """
        :param scope: -
        :param id: -
        :param location: 
        :param name: 
        :param resource_group_name: 
        :param active_directory: active_directory block.
        :param timeouts: timeouts block.
        :param count: 
        :param depends_on: 
        :param lifecycle: 
        :param provider: 
        """
        config = NetappAccountConfig(
            location=location,
            name=name,
            resource_group_name=resource_group_name,
            active_directory=active_directory,
            timeouts=timeouts,
            count=count,
            depends_on=depends_on,
            lifecycle=lifecycle,
            provider=provider,
        )

        jsii.create(NetappAccount, self, [scope, id, config])

    @jsii.member(jsii_name="synthesizeAttributes")
    def _synthesize_attributes(self) -> typing.Mapping[builtins.str, typing.Any]:
        return jsii.invoke(self, "synthesizeAttributes", [])

    @builtins.property # type: ignore
    @jsii.member(jsii_name="location")
    def location(self) -> builtins.str:
        return jsii.get(self, "location")

    @location.setter # type: ignore
    def location(self, value: builtins.str) -> None:
        jsii.set(self, "location", value)

    @builtins.property # type: ignore
    @jsii.member(jsii_name="name")
    def name(self) -> builtins.str:
        return jsii.get(self, "name")

    @name.setter # type: ignore
    def name(self, value: builtins.str) -> None:
        jsii.set(self, "name", value)

    @builtins.property # type: ignore
    @jsii.member(jsii_name="resourceGroupName")
    def resource_group_name(self) -> builtins.str:
        return jsii.get(self, "resourceGroupName")

    @resource_group_name.setter # type: ignore
    def resource_group_name(self, value: builtins.str) -> None:
        jsii.set(self, "resourceGroupName", value)

    @builtins.property # type: ignore
    @jsii.member(jsii_name="activeDirectory")
    def active_directory(
        self,
    ) -> typing.Optional[typing.List["NetappAccountActiveDirectory"]]:
        return jsii.get(self, "activeDirectory")

    @active_directory.setter # type: ignore
    def active_directory(
        self,
        value: typing.Optional[typing.List["NetappAccountActiveDirectory"]],
    ) -> None:
        jsii.set(self, "activeDirectory", value)

    @builtins.property # type: ignore
    @jsii.member(jsii_name="id")
    def id(self) -> typing.Optional[builtins.str]:
        return jsii.get(self, "id")

    @id.setter # type: ignore
    def id(self, value: typing.Optional[builtins.str]) -> None:
        jsii.set(self, "id", value)

    @builtins.property # type: ignore
    @jsii.member(jsii_name="timeouts")
    def timeouts(self) -> typing.Optional["NetappAccountTimeouts"]:
        return jsii.get(self, "timeouts")

    @timeouts.setter # type: ignore
    def timeouts(self, value: typing.Optional["NetappAccountTimeouts"]) -> None:
        jsii.set(self, "timeouts", value)


@jsii.data_type(
    jsii_type="@cdktf/provider-azurerm.NetappAccountActiveDirectory",
    jsii_struct_bases=[],
    name_mapping={
        "dns_servers": "dnsServers",
        "domain": "domain",
        "password": "password",
        "smb_server_name": "smbServerName",
        "username": "username",
        "organizational_unit": "organizationalUnit",
    },
)
class NetappAccountActiveDirectory:
    def __init__(
        self,
        *,
        dns_servers: typing.List[builtins.str],
        domain: builtins.str,
        password: builtins.str,
        smb_server_name: builtins.str,
        username: builtins.str,
        organizational_unit: typing.Optional[builtins.str] = None,
    ) -> None:
        """
        :param dns_servers: 
        :param domain: 
        :param password: 
        :param smb_server_name: 
        :param username: 
        :param organizational_unit: 
        """
        self._values: typing.Dict[str, typing.Any] = {
            "dns_servers": dns_servers,
            "domain": domain,
            "password": password,
            "smb_server_name": smb_server_name,
            "username": username,
        }
        if organizational_unit is not None:
            self._values["organizational_unit"] = organizational_unit

    @builtins.property
    def dns_servers(self) -> typing.List[builtins.str]:
        result = self._values.get("dns_servers")
        assert result is not None, "Required property 'dns_servers' is missing"
        return result

    @builtins.property
    def domain(self) -> builtins.str:
        result = self._values.get("domain")
        assert result is not None, "Required property 'domain' is missing"
        return result

    @builtins.property
    def password(self) -> builtins.str:
        result = self._values.get("password")
        assert result is not None, "Required property 'password' is missing"
        return result

    @builtins.property
    def smb_server_name(self) -> builtins.str:
        result = self._values.get("smb_server_name")
        assert result is not None, "Required property 'smb_server_name' is missing"
        return result

    @builtins.property
    def username(self) -> builtins.str:
        result = self._values.get("username")
        assert result is not None, "Required property 'username' is missing"
        return result

    @builtins.property
    def organizational_unit(self) -> typing.Optional[builtins.str]:
        result = self._values.get("organizational_unit")
        return result

    def __eq__(self, rhs: typing.Any) -> builtins.bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs: typing.Any) -> builtins.bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return "NetappAccountActiveDirectory(%s)" % ", ".join(
            k + "=" + repr(v) for k, v in self._values.items()
        )


@jsii.data_type(
    jsii_type="@cdktf/provider-azurerm.NetappAccountConfig",
    jsii_struct_bases=[cdktf.TerraformMetaArguments],
    name_mapping={
        "count": "count",
        "depends_on": "dependsOn",
        "lifecycle": "lifecycle",
        "provider": "provider",
        "location": "location",
        "name": "name",
        "resource_group_name": "resourceGroupName",
        "active_directory": "activeDirectory",
        "timeouts": "timeouts",
    },
)
class NetappAccountConfig(cdktf.TerraformMetaArguments):
    def __init__(
        self,
        *,
        count: typing.Optional[jsii.Number] = None,
        depends_on: typing.Optional[typing.List[cdktf.TerraformResource]] = None,
        lifecycle: typing.Optional[cdktf.TerraformResourceLifecycle] = None,
        provider: typing.Optional[cdktf.TerraformProvider] = None,
        location: builtins.str,
        name: builtins.str,
        resource_group_name: builtins.str,
        active_directory: typing.Optional[typing.List[NetappAccountActiveDirectory]] = None,
        timeouts: typing.Optional["NetappAccountTimeouts"] = None,
    ) -> None:
        """
        :param count: 
        :param depends_on: 
        :param lifecycle: 
        :param provider: 
        :param location: 
        :param name: 
        :param resource_group_name: 
        :param active_directory: active_directory block.
        :param timeouts: timeouts block.
        """
        if isinstance(lifecycle, dict):
            lifecycle = cdktf.TerraformResourceLifecycle(**lifecycle)
        if isinstance(timeouts, dict):
            timeouts = NetappAccountTimeouts(**timeouts)
        self._values: typing.Dict[str, typing.Any] = {
            "location": location,
            "name": name,
            "resource_group_name": resource_group_name,
        }
        if count is not None:
            self._values["count"] = count
        if depends_on is not None:
            self._values["depends_on"] = depends_on
        if lifecycle is not None:
            self._values["lifecycle"] = lifecycle
        if provider is not None:
            self._values["provider"] = provider
        if active_directory is not None:
            self._values["active_directory"] = active_directory
        if timeouts is not None:
            self._values["timeouts"] = timeouts

    @builtins.property
    def count(self) -> typing.Optional[jsii.Number]:
        """
        :stability: experimental
        """
        result = self._values.get("count")
        return result

    @builtins.property
    def depends_on(self) -> typing.Optional[typing.List[cdktf.TerraformResource]]:
        """
        :stability: experimental
        """
        result = self._values.get("depends_on")
        return result

    @builtins.property
    def lifecycle(self) -> typing.Optional[cdktf.TerraformResourceLifecycle]:
        """
        :stability: experimental
        """
        result = self._values.get("lifecycle")
        return result

    @builtins.property
    def provider(self) -> typing.Optional[cdktf.TerraformProvider]:
        """
        :stability: experimental
        """
        result = self._values.get("provider")
        return result

    @builtins.property
    def location(self) -> builtins.str:
        result = self._values.get("location")
        assert result is not None, "Required property 'location' is missing"
        return result

    @builtins.property
    def name(self) -> builtins.str:
        result = self._values.get("name")
        assert result is not None, "Required property 'name' is missing"
        return result

    @builtins.property
    def resource_group_name(self) -> builtins.str:
        result = self._values.get("resource_group_name")
        assert result is not None, "Required property 'resource_group_name' is missing"
        return result

    @builtins.property
    def active_directory(
        self,
    ) -> typing.Optional[typing.List[NetappAccountActiveDirectory]]:
        """active_directory block."""
        result = self._values.get("active_directory")
        return result

    @builtins.property
    def timeouts(self) -> typing.Optional["NetappAccountTimeouts"]:
        """timeouts block."""
        result = self._values.get("timeouts")
        return result

    def __eq__(self, rhs: typing.Any) -> builtins.bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs: typing.Any) -> builtins.bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return "NetappAccountConfig(%s)" % ", ".join(
            k + "=" + repr(v) for k, v in self._values.items()
        )


@jsii.data_type(
    jsii_type="@cdktf/provider-azurerm.NetappAccountTimeouts",
    jsii_struct_bases=[],
    name_mapping={
        "create": "create",
        "delete": "delete",
        "read": "read",
        "update": "update",
    },
)
class NetappAccountTimeouts:
    def __init__(
        self,
        *,
        create: typing.Optional[builtins.str] = None,
        delete: typing.Optional[builtins.str] = None,
        read: typing.Optional[builtins.str] = None,
        update: typing.Optional[builtins.str] = None,
    ) -> None:
        """
        :param create: 
        :param delete: 
        :param read: 
        :param update: 
        """
        self._values: typing.Dict[str, typing.Any] = {}
        if create is not None:
            self._values["create"] = create
        if delete is not None:
            self._values["delete"] = delete
        if read is not None:
            self._values["read"] = read
        if update is not None:
            self._values["update"] = update

    @builtins.property
    def create(self) -> typing.Optional[builtins.str]:
        result = self._values.get("create")
        return result

    @builtins.property
    def delete(self) -> typing.Optional[builtins.str]:
        result = self._values.get("delete")
        return result

    @builtins.property
    def read(self) -> typing.Optional[builtins.str]:
        result = self._values.get("read")
        return result

    @builtins.property
    def update(self) -> typing.Optional[builtins.str]:
        result = self._values.get("update")
        return result

    def __eq__(self, rhs: typing.Any) -> builtins.bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs: typing.Any) -> builtins.bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return "NetappAccountTimeouts(%s)" % ", ".join(
            k + "=" + repr(v) for k, v in self._values.items()
        )


class NetappPool(
    cdktf.TerraformResource,
    metaclass=jsii.JSIIMeta,
    jsii_type="@cdktf/provider-azurerm.NetappPool",
):
    def __init__(
        self,
        scope: constructs.Construct,
        id: builtins.str,
        *,
        account_name: builtins.str,
        location: builtins.str,
        name: builtins.str,
        resource_group_name: builtins.str,
        service_level: builtins.str,
        size_in_tb: jsii.Number,
        timeouts: typing.Optional["NetappPoolTimeouts"] = None,
        count: typing.Optional[jsii.Number] = None,
        depends_on: typing.Optional[typing.List[cdktf.TerraformResource]] = None,
        lifecycle: typing.Optional[cdktf.TerraformResourceLifecycle] = None,
        provider: typing.Optional[cdktf.TerraformProvider] = None,
    ) -> None:
        """
        :param scope: -
        :param id: -
        :param account_name: 
        :param location: 
        :param name: 
        :param resource_group_name: 
        :param service_level: 
        :param size_in_tb: 
        :param timeouts: timeouts block.
        :param count: 
        :param depends_on: 
        :param lifecycle: 
        :param provider: 
        """
        config = NetappPoolConfig(
            account_name=account_name,
            location=location,
            name=name,
            resource_group_name=resource_group_name,
            service_level=service_level,
            size_in_tb=size_in_tb,
            timeouts=timeouts,
            count=count,
            depends_on=depends_on,
            lifecycle=lifecycle,
            provider=provider,
        )

        jsii.create(NetappPool, self, [scope, id, config])

    @jsii.member(jsii_name="synthesizeAttributes")
    def _synthesize_attributes(self) -> typing.Mapping[builtins.str, typing.Any]:
        return jsii.invoke(self, "synthesizeAttributes", [])

    @builtins.property # type: ignore
    @jsii.member(jsii_name="accountName")
    def account_name(self) -> builtins.str:
        return jsii.get(self, "accountName")

    @account_name.setter # type: ignore
    def account_name(self, value: builtins.str) -> None:
        jsii.set(self, "accountName", value)

    @builtins.property # type: ignore
    @jsii.member(jsii_name="location")
    def location(self) -> builtins.str:
        return jsii.get(self, "location")

    @location.setter # type: ignore
    def location(self, value: builtins.str) -> None:
        jsii.set(self, "location", value)

    @builtins.property # type: ignore
    @jsii.member(jsii_name="name")
    def name(self) -> builtins.str:
        return jsii.get(self, "name")

    @name.setter # type: ignore
    def name(self, value: builtins.str) -> None:
        jsii.set(self, "name", value)

    @builtins.property # type: ignore
    @jsii.member(jsii_name="resourceGroupName")
    def resource_group_name(self) -> builtins.str:
        return jsii.get(self, "resourceGroupName")

    @resource_group_name.setter # type: ignore
    def resource_group_name(self, value: builtins.str) -> None:
        jsii.set(self, "resourceGroupName", value)

    @builtins.property # type: ignore
    @jsii.member(jsii_name="serviceLevel")
    def service_level(self) -> builtins.str:
        return jsii.get(self, "serviceLevel")

    @service_level.setter # type: ignore
    def service_level(self, value: builtins.str) -> None:
        jsii.set(self, "serviceLevel", value)

    @builtins.property # type: ignore
    @jsii.member(jsii_name="sizeInTb")
    def size_in_tb(self) -> jsii.Number:
        return jsii.get(self, "sizeInTb")

    @size_in_tb.setter # type: ignore
    def size_in_tb(self, value: jsii.Number) -> None:
        jsii.set(self, "sizeInTb", value)

    @builtins.property # type: ignore
    @jsii.member(jsii_name="id")
    def id(self) -> typing.Optional[builtins.str]:
        return jsii.get(self, "id")

    @id.setter # type: ignore
    def id(self, value: typing.Optional[builtins.str]) -> None:
        jsii.set(self, "id", value)

    @builtins.property # type: ignore
    @jsii.member(jsii_name="timeouts")
    def timeouts(self) -> typing.Optional["NetappPoolTimeouts"]:
        return jsii.get(self, "timeouts")

    @timeouts.setter # type: ignore
    def timeouts(self, value: typing.Optional["NetappPoolTimeouts"]) -> None:
        jsii.set(self, "timeouts", value)


@jsii.data_type(
    jsii_type="@cdktf/provider-azurerm.NetappPoolConfig",
    jsii_struct_bases=[cdktf.TerraformMetaArguments],
    name_mapping={
        "count": "count",
        "depends_on": "dependsOn",
        "lifecycle": "lifecycle",
        "provider": "provider",
        "account_name": "accountName",
        "location": "location",
        "name": "name",
        "resource_group_name": "resourceGroupName",
        "service_level": "serviceLevel",
        "size_in_tb": "sizeInTb",
        "timeouts": "timeouts",
    },
)
class NetappPoolConfig(cdktf.TerraformMetaArguments):
    def __init__(
        self,
        *,
        count: typing.Optional[jsii.Number] = None,
        depends_on: typing.Optional[typing.List[cdktf.TerraformResource]] = None,
        lifecycle: typing.Optional[cdktf.TerraformResourceLifecycle] = None,
        provider: typing.Optional[cdktf.TerraformProvider] = None,
        account_name: builtins.str,
        location: builtins.str,
        name: builtins.str,
        resource_group_name: builtins.str,
        service_level: builtins.str,
        size_in_tb: jsii.Number,
        timeouts: typing.Optional["NetappPoolTimeouts"] = None,
    ) -> None:
        """
        :param count: 
        :param depends_on: 
        :param lifecycle: 
        :param provider: 
        :param account_name: 
        :param location: 
        :param name: 
        :param resource_group_name: 
        :param service_level: 
        :param size_in_tb: 
        :param timeouts: timeouts block.
        """
        if isinstance(lifecycle, dict):
            lifecycle = cdktf.TerraformResourceLifecycle(**lifecycle)
        if isinstance(timeouts, dict):
            timeouts = NetappPoolTimeouts(**timeouts)
        self._values: typing.Dict[str, typing.Any] = {
            "account_name": account_name,
            "location": location,
            "name": name,
            "resource_group_name": resource_group_name,
            "service_level": service_level,
            "size_in_tb": size_in_tb,
        }
        if count is not None:
            self._values["count"] = count
        if depends_on is not None:
            self._values["depends_on"] = depends_on
        if lifecycle is not None:
            self._values["lifecycle"] = lifecycle
        if provider is not None:
            self._values["provider"] = provider
        if timeouts is not None:
            self._values["timeouts"] = timeouts

    @builtins.property
    def count(self) -> typing.Optional[jsii.Number]:
        """
        :stability: experimental
        """
        result = self._values.get("count")
        return result

    @builtins.property
    def depends_on(self) -> typing.Optional[typing.List[cdktf.TerraformResource]]:
        """
        :stability: experimental
        """
        result = self._values.get("depends_on")
        return result

    @builtins.property
    def lifecycle(self) -> typing.Optional[cdktf.TerraformResourceLifecycle]:
        """
        :stability: experimental
        """
        result = self._values.get("lifecycle")
        return result

    @builtins.property
    def provider(self) -> typing.Optional[cdktf.TerraformProvider]:
        """
        :stability: experimental
        """
        result = self._values.get("provider")
        return result

    @builtins.property
    def account_name(self) -> builtins.str:
        result = self._values.get("account_name")
        assert result is not None, "Required property 'account_name' is missing"
        return result

    @builtins.property
    def location(self) -> builtins.str:
        result = self._values.get("location")
        assert result is not None, "Required property 'location' is missing"
        return result

    @builtins.property
    def name(self) -> builtins.str:
        result = self._values.get("name")
        assert result is not None, "Required property 'name' is missing"
        return result

    @builtins.property
    def resource_group_name(self) -> builtins.str:
        result = self._values.get("resource_group_name")
        assert result is not None, "Required property 'resource_group_name' is missing"
        return result

    @builtins.property
    def service_level(self) -> builtins.str:
        result = self._values.get("service_level")
        assert result is not None, "Required property 'service_level' is missing"
        return result

    @builtins.property
    def size_in_tb(self) -> jsii.Number:
        result = self._values.get("size_in_tb")
        assert result is not None, "Required property 'size_in_tb' is missing"
        return result

    @builtins.property
    def timeouts(self) -> typing.Optional["NetappPoolTimeouts"]:
        """timeouts block."""
        result = self._values.get("timeouts")
        return result

    def __eq__(self, rhs: typing.Any) -> builtins.bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs: typing.Any) -> builtins.bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return "NetappPoolConfig(%s)" % ", ".join(
            k + "=" + repr(v) for k, v in self._values.items()
        )


@jsii.data_type(
    jsii_type="@cdktf/provider-azurerm.NetappPoolTimeouts",
    jsii_struct_bases=[],
    name_mapping={
        "create": "create",
        "delete": "delete",
        "read": "read",
        "update": "update",
    },
)
class NetappPoolTimeouts:
    def __init__(
        self,
        *,
        create: typing.Optional[builtins.str] = None,
        delete: typing.Optional[builtins.str] = None,
        read: typing.Optional[builtins.str] = None,
        update: typing.Optional[builtins.str] = None,
    ) -> None:
        """
        :param create: 
        :param delete: 
        :param read: 
        :param update: 
        """
        self._values: typing.Dict[str, typing.Any] = {}
        if create is not None:
            self._values["create"] = create
        if delete is not None:
            self._values["delete"] = delete
        if read is not None:
            self._values["read"] = read
        if update is not None:
            self._values["update"] = update

    @builtins.property
    def create(self) -> typing.Optional[builtins.str]:
        result = self._values.get("create")
        return result

    @builtins.property
    def delete(self) -> typing.Optional[builtins.str]:
        result = self._values.get("delete")
        return result

    @builtins.property
    def read(self) -> typing.Optional[builtins.str]:
        result = self._values.get("read")
        return result

    @builtins.property
    def update(self) -> typing.Optional[builtins.str]:
        result = self._values.get("update")
        return result

    def __eq__(self, rhs: typing.Any) -> builtins.bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs: typing.Any) -> builtins.bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return "NetappPoolTimeouts(%s)" % ", ".join(
            k + "=" + repr(v) for k, v in self._values.items()
        )


class NetappSnapshot(
    cdktf.TerraformResource,
    metaclass=jsii.JSIIMeta,
    jsii_type="@cdktf/provider-azurerm.NetappSnapshot",
):
    def __init__(
        self,
        scope: constructs.Construct,
        id: builtins.str,
        *,
        account_name: builtins.str,
        location: builtins.str,
        name: builtins.str,
        pool_name: builtins.str,
        resource_group_name: builtins.str,
        volume_name: builtins.str,
        timeouts: typing.Optional["NetappSnapshotTimeouts"] = None,
        count: typing.Optional[jsii.Number] = None,
        depends_on: typing.Optional[typing.List[cdktf.TerraformResource]] = None,
        lifecycle: typing.Optional[cdktf.TerraformResourceLifecycle] = None,
        provider: typing.Optional[cdktf.TerraformProvider] = None,
    ) -> None:
        """
        :param scope: -
        :param id: -
        :param account_name: 
        :param location: 
        :param name: 
        :param pool_name: 
        :param resource_group_name: 
        :param volume_name: 
        :param timeouts: timeouts block.
        :param count: 
        :param depends_on: 
        :param lifecycle: 
        :param provider: 
        """
        config = NetappSnapshotConfig(
            account_name=account_name,
            location=location,
            name=name,
            pool_name=pool_name,
            resource_group_name=resource_group_name,
            volume_name=volume_name,
            timeouts=timeouts,
            count=count,
            depends_on=depends_on,
            lifecycle=lifecycle,
            provider=provider,
        )

        jsii.create(NetappSnapshot, self, [scope, id, config])

    @jsii.member(jsii_name="synthesizeAttributes")
    def _synthesize_attributes(self) -> typing.Mapping[builtins.str, typing.Any]:
        return jsii.invoke(self, "synthesizeAttributes", [])

    @builtins.property # type: ignore
    @jsii.member(jsii_name="accountName")
    def account_name(self) -> builtins.str:
        return jsii.get(self, "accountName")

    @account_name.setter # type: ignore
    def account_name(self, value: builtins.str) -> None:
        jsii.set(self, "accountName", value)

    @builtins.property # type: ignore
    @jsii.member(jsii_name="location")
    def location(self) -> builtins.str:
        return jsii.get(self, "location")

    @location.setter # type: ignore
    def location(self, value: builtins.str) -> None:
        jsii.set(self, "location", value)

    @builtins.property # type: ignore
    @jsii.member(jsii_name="name")
    def name(self) -> builtins.str:
        return jsii.get(self, "name")

    @name.setter # type: ignore
    def name(self, value: builtins.str) -> None:
        jsii.set(self, "name", value)

    @builtins.property # type: ignore
    @jsii.member(jsii_name="poolName")
    def pool_name(self) -> builtins.str:
        return jsii.get(self, "poolName")

    @pool_name.setter # type: ignore
    def pool_name(self, value: builtins.str) -> None:
        jsii.set(self, "poolName", value)

    @builtins.property # type: ignore
    @jsii.member(jsii_name="resourceGroupName")
    def resource_group_name(self) -> builtins.str:
        return jsii.get(self, "resourceGroupName")

    @resource_group_name.setter # type: ignore
    def resource_group_name(self, value: builtins.str) -> None:
        jsii.set(self, "resourceGroupName", value)

    @builtins.property # type: ignore
    @jsii.member(jsii_name="volumeName")
    def volume_name(self) -> builtins.str:
        return jsii.get(self, "volumeName")

    @volume_name.setter # type: ignore
    def volume_name(self, value: builtins.str) -> None:
        jsii.set(self, "volumeName", value)

    @builtins.property # type: ignore
    @jsii.member(jsii_name="id")
    def id(self) -> typing.Optional[builtins.str]:
        return jsii.get(self, "id")

    @id.setter # type: ignore
    def id(self, value: typing.Optional[builtins.str]) -> None:
        jsii.set(self, "id", value)

    @builtins.property # type: ignore
    @jsii.member(jsii_name="timeouts")
    def timeouts(self) -> typing.Optional["NetappSnapshotTimeouts"]:
        return jsii.get(self, "timeouts")

    @timeouts.setter # type: ignore
    def timeouts(self, value: typing.Optional["NetappSnapshotTimeouts"]) -> None:
        jsii.set(self, "timeouts", value)


@jsii.data_type(
    jsii_type="@cdktf/provider-azurerm.NetappSnapshotConfig",
    jsii_struct_bases=[cdktf.TerraformMetaArguments],
    name_mapping={
        "count": "count",
        "depends_on": "dependsOn",
        "lifecycle": "lifecycle",
        "provider": "provider",
        "account_name": "accountName",
        "location": "location",
        "name": "name",
        "pool_name": "poolName",
        "resource_group_name": "resourceGroupName",
        "volume_name": "volumeName",
        "timeouts": "timeouts",
    },
)
class NetappSnapshotConfig(cdktf.TerraformMetaArguments):
    def __init__(
        self,
        *,
        count: typing.Optional[jsii.Number] = None,
        depends_on: typing.Optional[typing.List[cdktf.TerraformResource]] = None,
        lifecycle: typing.Optional[cdktf.TerraformResourceLifecycle] = None,
        provider: typing.Optional[cdktf.TerraformProvider] = None,
        account_name: builtins.str,
        location: builtins.str,
        name: builtins.str,
        pool_name: builtins.str,
        resource_group_name: builtins.str,
        volume_name: builtins.str,
        timeouts: typing.Optional["NetappSnapshotTimeouts"] = None,
    ) -> None:
        """
        :param count: 
        :param depends_on: 
        :param lifecycle: 
        :param provider: 
        :param account_name: 
        :param location: 
        :param name: 
        :param pool_name: 
        :param resource_group_name: 
        :param volume_name: 
        :param timeouts: timeouts block.
        """
        if isinstance(lifecycle, dict):
            lifecycle = cdktf.TerraformResourceLifecycle(**lifecycle)
        if isinstance(timeouts, dict):
            timeouts = NetappSnapshotTimeouts(**timeouts)
        self._values: typing.Dict[str, typing.Any] = {
            "account_name": account_name,
            "location": location,
            "name": name,
            "pool_name": pool_name,
            "resource_group_name": resource_group_name,
            "volume_name": volume_name,
        }
        if count is not None:
            self._values["count"] = count
        if depends_on is not None:
            self._values["depends_on"] = depends_on
        if lifecycle is not None:
            self._values["lifecycle"] = lifecycle
        if provider is not None:
            self._values["provider"] = provider
        if timeouts is not None:
            self._values["timeouts"] = timeouts

    @builtins.property
    def count(self) -> typing.Optional[jsii.Number]:
        """
        :stability: experimental
        """
        result = self._values.get("count")
        return result

    @builtins.property
    def depends_on(self) -> typing.Optional[typing.List[cdktf.TerraformResource]]:
        """
        :stability: experimental
        """
        result = self._values.get("depends_on")
        return result

    @builtins.property
    def lifecycle(self) -> typing.Optional[cdktf.TerraformResourceLifecycle]:
        """
        :stability: experimental
        """
        result = self._values.get("lifecycle")
        return result

    @builtins.property
    def provider(self) -> typing.Optional[cdktf.TerraformProvider]:
        """
        :stability: experimental
        """
        result = self._values.get("provider")
        return result

    @builtins.property
    def account_name(self) -> builtins.str:
        result = self._values.get("account_name")
        assert result is not None, "Required property 'account_name' is missing"
        return result

    @builtins.property
    def location(self) -> builtins.str:
        result = self._values.get("location")
        assert result is not None, "Required property 'location' is missing"
        return result

    @builtins.property
    def name(self) -> builtins.str:
        result = self._values.get("name")
        assert result is not None, "Required property 'name' is missing"
        return result

    @builtins.property
    def pool_name(self) -> builtins.str:
        result = self._values.get("pool_name")
        assert result is not None, "Required property 'pool_name' is missing"
        return result

    @builtins.property
    def resource_group_name(self) -> builtins.str:
        result = self._values.get("resource_group_name")
        assert result is not None, "Required property 'resource_group_name' is missing"
        return result

    @builtins.property
    def volume_name(self) -> builtins.str:
        result = self._values.get("volume_name")
        assert result is not None, "Required property 'volume_name' is missing"
        return result

    @builtins.property
    def timeouts(self) -> typing.Optional["NetappSnapshotTimeouts"]:
        """timeouts block."""
        result = self._values.get("timeouts")
        return result

    def __eq__(self, rhs: typing.Any) -> builtins.bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs: typing.Any) -> builtins.bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return "NetappSnapshotConfig(%s)" % ", ".join(
            k + "=" + repr(v) for k, v in self._values.items()
        )


@jsii.data_type(
    jsii_type="@cdktf/provider-azurerm.NetappSnapshotTimeouts",
    jsii_struct_bases=[],
    name_mapping={
        "create": "create",
        "delete": "delete",
        "read": "read",
        "update": "update",
    },
)
class NetappSnapshotTimeouts:
    def __init__(
        self,
        *,
        create: typing.Optional[builtins.str] = None,
        delete: typing.Optional[builtins.str] = None,
        read: typing.Optional[builtins.str] = None,
        update: typing.Optional[builtins.str] = None,
    ) -> None:
        """
        :param create: 
        :param delete: 
        :param read: 
        :param update: 
        """
        self._values: typing.Dict[str, typing.Any] = {}
        if create is not None:
            self._values["create"] = create
        if delete is not None:
            self._values["delete"] = delete
        if read is not None:
            self._values["read"] = read
        if update is not None:
            self._values["update"] = update

    @builtins.property
    def create(self) -> typing.Optional[builtins.str]:
        result = self._values.get("create")
        return result

    @builtins.property
    def delete(self) -> typing.Optional[builtins.str]:
        result = self._values.get("delete")
        return result

    @builtins.property
    def read(self) -> typing.Optional[builtins.str]:
        result = self._values.get("read")
        return result

    @builtins.property
    def update(self) -> typing.Optional[builtins.str]:
        result = self._values.get("update")
        return result

    def __eq__(self, rhs: typing.Any) -> builtins.bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs: typing.Any) -> builtins.bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return "NetappSnapshotTimeouts(%s)" % ", ".join(
            k + "=" + repr(v) for k, v in self._values.items()
        )


class NetappVolume(
    cdktf.TerraformResource,
    metaclass=jsii.JSIIMeta,
    jsii_type="@cdktf/provider-azurerm.NetappVolume",
):
    def __init__(
        self,
        scope: constructs.Construct,
        id: builtins.str,
        *,
        account_name: builtins.str,
        location: builtins.str,
        name: builtins.str,
        pool_name: builtins.str,
        resource_group_name: builtins.str,
        service_level: builtins.str,
        storage_quota_in_gb: jsii.Number,
        subnet_id: builtins.str,
        volume_path: builtins.str,
        export_policy_rule: typing.Optional[typing.List["NetappVolumeExportPolicyRule"]] = None,
        timeouts: typing.Optional["NetappVolumeTimeouts"] = None,
        count: typing.Optional[jsii.Number] = None,
        depends_on: typing.Optional[typing.List[cdktf.TerraformResource]] = None,
        lifecycle: typing.Optional[cdktf.TerraformResourceLifecycle] = None,
        provider: typing.Optional[cdktf.TerraformProvider] = None,
    ) -> None:
        """
        :param scope: -
        :param id: -
        :param account_name: 
        :param location: 
        :param name: 
        :param pool_name: 
        :param resource_group_name: 
        :param service_level: 
        :param storage_quota_in_gb: 
        :param subnet_id: 
        :param volume_path: 
        :param export_policy_rule: export_policy_rule block.
        :param timeouts: timeouts block.
        :param count: 
        :param depends_on: 
        :param lifecycle: 
        :param provider: 
        """
        config = NetappVolumeConfig(
            account_name=account_name,
            location=location,
            name=name,
            pool_name=pool_name,
            resource_group_name=resource_group_name,
            service_level=service_level,
            storage_quota_in_gb=storage_quota_in_gb,
            subnet_id=subnet_id,
            volume_path=volume_path,
            export_policy_rule=export_policy_rule,
            timeouts=timeouts,
            count=count,
            depends_on=depends_on,
            lifecycle=lifecycle,
            provider=provider,
        )

        jsii.create(NetappVolume, self, [scope, id, config])

    @jsii.member(jsii_name="synthesizeAttributes")
    def _synthesize_attributes(self) -> typing.Mapping[builtins.str, typing.Any]:
        return jsii.invoke(self, "synthesizeAttributes", [])

    @builtins.property # type: ignore
    @jsii.member(jsii_name="accountName")
    def account_name(self) -> builtins.str:
        return jsii.get(self, "accountName")

    @account_name.setter # type: ignore
    def account_name(self, value: builtins.str) -> None:
        jsii.set(self, "accountName", value)

    @builtins.property # type: ignore
    @jsii.member(jsii_name="location")
    def location(self) -> builtins.str:
        return jsii.get(self, "location")

    @location.setter # type: ignore
    def location(self, value: builtins.str) -> None:
        jsii.set(self, "location", value)

    @builtins.property # type: ignore
    @jsii.member(jsii_name="name")
    def name(self) -> builtins.str:
        return jsii.get(self, "name")

    @name.setter # type: ignore
    def name(self, value: builtins.str) -> None:
        jsii.set(self, "name", value)

    @builtins.property # type: ignore
    @jsii.member(jsii_name="poolName")
    def pool_name(self) -> builtins.str:
        return jsii.get(self, "poolName")

    @pool_name.setter # type: ignore
    def pool_name(self, value: builtins.str) -> None:
        jsii.set(self, "poolName", value)

    @builtins.property # type: ignore
    @jsii.member(jsii_name="resourceGroupName")
    def resource_group_name(self) -> builtins.str:
        return jsii.get(self, "resourceGroupName")

    @resource_group_name.setter # type: ignore
    def resource_group_name(self, value: builtins.str) -> None:
        jsii.set(self, "resourceGroupName", value)

    @builtins.property # type: ignore
    @jsii.member(jsii_name="serviceLevel")
    def service_level(self) -> builtins.str:
        return jsii.get(self, "serviceLevel")

    @service_level.setter # type: ignore
    def service_level(self, value: builtins.str) -> None:
        jsii.set(self, "serviceLevel", value)

    @builtins.property # type: ignore
    @jsii.member(jsii_name="storageQuotaInGb")
    def storage_quota_in_gb(self) -> jsii.Number:
        return jsii.get(self, "storageQuotaInGb")

    @storage_quota_in_gb.setter # type: ignore
    def storage_quota_in_gb(self, value: jsii.Number) -> None:
        jsii.set(self, "storageQuotaInGb", value)

    @builtins.property # type: ignore
    @jsii.member(jsii_name="subnetId")
    def subnet_id(self) -> builtins.str:
        return jsii.get(self, "subnetId")

    @subnet_id.setter # type: ignore
    def subnet_id(self, value: builtins.str) -> None:
        jsii.set(self, "subnetId", value)

    @builtins.property # type: ignore
    @jsii.member(jsii_name="volumePath")
    def volume_path(self) -> builtins.str:
        return jsii.get(self, "volumePath")

    @volume_path.setter # type: ignore
    def volume_path(self, value: builtins.str) -> None:
        jsii.set(self, "volumePath", value)

    @builtins.property # type: ignore
    @jsii.member(jsii_name="exportPolicyRule")
    def export_policy_rule(
        self,
    ) -> typing.Optional[typing.List["NetappVolumeExportPolicyRule"]]:
        return jsii.get(self, "exportPolicyRule")

    @export_policy_rule.setter # type: ignore
    def export_policy_rule(
        self,
        value: typing.Optional[typing.List["NetappVolumeExportPolicyRule"]],
    ) -> None:
        jsii.set(self, "exportPolicyRule", value)

    @builtins.property # type: ignore
    @jsii.member(jsii_name="id")
    def id(self) -> typing.Optional[builtins.str]:
        return jsii.get(self, "id")

    @id.setter # type: ignore
    def id(self, value: typing.Optional[builtins.str]) -> None:
        jsii.set(self, "id", value)

    @builtins.property # type: ignore
    @jsii.member(jsii_name="timeouts")
    def timeouts(self) -> typing.Optional["NetappVolumeTimeouts"]:
        return jsii.get(self, "timeouts")

    @timeouts.setter # type: ignore
    def timeouts(self, value: typing.Optional["NetappVolumeTimeouts"]) -> None:
        jsii.set(self, "timeouts", value)


@jsii.data_type(
    jsii_type="@cdktf/provider-azurerm.NetappVolumeConfig",
    jsii_struct_bases=[cdktf.TerraformMetaArguments],
    name_mapping={
        "count": "count",
        "depends_on": "dependsOn",
        "lifecycle": "lifecycle",
        "provider": "provider",
        "account_name": "accountName",
        "location": "location",
        "name": "name",
        "pool_name": "poolName",
        "resource_group_name": "resourceGroupName",
        "service_level": "serviceLevel",
        "storage_quota_in_gb": "storageQuotaInGb",
        "subnet_id": "subnetId",
        "volume_path": "volumePath",
        "export_policy_rule": "exportPolicyRule",
        "timeouts": "timeouts",
    },
)
class NetappVolumeConfig(cdktf.TerraformMetaArguments):
    def __init__(
        self,
        *,
        count: typing.Optional[jsii.Number] = None,
        depends_on: typing.Optional[typing.List[cdktf.TerraformResource]] = None,
        lifecycle: typing.Optional[cdktf.TerraformResourceLifecycle] = None,
        provider: typing.Optional[cdktf.TerraformProvider] = None,
        account_name: builtins.str,
        location: builtins.str,
        name: builtins.str,
        pool_name: builtins.str,
        resource_group_name: builtins.str,
        service_level: builtins.str,
        storage_quota_in_gb: jsii.Number,
        subnet_id: builtins.str,
        volume_path: builtins.str,
        export_policy_rule: typing.Optional[typing.List["NetappVolumeExportPolicyRule"]] = None,
        timeouts: typing.Optional["NetappVolumeTimeouts"] = None,
    ) -> None:
        """
        :param count: 
        :param depends_on: 
        :param lifecycle: 
        :param provider: 
        :param account_name: 
        :param location: 
        :param name: 
        :param pool_name: 
        :param resource_group_name: 
        :param service_level: 
        :param storage_quota_in_gb: 
        :param subnet_id: 
        :param volume_path: 
        :param export_policy_rule: export_policy_rule block.
        :param timeouts: timeouts block.
        """
        if isinstance(lifecycle, dict):
            lifecycle = cdktf.TerraformResourceLifecycle(**lifecycle)
        if isinstance(timeouts, dict):
            timeouts = NetappVolumeTimeouts(**timeouts)
        self._values: typing.Dict[str, typing.Any] = {
            "account_name": account_name,
            "location": location,
            "name": name,
            "pool_name": pool_name,
            "resource_group_name": resource_group_name,
            "service_level": service_level,
            "storage_quota_in_gb": storage_quota_in_gb,
            "subnet_id": subnet_id,
            "volume_path": volume_path,
        }
        if count is not None:
            self._values["count"] = count
        if depends_on is not None:
            self._values["depends_on"] = depends_on
        if lifecycle is not None:
            self._values["lifecycle"] = lifecycle
        if provider is not None:
            self._values["provider"] = provider
        if export_policy_rule is not None:
            self._values["export_policy_rule"] = export_policy_rule
        if timeouts is not None:
            self._values["timeouts"] = timeouts

    @builtins.property
    def count(self) -> typing.Optional[jsii.Number]:
        """
        :stability: experimental
        """
        result = self._values.get("count")
        return result

    @builtins.property
    def depends_on(self) -> typing.Optional[typing.List[cdktf.TerraformResource]]:
        """
        :stability: experimental
        """
        result = self._values.get("depends_on")
        return result

    @builtins.property
    def lifecycle(self) -> typing.Optional[cdktf.TerraformResourceLifecycle]:
        """
        :stability: experimental
        """
        result = self._values.get("lifecycle")
        return result

    @builtins.property
    def provider(self) -> typing.Optional[cdktf.TerraformProvider]:
        """
        :stability: experimental
        """
        result = self._values.get("provider")
        return result

    @builtins.property
    def account_name(self) -> builtins.str:
        result = self._values.get("account_name")
        assert result is not None, "Required property 'account_name' is missing"
        return result

    @builtins.property
    def location(self) -> builtins.str:
        result = self._values.get("location")
        assert result is not None, "Required property 'location' is missing"
        return result

    @builtins.property
    def name(self) -> builtins.str:
        result = self._values.get("name")
        assert result is not None, "Required property 'name' is missing"
        return result

    @builtins.property
    def pool_name(self) -> builtins.str:
        result = self._values.get("pool_name")
        assert result is not None, "Required property 'pool_name' is missing"
        return result

    @builtins.property
    def resource_group_name(self) -> builtins.str:
        result = self._values.get("resource_group_name")
        assert result is not None, "Required property 'resource_group_name' is missing"
        return result

    @builtins.property
    def service_level(self) -> builtins.str:
        result = self._values.get("service_level")
        assert result is not None, "Required property 'service_level' is missing"
        return result

    @builtins.property
    def storage_quota_in_gb(self) -> jsii.Number:
        result = self._values.get("storage_quota_in_gb")
        assert result is not None, "Required property 'storage_quota_in_gb' is missing"
        return result

    @builtins.property
    def subnet_id(self) -> builtins.str:
        result = self._values.get("subnet_id")
        assert result is not None, "Required property 'subnet_id' is missing"
        return result

    @builtins.property
    def volume_path(self) -> builtins.str:
        result = self._values.get("volume_path")
        assert result is not None, "Required property 'volume_path' is missing"
        return result

    @builtins.property
    def export_policy_rule(
        self,
    ) -> typing.Optional[typing.List["NetappVolumeExportPolicyRule"]]:
        """export_policy_rule block."""
        result = self._values.get("export_policy_rule")
        return result

    @builtins.property
    def timeouts(self) -> typing.Optional["NetappVolumeTimeouts"]:
        """timeouts block."""
        result = self._values.get("timeouts")
        return result

    def __eq__(self, rhs: typing.Any) -> builtins.bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs: typing.Any) -> builtins.bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return "NetappVolumeConfig(%s)" % ", ".join(
            k + "=" + repr(v) for k, v in self._values.items()
        )


@jsii.data_type(
    jsii_type="@cdktf/provider-azurerm.NetappVolumeExportPolicyRule",
    jsii_struct_bases=[],
    name_mapping={
        "allowed_clients": "allowedClients",
        "cifs_enabled": "cifsEnabled",
        "nfsv3_enabled": "nfsv3Enabled",
        "nfsv4_enabled": "nfsv4Enabled",
        "rule_index": "ruleIndex",
        "unix_read_only": "unixReadOnly",
        "unix_read_write": "unixReadWrite",
    },
)
class NetappVolumeExportPolicyRule:
    def __init__(
        self,
        *,
        allowed_clients: typing.List[builtins.str],
        cifs_enabled: builtins.bool,
        nfsv3_enabled: builtins.bool,
        nfsv4_enabled: builtins.bool,
        rule_index: jsii.Number,
        unix_read_only: typing.Optional[builtins.bool] = None,
        unix_read_write: typing.Optional[builtins.bool] = None,
    ) -> None:
        """
        :param allowed_clients: 
        :param cifs_enabled: 
        :param nfsv3_enabled: 
        :param nfsv4_enabled: 
        :param rule_index: 
        :param unix_read_only: 
        :param unix_read_write: 
        """
        self._values: typing.Dict[str, typing.Any] = {
            "allowed_clients": allowed_clients,
            "cifs_enabled": cifs_enabled,
            "nfsv3_enabled": nfsv3_enabled,
            "nfsv4_enabled": nfsv4_enabled,
            "rule_index": rule_index,
        }
        if unix_read_only is not None:
            self._values["unix_read_only"] = unix_read_only
        if unix_read_write is not None:
            self._values["unix_read_write"] = unix_read_write

    @builtins.property
    def allowed_clients(self) -> typing.List[builtins.str]:
        result = self._values.get("allowed_clients")
        assert result is not None, "Required property 'allowed_clients' is missing"
        return result

    @builtins.property
    def cifs_enabled(self) -> builtins.bool:
        result = self._values.get("cifs_enabled")
        assert result is not None, "Required property 'cifs_enabled' is missing"
        return result

    @builtins.property
    def nfsv3_enabled(self) -> builtins.bool:
        result = self._values.get("nfsv3_enabled")
        assert result is not None, "Required property 'nfsv3_enabled' is missing"
        return result

    @builtins.property
    def nfsv4_enabled(self) -> builtins.bool:
        result = self._values.get("nfsv4_enabled")
        assert result is not None, "Required property 'nfsv4_enabled' is missing"
        return result

    @builtins.property
    def rule_index(self) -> jsii.Number:
        result = self._values.get("rule_index")
        assert result is not None, "Required property 'rule_index' is missing"
        return result

    @builtins.property
    def unix_read_only(self) -> typing.Optional[builtins.bool]:
        result = self._values.get("unix_read_only")
        return result

    @builtins.property
    def unix_read_write(self) -> typing.Optional[builtins.bool]:
        result = self._values.get("unix_read_write")
        return result

    def __eq__(self, rhs: typing.Any) -> builtins.bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs: typing.Any) -> builtins.bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return "NetappVolumeExportPolicyRule(%s)" % ", ".join(
            k + "=" + repr(v) for k, v in self._values.items()
        )


@jsii.data_type(
    jsii_type="@cdktf/provider-azurerm.NetappVolumeTimeouts",
    jsii_struct_bases=[],
    name_mapping={
        "create": "create",
        "delete": "delete",
        "read": "read",
        "update": "update",
    },
)
class NetappVolumeTimeouts:
    def __init__(
        self,
        *,
        create: typing.Optional[builtins.str] = None,
        delete: typing.Optional[builtins.str] = None,
        read: typing.Optional[builtins.str] = None,
        update: typing.Optional[builtins.str] = None,
    ) -> None:
        """
        :param create: 
        :param delete: 
        :param read: 
        :param update: 
        """
        self._values: typing.Dict[str, typing.Any] = {}
        if create is not None:
            self._values["create"] = create
        if delete is not None:
            self._values["delete"] = delete
        if read is not None:
            self._values["read"] = read
        if update is not None:
            self._values["update"] = update

    @builtins.property
    def create(self) -> typing.Optional[builtins.str]:
        result = self._values.get("create")
        return result

    @builtins.property
    def delete(self) -> typing.Optional[builtins.str]:
        result = self._values.get("delete")
        return result

    @builtins.property
    def read(self) -> typing.Optional[builtins.str]:
        result = self._values.get("read")
        return result

    @builtins.property
    def update(self) -> typing.Optional[builtins.str]:
        result = self._values.get("update")
        return result

    def __eq__(self, rhs: typing.Any) -> builtins.bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs: typing.Any) -> builtins.bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return "NetappVolumeTimeouts(%s)" % ", ".join(
            k + "=" + repr(v) for k, v in self._values.items()
        )


class NetworkConnectionMonitor(
    cdktf.TerraformResource,
    metaclass=jsii.JSIIMeta,
    jsii_type="@cdktf/provider-azurerm.NetworkConnectionMonitor",
):
    def __init__(
        self,
        scope: constructs.Construct,
        id: builtins.str,
        *,
        destination: typing.List["NetworkConnectionMonitorDestination"],
        location: builtins.str,
        name: builtins.str,
        network_watcher_name: builtins.str,
        resource_group_name: builtins.str,
        source: typing.List["NetworkConnectionMonitorSource"],
        auto_start: typing.Optional[builtins.bool] = None,
        interval_in_seconds: typing.Optional[jsii.Number] = None,
        tags: typing.Optional[typing.Mapping[builtins.str, builtins.str]] = None,
        timeouts: typing.Optional["NetworkConnectionMonitorTimeouts"] = None,
        count: typing.Optional[jsii.Number] = None,
        depends_on: typing.Optional[typing.List[cdktf.TerraformResource]] = None,
        lifecycle: typing.Optional[cdktf.TerraformResourceLifecycle] = None,
        provider: typing.Optional[cdktf.TerraformProvider] = None,
    ) -> None:
        """
        :param scope: -
        :param id: -
        :param destination: destination block.
        :param location: 
        :param name: 
        :param network_watcher_name: 
        :param resource_group_name: 
        :param source: source block.
        :param auto_start: 
        :param interval_in_seconds: 
        :param tags: 
        :param timeouts: timeouts block.
        :param count: 
        :param depends_on: 
        :param lifecycle: 
        :param provider: 
        """
        config = NetworkConnectionMonitorConfig(
            destination=destination,
            location=location,
            name=name,
            network_watcher_name=network_watcher_name,
            resource_group_name=resource_group_name,
            source=source,
            auto_start=auto_start,
            interval_in_seconds=interval_in_seconds,
            tags=tags,
            timeouts=timeouts,
            count=count,
            depends_on=depends_on,
            lifecycle=lifecycle,
            provider=provider,
        )

        jsii.create(NetworkConnectionMonitor, self, [scope, id, config])

    @jsii.member(jsii_name="synthesizeAttributes")
    def _synthesize_attributes(self) -> typing.Mapping[builtins.str, typing.Any]:
        return jsii.invoke(self, "synthesizeAttributes", [])

    @builtins.property # type: ignore
    @jsii.member(jsii_name="destination")
    def destination(self) -> typing.List["NetworkConnectionMonitorDestination"]:
        return jsii.get(self, "destination")

    @destination.setter # type: ignore
    def destination(
        self,
        value: typing.List["NetworkConnectionMonitorDestination"],
    ) -> None:
        jsii.set(self, "destination", value)

    @builtins.property # type: ignore
    @jsii.member(jsii_name="location")
    def location(self) -> builtins.str:
        return jsii.get(self, "location")

    @location.setter # type: ignore
    def location(self, value: builtins.str) -> None:
        jsii.set(self, "location", value)

    @builtins.property # type: ignore
    @jsii.member(jsii_name="name")
    def name(self) -> builtins.str:
        return jsii.get(self, "name")

    @name.setter # type: ignore
    def name(self, value: builtins.str) -> None:
        jsii.set(self, "name", value)

    @builtins.property # type: ignore
    @jsii.member(jsii_name="networkWatcherName")
    def network_watcher_name(self) -> builtins.str:
        return jsii.get(self, "networkWatcherName")

    @network_watcher_name.setter # type: ignore
    def network_watcher_name(self, value: builtins.str) -> None:
        jsii.set(self, "networkWatcherName", value)

    @builtins.property # type: ignore
    @jsii.member(jsii_name="resourceGroupName")
    def resource_group_name(self) -> builtins.str:
        return jsii.get(self, "resourceGroupName")

    @resource_group_name.setter # type: ignore
    def resource_group_name(self, value: builtins.str) -> None:
        jsii.set(self, "resourceGroupName", value)

    @builtins.property # type: ignore
    @jsii.member(jsii_name="source")
    def source(self) -> typing.List["NetworkConnectionMonitorSource"]:
        return jsii.get(self, "source")

    @source.setter # type: ignore
    def source(self, value: typing.List["NetworkConnectionMonitorSource"]) -> None:
        jsii.set(self, "source", value)

    @builtins.property # type: ignore
    @jsii.member(jsii_name="autoStart")
    def auto_start(self) -> typing.Optional[builtins.bool]:
        return jsii.get(self, "autoStart")

    @auto_start.setter # type: ignore
    def auto_start(self, value: typing.Optional[builtins.bool]) -> None:
        jsii.set(self, "autoStart", value)

    @builtins.property # type: ignore
    @jsii.member(jsii_name="id")
    def id(self) -> typing.Optional[builtins.str]:
        return jsii.get(self, "id")

    @id.setter # type: ignore
    def id(self, value: typing.Optional[builtins.str]) -> None:
        jsii.set(self, "id", value)

    @builtins.property # type: ignore
    @jsii.member(jsii_name="intervalInSeconds")
    def interval_in_seconds(self) -> typing.Optional[jsii.Number]:
        return jsii.get(self, "intervalInSeconds")

    @interval_in_seconds.setter # type: ignore
    def interval_in_seconds(self, value: typing.Optional[jsii.Number]) -> None:
        jsii.set(self, "intervalInSeconds", value)

    @builtins.property # type: ignore
    @jsii.member(jsii_name="tags")
    def tags(self) -> typing.Optional[typing.Mapping[builtins.str, builtins.str]]:
        return jsii.get(self, "tags")

    @tags.setter # type: ignore
    def tags(
        self,
        value: typing.Optional[typing.Mapping[builtins.str, builtins.str]],
    ) -> None:
        jsii.set(self, "tags", value)

    @builtins.property # type: ignore
    @jsii.member(jsii_name="timeouts")
    def timeouts(self) -> typing.Optional["NetworkConnectionMonitorTimeouts"]:
        return jsii.get(self, "timeouts")

    @timeouts.setter # type: ignore
    def timeouts(
        self,
        value: typing.Optional["NetworkConnectionMonitorTimeouts"],
    ) -> None:
        jsii.set(self, "timeouts", value)


@jsii.data_type(
    jsii_type="@cdktf/provider-azurerm.NetworkConnectionMonitorConfig",
    jsii_struct_bases=[cdktf.TerraformMetaArguments],
    name_mapping={
        "count": "count",
        "depends_on": "dependsOn",
        "lifecycle": "lifecycle",
        "provider": "provider",
        "destination": "destination",
        "location": "location",
        "name": "name",
        "network_watcher_name": "networkWatcherName",
        "resource_group_name": "resourceGroupName",
        "source": "source",
        "auto_start": "autoStart",
        "interval_in_seconds": "intervalInSeconds",
        "tags": "tags",
        "timeouts": "timeouts",
    },
)
class NetworkConnectionMonitorConfig(cdktf.TerraformMetaArguments):
    def __init__(
        self,
        *,
        count: typing.Optional[jsii.Number] = None,
        depends_on: typing.Optional[typing.List[cdktf.TerraformResource]] = None,
        lifecycle: typing.Optional[cdktf.TerraformResourceLifecycle] = None,
        provider: typing.Optional[cdktf.TerraformProvider] = None,
        destination: typing.List["NetworkConnectionMonitorDestination"],
        location: builtins.str,
        name: builtins.str,
        network_watcher_name: builtins.str,
        resource_group_name: builtins.str,
        source: typing.List["NetworkConnectionMonitorSource"],
        auto_start: typing.Optional[builtins.bool] = None,
        interval_in_seconds: typing.Optional[jsii.Number] = None,
        tags: typing.Optional[typing.Mapping[builtins.str, builtins.str]] = None,
        timeouts: typing.Optional["NetworkConnectionMonitorTimeouts"] = None,
    ) -> None:
        """
        :param count: 
        :param depends_on: 
        :param lifecycle: 
        :param provider: 
        :param destination: destination block.
        :param location: 
        :param name: 
        :param network_watcher_name: 
        :param resource_group_name: 
        :param source: source block.
        :param auto_start: 
        :param interval_in_seconds: 
        :param tags: 
        :param timeouts: timeouts block.
        """
        if isinstance(lifecycle, dict):
            lifecycle = cdktf.TerraformResourceLifecycle(**lifecycle)
        if isinstance(timeouts, dict):
            timeouts = NetworkConnectionMonitorTimeouts(**timeouts)
        self._values: typing.Dict[str, typing.Any] = {
            "destination": destination,
            "location": location,
            "name": name,
            "network_watcher_name": network_watcher_name,
            "resource_group_name": resource_group_name,
            "source": source,
        }
        if count is not None:
            self._values["count"] = count
        if depends_on is not None:
            self._values["depends_on"] = depends_on
        if lifecycle is not None:
            self._values["lifecycle"] = lifecycle
        if provider is not None:
            self._values["provider"] = provider
        if auto_start is not None:
            self._values["auto_start"] = auto_start
        if interval_in_seconds is not None:
            self._values["interval_in_seconds"] = interval_in_seconds
        if tags is not None:
            self._values["tags"] = tags
        if timeouts is not None:
            self._values["timeouts"] = timeouts

    @builtins.property
    def count(self) -> typing.Optional[jsii.Number]:
        """
        :stability: experimental
        """
        result = self._values.get("count")
        return result

    @builtins.property
    def depends_on(self) -> typing.Optional[typing.List[cdktf.TerraformResource]]:
        """
        :stability: experimental
        """
        result = self._values.get("depends_on")
        return result

    @builtins.property
    def lifecycle(self) -> typing.Optional[cdktf.TerraformResourceLifecycle]:
        """
        :stability: experimental
        """
        result = self._values.get("lifecycle")
        return result

    @builtins.property
    def provider(self) -> typing.Optional[cdktf.TerraformProvider]:
        """
        :stability: experimental
        """
        result = self._values.get("provider")
        return result

    @builtins.property
    def destination(self) -> typing.List["NetworkConnectionMonitorDestination"]:
        """destination block."""
        result = self._values.get("destination")
        assert result is not None, "Required property 'destination' is missing"
        return result

    @builtins.property
    def location(self) -> builtins.str:
        result = self._values.get("location")
        assert result is not None, "Required property 'location' is missing"
        return result

    @builtins.property
    def name(self) -> builtins.str:
        result = self._values.get("name")
        assert result is not None, "Required property 'name' is missing"
        return result

    @builtins.property
    def network_watcher_name(self) -> builtins.str:
        result = self._values.get("network_watcher_name")
        assert result is not None, "Required property 'network_watcher_name' is missing"
        return result

    @builtins.property
    def resource_group_name(self) -> builtins.str:
        result = self._values.get("resource_group_name")
        assert result is not None, "Required property 'resource_group_name' is missing"
        return result

    @builtins.property
    def source(self) -> typing.List["NetworkConnectionMonitorSource"]:
        """source block."""
        result = self._values.get("source")
        assert result is not None, "Required property 'source' is missing"
        return result

    @builtins.property
    def auto_start(self) -> typing.Optional[builtins.bool]:
        result = self._values.get("auto_start")
        return result

    @builtins.property
    def interval_in_seconds(self) -> typing.Optional[jsii.Number]:
        result = self._values.get("interval_in_seconds")
        return result

    @builtins.property
    def tags(self) -> typing.Optional[typing.Mapping[builtins.str, builtins.str]]:
        result = self._values.get("tags")
        return result

    @builtins.property
    def timeouts(self) -> typing.Optional["NetworkConnectionMonitorTimeouts"]:
        """timeouts block."""
        result = self._values.get("timeouts")
        return result

    def __eq__(self, rhs: typing.Any) -> builtins.bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs: typing.Any) -> builtins.bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return "NetworkConnectionMonitorConfig(%s)" % ", ".join(
            k + "=" + repr(v) for k, v in self._values.items()
        )


@jsii.data_type(
    jsii_type="@cdktf/provider-azurerm.NetworkConnectionMonitorDestination",
    jsii_struct_bases=[],
    name_mapping={
        "port": "port",
        "address": "address",
        "virtual_machine_id": "virtualMachineId",
    },
)
class NetworkConnectionMonitorDestination:
    def __init__(
        self,
        *,
        port: jsii.Number,
        address: typing.Optional[builtins.str] = None,
        virtual_machine_id: typing.Optional[builtins.str] = None,
    ) -> None:
        """
        :param port: 
        :param address: 
        :param virtual_machine_id: 
        """
        self._values: typing.Dict[str, typing.Any] = {
            "port": port,
        }
        if address is not None:
            self._values["address"] = address
        if virtual_machine_id is not None:
            self._values["virtual_machine_id"] = virtual_machine_id

    @builtins.property
    def port(self) -> jsii.Number:
        result = self._values.get("port")
        assert result is not None, "Required property 'port' is missing"
        return result

    @builtins.property
    def address(self) -> typing.Optional[builtins.str]:
        result = self._values.get("address")
        return result

    @builtins.property
    def virtual_machine_id(self) -> typing.Optional[builtins.str]:
        result = self._values.get("virtual_machine_id")
        return result

    def __eq__(self, rhs: typing.Any) -> builtins.bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs: typing.Any) -> builtins.bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return "NetworkConnectionMonitorDestination(%s)" % ", ".join(
            k + "=" + repr(v) for k, v in self._values.items()
        )


@jsii.data_type(
    jsii_type="@cdktf/provider-azurerm.NetworkConnectionMonitorSource",
    jsii_struct_bases=[],
    name_mapping={"virtual_machine_id": "virtualMachineId", "port": "port"},
)
class NetworkConnectionMonitorSource:
    def __init__(
        self,
        *,
        virtual_machine_id: builtins.str,
        port: typing.Optional[jsii.Number] = None,
    ) -> None:
        """
        :param virtual_machine_id: 
        :param port: 
        """
        self._values: typing.Dict[str, typing.Any] = {
            "virtual_machine_id": virtual_machine_id,
        }
        if port is not None:
            self._values["port"] = port

    @builtins.property
    def virtual_machine_id(self) -> builtins.str:
        result = self._values.get("virtual_machine_id")
        assert result is not None, "Required property 'virtual_machine_id' is missing"
        return result

    @builtins.property
    def port(self) -> typing.Optional[jsii.Number]:
        result = self._values.get("port")
        return result

    def __eq__(self, rhs: typing.Any) -> builtins.bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs: typing.Any) -> builtins.bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return "NetworkConnectionMonitorSource(%s)" % ", ".join(
            k + "=" + repr(v) for k, v in self._values.items()
        )


@jsii.data_type(
    jsii_type="@cdktf/provider-azurerm.NetworkConnectionMonitorTimeouts",
    jsii_struct_bases=[],
    name_mapping={
        "create": "create",
        "delete": "delete",
        "read": "read",
        "update": "update",
    },
)
class NetworkConnectionMonitorTimeouts:
    def __init__(
        self,
        *,
        create: typing.Optional[builtins.str] = None,
        delete: typing.Optional[builtins.str] = None,
        read: typing.Optional[builtins.str] = None,
        update: typing.Optional[builtins.str] = None,
    ) -> None:
        """
        :param create: 
        :param delete: 
        :param read: 
        :param update: 
        """
        self._values: typing.Dict[str, typing.Any] = {}
        if create is not None:
            self._values["create"] = create
        if delete is not None:
            self._values["delete"] = delete
        if read is not None:
            self._values["read"] = read
        if update is not None:
            self._values["update"] = update

    @builtins.property
    def create(self) -> typing.Optional[builtins.str]:
        result = self._values.get("create")
        return result

    @builtins.property
    def delete(self) -> typing.Optional[builtins.str]:
        result = self._values.get("delete")
        return result

    @builtins.property
    def read(self) -> typing.Optional[builtins.str]:
        result = self._values.get("read")
        return result

    @builtins.property
    def update(self) -> typing.Optional[builtins.str]:
        result = self._values.get("update")
        return result

    def __eq__(self, rhs: typing.Any) -> builtins.bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs: typing.Any) -> builtins.bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return "NetworkConnectionMonitorTimeouts(%s)" % ", ".join(
            k + "=" + repr(v) for k, v in self._values.items()
        )


class NetworkDdosProtectionPlan(
    cdktf.TerraformResource,
    metaclass=jsii.JSIIMeta,
    jsii_type="@cdktf/provider-azurerm.NetworkDdosProtectionPlan",
):
    def __init__(
        self,
        scope: constructs.Construct,
        id: builtins.str,
        *,
        location: builtins.str,
        name: builtins.str,
        resource_group_name: builtins.str,
        tags: typing.Optional[typing.Mapping[builtins.str, builtins.str]] = None,
        timeouts: typing.Optional["NetworkDdosProtectionPlanTimeouts"] = None,
        count: typing.Optional[jsii.Number] = None,
        depends_on: typing.Optional[typing.List[cdktf.TerraformResource]] = None,
        lifecycle: typing.Optional[cdktf.TerraformResourceLifecycle] = None,
        provider: typing.Optional[cdktf.TerraformProvider] = None,
    ) -> None:
        """
        :param scope: -
        :param id: -
        :param location: 
        :param name: 
        :param resource_group_name: 
        :param tags: 
        :param timeouts: timeouts block.
        :param count: 
        :param depends_on: 
        :param lifecycle: 
        :param provider: 
        """
        config = NetworkDdosProtectionPlanConfig(
            location=location,
            name=name,
            resource_group_name=resource_group_name,
            tags=tags,
            timeouts=timeouts,
            count=count,
            depends_on=depends_on,
            lifecycle=lifecycle,
            provider=provider,
        )

        jsii.create(NetworkDdosProtectionPlan, self, [scope, id, config])

    @jsii.member(jsii_name="synthesizeAttributes")
    def _synthesize_attributes(self) -> typing.Mapping[builtins.str, typing.Any]:
        return jsii.invoke(self, "synthesizeAttributes", [])

    @builtins.property # type: ignore
    @jsii.member(jsii_name="virtualNetworkIds")
    def virtual_network_ids(self) -> typing.List[builtins.str]:
        return jsii.get(self, "virtualNetworkIds")

    @builtins.property # type: ignore
    @jsii.member(jsii_name="location")
    def location(self) -> builtins.str:
        return jsii.get(self, "location")

    @location.setter # type: ignore
    def location(self, value: builtins.str) -> None:
        jsii.set(self, "location", value)

    @builtins.property # type: ignore
    @jsii.member(jsii_name="name")
    def name(self) -> builtins.str:
        return jsii.get(self, "name")

    @name.setter # type: ignore
    def name(self, value: builtins.str) -> None:
        jsii.set(self, "name", value)

    @builtins.property # type: ignore
    @jsii.member(jsii_name="resourceGroupName")
    def resource_group_name(self) -> builtins.str:
        return jsii.get(self, "resourceGroupName")

    @resource_group_name.setter # type: ignore
    def resource_group_name(self, value: builtins.str) -> None:
        jsii.set(self, "resourceGroupName", value)

    @builtins.property # type: ignore
    @jsii.member(jsii_name="id")
    def id(self) -> typing.Optional[builtins.str]:
        return jsii.get(self, "id")

    @id.setter # type: ignore
    def id(self, value: typing.Optional[builtins.str]) -> None:
        jsii.set(self, "id", value)

    @builtins.property # type: ignore
    @jsii.member(jsii_name="tags")
    def tags(self) -> typing.Optional[typing.Mapping[builtins.str, builtins.str]]:
        return jsii.get(self, "tags")

    @tags.setter # type: ignore
    def tags(
        self,
        value: typing.Optional[typing.Mapping[builtins.str, builtins.str]],
    ) -> None:
        jsii.set(self, "tags", value)

    @builtins.property # type: ignore
    @jsii.member(jsii_name="timeouts")
    def timeouts(self) -> typing.Optional["NetworkDdosProtectionPlanTimeouts"]:
        return jsii.get(self, "timeouts")

    @timeouts.setter # type: ignore
    def timeouts(
        self,
        value: typing.Optional["NetworkDdosProtectionPlanTimeouts"],
    ) -> None:
        jsii.set(self, "timeouts", value)


@jsii.data_type(
    jsii_type="@cdktf/provider-azurerm.NetworkDdosProtectionPlanConfig",
    jsii_struct_bases=[cdktf.TerraformMetaArguments],
    name_mapping={
        "count": "count",
        "depends_on": "dependsOn",
        "lifecycle": "lifecycle",
        "provider": "provider",
        "location": "location",
        "name": "name",
        "resource_group_name": "resourceGroupName",
        "tags": "tags",
        "timeouts": "timeouts",
    },
)
class NetworkDdosProtectionPlanConfig(cdktf.TerraformMetaArguments):
    def __init__(
        self,
        *,
        count: typing.Optional[jsii.Number] = None,
        depends_on: typing.Optional[typing.List[cdktf.TerraformResource]] = None,
        lifecycle: typing.Optional[cdktf.TerraformResourceLifecycle] = None,
        provider: typing.Optional[cdktf.TerraformProvider] = None,
        location: builtins.str,
        name: builtins.str,
        resource_group_name: builtins.str,
        tags: typing.Optional[typing.Mapping[builtins.str, builtins.str]] = None,
        timeouts: typing.Optional["NetworkDdosProtectionPlanTimeouts"] = None,
    ) -> None:
        """
        :param count: 
        :param depends_on: 
        :param lifecycle: 
        :param provider: 
        :param location: 
        :param name: 
        :param resource_group_name: 
        :param tags: 
        :param timeouts: timeouts block.
        """
        if isinstance(lifecycle, dict):
            lifecycle = cdktf.TerraformResourceLifecycle(**lifecycle)
        if isinstance(timeouts, dict):
            timeouts = NetworkDdosProtectionPlanTimeouts(**timeouts)
        self._values: typing.Dict[str, typing.Any] = {
            "location": location,
            "name": name,
            "resource_group_name": resource_group_name,
        }
        if count is not None:
            self._values["count"] = count
        if depends_on is not None:
            self._values["depends_on"] = depends_on
        if lifecycle is not None:
            self._values["lifecycle"] = lifecycle
        if provider is not None:
            self._values["provider"] = provider
        if tags is not None:
            self._values["tags"] = tags
        if timeouts is not None:
            self._values["timeouts"] = timeouts

    @builtins.property
    def count(self) -> typing.Optional[jsii.Number]:
        """
        :stability: experimental
        """
        result = self._values.get("count")
        return result

    @builtins.property
    def depends_on(self) -> typing.Optional[typing.List[cdktf.TerraformResource]]:
        """
        :stability: experimental
        """
        result = self._values.get("depends_on")
        return result

    @builtins.property
    def lifecycle(self) -> typing.Optional[cdktf.TerraformResourceLifecycle]:
        """
        :stability: experimental
        """
        result = self._values.get("lifecycle")
        return result

    @builtins.property
    def provider(self) -> typing.Optional[cdktf.TerraformProvider]:
        """
        :stability: experimental
        """
        result = self._values.get("provider")
        return result

    @builtins.property
    def location(self) -> builtins.str:
        result = self._values.get("location")
        assert result is not None, "Required property 'location' is missing"
        return result

    @builtins.property
    def name(self) -> builtins.str:
        result = self._values.get("name")
        assert result is not None, "Required property 'name' is missing"
        return result

    @builtins.property
    def resource_group_name(self) -> builtins.str:
        result = self._values.get("resource_group_name")
        assert result is not None, "Required property 'resource_group_name' is missing"
        return result

    @builtins.property
    def tags(self) -> typing.Optional[typing.Mapping[builtins.str, builtins.str]]:
        result = self._values.get("tags")
        return result

    @builtins.property
    def timeouts(self) -> typing.Optional["NetworkDdosProtectionPlanTimeouts"]:
        """timeouts block."""
        result = self._values.get("timeouts")
        return result

    def __eq__(self, rhs: typing.Any) -> builtins.bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs: typing.Any) -> builtins.bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return "NetworkDdosProtectionPlanConfig(%s)" % ", ".join(
            k + "=" + repr(v) for k, v in self._values.items()
        )


@jsii.data_type(
    jsii_type="@cdktf/provider-azurerm.NetworkDdosProtectionPlanTimeouts",
    jsii_struct_bases=[],
    name_mapping={
        "create": "create",
        "delete": "delete",
        "read": "read",
        "update": "update",
    },
)
class NetworkDdosProtectionPlanTimeouts:
    def __init__(
        self,
        *,
        create: typing.Optional[builtins.str] = None,
        delete: typing.Optional[builtins.str] = None,
        read: typing.Optional[builtins.str] = None,
        update: typing.Optional[builtins.str] = None,
    ) -> None:
        """
        :param create: 
        :param delete: 
        :param read: 
        :param update: 
        """
        self._values: typing.Dict[str, typing.Any] = {}
        if create is not None:
            self._values["create"] = create
        if delete is not None:
            self._values["delete"] = delete
        if read is not None:
            self._values["read"] = read
        if update is not None:
            self._values["update"] = update

    @builtins.property
    def create(self) -> typing.Optional[builtins.str]:
        result = self._values.get("create")
        return result

    @builtins.property
    def delete(self) -> typing.Optional[builtins.str]:
        result = self._values.get("delete")
        return result

    @builtins.property
    def read(self) -> typing.Optional[builtins.str]:
        result = self._values.get("read")
        return result

    @builtins.property
    def update(self) -> typing.Optional[builtins.str]:
        result = self._values.get("update")
        return result

    def __eq__(self, rhs: typing.Any) -> builtins.bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs: typing.Any) -> builtins.bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return "NetworkDdosProtectionPlanTimeouts(%s)" % ", ".join(
            k + "=" + repr(v) for k, v in self._values.items()
        )


class NetworkInterface(
    cdktf.TerraformResource,
    metaclass=jsii.JSIIMeta,
    jsii_type="@cdktf/provider-azurerm.NetworkInterface",
):
    def __init__(
        self,
        scope: constructs.Construct,
        id: builtins.str,
        *,
        ip_configuration: typing.List["NetworkInterfaceIpConfiguration"],
        location: builtins.str,
        name: builtins.str,
        resource_group_name: builtins.str,
        dns_servers: typing.Optional[typing.List[builtins.str]] = None,
        enable_accelerated_networking: typing.Optional[builtins.bool] = None,
        enable_ip_forwarding: typing.Optional[builtins.bool] = None,
        internal_dns_name_label: typing.Optional[builtins.str] = None,
        tags: typing.Optional[typing.Mapping[builtins.str, builtins.str]] = None,
        timeouts: typing.Optional["NetworkInterfaceTimeouts"] = None,
        count: typing.Optional[jsii.Number] = None,
        depends_on: typing.Optional[typing.List[cdktf.TerraformResource]] = None,
        lifecycle: typing.Optional[cdktf.TerraformResourceLifecycle] = None,
        provider: typing.Optional[cdktf.TerraformProvider] = None,
    ) -> None:
        """
        :param scope: -
        :param id: -
        :param ip_configuration: ip_configuration block.
        :param location: 
        :param name: 
        :param resource_group_name: 
        :param dns_servers: 
        :param enable_accelerated_networking: 
        :param enable_ip_forwarding: 
        :param internal_dns_name_label: 
        :param tags: 
        :param timeouts: timeouts block.
        :param count: 
        :param depends_on: 
        :param lifecycle: 
        :param provider: 
        """
        config = NetworkInterfaceConfig(
            ip_configuration=ip_configuration,
            location=location,
            name=name,
            resource_group_name=resource_group_name,
            dns_servers=dns_servers,
            enable_accelerated_networking=enable_accelerated_networking,
            enable_ip_forwarding=enable_ip_forwarding,
            internal_dns_name_label=internal_dns_name_label,
            tags=tags,
            timeouts=timeouts,
            count=count,
            depends_on=depends_on,
            lifecycle=lifecycle,
            provider=provider,
        )

        jsii.create(NetworkInterface, self, [scope, id, config])

    @jsii.member(jsii_name="synthesizeAttributes")
    def _synthesize_attributes(self) -> typing.Mapping[builtins.str, typing.Any]:
        return jsii.invoke(self, "synthesizeAttributes", [])

    @builtins.property # type: ignore
    @jsii.member(jsii_name="appliedDnsServers")
    def applied_dns_servers(self) -> typing.List[builtins.str]:
        return jsii.get(self, "appliedDnsServers")

    @builtins.property # type: ignore
    @jsii.member(jsii_name="macAddress")
    def mac_address(self) -> builtins.str:
        return jsii.get(self, "macAddress")

    @builtins.property # type: ignore
    @jsii.member(jsii_name="privateIpAddress")
    def private_ip_address(self) -> builtins.str:
        return jsii.get(self, "privateIpAddress")

    @builtins.property # type: ignore
    @jsii.member(jsii_name="privateIpAddresses")
    def private_ip_addresses(self) -> typing.List[builtins.str]:
        return jsii.get(self, "privateIpAddresses")

    @builtins.property # type: ignore
    @jsii.member(jsii_name="virtualMachineId")
    def virtual_machine_id(self) -> builtins.str:
        return jsii.get(self, "virtualMachineId")

    @builtins.property # type: ignore
    @jsii.member(jsii_name="ipConfiguration")
    def ip_configuration(self) -> typing.List["NetworkInterfaceIpConfiguration"]:
        return jsii.get(self, "ipConfiguration")

    @ip_configuration.setter # type: ignore
    def ip_configuration(
        self,
        value: typing.List["NetworkInterfaceIpConfiguration"],
    ) -> None:
        jsii.set(self, "ipConfiguration", value)

    @builtins.property # type: ignore
    @jsii.member(jsii_name="location")
    def location(self) -> builtins.str:
        return jsii.get(self, "location")

    @location.setter # type: ignore
    def location(self, value: builtins.str) -> None:
        jsii.set(self, "location", value)

    @builtins.property # type: ignore
    @jsii.member(jsii_name="name")
    def name(self) -> builtins.str:
        return jsii.get(self, "name")

    @name.setter # type: ignore
    def name(self, value: builtins.str) -> None:
        jsii.set(self, "name", value)

    @builtins.property # type: ignore
    @jsii.member(jsii_name="resourceGroupName")
    def resource_group_name(self) -> builtins.str:
        return jsii.get(self, "resourceGroupName")

    @resource_group_name.setter # type: ignore
    def resource_group_name(self, value: builtins.str) -> None:
        jsii.set(self, "resourceGroupName", value)

    @builtins.property # type: ignore
    @jsii.member(jsii_name="dnsServers")
    def dns_servers(self) -> typing.Optional[typing.List[builtins.str]]:
        return jsii.get(self, "dnsServers")

    @dns_servers.setter # type: ignore
    def dns_servers(self, value: typing.Optional[typing.List[builtins.str]]) -> None:
        jsii.set(self, "dnsServers", value)

    @builtins.property # type: ignore
    @jsii.member(jsii_name="enableAcceleratedNetworking")
    def enable_accelerated_networking(self) -> typing.Optional[builtins.bool]:
        return jsii.get(self, "enableAcceleratedNetworking")

    @enable_accelerated_networking.setter # type: ignore
    def enable_accelerated_networking(
        self,
        value: typing.Optional[builtins.bool],
    ) -> None:
        jsii.set(self, "enableAcceleratedNetworking", value)

    @builtins.property # type: ignore
    @jsii.member(jsii_name="enableIpForwarding")
    def enable_ip_forwarding(self) -> typing.Optional[builtins.bool]:
        return jsii.get(self, "enableIpForwarding")

    @enable_ip_forwarding.setter # type: ignore
    def enable_ip_forwarding(self, value: typing.Optional[builtins.bool]) -> None:
        jsii.set(self, "enableIpForwarding", value)

    @builtins.property # type: ignore
    @jsii.member(jsii_name="id")
    def id(self) -> typing.Optional[builtins.str]:
        return jsii.get(self, "id")

    @id.setter # type: ignore
    def id(self, value: typing.Optional[builtins.str]) -> None:
        jsii.set(self, "id", value)

    @builtins.property # type: ignore
    @jsii.member(jsii_name="internalDnsNameLabel")
    def internal_dns_name_label(self) -> typing.Optional[builtins.str]:
        return jsii.get(self, "internalDnsNameLabel")

    @internal_dns_name_label.setter # type: ignore
    def internal_dns_name_label(self, value: typing.Optional[builtins.str]) -> None:
        jsii.set(self, "internalDnsNameLabel", value)

    @builtins.property # type: ignore
    @jsii.member(jsii_name="tags")
    def tags(self) -> typing.Optional[typing.Mapping[builtins.str, builtins.str]]:
        return jsii.get(self, "tags")

    @tags.setter # type: ignore
    def tags(
        self,
        value: typing.Optional[typing.Mapping[builtins.str, builtins.str]],
    ) -> None:
        jsii.set(self, "tags", value)

    @builtins.property # type: ignore
    @jsii.member(jsii_name="timeouts")
    def timeouts(self) -> typing.Optional["NetworkInterfaceTimeouts"]:
        return jsii.get(self, "timeouts")

    @timeouts.setter # type: ignore
    def timeouts(self, value: typing.Optional["NetworkInterfaceTimeouts"]) -> None:
        jsii.set(self, "timeouts", value)


class NetworkInterfaceApplicationGatewayBackendAddressPoolAssociation(
    cdktf.TerraformResource,
    metaclass=jsii.JSIIMeta,
    jsii_type="@cdktf/provider-azurerm.NetworkInterfaceApplicationGatewayBackendAddressPoolAssociation",
):
    def __init__(
        self,
        scope: constructs.Construct,
        id: builtins.str,
        *,
        backend_address_pool_id: builtins.str,
        ip_configuration_name: builtins.str,
        network_interface_id: builtins.str,
        timeouts: typing.Optional["NetworkInterfaceApplicationGatewayBackendAddressPoolAssociationTimeouts"] = None,
        count: typing.Optional[jsii.Number] = None,
        depends_on: typing.Optional[typing.List[cdktf.TerraformResource]] = None,
        lifecycle: typing.Optional[cdktf.TerraformResourceLifecycle] = None,
        provider: typing.Optional[cdktf.TerraformProvider] = None,
    ) -> None:
        """
        :param scope: -
        :param id: -
        :param backend_address_pool_id: 
        :param ip_configuration_name: 
        :param network_interface_id: 
        :param timeouts: timeouts block.
        :param count: 
        :param depends_on: 
        :param lifecycle: 
        :param provider: 
        """
        config = NetworkInterfaceApplicationGatewayBackendAddressPoolAssociationConfig(
            backend_address_pool_id=backend_address_pool_id,
            ip_configuration_name=ip_configuration_name,
            network_interface_id=network_interface_id,
            timeouts=timeouts,
            count=count,
            depends_on=depends_on,
            lifecycle=lifecycle,
            provider=provider,
        )

        jsii.create(NetworkInterfaceApplicationGatewayBackendAddressPoolAssociation, self, [scope, id, config])

    @jsii.member(jsii_name="synthesizeAttributes")
    def _synthesize_attributes(self) -> typing.Mapping[builtins.str, typing.Any]:
        return jsii.invoke(self, "synthesizeAttributes", [])

    @builtins.property # type: ignore
    @jsii.member(jsii_name="backendAddressPoolId")
    def backend_address_pool_id(self) -> builtins.str:
        return jsii.get(self, "backendAddressPoolId")

    @backend_address_pool_id.setter # type: ignore
    def backend_address_pool_id(self, value: builtins.str) -> None:
        jsii.set(self, "backendAddressPoolId", value)

    @builtins.property # type: ignore
    @jsii.member(jsii_name="ipConfigurationName")
    def ip_configuration_name(self) -> builtins.str:
        return jsii.get(self, "ipConfigurationName")

    @ip_configuration_name.setter # type: ignore
    def ip_configuration_name(self, value: builtins.str) -> None:
        jsii.set(self, "ipConfigurationName", value)

    @builtins.property # type: ignore
    @jsii.member(jsii_name="networkInterfaceId")
    def network_interface_id(self) -> builtins.str:
        return jsii.get(self, "networkInterfaceId")

    @network_interface_id.setter # type: ignore
    def network_interface_id(self, value: builtins.str) -> None:
        jsii.set(self, "networkInterfaceId", value)

    @builtins.property # type: ignore
    @jsii.member(jsii_name="id")
    def id(self) -> typing.Optional[builtins.str]:
        return jsii.get(self, "id")

    @id.setter # type: ignore
    def id(self, value: typing.Optional[builtins.str]) -> None:
        jsii.set(self, "id", value)

    @builtins.property # type: ignore
    @jsii.member(jsii_name="timeouts")
    def timeouts(
        self,
    ) -> typing.Optional["NetworkInterfaceApplicationGatewayBackendAddressPoolAssociationTimeouts"]:
        return jsii.get(self, "timeouts")

    @timeouts.setter # type: ignore
    def timeouts(
        self,
        value: typing.Optional["NetworkInterfaceApplicationGatewayBackendAddressPoolAssociationTimeouts"],
    ) -> None:
        jsii.set(self, "timeouts", value)


@jsii.data_type(
    jsii_type="@cdktf/provider-azurerm.NetworkInterfaceApplicationGatewayBackendAddressPoolAssociationConfig",
    jsii_struct_bases=[cdktf.TerraformMetaArguments],
    name_mapping={
        "count": "count",
        "depends_on": "dependsOn",
        "lifecycle": "lifecycle",
        "provider": "provider",
        "backend_address_pool_id": "backendAddressPoolId",
        "ip_configuration_name": "ipConfigurationName",
        "network_interface_id": "networkInterfaceId",
        "timeouts": "timeouts",
    },
)
class NetworkInterfaceApplicationGatewayBackendAddressPoolAssociationConfig(
    cdktf.TerraformMetaArguments,
):
    def __init__(
        self,
        *,
        count: typing.Optional[jsii.Number] = None,
        depends_on: typing.Optional[typing.List[cdktf.TerraformResource]] = None,
        lifecycle: typing.Optional[cdktf.TerraformResourceLifecycle] = None,
        provider: typing.Optional[cdktf.TerraformProvider] = None,
        backend_address_pool_id: builtins.str,
        ip_configuration_name: builtins.str,
        network_interface_id: builtins.str,
        timeouts: typing.Optional["NetworkInterfaceApplicationGatewayBackendAddressPoolAssociationTimeouts"] = None,
    ) -> None:
        """
        :param count: 
        :param depends_on: 
        :param lifecycle: 
        :param provider: 
        :param backend_address_pool_id: 
        :param ip_configuration_name: 
        :param network_interface_id: 
        :param timeouts: timeouts block.
        """
        if isinstance(lifecycle, dict):
            lifecycle = cdktf.TerraformResourceLifecycle(**lifecycle)
        if isinstance(timeouts, dict):
            timeouts = NetworkInterfaceApplicationGatewayBackendAddressPoolAssociationTimeouts(**timeouts)
        self._values: typing.Dict[str, typing.Any] = {
            "backend_address_pool_id": backend_address_pool_id,
            "ip_configuration_name": ip_configuration_name,
            "network_interface_id": network_interface_id,
        }
        if count is not None:
            self._values["count"] = count
        if depends_on is not None:
            self._values["depends_on"] = depends_on
        if lifecycle is not None:
            self._values["lifecycle"] = lifecycle
        if provider is not None:
            self._values["provider"] = provider
        if timeouts is not None:
            self._values["timeouts"] = timeouts

    @builtins.property
    def count(self) -> typing.Optional[jsii.Number]:
        """
        :stability: experimental
        """
        result = self._values.get("count")
        return result

    @builtins.property
    def depends_on(self) -> typing.Optional[typing.List[cdktf.TerraformResource]]:
        """
        :stability: experimental
        """
        result = self._values.get("depends_on")
        return result

    @builtins.property
    def lifecycle(self) -> typing.Optional[cdktf.TerraformResourceLifecycle]:
        """
        :stability: experimental
        """
        result = self._values.get("lifecycle")
        return result

    @builtins.property
    def provider(self) -> typing.Optional[cdktf.TerraformProvider]:
        """
        :stability: experimental
        """
        result = self._values.get("provider")
        return result

    @builtins.property
    def backend_address_pool_id(self) -> builtins.str:
        result = self._values.get("backend_address_pool_id")
        assert result is not None, "Required property 'backend_address_pool_id' is missing"
        return result

    @builtins.property
    def ip_configuration_name(self) -> builtins.str:
        result = self._values.get("ip_configuration_name")
        assert result is not None, "Required property 'ip_configuration_name' is missing"
        return result

    @builtins.property
    def network_interface_id(self) -> builtins.str:
        result = self._values.get("network_interface_id")
        assert result is not None, "Required property 'network_interface_id' is missing"
        return result

    @builtins.property
    def timeouts(
        self,
    ) -> typing.Optional["NetworkInterfaceApplicationGatewayBackendAddressPoolAssociationTimeouts"]:
        """timeouts block."""
        result = self._values.get("timeouts")
        return result

    def __eq__(self, rhs: typing.Any) -> builtins.bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs: typing.Any) -> builtins.bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return "NetworkInterfaceApplicationGatewayBackendAddressPoolAssociationConfig(%s)" % ", ".join(
            k + "=" + repr(v) for k, v in self._values.items()
        )


@jsii.data_type(
    jsii_type="@cdktf/provider-azurerm.NetworkInterfaceApplicationGatewayBackendAddressPoolAssociationTimeouts",
    jsii_struct_bases=[],
    name_mapping={
        "create": "create",
        "delete": "delete",
        "read": "read",
        "update": "update",
    },
)
class NetworkInterfaceApplicationGatewayBackendAddressPoolAssociationTimeouts:
    def __init__(
        self,
        *,
        create: typing.Optional[builtins.str] = None,
        delete: typing.Optional[builtins.str] = None,
        read: typing.Optional[builtins.str] = None,
        update: typing.Optional[builtins.str] = None,
    ) -> None:
        """
        :param create: 
        :param delete: 
        :param read: 
        :param update: 
        """
        self._values: typing.Dict[str, typing.Any] = {}
        if create is not None:
            self._values["create"] = create
        if delete is not None:
            self._values["delete"] = delete
        if read is not None:
            self._values["read"] = read
        if update is not None:
            self._values["update"] = update

    @builtins.property
    def create(self) -> typing.Optional[builtins.str]:
        result = self._values.get("create")
        return result

    @builtins.property
    def delete(self) -> typing.Optional[builtins.str]:
        result = self._values.get("delete")
        return result

    @builtins.property
    def read(self) -> typing.Optional[builtins.str]:
        result = self._values.get("read")
        return result

    @builtins.property
    def update(self) -> typing.Optional[builtins.str]:
        result = self._values.get("update")
        return result

    def __eq__(self, rhs: typing.Any) -> builtins.bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs: typing.Any) -> builtins.bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return "NetworkInterfaceApplicationGatewayBackendAddressPoolAssociationTimeouts(%s)" % ", ".join(
            k + "=" + repr(v) for k, v in self._values.items()
        )


class NetworkInterfaceApplicationSecurityGroupAssociation(
    cdktf.TerraformResource,
    metaclass=jsii.JSIIMeta,
    jsii_type="@cdktf/provider-azurerm.NetworkInterfaceApplicationSecurityGroupAssociation",
):
    def __init__(
        self,
        scope: constructs.Construct,
        id: builtins.str,
        *,
        application_security_group_id: builtins.str,
        network_interface_id: builtins.str,
        timeouts: typing.Optional["NetworkInterfaceApplicationSecurityGroupAssociationTimeouts"] = None,
        count: typing.Optional[jsii.Number] = None,
        depends_on: typing.Optional[typing.List[cdktf.TerraformResource]] = None,
        lifecycle: typing.Optional[cdktf.TerraformResourceLifecycle] = None,
        provider: typing.Optional[cdktf.TerraformProvider] = None,
    ) -> None:
        """
        :param scope: -
        :param id: -
        :param application_security_group_id: 
        :param network_interface_id: 
        :param timeouts: timeouts block.
        :param count: 
        :param depends_on: 
        :param lifecycle: 
        :param provider: 
        """
        config = NetworkInterfaceApplicationSecurityGroupAssociationConfig(
            application_security_group_id=application_security_group_id,
            network_interface_id=network_interface_id,
            timeouts=timeouts,
            count=count,
            depends_on=depends_on,
            lifecycle=lifecycle,
            provider=provider,
        )

        jsii.create(NetworkInterfaceApplicationSecurityGroupAssociation, self, [scope, id, config])

    @jsii.member(jsii_name="synthesizeAttributes")
    def _synthesize_attributes(self) -> typing.Mapping[builtins.str, typing.Any]:
        return jsii.invoke(self, "synthesizeAttributes", [])

    @builtins.property # type: ignore
    @jsii.member(jsii_name="applicationSecurityGroupId")
    def application_security_group_id(self) -> builtins.str:
        return jsii.get(self, "applicationSecurityGroupId")

    @application_security_group_id.setter # type: ignore
    def application_security_group_id(self, value: builtins.str) -> None:
        jsii.set(self, "applicationSecurityGroupId", value)

    @builtins.property # type: ignore
    @jsii.member(jsii_name="networkInterfaceId")
    def network_interface_id(self) -> builtins.str:
        return jsii.get(self, "networkInterfaceId")

    @network_interface_id.setter # type: ignore
    def network_interface_id(self, value: builtins.str) -> None:
        jsii.set(self, "networkInterfaceId", value)

    @builtins.property # type: ignore
    @jsii.member(jsii_name="id")
    def id(self) -> typing.Optional[builtins.str]:
        return jsii.get(self, "id")

    @id.setter # type: ignore
    def id(self, value: typing.Optional[builtins.str]) -> None:
        jsii.set(self, "id", value)

    @builtins.property # type: ignore
    @jsii.member(jsii_name="timeouts")
    def timeouts(
        self,
    ) -> typing.Optional["NetworkInterfaceApplicationSecurityGroupAssociationTimeouts"]:
        return jsii.get(self, "timeouts")

    @timeouts.setter # type: ignore
    def timeouts(
        self,
        value: typing.Optional["NetworkInterfaceApplicationSecurityGroupAssociationTimeouts"],
    ) -> None:
        jsii.set(self, "timeouts", value)


@jsii.data_type(
    jsii_type="@cdktf/provider-azurerm.NetworkInterfaceApplicationSecurityGroupAssociationConfig",
    jsii_struct_bases=[cdktf.TerraformMetaArguments],
    name_mapping={
        "count": "count",
        "depends_on": "dependsOn",
        "lifecycle": "lifecycle",
        "provider": "provider",
        "application_security_group_id": "applicationSecurityGroupId",
        "network_interface_id": "networkInterfaceId",
        "timeouts": "timeouts",
    },
)
class NetworkInterfaceApplicationSecurityGroupAssociationConfig(
    cdktf.TerraformMetaArguments,
):
    def __init__(
        self,
        *,
        count: typing.Optional[jsii.Number] = None,
        depends_on: typing.Optional[typing.List[cdktf.TerraformResource]] = None,
        lifecycle: typing.Optional[cdktf.TerraformResourceLifecycle] = None,
        provider: typing.Optional[cdktf.TerraformProvider] = None,
        application_security_group_id: builtins.str,
        network_interface_id: builtins.str,
        timeouts: typing.Optional["NetworkInterfaceApplicationSecurityGroupAssociationTimeouts"] = None,
    ) -> None:
        """
        :param count: 
        :param depends_on: 
        :param lifecycle: 
        :param provider: 
        :param application_security_group_id: 
        :param network_interface_id: 
        :param timeouts: timeouts block.
        """
        if isinstance(lifecycle, dict):
            lifecycle = cdktf.TerraformResourceLifecycle(**lifecycle)
        if isinstance(timeouts, dict):
            timeouts = NetworkInterfaceApplicationSecurityGroupAssociationTimeouts(**timeouts)
        self._values: typing.Dict[str, typing.Any] = {
            "application_security_group_id": application_security_group_id,
            "network_interface_id": network_interface_id,
        }
        if count is not None:
            self._values["count"] = count
        if depends_on is not None:
            self._values["depends_on"] = depends_on
        if lifecycle is not None:
            self._values["lifecycle"] = lifecycle
        if provider is not None:
            self._values["provider"] = provider
        if timeouts is not None:
            self._values["timeouts"] = timeouts

    @builtins.property
    def count(self) -> typing.Optional[jsii.Number]:
        """
        :stability: experimental
        """
        result = self._values.get("count")
        return result

    @builtins.property
    def depends_on(self) -> typing.Optional[typing.List[cdktf.TerraformResource]]:
        """
        :stability: experimental
        """
        result = self._values.get("depends_on")
        return result

    @builtins.property
    def lifecycle(self) -> typing.Optional[cdktf.TerraformResourceLifecycle]:
        """
        :stability: experimental
        """
        result = self._values.get("lifecycle")
        return result

    @builtins.property
    def provider(self) -> typing.Optional[cdktf.TerraformProvider]:
        """
        :stability: experimental
        """
        result = self._values.get("provider")
        return result

    @builtins.property
    def application_security_group_id(self) -> builtins.str:
        result = self._values.get("application_security_group_id")
        assert result is not None, "Required property 'application_security_group_id' is missing"
        return result

    @builtins.property
    def network_interface_id(self) -> builtins.str:
        result = self._values.get("network_interface_id")
        assert result is not None, "Required property 'network_interface_id' is missing"
        return result

    @builtins.property
    def timeouts(
        self,
    ) -> typing.Optional["NetworkInterfaceApplicationSecurityGroupAssociationTimeouts"]:
        """timeouts block."""
        result = self._values.get("timeouts")
        return result

    def __eq__(self, rhs: typing.Any) -> builtins.bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs: typing.Any) -> builtins.bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return "NetworkInterfaceApplicationSecurityGroupAssociationConfig(%s)" % ", ".join(
            k + "=" + repr(v) for k, v in self._values.items()
        )


@jsii.data_type(
    jsii_type="@cdktf/provider-azurerm.NetworkInterfaceApplicationSecurityGroupAssociationTimeouts",
    jsii_struct_bases=[],
    name_mapping={
        "create": "create",
        "delete": "delete",
        "read": "read",
        "update": "update",
    },
)
class NetworkInterfaceApplicationSecurityGroupAssociationTimeouts:
    def __init__(
        self,
        *,
        create: typing.Optional[builtins.str] = None,
        delete: typing.Optional[builtins.str] = None,
        read: typing.Optional[builtins.str] = None,
        update: typing.Optional[builtins.str] = None,
    ) -> None:
        """
        :param create: 
        :param delete: 
        :param read: 
        :param update: 
        """
        self._values: typing.Dict[str, typing.Any] = {}
        if create is not None:
            self._values["create"] = create
        if delete is not None:
            self._values["delete"] = delete
        if read is not None:
            self._values["read"] = read
        if update is not None:
            self._values["update"] = update

    @builtins.property
    def create(self) -> typing.Optional[builtins.str]:
        result = self._values.get("create")
        return result

    @builtins.property
    def delete(self) -> typing.Optional[builtins.str]:
        result = self._values.get("delete")
        return result

    @builtins.property
    def read(self) -> typing.Optional[builtins.str]:
        result = self._values.get("read")
        return result

    @builtins.property
    def update(self) -> typing.Optional[builtins.str]:
        result = self._values.get("update")
        return result

    def __eq__(self, rhs: typing.Any) -> builtins.bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs: typing.Any) -> builtins.bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return "NetworkInterfaceApplicationSecurityGroupAssociationTimeouts(%s)" % ", ".join(
            k + "=" + repr(v) for k, v in self._values.items()
        )


class NetworkInterfaceBackendAddressPoolAssociation(
    cdktf.TerraformResource,
    metaclass=jsii.JSIIMeta,
    jsii_type="@cdktf/provider-azurerm.NetworkInterfaceBackendAddressPoolAssociation",
):
    def __init__(
        self,
        scope: constructs.Construct,
        id: builtins.str,
        *,
        backend_address_pool_id: builtins.str,
        ip_configuration_name: builtins.str,
        network_interface_id: builtins.str,
        timeouts: typing.Optional["NetworkInterfaceBackendAddressPoolAssociationTimeouts"] = None,
        count: typing.Optional[jsii.Number] = None,
        depends_on: typing.Optional[typing.List[cdktf.TerraformResource]] = None,
        lifecycle: typing.Optional[cdktf.TerraformResourceLifecycle] = None,
        provider: typing.Optional[cdktf.TerraformProvider] = None,
    ) -> None:
        """
        :param scope: -
        :param id: -
        :param backend_address_pool_id: 
        :param ip_configuration_name: 
        :param network_interface_id: 
        :param timeouts: timeouts block.
        :param count: 
        :param depends_on: 
        :param lifecycle: 
        :param provider: 
        """
        config = NetworkInterfaceBackendAddressPoolAssociationConfig(
            backend_address_pool_id=backend_address_pool_id,
            ip_configuration_name=ip_configuration_name,
            network_interface_id=network_interface_id,
            timeouts=timeouts,
            count=count,
            depends_on=depends_on,
            lifecycle=lifecycle,
            provider=provider,
        )

        jsii.create(NetworkInterfaceBackendAddressPoolAssociation, self, [scope, id, config])

    @jsii.member(jsii_name="synthesizeAttributes")
    def _synthesize_attributes(self) -> typing.Mapping[builtins.str, typing.Any]:
        return jsii.invoke(self, "synthesizeAttributes", [])

    @builtins.property # type: ignore
    @jsii.member(jsii_name="backendAddressPoolId")
    def backend_address_pool_id(self) -> builtins.str:
        return jsii.get(self, "backendAddressPoolId")

    @backend_address_pool_id.setter # type: ignore
    def backend_address_pool_id(self, value: builtins.str) -> None:
        jsii.set(self, "backendAddressPoolId", value)

    @builtins.property # type: ignore
    @jsii.member(jsii_name="ipConfigurationName")
    def ip_configuration_name(self) -> builtins.str:
        return jsii.get(self, "ipConfigurationName")

    @ip_configuration_name.setter # type: ignore
    def ip_configuration_name(self, value: builtins.str) -> None:
        jsii.set(self, "ipConfigurationName", value)

    @builtins.property # type: ignore
    @jsii.member(jsii_name="networkInterfaceId")
    def network_interface_id(self) -> builtins.str:
        return jsii.get(self, "networkInterfaceId")

    @network_interface_id.setter # type: ignore
    def network_interface_id(self, value: builtins.str) -> None:
        jsii.set(self, "networkInterfaceId", value)

    @builtins.property # type: ignore
    @jsii.member(jsii_name="id")
    def id(self) -> typing.Optional[builtins.str]:
        return jsii.get(self, "id")

    @id.setter # type: ignore
    def id(self, value: typing.Optional[builtins.str]) -> None:
        jsii.set(self, "id", value)

    @builtins.property # type: ignore
    @jsii.member(jsii_name="timeouts")
    def timeouts(
        self,
    ) -> typing.Optional["NetworkInterfaceBackendAddressPoolAssociationTimeouts"]:
        return jsii.get(self, "timeouts")

    @timeouts.setter # type: ignore
    def timeouts(
        self,
        value: typing.Optional["NetworkInterfaceBackendAddressPoolAssociationTimeouts"],
    ) -> None:
        jsii.set(self, "timeouts", value)


@jsii.data_type(
    jsii_type="@cdktf/provider-azurerm.NetworkInterfaceBackendAddressPoolAssociationConfig",
    jsii_struct_bases=[cdktf.TerraformMetaArguments],
    name_mapping={
        "count": "count",
        "depends_on": "dependsOn",
        "lifecycle": "lifecycle",
        "provider": "provider",
        "backend_address_pool_id": "backendAddressPoolId",
        "ip_configuration_name": "ipConfigurationName",
        "network_interface_id": "networkInterfaceId",
        "timeouts": "timeouts",
    },
)
class NetworkInterfaceBackendAddressPoolAssociationConfig(cdktf.TerraformMetaArguments):
    def __init__(
        self,
        *,
        count: typing.Optional[jsii.Number] = None,
        depends_on: typing.Optional[typing.List[cdktf.TerraformResource]] = None,
        lifecycle: typing.Optional[cdktf.TerraformResourceLifecycle] = None,
        provider: typing.Optional[cdktf.TerraformProvider] = None,
        backend_address_pool_id: builtins.str,
        ip_configuration_name: builtins.str,
        network_interface_id: builtins.str,
        timeouts: typing.Optional["NetworkInterfaceBackendAddressPoolAssociationTimeouts"] = None,
    ) -> None:
        """
        :param count: 
        :param depends_on: 
        :param lifecycle: 
        :param provider: 
        :param backend_address_pool_id: 
        :param ip_configuration_name: 
        :param network_interface_id: 
        :param timeouts: timeouts block.
        """
        if isinstance(lifecycle, dict):
            lifecycle = cdktf.TerraformResourceLifecycle(**lifecycle)
        if isinstance(timeouts, dict):
            timeouts = NetworkInterfaceBackendAddressPoolAssociationTimeouts(**timeouts)
        self._values: typing.Dict[str, typing.Any] = {
            "backend_address_pool_id": backend_address_pool_id,
            "ip_configuration_name": ip_configuration_name,
            "network_interface_id": network_interface_id,
        }
        if count is not None:
            self._values["count"] = count
        if depends_on is not None:
            self._values["depends_on"] = depends_on
        if lifecycle is not None:
            self._values["lifecycle"] = lifecycle
        if provider is not None:
            self._values["provider"] = provider
        if timeouts is not None:
            self._values["timeouts"] = timeouts

    @builtins.property
    def count(self) -> typing.Optional[jsii.Number]:
        """
        :stability: experimental
        """
        result = self._values.get("count")
        return result

    @builtins.property
    def depends_on(self) -> typing.Optional[typing.List[cdktf.TerraformResource]]:
        """
        :stability: experimental
        """
        result = self._values.get("depends_on")
        return result

    @builtins.property
    def lifecycle(self) -> typing.Optional[cdktf.TerraformResourceLifecycle]:
        """
        :stability: experimental
        """
        result = self._values.get("lifecycle")
        return result

    @builtins.property
    def provider(self) -> typing.Optional[cdktf.TerraformProvider]:
        """
        :stability: experimental
        """
        result = self._values.get("provider")
        return result

    @builtins.property
    def backend_address_pool_id(self) -> builtins.str:
        result = self._values.get("backend_address_pool_id")
        assert result is not None, "Required property 'backend_address_pool_id' is missing"
        return result

    @builtins.property
    def ip_configuration_name(self) -> builtins.str:
        result = self._values.get("ip_configuration_name")
        assert result is not None, "Required property 'ip_configuration_name' is missing"
        return result

    @builtins.property
    def network_interface_id(self) -> builtins.str:
        result = self._values.get("network_interface_id")
        assert result is not None, "Required property 'network_interface_id' is missing"
        return result

    @builtins.property
    def timeouts(
        self,
    ) -> typing.Optional["NetworkInterfaceBackendAddressPoolAssociationTimeouts"]:
        """timeouts block."""
        result = self._values.get("timeouts")
        return result

    def __eq__(self, rhs: typing.Any) -> builtins.bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs: typing.Any) -> builtins.bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return "NetworkInterfaceBackendAddressPoolAssociationConfig(%s)" % ", ".join(
            k + "=" + repr(v) for k, v in self._values.items()
        )


@jsii.data_type(
    jsii_type="@cdktf/provider-azurerm.NetworkInterfaceBackendAddressPoolAssociationTimeouts",
    jsii_struct_bases=[],
    name_mapping={
        "create": "create",
        "delete": "delete",
        "read": "read",
        "update": "update",
    },
)
class NetworkInterfaceBackendAddressPoolAssociationTimeouts:
    def __init__(
        self,
        *,
        create: typing.Optional[builtins.str] = None,
        delete: typing.Optional[builtins.str] = None,
        read: typing.Optional[builtins.str] = None,
        update: typing.Optional[builtins.str] = None,
    ) -> None:
        """
        :param create: 
        :param delete: 
        :param read: 
        :param update: 
        """
        self._values: typing.Dict[str, typing.Any] = {}
        if create is not None:
            self._values["create"] = create
        if delete is not None:
            self._values["delete"] = delete
        if read is not None:
            self._values["read"] = read
        if update is not None:
            self._values["update"] = update

    @builtins.property
    def create(self) -> typing.Optional[builtins.str]:
        result = self._values.get("create")
        return result

    @builtins.property
    def delete(self) -> typing.Optional[builtins.str]:
        result = self._values.get("delete")
        return result

    @builtins.property
    def read(self) -> typing.Optional[builtins.str]:
        result = self._values.get("read")
        return result

    @builtins.property
    def update(self) -> typing.Optional[builtins.str]:
        result = self._values.get("update")
        return result

    def __eq__(self, rhs: typing.Any) -> builtins.bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs: typing.Any) -> builtins.bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return "NetworkInterfaceBackendAddressPoolAssociationTimeouts(%s)" % ", ".join(
            k + "=" + repr(v) for k, v in self._values.items()
        )


@jsii.data_type(
    jsii_type="@cdktf/provider-azurerm.NetworkInterfaceConfig",
    jsii_struct_bases=[cdktf.TerraformMetaArguments],
    name_mapping={
        "count": "count",
        "depends_on": "dependsOn",
        "lifecycle": "lifecycle",
        "provider": "provider",
        "ip_configuration": "ipConfiguration",
        "location": "location",
        "name": "name",
        "resource_group_name": "resourceGroupName",
        "dns_servers": "dnsServers",
        "enable_accelerated_networking": "enableAcceleratedNetworking",
        "enable_ip_forwarding": "enableIpForwarding",
        "internal_dns_name_label": "internalDnsNameLabel",
        "tags": "tags",
        "timeouts": "timeouts",
    },
)
class NetworkInterfaceConfig(cdktf.TerraformMetaArguments):
    def __init__(
        self,
        *,
        count: typing.Optional[jsii.Number] = None,
        depends_on: typing.Optional[typing.List[cdktf.TerraformResource]] = None,
        lifecycle: typing.Optional[cdktf.TerraformResourceLifecycle] = None,
        provider: typing.Optional[cdktf.TerraformProvider] = None,
        ip_configuration: typing.List["NetworkInterfaceIpConfiguration"],
        location: builtins.str,
        name: builtins.str,
        resource_group_name: builtins.str,
        dns_servers: typing.Optional[typing.List[builtins.str]] = None,
        enable_accelerated_networking: typing.Optional[builtins.bool] = None,
        enable_ip_forwarding: typing.Optional[builtins.bool] = None,
        internal_dns_name_label: typing.Optional[builtins.str] = None,
        tags: typing.Optional[typing.Mapping[builtins.str, builtins.str]] = None,
        timeouts: typing.Optional["NetworkInterfaceTimeouts"] = None,
    ) -> None:
        """
        :param count: 
        :param depends_on: 
        :param lifecycle: 
        :param provider: 
        :param ip_configuration: ip_configuration block.
        :param location: 
        :param name: 
        :param resource_group_name: 
        :param dns_servers: 
        :param enable_accelerated_networking: 
        :param enable_ip_forwarding: 
        :param internal_dns_name_label: 
        :param tags: 
        :param timeouts: timeouts block.
        """
        if isinstance(lifecycle, dict):
            lifecycle = cdktf.TerraformResourceLifecycle(**lifecycle)
        if isinstance(timeouts, dict):
            timeouts = NetworkInterfaceTimeouts(**timeouts)
        self._values: typing.Dict[str, typing.Any] = {
            "ip_configuration": ip_configuration,
            "location": location,
            "name": name,
            "resource_group_name": resource_group_name,
        }
        if count is not None:
            self._values["count"] = count
        if depends_on is not None:
            self._values["depends_on"] = depends_on
        if lifecycle is not None:
            self._values["lifecycle"] = lifecycle
        if provider is not None:
            self._values["provider"] = provider
        if dns_servers is not None:
            self._values["dns_servers"] = dns_servers
        if enable_accelerated_networking is not None:
            self._values["enable_accelerated_networking"] = enable_accelerated_networking
        if enable_ip_forwarding is not None:
            self._values["enable_ip_forwarding"] = enable_ip_forwarding
        if internal_dns_name_label is not None:
            self._values["internal_dns_name_label"] = internal_dns_name_label
        if tags is not None:
            self._values["tags"] = tags
        if timeouts is not None:
            self._values["timeouts"] = timeouts

    @builtins.property
    def count(self) -> typing.Optional[jsii.Number]:
        """
        :stability: experimental
        """
        result = self._values.get("count")
        return result

    @builtins.property
    def depends_on(self) -> typing.Optional[typing.List[cdktf.TerraformResource]]:
        """
        :stability: experimental
        """
        result = self._values.get("depends_on")
        return result

    @builtins.property
    def lifecycle(self) -> typing.Optional[cdktf.TerraformResourceLifecycle]:
        """
        :stability: experimental
        """
        result = self._values.get("lifecycle")
        return result

    @builtins.property
    def provider(self) -> typing.Optional[cdktf.TerraformProvider]:
        """
        :stability: experimental
        """
        result = self._values.get("provider")
        return result

    @builtins.property
    def ip_configuration(self) -> typing.List["NetworkInterfaceIpConfiguration"]:
        """ip_configuration block."""
        result = self._values.get("ip_configuration")
        assert result is not None, "Required property 'ip_configuration' is missing"
        return result

    @builtins.property
    def location(self) -> builtins.str:
        result = self._values.get("location")
        assert result is not None, "Required property 'location' is missing"
        return result

    @builtins.property
    def name(self) -> builtins.str:
        result = self._values.get("name")
        assert result is not None, "Required property 'name' is missing"
        return result

    @builtins.property
    def resource_group_name(self) -> builtins.str:
        result = self._values.get("resource_group_name")
        assert result is not None, "Required property 'resource_group_name' is missing"
        return result

    @builtins.property
    def dns_servers(self) -> typing.Optional[typing.List[builtins.str]]:
        result = self._values.get("dns_servers")
        return result

    @builtins.property
    def enable_accelerated_networking(self) -> typing.Optional[builtins.bool]:
        result = self._values.get("enable_accelerated_networking")
        return result

    @builtins.property
    def enable_ip_forwarding(self) -> typing.Optional[builtins.bool]:
        result = self._values.get("enable_ip_forwarding")
        return result

    @builtins.property
    def internal_dns_name_label(self) -> typing.Optional[builtins.str]:
        result = self._values.get("internal_dns_name_label")
        return result

    @builtins.property
    def tags(self) -> typing.Optional[typing.Mapping[builtins.str, builtins.str]]:
        result = self._values.get("tags")
        return result

    @builtins.property
    def timeouts(self) -> typing.Optional["NetworkInterfaceTimeouts"]:
        """timeouts block."""
        result = self._values.get("timeouts")
        return result

    def __eq__(self, rhs: typing.Any) -> builtins.bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs: typing.Any) -> builtins.bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return "NetworkInterfaceConfig(%s)" % ", ".join(
            k + "=" + repr(v) for k, v in self._values.items()
        )


@jsii.data_type(
    jsii_type="@cdktf/provider-azurerm.NetworkInterfaceIpConfiguration",
    jsii_struct_bases=[],
    name_mapping={
        "name": "name",
        "private_ip_address_allocation": "privateIpAddressAllocation",
        "primary": "primary",
        "private_ip_address": "privateIpAddress",
        "private_ip_address_version": "privateIpAddressVersion",
        "public_ip_address_id": "publicIpAddressId",
        "subnet_id": "subnetId",
    },
)
class NetworkInterfaceIpConfiguration:
    def __init__(
        self,
        *,
        name: builtins.str,
        private_ip_address_allocation: builtins.str,
        primary: typing.Optional[builtins.bool] = None,
        private_ip_address: typing.Optional[builtins.str] = None,
        private_ip_address_version: typing.Optional[builtins.str] = None,
        public_ip_address_id: typing.Optional[builtins.str] = None,
        subnet_id: typing.Optional[builtins.str] = None,
    ) -> None:
        """
        :param name: 
        :param private_ip_address_allocation: 
        :param primary: 
        :param private_ip_address: 
        :param private_ip_address_version: 
        :param public_ip_address_id: 
        :param subnet_id: 
        """
        self._values: typing.Dict[str, typing.Any] = {
            "name": name,
            "private_ip_address_allocation": private_ip_address_allocation,
        }
        if primary is not None:
            self._values["primary"] = primary
        if private_ip_address is not None:
            self._values["private_ip_address"] = private_ip_address
        if private_ip_address_version is not None:
            self._values["private_ip_address_version"] = private_ip_address_version
        if public_ip_address_id is not None:
            self._values["public_ip_address_id"] = public_ip_address_id
        if subnet_id is not None:
            self._values["subnet_id"] = subnet_id

    @builtins.property
    def name(self) -> builtins.str:
        result = self._values.get("name")
        assert result is not None, "Required property 'name' is missing"
        return result

    @builtins.property
    def private_ip_address_allocation(self) -> builtins.str:
        result = self._values.get("private_ip_address_allocation")
        assert result is not None, "Required property 'private_ip_address_allocation' is missing"
        return result

    @builtins.property
    def primary(self) -> typing.Optional[builtins.bool]:
        result = self._values.get("primary")
        return result

    @builtins.property
    def private_ip_address(self) -> typing.Optional[builtins.str]:
        result = self._values.get("private_ip_address")
        return result

    @builtins.property
    def private_ip_address_version(self) -> typing.Optional[builtins.str]:
        result = self._values.get("private_ip_address_version")
        return result

    @builtins.property
    def public_ip_address_id(self) -> typing.Optional[builtins.str]:
        result = self._values.get("public_ip_address_id")
        return result

    @builtins.property
    def subnet_id(self) -> typing.Optional[builtins.str]:
        result = self._values.get("subnet_id")
        return result

    def __eq__(self, rhs: typing.Any) -> builtins.bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs: typing.Any) -> builtins.bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return "NetworkInterfaceIpConfiguration(%s)" % ", ".join(
            k + "=" + repr(v) for k, v in self._values.items()
        )


class NetworkInterfaceNatRuleAssociation(
    cdktf.TerraformResource,
    metaclass=jsii.JSIIMeta,
    jsii_type="@cdktf/provider-azurerm.NetworkInterfaceNatRuleAssociation",
):
    def __init__(
        self,
        scope: constructs.Construct,
        id: builtins.str,
        *,
        ip_configuration_name: builtins.str,
        nat_rule_id: builtins.str,
        network_interface_id: builtins.str,
        timeouts: typing.Optional["NetworkInterfaceNatRuleAssociationTimeouts"] = None,
        count: typing.Optional[jsii.Number] = None,
        depends_on: typing.Optional[typing.List[cdktf.TerraformResource]] = None,
        lifecycle: typing.Optional[cdktf.TerraformResourceLifecycle] = None,
        provider: typing.Optional[cdktf.TerraformProvider] = None,
    ) -> None:
        """
        :param scope: -
        :param id: -
        :param ip_configuration_name: 
        :param nat_rule_id: 
        :param network_interface_id: 
        :param timeouts: timeouts block.
        :param count: 
        :param depends_on: 
        :param lifecycle: 
        :param provider: 
        """
        config = NetworkInterfaceNatRuleAssociationConfig(
            ip_configuration_name=ip_configuration_name,
            nat_rule_id=nat_rule_id,
            network_interface_id=network_interface_id,
            timeouts=timeouts,
            count=count,
            depends_on=depends_on,
            lifecycle=lifecycle,
            provider=provider,
        )

        jsii.create(NetworkInterfaceNatRuleAssociation, self, [scope, id, config])

    @jsii.member(jsii_name="synthesizeAttributes")
    def _synthesize_attributes(self) -> typing.Mapping[builtins.str, typing.Any]:
        return jsii.invoke(self, "synthesizeAttributes", [])

    @builtins.property # type: ignore
    @jsii.member(jsii_name="ipConfigurationName")
    def ip_configuration_name(self) -> builtins.str:
        return jsii.get(self, "ipConfigurationName")

    @ip_configuration_name.setter # type: ignore
    def ip_configuration_name(self, value: builtins.str) -> None:
        jsii.set(self, "ipConfigurationName", value)

    @builtins.property # type: ignore
    @jsii.member(jsii_name="natRuleId")
    def nat_rule_id(self) -> builtins.str:
        return jsii.get(self, "natRuleId")

    @nat_rule_id.setter # type: ignore
    def nat_rule_id(self, value: builtins.str) -> None:
        jsii.set(self, "natRuleId", value)

    @builtins.property # type: ignore
    @jsii.member(jsii_name="networkInterfaceId")
    def network_interface_id(self) -> builtins.str:
        return jsii.get(self, "networkInterfaceId")

    @network_interface_id.setter # type: ignore
    def network_interface_id(self, value: builtins.str) -> None:
        jsii.set(self, "networkInterfaceId", value)

    @builtins.property # type: ignore
    @jsii.member(jsii_name="id")
    def id(self) -> typing.Optional[builtins.str]:
        return jsii.get(self, "id")

    @id.setter # type: ignore
    def id(self, value: typing.Optional[builtins.str]) -> None:
        jsii.set(self, "id", value)

    @builtins.property # type: ignore
    @jsii.member(jsii_name="timeouts")
    def timeouts(self) -> typing.Optional["NetworkInterfaceNatRuleAssociationTimeouts"]:
        return jsii.get(self, "timeouts")

    @timeouts.setter # type: ignore
    def timeouts(
        self,
        value: typing.Optional["NetworkInterfaceNatRuleAssociationTimeouts"],
    ) -> None:
        jsii.set(self, "timeouts", value)


@jsii.data_type(
    jsii_type="@cdktf/provider-azurerm.NetworkInterfaceNatRuleAssociationConfig",
    jsii_struct_bases=[cdktf.TerraformMetaArguments],
    name_mapping={
        "count": "count",
        "depends_on": "dependsOn",
        "lifecycle": "lifecycle",
        "provider": "provider",
        "ip_configuration_name": "ipConfigurationName",
        "nat_rule_id": "natRuleId",
        "network_interface_id": "networkInterfaceId",
        "timeouts": "timeouts",
    },
)
class NetworkInterfaceNatRuleAssociationConfig(cdktf.TerraformMetaArguments):
    def __init__(
        self,
        *,
        count: typing.Optional[jsii.Number] = None,
        depends_on: typing.Optional[typing.List[cdktf.TerraformResource]] = None,
        lifecycle: typing.Optional[cdktf.TerraformResourceLifecycle] = None,
        provider: typing.Optional[cdktf.TerraformProvider] = None,
        ip_configuration_name: builtins.str,
        nat_rule_id: builtins.str,
        network_interface_id: builtins.str,
        timeouts: typing.Optional["NetworkInterfaceNatRuleAssociationTimeouts"] = None,
    ) -> None:
        """
        :param count: 
        :param depends_on: 
        :param lifecycle: 
        :param provider: 
        :param ip_configuration_name: 
        :param nat_rule_id: 
        :param network_interface_id: 
        :param timeouts: timeouts block.
        """
        if isinstance(lifecycle, dict):
            lifecycle = cdktf.TerraformResourceLifecycle(**lifecycle)
        if isinstance(timeouts, dict):
            timeouts = NetworkInterfaceNatRuleAssociationTimeouts(**timeouts)
        self._values: typing.Dict[str, typing.Any] = {
            "ip_configuration_name": ip_configuration_name,
            "nat_rule_id": nat_rule_id,
            "network_interface_id": network_interface_id,
        }
        if count is not None:
            self._values["count"] = count
        if depends_on is not None:
            self._values["depends_on"] = depends_on
        if lifecycle is not None:
            self._values["lifecycle"] = lifecycle
        if provider is not None:
            self._values["provider"] = provider
        if timeouts is not None:
            self._values["timeouts"] = timeouts

    @builtins.property
    def count(self) -> typing.Optional[jsii.Number]:
        """
        :stability: experimental
        """
        result = self._values.get("count")
        return result

    @builtins.property
    def depends_on(self) -> typing.Optional[typing.List[cdktf.TerraformResource]]:
        """
        :stability: experimental
        """
        result = self._values.get("depends_on")
        return result

    @builtins.property
    def lifecycle(self) -> typing.Optional[cdktf.TerraformResourceLifecycle]:
        """
        :stability: experimental
        """
        result = self._values.get("lifecycle")
        return result

    @builtins.property
    def provider(self) -> typing.Optional[cdktf.TerraformProvider]:
        """
        :stability: experimental
        """
        result = self._values.get("provider")
        return result

    @builtins.property
    def ip_configuration_name(self) -> builtins.str:
        result = self._values.get("ip_configuration_name")
        assert result is not None, "Required property 'ip_configuration_name' is missing"
        return result

    @builtins.property
    def nat_rule_id(self) -> builtins.str:
        result = self._values.get("nat_rule_id")
        assert result is not None, "Required property 'nat_rule_id' is missing"
        return result

    @builtins.property
    def network_interface_id(self) -> builtins.str:
        result = self._values.get("network_interface_id")
        assert result is not None, "Required property 'network_interface_id' is missing"
        return result

    @builtins.property
    def timeouts(self) -> typing.Optional["NetworkInterfaceNatRuleAssociationTimeouts"]:
        """timeouts block."""
        result = self._values.get("timeouts")
        return result

    def __eq__(self, rhs: typing.Any) -> builtins.bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs: typing.Any) -> builtins.bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return "NetworkInterfaceNatRuleAssociationConfig(%s)" % ", ".join(
            k + "=" + repr(v) for k, v in self._values.items()
        )


@jsii.data_type(
    jsii_type="@cdktf/provider-azurerm.NetworkInterfaceNatRuleAssociationTimeouts",
    jsii_struct_bases=[],
    name_mapping={
        "create": "create",
        "delete": "delete",
        "read": "read",
        "update": "update",
    },
)
class NetworkInterfaceNatRuleAssociationTimeouts:
    def __init__(
        self,
        *,
        create: typing.Optional[builtins.str] = None,
        delete: typing.Optional[builtins.str] = None,
        read: typing.Optional[builtins.str] = None,
        update: typing.Optional[builtins.str] = None,
    ) -> None:
        """
        :param create: 
        :param delete: 
        :param read: 
        :param update: 
        """
        self._values: typing.Dict[str, typing.Any] = {}
        if create is not None:
            self._values["create"] = create
        if delete is not None:
            self._values["delete"] = delete
        if read is not None:
            self._values["read"] = read
        if update is not None:
            self._values["update"] = update

    @builtins.property
    def create(self) -> typing.Optional[builtins.str]:
        result = self._values.get("create")
        return result

    @builtins.property
    def delete(self) -> typing.Optional[builtins.str]:
        result = self._values.get("delete")
        return result

    @builtins.property
    def read(self) -> typing.Optional[builtins.str]:
        result = self._values.get("read")
        return result

    @builtins.property
    def update(self) -> typing.Optional[builtins.str]:
        result = self._values.get("update")
        return result

    def __eq__(self, rhs: typing.Any) -> builtins.bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs: typing.Any) -> builtins.bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return "NetworkInterfaceNatRuleAssociationTimeouts(%s)" % ", ".join(
            k + "=" + repr(v) for k, v in self._values.items()
        )


class NetworkInterfaceSecurityGroupAssociation(
    cdktf.TerraformResource,
    metaclass=jsii.JSIIMeta,
    jsii_type="@cdktf/provider-azurerm.NetworkInterfaceSecurityGroupAssociation",
):
    def __init__(
        self,
        scope: constructs.Construct,
        id: builtins.str,
        *,
        network_interface_id: builtins.str,
        network_security_group_id: builtins.str,
        timeouts: typing.Optional["NetworkInterfaceSecurityGroupAssociationTimeouts"] = None,
        count: typing.Optional[jsii.Number] = None,
        depends_on: typing.Optional[typing.List[cdktf.TerraformResource]] = None,
        lifecycle: typing.Optional[cdktf.TerraformResourceLifecycle] = None,
        provider: typing.Optional[cdktf.TerraformProvider] = None,
    ) -> None:
        """
        :param scope: -
        :param id: -
        :param network_interface_id: 
        :param network_security_group_id: 
        :param timeouts: timeouts block.
        :param count: 
        :param depends_on: 
        :param lifecycle: 
        :param provider: 
        """
        config = NetworkInterfaceSecurityGroupAssociationConfig(
            network_interface_id=network_interface_id,
            network_security_group_id=network_security_group_id,
            timeouts=timeouts,
            count=count,
            depends_on=depends_on,
            lifecycle=lifecycle,
            provider=provider,
        )

        jsii.create(NetworkInterfaceSecurityGroupAssociation, self, [scope, id, config])

    @jsii.member(jsii_name="synthesizeAttributes")
    def _synthesize_attributes(self) -> typing.Mapping[builtins.str, typing.Any]:
        return jsii.invoke(self, "synthesizeAttributes", [])

    @builtins.property # type: ignore
    @jsii.member(jsii_name="networkInterfaceId")
    def network_interface_id(self) -> builtins.str:
        return jsii.get(self, "networkInterfaceId")

    @network_interface_id.setter # type: ignore
    def network_interface_id(self, value: builtins.str) -> None:
        jsii.set(self, "networkInterfaceId", value)

    @builtins.property # type: ignore
    @jsii.member(jsii_name="networkSecurityGroupId")
    def network_security_group_id(self) -> builtins.str:
        return jsii.get(self, "networkSecurityGroupId")

    @network_security_group_id.setter # type: ignore
    def network_security_group_id(self, value: builtins.str) -> None:
        jsii.set(self, "networkSecurityGroupId", value)

    @builtins.property # type: ignore
    @jsii.member(jsii_name="id")
    def id(self) -> typing.Optional[builtins.str]:
        return jsii.get(self, "id")

    @id.setter # type: ignore
    def id(self, value: typing.Optional[builtins.str]) -> None:
        jsii.set(self, "id", value)

    @builtins.property # type: ignore
    @jsii.member(jsii_name="timeouts")
    def timeouts(
        self,
    ) -> typing.Optional["NetworkInterfaceSecurityGroupAssociationTimeouts"]:
        return jsii.get(self, "timeouts")

    @timeouts.setter # type: ignore
    def timeouts(
        self,
        value: typing.Optional["NetworkInterfaceSecurityGroupAssociationTimeouts"],
    ) -> None:
        jsii.set(self, "timeouts", value)


@jsii.data_type(
    jsii_type="@cdktf/provider-azurerm.NetworkInterfaceSecurityGroupAssociationConfig",
    jsii_struct_bases=[cdktf.TerraformMetaArguments],
    name_mapping={
        "count": "count",
        "depends_on": "dependsOn",
        "lifecycle": "lifecycle",
        "provider": "provider",
        "network_interface_id": "networkInterfaceId",
        "network_security_group_id": "networkSecurityGroupId",
        "timeouts": "timeouts",
    },
)
class NetworkInterfaceSecurityGroupAssociationConfig(cdktf.TerraformMetaArguments):
    def __init__(
        self,
        *,
        count: typing.Optional[jsii.Number] = None,
        depends_on: typing.Optional[typing.List[cdktf.TerraformResource]] = None,
        lifecycle: typing.Optional[cdktf.TerraformResourceLifecycle] = None,
        provider: typing.Optional[cdktf.TerraformProvider] = None,
        network_interface_id: builtins.str,
        network_security_group_id: builtins.str,
        timeouts: typing.Optional["NetworkInterfaceSecurityGroupAssociationTimeouts"] = None,
    ) -> None:
        """
        :param count: 
        :param depends_on: 
        :param lifecycle: 
        :param provider: 
        :param network_interface_id: 
        :param network_security_group_id: 
        :param timeouts: timeouts block.
        """
        if isinstance(lifecycle, dict):
            lifecycle = cdktf.TerraformResourceLifecycle(**lifecycle)
        if isinstance(timeouts, dict):
            timeouts = NetworkInterfaceSecurityGroupAssociationTimeouts(**timeouts)
        self._values: typing.Dict[str, typing.Any] = {
            "network_interface_id": network_interface_id,
            "network_security_group_id": network_security_group_id,
        }
        if count is not None:
            self._values["count"] = count
        if depends_on is not None:
            self._values["depends_on"] = depends_on
        if lifecycle is not None:
            self._values["lifecycle"] = lifecycle
        if provider is not None:
            self._values["provider"] = provider
        if timeouts is not None:
            self._values["timeouts"] = timeouts

    @builtins.property
    def count(self) -> typing.Optional[jsii.Number]:
        """
        :stability: experimental
        """
        result = self._values.get("count")
        return result

    @builtins.property
    def depends_on(self) -> typing.Optional[typing.List[cdktf.TerraformResource]]:
        """
        :stability: experimental
        """
        result = self._values.get("depends_on")
        return result

    @builtins.property
    def lifecycle(self) -> typing.Optional[cdktf.TerraformResourceLifecycle]:
        """
        :stability: experimental
        """
        result = self._values.get("lifecycle")
        return result

    @builtins.property
    def provider(self) -> typing.Optional[cdktf.TerraformProvider]:
        """
        :stability: experimental
        """
        result = self._values.get("provider")
        return result

    @builtins.property
    def network_interface_id(self) -> builtins.str:
        result = self._values.get("network_interface_id")
        assert result is not None, "Required property 'network_interface_id' is missing"
        return result

    @builtins.property
    def network_security_group_id(self) -> builtins.str:
        result = self._values.get("network_security_group_id")
        assert result is not None, "Required property 'network_security_group_id' is missing"
        return result

    @builtins.property
    def timeouts(
        self,
    ) -> typing.Optional["NetworkInterfaceSecurityGroupAssociationTimeouts"]:
        """timeouts block."""
        result = self._values.get("timeouts")
        return result

    def __eq__(self, rhs: typing.Any) -> builtins.bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs: typing.Any) -> builtins.bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return "NetworkInterfaceSecurityGroupAssociationConfig(%s)" % ", ".join(
            k + "=" + repr(v) for k, v in self._values.items()
        )


@jsii.data_type(
    jsii_type="@cdktf/provider-azurerm.NetworkInterfaceSecurityGroupAssociationTimeouts",
    jsii_struct_bases=[],
    name_mapping={
        "create": "create",
        "delete": "delete",
        "read": "read",
        "update": "update",
    },
)
class NetworkInterfaceSecurityGroupAssociationTimeouts:
    def __init__(
        self,
        *,
        create: typing.Optional[builtins.str] = None,
        delete: typing.Optional[builtins.str] = None,
        read: typing.Optional[builtins.str] = None,
        update: typing.Optional[builtins.str] = None,
    ) -> None:
        """
        :param create: 
        :param delete: 
        :param read: 
        :param update: 
        """
        self._values: typing.Dict[str, typing.Any] = {}
        if create is not None:
            self._values["create"] = create
        if delete is not None:
            self._values["delete"] = delete
        if read is not None:
            self._values["read"] = read
        if update is not None:
            self._values["update"] = update

    @builtins.property
    def create(self) -> typing.Optional[builtins.str]:
        result = self._values.get("create")
        return result

    @builtins.property
    def delete(self) -> typing.Optional[builtins.str]:
        result = self._values.get("delete")
        return result

    @builtins.property
    def read(self) -> typing.Optional[builtins.str]:
        result = self._values.get("read")
        return result

    @builtins.property
    def update(self) -> typing.Optional[builtins.str]:
        result = self._values.get("update")
        return result

    def __eq__(self, rhs: typing.Any) -> builtins.bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs: typing.Any) -> builtins.bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return "NetworkInterfaceSecurityGroupAssociationTimeouts(%s)" % ", ".join(
            k + "=" + repr(v) for k, v in self._values.items()
        )


@jsii.data_type(
    jsii_type="@cdktf/provider-azurerm.NetworkInterfaceTimeouts",
    jsii_struct_bases=[],
    name_mapping={
        "create": "create",
        "delete": "delete",
        "read": "read",
        "update": "update",
    },
)
class NetworkInterfaceTimeouts:
    def __init__(
        self,
        *,
        create: typing.Optional[builtins.str] = None,
        delete: typing.Optional[builtins.str] = None,
        read: typing.Optional[builtins.str] = None,
        update: typing.Optional[builtins.str] = None,
    ) -> None:
        """
        :param create: 
        :param delete: 
        :param read: 
        :param update: 
        """
        self._values: typing.Dict[str, typing.Any] = {}
        if create is not None:
            self._values["create"] = create
        if delete is not None:
            self._values["delete"] = delete
        if read is not None:
            self._values["read"] = read
        if update is not None:
            self._values["update"] = update

    @builtins.property
    def create(self) -> typing.Optional[builtins.str]:
        result = self._values.get("create")
        return result

    @builtins.property
    def delete(self) -> typing.Optional[builtins.str]:
        result = self._values.get("delete")
        return result

    @builtins.property
    def read(self) -> typing.Optional[builtins.str]:
        result = self._values.get("read")
        return result

    @builtins.property
    def update(self) -> typing.Optional[builtins.str]:
        result = self._values.get("update")
        return result

    def __eq__(self, rhs: typing.Any) -> builtins.bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs: typing.Any) -> builtins.bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return "NetworkInterfaceTimeouts(%s)" % ", ".join(
            k + "=" + repr(v) for k, v in self._values.items()
        )


class NetworkPacketCapture(
    cdktf.TerraformResource,
    metaclass=jsii.JSIIMeta,
    jsii_type="@cdktf/provider-azurerm.NetworkPacketCapture",
):
    def __init__(
        self,
        scope: constructs.Construct,
        id: builtins.str,
        *,
        name: builtins.str,
        network_watcher_name: builtins.str,
        resource_group_name: builtins.str,
        storage_location: typing.List["NetworkPacketCaptureStorageLocation"],
        target_resource_id: builtins.str,
        filter: typing.Optional[typing.List["NetworkPacketCaptureFilter"]] = None,
        maximum_bytes_per_packet: typing.Optional[jsii.Number] = None,
        maximum_bytes_per_session: typing.Optional[jsii.Number] = None,
        maximum_capture_duration: typing.Optional[jsii.Number] = None,
        timeouts: typing.Optional["NetworkPacketCaptureTimeouts"] = None,
        count: typing.Optional[jsii.Number] = None,
        depends_on: typing.Optional[typing.List[cdktf.TerraformResource]] = None,
        lifecycle: typing.Optional[cdktf.TerraformResourceLifecycle] = None,
        provider: typing.Optional[cdktf.TerraformProvider] = None,
    ) -> None:
        """
        :param scope: -
        :param id: -
        :param name: 
        :param network_watcher_name: 
        :param resource_group_name: 
        :param storage_location: storage_location block.
        :param target_resource_id: 
        :param filter: filter block.
        :param maximum_bytes_per_packet: 
        :param maximum_bytes_per_session: 
        :param maximum_capture_duration: 
        :param timeouts: timeouts block.
        :param count: 
        :param depends_on: 
        :param lifecycle: 
        :param provider: 
        """
        config = NetworkPacketCaptureConfig(
            name=name,
            network_watcher_name=network_watcher_name,
            resource_group_name=resource_group_name,
            storage_location=storage_location,
            target_resource_id=target_resource_id,
            filter=filter,
            maximum_bytes_per_packet=maximum_bytes_per_packet,
            maximum_bytes_per_session=maximum_bytes_per_session,
            maximum_capture_duration=maximum_capture_duration,
            timeouts=timeouts,
            count=count,
            depends_on=depends_on,
            lifecycle=lifecycle,
            provider=provider,
        )

        jsii.create(NetworkPacketCapture, self, [scope, id, config])

    @jsii.member(jsii_name="synthesizeAttributes")
    def _synthesize_attributes(self) -> typing.Mapping[builtins.str, typing.Any]:
        return jsii.invoke(self, "synthesizeAttributes", [])

    @builtins.property # type: ignore
    @jsii.member(jsii_name="name")
    def name(self) -> builtins.str:
        return jsii.get(self, "name")

    @name.setter # type: ignore
    def name(self, value: builtins.str) -> None:
        jsii.set(self, "name", value)

    @builtins.property # type: ignore
    @jsii.member(jsii_name="networkWatcherName")
    def network_watcher_name(self) -> builtins.str:
        return jsii.get(self, "networkWatcherName")

    @network_watcher_name.setter # type: ignore
    def network_watcher_name(self, value: builtins.str) -> None:
        jsii.set(self, "networkWatcherName", value)

    @builtins.property # type: ignore
    @jsii.member(jsii_name="resourceGroupName")
    def resource_group_name(self) -> builtins.str:
        return jsii.get(self, "resourceGroupName")

    @resource_group_name.setter # type: ignore
    def resource_group_name(self, value: builtins.str) -> None:
        jsii.set(self, "resourceGroupName", value)

    @builtins.property # type: ignore
    @jsii.member(jsii_name="storageLocation")
    def storage_location(self) -> typing.List["NetworkPacketCaptureStorageLocation"]:
        return jsii.get(self, "storageLocation")

    @storage_location.setter # type: ignore
    def storage_location(
        self,
        value: typing.List["NetworkPacketCaptureStorageLocation"],
    ) -> None:
        jsii.set(self, "storageLocation", value)

    @builtins.property # type: ignore
    @jsii.member(jsii_name="targetResourceId")
    def target_resource_id(self) -> builtins.str:
        return jsii.get(self, "targetResourceId")

    @target_resource_id.setter # type: ignore
    def target_resource_id(self, value: builtins.str) -> None:
        jsii.set(self, "targetResourceId", value)

    @builtins.property # type: ignore
    @jsii.member(jsii_name="filter")
    def filter(self) -> typing.Optional[typing.List["NetworkPacketCaptureFilter"]]:
        return jsii.get(self, "filter")

    @filter.setter # type: ignore
    def filter(
        self,
        value: typing.Optional[typing.List["NetworkPacketCaptureFilter"]],
    ) -> None:
        jsii.set(self, "filter", value)

    @builtins.property # type: ignore
    @jsii.member(jsii_name="id")
    def id(self) -> typing.Optional[builtins.str]:
        return jsii.get(self, "id")

    @id.setter # type: ignore
    def id(self, value: typing.Optional[builtins.str]) -> None:
        jsii.set(self, "id", value)

    @builtins.property # type: ignore
    @jsii.member(jsii_name="maximumBytesPerPacket")
    def maximum_bytes_per_packet(self) -> typing.Optional[jsii.Number]:
        return jsii.get(self, "maximumBytesPerPacket")

    @maximum_bytes_per_packet.setter # type: ignore
    def maximum_bytes_per_packet(self, value: typing.Optional[jsii.Number]) -> None:
        jsii.set(self, "maximumBytesPerPacket", value)

    @builtins.property # type: ignore
    @jsii.member(jsii_name="maximumBytesPerSession")
    def maximum_bytes_per_session(self) -> typing.Optional[jsii.Number]:
        return jsii.get(self, "maximumBytesPerSession")

    @maximum_bytes_per_session.setter # type: ignore
    def maximum_bytes_per_session(self, value: typing.Optional[jsii.Number]) -> None:
        jsii.set(self, "maximumBytesPerSession", value)

    @builtins.property # type: ignore
    @jsii.member(jsii_name="maximumCaptureDuration")
    def maximum_capture_duration(self) -> typing.Optional[jsii.Number]:
        return jsii.get(self, "maximumCaptureDuration")

    @maximum_capture_duration.setter # type: ignore
    def maximum_capture_duration(self, value: typing.Optional[jsii.Number]) -> None:
        jsii.set(self, "maximumCaptureDuration", value)

    @builtins.property # type: ignore
    @jsii.member(jsii_name="timeouts")
    def timeouts(self) -> typing.Optional["NetworkPacketCaptureTimeouts"]:
        return jsii.get(self, "timeouts")

    @timeouts.setter # type: ignore
    def timeouts(self, value: typing.Optional["NetworkPacketCaptureTimeouts"]) -> None:
        jsii.set(self, "timeouts", value)


@jsii.data_type(
    jsii_type="@cdktf/provider-azurerm.NetworkPacketCaptureConfig",
    jsii_struct_bases=[cdktf.TerraformMetaArguments],
    name_mapping={
        "count": "count",
        "depends_on": "dependsOn",
        "lifecycle": "lifecycle",
        "provider": "provider",
        "name": "name",
        "network_watcher_name": "networkWatcherName",
        "resource_group_name": "resourceGroupName",
        "storage_location": "storageLocation",
        "target_resource_id": "targetResourceId",
        "filter": "filter",
        "maximum_bytes_per_packet": "maximumBytesPerPacket",
        "maximum_bytes_per_session": "maximumBytesPerSession",
        "maximum_capture_duration": "maximumCaptureDuration",
        "timeouts": "timeouts",
    },
)
class NetworkPacketCaptureConfig(cdktf.TerraformMetaArguments):
    def __init__(
        self,
        *,
        count: typing.Optional[jsii.Number] = None,
        depends_on: typing.Optional[typing.List[cdktf.TerraformResource]] = None,
        lifecycle: typing.Optional[cdktf.TerraformResourceLifecycle] = None,
        provider: typing.Optional[cdktf.TerraformProvider] = None,
        name: builtins.str,
        network_watcher_name: builtins.str,
        resource_group_name: builtins.str,
        storage_location: typing.List["NetworkPacketCaptureStorageLocation"],
        target_resource_id: builtins.str,
        filter: typing.Optional[typing.List["NetworkPacketCaptureFilter"]] = None,
        maximum_bytes_per_packet: typing.Optional[jsii.Number] = None,
        maximum_bytes_per_session: typing.Optional[jsii.Number] = None,
        maximum_capture_duration: typing.Optional[jsii.Number] = None,
        timeouts: typing.Optional["NetworkPacketCaptureTimeouts"] = None,
    ) -> None:
        """
        :param count: 
        :param depends_on: 
        :param lifecycle: 
        :param provider: 
        :param name: 
        :param network_watcher_name: 
        :param resource_group_name: 
        :param storage_location: storage_location block.
        :param target_resource_id: 
        :param filter: filter block.
        :param maximum_bytes_per_packet: 
        :param maximum_bytes_per_session: 
        :param maximum_capture_duration: 
        :param timeouts: timeouts block.
        """
        if isinstance(lifecycle, dict):
            lifecycle = cdktf.TerraformResourceLifecycle(**lifecycle)
        if isinstance(timeouts, dict):
            timeouts = NetworkPacketCaptureTimeouts(**timeouts)
        self._values: typing.Dict[str, typing.Any] = {
            "name": name,
            "network_watcher_name": network_watcher_name,
            "resource_group_name": resource_group_name,
            "storage_location": storage_location,
            "target_resource_id": target_resource_id,
        }
        if count is not None:
            self._values["count"] = count
        if depends_on is not None:
            self._values["depends_on"] = depends_on
        if lifecycle is not None:
            self._values["lifecycle"] = lifecycle
        if provider is not None:
            self._values["provider"] = provider
        if filter is not None:
            self._values["filter"] = filter
        if maximum_bytes_per_packet is not None:
            self._values["maximum_bytes_per_packet"] = maximum_bytes_per_packet
        if maximum_bytes_per_session is not None:
            self._values["maximum_bytes_per_session"] = maximum_bytes_per_session
        if maximum_capture_duration is not None:
            self._values["maximum_capture_duration"] = maximum_capture_duration
        if timeouts is not None:
            self._values["timeouts"] = timeouts

    @builtins.property
    def count(self) -> typing.Optional[jsii.Number]:
        """
        :stability: experimental
        """
        result = self._values.get("count")
        return result

    @builtins.property
    def depends_on(self) -> typing.Optional[typing.List[cdktf.TerraformResource]]:
        """
        :stability: experimental
        """
        result = self._values.get("depends_on")
        return result

    @builtins.property
    def lifecycle(self) -> typing.Optional[cdktf.TerraformResourceLifecycle]:
        """
        :stability: experimental
        """
        result = self._values.get("lifecycle")
        return result

    @builtins.property
    def provider(self) -> typing.Optional[cdktf.TerraformProvider]:
        """
        :stability: experimental
        """
        result = self._values.get("provider")
        return result

    @builtins.property
    def name(self) -> builtins.str:
        result = self._values.get("name")
        assert result is not None, "Required property 'name' is missing"
        return result

    @builtins.property
    def network_watcher_name(self) -> builtins.str:
        result = self._values.get("network_watcher_name")
        assert result is not None, "Required property 'network_watcher_name' is missing"
        return result

    @builtins.property
    def resource_group_name(self) -> builtins.str:
        result = self._values.get("resource_group_name")
        assert result is not None, "Required property 'resource_group_name' is missing"
        return result

    @builtins.property
    def storage_location(self) -> typing.List["NetworkPacketCaptureStorageLocation"]:
        """storage_location block."""
        result = self._values.get("storage_location")
        assert result is not None, "Required property 'storage_location' is missing"
        return result

    @builtins.property
    def target_resource_id(self) -> builtins.str:
        result = self._values.get("target_resource_id")
        assert result is not None, "Required property 'target_resource_id' is missing"
        return result

    @builtins.property
    def filter(self) -> typing.Optional[typing.List["NetworkPacketCaptureFilter"]]:
        """filter block."""
        result = self._values.get("filter")
        return result

    @builtins.property
    def maximum_bytes_per_packet(self) -> typing.Optional[jsii.Number]:
        result = self._values.get("maximum_bytes_per_packet")
        return result

    @builtins.property
    def maximum_bytes_per_session(self) -> typing.Optional[jsii.Number]:
        result = self._values.get("maximum_bytes_per_session")
        return result

    @builtins.property
    def maximum_capture_duration(self) -> typing.Optional[jsii.Number]:
        result = self._values.get("maximum_capture_duration")
        return result

    @builtins.property
    def timeouts(self) -> typing.Optional["NetworkPacketCaptureTimeouts"]:
        """timeouts block."""
        result = self._values.get("timeouts")
        return result

    def __eq__(self, rhs: typing.Any) -> builtins.bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs: typing.Any) -> builtins.bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return "NetworkPacketCaptureConfig(%s)" % ", ".join(
            k + "=" + repr(v) for k, v in self._values.items()
        )


@jsii.data_type(
    jsii_type="@cdktf/provider-azurerm.NetworkPacketCaptureFilter",
    jsii_struct_bases=[],
    name_mapping={
        "protocol": "protocol",
        "local_ip_address": "localIpAddress",
        "local_port": "localPort",
        "remote_ip_address": "remoteIpAddress",
        "remote_port": "remotePort",
    },
)
class NetworkPacketCaptureFilter:
    def __init__(
        self,
        *,
        protocol: builtins.str,
        local_ip_address: typing.Optional[builtins.str] = None,
        local_port: typing.Optional[builtins.str] = None,
        remote_ip_address: typing.Optional[builtins.str] = None,
        remote_port: typing.Optional[builtins.str] = None,
    ) -> None:
        """
        :param protocol: 
        :param local_ip_address: 
        :param local_port: 
        :param remote_ip_address: 
        :param remote_port: 
        """
        self._values: typing.Dict[str, typing.Any] = {
            "protocol": protocol,
        }
        if local_ip_address is not None:
            self._values["local_ip_address"] = local_ip_address
        if local_port is not None:
            self._values["local_port"] = local_port
        if remote_ip_address is not None:
            self._values["remote_ip_address"] = remote_ip_address
        if remote_port is not None:
            self._values["remote_port"] = remote_port

    @builtins.property
    def protocol(self) -> builtins.str:
        result = self._values.get("protocol")
        assert result is not None, "Required property 'protocol' is missing"
        return result

    @builtins.property
    def local_ip_address(self) -> typing.Optional[builtins.str]:
        result = self._values.get("local_ip_address")
        return result

    @builtins.property
    def local_port(self) -> typing.Optional[builtins.str]:
        result = self._values.get("local_port")
        return result

    @builtins.property
    def remote_ip_address(self) -> typing.Optional[builtins.str]:
        result = self._values.get("remote_ip_address")
        return result

    @builtins.property
    def remote_port(self) -> typing.Optional[builtins.str]:
        result = self._values.get("remote_port")
        return result

    def __eq__(self, rhs: typing.Any) -> builtins.bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs: typing.Any) -> builtins.bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return "NetworkPacketCaptureFilter(%s)" % ", ".join(
            k + "=" + repr(v) for k, v in self._values.items()
        )


@jsii.data_type(
    jsii_type="@cdktf/provider-azurerm.NetworkPacketCaptureStorageLocation",
    jsii_struct_bases=[],
    name_mapping={"file_path": "filePath", "storage_account_id": "storageAccountId"},
)
class NetworkPacketCaptureStorageLocation:
    def __init__(
        self,
        *,
        file_path: typing.Optional[builtins.str] = None,
        storage_account_id: typing.Optional[builtins.str] = None,
    ) -> None:
        """
        :param file_path: 
        :param storage_account_id: 
        """
        self._values: typing.Dict[str, typing.Any] = {}
        if file_path is not None:
            self._values["file_path"] = file_path
        if storage_account_id is not None:
            self._values["storage_account_id"] = storage_account_id

    @builtins.property
    def file_path(self) -> typing.Optional[builtins.str]:
        result = self._values.get("file_path")
        return result

    @builtins.property
    def storage_account_id(self) -> typing.Optional[builtins.str]:
        result = self._values.get("storage_account_id")
        return result

    def __eq__(self, rhs: typing.Any) -> builtins.bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs: typing.Any) -> builtins.bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return "NetworkPacketCaptureStorageLocation(%s)" % ", ".join(
            k + "=" + repr(v) for k, v in self._values.items()
        )


@jsii.data_type(
    jsii_type="@cdktf/provider-azurerm.NetworkPacketCaptureTimeouts",
    jsii_struct_bases=[],
    name_mapping={
        "create": "create",
        "delete": "delete",
        "read": "read",
        "update": "update",
    },
)
class NetworkPacketCaptureTimeouts:
    def __init__(
        self,
        *,
        create: typing.Optional[builtins.str] = None,
        delete: typing.Optional[builtins.str] = None,
        read: typing.Optional[builtins.str] = None,
        update: typing.Optional[builtins.str] = None,
    ) -> None:
        """
        :param create: 
        :param delete: 
        :param read: 
        :param update: 
        """
        self._values: typing.Dict[str, typing.Any] = {}
        if create is not None:
            self._values["create"] = create
        if delete is not None:
            self._values["delete"] = delete
        if read is not None:
            self._values["read"] = read
        if update is not None:
            self._values["update"] = update

    @builtins.property
    def create(self) -> typing.Optional[builtins.str]:
        result = self._values.get("create")
        return result

    @builtins.property
    def delete(self) -> typing.Optional[builtins.str]:
        result = self._values.get("delete")
        return result

    @builtins.property
    def read(self) -> typing.Optional[builtins.str]:
        result = self._values.get("read")
        return result

    @builtins.property
    def update(self) -> typing.Optional[builtins.str]:
        result = self._values.get("update")
        return result

    def __eq__(self, rhs: typing.Any) -> builtins.bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs: typing.Any) -> builtins.bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return "NetworkPacketCaptureTimeouts(%s)" % ", ".join(
            k + "=" + repr(v) for k, v in self._values.items()
        )


class NetworkProfile(
    cdktf.TerraformResource,
    metaclass=jsii.JSIIMeta,
    jsii_type="@cdktf/provider-azurerm.NetworkProfile",
):
    def __init__(
        self,
        scope: constructs.Construct,
        id: builtins.str,
        *,
        container_network_interface: typing.List["NetworkProfileContainerNetworkInterface"],
        location: builtins.str,
        name: builtins.str,
        resource_group_name: builtins.str,
        tags: typing.Optional[typing.Mapping[builtins.str, builtins.str]] = None,
        timeouts: typing.Optional["NetworkProfileTimeouts"] = None,
        count: typing.Optional[jsii.Number] = None,
        depends_on: typing.Optional[typing.List[cdktf.TerraformResource]] = None,
        lifecycle: typing.Optional[cdktf.TerraformResourceLifecycle] = None,
        provider: typing.Optional[cdktf.TerraformProvider] = None,
    ) -> None:
        """
        :param scope: -
        :param id: -
        :param container_network_interface: container_network_interface block.
        :param location: 
        :param name: 
        :param resource_group_name: 
        :param tags: 
        :param timeouts: timeouts block.
        :param count: 
        :param depends_on: 
        :param lifecycle: 
        :param provider: 
        """
        config = NetworkProfileConfig(
            container_network_interface=container_network_interface,
            location=location,
            name=name,
            resource_group_name=resource_group_name,
            tags=tags,
            timeouts=timeouts,
            count=count,
            depends_on=depends_on,
            lifecycle=lifecycle,
            provider=provider,
        )

        jsii.create(NetworkProfile, self, [scope, id, config])

    @jsii.member(jsii_name="synthesizeAttributes")
    def _synthesize_attributes(self) -> typing.Mapping[builtins.str, typing.Any]:
        return jsii.invoke(self, "synthesizeAttributes", [])

    @builtins.property # type: ignore
    @jsii.member(jsii_name="containerNetworkInterfaceIds")
    def container_network_interface_ids(self) -> typing.List[builtins.str]:
        return jsii.get(self, "containerNetworkInterfaceIds")

    @builtins.property # type: ignore
    @jsii.member(jsii_name="containerNetworkInterface")
    def container_network_interface(
        self,
    ) -> typing.List["NetworkProfileContainerNetworkInterface"]:
        return jsii.get(self, "containerNetworkInterface")

    @container_network_interface.setter # type: ignore
    def container_network_interface(
        self,
        value: typing.List["NetworkProfileContainerNetworkInterface"],
    ) -> None:
        jsii.set(self, "containerNetworkInterface", value)

    @builtins.property # type: ignore
    @jsii.member(jsii_name="location")
    def location(self) -> builtins.str:
        return jsii.get(self, "location")

    @location.setter # type: ignore
    def location(self, value: builtins.str) -> None:
        jsii.set(self, "location", value)

    @builtins.property # type: ignore
    @jsii.member(jsii_name="name")
    def name(self) -> builtins.str:
        return jsii.get(self, "name")

    @name.setter # type: ignore
    def name(self, value: builtins.str) -> None:
        jsii.set(self, "name", value)

    @builtins.property # type: ignore
    @jsii.member(jsii_name="resourceGroupName")
    def resource_group_name(self) -> builtins.str:
        return jsii.get(self, "resourceGroupName")

    @resource_group_name.setter # type: ignore
    def resource_group_name(self, value: builtins.str) -> None:
        jsii.set(self, "resourceGroupName", value)

    @builtins.property # type: ignore
    @jsii.member(jsii_name="id")
    def id(self) -> typing.Optional[builtins.str]:
        return jsii.get(self, "id")

    @id.setter # type: ignore
    def id(self, value: typing.Optional[builtins.str]) -> None:
        jsii.set(self, "id", value)

    @builtins.property # type: ignore
    @jsii.member(jsii_name="tags")
    def tags(self) -> typing.Optional[typing.Mapping[builtins.str, builtins.str]]:
        return jsii.get(self, "tags")

    @tags.setter # type: ignore
    def tags(
        self,
        value: typing.Optional[typing.Mapping[builtins.str, builtins.str]],
    ) -> None:
        jsii.set(self, "tags", value)

    @builtins.property # type: ignore
    @jsii.member(jsii_name="timeouts")
    def timeouts(self) -> typing.Optional["NetworkProfileTimeouts"]:
        return jsii.get(self, "timeouts")

    @timeouts.setter # type: ignore
    def timeouts(self, value: typing.Optional["NetworkProfileTimeouts"]) -> None:
        jsii.set(self, "timeouts", value)


@jsii.data_type(
    jsii_type="@cdktf/provider-azurerm.NetworkProfileConfig",
    jsii_struct_bases=[cdktf.TerraformMetaArguments],
    name_mapping={
        "count": "count",
        "depends_on": "dependsOn",
        "lifecycle": "lifecycle",
        "provider": "provider",
        "container_network_interface": "containerNetworkInterface",
        "location": "location",
        "name": "name",
        "resource_group_name": "resourceGroupName",
        "tags": "tags",
        "timeouts": "timeouts",
    },
)
class NetworkProfileConfig(cdktf.TerraformMetaArguments):
    def __init__(
        self,
        *,
        count: typing.Optional[jsii.Number] = None,
        depends_on: typing.Optional[typing.List[cdktf.TerraformResource]] = None,
        lifecycle: typing.Optional[cdktf.TerraformResourceLifecycle] = None,
        provider: typing.Optional[cdktf.TerraformProvider] = None,
        container_network_interface: typing.List["NetworkProfileContainerNetworkInterface"],
        location: builtins.str,
        name: builtins.str,
        resource_group_name: builtins.str,
        tags: typing.Optional[typing.Mapping[builtins.str, builtins.str]] = None,
        timeouts: typing.Optional["NetworkProfileTimeouts"] = None,
    ) -> None:
        """
        :param count: 
        :param depends_on: 
        :param lifecycle: 
        :param provider: 
        :param container_network_interface: container_network_interface block.
        :param location: 
        :param name: 
        :param resource_group_name: 
        :param tags: 
        :param timeouts: timeouts block.
        """
        if isinstance(lifecycle, dict):
            lifecycle = cdktf.TerraformResourceLifecycle(**lifecycle)
        if isinstance(timeouts, dict):
            timeouts = NetworkProfileTimeouts(**timeouts)
        self._values: typing.Dict[str, typing.Any] = {
            "container_network_interface": container_network_interface,
            "location": location,
            "name": name,
            "resource_group_name": resource_group_name,
        }
        if count is not None:
            self._values["count"] = count
        if depends_on is not None:
            self._values["depends_on"] = depends_on
        if lifecycle is not None:
            self._values["lifecycle"] = lifecycle
        if provider is not None:
            self._values["provider"] = provider
        if tags is not None:
            self._values["tags"] = tags
        if timeouts is not None:
            self._values["timeouts"] = timeouts

    @builtins.property
    def count(self) -> typing.Optional[jsii.Number]:
        """
        :stability: experimental
        """
        result = self._values.get("count")
        return result

    @builtins.property
    def depends_on(self) -> typing.Optional[typing.List[cdktf.TerraformResource]]:
        """
        :stability: experimental
        """
        result = self._values.get("depends_on")
        return result

    @builtins.property
    def lifecycle(self) -> typing.Optional[cdktf.TerraformResourceLifecycle]:
        """
        :stability: experimental
        """
        result = self._values.get("lifecycle")
        return result

    @builtins.property
    def provider(self) -> typing.Optional[cdktf.TerraformProvider]:
        """
        :stability: experimental
        """
        result = self._values.get("provider")
        return result

    @builtins.property
    def container_network_interface(
        self,
    ) -> typing.List["NetworkProfileContainerNetworkInterface"]:
        """container_network_interface block."""
        result = self._values.get("container_network_interface")
        assert result is not None, "Required property 'container_network_interface' is missing"
        return result

    @builtins.property
    def location(self) -> builtins.str:
        result = self._values.get("location")
        assert result is not None, "Required property 'location' is missing"
        return result

    @builtins.property
    def name(self) -> builtins.str:
        result = self._values.get("name")
        assert result is not None, "Required property 'name' is missing"
        return result

    @builtins.property
    def resource_group_name(self) -> builtins.str:
        result = self._values.get("resource_group_name")
        assert result is not None, "Required property 'resource_group_name' is missing"
        return result

    @builtins.property
    def tags(self) -> typing.Optional[typing.Mapping[builtins.str, builtins.str]]:
        result = self._values.get("tags")
        return result

    @builtins.property
    def timeouts(self) -> typing.Optional["NetworkProfileTimeouts"]:
        """timeouts block."""
        result = self._values.get("timeouts")
        return result

    def __eq__(self, rhs: typing.Any) -> builtins.bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs: typing.Any) -> builtins.bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return "NetworkProfileConfig(%s)" % ", ".join(
            k + "=" + repr(v) for k, v in self._values.items()
        )


@jsii.data_type(
    jsii_type="@cdktf/provider-azurerm.NetworkProfileContainerNetworkInterface",
    jsii_struct_bases=[],
    name_mapping={"ip_configuration": "ipConfiguration", "name": "name"},
)
class NetworkProfileContainerNetworkInterface:
    def __init__(
        self,
        *,
        ip_configuration: typing.List["NetworkProfileContainerNetworkInterfaceIpConfiguration"],
        name: builtins.str,
    ) -> None:
        """
        :param ip_configuration: ip_configuration block.
        :param name: 
        """
        self._values: typing.Dict[str, typing.Any] = {
            "ip_configuration": ip_configuration,
            "name": name,
        }

    @builtins.property
    def ip_configuration(
        self,
    ) -> typing.List["NetworkProfileContainerNetworkInterfaceIpConfiguration"]:
        """ip_configuration block."""
        result = self._values.get("ip_configuration")
        assert result is not None, "Required property 'ip_configuration' is missing"
        return result

    @builtins.property
    def name(self) -> builtins.str:
        result = self._values.get("name")
        assert result is not None, "Required property 'name' is missing"
        return result

    def __eq__(self, rhs: typing.Any) -> builtins.bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs: typing.Any) -> builtins.bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return "NetworkProfileContainerNetworkInterface(%s)" % ", ".join(
            k + "=" + repr(v) for k, v in self._values.items()
        )


@jsii.data_type(
    jsii_type="@cdktf/provider-azurerm.NetworkProfileContainerNetworkInterfaceIpConfiguration",
    jsii_struct_bases=[],
    name_mapping={"name": "name", "subnet_id": "subnetId"},
)
class NetworkProfileContainerNetworkInterfaceIpConfiguration:
    def __init__(self, *, name: builtins.str, subnet_id: builtins.str) -> None:
        """
        :param name: 
        :param subnet_id: 
        """
        self._values: typing.Dict[str, typing.Any] = {
            "name": name,
            "subnet_id": subnet_id,
        }

    @builtins.property
    def name(self) -> builtins.str:
        result = self._values.get("name")
        assert result is not None, "Required property 'name' is missing"
        return result

    @builtins.property
    def subnet_id(self) -> builtins.str:
        result = self._values.get("subnet_id")
        assert result is not None, "Required property 'subnet_id' is missing"
        return result

    def __eq__(self, rhs: typing.Any) -> builtins.bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs: typing.Any) -> builtins.bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return "NetworkProfileContainerNetworkInterfaceIpConfiguration(%s)" % ", ".join(
            k + "=" + repr(v) for k, v in self._values.items()
        )


@jsii.data_type(
    jsii_type="@cdktf/provider-azurerm.NetworkProfileTimeouts",
    jsii_struct_bases=[],
    name_mapping={
        "create": "create",
        "delete": "delete",
        "read": "read",
        "update": "update",
    },
)
class NetworkProfileTimeouts:
    def __init__(
        self,
        *,
        create: typing.Optional[builtins.str] = None,
        delete: typing.Optional[builtins.str] = None,
        read: typing.Optional[builtins.str] = None,
        update: typing.Optional[builtins.str] = None,
    ) -> None:
        """
        :param create: 
        :param delete: 
        :param read: 
        :param update: 
        """
        self._values: typing.Dict[str, typing.Any] = {}
        if create is not None:
            self._values["create"] = create
        if delete is not None:
            self._values["delete"] = delete
        if read is not None:
            self._values["read"] = read
        if update is not None:
            self._values["update"] = update

    @builtins.property
    def create(self) -> typing.Optional[builtins.str]:
        result = self._values.get("create")
        return result

    @builtins.property
    def delete(self) -> typing.Optional[builtins.str]:
        result = self._values.get("delete")
        return result

    @builtins.property
    def read(self) -> typing.Optional[builtins.str]:
        result = self._values.get("read")
        return result

    @builtins.property
    def update(self) -> typing.Optional[builtins.str]:
        result = self._values.get("update")
        return result

    def __eq__(self, rhs: typing.Any) -> builtins.bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs: typing.Any) -> builtins.bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return "NetworkProfileTimeouts(%s)" % ", ".join(
            k + "=" + repr(v) for k, v in self._values.items()
        )


class NetworkSecurityGroup(
    cdktf.TerraformResource,
    metaclass=jsii.JSIIMeta,
    jsii_type="@cdktf/provider-azurerm.NetworkSecurityGroup",
):
    def __init__(
        self,
        scope: constructs.Construct,
        id: builtins.str,
        *,
        location: builtins.str,
        name: builtins.str,
        resource_group_name: builtins.str,
        security_rule: typing.Optional[typing.List["NetworkSecurityGroupSecurityRule"]] = None,
        tags: typing.Optional[typing.Mapping[builtins.str, builtins.str]] = None,
        timeouts: typing.Optional["NetworkSecurityGroupTimeouts"] = None,
        count: typing.Optional[jsii.Number] = None,
        depends_on: typing.Optional[typing.List[cdktf.TerraformResource]] = None,
        lifecycle: typing.Optional[cdktf.TerraformResourceLifecycle] = None,
        provider: typing.Optional[cdktf.TerraformProvider] = None,
    ) -> None:
        """
        :param scope: -
        :param id: -
        :param location: 
        :param name: 
        :param resource_group_name: 
        :param security_rule: 
        :param tags: 
        :param timeouts: timeouts block.
        :param count: 
        :param depends_on: 
        :param lifecycle: 
        :param provider: 
        """
        config = NetworkSecurityGroupConfig(
            location=location,
            name=name,
            resource_group_name=resource_group_name,
            security_rule=security_rule,
            tags=tags,
            timeouts=timeouts,
            count=count,
            depends_on=depends_on,
            lifecycle=lifecycle,
            provider=provider,
        )

        jsii.create(NetworkSecurityGroup, self, [scope, id, config])

    @jsii.member(jsii_name="synthesizeAttributes")
    def _synthesize_attributes(self) -> typing.Mapping[builtins.str, typing.Any]:
        return jsii.invoke(self, "synthesizeAttributes", [])

    @builtins.property # type: ignore
    @jsii.member(jsii_name="location")
    def location(self) -> builtins.str:
        return jsii.get(self, "location")

    @location.setter # type: ignore
    def location(self, value: builtins.str) -> None:
        jsii.set(self, "location", value)

    @builtins.property # type: ignore
    @jsii.member(jsii_name="name")
    def name(self) -> builtins.str:
        return jsii.get(self, "name")

    @name.setter # type: ignore
    def name(self, value: builtins.str) -> None:
        jsii.set(self, "name", value)

    @builtins.property # type: ignore
    @jsii.member(jsii_name="resourceGroupName")
    def resource_group_name(self) -> builtins.str:
        return jsii.get(self, "resourceGroupName")

    @resource_group_name.setter # type: ignore
    def resource_group_name(self, value: builtins.str) -> None:
        jsii.set(self, "resourceGroupName", value)

    @builtins.property # type: ignore
    @jsii.member(jsii_name="id")
    def id(self) -> typing.Optional[builtins.str]:
        return jsii.get(self, "id")

    @id.setter # type: ignore
    def id(self, value: typing.Optional[builtins.str]) -> None:
        jsii.set(self, "id", value)

    @builtins.property # type: ignore
    @jsii.member(jsii_name="securityRule")
    def security_rule(
        self,
    ) -> typing.Optional[typing.List["NetworkSecurityGroupSecurityRule"]]:
        return jsii.get(self, "securityRule")

    @security_rule.setter # type: ignore
    def security_rule(
        self,
        value: typing.Optional[typing.List["NetworkSecurityGroupSecurityRule"]],
    ) -> None:
        jsii.set(self, "securityRule", value)

    @builtins.property # type: ignore
    @jsii.member(jsii_name="tags")
    def tags(self) -> typing.Optional[typing.Mapping[builtins.str, builtins.str]]:
        return jsii.get(self, "tags")

    @tags.setter # type: ignore
    def tags(
        self,
        value: typing.Optional[typing.Mapping[builtins.str, builtins.str]],
    ) -> None:
        jsii.set(self, "tags", value)

    @builtins.property # type: ignore
    @jsii.member(jsii_name="timeouts")
    def timeouts(self) -> typing.Optional["NetworkSecurityGroupTimeouts"]:
        return jsii.get(self, "timeouts")

    @timeouts.setter # type: ignore
    def timeouts(self, value: typing.Optional["NetworkSecurityGroupTimeouts"]) -> None:
        jsii.set(self, "timeouts", value)


@jsii.data_type(
    jsii_type="@cdktf/provider-azurerm.NetworkSecurityGroupConfig",
    jsii_struct_bases=[cdktf.TerraformMetaArguments],
    name_mapping={
        "count": "count",
        "depends_on": "dependsOn",
        "lifecycle": "lifecycle",
        "provider": "provider",
        "location": "location",
        "name": "name",
        "resource_group_name": "resourceGroupName",
        "security_rule": "securityRule",
        "tags": "tags",
        "timeouts": "timeouts",
    },
)
class NetworkSecurityGroupConfig(cdktf.TerraformMetaArguments):
    def __init__(
        self,
        *,
        count: typing.Optional[jsii.Number] = None,
        depends_on: typing.Optional[typing.List[cdktf.TerraformResource]] = None,
        lifecycle: typing.Optional[cdktf.TerraformResourceLifecycle] = None,
        provider: typing.Optional[cdktf.TerraformProvider] = None,
        location: builtins.str,
        name: builtins.str,
        resource_group_name: builtins.str,
        security_rule: typing.Optional[typing.List["NetworkSecurityGroupSecurityRule"]] = None,
        tags: typing.Optional[typing.Mapping[builtins.str, builtins.str]] = None,
        timeouts: typing.Optional["NetworkSecurityGroupTimeouts"] = None,
    ) -> None:
        """
        :param count: 
        :param depends_on: 
        :param lifecycle: 
        :param provider: 
        :param location: 
        :param name: 
        :param resource_group_name: 
        :param security_rule: 
        :param tags: 
        :param timeouts: timeouts block.
        """
        if isinstance(lifecycle, dict):
            lifecycle = cdktf.TerraformResourceLifecycle(**lifecycle)
        if isinstance(timeouts, dict):
            timeouts = NetworkSecurityGroupTimeouts(**timeouts)
        self._values: typing.Dict[str, typing.Any] = {
            "location": location,
            "name": name,
            "resource_group_name": resource_group_name,
        }
        if count is not None:
            self._values["count"] = count
        if depends_on is not None:
            self._values["depends_on"] = depends_on
        if lifecycle is not None:
            self._values["lifecycle"] = lifecycle
        if provider is not None:
            self._values["provider"] = provider
        if security_rule is not None:
            self._values["security_rule"] = security_rule
        if tags is not None:
            self._values["tags"] = tags
        if timeouts is not None:
            self._values["timeouts"] = timeouts

    @builtins.property
    def count(self) -> typing.Optional[jsii.Number]:
        """
        :stability: experimental
        """
        result = self._values.get("count")
        return result

    @builtins.property
    def depends_on(self) -> typing.Optional[typing.List[cdktf.TerraformResource]]:
        """
        :stability: experimental
        """
        result = self._values.get("depends_on")
        return result

    @builtins.property
    def lifecycle(self) -> typing.Optional[cdktf.TerraformResourceLifecycle]:
        """
        :stability: experimental
        """
        result = self._values.get("lifecycle")
        return result

    @builtins.property
    def provider(self) -> typing.Optional[cdktf.TerraformProvider]:
        """
        :stability: experimental
        """
        result = self._values.get("provider")
        return result

    @builtins.property
    def location(self) -> builtins.str:
        result = self._values.get("location")
        assert result is not None, "Required property 'location' is missing"
        return result

    @builtins.property
    def name(self) -> builtins.str:
        result = self._values.get("name")
        assert result is not None, "Required property 'name' is missing"
        return result

    @builtins.property
    def resource_group_name(self) -> builtins.str:
        result = self._values.get("resource_group_name")
        assert result is not None, "Required property 'resource_group_name' is missing"
        return result

    @builtins.property
    def security_rule(
        self,
    ) -> typing.Optional[typing.List["NetworkSecurityGroupSecurityRule"]]:
        result = self._values.get("security_rule")
        return result

    @builtins.property
    def tags(self) -> typing.Optional[typing.Mapping[builtins.str, builtins.str]]:
        result = self._values.get("tags")
        return result

    @builtins.property
    def timeouts(self) -> typing.Optional["NetworkSecurityGroupTimeouts"]:
        """timeouts block."""
        result = self._values.get("timeouts")
        return result

    def __eq__(self, rhs: typing.Any) -> builtins.bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs: typing.Any) -> builtins.bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return "NetworkSecurityGroupConfig(%s)" % ", ".join(
            k + "=" + repr(v) for k, v in self._values.items()
        )


@jsii.data_type(
    jsii_type="@cdktf/provider-azurerm.NetworkSecurityGroupSecurityRule",
    jsii_struct_bases=[],
    name_mapping={
        "access": "access",
        "description": "description",
        "destination_address_prefix": "destinationAddressPrefix",
        "destination_address_prefixes": "destinationAddressPrefixes",
        "destination_application_security_group_ids": "destinationApplicationSecurityGroupIds",
        "destination_port_range": "destinationPortRange",
        "destination_port_ranges": "destinationPortRanges",
        "direction": "direction",
        "name": "name",
        "priority": "priority",
        "protocol": "protocol",
        "source_address_prefix": "sourceAddressPrefix",
        "source_address_prefixes": "sourceAddressPrefixes",
        "source_application_security_group_ids": "sourceApplicationSecurityGroupIds",
        "source_port_range": "sourcePortRange",
        "source_port_ranges": "sourcePortRanges",
    },
)
class NetworkSecurityGroupSecurityRule:
    def __init__(
        self,
        *,
        access: typing.Optional[builtins.str] = None,
        description: typing.Optional[builtins.str] = None,
        destination_address_prefix: typing.Optional[builtins.str] = None,
        destination_address_prefixes: typing.Optional[typing.List[builtins.str]] = None,
        destination_application_security_group_ids: typing.Optional[typing.List[builtins.str]] = None,
        destination_port_range: typing.Optional[builtins.str] = None,
        destination_port_ranges: typing.Optional[typing.List[builtins.str]] = None,
        direction: typing.Optional[builtins.str] = None,
        name: typing.Optional[builtins.str] = None,
        priority: typing.Optional[jsii.Number] = None,
        protocol: typing.Optional[builtins.str] = None,
        source_address_prefix: typing.Optional[builtins.str] = None,
        source_address_prefixes: typing.Optional[typing.List[builtins.str]] = None,
        source_application_security_group_ids: typing.Optional[typing.List[builtins.str]] = None,
        source_port_range: typing.Optional[builtins.str] = None,
        source_port_ranges: typing.Optional[typing.List[builtins.str]] = None,
    ) -> None:
        """
        :param access: 
        :param description: 
        :param destination_address_prefix: 
        :param destination_address_prefixes: 
        :param destination_application_security_group_ids: 
        :param destination_port_range: 
        :param destination_port_ranges: 
        :param direction: 
        :param name: 
        :param priority: 
        :param protocol: 
        :param source_address_prefix: 
        :param source_address_prefixes: 
        :param source_application_security_group_ids: 
        :param source_port_range: 
        :param source_port_ranges: 
        """
        self._values: typing.Dict[str, typing.Any] = {}
        if access is not None:
            self._values["access"] = access
        if description is not None:
            self._values["description"] = description
        if destination_address_prefix is not None:
            self._values["destination_address_prefix"] = destination_address_prefix
        if destination_address_prefixes is not None:
            self._values["destination_address_prefixes"] = destination_address_prefixes
        if destination_application_security_group_ids is not None:
            self._values["destination_application_security_group_ids"] = destination_application_security_group_ids
        if destination_port_range is not None:
            self._values["destination_port_range"] = destination_port_range
        if destination_port_ranges is not None:
            self._values["destination_port_ranges"] = destination_port_ranges
        if direction is not None:
            self._values["direction"] = direction
        if name is not None:
            self._values["name"] = name
        if priority is not None:
            self._values["priority"] = priority
        if protocol is not None:
            self._values["protocol"] = protocol
        if source_address_prefix is not None:
            self._values["source_address_prefix"] = source_address_prefix
        if source_address_prefixes is not None:
            self._values["source_address_prefixes"] = source_address_prefixes
        if source_application_security_group_ids is not None:
            self._values["source_application_security_group_ids"] = source_application_security_group_ids
        if source_port_range is not None:
            self._values["source_port_range"] = source_port_range
        if source_port_ranges is not None:
            self._values["source_port_ranges"] = source_port_ranges

    @builtins.property
    def access(self) -> typing.Optional[builtins.str]:
        result = self._values.get("access")
        return result

    @builtins.property
    def description(self) -> typing.Optional[builtins.str]:
        result = self._values.get("description")
        return result

    @builtins.property
    def destination_address_prefix(self) -> typing.Optional[builtins.str]:
        result = self._values.get("destination_address_prefix")
        return result

    @builtins.property
    def destination_address_prefixes(
        self,
    ) -> typing.Optional[typing.List[builtins.str]]:
        result = self._values.get("destination_address_prefixes")
        return result

    @builtins.property
    def destination_application_security_group_ids(
        self,
    ) -> typing.Optional[typing.List[builtins.str]]:
        result = self._values.get("destination_application_security_group_ids")
        return result

    @builtins.property
    def destination_port_range(self) -> typing.Optional[builtins.str]:
        result = self._values.get("destination_port_range")
        return result

    @builtins.property
    def destination_port_ranges(self) -> typing.Optional[typing.List[builtins.str]]:
        result = self._values.get("destination_port_ranges")
        return result

    @builtins.property
    def direction(self) -> typing.Optional[builtins.str]:
        result = self._values.get("direction")
        return result

    @builtins.property
    def name(self) -> typing.Optional[builtins.str]:
        result = self._values.get("name")
        return result

    @builtins.property
    def priority(self) -> typing.Optional[jsii.Number]:
        result = self._values.get("priority")
        return result

    @builtins.property
    def protocol(self) -> typing.Optional[builtins.str]:
        result = self._values.get("protocol")
        return result

    @builtins.property
    def source_address_prefix(self) -> typing.Optional[builtins.str]:
        result = self._values.get("source_address_prefix")
        return result

    @builtins.property
    def source_address_prefixes(self) -> typing.Optional[typing.List[builtins.str]]:
        result = self._values.get("source_address_prefixes")
        return result

    @builtins.property
    def source_application_security_group_ids(
        self,
    ) -> typing.Optional[typing.List[builtins.str]]:
        result = self._values.get("source_application_security_group_ids")
        return result

    @builtins.property
    def source_port_range(self) -> typing.Optional[builtins.str]:
        result = self._values.get("source_port_range")
        return result

    @builtins.property
    def source_port_ranges(self) -> typing.Optional[typing.List[builtins.str]]:
        result = self._values.get("source_port_ranges")
        return result

    def __eq__(self, rhs: typing.Any) -> builtins.bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs: typing.Any) -> builtins.bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return "NetworkSecurityGroupSecurityRule(%s)" % ", ".join(
            k + "=" + repr(v) for k, v in self._values.items()
        )


@jsii.data_type(
    jsii_type="@cdktf/provider-azurerm.NetworkSecurityGroupTimeouts",
    jsii_struct_bases=[],
    name_mapping={
        "create": "create",
        "delete": "delete",
        "read": "read",
        "update": "update",
    },
)
class NetworkSecurityGroupTimeouts:
    def __init__(
        self,
        *,
        create: typing.Optional[builtins.str] = None,
        delete: typing.Optional[builtins.str] = None,
        read: typing.Optional[builtins.str] = None,
        update: typing.Optional[builtins.str] = None,
    ) -> None:
        """
        :param create: 
        :param delete: 
        :param read: 
        :param update: 
        """
        self._values: typing.Dict[str, typing.Any] = {}
        if create is not None:
            self._values["create"] = create
        if delete is not None:
            self._values["delete"] = delete
        if read is not None:
            self._values["read"] = read
        if update is not None:
            self._values["update"] = update

    @builtins.property
    def create(self) -> typing.Optional[builtins.str]:
        result = self._values.get("create")
        return result

    @builtins.property
    def delete(self) -> typing.Optional[builtins.str]:
        result = self._values.get("delete")
        return result

    @builtins.property
    def read(self) -> typing.Optional[builtins.str]:
        result = self._values.get("read")
        return result

    @builtins.property
    def update(self) -> typing.Optional[builtins.str]:
        result = self._values.get("update")
        return result

    def __eq__(self, rhs: typing.Any) -> builtins.bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs: typing.Any) -> builtins.bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return "NetworkSecurityGroupTimeouts(%s)" % ", ".join(
            k + "=" + repr(v) for k, v in self._values.items()
        )


class NetworkSecurityRule(
    cdktf.TerraformResource,
    metaclass=jsii.JSIIMeta,
    jsii_type="@cdktf/provider-azurerm.NetworkSecurityRule",
):
    def __init__(
        self,
        scope: constructs.Construct,
        id: builtins.str,
        *,
        access: builtins.str,
        direction: builtins.str,
        name: builtins.str,
        network_security_group_name: builtins.str,
        priority: jsii.Number,
        protocol: builtins.str,
        resource_group_name: builtins.str,
        description: typing.Optional[builtins.str] = None,
        destination_address_prefix: typing.Optional[builtins.str] = None,
        destination_address_prefixes: typing.Optional[typing.List[builtins.str]] = None,
        destination_application_security_group_ids: typing.Optional[typing.List[builtins.str]] = None,
        destination_port_range: typing.Optional[builtins.str] = None,
        destination_port_ranges: typing.Optional[typing.List[builtins.str]] = None,
        source_address_prefix: typing.Optional[builtins.str] = None,
        source_address_prefixes: typing.Optional[typing.List[builtins.str]] = None,
        source_application_security_group_ids: typing.Optional[typing.List[builtins.str]] = None,
        source_port_range: typing.Optional[builtins.str] = None,
        source_port_ranges: typing.Optional[typing.List[builtins.str]] = None,
        timeouts: typing.Optional["NetworkSecurityRuleTimeouts"] = None,
        count: typing.Optional[jsii.Number] = None,
        depends_on: typing.Optional[typing.List[cdktf.TerraformResource]] = None,
        lifecycle: typing.Optional[cdktf.TerraformResourceLifecycle] = None,
        provider: typing.Optional[cdktf.TerraformProvider] = None,
    ) -> None:
        """
        :param scope: -
        :param id: -
        :param access: 
        :param direction: 
        :param name: 
        :param network_security_group_name: 
        :param priority: 
        :param protocol: 
        :param resource_group_name: 
        :param description: 
        :param destination_address_prefix: 
        :param destination_address_prefixes: 
        :param destination_application_security_group_ids: 
        :param destination_port_range: 
        :param destination_port_ranges: 
        :param source_address_prefix: 
        :param source_address_prefixes: 
        :param source_application_security_group_ids: 
        :param source_port_range: 
        :param source_port_ranges: 
        :param timeouts: timeouts block.
        :param count: 
        :param depends_on: 
        :param lifecycle: 
        :param provider: 
        """
        config = NetworkSecurityRuleConfig(
            access=access,
            direction=direction,
            name=name,
            network_security_group_name=network_security_group_name,
            priority=priority,
            protocol=protocol,
            resource_group_name=resource_group_name,
            description=description,
            destination_address_prefix=destination_address_prefix,
            destination_address_prefixes=destination_address_prefixes,
            destination_application_security_group_ids=destination_application_security_group_ids,
            destination_port_range=destination_port_range,
            destination_port_ranges=destination_port_ranges,
            source_address_prefix=source_address_prefix,
            source_address_prefixes=source_address_prefixes,
            source_application_security_group_ids=source_application_security_group_ids,
            source_port_range=source_port_range,
            source_port_ranges=source_port_ranges,
            timeouts=timeouts,
            count=count,
            depends_on=depends_on,
            lifecycle=lifecycle,
            provider=provider,
        )

        jsii.create(NetworkSecurityRule, self, [scope, id, config])

    @jsii.member(jsii_name="synthesizeAttributes")
    def _synthesize_attributes(self) -> typing.Mapping[builtins.str, typing.Any]:
        return jsii.invoke(self, "synthesizeAttributes", [])

    @builtins.property # type: ignore
    @jsii.member(jsii_name="access")
    def access(self) -> builtins.str:
        return jsii.get(self, "access")

    @access.setter # type: ignore
    def access(self, value: builtins.str) -> None:
        jsii.set(self, "access", value)

    @builtins.property # type: ignore
    @jsii.member(jsii_name="direction")
    def direction(self) -> builtins.str:
        return jsii.get(self, "direction")

    @direction.setter # type: ignore
    def direction(self, value: builtins.str) -> None:
        jsii.set(self, "direction", value)

    @builtins.property # type: ignore
    @jsii.member(jsii_name="name")
    def name(self) -> builtins.str:
        return jsii.get(self, "name")

    @name.setter # type: ignore
    def name(self, value: builtins.str) -> None:
        jsii.set(self, "name", value)

    @builtins.property # type: ignore
    @jsii.member(jsii_name="networkSecurityGroupName")
    def network_security_group_name(self) -> builtins.str:
        return jsii.get(self, "networkSecurityGroupName")

    @network_security_group_name.setter # type: ignore
    def network_security_group_name(self, value: builtins.str) -> None:
        jsii.set(self, "networkSecurityGroupName", value)

    @builtins.property # type: ignore
    @jsii.member(jsii_name="priority")
    def priority(self) -> jsii.Number:
        return jsii.get(self, "priority")

    @priority.setter # type: ignore
    def priority(self, value: jsii.Number) -> None:
        jsii.set(self, "priority", value)

    @builtins.property # type: ignore
    @jsii.member(jsii_name="protocol")
    def protocol(self) -> builtins.str:
        return jsii.get(self, "protocol")

    @protocol.setter # type: ignore
    def protocol(self, value: builtins.str) -> None:
        jsii.set(self, "protocol", value)

    @builtins.property # type: ignore
    @jsii.member(jsii_name="resourceGroupName")
    def resource_group_name(self) -> builtins.str:
        return jsii.get(self, "resourceGroupName")

    @resource_group_name.setter # type: ignore
    def resource_group_name(self, value: builtins.str) -> None:
        jsii.set(self, "resourceGroupName", value)

    @builtins.property # type: ignore
    @jsii.member(jsii_name="description")
    def description(self) -> typing.Optional[builtins.str]:
        return jsii.get(self, "description")

    @description.setter # type: ignore
    def description(self, value: typing.Optional[builtins.str]) -> None:
        jsii.set(self, "description", value)

    @builtins.property # type: ignore
    @jsii.member(jsii_name="destinationAddressPrefix")
    def destination_address_prefix(self) -> typing.Optional[builtins.str]:
        return jsii.get(self, "destinationAddressPrefix")

    @destination_address_prefix.setter # type: ignore
    def destination_address_prefix(self, value: typing.Optional[builtins.str]) -> None:
        jsii.set(self, "destinationAddressPrefix", value)

    @builtins.property # type: ignore
    @jsii.member(jsii_name="destinationAddressPrefixes")
    def destination_address_prefixes(
        self,
    ) -> typing.Optional[typing.List[builtins.str]]:
        return jsii.get(self, "destinationAddressPrefixes")

    @destination_address_prefixes.setter # type: ignore
    def destination_address_prefixes(
        self,
        value: typing.Optional[typing.List[builtins.str]],
    ) -> None:
        jsii.set(self, "destinationAddressPrefixes", value)

    @builtins.property # type: ignore
    @jsii.member(jsii_name="destinationApplicationSecurityGroupIds")
    def destination_application_security_group_ids(
        self,
    ) -> typing.Optional[typing.List[builtins.str]]:
        return jsii.get(self, "destinationApplicationSecurityGroupIds")

    @destination_application_security_group_ids.setter # type: ignore
    def destination_application_security_group_ids(
        self,
        value: typing.Optional[typing.List[builtins.str]],
    ) -> None:
        jsii.set(self, "destinationApplicationSecurityGroupIds", value)

    @builtins.property # type: ignore
    @jsii.member(jsii_name="destinationPortRange")
    def destination_port_range(self) -> typing.Optional[builtins.str]:
        return jsii.get(self, "destinationPortRange")

    @destination_port_range.setter # type: ignore
    def destination_port_range(self, value: typing.Optional[builtins.str]) -> None:
        jsii.set(self, "destinationPortRange", value)

    @builtins.property # type: ignore
    @jsii.member(jsii_name="destinationPortRanges")
    def destination_port_ranges(self) -> typing.Optional[typing.List[builtins.str]]:
        return jsii.get(self, "destinationPortRanges")

    @destination_port_ranges.setter # type: ignore
    def destination_port_ranges(
        self,
        value: typing.Optional[typing.List[builtins.str]],
    ) -> None:
        jsii.set(self, "destinationPortRanges", value)

    @builtins.property # type: ignore
    @jsii.member(jsii_name="id")
    def id(self) -> typing.Optional[builtins.str]:
        return jsii.get(self, "id")

    @id.setter # type: ignore
    def id(self, value: typing.Optional[builtins.str]) -> None:
        jsii.set(self, "id", value)

    @builtins.property # type: ignore
    @jsii.member(jsii_name="sourceAddressPrefix")
    def source_address_prefix(self) -> typing.Optional[builtins.str]:
        return jsii.get(self, "sourceAddressPrefix")

    @source_address_prefix.setter # type: ignore
    def source_address_prefix(self, value: typing.Optional[builtins.str]) -> None:
        jsii.set(self, "sourceAddressPrefix", value)

    @builtins.property # type: ignore
    @jsii.member(jsii_name="sourceAddressPrefixes")
    def source_address_prefixes(self) -> typing.Optional[typing.List[builtins.str]]:
        return jsii.get(self, "sourceAddressPrefixes")

    @source_address_prefixes.setter # type: ignore
    def source_address_prefixes(
        self,
        value: typing.Optional[typing.List[builtins.str]],
    ) -> None:
        jsii.set(self, "sourceAddressPrefixes", value)

    @builtins.property # type: ignore
    @jsii.member(jsii_name="sourceApplicationSecurityGroupIds")
    def source_application_security_group_ids(
        self,
    ) -> typing.Optional[typing.List[builtins.str]]:
        return jsii.get(self, "sourceApplicationSecurityGroupIds")

    @source_application_security_group_ids.setter # type: ignore
    def source_application_security_group_ids(
        self,
        value: typing.Optional[typing.List[builtins.str]],
    ) -> None:
        jsii.set(self, "sourceApplicationSecurityGroupIds", value)

    @builtins.property # type: ignore
    @jsii.member(jsii_name="sourcePortRange")
    def source_port_range(self) -> typing.Optional[builtins.str]:
        return jsii.get(self, "sourcePortRange")

    @source_port_range.setter # type: ignore
    def source_port_range(self, value: typing.Optional[builtins.str]) -> None:
        jsii.set(self, "sourcePortRange", value)

    @builtins.property # type: ignore
    @jsii.member(jsii_name="sourcePortRanges")
    def source_port_ranges(self) -> typing.Optional[typing.List[builtins.str]]:
        return jsii.get(self, "sourcePortRanges")

    @source_port_ranges.setter # type: ignore
    def source_port_ranges(
        self,
        value: typing.Optional[typing.List[builtins.str]],
    ) -> None:
        jsii.set(self, "sourcePortRanges", value)

    @builtins.property # type: ignore
    @jsii.member(jsii_name="timeouts")
    def timeouts(self) -> typing.Optional["NetworkSecurityRuleTimeouts"]:
        return jsii.get(self, "timeouts")

    @timeouts.setter # type: ignore
    def timeouts(self, value: typing.Optional["NetworkSecurityRuleTimeouts"]) -> None:
        jsii.set(self, "timeouts", value)


@jsii.data_type(
    jsii_type="@cdktf/provider-azurerm.NetworkSecurityRuleConfig",
    jsii_struct_bases=[cdktf.TerraformMetaArguments],
    name_mapping={
        "count": "count",
        "depends_on": "dependsOn",
        "lifecycle": "lifecycle",
        "provider": "provider",
        "access": "access",
        "direction": "direction",
        "name": "name",
        "network_security_group_name": "networkSecurityGroupName",
        "priority": "priority",
        "protocol": "protocol",
        "resource_group_name": "resourceGroupName",
        "description": "description",
        "destination_address_prefix": "destinationAddressPrefix",
        "destination_address_prefixes": "destinationAddressPrefixes",
        "destination_application_security_group_ids": "destinationApplicationSecurityGroupIds",
        "destination_port_range": "destinationPortRange",
        "destination_port_ranges": "destinationPortRanges",
        "source_address_prefix": "sourceAddressPrefix",
        "source_address_prefixes": "sourceAddressPrefixes",
        "source_application_security_group_ids": "sourceApplicationSecurityGroupIds",
        "source_port_range": "sourcePortRange",
        "source_port_ranges": "sourcePortRanges",
        "timeouts": "timeouts",
    },
)
class NetworkSecurityRuleConfig(cdktf.TerraformMetaArguments):
    def __init__(
        self,
        *,
        count: typing.Optional[jsii.Number] = None,
        depends_on: typing.Optional[typing.List[cdktf.TerraformResource]] = None,
        lifecycle: typing.Optional[cdktf.TerraformResourceLifecycle] = None,
        provider: typing.Optional[cdktf.TerraformProvider] = None,
        access: builtins.str,
        direction: builtins.str,
        name: builtins.str,
        network_security_group_name: builtins.str,
        priority: jsii.Number,
        protocol: builtins.str,
        resource_group_name: builtins.str,
        description: typing.Optional[builtins.str] = None,
        destination_address_prefix: typing.Optional[builtins.str] = None,
        destination_address_prefixes: typing.Optional[typing.List[builtins.str]] = None,
        destination_application_security_group_ids: typing.Optional[typing.List[builtins.str]] = None,
        destination_port_range: typing.Optional[builtins.str] = None,
        destination_port_ranges: typing.Optional[typing.List[builtins.str]] = None,
        source_address_prefix: typing.Optional[builtins.str] = None,
        source_address_prefixes: typing.Optional[typing.List[builtins.str]] = None,
        source_application_security_group_ids: typing.Optional[typing.List[builtins.str]] = None,
        source_port_range: typing.Optional[builtins.str] = None,
        source_port_ranges: typing.Optional[typing.List[builtins.str]] = None,
        timeouts: typing.Optional["NetworkSecurityRuleTimeouts"] = None,
    ) -> None:
        """
        :param count: 
        :param depends_on: 
        :param lifecycle: 
        :param provider: 
        :param access: 
        :param direction: 
        :param name: 
        :param network_security_group_name: 
        :param priority: 
        :param protocol: 
        :param resource_group_name: 
        :param description: 
        :param destination_address_prefix: 
        :param destination_address_prefixes: 
        :param destination_application_security_group_ids: 
        :param destination_port_range: 
        :param destination_port_ranges: 
        :param source_address_prefix: 
        :param source_address_prefixes: 
        :param source_application_security_group_ids: 
        :param source_port_range: 
        :param source_port_ranges: 
        :param timeouts: timeouts block.
        """
        if isinstance(lifecycle, dict):
            lifecycle = cdktf.TerraformResourceLifecycle(**lifecycle)
        if isinstance(timeouts, dict):
            timeouts = NetworkSecurityRuleTimeouts(**timeouts)
        self._values: typing.Dict[str, typing.Any] = {
            "access": access,
            "direction": direction,
            "name": name,
            "network_security_group_name": network_security_group_name,
            "priority": priority,
            "protocol": protocol,
            "resource_group_name": resource_group_name,
        }
        if count is not None:
            self._values["count"] = count
        if depends_on is not None:
            self._values["depends_on"] = depends_on
        if lifecycle is not None:
            self._values["lifecycle"] = lifecycle
        if provider is not None:
            self._values["provider"] = provider
        if description is not None:
            self._values["description"] = description
        if destination_address_prefix is not None:
            self._values["destination_address_prefix"] = destination_address_prefix
        if destination_address_prefixes is not None:
            self._values["destination_address_prefixes"] = destination_address_prefixes
        if destination_application_security_group_ids is not None:
            self._values["destination_application_security_group_ids"] = destination_application_security_group_ids
        if destination_port_range is not None:
            self._values["destination_port_range"] = destination_port_range
        if destination_port_ranges is not None:
            self._values["destination_port_ranges"] = destination_port_ranges
        if source_address_prefix is not None:
            self._values["source_address_prefix"] = source_address_prefix
        if source_address_prefixes is not None:
            self._values["source_address_prefixes"] = source_address_prefixes
        if source_application_security_group_ids is not None:
            self._values["source_application_security_group_ids"] = source_application_security_group_ids
        if source_port_range is not None:
            self._values["source_port_range"] = source_port_range
        if source_port_ranges is not None:
            self._values["source_port_ranges"] = source_port_ranges
        if timeouts is not None:
            self._values["timeouts"] = timeouts

    @builtins.property
    def count(self) -> typing.Optional[jsii.Number]:
        """
        :stability: experimental
        """
        result = self._values.get("count")
        return result

    @builtins.property
    def depends_on(self) -> typing.Optional[typing.List[cdktf.TerraformResource]]:
        """
        :stability: experimental
        """
        result = self._values.get("depends_on")
        return result

    @builtins.property
    def lifecycle(self) -> typing.Optional[cdktf.TerraformResourceLifecycle]:
        """
        :stability: experimental
        """
        result = self._values.get("lifecycle")
        return result

    @builtins.property
    def provider(self) -> typing.Optional[cdktf.TerraformProvider]:
        """
        :stability: experimental
        """
        result = self._values.get("provider")
        return result

    @builtins.property
    def access(self) -> builtins.str:
        result = self._values.get("access")
        assert result is not None, "Required property 'access' is missing"
        return result

    @builtins.property
    def direction(self) -> builtins.str:
        result = self._values.get("direction")
        assert result is not None, "Required property 'direction' is missing"
        return result

    @builtins.property
    def name(self) -> builtins.str:
        result = self._values.get("name")
        assert result is not None, "Required property 'name' is missing"
        return result

    @builtins.property
    def network_security_group_name(self) -> builtins.str:
        result = self._values.get("network_security_group_name")
        assert result is not None, "Required property 'network_security_group_name' is missing"
        return result

    @builtins.property
    def priority(self) -> jsii.Number:
        result = self._values.get("priority")
        assert result is not None, "Required property 'priority' is missing"
        return result

    @builtins.property
    def protocol(self) -> builtins.str:
        result = self._values.get("protocol")
        assert result is not None, "Required property 'protocol' is missing"
        return result

    @builtins.property
    def resource_group_name(self) -> builtins.str:
        result = self._values.get("resource_group_name")
        assert result is not None, "Required property 'resource_group_name' is missing"
        return result

    @builtins.property
    def description(self) -> typing.Optional[builtins.str]:
        result = self._values.get("description")
        return result

    @builtins.property
    def destination_address_prefix(self) -> typing.Optional[builtins.str]:
        result = self._values.get("destination_address_prefix")
        return result

    @builtins.property
    def destination_address_prefixes(
        self,
    ) -> typing.Optional[typing.List[builtins.str]]:
        result = self._values.get("destination_address_prefixes")
        return result

    @builtins.property
    def destination_application_security_group_ids(
        self,
    ) -> typing.Optional[typing.List[builtins.str]]:
        result = self._values.get("destination_application_security_group_ids")
        return result

    @builtins.property
    def destination_port_range(self) -> typing.Optional[builtins.str]:
        result = self._values.get("destination_port_range")
        return result

    @builtins.property
    def destination_port_ranges(self) -> typing.Optional[typing.List[builtins.str]]:
        result = self._values.get("destination_port_ranges")
        return result

    @builtins.property
    def source_address_prefix(self) -> typing.Optional[builtins.str]:
        result = self._values.get("source_address_prefix")
        return result

    @builtins.property
    def source_address_prefixes(self) -> typing.Optional[typing.List[builtins.str]]:
        result = self._values.get("source_address_prefixes")
        return result

    @builtins.property
    def source_application_security_group_ids(
        self,
    ) -> typing.Optional[typing.List[builtins.str]]:
        result = self._values.get("source_application_security_group_ids")
        return result

    @builtins.property
    def source_port_range(self) -> typing.Optional[builtins.str]:
        result = self._values.get("source_port_range")
        return result

    @builtins.property
    def source_port_ranges(self) -> typing.Optional[typing.List[builtins.str]]:
        result = self._values.get("source_port_ranges")
        return result

    @builtins.property
    def timeouts(self) -> typing.Optional["NetworkSecurityRuleTimeouts"]:
        """timeouts block."""
        result = self._values.get("timeouts")
        return result

    def __eq__(self, rhs: typing.Any) -> builtins.bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs: typing.Any) -> builtins.bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return "NetworkSecurityRuleConfig(%s)" % ", ".join(
            k + "=" + repr(v) for k, v in self._values.items()
        )


@jsii.data_type(
    jsii_type="@cdktf/provider-azurerm.NetworkSecurityRuleTimeouts",
    jsii_struct_bases=[],
    name_mapping={
        "create": "create",
        "delete": "delete",
        "read": "read",
        "update": "update",
    },
)
class NetworkSecurityRuleTimeouts:
    def __init__(
        self,
        *,
        create: typing.Optional[builtins.str] = None,
        delete: typing.Optional[builtins.str] = None,
        read: typing.Optional[builtins.str] = None,
        update: typing.Optional[builtins.str] = None,
    ) -> None:
        """
        :param create: 
        :param delete: 
        :param read: 
        :param update: 
        """
        self._values: typing.Dict[str, typing.Any] = {}
        if create is not None:
            self._values["create"] = create
        if delete is not None:
            self._values["delete"] = delete
        if read is not None:
            self._values["read"] = read
        if update is not None:
            self._values["update"] = update

    @builtins.property
    def create(self) -> typing.Optional[builtins.str]:
        result = self._values.get("create")
        return result

    @builtins.property
    def delete(self) -> typing.Optional[builtins.str]:
        result = self._values.get("delete")
        return result

    @builtins.property
    def read(self) -> typing.Optional[builtins.str]:
        result = self._values.get("read")
        return result

    @builtins.property
    def update(self) -> typing.Optional[builtins.str]:
        result = self._values.get("update")
        return result

    def __eq__(self, rhs: typing.Any) -> builtins.bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs: typing.Any) -> builtins.bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return "NetworkSecurityRuleTimeouts(%s)" % ", ".join(
            k + "=" + repr(v) for k, v in self._values.items()
        )


class NetworkWatcher(
    cdktf.TerraformResource,
    metaclass=jsii.JSIIMeta,
    jsii_type="@cdktf/provider-azurerm.NetworkWatcher",
):
    def __init__(
        self,
        scope: constructs.Construct,
        id: builtins.str,
        *,
        location: builtins.str,
        name: builtins.str,
        resource_group_name: builtins.str,
        tags: typing.Optional[typing.Mapping[builtins.str, builtins.str]] = None,
        timeouts: typing.Optional["NetworkWatcherTimeouts"] = None,
        count: typing.Optional[jsii.Number] = None,
        depends_on: typing.Optional[typing.List[cdktf.TerraformResource]] = None,
        lifecycle: typing.Optional[cdktf.TerraformResourceLifecycle] = None,
        provider: typing.Optional[cdktf.TerraformProvider] = None,
    ) -> None:
        """
        :param scope: -
        :param id: -
        :param location: 
        :param name: 
        :param resource_group_name: 
        :param tags: 
        :param timeouts: timeouts block.
        :param count: 
        :param depends_on: 
        :param lifecycle: 
        :param provider: 
        """
        config = NetworkWatcherConfig(
            location=location,
            name=name,
            resource_group_name=resource_group_name,
            tags=tags,
            timeouts=timeouts,
            count=count,
            depends_on=depends_on,
            lifecycle=lifecycle,
            provider=provider,
        )

        jsii.create(NetworkWatcher, self, [scope, id, config])

    @jsii.member(jsii_name="synthesizeAttributes")
    def _synthesize_attributes(self) -> typing.Mapping[builtins.str, typing.Any]:
        return jsii.invoke(self, "synthesizeAttributes", [])

    @builtins.property # type: ignore
    @jsii.member(jsii_name="location")
    def location(self) -> builtins.str:
        return jsii.get(self, "location")

    @location.setter # type: ignore
    def location(self, value: builtins.str) -> None:
        jsii.set(self, "location", value)

    @builtins.property # type: ignore
    @jsii.member(jsii_name="name")
    def name(self) -> builtins.str:
        return jsii.get(self, "name")

    @name.setter # type: ignore
    def name(self, value: builtins.str) -> None:
        jsii.set(self, "name", value)

    @builtins.property # type: ignore
    @jsii.member(jsii_name="resourceGroupName")
    def resource_group_name(self) -> builtins.str:
        return jsii.get(self, "resourceGroupName")

    @resource_group_name.setter # type: ignore
    def resource_group_name(self, value: builtins.str) -> None:
        jsii.set(self, "resourceGroupName", value)

    @builtins.property # type: ignore
    @jsii.member(jsii_name="id")
    def id(self) -> typing.Optional[builtins.str]:
        return jsii.get(self, "id")

    @id.setter # type: ignore
    def id(self, value: typing.Optional[builtins.str]) -> None:
        jsii.set(self, "id", value)

    @builtins.property # type: ignore
    @jsii.member(jsii_name="tags")
    def tags(self) -> typing.Optional[typing.Mapping[builtins.str, builtins.str]]:
        return jsii.get(self, "tags")

    @tags.setter # type: ignore
    def tags(
        self,
        value: typing.Optional[typing.Mapping[builtins.str, builtins.str]],
    ) -> None:
        jsii.set(self, "tags", value)

    @builtins.property # type: ignore
    @jsii.member(jsii_name="timeouts")
    def timeouts(self) -> typing.Optional["NetworkWatcherTimeouts"]:
        return jsii.get(self, "timeouts")

    @timeouts.setter # type: ignore
    def timeouts(self, value: typing.Optional["NetworkWatcherTimeouts"]) -> None:
        jsii.set(self, "timeouts", value)


@jsii.data_type(
    jsii_type="@cdktf/provider-azurerm.NetworkWatcherConfig",
    jsii_struct_bases=[cdktf.TerraformMetaArguments],
    name_mapping={
        "count": "count",
        "depends_on": "dependsOn",
        "lifecycle": "lifecycle",
        "provider": "provider",
        "location": "location",
        "name": "name",
        "resource_group_name": "resourceGroupName",
        "tags": "tags",
        "timeouts": "timeouts",
    },
)
class NetworkWatcherConfig(cdktf.TerraformMetaArguments):
    def __init__(
        self,
        *,
        count: typing.Optional[jsii.Number] = None,
        depends_on: typing.Optional[typing.List[cdktf.TerraformResource]] = None,
        lifecycle: typing.Optional[cdktf.TerraformResourceLifecycle] = None,
        provider: typing.Optional[cdktf.TerraformProvider] = None,
        location: builtins.str,
        name: builtins.str,
        resource_group_name: builtins.str,
        tags: typing.Optional[typing.Mapping[builtins.str, builtins.str]] = None,
        timeouts: typing.Optional["NetworkWatcherTimeouts"] = None,
    ) -> None:
        """
        :param count: 
        :param depends_on: 
        :param lifecycle: 
        :param provider: 
        :param location: 
        :param name: 
        :param resource_group_name: 
        :param tags: 
        :param timeouts: timeouts block.
        """
        if isinstance(lifecycle, dict):
            lifecycle = cdktf.TerraformResourceLifecycle(**lifecycle)
        if isinstance(timeouts, dict):
            timeouts = NetworkWatcherTimeouts(**timeouts)
        self._values: typing.Dict[str, typing.Any] = {
            "location": location,
            "name": name,
            "resource_group_name": resource_group_name,
        }
        if count is not None:
            self._values["count"] = count
        if depends_on is not None:
            self._values["depends_on"] = depends_on
        if lifecycle is not None:
            self._values["lifecycle"] = lifecycle
        if provider is not None:
            self._values["provider"] = provider
        if tags is not None:
            self._values["tags"] = tags
        if timeouts is not None:
            self._values["timeouts"] = timeouts

    @builtins.property
    def count(self) -> typing.Optional[jsii.Number]:
        """
        :stability: experimental
        """
        result = self._values.get("count")
        return result

    @builtins.property
    def depends_on(self) -> typing.Optional[typing.List[cdktf.TerraformResource]]:
        """
        :stability: experimental
        """
        result = self._values.get("depends_on")
        return result

    @builtins.property
    def lifecycle(self) -> typing.Optional[cdktf.TerraformResourceLifecycle]:
        """
        :stability: experimental
        """
        result = self._values.get("lifecycle")
        return result

    @builtins.property
    def provider(self) -> typing.Optional[cdktf.TerraformProvider]:
        """
        :stability: experimental
        """
        result = self._values.get("provider")
        return result

    @builtins.property
    def location(self) -> builtins.str:
        result = self._values.get("location")
        assert result is not None, "Required property 'location' is missing"
        return result

    @builtins.property
    def name(self) -> builtins.str:
        result = self._values.get("name")
        assert result is not None, "Required property 'name' is missing"
        return result

    @builtins.property
    def resource_group_name(self) -> builtins.str:
        result = self._values.get("resource_group_name")
        assert result is not None, "Required property 'resource_group_name' is missing"
        return result

    @builtins.property
    def tags(self) -> typing.Optional[typing.Mapping[builtins.str, builtins.str]]:
        result = self._values.get("tags")
        return result

    @builtins.property
    def timeouts(self) -> typing.Optional["NetworkWatcherTimeouts"]:
        """timeouts block."""
        result = self._values.get("timeouts")
        return result

    def __eq__(self, rhs: typing.Any) -> builtins.bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs: typing.Any) -> builtins.bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return "NetworkWatcherConfig(%s)" % ", ".join(
            k + "=" + repr(v) for k, v in self._values.items()
        )


class NetworkWatcherFlowLog(
    cdktf.TerraformResource,
    metaclass=jsii.JSIIMeta,
    jsii_type="@cdktf/provider-azurerm.NetworkWatcherFlowLog",
):
    def __init__(
        self,
        scope: constructs.Construct,
        id: builtins.str,
        *,
        enabled: builtins.bool,
        network_security_group_id: builtins.str,
        network_watcher_name: builtins.str,
        resource_group_name: builtins.str,
        retention_policy: typing.List["NetworkWatcherFlowLogRetentionPolicy"],
        storage_account_id: builtins.str,
        timeouts: typing.Optional["NetworkWatcherFlowLogTimeouts"] = None,
        traffic_analytics: typing.Optional[typing.List["NetworkWatcherFlowLogTrafficAnalytics"]] = None,
        version: typing.Optional[jsii.Number] = None,
        count: typing.Optional[jsii.Number] = None,
        depends_on: typing.Optional[typing.List[cdktf.TerraformResource]] = None,
        lifecycle: typing.Optional[cdktf.TerraformResourceLifecycle] = None,
        provider: typing.Optional[cdktf.TerraformProvider] = None,
    ) -> None:
        """
        :param scope: -
        :param id: -
        :param enabled: 
        :param network_security_group_id: 
        :param network_watcher_name: 
        :param resource_group_name: 
        :param retention_policy: retention_policy block.
        :param storage_account_id: 
        :param timeouts: timeouts block.
        :param traffic_analytics: traffic_analytics block.
        :param version: 
        :param count: 
        :param depends_on: 
        :param lifecycle: 
        :param provider: 
        """
        config = NetworkWatcherFlowLogConfig(
            enabled=enabled,
            network_security_group_id=network_security_group_id,
            network_watcher_name=network_watcher_name,
            resource_group_name=resource_group_name,
            retention_policy=retention_policy,
            storage_account_id=storage_account_id,
            timeouts=timeouts,
            traffic_analytics=traffic_analytics,
            version=version,
            count=count,
            depends_on=depends_on,
            lifecycle=lifecycle,
            provider=provider,
        )

        jsii.create(NetworkWatcherFlowLog, self, [scope, id, config])

    @jsii.member(jsii_name="synthesizeAttributes")
    def _synthesize_attributes(self) -> typing.Mapping[builtins.str, typing.Any]:
        return jsii.invoke(self, "synthesizeAttributes", [])

    @builtins.property # type: ignore
    @jsii.member(jsii_name="enabled")
    def enabled(self) -> builtins.bool:
        return jsii.get(self, "enabled")

    @enabled.setter # type: ignore
    def enabled(self, value: builtins.bool) -> None:
        jsii.set(self, "enabled", value)

    @builtins.property # type: ignore
    @jsii.member(jsii_name="networkSecurityGroupId")
    def network_security_group_id(self) -> builtins.str:
        return jsii.get(self, "networkSecurityGroupId")

    @network_security_group_id.setter # type: ignore
    def network_security_group_id(self, value: builtins.str) -> None:
        jsii.set(self, "networkSecurityGroupId", value)

    @builtins.property # type: ignore
    @jsii.member(jsii_name="networkWatcherName")
    def network_watcher_name(self) -> builtins.str:
        return jsii.get(self, "networkWatcherName")

    @network_watcher_name.setter # type: ignore
    def network_watcher_name(self, value: builtins.str) -> None:
        jsii.set(self, "networkWatcherName", value)

    @builtins.property # type: ignore
    @jsii.member(jsii_name="resourceGroupName")
    def resource_group_name(self) -> builtins.str:
        return jsii.get(self, "resourceGroupName")

    @resource_group_name.setter # type: ignore
    def resource_group_name(self, value: builtins.str) -> None:
        jsii.set(self, "resourceGroupName", value)

    @builtins.property # type: ignore
    @jsii.member(jsii_name="retentionPolicy")
    def retention_policy(self) -> typing.List["NetworkWatcherFlowLogRetentionPolicy"]:
        return jsii.get(self, "retentionPolicy")

    @retention_policy.setter # type: ignore
    def retention_policy(
        self,
        value: typing.List["NetworkWatcherFlowLogRetentionPolicy"],
    ) -> None:
        jsii.set(self, "retentionPolicy", value)

    @builtins.property # type: ignore
    @jsii.member(jsii_name="storageAccountId")
    def storage_account_id(self) -> builtins.str:
        return jsii.get(self, "storageAccountId")

    @storage_account_id.setter # type: ignore
    def storage_account_id(self, value: builtins.str) -> None:
        jsii.set(self, "storageAccountId", value)

    @builtins.property # type: ignore
    @jsii.member(jsii_name="id")
    def id(self) -> typing.Optional[builtins.str]:
        return jsii.get(self, "id")

    @id.setter # type: ignore
    def id(self, value: typing.Optional[builtins.str]) -> None:
        jsii.set(self, "id", value)

    @builtins.property # type: ignore
    @jsii.member(jsii_name="timeouts")
    def timeouts(self) -> typing.Optional["NetworkWatcherFlowLogTimeouts"]:
        return jsii.get(self, "timeouts")

    @timeouts.setter # type: ignore
    def timeouts(self, value: typing.Optional["NetworkWatcherFlowLogTimeouts"]) -> None:
        jsii.set(self, "timeouts", value)

    @builtins.property # type: ignore
    @jsii.member(jsii_name="trafficAnalytics")
    def traffic_analytics(
        self,
    ) -> typing.Optional[typing.List["NetworkWatcherFlowLogTrafficAnalytics"]]:
        return jsii.get(self, "trafficAnalytics")

    @traffic_analytics.setter # type: ignore
    def traffic_analytics(
        self,
        value: typing.Optional[typing.List["NetworkWatcherFlowLogTrafficAnalytics"]],
    ) -> None:
        jsii.set(self, "trafficAnalytics", value)

    @builtins.property # type: ignore
    @jsii.member(jsii_name="version")
    def version(self) -> typing.Optional[jsii.Number]:
        return jsii.get(self, "version")

    @version.setter # type: ignore
    def version(self, value: typing.Optional[jsii.Number]) -> None:
        jsii.set(self, "version", value)


@jsii.data_type(
    jsii_type="@cdktf/provider-azurerm.NetworkWatcherFlowLogConfig",
    jsii_struct_bases=[cdktf.TerraformMetaArguments],
    name_mapping={
        "count": "count",
        "depends_on": "dependsOn",
        "lifecycle": "lifecycle",
        "provider": "provider",
        "enabled": "enabled",
        "network_security_group_id": "networkSecurityGroupId",
        "network_watcher_name": "networkWatcherName",
        "resource_group_name": "resourceGroupName",
        "retention_policy": "retentionPolicy",
        "storage_account_id": "storageAccountId",
        "timeouts": "timeouts",
        "traffic_analytics": "trafficAnalytics",
        "version": "version",
    },
)
class NetworkWatcherFlowLogConfig(cdktf.TerraformMetaArguments):
    def __init__(
        self,
        *,
        count: typing.Optional[jsii.Number] = None,
        depends_on: typing.Optional[typing.List[cdktf.TerraformResource]] = None,
        lifecycle: typing.Optional[cdktf.TerraformResourceLifecycle] = None,
        provider: typing.Optional[cdktf.TerraformProvider] = None,
        enabled: builtins.bool,
        network_security_group_id: builtins.str,
        network_watcher_name: builtins.str,
        resource_group_name: builtins.str,
        retention_policy: typing.List["NetworkWatcherFlowLogRetentionPolicy"],
        storage_account_id: builtins.str,
        timeouts: typing.Optional["NetworkWatcherFlowLogTimeouts"] = None,
        traffic_analytics: typing.Optional[typing.List["NetworkWatcherFlowLogTrafficAnalytics"]] = None,
        version: typing.Optional[jsii.Number] = None,
    ) -> None:
        """
        :param count: 
        :param depends_on: 
        :param lifecycle: 
        :param provider: 
        :param enabled: 
        :param network_security_group_id: 
        :param network_watcher_name: 
        :param resource_group_name: 
        :param retention_policy: retention_policy block.
        :param storage_account_id: 
        :param timeouts: timeouts block.
        :param traffic_analytics: traffic_analytics block.
        :param version: 
        """
        if isinstance(lifecycle, dict):
            lifecycle = cdktf.TerraformResourceLifecycle(**lifecycle)
        if isinstance(timeouts, dict):
            timeouts = NetworkWatcherFlowLogTimeouts(**timeouts)
        self._values: typing.Dict[str, typing.Any] = {
            "enabled": enabled,
            "network_security_group_id": network_security_group_id,
            "network_watcher_name": network_watcher_name,
            "resource_group_name": resource_group_name,
            "retention_policy": retention_policy,
            "storage_account_id": storage_account_id,
        }
        if count is not None:
            self._values["count"] = count
        if depends_on is not None:
            self._values["depends_on"] = depends_on
        if lifecycle is not None:
            self._values["lifecycle"] = lifecycle
        if provider is not None:
            self._values["provider"] = provider
        if timeouts is not None:
            self._values["timeouts"] = timeouts
        if traffic_analytics is not None:
            self._values["traffic_analytics"] = traffic_analytics
        if version is not None:
            self._values["version"] = version

    @builtins.property
    def count(self) -> typing.Optional[jsii.Number]:
        """
        :stability: experimental
        """
        result = self._values.get("count")
        return result

    @builtins.property
    def depends_on(self) -> typing.Optional[typing.List[cdktf.TerraformResource]]:
        """
        :stability: experimental
        """
        result = self._values.get("depends_on")
        return result

    @builtins.property
    def lifecycle(self) -> typing.Optional[cdktf.TerraformResourceLifecycle]:
        """
        :stability: experimental
        """
        result = self._values.get("lifecycle")
        return result

    @builtins.property
    def provider(self) -> typing.Optional[cdktf.TerraformProvider]:
        """
        :stability: experimental
        """
        result = self._values.get("provider")
        return result

    @builtins.property
    def enabled(self) -> builtins.bool:
        result = self._values.get("enabled")
        assert result is not None, "Required property 'enabled' is missing"
        return result

    @builtins.property
    def network_security_group_id(self) -> builtins.str:
        result = self._values.get("network_security_group_id")
        assert result is not None, "Required property 'network_security_group_id' is missing"
        return result

    @builtins.property
    def network_watcher_name(self) -> builtins.str:
        result = self._values.get("network_watcher_name")
        assert result is not None, "Required property 'network_watcher_name' is missing"
        return result

    @builtins.property
    def resource_group_name(self) -> builtins.str:
        result = self._values.get("resource_group_name")
        assert result is not None, "Required property 'resource_group_name' is missing"
        return result

    @builtins.property
    def retention_policy(self) -> typing.List["NetworkWatcherFlowLogRetentionPolicy"]:
        """retention_policy block."""
        result = self._values.get("retention_policy")
        assert result is not None, "Required property 'retention_policy' is missing"
        return result

    @builtins.property
    def storage_account_id(self) -> builtins.str:
        result = self._values.get("storage_account_id")
        assert result is not None, "Required property 'storage_account_id' is missing"
        return result

    @builtins.property
    def timeouts(self) -> typing.Optional["NetworkWatcherFlowLogTimeouts"]:
        """timeouts block."""
        result = self._values.get("timeouts")
        return result

    @builtins.property
    def traffic_analytics(
        self,
    ) -> typing.Optional[typing.List["NetworkWatcherFlowLogTrafficAnalytics"]]:
        """traffic_analytics block."""
        result = self._values.get("traffic_analytics")
        return result

    @builtins.property
    def version(self) -> typing.Optional[jsii.Number]:
        result = self._values.get("version")
        return result

    def __eq__(self, rhs: typing.Any) -> builtins.bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs: typing.Any) -> builtins.bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return "NetworkWatcherFlowLogConfig(%s)" % ", ".join(
            k + "=" + repr(v) for k, v in self._values.items()
        )


@jsii.data_type(
    jsii_type="@cdktf/provider-azurerm.NetworkWatcherFlowLogRetentionPolicy",
    jsii_struct_bases=[],
    name_mapping={"days": "days", "enabled": "enabled"},
)
class NetworkWatcherFlowLogRetentionPolicy:
    def __init__(self, *, days: jsii.Number, enabled: builtins.bool) -> None:
        """
        :param days: 
        :param enabled: 
        """
        self._values: typing.Dict[str, typing.Any] = {
            "days": days,
            "enabled": enabled,
        }

    @builtins.property
    def days(self) -> jsii.Number:
        result = self._values.get("days")
        assert result is not None, "Required property 'days' is missing"
        return result

    @builtins.property
    def enabled(self) -> builtins.bool:
        result = self._values.get("enabled")
        assert result is not None, "Required property 'enabled' is missing"
        return result

    def __eq__(self, rhs: typing.Any) -> builtins.bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs: typing.Any) -> builtins.bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return "NetworkWatcherFlowLogRetentionPolicy(%s)" % ", ".join(
            k + "=" + repr(v) for k, v in self._values.items()
        )


@jsii.data_type(
    jsii_type="@cdktf/provider-azurerm.NetworkWatcherFlowLogTimeouts",
    jsii_struct_bases=[],
    name_mapping={
        "create": "create",
        "delete": "delete",
        "read": "read",
        "update": "update",
    },
)
class NetworkWatcherFlowLogTimeouts:
    def __init__(
        self,
        *,
        create: typing.Optional[builtins.str] = None,
        delete: typing.Optional[builtins.str] = None,
        read: typing.Optional[builtins.str] = None,
        update: typing.Optional[builtins.str] = None,
    ) -> None:
        """
        :param create: 
        :param delete: 
        :param read: 
        :param update: 
        """
        self._values: typing.Dict[str, typing.Any] = {}
        if create is not None:
            self._values["create"] = create
        if delete is not None:
            self._values["delete"] = delete
        if read is not None:
            self._values["read"] = read
        if update is not None:
            self._values["update"] = update

    @builtins.property
    def create(self) -> typing.Optional[builtins.str]:
        result = self._values.get("create")
        return result

    @builtins.property
    def delete(self) -> typing.Optional[builtins.str]:
        result = self._values.get("delete")
        return result

    @builtins.property
    def read(self) -> typing.Optional[builtins.str]:
        result = self._values.get("read")
        return result

    @builtins.property
    def update(self) -> typing.Optional[builtins.str]:
        result = self._values.get("update")
        return result

    def __eq__(self, rhs: typing.Any) -> builtins.bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs: typing.Any) -> builtins.bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return "NetworkWatcherFlowLogTimeouts(%s)" % ", ".join(
            k + "=" + repr(v) for k, v in self._values.items()
        )


@jsii.data_type(
    jsii_type="@cdktf/provider-azurerm.NetworkWatcherFlowLogTrafficAnalytics",
    jsii_struct_bases=[],
    name_mapping={
        "enabled": "enabled",
        "workspace_id": "workspaceId",
        "workspace_region": "workspaceRegion",
        "workspace_resource_id": "workspaceResourceId",
    },
)
class NetworkWatcherFlowLogTrafficAnalytics:
    def __init__(
        self,
        *,
        enabled: builtins.bool,
        workspace_id: builtins.str,
        workspace_region: builtins.str,
        workspace_resource_id: builtins.str,
    ) -> None:
        """
        :param enabled: 
        :param workspace_id: 
        :param workspace_region: 
        :param workspace_resource_id: 
        """
        self._values: typing.Dict[str, typing.Any] = {
            "enabled": enabled,
            "workspace_id": workspace_id,
            "workspace_region": workspace_region,
            "workspace_resource_id": workspace_resource_id,
        }

    @builtins.property
    def enabled(self) -> builtins.bool:
        result = self._values.get("enabled")
        assert result is not None, "Required property 'enabled' is missing"
        return result

    @builtins.property
    def workspace_id(self) -> builtins.str:
        result = self._values.get("workspace_id")
        assert result is not None, "Required property 'workspace_id' is missing"
        return result

    @builtins.property
    def workspace_region(self) -> builtins.str:
        result = self._values.get("workspace_region")
        assert result is not None, "Required property 'workspace_region' is missing"
        return result

    @builtins.property
    def workspace_resource_id(self) -> builtins.str:
        result = self._values.get("workspace_resource_id")
        assert result is not None, "Required property 'workspace_resource_id' is missing"
        return result

    def __eq__(self, rhs: typing.Any) -> builtins.bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs: typing.Any) -> builtins.bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return "NetworkWatcherFlowLogTrafficAnalytics(%s)" % ", ".join(
            k + "=" + repr(v) for k, v in self._values.items()
        )


@jsii.data_type(
    jsii_type="@cdktf/provider-azurerm.NetworkWatcherTimeouts",
    jsii_struct_bases=[],
    name_mapping={
        "create": "create",
        "delete": "delete",
        "read": "read",
        "update": "update",
    },
)
class NetworkWatcherTimeouts:
    def __init__(
        self,
        *,
        create: typing.Optional[builtins.str] = None,
        delete: typing.Optional[builtins.str] = None,
        read: typing.Optional[builtins.str] = None,
        update: typing.Optional[builtins.str] = None,
    ) -> None:
        """
        :param create: 
        :param delete: 
        :param read: 
        :param update: 
        """
        self._values: typing.Dict[str, typing.Any] = {}
        if create is not None:
            self._values["create"] = create
        if delete is not None:
            self._values["delete"] = delete
        if read is not None:
            self._values["read"] = read
        if update is not None:
            self._values["update"] = update

    @builtins.property
    def create(self) -> typing.Optional[builtins.str]:
        result = self._values.get("create")
        return result

    @builtins.property
    def delete(self) -> typing.Optional[builtins.str]:
        result = self._values.get("delete")
        return result

    @builtins.property
    def read(self) -> typing.Optional[builtins.str]:
        result = self._values.get("read")
        return result

    @builtins.property
    def update(self) -> typing.Optional[builtins.str]:
        result = self._values.get("update")
        return result

    def __eq__(self, rhs: typing.Any) -> builtins.bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs: typing.Any) -> builtins.bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return "NetworkWatcherTimeouts(%s)" % ", ".join(
            k + "=" + repr(v) for k, v in self._values.items()
        )


class NotificationHub(
    cdktf.TerraformResource,
    metaclass=jsii.JSIIMeta,
    jsii_type="@cdktf/provider-azurerm.NotificationHub",
):
    def __init__(
        self,
        scope: constructs.Construct,
        id: builtins.str,
        *,
        location: builtins.str,
        name: builtins.str,
        namespace_name: builtins.str,
        resource_group_name: builtins.str,
        apns_credential: typing.Optional[typing.List["NotificationHubApnsCredential"]] = None,
        gcm_credential: typing.Optional[typing.List["NotificationHubGcmCredential"]] = None,
        timeouts: typing.Optional["NotificationHubTimeouts"] = None,
        count: typing.Optional[jsii.Number] = None,
        depends_on: typing.Optional[typing.List[cdktf.TerraformResource]] = None,
        lifecycle: typing.Optional[cdktf.TerraformResourceLifecycle] = None,
        provider: typing.Optional[cdktf.TerraformProvider] = None,
    ) -> None:
        """
        :param scope: -
        :param id: -
        :param location: 
        :param name: 
        :param namespace_name: 
        :param resource_group_name: 
        :param apns_credential: apns_credential block.
        :param gcm_credential: gcm_credential block.
        :param timeouts: timeouts block.
        :param count: 
        :param depends_on: 
        :param lifecycle: 
        :param provider: 
        """
        config = NotificationHubConfig(
            location=location,
            name=name,
            namespace_name=namespace_name,
            resource_group_name=resource_group_name,
            apns_credential=apns_credential,
            gcm_credential=gcm_credential,
            timeouts=timeouts,
            count=count,
            depends_on=depends_on,
            lifecycle=lifecycle,
            provider=provider,
        )

        jsii.create(NotificationHub, self, [scope, id, config])

    @jsii.member(jsii_name="synthesizeAttributes")
    def _synthesize_attributes(self) -> typing.Mapping[builtins.str, typing.Any]:
        return jsii.invoke(self, "synthesizeAttributes", [])

    @builtins.property # type: ignore
    @jsii.member(jsii_name="location")
    def location(self) -> builtins.str:
        return jsii.get(self, "location")

    @location.setter # type: ignore
    def location(self, value: builtins.str) -> None:
        jsii.set(self, "location", value)

    @builtins.property # type: ignore
    @jsii.member(jsii_name="name")
    def name(self) -> builtins.str:
        return jsii.get(self, "name")

    @name.setter # type: ignore
    def name(self, value: builtins.str) -> None:
        jsii.set(self, "name", value)

    @builtins.property # type: ignore
    @jsii.member(jsii_name="namespaceName")
    def namespace_name(self) -> builtins.str:
        return jsii.get(self, "namespaceName")

    @namespace_name.setter # type: ignore
    def namespace_name(self, value: builtins.str) -> None:
        jsii.set(self, "namespaceName", value)

    @builtins.property # type: ignore
    @jsii.member(jsii_name="resourceGroupName")
    def resource_group_name(self) -> builtins.str:
        return jsii.get(self, "resourceGroupName")

    @resource_group_name.setter # type: ignore
    def resource_group_name(self, value: builtins.str) -> None:
        jsii.set(self, "resourceGroupName", value)

    @builtins.property # type: ignore
    @jsii.member(jsii_name="apnsCredential")
    def apns_credential(
        self,
    ) -> typing.Optional[typing.List["NotificationHubApnsCredential"]]:
        return jsii.get(self, "apnsCredential")

    @apns_credential.setter # type: ignore
    def apns_credential(
        self,
        value: typing.Optional[typing.List["NotificationHubApnsCredential"]],
    ) -> None:
        jsii.set(self, "apnsCredential", value)

    @builtins.property # type: ignore
    @jsii.member(jsii_name="gcmCredential")
    def gcm_credential(
        self,
    ) -> typing.Optional[typing.List["NotificationHubGcmCredential"]]:
        return jsii.get(self, "gcmCredential")

    @gcm_credential.setter # type: ignore
    def gcm_credential(
        self,
        value: typing.Optional[typing.List["NotificationHubGcmCredential"]],
    ) -> None:
        jsii.set(self, "gcmCredential", value)

    @builtins.property # type: ignore
    @jsii.member(jsii_name="id")
    def id(self) -> typing.Optional[builtins.str]:
        return jsii.get(self, "id")

    @id.setter # type: ignore
    def id(self, value: typing.Optional[builtins.str]) -> None:
        jsii.set(self, "id", value)

    @builtins.property # type: ignore
    @jsii.member(jsii_name="timeouts")
    def timeouts(self) -> typing.Optional["NotificationHubTimeouts"]:
        return jsii.get(self, "timeouts")

    @timeouts.setter # type: ignore
    def timeouts(self, value: typing.Optional["NotificationHubTimeouts"]) -> None:
        jsii.set(self, "timeouts", value)


@jsii.data_type(
    jsii_type="@cdktf/provider-azurerm.NotificationHubApnsCredential",
    jsii_struct_bases=[],
    name_mapping={
        "application_mode": "applicationMode",
        "bundle_id": "bundleId",
        "key_id": "keyId",
        "team_id": "teamId",
        "token": "token",
    },
)
class NotificationHubApnsCredential:
    def __init__(
        self,
        *,
        application_mode: builtins.str,
        bundle_id: builtins.str,
        key_id: builtins.str,
        team_id: builtins.str,
        token: builtins.str,
    ) -> None:
        """
        :param application_mode: 
        :param bundle_id: 
        :param key_id: 
        :param team_id: 
        :param token: 
        """
        self._values: typing.Dict[str, typing.Any] = {
            "application_mode": application_mode,
            "bundle_id": bundle_id,
            "key_id": key_id,
            "team_id": team_id,
            "token": token,
        }

    @builtins.property
    def application_mode(self) -> builtins.str:
        result = self._values.get("application_mode")
        assert result is not None, "Required property 'application_mode' is missing"
        return result

    @builtins.property
    def bundle_id(self) -> builtins.str:
        result = self._values.get("bundle_id")
        assert result is not None, "Required property 'bundle_id' is missing"
        return result

    @builtins.property
    def key_id(self) -> builtins.str:
        result = self._values.get("key_id")
        assert result is not None, "Required property 'key_id' is missing"
        return result

    @builtins.property
    def team_id(self) -> builtins.str:
        result = self._values.get("team_id")
        assert result is not None, "Required property 'team_id' is missing"
        return result

    @builtins.property
    def token(self) -> builtins.str:
        result = self._values.get("token")
        assert result is not None, "Required property 'token' is missing"
        return result

    def __eq__(self, rhs: typing.Any) -> builtins.bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs: typing.Any) -> builtins.bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return "NotificationHubApnsCredential(%s)" % ", ".join(
            k + "=" + repr(v) for k, v in self._values.items()
        )


class NotificationHubAuthorizationRule(
    cdktf.TerraformResource,
    metaclass=jsii.JSIIMeta,
    jsii_type="@cdktf/provider-azurerm.NotificationHubAuthorizationRule",
):
    def __init__(
        self,
        scope: constructs.Construct,
        id: builtins.str,
        *,
        name: builtins.str,
        namespace_name: builtins.str,
        notification_hub_name: builtins.str,
        resource_group_name: builtins.str,
        listen: typing.Optional[builtins.bool] = None,
        manage: typing.Optional[builtins.bool] = None,
        send: typing.Optional[builtins.bool] = None,
        timeouts: typing.Optional["NotificationHubAuthorizationRuleTimeouts"] = None,
        count: typing.Optional[jsii.Number] = None,
        depends_on: typing.Optional[typing.List[cdktf.TerraformResource]] = None,
        lifecycle: typing.Optional[cdktf.TerraformResourceLifecycle] = None,
        provider: typing.Optional[cdktf.TerraformProvider] = None,
    ) -> None:
        """
        :param scope: -
        :param id: -
        :param name: 
        :param namespace_name: 
        :param notification_hub_name: 
        :param resource_group_name: 
        :param listen: 
        :param manage: 
        :param send: 
        :param timeouts: timeouts block.
        :param count: 
        :param depends_on: 
        :param lifecycle: 
        :param provider: 
        """
        config = NotificationHubAuthorizationRuleConfig(
            name=name,
            namespace_name=namespace_name,
            notification_hub_name=notification_hub_name,
            resource_group_name=resource_group_name,
            listen=listen,
            manage=manage,
            send=send,
            timeouts=timeouts,
            count=count,
            depends_on=depends_on,
            lifecycle=lifecycle,
            provider=provider,
        )

        jsii.create(NotificationHubAuthorizationRule, self, [scope, id, config])

    @jsii.member(jsii_name="synthesizeAttributes")
    def _synthesize_attributes(self) -> typing.Mapping[builtins.str, typing.Any]:
        return jsii.invoke(self, "synthesizeAttributes", [])

    @builtins.property # type: ignore
    @jsii.member(jsii_name="primaryAccessKey")
    def primary_access_key(self) -> builtins.str:
        return jsii.get(self, "primaryAccessKey")

    @builtins.property # type: ignore
    @jsii.member(jsii_name="secondaryAccessKey")
    def secondary_access_key(self) -> builtins.str:
        return jsii.get(self, "secondaryAccessKey")

    @builtins.property # type: ignore
    @jsii.member(jsii_name="name")
    def name(self) -> builtins.str:
        return jsii.get(self, "name")

    @name.setter # type: ignore
    def name(self, value: builtins.str) -> None:
        jsii.set(self, "name", value)

    @builtins.property # type: ignore
    @jsii.member(jsii_name="namespaceName")
    def namespace_name(self) -> builtins.str:
        return jsii.get(self, "namespaceName")

    @namespace_name.setter # type: ignore
    def namespace_name(self, value: builtins.str) -> None:
        jsii.set(self, "namespaceName", value)

    @builtins.property # type: ignore
    @jsii.member(jsii_name="notificationHubName")
    def notification_hub_name(self) -> builtins.str:
        return jsii.get(self, "notificationHubName")

    @notification_hub_name.setter # type: ignore
    def notification_hub_name(self, value: builtins.str) -> None:
        jsii.set(self, "notificationHubName", value)

    @builtins.property # type: ignore
    @jsii.member(jsii_name="resourceGroupName")
    def resource_group_name(self) -> builtins.str:
        return jsii.get(self, "resourceGroupName")

    @resource_group_name.setter # type: ignore
    def resource_group_name(self, value: builtins.str) -> None:
        jsii.set(self, "resourceGroupName", value)

    @builtins.property # type: ignore
    @jsii.member(jsii_name="id")
    def id(self) -> typing.Optional[builtins.str]:
        return jsii.get(self, "id")

    @id.setter # type: ignore
    def id(self, value: typing.Optional[builtins.str]) -> None:
        jsii.set(self, "id", value)

    @builtins.property # type: ignore
    @jsii.member(jsii_name="listen")
    def listen(self) -> typing.Optional[builtins.bool]:
        return jsii.get(self, "listen")

    @listen.setter # type: ignore
    def listen(self, value: typing.Optional[builtins.bool]) -> None:
        jsii.set(self, "listen", value)

    @builtins.property # type: ignore
    @jsii.member(jsii_name="manage")
    def manage(self) -> typing.Optional[builtins.bool]:
        return jsii.get(self, "manage")

    @manage.setter # type: ignore
    def manage(self, value: typing.Optional[builtins.bool]) -> None:
        jsii.set(self, "manage", value)

    @builtins.property # type: ignore
    @jsii.member(jsii_name="send")
    def send(self) -> typing.Optional[builtins.bool]:
        return jsii.get(self, "send")

    @send.setter # type: ignore
    def send(self, value: typing.Optional[builtins.bool]) -> None:
        jsii.set(self, "send", value)

    @builtins.property # type: ignore
    @jsii.member(jsii_name="timeouts")
    def timeouts(self) -> typing.Optional["NotificationHubAuthorizationRuleTimeouts"]:
        return jsii.get(self, "timeouts")

    @timeouts.setter # type: ignore
    def timeouts(
        self,
        value: typing.Optional["NotificationHubAuthorizationRuleTimeouts"],
    ) -> None:
        jsii.set(self, "timeouts", value)


@jsii.data_type(
    jsii_type="@cdktf/provider-azurerm.NotificationHubAuthorizationRuleConfig",
    jsii_struct_bases=[cdktf.TerraformMetaArguments],
    name_mapping={
        "count": "count",
        "depends_on": "dependsOn",
        "lifecycle": "lifecycle",
        "provider": "provider",
        "name": "name",
        "namespace_name": "namespaceName",
        "notification_hub_name": "notificationHubName",
        "resource_group_name": "resourceGroupName",
        "listen": "listen",
        "manage": "manage",
        "send": "send",
        "timeouts": "timeouts",
    },
)
class NotificationHubAuthorizationRuleConfig(cdktf.TerraformMetaArguments):
    def __init__(
        self,
        *,
        count: typing.Optional[jsii.Number] = None,
        depends_on: typing.Optional[typing.List[cdktf.TerraformResource]] = None,
        lifecycle: typing.Optional[cdktf.TerraformResourceLifecycle] = None,
        provider: typing.Optional[cdktf.TerraformProvider] = None,
        name: builtins.str,
        namespace_name: builtins.str,
        notification_hub_name: builtins.str,
        resource_group_name: builtins.str,
        listen: typing.Optional[builtins.bool] = None,
        manage: typing.Optional[builtins.bool] = None,
        send: typing.Optional[builtins.bool] = None,
        timeouts: typing.Optional["NotificationHubAuthorizationRuleTimeouts"] = None,
    ) -> None:
        """
        :param count: 
        :param depends_on: 
        :param lifecycle: 
        :param provider: 
        :param name: 
        :param namespace_name: 
        :param notification_hub_name: 
        :param resource_group_name: 
        :param listen: 
        :param manage: 
        :param send: 
        :param timeouts: timeouts block.
        """
        if isinstance(lifecycle, dict):
            lifecycle = cdktf.TerraformResourceLifecycle(**lifecycle)
        if isinstance(timeouts, dict):
            timeouts = NotificationHubAuthorizationRuleTimeouts(**timeouts)
        self._values: typing.Dict[str, typing.Any] = {
            "name": name,
            "namespace_name": namespace_name,
            "notification_hub_name": notification_hub_name,
            "resource_group_name": resource_group_name,
        }
        if count is not None:
            self._values["count"] = count
        if depends_on is not None:
            self._values["depends_on"] = depends_on
        if lifecycle is not None:
            self._values["lifecycle"] = lifecycle
        if provider is not None:
            self._values["provider"] = provider
        if listen is not None:
            self._values["listen"] = listen
        if manage is not None:
            self._values["manage"] = manage
        if send is not None:
            self._values["send"] = send
        if timeouts is not None:
            self._values["timeouts"] = timeouts

    @builtins.property
    def count(self) -> typing.Optional[jsii.Number]:
        """
        :stability: experimental
        """
        result = self._values.get("count")
        return result

    @builtins.property
    def depends_on(self) -> typing.Optional[typing.List[cdktf.TerraformResource]]:
        """
        :stability: experimental
        """
        result = self._values.get("depends_on")
        return result

    @builtins.property
    def lifecycle(self) -> typing.Optional[cdktf.TerraformResourceLifecycle]:
        """
        :stability: experimental
        """
        result = self._values.get("lifecycle")
        return result

    @builtins.property
    def provider(self) -> typing.Optional[cdktf.TerraformProvider]:
        """
        :stability: experimental
        """
        result = self._values.get("provider")
        return result

    @builtins.property
    def name(self) -> builtins.str:
        result = self._values.get("name")
        assert result is not None, "Required property 'name' is missing"
        return result

    @builtins.property
    def namespace_name(self) -> builtins.str:
        result = self._values.get("namespace_name")
        assert result is not None, "Required property 'namespace_name' is missing"
        return result

    @builtins.property
    def notification_hub_name(self) -> builtins.str:
        result = self._values.get("notification_hub_name")
        assert result is not None, "Required property 'notification_hub_name' is missing"
        return result

    @builtins.property
    def resource_group_name(self) -> builtins.str:
        result = self._values.get("resource_group_name")
        assert result is not None, "Required property 'resource_group_name' is missing"
        return result

    @builtins.property
    def listen(self) -> typing.Optional[builtins.bool]:
        result = self._values.get("listen")
        return result

    @builtins.property
    def manage(self) -> typing.Optional[builtins.bool]:
        result = self._values.get("manage")
        return result

    @builtins.property
    def send(self) -> typing.Optional[builtins.bool]:
        result = self._values.get("send")
        return result

    @builtins.property
    def timeouts(self) -> typing.Optional["NotificationHubAuthorizationRuleTimeouts"]:
        """timeouts block."""
        result = self._values.get("timeouts")
        return result

    def __eq__(self, rhs: typing.Any) -> builtins.bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs: typing.Any) -> builtins.bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return "NotificationHubAuthorizationRuleConfig(%s)" % ", ".join(
            k + "=" + repr(v) for k, v in self._values.items()
        )


@jsii.data_type(
    jsii_type="@cdktf/provider-azurerm.NotificationHubAuthorizationRuleTimeouts",
    jsii_struct_bases=[],
    name_mapping={
        "create": "create",
        "delete": "delete",
        "read": "read",
        "update": "update",
    },
)
class NotificationHubAuthorizationRuleTimeouts:
    def __init__(
        self,
        *,
        create: typing.Optional[builtins.str] = None,
        delete: typing.Optional[builtins.str] = None,
        read: typing.Optional[builtins.str] = None,
        update: typing.Optional[builtins.str] = None,
    ) -> None:
        """
        :param create: 
        :param delete: 
        :param read: 
        :param update: 
        """
        self._values: typing.Dict[str, typing.Any] = {}
        if create is not None:
            self._values["create"] = create
        if delete is not None:
            self._values["delete"] = delete
        if read is not None:
            self._values["read"] = read
        if update is not None:
            self._values["update"] = update

    @builtins.property
    def create(self) -> typing.Optional[builtins.str]:
        result = self._values.get("create")
        return result

    @builtins.property
    def delete(self) -> typing.Optional[builtins.str]:
        result = self._values.get("delete")
        return result

    @builtins.property
    def read(self) -> typing.Optional[builtins.str]:
        result = self._values.get("read")
        return result

    @builtins.property
    def update(self) -> typing.Optional[builtins.str]:
        result = self._values.get("update")
        return result

    def __eq__(self, rhs: typing.Any) -> builtins.bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs: typing.Any) -> builtins.bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return "NotificationHubAuthorizationRuleTimeouts(%s)" % ", ".join(
            k + "=" + repr(v) for k, v in self._values.items()
        )


@jsii.data_type(
    jsii_type="@cdktf/provider-azurerm.NotificationHubConfig",
    jsii_struct_bases=[cdktf.TerraformMetaArguments],
    name_mapping={
        "count": "count",
        "depends_on": "dependsOn",
        "lifecycle": "lifecycle",
        "provider": "provider",
        "location": "location",
        "name": "name",
        "namespace_name": "namespaceName",
        "resource_group_name": "resourceGroupName",
        "apns_credential": "apnsCredential",
        "gcm_credential": "gcmCredential",
        "timeouts": "timeouts",
    },
)
class NotificationHubConfig(cdktf.TerraformMetaArguments):
    def __init__(
        self,
        *,
        count: typing.Optional[jsii.Number] = None,
        depends_on: typing.Optional[typing.List[cdktf.TerraformResource]] = None,
        lifecycle: typing.Optional[cdktf.TerraformResourceLifecycle] = None,
        provider: typing.Optional[cdktf.TerraformProvider] = None,
        location: builtins.str,
        name: builtins.str,
        namespace_name: builtins.str,
        resource_group_name: builtins.str,
        apns_credential: typing.Optional[typing.List[NotificationHubApnsCredential]] = None,
        gcm_credential: typing.Optional[typing.List["NotificationHubGcmCredential"]] = None,
        timeouts: typing.Optional["NotificationHubTimeouts"] = None,
    ) -> None:
        """
        :param count: 
        :param depends_on: 
        :param lifecycle: 
        :param provider: 
        :param location: 
        :param name: 
        :param namespace_name: 
        :param resource_group_name: 
        :param apns_credential: apns_credential block.
        :param gcm_credential: gcm_credential block.
        :param timeouts: timeouts block.
        """
        if isinstance(lifecycle, dict):
            lifecycle = cdktf.TerraformResourceLifecycle(**lifecycle)
        if isinstance(timeouts, dict):
            timeouts = NotificationHubTimeouts(**timeouts)
        self._values: typing.Dict[str, typing.Any] = {
            "location": location,
            "name": name,
            "namespace_name": namespace_name,
            "resource_group_name": resource_group_name,
        }
        if count is not None:
            self._values["count"] = count
        if depends_on is not None:
            self._values["depends_on"] = depends_on
        if lifecycle is not None:
            self._values["lifecycle"] = lifecycle
        if provider is not None:
            self._values["provider"] = provider
        if apns_credential is not None:
            self._values["apns_credential"] = apns_credential
        if gcm_credential is not None:
            self._values["gcm_credential"] = gcm_credential
        if timeouts is not None:
            self._values["timeouts"] = timeouts

    @builtins.property
    def count(self) -> typing.Optional[jsii.Number]:
        """
        :stability: experimental
        """
        result = self._values.get("count")
        return result

    @builtins.property
    def depends_on(self) -> typing.Optional[typing.List[cdktf.TerraformResource]]:
        """
        :stability: experimental
        """
        result = self._values.get("depends_on")
        return result

    @builtins.property
    def lifecycle(self) -> typing.Optional[cdktf.TerraformResourceLifecycle]:
        """
        :stability: experimental
        """
        result = self._values.get("lifecycle")
        return result

    @builtins.property
    def provider(self) -> typing.Optional[cdktf.TerraformProvider]:
        """
        :stability: experimental
        """
        result = self._values.get("provider")
        return result

    @builtins.property
    def location(self) -> builtins.str:
        result = self._values.get("location")
        assert result is not None, "Required property 'location' is missing"
        return result

    @builtins.property
    def name(self) -> builtins.str:
        result = self._values.get("name")
        assert result is not None, "Required property 'name' is missing"
        return result

    @builtins.property
    def namespace_name(self) -> builtins.str:
        result = self._values.get("namespace_name")
        assert result is not None, "Required property 'namespace_name' is missing"
        return result

    @builtins.property
    def resource_group_name(self) -> builtins.str:
        result = self._values.get("resource_group_name")
        assert result is not None, "Required property 'resource_group_name' is missing"
        return result

    @builtins.property
    def apns_credential(
        self,
    ) -> typing.Optional[typing.List[NotificationHubApnsCredential]]:
        """apns_credential block."""
        result = self._values.get("apns_credential")
        return result

    @builtins.property
    def gcm_credential(
        self,
    ) -> typing.Optional[typing.List["NotificationHubGcmCredential"]]:
        """gcm_credential block."""
        result = self._values.get("gcm_credential")
        return result

    @builtins.property
    def timeouts(self) -> typing.Optional["NotificationHubTimeouts"]:
        """timeouts block."""
        result = self._values.get("timeouts")
        return result

    def __eq__(self, rhs: typing.Any) -> builtins.bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs: typing.Any) -> builtins.bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return "NotificationHubConfig(%s)" % ", ".join(
            k + "=" + repr(v) for k, v in self._values.items()
        )


@jsii.data_type(
    jsii_type="@cdktf/provider-azurerm.NotificationHubGcmCredential",
    jsii_struct_bases=[],
    name_mapping={"api_key": "apiKey"},
)
class NotificationHubGcmCredential:
    def __init__(self, *, api_key: builtins.str) -> None:
        """
        :param api_key: 
        """
        self._values: typing.Dict[str, typing.Any] = {
            "api_key": api_key,
        }

    @builtins.property
    def api_key(self) -> builtins.str:
        result = self._values.get("api_key")
        assert result is not None, "Required property 'api_key' is missing"
        return result

    def __eq__(self, rhs: typing.Any) -> builtins.bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs: typing.Any) -> builtins.bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return "NotificationHubGcmCredential(%s)" % ", ".join(
            k + "=" + repr(v) for k, v in self._values.items()
        )


class NotificationHubNamespace(
    cdktf.TerraformResource,
    metaclass=jsii.JSIIMeta,
    jsii_type="@cdktf/provider-azurerm.NotificationHubNamespace",
):
    def __init__(
        self,
        scope: constructs.Construct,
        id: builtins.str,
        *,
        location: builtins.str,
        name: builtins.str,
        namespace_type: builtins.str,
        resource_group_name: builtins.str,
        sku_name: builtins.str,
        enabled: typing.Optional[builtins.bool] = None,
        timeouts: typing.Optional["NotificationHubNamespaceTimeouts"] = None,
        count: typing.Optional[jsii.Number] = None,
        depends_on: typing.Optional[typing.List[cdktf.TerraformResource]] = None,
        lifecycle: typing.Optional[cdktf.TerraformResourceLifecycle] = None,
        provider: typing.Optional[cdktf.TerraformProvider] = None,
    ) -> None:
        """
        :param scope: -
        :param id: -
        :param location: 
        :param name: 
        :param namespace_type: 
        :param resource_group_name: 
        :param sku_name: 
        :param enabled: 
        :param timeouts: timeouts block.
        :param count: 
        :param depends_on: 
        :param lifecycle: 
        :param provider: 
        """
        config = NotificationHubNamespaceConfig(
            location=location,
            name=name,
            namespace_type=namespace_type,
            resource_group_name=resource_group_name,
            sku_name=sku_name,
            enabled=enabled,
            timeouts=timeouts,
            count=count,
            depends_on=depends_on,
            lifecycle=lifecycle,
            provider=provider,
        )

        jsii.create(NotificationHubNamespace, self, [scope, id, config])

    @jsii.member(jsii_name="synthesizeAttributes")
    def _synthesize_attributes(self) -> typing.Mapping[builtins.str, typing.Any]:
        return jsii.invoke(self, "synthesizeAttributes", [])

    @builtins.property # type: ignore
    @jsii.member(jsii_name="servicebusEndpoint")
    def servicebus_endpoint(self) -> builtins.str:
        return jsii.get(self, "servicebusEndpoint")

    @builtins.property # type: ignore
    @jsii.member(jsii_name="location")
    def location(self) -> builtins.str:
        return jsii.get(self, "location")

    @location.setter # type: ignore
    def location(self, value: builtins.str) -> None:
        jsii.set(self, "location", value)

    @builtins.property # type: ignore
    @jsii.member(jsii_name="name")
    def name(self) -> builtins.str:
        return jsii.get(self, "name")

    @name.setter # type: ignore
    def name(self, value: builtins.str) -> None:
        jsii.set(self, "name", value)

    @builtins.property # type: ignore
    @jsii.member(jsii_name="namespaceType")
    def namespace_type(self) -> builtins.str:
        return jsii.get(self, "namespaceType")

    @namespace_type.setter # type: ignore
    def namespace_type(self, value: builtins.str) -> None:
        jsii.set(self, "namespaceType", value)

    @builtins.property # type: ignore
    @jsii.member(jsii_name="resourceGroupName")
    def resource_group_name(self) -> builtins.str:
        return jsii.get(self, "resourceGroupName")

    @resource_group_name.setter # type: ignore
    def resource_group_name(self, value: builtins.str) -> None:
        jsii.set(self, "resourceGroupName", value)

    @builtins.property # type: ignore
    @jsii.member(jsii_name="skuName")
    def sku_name(self) -> builtins.str:
        return jsii.get(self, "skuName")

    @sku_name.setter # type: ignore
    def sku_name(self, value: builtins.str) -> None:
        jsii.set(self, "skuName", value)

    @builtins.property # type: ignore
    @jsii.member(jsii_name="enabled")
    def enabled(self) -> typing.Optional[builtins.bool]:
        return jsii.get(self, "enabled")

    @enabled.setter # type: ignore
    def enabled(self, value: typing.Optional[builtins.bool]) -> None:
        jsii.set(self, "enabled", value)

    @builtins.property # type: ignore
    @jsii.member(jsii_name="id")
    def id(self) -> typing.Optional[builtins.str]:
        return jsii.get(self, "id")

    @id.setter # type: ignore
    def id(self, value: typing.Optional[builtins.str]) -> None:
        jsii.set(self, "id", value)

    @builtins.property # type: ignore
    @jsii.member(jsii_name="timeouts")
    def timeouts(self) -> typing.Optional["NotificationHubNamespaceTimeouts"]:
        return jsii.get(self, "timeouts")

    @timeouts.setter # type: ignore
    def timeouts(
        self,
        value: typing.Optional["NotificationHubNamespaceTimeouts"],
    ) -> None:
        jsii.set(self, "timeouts", value)


@jsii.data_type(
    jsii_type="@cdktf/provider-azurerm.NotificationHubNamespaceConfig",
    jsii_struct_bases=[cdktf.TerraformMetaArguments],
    name_mapping={
        "count": "count",
        "depends_on": "dependsOn",
        "lifecycle": "lifecycle",
        "provider": "provider",
        "location": "location",
        "name": "name",
        "namespace_type": "namespaceType",
        "resource_group_name": "resourceGroupName",
        "sku_name": "skuName",
        "enabled": "enabled",
        "timeouts": "timeouts",
    },
)
class NotificationHubNamespaceConfig(cdktf.TerraformMetaArguments):
    def __init__(
        self,
        *,
        count: typing.Optional[jsii.Number] = None,
        depends_on: typing.Optional[typing.List[cdktf.TerraformResource]] = None,
        lifecycle: typing.Optional[cdktf.TerraformResourceLifecycle] = None,
        provider: typing.Optional[cdktf.TerraformProvider] = None,
        location: builtins.str,
        name: builtins.str,
        namespace_type: builtins.str,
        resource_group_name: builtins.str,
        sku_name: builtins.str,
        enabled: typing.Optional[builtins.bool] = None,
        timeouts: typing.Optional["NotificationHubNamespaceTimeouts"] = None,
    ) -> None:
        """
        :param count: 
        :param depends_on: 
        :param lifecycle: 
        :param provider: 
        :param location: 
        :param name: 
        :param namespace_type: 
        :param resource_group_name: 
        :param sku_name: 
        :param enabled: 
        :param timeouts: timeouts block.
        """
        if isinstance(lifecycle, dict):
            lifecycle = cdktf.TerraformResourceLifecycle(**lifecycle)
        if isinstance(timeouts, dict):
            timeouts = NotificationHubNamespaceTimeouts(**timeouts)
        self._values: typing.Dict[str, typing.Any] = {
            "location": location,
            "name": name,
            "namespace_type": namespace_type,
            "resource_group_name": resource_group_name,
            "sku_name": sku_name,
        }
        if count is not None:
            self._values["count"] = count
        if depends_on is not None:
            self._values["depends_on"] = depends_on
        if lifecycle is not None:
            self._values["lifecycle"] = lifecycle
        if provider is not None:
            self._values["provider"] = provider
        if enabled is not None:
            self._values["enabled"] = enabled
        if timeouts is not None:
            self._values["timeouts"] = timeouts

    @builtins.property
    def count(self) -> typing.Optional[jsii.Number]:
        """
        :stability: experimental
        """
        result = self._values.get("count")
        return result

    @builtins.property
    def depends_on(self) -> typing.Optional[typing.List[cdktf.TerraformResource]]:
        """
        :stability: experimental
        """
        result = self._values.get("depends_on")
        return result

    @builtins.property
    def lifecycle(self) -> typing.Optional[cdktf.TerraformResourceLifecycle]:
        """
        :stability: experimental
        """
        result = self._values.get("lifecycle")
        return result

    @builtins.property
    def provider(self) -> typing.Optional[cdktf.TerraformProvider]:
        """
        :stability: experimental
        """
        result = self._values.get("provider")
        return result

    @builtins.property
    def location(self) -> builtins.str:
        result = self._values.get("location")
        assert result is not None, "Required property 'location' is missing"
        return result

    @builtins.property
    def name(self) -> builtins.str:
        result = self._values.get("name")
        assert result is not None, "Required property 'name' is missing"
        return result

    @builtins.property
    def namespace_type(self) -> builtins.str:
        result = self._values.get("namespace_type")
        assert result is not None, "Required property 'namespace_type' is missing"
        return result

    @builtins.property
    def resource_group_name(self) -> builtins.str:
        result = self._values.get("resource_group_name")
        assert result is not None, "Required property 'resource_group_name' is missing"
        return result

    @builtins.property
    def sku_name(self) -> builtins.str:
        result = self._values.get("sku_name")
        assert result is not None, "Required property 'sku_name' is missing"
        return result

    @builtins.property
    def enabled(self) -> typing.Optional[builtins.bool]:
        result = self._values.get("enabled")
        return result

    @builtins.property
    def timeouts(self) -> typing.Optional["NotificationHubNamespaceTimeouts"]:
        """timeouts block."""
        result = self._values.get("timeouts")
        return result

    def __eq__(self, rhs: typing.Any) -> builtins.bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs: typing.Any) -> builtins.bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return "NotificationHubNamespaceConfig(%s)" % ", ".join(
            k + "=" + repr(v) for k, v in self._values.items()
        )


@jsii.data_type(
    jsii_type="@cdktf/provider-azurerm.NotificationHubNamespaceTimeouts",
    jsii_struct_bases=[],
    name_mapping={
        "create": "create",
        "delete": "delete",
        "read": "read",
        "update": "update",
    },
)
class NotificationHubNamespaceTimeouts:
    def __init__(
        self,
        *,
        create: typing.Optional[builtins.str] = None,
        delete: typing.Optional[builtins.str] = None,
        read: typing.Optional[builtins.str] = None,
        update: typing.Optional[builtins.str] = None,
    ) -> None:
        """
        :param create: 
        :param delete: 
        :param read: 
        :param update: 
        """
        self._values: typing.Dict[str, typing.Any] = {}
        if create is not None:
            self._values["create"] = create
        if delete is not None:
            self._values["delete"] = delete
        if read is not None:
            self._values["read"] = read
        if update is not None:
            self._values["update"] = update

    @builtins.property
    def create(self) -> typing.Optional[builtins.str]:
        result = self._values.get("create")
        return result

    @builtins.property
    def delete(self) -> typing.Optional[builtins.str]:
        result = self._values.get("delete")
        return result

    @builtins.property
    def read(self) -> typing.Optional[builtins.str]:
        result = self._values.get("read")
        return result

    @builtins.property
    def update(self) -> typing.Optional[builtins.str]:
        result = self._values.get("update")
        return result

    def __eq__(self, rhs: typing.Any) -> builtins.bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs: typing.Any) -> builtins.bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return "NotificationHubNamespaceTimeouts(%s)" % ", ".join(
            k + "=" + repr(v) for k, v in self._values.items()
        )


@jsii.data_type(
    jsii_type="@cdktf/provider-azurerm.NotificationHubTimeouts",
    jsii_struct_bases=[],
    name_mapping={
        "create": "create",
        "delete": "delete",
        "read": "read",
        "update": "update",
    },
)
class NotificationHubTimeouts:
    def __init__(
        self,
        *,
        create: typing.Optional[builtins.str] = None,
        delete: typing.Optional[builtins.str] = None,
        read: typing.Optional[builtins.str] = None,
        update: typing.Optional[builtins.str] = None,
    ) -> None:
        """
        :param create: 
        :param delete: 
        :param read: 
        :param update: 
        """
        self._values: typing.Dict[str, typing.Any] = {}
        if create is not None:
            self._values["create"] = create
        if delete is not None:
            self._values["delete"] = delete
        if read is not None:
            self._values["read"] = read
        if update is not None:
            self._values["update"] = update

    @builtins.property
    def create(self) -> typing.Optional[builtins.str]:
        result = self._values.get("create")
        return result

    @builtins.property
    def delete(self) -> typing.Optional[builtins.str]:
        result = self._values.get("delete")
        return result

    @builtins.property
    def read(self) -> typing.Optional[builtins.str]:
        result = self._values.get("read")
        return result

    @builtins.property
    def update(self) -> typing.Optional[builtins.str]:
        result = self._values.get("update")
        return result

    def __eq__(self, rhs: typing.Any) -> builtins.bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs: typing.Any) -> builtins.bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return "NotificationHubTimeouts(%s)" % ", ".join(
            k + "=" + repr(v) for k, v in self._values.items()
        )


class PacketCapture(
    cdktf.TerraformResource,
    metaclass=jsii.JSIIMeta,
    jsii_type="@cdktf/provider-azurerm.PacketCapture",
):
    def __init__(
        self,
        scope: constructs.Construct,
        id: builtins.str,
        *,
        name: builtins.str,
        network_watcher_name: builtins.str,
        resource_group_name: builtins.str,
        storage_location: typing.List["PacketCaptureStorageLocation"],
        target_resource_id: builtins.str,
        filter: typing.Optional[typing.List["PacketCaptureFilter"]] = None,
        maximum_bytes_per_packet: typing.Optional[jsii.Number] = None,
        maximum_bytes_per_session: typing.Optional[jsii.Number] = None,
        maximum_capture_duration: typing.Optional[jsii.Number] = None,
        timeouts: typing.Optional["PacketCaptureTimeouts"] = None,
        count: typing.Optional[jsii.Number] = None,
        depends_on: typing.Optional[typing.List[cdktf.TerraformResource]] = None,
        lifecycle: typing.Optional[cdktf.TerraformResourceLifecycle] = None,
        provider: typing.Optional[cdktf.TerraformProvider] = None,
    ) -> None:
        """
        :param scope: -
        :param id: -
        :param name: 
        :param network_watcher_name: 
        :param resource_group_name: 
        :param storage_location: storage_location block.
        :param target_resource_id: 
        :param filter: filter block.
        :param maximum_bytes_per_packet: 
        :param maximum_bytes_per_session: 
        :param maximum_capture_duration: 
        :param timeouts: timeouts block.
        :param count: 
        :param depends_on: 
        :param lifecycle: 
        :param provider: 
        """
        config = PacketCaptureConfig(
            name=name,
            network_watcher_name=network_watcher_name,
            resource_group_name=resource_group_name,
            storage_location=storage_location,
            target_resource_id=target_resource_id,
            filter=filter,
            maximum_bytes_per_packet=maximum_bytes_per_packet,
            maximum_bytes_per_session=maximum_bytes_per_session,
            maximum_capture_duration=maximum_capture_duration,
            timeouts=timeouts,
            count=count,
            depends_on=depends_on,
            lifecycle=lifecycle,
            provider=provider,
        )

        jsii.create(PacketCapture, self, [scope, id, config])

    @jsii.member(jsii_name="synthesizeAttributes")
    def _synthesize_attributes(self) -> typing.Mapping[builtins.str, typing.Any]:
        return jsii.invoke(self, "synthesizeAttributes", [])

    @builtins.property # type: ignore
    @jsii.member(jsii_name="name")
    def name(self) -> builtins.str:
        return jsii.get(self, "name")

    @name.setter # type: ignore
    def name(self, value: builtins.str) -> None:
        jsii.set(self, "name", value)

    @builtins.property # type: ignore
    @jsii.member(jsii_name="networkWatcherName")
    def network_watcher_name(self) -> builtins.str:
        return jsii.get(self, "networkWatcherName")

    @network_watcher_name.setter # type: ignore
    def network_watcher_name(self, value: builtins.str) -> None:
        jsii.set(self, "networkWatcherName", value)

    @builtins.property # type: ignore
    @jsii.member(jsii_name="resourceGroupName")
    def resource_group_name(self) -> builtins.str:
        return jsii.get(self, "resourceGroupName")

    @resource_group_name.setter # type: ignore
    def resource_group_name(self, value: builtins.str) -> None:
        jsii.set(self, "resourceGroupName", value)

    @builtins.property # type: ignore
    @jsii.member(jsii_name="storageLocation")
    def storage_location(self) -> typing.List["PacketCaptureStorageLocation"]:
        return jsii.get(self, "storageLocation")

    @storage_location.setter # type: ignore
    def storage_location(
        self,
        value: typing.List["PacketCaptureStorageLocation"],
    ) -> None:
        jsii.set(self, "storageLocation", value)

    @builtins.property # type: ignore
    @jsii.member(jsii_name="targetResourceId")
    def target_resource_id(self) -> builtins.str:
        return jsii.get(self, "targetResourceId")

    @target_resource_id.setter # type: ignore
    def target_resource_id(self, value: builtins.str) -> None:
        jsii.set(self, "targetResourceId", value)

    @builtins.property # type: ignore
    @jsii.member(jsii_name="filter")
    def filter(self) -> typing.Optional[typing.List["PacketCaptureFilter"]]:
        return jsii.get(self, "filter")

    @filter.setter # type: ignore
    def filter(
        self,
        value: typing.Optional[typing.List["PacketCaptureFilter"]],
    ) -> None:
        jsii.set(self, "filter", value)

    @builtins.property # type: ignore
    @jsii.member(jsii_name="id")
    def id(self) -> typing.Optional[builtins.str]:
        return jsii.get(self, "id")

    @id.setter # type: ignore
    def id(self, value: typing.Optional[builtins.str]) -> None:
        jsii.set(self, "id", value)

    @builtins.property # type: ignore
    @jsii.member(jsii_name="maximumBytesPerPacket")
    def maximum_bytes_per_packet(self) -> typing.Optional[jsii.Number]:
        return jsii.get(self, "maximumBytesPerPacket")

    @maximum_bytes_per_packet.setter # type: ignore
    def maximum_bytes_per_packet(self, value: typing.Optional[jsii.Number]) -> None:
        jsii.set(self, "maximumBytesPerPacket", value)

    @builtins.property # type: ignore
    @jsii.member(jsii_name="maximumBytesPerSession")
    def maximum_bytes_per_session(self) -> typing.Optional[jsii.Number]:
        return jsii.get(self, "maximumBytesPerSession")

    @maximum_bytes_per_session.setter # type: ignore
    def maximum_bytes_per_session(self, value: typing.Optional[jsii.Number]) -> None:
        jsii.set(self, "maximumBytesPerSession", value)

    @builtins.property # type: ignore
    @jsii.member(jsii_name="maximumCaptureDuration")
    def maximum_capture_duration(self) -> typing.Optional[jsii.Number]:
        return jsii.get(self, "maximumCaptureDuration")

    @maximum_capture_duration.setter # type: ignore
    def maximum_capture_duration(self, value: typing.Optional[jsii.Number]) -> None:
        jsii.set(self, "maximumCaptureDuration", value)

    @builtins.property # type: ignore
    @jsii.member(jsii_name="timeouts")
    def timeouts(self) -> typing.Optional["PacketCaptureTimeouts"]:
        return jsii.get(self, "timeouts")

    @timeouts.setter # type: ignore
    def timeouts(self, value: typing.Optional["PacketCaptureTimeouts"]) -> None:
        jsii.set(self, "timeouts", value)


@jsii.data_type(
    jsii_type="@cdktf/provider-azurerm.PacketCaptureConfig",
    jsii_struct_bases=[cdktf.TerraformMetaArguments],
    name_mapping={
        "count": "count",
        "depends_on": "dependsOn",
        "lifecycle": "lifecycle",
        "provider": "provider",
        "name": "name",
        "network_watcher_name": "networkWatcherName",
        "resource_group_name": "resourceGroupName",
        "storage_location": "storageLocation",
        "target_resource_id": "targetResourceId",
        "filter": "filter",
        "maximum_bytes_per_packet": "maximumBytesPerPacket",
        "maximum_bytes_per_session": "maximumBytesPerSession",
        "maximum_capture_duration": "maximumCaptureDuration",
        "timeouts": "timeouts",
    },
)
class PacketCaptureConfig(cdktf.TerraformMetaArguments):
    def __init__(
        self,
        *,
        count: typing.Optional[jsii.Number] = None,
        depends_on: typing.Optional[typing.List[cdktf.TerraformResource]] = None,
        lifecycle: typing.Optional[cdktf.TerraformResourceLifecycle] = None,
        provider: typing.Optional[cdktf.TerraformProvider] = None,
        name: builtins.str,
        network_watcher_name: builtins.str,
        resource_group_name: builtins.str,
        storage_location: typing.List["PacketCaptureStorageLocation"],
        target_resource_id: builtins.str,
        filter: typing.Optional[typing.List["PacketCaptureFilter"]] = None,
        maximum_bytes_per_packet: typing.Optional[jsii.Number] = None,
        maximum_bytes_per_session: typing.Optional[jsii.Number] = None,
        maximum_capture_duration: typing.Optional[jsii.Number] = None,
        timeouts: typing.Optional["PacketCaptureTimeouts"] = None,
    ) -> None:
        """
        :param count: 
        :param depends_on: 
        :param lifecycle: 
        :param provider: 
        :param name: 
        :param network_watcher_name: 
        :param resource_group_name: 
        :param storage_location: storage_location block.
        :param target_resource_id: 
        :param filter: filter block.
        :param maximum_bytes_per_packet: 
        :param maximum_bytes_per_session: 
        :param maximum_capture_duration: 
        :param timeouts: timeouts block.
        """
        if isinstance(lifecycle, dict):
            lifecycle = cdktf.TerraformResourceLifecycle(**lifecycle)
        if isinstance(timeouts, dict):
            timeouts = PacketCaptureTimeouts(**timeouts)
        self._values: typing.Dict[str, typing.Any] = {
            "name": name,
            "network_watcher_name": network_watcher_name,
            "resource_group_name": resource_group_name,
            "storage_location": storage_location,
            "target_resource_id": target_resource_id,
        }
        if count is not None:
            self._values["count"] = count
        if depends_on is not None:
            self._values["depends_on"] = depends_on
        if lifecycle is not None:
            self._values["lifecycle"] = lifecycle
        if provider is not None:
            self._values["provider"] = provider
        if filter is not None:
            self._values["filter"] = filter
        if maximum_bytes_per_packet is not None:
            self._values["maximum_bytes_per_packet"] = maximum_bytes_per_packet
        if maximum_bytes_per_session is not None:
            self._values["maximum_bytes_per_session"] = maximum_bytes_per_session
        if maximum_capture_duration is not None:
            self._values["maximum_capture_duration"] = maximum_capture_duration
        if timeouts is not None:
            self._values["timeouts"] = timeouts

    @builtins.property
    def count(self) -> typing.Optional[jsii.Number]:
        """
        :stability: experimental
        """
        result = self._values.get("count")
        return result

    @builtins.property
    def depends_on(self) -> typing.Optional[typing.List[cdktf.TerraformResource]]:
        """
        :stability: experimental
        """
        result = self._values.get("depends_on")
        return result

    @builtins.property
    def lifecycle(self) -> typing.Optional[cdktf.TerraformResourceLifecycle]:
        """
        :stability: experimental
        """
        result = self._values.get("lifecycle")
        return result

    @builtins.property
    def provider(self) -> typing.Optional[cdktf.TerraformProvider]:
        """
        :stability: experimental
        """
        result = self._values.get("provider")
        return result

    @builtins.property
    def name(self) -> builtins.str:
        result = self._values.get("name")
        assert result is not None, "Required property 'name' is missing"
        return result

    @builtins.property
    def network_watcher_name(self) -> builtins.str:
        result = self._values.get("network_watcher_name")
        assert result is not None, "Required property 'network_watcher_name' is missing"
        return result

    @builtins.property
    def resource_group_name(self) -> builtins.str:
        result = self._values.get("resource_group_name")
        assert result is not None, "Required property 'resource_group_name' is missing"
        return result

    @builtins.property
    def storage_location(self) -> typing.List["PacketCaptureStorageLocation"]:
        """storage_location block."""
        result = self._values.get("storage_location")
        assert result is not None, "Required property 'storage_location' is missing"
        return result

    @builtins.property
    def target_resource_id(self) -> builtins.str:
        result = self._values.get("target_resource_id")
        assert result is not None, "Required property 'target_resource_id' is missing"
        return result

    @builtins.property
    def filter(self) -> typing.Optional[typing.List["PacketCaptureFilter"]]:
        """filter block."""
        result = self._values.get("filter")
        return result

    @builtins.property
    def maximum_bytes_per_packet(self) -> typing.Optional[jsii.Number]:
        result = self._values.get("maximum_bytes_per_packet")
        return result

    @builtins.property
    def maximum_bytes_per_session(self) -> typing.Optional[jsii.Number]:
        result = self._values.get("maximum_bytes_per_session")
        return result

    @builtins.property
    def maximum_capture_duration(self) -> typing.Optional[jsii.Number]:
        result = self._values.get("maximum_capture_duration")
        return result

    @builtins.property
    def timeouts(self) -> typing.Optional["PacketCaptureTimeouts"]:
        """timeouts block."""
        result = self._values.get("timeouts")
        return result

    def __eq__(self, rhs: typing.Any) -> builtins.bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs: typing.Any) -> builtins.bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return "PacketCaptureConfig(%s)" % ", ".join(
            k + "=" + repr(v) for k, v in self._values.items()
        )


@jsii.data_type(
    jsii_type="@cdktf/provider-azurerm.PacketCaptureFilter",
    jsii_struct_bases=[],
    name_mapping={
        "protocol": "protocol",
        "local_ip_address": "localIpAddress",
        "local_port": "localPort",
        "remote_ip_address": "remoteIpAddress",
        "remote_port": "remotePort",
    },
)
class PacketCaptureFilter:
    def __init__(
        self,
        *,
        protocol: builtins.str,
        local_ip_address: typing.Optional[builtins.str] = None,
        local_port: typing.Optional[builtins.str] = None,
        remote_ip_address: typing.Optional[builtins.str] = None,
        remote_port: typing.Optional[builtins.str] = None,
    ) -> None:
        """
        :param protocol: 
        :param local_ip_address: 
        :param local_port: 
        :param remote_ip_address: 
        :param remote_port: 
        """
        self._values: typing.Dict[str, typing.Any] = {
            "protocol": protocol,
        }
        if local_ip_address is not None:
            self._values["local_ip_address"] = local_ip_address
        if local_port is not None:
            self._values["local_port"] = local_port
        if remote_ip_address is not None:
            self._values["remote_ip_address"] = remote_ip_address
        if remote_port is not None:
            self._values["remote_port"] = remote_port

    @builtins.property
    def protocol(self) -> builtins.str:
        result = self._values.get("protocol")
        assert result is not None, "Required property 'protocol' is missing"
        return result

    @builtins.property
    def local_ip_address(self) -> typing.Optional[builtins.str]:
        result = self._values.get("local_ip_address")
        return result

    @builtins.property
    def local_port(self) -> typing.Optional[builtins.str]:
        result = self._values.get("local_port")
        return result

    @builtins.property
    def remote_ip_address(self) -> typing.Optional[builtins.str]:
        result = self._values.get("remote_ip_address")
        return result

    @builtins.property
    def remote_port(self) -> typing.Optional[builtins.str]:
        result = self._values.get("remote_port")
        return result

    def __eq__(self, rhs: typing.Any) -> builtins.bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs: typing.Any) -> builtins.bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return "PacketCaptureFilter(%s)" % ", ".join(
            k + "=" + repr(v) for k, v in self._values.items()
        )


@jsii.data_type(
    jsii_type="@cdktf/provider-azurerm.PacketCaptureStorageLocation",
    jsii_struct_bases=[],
    name_mapping={"file_path": "filePath", "storage_account_id": "storageAccountId"},
)
class PacketCaptureStorageLocation:
    def __init__(
        self,
        *,
        file_path: typing.Optional[builtins.str] = None,
        storage_account_id: typing.Optional[builtins.str] = None,
    ) -> None:
        """
        :param file_path: 
        :param storage_account_id: 
        """
        self._values: typing.Dict[str, typing.Any] = {}
        if file_path is not None:
            self._values["file_path"] = file_path
        if storage_account_id is not None:
            self._values["storage_account_id"] = storage_account_id

    @builtins.property
    def file_path(self) -> typing.Optional[builtins.str]:
        result = self._values.get("file_path")
        return result

    @builtins.property
    def storage_account_id(self) -> typing.Optional[builtins.str]:
        result = self._values.get("storage_account_id")
        return result

    def __eq__(self, rhs: typing.Any) -> builtins.bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs: typing.Any) -> builtins.bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return "PacketCaptureStorageLocation(%s)" % ", ".join(
            k + "=" + repr(v) for k, v in self._values.items()
        )


@jsii.data_type(
    jsii_type="@cdktf/provider-azurerm.PacketCaptureTimeouts",
    jsii_struct_bases=[],
    name_mapping={
        "create": "create",
        "delete": "delete",
        "read": "read",
        "update": "update",
    },
)
class PacketCaptureTimeouts:
    def __init__(
        self,
        *,
        create: typing.Optional[builtins.str] = None,
        delete: typing.Optional[builtins.str] = None,
        read: typing.Optional[builtins.str] = None,
        update: typing.Optional[builtins.str] = None,
    ) -> None:
        """
        :param create: 
        :param delete: 
        :param read: 
        :param update: 
        """
        self._values: typing.Dict[str, typing.Any] = {}
        if create is not None:
            self._values["create"] = create
        if delete is not None:
            self._values["delete"] = delete
        if read is not None:
            self._values["read"] = read
        if update is not None:
            self._values["update"] = update

    @builtins.property
    def create(self) -> typing.Optional[builtins.str]:
        result = self._values.get("create")
        return result

    @builtins.property
    def delete(self) -> typing.Optional[builtins.str]:
        result = self._values.get("delete")
        return result

    @builtins.property
    def read(self) -> typing.Optional[builtins.str]:
        result = self._values.get("read")
        return result

    @builtins.property
    def update(self) -> typing.Optional[builtins.str]:
        result = self._values.get("update")
        return result

    def __eq__(self, rhs: typing.Any) -> builtins.bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs: typing.Any) -> builtins.bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return "PacketCaptureTimeouts(%s)" % ", ".join(
            k + "=" + repr(v) for k, v in self._values.items()
        )


class PointToSiteVpnGateway(
    cdktf.TerraformResource,
    metaclass=jsii.JSIIMeta,
    jsii_type="@cdktf/provider-azurerm.PointToSiteVpnGateway",
):
    def __init__(
        self,
        scope: constructs.Construct,
        id: builtins.str,
        *,
        connection_configuration: typing.List["PointToSiteVpnGatewayConnectionConfiguration"],
        location: builtins.str,
        name: builtins.str,
        resource_group_name: builtins.str,
        scale_unit: jsii.Number,
        virtual_hub_id: builtins.str,
        vpn_server_configuration_id: builtins.str,
        tags: typing.Optional[typing.Mapping[builtins.str, builtins.str]] = None,
        timeouts: typing.Optional["PointToSiteVpnGatewayTimeouts"] = None,
        count: typing.Optional[jsii.Number] = None,
        depends_on: typing.Optional[typing.List[cdktf.TerraformResource]] = None,
        lifecycle: typing.Optional[cdktf.TerraformResourceLifecycle] = None,
        provider: typing.Optional[cdktf.TerraformProvider] = None,
    ) -> None:
        """
        :param scope: -
        :param id: -
        :param connection_configuration: connection_configuration block.
        :param location: 
        :param name: 
        :param resource_group_name: 
        :param scale_unit: 
        :param virtual_hub_id: 
        :param vpn_server_configuration_id: 
        :param tags: 
        :param timeouts: timeouts block.
        :param count: 
        :param depends_on: 
        :param lifecycle: 
        :param provider: 
        """
        config = PointToSiteVpnGatewayConfig(
            connection_configuration=connection_configuration,
            location=location,
            name=name,
            resource_group_name=resource_group_name,
            scale_unit=scale_unit,
            virtual_hub_id=virtual_hub_id,
            vpn_server_configuration_id=vpn_server_configuration_id,
            tags=tags,
            timeouts=timeouts,
            count=count,
            depends_on=depends_on,
            lifecycle=lifecycle,
            provider=provider,
        )

        jsii.create(PointToSiteVpnGateway, self, [scope, id, config])

    @jsii.member(jsii_name="synthesizeAttributes")
    def _synthesize_attributes(self) -> typing.Mapping[builtins.str, typing.Any]:
        return jsii.invoke(self, "synthesizeAttributes", [])

    @builtins.property # type: ignore
    @jsii.member(jsii_name="connectionConfiguration")
    def connection_configuration(
        self,
    ) -> typing.List["PointToSiteVpnGatewayConnectionConfiguration"]:
        return jsii.get(self, "connectionConfiguration")

    @connection_configuration.setter # type: ignore
    def connection_configuration(
        self,
        value: typing.List["PointToSiteVpnGatewayConnectionConfiguration"],
    ) -> None:
        jsii.set(self, "connectionConfiguration", value)

    @builtins.property # type: ignore
    @jsii.member(jsii_name="location")
    def location(self) -> builtins.str:
        return jsii.get(self, "location")

    @location.setter # type: ignore
    def location(self, value: builtins.str) -> None:
        jsii.set(self, "location", value)

    @builtins.property # type: ignore
    @jsii.member(jsii_name="name")
    def name(self) -> builtins.str:
        return jsii.get(self, "name")

    @name.setter # type: ignore
    def name(self, value: builtins.str) -> None:
        jsii.set(self, "name", value)

    @builtins.property # type: ignore
    @jsii.member(jsii_name="resourceGroupName")
    def resource_group_name(self) -> builtins.str:
        return jsii.get(self, "resourceGroupName")

    @resource_group_name.setter # type: ignore
    def resource_group_name(self, value: builtins.str) -> None:
        jsii.set(self, "resourceGroupName", value)

    @builtins.property # type: ignore
    @jsii.member(jsii_name="scaleUnit")
    def scale_unit(self) -> jsii.Number:
        return jsii.get(self, "scaleUnit")

    @scale_unit.setter # type: ignore
    def scale_unit(self, value: jsii.Number) -> None:
        jsii.set(self, "scaleUnit", value)

    @builtins.property # type: ignore
    @jsii.member(jsii_name="virtualHubId")
    def virtual_hub_id(self) -> builtins.str:
        return jsii.get(self, "virtualHubId")

    @virtual_hub_id.setter # type: ignore
    def virtual_hub_id(self, value: builtins.str) -> None:
        jsii.set(self, "virtualHubId", value)

    @builtins.property # type: ignore
    @jsii.member(jsii_name="vpnServerConfigurationId")
    def vpn_server_configuration_id(self) -> builtins.str:
        return jsii.get(self, "vpnServerConfigurationId")

    @vpn_server_configuration_id.setter # type: ignore
    def vpn_server_configuration_id(self, value: builtins.str) -> None:
        jsii.set(self, "vpnServerConfigurationId", value)

    @builtins.property # type: ignore
    @jsii.member(jsii_name="id")
    def id(self) -> typing.Optional[builtins.str]:
        return jsii.get(self, "id")

    @id.setter # type: ignore
    def id(self, value: typing.Optional[builtins.str]) -> None:
        jsii.set(self, "id", value)

    @builtins.property # type: ignore
    @jsii.member(jsii_name="tags")
    def tags(self) -> typing.Optional[typing.Mapping[builtins.str, builtins.str]]:
        return jsii.get(self, "tags")

    @tags.setter # type: ignore
    def tags(
        self,
        value: typing.Optional[typing.Mapping[builtins.str, builtins.str]],
    ) -> None:
        jsii.set(self, "tags", value)

    @builtins.property # type: ignore
    @jsii.member(jsii_name="timeouts")
    def timeouts(self) -> typing.Optional["PointToSiteVpnGatewayTimeouts"]:
        return jsii.get(self, "timeouts")

    @timeouts.setter # type: ignore
    def timeouts(self, value: typing.Optional["PointToSiteVpnGatewayTimeouts"]) -> None:
        jsii.set(self, "timeouts", value)


@jsii.data_type(
    jsii_type="@cdktf/provider-azurerm.PointToSiteVpnGatewayConfig",
    jsii_struct_bases=[cdktf.TerraformMetaArguments],
    name_mapping={
        "count": "count",
        "depends_on": "dependsOn",
        "lifecycle": "lifecycle",
        "provider": "provider",
        "connection_configuration": "connectionConfiguration",
        "location": "location",
        "name": "name",
        "resource_group_name": "resourceGroupName",
        "scale_unit": "scaleUnit",
        "virtual_hub_id": "virtualHubId",
        "vpn_server_configuration_id": "vpnServerConfigurationId",
        "tags": "tags",
        "timeouts": "timeouts",
    },
)
class PointToSiteVpnGatewayConfig(cdktf.TerraformMetaArguments):
    def __init__(
        self,
        *,
        count: typing.Optional[jsii.Number] = None,
        depends_on: typing.Optional[typing.List[cdktf.TerraformResource]] = None,
        lifecycle: typing.Optional[cdktf.TerraformResourceLifecycle] = None,
        provider: typing.Optional[cdktf.TerraformProvider] = None,
        connection_configuration: typing.List["PointToSiteVpnGatewayConnectionConfiguration"],
        location: builtins.str,
        name: builtins.str,
        resource_group_name: builtins.str,
        scale_unit: jsii.Number,
        virtual_hub_id: builtins.str,
        vpn_server_configuration_id: builtins.str,
        tags: typing.Optional[typing.Mapping[builtins.str, builtins.str]] = None,
        timeouts: typing.Optional["PointToSiteVpnGatewayTimeouts"] = None,
    ) -> None:
        """
        :param count: 
        :param depends_on: 
        :param lifecycle: 
        :param provider: 
        :param connection_configuration: connection_configuration block.
        :param location: 
        :param name: 
        :param resource_group_name: 
        :param scale_unit: 
        :param virtual_hub_id: 
        :param vpn_server_configuration_id: 
        :param tags: 
        :param timeouts: timeouts block.
        """
        if isinstance(lifecycle, dict):
            lifecycle = cdktf.TerraformResourceLifecycle(**lifecycle)
        if isinstance(timeouts, dict):
            timeouts = PointToSiteVpnGatewayTimeouts(**timeouts)
        self._values: typing.Dict[str, typing.Any] = {
            "connection_configuration": connection_configuration,
            "location": location,
            "name": name,
            "resource_group_name": resource_group_name,
            "scale_unit": scale_unit,
            "virtual_hub_id": virtual_hub_id,
            "vpn_server_configuration_id": vpn_server_configuration_id,
        }
        if count is not None:
            self._values["count"] = count
        if depends_on is not None:
            self._values["depends_on"] = depends_on
        if lifecycle is not None:
            self._values["lifecycle"] = lifecycle
        if provider is not None:
            self._values["provider"] = provider
        if tags is not None:
            self._values["tags"] = tags
        if timeouts is not None:
            self._values["timeouts"] = timeouts

    @builtins.property
    def count(self) -> typing.Optional[jsii.Number]:
        """
        :stability: experimental
        """
        result = self._values.get("count")
        return result

    @builtins.property
    def depends_on(self) -> typing.Optional[typing.List[cdktf.TerraformResource]]:
        """
        :stability: experimental
        """
        result = self._values.get("depends_on")
        return result

    @builtins.property
    def lifecycle(self) -> typing.Optional[cdktf.TerraformResourceLifecycle]:
        """
        :stability: experimental
        """
        result = self._values.get("lifecycle")
        return result

    @builtins.property
    def provider(self) -> typing.Optional[cdktf.TerraformProvider]:
        """
        :stability: experimental
        """
        result = self._values.get("provider")
        return result

    @builtins.property
    def connection_configuration(
        self,
    ) -> typing.List["PointToSiteVpnGatewayConnectionConfiguration"]:
        """connection_configuration block."""
        result = self._values.get("connection_configuration")
        assert result is not None, "Required property 'connection_configuration' is missing"
        return result

    @builtins.property
    def location(self) -> builtins.str:
        result = self._values.get("location")
        assert result is not None, "Required property 'location' is missing"
        return result

    @builtins.property
    def name(self) -> builtins.str:
        result = self._values.get("name")
        assert result is not None, "Required property 'name' is missing"
        return result

    @builtins.property
    def resource_group_name(self) -> builtins.str:
        result = self._values.get("resource_group_name")
        assert result is not None, "Required property 'resource_group_name' is missing"
        return result

    @builtins.property
    def scale_unit(self) -> jsii.Number:
        result = self._values.get("scale_unit")
        assert result is not None, "Required property 'scale_unit' is missing"
        return result

    @builtins.property
    def virtual_hub_id(self) -> builtins.str:
        result = self._values.get("virtual_hub_id")
        assert result is not None, "Required property 'virtual_hub_id' is missing"
        return result

    @builtins.property
    def vpn_server_configuration_id(self) -> builtins.str:
        result = self._values.get("vpn_server_configuration_id")
        assert result is not None, "Required property 'vpn_server_configuration_id' is missing"
        return result

    @builtins.property
    def tags(self) -> typing.Optional[typing.Mapping[builtins.str, builtins.str]]:
        result = self._values.get("tags")
        return result

    @builtins.property
    def timeouts(self) -> typing.Optional["PointToSiteVpnGatewayTimeouts"]:
        """timeouts block."""
        result = self._values.get("timeouts")
        return result

    def __eq__(self, rhs: typing.Any) -> builtins.bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs: typing.Any) -> builtins.bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return "PointToSiteVpnGatewayConfig(%s)" % ", ".join(
            k + "=" + repr(v) for k, v in self._values.items()
        )


@jsii.data_type(
    jsii_type="@cdktf/provider-azurerm.PointToSiteVpnGatewayConnectionConfiguration",
    jsii_struct_bases=[],
    name_mapping={"name": "name", "vpn_client_address_pool": "vpnClientAddressPool"},
)
class PointToSiteVpnGatewayConnectionConfiguration:
    def __init__(
        self,
        *,
        name: builtins.str,
        vpn_client_address_pool: typing.List["PointToSiteVpnGatewayConnectionConfigurationVpnClientAddressPool"],
    ) -> None:
        """
        :param name: 
        :param vpn_client_address_pool: vpn_client_address_pool block.
        """
        self._values: typing.Dict[str, typing.Any] = {
            "name": name,
            "vpn_client_address_pool": vpn_client_address_pool,
        }

    @builtins.property
    def name(self) -> builtins.str:
        result = self._values.get("name")
        assert result is not None, "Required property 'name' is missing"
        return result

    @builtins.property
    def vpn_client_address_pool(
        self,
    ) -> typing.List["PointToSiteVpnGatewayConnectionConfigurationVpnClientAddressPool"]:
        """vpn_client_address_pool block."""
        result = self._values.get("vpn_client_address_pool")
        assert result is not None, "Required property 'vpn_client_address_pool' is missing"
        return result

    def __eq__(self, rhs: typing.Any) -> builtins.bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs: typing.Any) -> builtins.bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return "PointToSiteVpnGatewayConnectionConfiguration(%s)" % ", ".join(
            k + "=" + repr(v) for k, v in self._values.items()
        )


@jsii.data_type(
    jsii_type="@cdktf/provider-azurerm.PointToSiteVpnGatewayConnectionConfigurationVpnClientAddressPool",
    jsii_struct_bases=[],
    name_mapping={"address_prefixes": "addressPrefixes"},
)
class PointToSiteVpnGatewayConnectionConfigurationVpnClientAddressPool:
    def __init__(self, *, address_prefixes: typing.List[builtins.str]) -> None:
        """
        :param address_prefixes: 
        """
        self._values: typing.Dict[str, typing.Any] = {
            "address_prefixes": address_prefixes,
        }

    @builtins.property
    def address_prefixes(self) -> typing.List[builtins.str]:
        result = self._values.get("address_prefixes")
        assert result is not None, "Required property 'address_prefixes' is missing"
        return result

    def __eq__(self, rhs: typing.Any) -> builtins.bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs: typing.Any) -> builtins.bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return "PointToSiteVpnGatewayConnectionConfigurationVpnClientAddressPool(%s)" % ", ".join(
            k + "=" + repr(v) for k, v in self._values.items()
        )


@jsii.data_type(
    jsii_type="@cdktf/provider-azurerm.PointToSiteVpnGatewayTimeouts",
    jsii_struct_bases=[],
    name_mapping={
        "create": "create",
        "delete": "delete",
        "read": "read",
        "update": "update",
    },
)
class PointToSiteVpnGatewayTimeouts:
    def __init__(
        self,
        *,
        create: typing.Optional[builtins.str] = None,
        delete: typing.Optional[builtins.str] = None,
        read: typing.Optional[builtins.str] = None,
        update: typing.Optional[builtins.str] = None,
    ) -> None:
        """
        :param create: 
        :param delete: 
        :param read: 
        :param update: 
        """
        self._values: typing.Dict[str, typing.Any] = {}
        if create is not None:
            self._values["create"] = create
        if delete is not None:
            self._values["delete"] = delete
        if read is not None:
            self._values["read"] = read
        if update is not None:
            self._values["update"] = update

    @builtins.property
    def create(self) -> typing.Optional[builtins.str]:
        result = self._values.get("create")
        return result

    @builtins.property
    def delete(self) -> typing.Optional[builtins.str]:
        result = self._values.get("delete")
        return result

    @builtins.property
    def read(self) -> typing.Optional[builtins.str]:
        result = self._values.get("read")
        return result

    @builtins.property
    def update(self) -> typing.Optional[builtins.str]:
        result = self._values.get("update")
        return result

    def __eq__(self, rhs: typing.Any) -> builtins.bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs: typing.Any) -> builtins.bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return "PointToSiteVpnGatewayTimeouts(%s)" % ", ".join(
            k + "=" + repr(v) for k, v in self._values.items()
        )


class PolicyAssignment(
    cdktf.TerraformResource,
    metaclass=jsii.JSIIMeta,
    jsii_type="@cdktf/provider-azurerm.PolicyAssignment",
):
    def __init__(
        self,
        scope_: constructs.Construct,
        id: builtins.str,
        *,
        name: builtins.str,
        policy_definition_id: builtins.str,
        scope: builtins.str,
        description: typing.Optional[builtins.str] = None,
        display_name: typing.Optional[builtins.str] = None,
        identity: typing.Optional[typing.List["PolicyAssignmentIdentity"]] = None,
        location: typing.Optional[builtins.str] = None,
        not_scopes: typing.Optional[typing.List[builtins.str]] = None,
        parameters: typing.Optional[builtins.str] = None,
        timeouts: typing.Optional["PolicyAssignmentTimeouts"] = None,
        count: typing.Optional[jsii.Number] = None,
        depends_on: typing.Optional[typing.List[cdktf.TerraformResource]] = None,
        lifecycle: typing.Optional[cdktf.TerraformResourceLifecycle] = None,
        provider: typing.Optional[cdktf.TerraformProvider] = None,
    ) -> None:
        """
        :param scope_: -
        :param id: -
        :param name: 
        :param policy_definition_id: 
        :param scope: 
        :param description: 
        :param display_name: 
        :param identity: identity block.
        :param location: 
        :param not_scopes: 
        :param parameters: 
        :param timeouts: timeouts block.
        :param count: 
        :param depends_on: 
        :param lifecycle: 
        :param provider: 
        """
        config = PolicyAssignmentConfig(
            name=name,
            policy_definition_id=policy_definition_id,
            scope=scope,
            description=description,
            display_name=display_name,
            identity=identity,
            location=location,
            not_scopes=not_scopes,
            parameters=parameters,
            timeouts=timeouts,
            count=count,
            depends_on=depends_on,
            lifecycle=lifecycle,
            provider=provider,
        )

        jsii.create(PolicyAssignment, self, [scope_, id, config])

    @jsii.member(jsii_name="synthesizeAttributes")
    def _synthesize_attributes(self) -> typing.Mapping[builtins.str, typing.Any]:
        return jsii.invoke(self, "synthesizeAttributes", [])

    @builtins.property # type: ignore
    @jsii.member(jsii_name="name")
    def name(self) -> builtins.str:
        return jsii.get(self, "name")

    @name.setter # type: ignore
    def name(self, value: builtins.str) -> None:
        jsii.set(self, "name", value)

    @builtins.property # type: ignore
    @jsii.member(jsii_name="policyDefinitionId")
    def policy_definition_id(self) -> builtins.str:
        return jsii.get(self, "policyDefinitionId")

    @policy_definition_id.setter # type: ignore
    def policy_definition_id(self, value: builtins.str) -> None:
        jsii.set(self, "policyDefinitionId", value)

    @builtins.property # type: ignore
    @jsii.member(jsii_name="scope")
    def scope(self) -> builtins.str:
        return jsii.get(self, "scope")

    @scope.setter # type: ignore
    def scope(self, value: builtins.str) -> None:
        jsii.set(self, "scope", value)

    @builtins.property # type: ignore
    @jsii.member(jsii_name="description")
    def description(self) -> typing.Optional[builtins.str]:
        return jsii.get(self, "description")

    @description.setter # type: ignore
    def description(self, value: typing.Optional[builtins.str]) -> None:
        jsii.set(self, "description", value)

    @builtins.property # type: ignore
    @jsii.member(jsii_name="displayName")
    def display_name(self) -> typing.Optional[builtins.str]:
        return jsii.get(self, "displayName")

    @display_name.setter # type: ignore
    def display_name(self, value: typing.Optional[builtins.str]) -> None:
        jsii.set(self, "displayName", value)

    @builtins.property # type: ignore
    @jsii.member(jsii_name="id")
    def id(self) -> typing.Optional[builtins.str]:
        return jsii.get(self, "id")

    @id.setter # type: ignore
    def id(self, value: typing.Optional[builtins.str]) -> None:
        jsii.set(self, "id", value)

    @builtins.property # type: ignore
    @jsii.member(jsii_name="identity")
    def identity(self) -> typing.Optional[typing.List["PolicyAssignmentIdentity"]]:
        return jsii.get(self, "identity")

    @identity.setter # type: ignore
    def identity(
        self,
        value: typing.Optional[typing.List["PolicyAssignmentIdentity"]],
    ) -> None:
        jsii.set(self, "identity", value)

    @builtins.property # type: ignore
    @jsii.member(jsii_name="location")
    def location(self) -> typing.Optional[builtins.str]:
        return jsii.get(self, "location")

    @location.setter # type: ignore
    def location(self, value: typing.Optional[builtins.str]) -> None:
        jsii.set(self, "location", value)

    @builtins.property # type: ignore
    @jsii.member(jsii_name="notScopes")
    def not_scopes(self) -> typing.Optional[typing.List[builtins.str]]:
        return jsii.get(self, "notScopes")

    @not_scopes.setter # type: ignore
    def not_scopes(self, value: typing.Optional[typing.List[builtins.str]]) -> None:
        jsii.set(self, "notScopes", value)

    @builtins.property # type: ignore
    @jsii.member(jsii_name="parameters")
    def parameters(self) -> typing.Optional[builtins.str]:
        return jsii.get(self, "parameters")

    @parameters.setter # type: ignore
    def parameters(self, value: typing.Optional[builtins.str]) -> None:
        jsii.set(self, "parameters", value)

    @builtins.property # type: ignore
    @jsii.member(jsii_name="timeouts")
    def timeouts(self) -> typing.Optional["PolicyAssignmentTimeouts"]:
        return jsii.get(self, "timeouts")

    @timeouts.setter # type: ignore
    def timeouts(self, value: typing.Optional["PolicyAssignmentTimeouts"]) -> None:
        jsii.set(self, "timeouts", value)


@jsii.data_type(
    jsii_type="@cdktf/provider-azurerm.PolicyAssignmentConfig",
    jsii_struct_bases=[cdktf.TerraformMetaArguments],
    name_mapping={
        "count": "count",
        "depends_on": "dependsOn",
        "lifecycle": "lifecycle",
        "provider": "provider",
        "name": "name",
        "policy_definition_id": "policyDefinitionId",
        "scope": "scope",
        "description": "description",
        "display_name": "displayName",
        "identity": "identity",
        "location": "location",
        "not_scopes": "notScopes",
        "parameters": "parameters",
        "timeouts": "timeouts",
    },
)
class PolicyAssignmentConfig(cdktf.TerraformMetaArguments):
    def __init__(
        self,
        *,
        count: typing.Optional[jsii.Number] = None,
        depends_on: typing.Optional[typing.List[cdktf.TerraformResource]] = None,
        lifecycle: typing.Optional[cdktf.TerraformResourceLifecycle] = None,
        provider: typing.Optional[cdktf.TerraformProvider] = None,
        name: builtins.str,
        policy_definition_id: builtins.str,
        scope: builtins.str,
        description: typing.Optional[builtins.str] = None,
        display_name: typing.Optional[builtins.str] = None,
        identity: typing.Optional[typing.List["PolicyAssignmentIdentity"]] = None,
        location: typing.Optional[builtins.str] = None,
        not_scopes: typing.Optional[typing.List[builtins.str]] = None,
        parameters: typing.Optional[builtins.str] = None,
        timeouts: typing.Optional["PolicyAssignmentTimeouts"] = None,
    ) -> None:
        """
        :param count: 
        :param depends_on: 
        :param lifecycle: 
        :param provider: 
        :param name: 
        :param policy_definition_id: 
        :param scope: 
        :param description: 
        :param display_name: 
        :param identity: identity block.
        :param location: 
        :param not_scopes: 
        :param parameters: 
        :param timeouts: timeouts block.
        """
        if isinstance(lifecycle, dict):
            lifecycle = cdktf.TerraformResourceLifecycle(**lifecycle)
        if isinstance(timeouts, dict):
            timeouts = PolicyAssignmentTimeouts(**timeouts)
        self._values: typing.Dict[str, typing.Any] = {
            "name": name,
            "policy_definition_id": policy_definition_id,
            "scope": scope,
        }
        if count is not None:
            self._values["count"] = count
        if depends_on is not None:
            self._values["depends_on"] = depends_on
        if lifecycle is not None:
            self._values["lifecycle"] = lifecycle
        if provider is not None:
            self._values["provider"] = provider
        if description is not None:
            self._values["description"] = description
        if display_name is not None:
            self._values["display_name"] = display_name
        if identity is not None:
            self._values["identity"] = identity
        if location is not None:
            self._values["location"] = location
        if not_scopes is not None:
            self._values["not_scopes"] = not_scopes
        if parameters is not None:
            self._values["parameters"] = parameters
        if timeouts is not None:
            self._values["timeouts"] = timeouts

    @builtins.property
    def count(self) -> typing.Optional[jsii.Number]:
        """
        :stability: experimental
        """
        result = self._values.get("count")
        return result

    @builtins.property
    def depends_on(self) -> typing.Optional[typing.List[cdktf.TerraformResource]]:
        """
        :stability: experimental
        """
        result = self._values.get("depends_on")
        return result

    @builtins.property
    def lifecycle(self) -> typing.Optional[cdktf.TerraformResourceLifecycle]:
        """
        :stability: experimental
        """
        result = self._values.get("lifecycle")
        return result

    @builtins.property
    def provider(self) -> typing.Optional[cdktf.TerraformProvider]:
        """
        :stability: experimental
        """
        result = self._values.get("provider")
        return result

    @builtins.property
    def name(self) -> builtins.str:
        result = self._values.get("name")
        assert result is not None, "Required property 'name' is missing"
        return result

    @builtins.property
    def policy_definition_id(self) -> builtins.str:
        result = self._values.get("policy_definition_id")
        assert result is not None, "Required property 'policy_definition_id' is missing"
        return result

    @builtins.property
    def scope(self) -> builtins.str:
        result = self._values.get("scope")
        assert result is not None, "Required property 'scope' is missing"
        return result

    @builtins.property
    def description(self) -> typing.Optional[builtins.str]:
        result = self._values.get("description")
        return result

    @builtins.property
    def display_name(self) -> typing.Optional[builtins.str]:
        result = self._values.get("display_name")
        return result

    @builtins.property
    def identity(self) -> typing.Optional[typing.List["PolicyAssignmentIdentity"]]:
        """identity block."""
        result = self._values.get("identity")
        return result

    @builtins.property
    def location(self) -> typing.Optional[builtins.str]:
        result = self._values.get("location")
        return result

    @builtins.property
    def not_scopes(self) -> typing.Optional[typing.List[builtins.str]]:
        result = self._values.get("not_scopes")
        return result

    @builtins.property
    def parameters(self) -> typing.Optional[builtins.str]:
        result = self._values.get("parameters")
        return result

    @builtins.property
    def timeouts(self) -> typing.Optional["PolicyAssignmentTimeouts"]:
        """timeouts block."""
        result = self._values.get("timeouts")
        return result

    def __eq__(self, rhs: typing.Any) -> builtins.bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs: typing.Any) -> builtins.bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return "PolicyAssignmentConfig(%s)" % ", ".join(
            k + "=" + repr(v) for k, v in self._values.items()
        )


@jsii.data_type(
    jsii_type="@cdktf/provider-azurerm.PolicyAssignmentIdentity",
    jsii_struct_bases=[],
    name_mapping={"type": "type"},
)
class PolicyAssignmentIdentity:
    def __init__(self, *, type: typing.Optional[builtins.str] = None) -> None:
        """
        :param type: 
        """
        self._values: typing.Dict[str, typing.Any] = {}
        if type is not None:
            self._values["type"] = type

    @builtins.property
    def type(self) -> typing.Optional[builtins.str]:
        result = self._values.get("type")
        return result

    def __eq__(self, rhs: typing.Any) -> builtins.bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs: typing.Any) -> builtins.bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return "PolicyAssignmentIdentity(%s)" % ", ".join(
            k + "=" + repr(v) for k, v in self._values.items()
        )


@jsii.data_type(
    jsii_type="@cdktf/provider-azurerm.PolicyAssignmentTimeouts",
    jsii_struct_bases=[],
    name_mapping={
        "create": "create",
        "delete": "delete",
        "read": "read",
        "update": "update",
    },
)
class PolicyAssignmentTimeouts:
    def __init__(
        self,
        *,
        create: typing.Optional[builtins.str] = None,
        delete: typing.Optional[builtins.str] = None,
        read: typing.Optional[builtins.str] = None,
        update: typing.Optional[builtins.str] = None,
    ) -> None:
        """
        :param create: 
        :param delete: 
        :param read: 
        :param update: 
        """
        self._values: typing.Dict[str, typing.Any] = {}
        if create is not None:
            self._values["create"] = create
        if delete is not None:
            self._values["delete"] = delete
        if read is not None:
            self._values["read"] = read
        if update is not None:
            self._values["update"] = update

    @builtins.property
    def create(self) -> typing.Optional[builtins.str]:
        result = self._values.get("create")
        return result

    @builtins.property
    def delete(self) -> typing.Optional[builtins.str]:
        result = self._values.get("delete")
        return result

    @builtins.property
    def read(self) -> typing.Optional[builtins.str]:
        result = self._values.get("read")
        return result

    @builtins.property
    def update(self) -> typing.Optional[builtins.str]:
        result = self._values.get("update")
        return result

    def __eq__(self, rhs: typing.Any) -> builtins.bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs: typing.Any) -> builtins.bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return "PolicyAssignmentTimeouts(%s)" % ", ".join(
            k + "=" + repr(v) for k, v in self._values.items()
        )


class PolicyDefinition(
    cdktf.TerraformResource,
    metaclass=jsii.JSIIMeta,
    jsii_type="@cdktf/provider-azurerm.PolicyDefinition",
):
    def __init__(
        self,
        scope: constructs.Construct,
        id: builtins.str,
        *,
        display_name: builtins.str,
        mode: builtins.str,
        name: builtins.str,
        policy_type: builtins.str,
        description: typing.Optional[builtins.str] = None,
        management_group_id: typing.Optional[builtins.str] = None,
        metadata: typing.Optional[builtins.str] = None,
        parameters: typing.Optional[builtins.str] = None,
        policy_rule: typing.Optional[builtins.str] = None,
        timeouts: typing.Optional["PolicyDefinitionTimeouts"] = None,
        count: typing.Optional[jsii.Number] = None,
        depends_on: typing.Optional[typing.List[cdktf.TerraformResource]] = None,
        lifecycle: typing.Optional[cdktf.TerraformResourceLifecycle] = None,
        provider: typing.Optional[cdktf.TerraformProvider] = None,
    ) -> None:
        """
        :param scope: -
        :param id: -
        :param display_name: 
        :param mode: 
        :param name: 
        :param policy_type: 
        :param description: 
        :param management_group_id: 
        :param metadata: 
        :param parameters: 
        :param policy_rule: 
        :param timeouts: timeouts block.
        :param count: 
        :param depends_on: 
        :param lifecycle: 
        :param provider: 
        """
        config = PolicyDefinitionConfig(
            display_name=display_name,
            mode=mode,
            name=name,
            policy_type=policy_type,
            description=description,
            management_group_id=management_group_id,
            metadata=metadata,
            parameters=parameters,
            policy_rule=policy_rule,
            timeouts=timeouts,
            count=count,
            depends_on=depends_on,
            lifecycle=lifecycle,
            provider=provider,
        )

        jsii.create(PolicyDefinition, self, [scope, id, config])

    @jsii.member(jsii_name="synthesizeAttributes")
    def _synthesize_attributes(self) -> typing.Mapping[builtins.str, typing.Any]:
        return jsii.invoke(self, "synthesizeAttributes", [])

    @builtins.property # type: ignore
    @jsii.member(jsii_name="displayName")
    def display_name(self) -> builtins.str:
        return jsii.get(self, "displayName")

    @display_name.setter # type: ignore
    def display_name(self, value: builtins.str) -> None:
        jsii.set(self, "displayName", value)

    @builtins.property # type: ignore
    @jsii.member(jsii_name="mode")
    def mode(self) -> builtins.str:
        return jsii.get(self, "mode")

    @mode.setter # type: ignore
    def mode(self, value: builtins.str) -> None:
        jsii.set(self, "mode", value)

    @builtins.property # type: ignore
    @jsii.member(jsii_name="name")
    def name(self) -> builtins.str:
        return jsii.get(self, "name")

    @name.setter # type: ignore
    def name(self, value: builtins.str) -> None:
        jsii.set(self, "name", value)

    @builtins.property # type: ignore
    @jsii.member(jsii_name="policyType")
    def policy_type(self) -> builtins.str:
        return jsii.get(self, "policyType")

    @policy_type.setter # type: ignore
    def policy_type(self, value: builtins.str) -> None:
        jsii.set(self, "policyType", value)

    @builtins.property # type: ignore
    @jsii.member(jsii_name="description")
    def description(self) -> typing.Optional[builtins.str]:
        return jsii.get(self, "description")

    @description.setter # type: ignore
    def description(self, value: typing.Optional[builtins.str]) -> None:
        jsii.set(self, "description", value)

    @builtins.property # type: ignore
    @jsii.member(jsii_name="id")
    def id(self) -> typing.Optional[builtins.str]:
        return jsii.get(self, "id")

    @id.setter # type: ignore
    def id(self, value: typing.Optional[builtins.str]) -> None:
        jsii.set(self, "id", value)

    @builtins.property # type: ignore
    @jsii.member(jsii_name="managementGroupId")
    def management_group_id(self) -> typing.Optional[builtins.str]:
        return jsii.get(self, "managementGroupId")

    @management_group_id.setter # type: ignore
    def management_group_id(self, value: typing.Optional[builtins.str]) -> None:
        jsii.set(self, "managementGroupId", value)

    @builtins.property # type: ignore
    @jsii.member(jsii_name="metadata")
    def metadata(self) -> typing.Optional[builtins.str]:
        return jsii.get(self, "metadata")

    @metadata.setter # type: ignore
    def metadata(self, value: typing.Optional[builtins.str]) -> None:
        jsii.set(self, "metadata", value)

    @builtins.property # type: ignore
    @jsii.member(jsii_name="parameters")
    def parameters(self) -> typing.Optional[builtins.str]:
        return jsii.get(self, "parameters")

    @parameters.setter # type: ignore
    def parameters(self, value: typing.Optional[builtins.str]) -> None:
        jsii.set(self, "parameters", value)

    @builtins.property # type: ignore
    @jsii.member(jsii_name="policyRule")
    def policy_rule(self) -> typing.Optional[builtins.str]:
        return jsii.get(self, "policyRule")

    @policy_rule.setter # type: ignore
    def policy_rule(self, value: typing.Optional[builtins.str]) -> None:
        jsii.set(self, "policyRule", value)

    @builtins.property # type: ignore
    @jsii.member(jsii_name="timeouts")
    def timeouts(self) -> typing.Optional["PolicyDefinitionTimeouts"]:
        return jsii.get(self, "timeouts")

    @timeouts.setter # type: ignore
    def timeouts(self, value: typing.Optional["PolicyDefinitionTimeouts"]) -> None:
        jsii.set(self, "timeouts", value)


@jsii.data_type(
    jsii_type="@cdktf/provider-azurerm.PolicyDefinitionConfig",
    jsii_struct_bases=[cdktf.TerraformMetaArguments],
    name_mapping={
        "count": "count",
        "depends_on": "dependsOn",
        "lifecycle": "lifecycle",
        "provider": "provider",
        "display_name": "displayName",
        "mode": "mode",
        "name": "name",
        "policy_type": "policyType",
        "description": "description",
        "management_group_id": "managementGroupId",
        "metadata": "metadata",
        "parameters": "parameters",
        "policy_rule": "policyRule",
        "timeouts": "timeouts",
    },
)
class PolicyDefinitionConfig(cdktf.TerraformMetaArguments):
    def __init__(
        self,
        *,
        count: typing.Optional[jsii.Number] = None,
        depends_on: typing.Optional[typing.List[cdktf.TerraformResource]] = None,
        lifecycle: typing.Optional[cdktf.TerraformResourceLifecycle] = None,
        provider: typing.Optional[cdktf.TerraformProvider] = None,
        display_name: builtins.str,
        mode: builtins.str,
        name: builtins.str,
        policy_type: builtins.str,
        description: typing.Optional[builtins.str] = None,
        management_group_id: typing.Optional[builtins.str] = None,
        metadata: typing.Optional[builtins.str] = None,
        parameters: typing.Optional[builtins.str] = None,
        policy_rule: typing.Optional[builtins.str] = None,
        timeouts: typing.Optional["PolicyDefinitionTimeouts"] = None,
    ) -> None:
        """
        :param count: 
        :param depends_on: 
        :param lifecycle: 
        :param provider: 
        :param display_name: 
        :param mode: 
        :param name: 
        :param policy_type: 
        :param description: 
        :param management_group_id: 
        :param metadata: 
        :param parameters: 
        :param policy_rule: 
        :param timeouts: timeouts block.
        """
        if isinstance(lifecycle, dict):
            lifecycle = cdktf.TerraformResourceLifecycle(**lifecycle)
        if isinstance(timeouts, dict):
            timeouts = PolicyDefinitionTimeouts(**timeouts)
        self._values: typing.Dict[str, typing.Any] = {
            "display_name": display_name,
            "mode": mode,
            "name": name,
            "policy_type": policy_type,
        }
        if count is not None:
            self._values["count"] = count
        if depends_on is not None:
            self._values["depends_on"] = depends_on
        if lifecycle is not None:
            self._values["lifecycle"] = lifecycle
        if provider is not None:
            self._values["provider"] = provider
        if description is not None:
            self._values["description"] = description
        if management_group_id is not None:
            self._values["management_group_id"] = management_group_id
        if metadata is not None:
            self._values["metadata"] = metadata
        if parameters is not None:
            self._values["parameters"] = parameters
        if policy_rule is not None:
            self._values["policy_rule"] = policy_rule
        if timeouts is not None:
            self._values["timeouts"] = timeouts

    @builtins.property
    def count(self) -> typing.Optional[jsii.Number]:
        """
        :stability: experimental
        """
        result = self._values.get("count")
        return result

    @builtins.property
    def depends_on(self) -> typing.Optional[typing.List[cdktf.TerraformResource]]:
        """
        :stability: experimental
        """
        result = self._values.get("depends_on")
        return result

    @builtins.property
    def lifecycle(self) -> typing.Optional[cdktf.TerraformResourceLifecycle]:
        """
        :stability: experimental
        """
        result = self._values.get("lifecycle")
        return result

    @builtins.property
    def provider(self) -> typing.Optional[cdktf.TerraformProvider]:
        """
        :stability: experimental
        """
        result = self._values.get("provider")
        return result

    @builtins.property
    def display_name(self) -> builtins.str:
        result = self._values.get("display_name")
        assert result is not None, "Required property 'display_name' is missing"
        return result

    @builtins.property
    def mode(self) -> builtins.str:
        result = self._values.get("mode")
        assert result is not None, "Required property 'mode' is missing"
        return result

    @builtins.property
    def name(self) -> builtins.str:
        result = self._values.get("name")
        assert result is not None, "Required property 'name' is missing"
        return result

    @builtins.property
    def policy_type(self) -> builtins.str:
        result = self._values.get("policy_type")
        assert result is not None, "Required property 'policy_type' is missing"
        return result

    @builtins.property
    def description(self) -> typing.Optional[builtins.str]:
        result = self._values.get("description")
        return result

    @builtins.property
    def management_group_id(self) -> typing.Optional[builtins.str]:
        result = self._values.get("management_group_id")
        return result

    @builtins.property
    def metadata(self) -> typing.Optional[builtins.str]:
        result = self._values.get("metadata")
        return result

    @builtins.property
    def parameters(self) -> typing.Optional[builtins.str]:
        result = self._values.get("parameters")
        return result

    @builtins.property
    def policy_rule(self) -> typing.Optional[builtins.str]:
        result = self._values.get("policy_rule")
        return result

    @builtins.property
    def timeouts(self) -> typing.Optional["PolicyDefinitionTimeouts"]:
        """timeouts block."""
        result = self._values.get("timeouts")
        return result

    def __eq__(self, rhs: typing.Any) -> builtins.bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs: typing.Any) -> builtins.bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return "PolicyDefinitionConfig(%s)" % ", ".join(
            k + "=" + repr(v) for k, v in self._values.items()
        )


@jsii.data_type(
    jsii_type="@cdktf/provider-azurerm.PolicyDefinitionTimeouts",
    jsii_struct_bases=[],
    name_mapping={
        "create": "create",
        "delete": "delete",
        "read": "read",
        "update": "update",
    },
)
class PolicyDefinitionTimeouts:
    def __init__(
        self,
        *,
        create: typing.Optional[builtins.str] = None,
        delete: typing.Optional[builtins.str] = None,
        read: typing.Optional[builtins.str] = None,
        update: typing.Optional[builtins.str] = None,
    ) -> None:
        """
        :param create: 
        :param delete: 
        :param read: 
        :param update: 
        """
        self._values: typing.Dict[str, typing.Any] = {}
        if create is not None:
            self._values["create"] = create
        if delete is not None:
            self._values["delete"] = delete
        if read is not None:
            self._values["read"] = read
        if update is not None:
            self._values["update"] = update

    @builtins.property
    def create(self) -> typing.Optional[builtins.str]:
        result = self._values.get("create")
        return result

    @builtins.property
    def delete(self) -> typing.Optional[builtins.str]:
        result = self._values.get("delete")
        return result

    @builtins.property
    def read(self) -> typing.Optional[builtins.str]:
        result = self._values.get("read")
        return result

    @builtins.property
    def update(self) -> typing.Optional[builtins.str]:
        result = self._values.get("update")
        return result

    def __eq__(self, rhs: typing.Any) -> builtins.bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs: typing.Any) -> builtins.bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return "PolicyDefinitionTimeouts(%s)" % ", ".join(
            k + "=" + repr(v) for k, v in self._values.items()
        )


class PolicySetDefinition(
    cdktf.TerraformResource,
    metaclass=jsii.JSIIMeta,
    jsii_type="@cdktf/provider-azurerm.PolicySetDefinition",
):
    def __init__(
        self,
        scope: constructs.Construct,
        id: builtins.str,
        *,
        display_name: builtins.str,
        name: builtins.str,
        policy_type: builtins.str,
        description: typing.Optional[builtins.str] = None,
        management_group_id: typing.Optional[builtins.str] = None,
        metadata: typing.Optional[builtins.str] = None,
        parameters: typing.Optional[builtins.str] = None,
        policy_definitions: typing.Optional[builtins.str] = None,
        timeouts: typing.Optional["PolicySetDefinitionTimeouts"] = None,
        count: typing.Optional[jsii.Number] = None,
        depends_on: typing.Optional[typing.List[cdktf.TerraformResource]] = None,
        lifecycle: typing.Optional[cdktf.TerraformResourceLifecycle] = None,
        provider: typing.Optional[cdktf.TerraformProvider] = None,
    ) -> None:
        """
        :param scope: -
        :param id: -
        :param display_name: 
        :param name: 
        :param policy_type: 
        :param description: 
        :param management_group_id: 
        :param metadata: 
        :param parameters: 
        :param policy_definitions: 
        :param timeouts: timeouts block.
        :param count: 
        :param depends_on: 
        :param lifecycle: 
        :param provider: 
        """
        config = PolicySetDefinitionConfig(
            display_name=display_name,
            name=name,
            policy_type=policy_type,
            description=description,
            management_group_id=management_group_id,
            metadata=metadata,
            parameters=parameters,
            policy_definitions=policy_definitions,
            timeouts=timeouts,
            count=count,
            depends_on=depends_on,
            lifecycle=lifecycle,
            provider=provider,
        )

        jsii.create(PolicySetDefinition, self, [scope, id, config])

    @jsii.member(jsii_name="synthesizeAttributes")
    def _synthesize_attributes(self) -> typing.Mapping[builtins.str, typing.Any]:
        return jsii.invoke(self, "synthesizeAttributes", [])

    @builtins.property # type: ignore
    @jsii.member(jsii_name="displayName")
    def display_name(self) -> builtins.str:
        return jsii.get(self, "displayName")

    @display_name.setter # type: ignore
    def display_name(self, value: builtins.str) -> None:
        jsii.set(self, "displayName", value)

    @builtins.property # type: ignore
    @jsii.member(jsii_name="name")
    def name(self) -> builtins.str:
        return jsii.get(self, "name")

    @name.setter # type: ignore
    def name(self, value: builtins.str) -> None:
        jsii.set(self, "name", value)

    @builtins.property # type: ignore
    @jsii.member(jsii_name="policyType")
    def policy_type(self) -> builtins.str:
        return jsii.get(self, "policyType")

    @policy_type.setter # type: ignore
    def policy_type(self, value: builtins.str) -> None:
        jsii.set(self, "policyType", value)

    @builtins.property # type: ignore
    @jsii.member(jsii_name="description")
    def description(self) -> typing.Optional[builtins.str]:
        return jsii.get(self, "description")

    @description.setter # type: ignore
    def description(self, value: typing.Optional[builtins.str]) -> None:
        jsii.set(self, "description", value)

    @builtins.property # type: ignore
    @jsii.member(jsii_name="id")
    def id(self) -> typing.Optional[builtins.str]:
        return jsii.get(self, "id")

    @id.setter # type: ignore
    def id(self, value: typing.Optional[builtins.str]) -> None:
        jsii.set(self, "id", value)

    @builtins.property # type: ignore
    @jsii.member(jsii_name="managementGroupId")
    def management_group_id(self) -> typing.Optional[builtins.str]:
        return jsii.get(self, "managementGroupId")

    @management_group_id.setter # type: ignore
    def management_group_id(self, value: typing.Optional[builtins.str]) -> None:
        jsii.set(self, "managementGroupId", value)

    @builtins.property # type: ignore
    @jsii.member(jsii_name="metadata")
    def metadata(self) -> typing.Optional[builtins.str]:
        return jsii.get(self, "metadata")

    @metadata.setter # type: ignore
    def metadata(self, value: typing.Optional[builtins.str]) -> None:
        jsii.set(self, "metadata", value)

    @builtins.property # type: ignore
    @jsii.member(jsii_name="parameters")
    def parameters(self) -> typing.Optional[builtins.str]:
        return jsii.get(self, "parameters")

    @parameters.setter # type: ignore
    def parameters(self, value: typing.Optional[builtins.str]) -> None:
        jsii.set(self, "parameters", value)

    @builtins.property # type: ignore
    @jsii.member(jsii_name="policyDefinitions")
    def policy_definitions(self) -> typing.Optional[builtins.str]:
        return jsii.get(self, "policyDefinitions")

    @policy_definitions.setter # type: ignore
    def policy_definitions(self, value: typing.Optional[builtins.str]) -> None:
        jsii.set(self, "policyDefinitions", value)

    @builtins.property # type: ignore
    @jsii.member(jsii_name="timeouts")
    def timeouts(self) -> typing.Optional["PolicySetDefinitionTimeouts"]:
        return jsii.get(self, "timeouts")

    @timeouts.setter # type: ignore
    def timeouts(self, value: typing.Optional["PolicySetDefinitionTimeouts"]) -> None:
        jsii.set(self, "timeouts", value)


@jsii.data_type(
    jsii_type="@cdktf/provider-azurerm.PolicySetDefinitionConfig",
    jsii_struct_bases=[cdktf.TerraformMetaArguments],
    name_mapping={
        "count": "count",
        "depends_on": "dependsOn",
        "lifecycle": "lifecycle",
        "provider": "provider",
        "display_name": "displayName",
        "name": "name",
        "policy_type": "policyType",
        "description": "description",
        "management_group_id": "managementGroupId",
        "metadata": "metadata",
        "parameters": "parameters",
        "policy_definitions": "policyDefinitions",
        "timeouts": "timeouts",
    },
)
class PolicySetDefinitionConfig(cdktf.TerraformMetaArguments):
    def __init__(
        self,
        *,
        count: typing.Optional[jsii.Number] = None,
        depends_on: typing.Optional[typing.List[cdktf.TerraformResource]] = None,
        lifecycle: typing.Optional[cdktf.TerraformResourceLifecycle] = None,
        provider: typing.Optional[cdktf.TerraformProvider] = None,
        display_name: builtins.str,
        name: builtins.str,
        policy_type: builtins.str,
        description: typing.Optional[builtins.str] = None,
        management_group_id: typing.Optional[builtins.str] = None,
        metadata: typing.Optional[builtins.str] = None,
        parameters: typing.Optional[builtins.str] = None,
        policy_definitions: typing.Optional[builtins.str] = None,
        timeouts: typing.Optional["PolicySetDefinitionTimeouts"] = None,
    ) -> None:
        """
        :param count: 
        :param depends_on: 
        :param lifecycle: 
        :param provider: 
        :param display_name: 
        :param name: 
        :param policy_type: 
        :param description: 
        :param management_group_id: 
        :param metadata: 
        :param parameters: 
        :param policy_definitions: 
        :param timeouts: timeouts block.
        """
        if isinstance(lifecycle, dict):
            lifecycle = cdktf.TerraformResourceLifecycle(**lifecycle)
        if isinstance(timeouts, dict):
            timeouts = PolicySetDefinitionTimeouts(**timeouts)
        self._values: typing.Dict[str, typing.Any] = {
            "display_name": display_name,
            "name": name,
            "policy_type": policy_type,
        }
        if count is not None:
            self._values["count"] = count
        if depends_on is not None:
            self._values["depends_on"] = depends_on
        if lifecycle is not None:
            self._values["lifecycle"] = lifecycle
        if provider is not None:
            self._values["provider"] = provider
        if description is not None:
            self._values["description"] = description
        if management_group_id is not None:
            self._values["management_group_id"] = management_group_id
        if metadata is not None:
            self._values["metadata"] = metadata
        if parameters is not None:
            self._values["parameters"] = parameters
        if policy_definitions is not None:
            self._values["policy_definitions"] = policy_definitions
        if timeouts is not None:
            self._values["timeouts"] = timeouts

    @builtins.property
    def count(self) -> typing.Optional[jsii.Number]:
        """
        :stability: experimental
        """
        result = self._values.get("count")
        return result

    @builtins.property
    def depends_on(self) -> typing.Optional[typing.List[cdktf.TerraformResource]]:
        """
        :stability: experimental
        """
        result = self._values.get("depends_on")
        return result

    @builtins.property
    def lifecycle(self) -> typing.Optional[cdktf.TerraformResourceLifecycle]:
        """
        :stability: experimental
        """
        result = self._values.get("lifecycle")
        return result

    @builtins.property
    def provider(self) -> typing.Optional[cdktf.TerraformProvider]:
        """
        :stability: experimental
        """
        result = self._values.get("provider")
        return result

    @builtins.property
    def display_name(self) -> builtins.str:
        result = self._values.get("display_name")
        assert result is not None, "Required property 'display_name' is missing"
        return result

    @builtins.property
    def name(self) -> builtins.str:
        result = self._values.get("name")
        assert result is not None, "Required property 'name' is missing"
        return result

    @builtins.property
    def policy_type(self) -> builtins.str:
        result = self._values.get("policy_type")
        assert result is not None, "Required property 'policy_type' is missing"
        return result

    @builtins.property
    def description(self) -> typing.Optional[builtins.str]:
        result = self._values.get("description")
        return result

    @builtins.property
    def management_group_id(self) -> typing.Optional[builtins.str]:
        result = self._values.get("management_group_id")
        return result

    @builtins.property
    def metadata(self) -> typing.Optional[builtins.str]:
        result = self._values.get("metadata")
        return result

    @builtins.property
    def parameters(self) -> typing.Optional[builtins.str]:
        result = self._values.get("parameters")
        return result

    @builtins.property
    def policy_definitions(self) -> typing.Optional[builtins.str]:
        result = self._values.get("policy_definitions")
        return result

    @builtins.property
    def timeouts(self) -> typing.Optional["PolicySetDefinitionTimeouts"]:
        """timeouts block."""
        result = self._values.get("timeouts")
        return result

    def __eq__(self, rhs: typing.Any) -> builtins.bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs: typing.Any) -> builtins.bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return "PolicySetDefinitionConfig(%s)" % ", ".join(
            k + "=" + repr(v) for k, v in self._values.items()
        )


@jsii.data_type(
    jsii_type="@cdktf/provider-azurerm.PolicySetDefinitionTimeouts",
    jsii_struct_bases=[],
    name_mapping={
        "create": "create",
        "delete": "delete",
        "read": "read",
        "update": "update",
    },
)
class PolicySetDefinitionTimeouts:
    def __init__(
        self,
        *,
        create: typing.Optional[builtins.str] = None,
        delete: typing.Optional[builtins.str] = None,
        read: typing.Optional[builtins.str] = None,
        update: typing.Optional[builtins.str] = None,
    ) -> None:
        """
        :param create: 
        :param delete: 
        :param read: 
        :param update: 
        """
        self._values: typing.Dict[str, typing.Any] = {}
        if create is not None:
            self._values["create"] = create
        if delete is not None:
            self._values["delete"] = delete
        if read is not None:
            self._values["read"] = read
        if update is not None:
            self._values["update"] = update

    @builtins.property
    def create(self) -> typing.Optional[builtins.str]:
        result = self._values.get("create")
        return result

    @builtins.property
    def delete(self) -> typing.Optional[builtins.str]:
        result = self._values.get("delete")
        return result

    @builtins.property
    def read(self) -> typing.Optional[builtins.str]:
        result = self._values.get("read")
        return result

    @builtins.property
    def update(self) -> typing.Optional[builtins.str]:
        result = self._values.get("update")
        return result

    def __eq__(self, rhs: typing.Any) -> builtins.bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs: typing.Any) -> builtins.bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return "PolicySetDefinitionTimeouts(%s)" % ", ".join(
            k + "=" + repr(v) for k, v in self._values.items()
        )


class PostgresqlConfiguration(
    cdktf.TerraformResource,
    metaclass=jsii.JSIIMeta,
    jsii_type="@cdktf/provider-azurerm.PostgresqlConfiguration",
):
    def __init__(
        self,
        scope: constructs.Construct,
        id: builtins.str,
        *,
        name: builtins.str,
        resource_group_name: builtins.str,
        server_name: builtins.str,
        value: builtins.str,
        timeouts: typing.Optional["PostgresqlConfigurationTimeouts"] = None,
        count: typing.Optional[jsii.Number] = None,
        depends_on: typing.Optional[typing.List[cdktf.TerraformResource]] = None,
        lifecycle: typing.Optional[cdktf.TerraformResourceLifecycle] = None,
        provider: typing.Optional[cdktf.TerraformProvider] = None,
    ) -> None:
        """
        :param scope: -
        :param id: -
        :param name: 
        :param resource_group_name: 
        :param server_name: 
        :param value: 
        :param timeouts: timeouts block.
        :param count: 
        :param depends_on: 
        :param lifecycle: 
        :param provider: 
        """
        config = PostgresqlConfigurationConfig(
            name=name,
            resource_group_name=resource_group_name,
            server_name=server_name,
            value=value,
            timeouts=timeouts,
            count=count,
            depends_on=depends_on,
            lifecycle=lifecycle,
            provider=provider,
        )

        jsii.create(PostgresqlConfiguration, self, [scope, id, config])

    @jsii.member(jsii_name="synthesizeAttributes")
    def _synthesize_attributes(self) -> typing.Mapping[builtins.str, typing.Any]:
        return jsii.invoke(self, "synthesizeAttributes", [])

    @builtins.property # type: ignore
    @jsii.member(jsii_name="name")
    def name(self) -> builtins.str:
        return jsii.get(self, "name")

    @name.setter # type: ignore
    def name(self, value: builtins.str) -> None:
        jsii.set(self, "name", value)

    @builtins.property # type: ignore
    @jsii.member(jsii_name="resourceGroupName")
    def resource_group_name(self) -> builtins.str:
        return jsii.get(self, "resourceGroupName")

    @resource_group_name.setter # type: ignore
    def resource_group_name(self, value: builtins.str) -> None:
        jsii.set(self, "resourceGroupName", value)

    @builtins.property # type: ignore
    @jsii.member(jsii_name="serverName")
    def server_name(self) -> builtins.str:
        return jsii.get(self, "serverName")

    @server_name.setter # type: ignore
    def server_name(self, value: builtins.str) -> None:
        jsii.set(self, "serverName", value)

    @builtins.property # type: ignore
    @jsii.member(jsii_name="value")
    def value(self) -> builtins.str:
        return jsii.get(self, "value")

    @value.setter # type: ignore
    def value(self, value: builtins.str) -> None:
        jsii.set(self, "value", value)

    @builtins.property # type: ignore
    @jsii.member(jsii_name="id")
    def id(self) -> typing.Optional[builtins.str]:
        return jsii.get(self, "id")

    @id.setter # type: ignore
    def id(self, value: typing.Optional[builtins.str]) -> None:
        jsii.set(self, "id", value)

    @builtins.property # type: ignore
    @jsii.member(jsii_name="timeouts")
    def timeouts(self) -> typing.Optional["PostgresqlConfigurationTimeouts"]:
        return jsii.get(self, "timeouts")

    @timeouts.setter # type: ignore
    def timeouts(
        self,
        value: typing.Optional["PostgresqlConfigurationTimeouts"],
    ) -> None:
        jsii.set(self, "timeouts", value)


@jsii.data_type(
    jsii_type="@cdktf/provider-azurerm.PostgresqlConfigurationConfig",
    jsii_struct_bases=[cdktf.TerraformMetaArguments],
    name_mapping={
        "count": "count",
        "depends_on": "dependsOn",
        "lifecycle": "lifecycle",
        "provider": "provider",
        "name": "name",
        "resource_group_name": "resourceGroupName",
        "server_name": "serverName",
        "value": "value",
        "timeouts": "timeouts",
    },
)
class PostgresqlConfigurationConfig(cdktf.TerraformMetaArguments):
    def __init__(
        self,
        *,
        count: typing.Optional[jsii.Number] = None,
        depends_on: typing.Optional[typing.List[cdktf.TerraformResource]] = None,
        lifecycle: typing.Optional[cdktf.TerraformResourceLifecycle] = None,
        provider: typing.Optional[cdktf.TerraformProvider] = None,
        name: builtins.str,
        resource_group_name: builtins.str,
        server_name: builtins.str,
        value: builtins.str,
        timeouts: typing.Optional["PostgresqlConfigurationTimeouts"] = None,
    ) -> None:
        """
        :param count: 
        :param depends_on: 
        :param lifecycle: 
        :param provider: 
        :param name: 
        :param resource_group_name: 
        :param server_name: 
        :param value: 
        :param timeouts: timeouts block.
        """
        if isinstance(lifecycle, dict):
            lifecycle = cdktf.TerraformResourceLifecycle(**lifecycle)
        if isinstance(timeouts, dict):
            timeouts = PostgresqlConfigurationTimeouts(**timeouts)
        self._values: typing.Dict[str, typing.Any] = {
            "name": name,
            "resource_group_name": resource_group_name,
            "server_name": server_name,
            "value": value,
        }
        if count is not None:
            self._values["count"] = count
        if depends_on is not None:
            self._values["depends_on"] = depends_on
        if lifecycle is not None:
            self._values["lifecycle"] = lifecycle
        if provider is not None:
            self._values["provider"] = provider
        if timeouts is not None:
            self._values["timeouts"] = timeouts

    @builtins.property
    def count(self) -> typing.Optional[jsii.Number]:
        """
        :stability: experimental
        """
        result = self._values.get("count")
        return result

    @builtins.property
    def depends_on(self) -> typing.Optional[typing.List[cdktf.TerraformResource]]:
        """
        :stability: experimental
        """
        result = self._values.get("depends_on")
        return result

    @builtins.property
    def lifecycle(self) -> typing.Optional[cdktf.TerraformResourceLifecycle]:
        """
        :stability: experimental
        """
        result = self._values.get("lifecycle")
        return result

    @builtins.property
    def provider(self) -> typing.Optional[cdktf.TerraformProvider]:
        """
        :stability: experimental
        """
        result = self._values.get("provider")
        return result

    @builtins.property
    def name(self) -> builtins.str:
        result = self._values.get("name")
        assert result is not None, "Required property 'name' is missing"
        return result

    @builtins.property
    def resource_group_name(self) -> builtins.str:
        result = self._values.get("resource_group_name")
        assert result is not None, "Required property 'resource_group_name' is missing"
        return result

    @builtins.property
    def server_name(self) -> builtins.str:
        result = self._values.get("server_name")
        assert result is not None, "Required property 'server_name' is missing"
        return result

    @builtins.property
    def value(self) -> builtins.str:
        result = self._values.get("value")
        assert result is not None, "Required property 'value' is missing"
        return result

    @builtins.property
    def timeouts(self) -> typing.Optional["PostgresqlConfigurationTimeouts"]:
        """timeouts block."""
        result = self._values.get("timeouts")
        return result

    def __eq__(self, rhs: typing.Any) -> builtins.bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs: typing.Any) -> builtins.bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return "PostgresqlConfigurationConfig(%s)" % ", ".join(
            k + "=" + repr(v) for k, v in self._values.items()
        )


@jsii.data_type(
    jsii_type="@cdktf/provider-azurerm.PostgresqlConfigurationTimeouts",
    jsii_struct_bases=[],
    name_mapping={
        "create": "create",
        "delete": "delete",
        "read": "read",
        "update": "update",
    },
)
class PostgresqlConfigurationTimeouts:
    def __init__(
        self,
        *,
        create: typing.Optional[builtins.str] = None,
        delete: typing.Optional[builtins.str] = None,
        read: typing.Optional[builtins.str] = None,
        update: typing.Optional[builtins.str] = None,
    ) -> None:
        """
        :param create: 
        :param delete: 
        :param read: 
        :param update: 
        """
        self._values: typing.Dict[str, typing.Any] = {}
        if create is not None:
            self._values["create"] = create
        if delete is not None:
            self._values["delete"] = delete
        if read is not None:
            self._values["read"] = read
        if update is not None:
            self._values["update"] = update

    @builtins.property
    def create(self) -> typing.Optional[builtins.str]:
        result = self._values.get("create")
        return result

    @builtins.property
    def delete(self) -> typing.Optional[builtins.str]:
        result = self._values.get("delete")
        return result

    @builtins.property
    def read(self) -> typing.Optional[builtins.str]:
        result = self._values.get("read")
        return result

    @builtins.property
    def update(self) -> typing.Optional[builtins.str]:
        result = self._values.get("update")
        return result

    def __eq__(self, rhs: typing.Any) -> builtins.bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs: typing.Any) -> builtins.bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return "PostgresqlConfigurationTimeouts(%s)" % ", ".join(
            k + "=" + repr(v) for k, v in self._values.items()
        )


class PostgresqlDatabase(
    cdktf.TerraformResource,
    metaclass=jsii.JSIIMeta,
    jsii_type="@cdktf/provider-azurerm.PostgresqlDatabase",
):
    def __init__(
        self,
        scope: constructs.Construct,
        id: builtins.str,
        *,
        charset: builtins.str,
        collation: builtins.str,
        name: builtins.str,
        resource_group_name: builtins.str,
        server_name: builtins.str,
        timeouts: typing.Optional["PostgresqlDatabaseTimeouts"] = None,
        count: typing.Optional[jsii.Number] = None,
        depends_on: typing.Optional[typing.List[cdktf.TerraformResource]] = None,
        lifecycle: typing.Optional[cdktf.TerraformResourceLifecycle] = None,
        provider: typing.Optional[cdktf.TerraformProvider] = None,
    ) -> None:
        """
        :param scope: -
        :param id: -
        :param charset: 
        :param collation: 
        :param name: 
        :param resource_group_name: 
        :param server_name: 
        :param timeouts: timeouts block.
        :param count: 
        :param depends_on: 
        :param lifecycle: 
        :param provider: 
        """
        config = PostgresqlDatabaseConfig(
            charset=charset,
            collation=collation,
            name=name,
            resource_group_name=resource_group_name,
            server_name=server_name,
            timeouts=timeouts,
            count=count,
            depends_on=depends_on,
            lifecycle=lifecycle,
            provider=provider,
        )

        jsii.create(PostgresqlDatabase, self, [scope, id, config])

    @jsii.member(jsii_name="synthesizeAttributes")
    def _synthesize_attributes(self) -> typing.Mapping[builtins.str, typing.Any]:
        return jsii.invoke(self, "synthesizeAttributes", [])

    @builtins.property # type: ignore
    @jsii.member(jsii_name="charset")
    def charset(self) -> builtins.str:
        return jsii.get(self, "charset")

    @charset.setter # type: ignore
    def charset(self, value: builtins.str) -> None:
        jsii.set(self, "charset", value)

    @builtins.property # type: ignore
    @jsii.member(jsii_name="collation")
    def collation(self) -> builtins.str:
        return jsii.get(self, "collation")

    @collation.setter # type: ignore
    def collation(self, value: builtins.str) -> None:
        jsii.set(self, "collation", value)

    @builtins.property # type: ignore
    @jsii.member(jsii_name="name")
    def name(self) -> builtins.str:
        return jsii.get(self, "name")

    @name.setter # type: ignore
    def name(self, value: builtins.str) -> None:
        jsii.set(self, "name", value)

    @builtins.property # type: ignore
    @jsii.member(jsii_name="resourceGroupName")
    def resource_group_name(self) -> builtins.str:
        return jsii.get(self, "resourceGroupName")

    @resource_group_name.setter # type: ignore
    def resource_group_name(self, value: builtins.str) -> None:
        jsii.set(self, "resourceGroupName", value)

    @builtins.property # type: ignore
    @jsii.member(jsii_name="serverName")
    def server_name(self) -> builtins.str:
        return jsii.get(self, "serverName")

    @server_name.setter # type: ignore
    def server_name(self, value: builtins.str) -> None:
        jsii.set(self, "serverName", value)

    @builtins.property # type: ignore
    @jsii.member(jsii_name="id")
    def id(self) -> typing.Optional[builtins.str]:
        return jsii.get(self, "id")

    @id.setter # type: ignore
    def id(self, value: typing.Optional[builtins.str]) -> None:
        jsii.set(self, "id", value)

    @builtins.property # type: ignore
    @jsii.member(jsii_name="timeouts")
    def timeouts(self) -> typing.Optional["PostgresqlDatabaseTimeouts"]:
        return jsii.get(self, "timeouts")

    @timeouts.setter # type: ignore
    def timeouts(self, value: typing.Optional["PostgresqlDatabaseTimeouts"]) -> None:
        jsii.set(self, "timeouts", value)


@jsii.data_type(
    jsii_type="@cdktf/provider-azurerm.PostgresqlDatabaseConfig",
    jsii_struct_bases=[cdktf.TerraformMetaArguments],
    name_mapping={
        "count": "count",
        "depends_on": "dependsOn",
        "lifecycle": "lifecycle",
        "provider": "provider",
        "charset": "charset",
        "collation": "collation",
        "name": "name",
        "resource_group_name": "resourceGroupName",
        "server_name": "serverName",
        "timeouts": "timeouts",
    },
)
class PostgresqlDatabaseConfig(cdktf.TerraformMetaArguments):
    def __init__(
        self,
        *,
        count: typing.Optional[jsii.Number] = None,
        depends_on: typing.Optional[typing.List[cdktf.TerraformResource]] = None,
        lifecycle: typing.Optional[cdktf.TerraformResourceLifecycle] = None,
        provider: typing.Optional[cdktf.TerraformProvider] = None,
        charset: builtins.str,
        collation: builtins.str,
        name: builtins.str,
        resource_group_name: builtins.str,
        server_name: builtins.str,
        timeouts: typing.Optional["PostgresqlDatabaseTimeouts"] = None,
    ) -> None:
        """
        :param count: 
        :param depends_on: 
        :param lifecycle: 
        :param provider: 
        :param charset: 
        :param collation: 
        :param name: 
        :param resource_group_name: 
        :param server_name: 
        :param timeouts: timeouts block.
        """
        if isinstance(lifecycle, dict):
            lifecycle = cdktf.TerraformResourceLifecycle(**lifecycle)
        if isinstance(timeouts, dict):
            timeouts = PostgresqlDatabaseTimeouts(**timeouts)
        self._values: typing.Dict[str, typing.Any] = {
            "charset": charset,
            "collation": collation,
            "name": name,
            "resource_group_name": resource_group_name,
            "server_name": server_name,
        }
        if count is not None:
            self._values["count"] = count
        if depends_on is not None:
            self._values["depends_on"] = depends_on
        if lifecycle is not None:
            self._values["lifecycle"] = lifecycle
        if provider is not None:
            self._values["provider"] = provider
        if timeouts is not None:
            self._values["timeouts"] = timeouts

    @builtins.property
    def count(self) -> typing.Optional[jsii.Number]:
        """
        :stability: experimental
        """
        result = self._values.get("count")
        return result

    @builtins.property
    def depends_on(self) -> typing.Optional[typing.List[cdktf.TerraformResource]]:
        """
        :stability: experimental
        """
        result = self._values.get("depends_on")
        return result

    @builtins.property
    def lifecycle(self) -> typing.Optional[cdktf.TerraformResourceLifecycle]:
        """
        :stability: experimental
        """
        result = self._values.get("lifecycle")
        return result

    @builtins.property
    def provider(self) -> typing.Optional[cdktf.TerraformProvider]:
        """
        :stability: experimental
        """
        result = self._values.get("provider")
        return result

    @builtins.property
    def charset(self) -> builtins.str:
        result = self._values.get("charset")
        assert result is not None, "Required property 'charset' is missing"
        return result

    @builtins.property
    def collation(self) -> builtins.str:
        result = self._values.get("collation")
        assert result is not None, "Required property 'collation' is missing"
        return result

    @builtins.property
    def name(self) -> builtins.str:
        result = self._values.get("name")
        assert result is not None, "Required property 'name' is missing"
        return result

    @builtins.property
    def resource_group_name(self) -> builtins.str:
        result = self._values.get("resource_group_name")
        assert result is not None, "Required property 'resource_group_name' is missing"
        return result

    @builtins.property
    def server_name(self) -> builtins.str:
        result = self._values.get("server_name")
        assert result is not None, "Required property 'server_name' is missing"
        return result

    @builtins.property
    def timeouts(self) -> typing.Optional["PostgresqlDatabaseTimeouts"]:
        """timeouts block."""
        result = self._values.get("timeouts")
        return result

    def __eq__(self, rhs: typing.Any) -> builtins.bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs: typing.Any) -> builtins.bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return "PostgresqlDatabaseConfig(%s)" % ", ".join(
            k + "=" + repr(v) for k, v in self._values.items()
        )


@jsii.data_type(
    jsii_type="@cdktf/provider-azurerm.PostgresqlDatabaseTimeouts",
    jsii_struct_bases=[],
    name_mapping={
        "create": "create",
        "delete": "delete",
        "read": "read",
        "update": "update",
    },
)
class PostgresqlDatabaseTimeouts:
    def __init__(
        self,
        *,
        create: typing.Optional[builtins.str] = None,
        delete: typing.Optional[builtins.str] = None,
        read: typing.Optional[builtins.str] = None,
        update: typing.Optional[builtins.str] = None,
    ) -> None:
        """
        :param create: 
        :param delete: 
        :param read: 
        :param update: 
        """
        self._values: typing.Dict[str, typing.Any] = {}
        if create is not None:
            self._values["create"] = create
        if delete is not None:
            self._values["delete"] = delete
        if read is not None:
            self._values["read"] = read
        if update is not None:
            self._values["update"] = update

    @builtins.property
    def create(self) -> typing.Optional[builtins.str]:
        result = self._values.get("create")
        return result

    @builtins.property
    def delete(self) -> typing.Optional[builtins.str]:
        result = self._values.get("delete")
        return result

    @builtins.property
    def read(self) -> typing.Optional[builtins.str]:
        result = self._values.get("read")
        return result

    @builtins.property
    def update(self) -> typing.Optional[builtins.str]:
        result = self._values.get("update")
        return result

    def __eq__(self, rhs: typing.Any) -> builtins.bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs: typing.Any) -> builtins.bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return "PostgresqlDatabaseTimeouts(%s)" % ", ".join(
            k + "=" + repr(v) for k, v in self._values.items()
        )


class PostgresqlFirewallRule(
    cdktf.TerraformResource,
    metaclass=jsii.JSIIMeta,
    jsii_type="@cdktf/provider-azurerm.PostgresqlFirewallRule",
):
    def __init__(
        self,
        scope: constructs.Construct,
        id: builtins.str,
        *,
        end_ip_address: builtins.str,
        name: builtins.str,
        resource_group_name: builtins.str,
        server_name: builtins.str,
        start_ip_address: builtins.str,
        timeouts: typing.Optional["PostgresqlFirewallRuleTimeouts"] = None,
        count: typing.Optional[jsii.Number] = None,
        depends_on: typing.Optional[typing.List[cdktf.TerraformResource]] = None,
        lifecycle: typing.Optional[cdktf.TerraformResourceLifecycle] = None,
        provider: typing.Optional[cdktf.TerraformProvider] = None,
    ) -> None:
        """
        :param scope: -
        :param id: -
        :param end_ip_address: 
        :param name: 
        :param resource_group_name: 
        :param server_name: 
        :param start_ip_address: 
        :param timeouts: timeouts block.
        :param count: 
        :param depends_on: 
        :param lifecycle: 
        :param provider: 
        """
        config = PostgresqlFirewallRuleConfig(
            end_ip_address=end_ip_address,
            name=name,
            resource_group_name=resource_group_name,
            server_name=server_name,
            start_ip_address=start_ip_address,
            timeouts=timeouts,
            count=count,
            depends_on=depends_on,
            lifecycle=lifecycle,
            provider=provider,
        )

        jsii.create(PostgresqlFirewallRule, self, [scope, id, config])

    @jsii.member(jsii_name="synthesizeAttributes")
    def _synthesize_attributes(self) -> typing.Mapping[builtins.str, typing.Any]:
        return jsii.invoke(self, "synthesizeAttributes", [])

    @builtins.property # type: ignore
    @jsii.member(jsii_name="endIpAddress")
    def end_ip_address(self) -> builtins.str:
        return jsii.get(self, "endIpAddress")

    @end_ip_address.setter # type: ignore
    def end_ip_address(self, value: builtins.str) -> None:
        jsii.set(self, "endIpAddress", value)

    @builtins.property # type: ignore
    @jsii.member(jsii_name="name")
    def name(self) -> builtins.str:
        return jsii.get(self, "name")

    @name.setter # type: ignore
    def name(self, value: builtins.str) -> None:
        jsii.set(self, "name", value)

    @builtins.property # type: ignore
    @jsii.member(jsii_name="resourceGroupName")
    def resource_group_name(self) -> builtins.str:
        return jsii.get(self, "resourceGroupName")

    @resource_group_name.setter # type: ignore
    def resource_group_name(self, value: builtins.str) -> None:
        jsii.set(self, "resourceGroupName", value)

    @builtins.property # type: ignore
    @jsii.member(jsii_name="serverName")
    def server_name(self) -> builtins.str:
        return jsii.get(self, "serverName")

    @server_name.setter # type: ignore
    def server_name(self, value: builtins.str) -> None:
        jsii.set(self, "serverName", value)

    @builtins.property # type: ignore
    @jsii.member(jsii_name="startIpAddress")
    def start_ip_address(self) -> builtins.str:
        return jsii.get(self, "startIpAddress")

    @start_ip_address.setter # type: ignore
    def start_ip_address(self, value: builtins.str) -> None:
        jsii.set(self, "startIpAddress", value)

    @builtins.property # type: ignore
    @jsii.member(jsii_name="id")
    def id(self) -> typing.Optional[builtins.str]:
        return jsii.get(self, "id")

    @id.setter # type: ignore
    def id(self, value: typing.Optional[builtins.str]) -> None:
        jsii.set(self, "id", value)

    @builtins.property # type: ignore
    @jsii.member(jsii_name="timeouts")
    def timeouts(self) -> typing.Optional["PostgresqlFirewallRuleTimeouts"]:
        return jsii.get(self, "timeouts")

    @timeouts.setter # type: ignore
    def timeouts(
        self,
        value: typing.Optional["PostgresqlFirewallRuleTimeouts"],
    ) -> None:
        jsii.set(self, "timeouts", value)


@jsii.data_type(
    jsii_type="@cdktf/provider-azurerm.PostgresqlFirewallRuleConfig",
    jsii_struct_bases=[cdktf.TerraformMetaArguments],
    name_mapping={
        "count": "count",
        "depends_on": "dependsOn",
        "lifecycle": "lifecycle",
        "provider": "provider",
        "end_ip_address": "endIpAddress",
        "name": "name",
        "resource_group_name": "resourceGroupName",
        "server_name": "serverName",
        "start_ip_address": "startIpAddress",
        "timeouts": "timeouts",
    },
)
class PostgresqlFirewallRuleConfig(cdktf.TerraformMetaArguments):
    def __init__(
        self,
        *,
        count: typing.Optional[jsii.Number] = None,
        depends_on: typing.Optional[typing.List[cdktf.TerraformResource]] = None,
        lifecycle: typing.Optional[cdktf.TerraformResourceLifecycle] = None,
        provider: typing.Optional[cdktf.TerraformProvider] = None,
        end_ip_address: builtins.str,
        name: builtins.str,
        resource_group_name: builtins.str,
        server_name: builtins.str,
        start_ip_address: builtins.str,
        timeouts: typing.Optional["PostgresqlFirewallRuleTimeouts"] = None,
    ) -> None:
        """
        :param count: 
        :param depends_on: 
        :param lifecycle: 
        :param provider: 
        :param end_ip_address: 
        :param name: 
        :param resource_group_name: 
        :param server_name: 
        :param start_ip_address: 
        :param timeouts: timeouts block.
        """
        if isinstance(lifecycle, dict):
            lifecycle = cdktf.TerraformResourceLifecycle(**lifecycle)
        if isinstance(timeouts, dict):
            timeouts = PostgresqlFirewallRuleTimeouts(**timeouts)
        self._values: typing.Dict[str, typing.Any] = {
            "end_ip_address": end_ip_address,
            "name": name,
            "resource_group_name": resource_group_name,
            "server_name": server_name,
            "start_ip_address": start_ip_address,
        }
        if count is not None:
            self._values["count"] = count
        if depends_on is not None:
            self._values["depends_on"] = depends_on
        if lifecycle is not None:
            self._values["lifecycle"] = lifecycle
        if provider is not None:
            self._values["provider"] = provider
        if timeouts is not None:
            self._values["timeouts"] = timeouts

    @builtins.property
    def count(self) -> typing.Optional[jsii.Number]:
        """
        :stability: experimental
        """
        result = self._values.get("count")
        return result

    @builtins.property
    def depends_on(self) -> typing.Optional[typing.List[cdktf.TerraformResource]]:
        """
        :stability: experimental
        """
        result = self._values.get("depends_on")
        return result

    @builtins.property
    def lifecycle(self) -> typing.Optional[cdktf.TerraformResourceLifecycle]:
        """
        :stability: experimental
        """
        result = self._values.get("lifecycle")
        return result

    @builtins.property
    def provider(self) -> typing.Optional[cdktf.TerraformProvider]:
        """
        :stability: experimental
        """
        result = self._values.get("provider")
        return result

    @builtins.property
    def end_ip_address(self) -> builtins.str:
        result = self._values.get("end_ip_address")
        assert result is not None, "Required property 'end_ip_address' is missing"
        return result

    @builtins.property
    def name(self) -> builtins.str:
        result = self._values.get("name")
        assert result is not None, "Required property 'name' is missing"
        return result

    @builtins.property
    def resource_group_name(self) -> builtins.str:
        result = self._values.get("resource_group_name")
        assert result is not None, "Required property 'resource_group_name' is missing"
        return result

    @builtins.property
    def server_name(self) -> builtins.str:
        result = self._values.get("server_name")
        assert result is not None, "Required property 'server_name' is missing"
        return result

    @builtins.property
    def start_ip_address(self) -> builtins.str:
        result = self._values.get("start_ip_address")
        assert result is not None, "Required property 'start_ip_address' is missing"
        return result

    @builtins.property
    def timeouts(self) -> typing.Optional["PostgresqlFirewallRuleTimeouts"]:
        """timeouts block."""
        result = self._values.get("timeouts")
        return result

    def __eq__(self, rhs: typing.Any) -> builtins.bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs: typing.Any) -> builtins.bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return "PostgresqlFirewallRuleConfig(%s)" % ", ".join(
            k + "=" + repr(v) for k, v in self._values.items()
        )


@jsii.data_type(
    jsii_type="@cdktf/provider-azurerm.PostgresqlFirewallRuleTimeouts",
    jsii_struct_bases=[],
    name_mapping={
        "create": "create",
        "delete": "delete",
        "read": "read",
        "update": "update",
    },
)
class PostgresqlFirewallRuleTimeouts:
    def __init__(
        self,
        *,
        create: typing.Optional[builtins.str] = None,
        delete: typing.Optional[builtins.str] = None,
        read: typing.Optional[builtins.str] = None,
        update: typing.Optional[builtins.str] = None,
    ) -> None:
        """
        :param create: 
        :param delete: 
        :param read: 
        :param update: 
        """
        self._values: typing.Dict[str, typing.Any] = {}
        if create is not None:
            self._values["create"] = create
        if delete is not None:
            self._values["delete"] = delete
        if read is not None:
            self._values["read"] = read
        if update is not None:
            self._values["update"] = update

    @builtins.property
    def create(self) -> typing.Optional[builtins.str]:
        result = self._values.get("create")
        return result

    @builtins.property
    def delete(self) -> typing.Optional[builtins.str]:
        result = self._values.get("delete")
        return result

    @builtins.property
    def read(self) -> typing.Optional[builtins.str]:
        result = self._values.get("read")
        return result

    @builtins.property
    def update(self) -> typing.Optional[builtins.str]:
        result = self._values.get("update")
        return result

    def __eq__(self, rhs: typing.Any) -> builtins.bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs: typing.Any) -> builtins.bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return "PostgresqlFirewallRuleTimeouts(%s)" % ", ".join(
            k + "=" + repr(v) for k, v in self._values.items()
        )


class PostgresqlServer(
    cdktf.TerraformResource,
    metaclass=jsii.JSIIMeta,
    jsii_type="@cdktf/provider-azurerm.PostgresqlServer",
):
    def __init__(
        self,
        scope: constructs.Construct,
        id: builtins.str,
        *,
        administrator_login: builtins.str,
        administrator_login_password: builtins.str,
        location: builtins.str,
        name: builtins.str,
        resource_group_name: builtins.str,
        sku_name: builtins.str,
        ssl_enforcement: builtins.str,
        storage_profile: typing.List["PostgresqlServerStorageProfile"],
        version: builtins.str,
        tags: typing.Optional[typing.Mapping[builtins.str, builtins.str]] = None,
        timeouts: typing.Optional["PostgresqlServerTimeouts"] = None,
        count: typing.Optional[jsii.Number] = None,
        depends_on: typing.Optional[typing.List[cdktf.TerraformResource]] = None,
        lifecycle: typing.Optional[cdktf.TerraformResourceLifecycle] = None,
        provider: typing.Optional[cdktf.TerraformProvider] = None,
    ) -> None:
        """
        :param scope: -
        :param id: -
        :param administrator_login: 
        :param administrator_login_password: 
        :param location: 
        :param name: 
        :param resource_group_name: 
        :param sku_name: 
        :param ssl_enforcement: 
        :param storage_profile: storage_profile block.
        :param version: 
        :param tags: 
        :param timeouts: timeouts block.
        :param count: 
        :param depends_on: 
        :param lifecycle: 
        :param provider: 
        """
        config = PostgresqlServerConfig(
            administrator_login=administrator_login,
            administrator_login_password=administrator_login_password,
            location=location,
            name=name,
            resource_group_name=resource_group_name,
            sku_name=sku_name,
            ssl_enforcement=ssl_enforcement,
            storage_profile=storage_profile,
            version=version,
            tags=tags,
            timeouts=timeouts,
            count=count,
            depends_on=depends_on,
            lifecycle=lifecycle,
            provider=provider,
        )

        jsii.create(PostgresqlServer, self, [scope, id, config])

    @jsii.member(jsii_name="synthesizeAttributes")
    def _synthesize_attributes(self) -> typing.Mapping[builtins.str, typing.Any]:
        return jsii.invoke(self, "synthesizeAttributes", [])

    @builtins.property # type: ignore
    @jsii.member(jsii_name="fqdn")
    def fqdn(self) -> builtins.str:
        return jsii.get(self, "fqdn")

    @builtins.property # type: ignore
    @jsii.member(jsii_name="administratorLogin")
    def administrator_login(self) -> builtins.str:
        return jsii.get(self, "administratorLogin")

    @administrator_login.setter # type: ignore
    def administrator_login(self, value: builtins.str) -> None:
        jsii.set(self, "administratorLogin", value)

    @builtins.property # type: ignore
    @jsii.member(jsii_name="administratorLoginPassword")
    def administrator_login_password(self) -> builtins.str:
        return jsii.get(self, "administratorLoginPassword")

    @administrator_login_password.setter # type: ignore
    def administrator_login_password(self, value: builtins.str) -> None:
        jsii.set(self, "administratorLoginPassword", value)

    @builtins.property # type: ignore
    @jsii.member(jsii_name="location")
    def location(self) -> builtins.str:
        return jsii.get(self, "location")

    @location.setter # type: ignore
    def location(self, value: builtins.str) -> None:
        jsii.set(self, "location", value)

    @builtins.property # type: ignore
    @jsii.member(jsii_name="name")
    def name(self) -> builtins.str:
        return jsii.get(self, "name")

    @name.setter # type: ignore
    def name(self, value: builtins.str) -> None:
        jsii.set(self, "name", value)

    @builtins.property # type: ignore
    @jsii.member(jsii_name="resourceGroupName")
    def resource_group_name(self) -> builtins.str:
        return jsii.get(self, "resourceGroupName")

    @resource_group_name.setter # type: ignore
    def resource_group_name(self, value: builtins.str) -> None:
        jsii.set(self, "resourceGroupName", value)

    @builtins.property # type: ignore
    @jsii.member(jsii_name="skuName")
    def sku_name(self) -> builtins.str:
        return jsii.get(self, "skuName")

    @sku_name.setter # type: ignore
    def sku_name(self, value: builtins.str) -> None:
        jsii.set(self, "skuName", value)

    @builtins.property # type: ignore
    @jsii.member(jsii_name="sslEnforcement")
    def ssl_enforcement(self) -> builtins.str:
        return jsii.get(self, "sslEnforcement")

    @ssl_enforcement.setter # type: ignore
    def ssl_enforcement(self, value: builtins.str) -> None:
        jsii.set(self, "sslEnforcement", value)

    @builtins.property # type: ignore
    @jsii.member(jsii_name="storageProfile")
    def storage_profile(self) -> typing.List["PostgresqlServerStorageProfile"]:
        return jsii.get(self, "storageProfile")

    @storage_profile.setter # type: ignore
    def storage_profile(
        self,
        value: typing.List["PostgresqlServerStorageProfile"],
    ) -> None:
        jsii.set(self, "storageProfile", value)

    @builtins.property # type: ignore
    @jsii.member(jsii_name="version")
    def version(self) -> builtins.str:
        return jsii.get(self, "version")

    @version.setter # type: ignore
    def version(self, value: builtins.str) -> None:
        jsii.set(self, "version", value)

    @builtins.property # type: ignore
    @jsii.member(jsii_name="id")
    def id(self) -> typing.Optional[builtins.str]:
        return jsii.get(self, "id")

    @id.setter # type: ignore
    def id(self, value: typing.Optional[builtins.str]) -> None:
        jsii.set(self, "id", value)

    @builtins.property # type: ignore
    @jsii.member(jsii_name="tags")
    def tags(self) -> typing.Optional[typing.Mapping[builtins.str, builtins.str]]:
        return jsii.get(self, "tags")

    @tags.setter # type: ignore
    def tags(
        self,
        value: typing.Optional[typing.Mapping[builtins.str, builtins.str]],
    ) -> None:
        jsii.set(self, "tags", value)

    @builtins.property # type: ignore
    @jsii.member(jsii_name="timeouts")
    def timeouts(self) -> typing.Optional["PostgresqlServerTimeouts"]:
        return jsii.get(self, "timeouts")

    @timeouts.setter # type: ignore
    def timeouts(self, value: typing.Optional["PostgresqlServerTimeouts"]) -> None:
        jsii.set(self, "timeouts", value)


@jsii.data_type(
    jsii_type="@cdktf/provider-azurerm.PostgresqlServerConfig",
    jsii_struct_bases=[cdktf.TerraformMetaArguments],
    name_mapping={
        "count": "count",
        "depends_on": "dependsOn",
        "lifecycle": "lifecycle",
        "provider": "provider",
        "administrator_login": "administratorLogin",
        "administrator_login_password": "administratorLoginPassword",
        "location": "location",
        "name": "name",
        "resource_group_name": "resourceGroupName",
        "sku_name": "skuName",
        "ssl_enforcement": "sslEnforcement",
        "storage_profile": "storageProfile",
        "version": "version",
        "tags": "tags",
        "timeouts": "timeouts",
    },
)
class PostgresqlServerConfig(cdktf.TerraformMetaArguments):
    def __init__(
        self,
        *,
        count: typing.Optional[jsii.Number] = None,
        depends_on: typing.Optional[typing.List[cdktf.TerraformResource]] = None,
        lifecycle: typing.Optional[cdktf.TerraformResourceLifecycle] = None,
        provider: typing.Optional[cdktf.TerraformProvider] = None,
        administrator_login: builtins.str,
        administrator_login_password: builtins.str,
        location: builtins.str,
        name: builtins.str,
        resource_group_name: builtins.str,
        sku_name: builtins.str,
        ssl_enforcement: builtins.str,
        storage_profile: typing.List["PostgresqlServerStorageProfile"],
        version: builtins.str,
        tags: typing.Optional[typing.Mapping[builtins.str, builtins.str]] = None,
        timeouts: typing.Optional["PostgresqlServerTimeouts"] = None,
    ) -> None:
        """
        :param count: 
        :param depends_on: 
        :param lifecycle: 
        :param provider: 
        :param administrator_login: 
        :param administrator_login_password: 
        :param location: 
        :param name: 
        :param resource_group_name: 
        :param sku_name: 
        :param ssl_enforcement: 
        :param storage_profile: storage_profile block.
        :param version: 
        :param tags: 
        :param timeouts: timeouts block.
        """
        if isinstance(lifecycle, dict):
            lifecycle = cdktf.TerraformResourceLifecycle(**lifecycle)
        if isinstance(timeouts, dict):
            timeouts = PostgresqlServerTimeouts(**timeouts)
        self._values: typing.Dict[str, typing.Any] = {
            "administrator_login": administrator_login,
            "administrator_login_password": administrator_login_password,
            "location": location,
            "name": name,
            "resource_group_name": resource_group_name,
            "sku_name": sku_name,
            "ssl_enforcement": ssl_enforcement,
            "storage_profile": storage_profile,
            "version": version,
        }
        if count is not None:
            self._values["count"] = count
        if depends_on is not None:
            self._values["depends_on"] = depends_on
        if lifecycle is not None:
            self._values["lifecycle"] = lifecycle
        if provider is not None:
            self._values["provider"] = provider
        if tags is not None:
            self._values["tags"] = tags
        if timeouts is not None:
            self._values["timeouts"] = timeouts

    @builtins.property
    def count(self) -> typing.Optional[jsii.Number]:
        """
        :stability: experimental
        """
        result = self._values.get("count")
        return result

    @builtins.property
    def depends_on(self) -> typing.Optional[typing.List[cdktf.TerraformResource]]:
        """
        :stability: experimental
        """
        result = self._values.get("depends_on")
        return result

    @builtins.property
    def lifecycle(self) -> typing.Optional[cdktf.TerraformResourceLifecycle]:
        """
        :stability: experimental
        """
        result = self._values.get("lifecycle")
        return result

    @builtins.property
    def provider(self) -> typing.Optional[cdktf.TerraformProvider]:
        """
        :stability: experimental
        """
        result = self._values.get("provider")
        return result

    @builtins.property
    def administrator_login(self) -> builtins.str:
        result = self._values.get("administrator_login")
        assert result is not None, "Required property 'administrator_login' is missing"
        return result

    @builtins.property
    def administrator_login_password(self) -> builtins.str:
        result = self._values.get("administrator_login_password")
        assert result is not None, "Required property 'administrator_login_password' is missing"
        return result

    @builtins.property
    def location(self) -> builtins.str:
        result = self._values.get("location")
        assert result is not None, "Required property 'location' is missing"
        return result

    @builtins.property
    def name(self) -> builtins.str:
        result = self._values.get("name")
        assert result is not None, "Required property 'name' is missing"
        return result

    @builtins.property
    def resource_group_name(self) -> builtins.str:
        result = self._values.get("resource_group_name")
        assert result is not None, "Required property 'resource_group_name' is missing"
        return result

    @builtins.property
    def sku_name(self) -> builtins.str:
        result = self._values.get("sku_name")
        assert result is not None, "Required property 'sku_name' is missing"
        return result

    @builtins.property
    def ssl_enforcement(self) -> builtins.str:
        result = self._values.get("ssl_enforcement")
        assert result is not None, "Required property 'ssl_enforcement' is missing"
        return result

    @builtins.property
    def storage_profile(self) -> typing.List["PostgresqlServerStorageProfile"]:
        """storage_profile block."""
        result = self._values.get("storage_profile")
        assert result is not None, "Required property 'storage_profile' is missing"
        return result

    @builtins.property
    def version(self) -> builtins.str:
        result = self._values.get("version")
        assert result is not None, "Required property 'version' is missing"
        return result

    @builtins.property
    def tags(self) -> typing.Optional[typing.Mapping[builtins.str, builtins.str]]:
        result = self._values.get("tags")
        return result

    @builtins.property
    def timeouts(self) -> typing.Optional["PostgresqlServerTimeouts"]:
        """timeouts block."""
        result = self._values.get("timeouts")
        return result

    def __eq__(self, rhs: typing.Any) -> builtins.bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs: typing.Any) -> builtins.bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return "PostgresqlServerConfig(%s)" % ", ".join(
            k + "=" + repr(v) for k, v in self._values.items()
        )


@jsii.data_type(
    jsii_type="@cdktf/provider-azurerm.PostgresqlServerStorageProfile",
    jsii_struct_bases=[],
    name_mapping={
        "storage_mb": "storageMb",
        "auto_grow": "autoGrow",
        "backup_retention_days": "backupRetentionDays",
        "geo_redundant_backup": "geoRedundantBackup",
    },
)
class PostgresqlServerStorageProfile:
    def __init__(
        self,
        *,
        storage_mb: jsii.Number,
        auto_grow: typing.Optional[builtins.str] = None,
        backup_retention_days: typing.Optional[jsii.Number] = None,
        geo_redundant_backup: typing.Optional[builtins.str] = None,
    ) -> None:
        """
        :param storage_mb: 
        :param auto_grow: 
        :param backup_retention_days: 
        :param geo_redundant_backup: 
        """
        self._values: typing.Dict[str, typing.Any] = {
            "storage_mb": storage_mb,
        }
        if auto_grow is not None:
            self._values["auto_grow"] = auto_grow
        if backup_retention_days is not None:
            self._values["backup_retention_days"] = backup_retention_days
        if geo_redundant_backup is not None:
            self._values["geo_redundant_backup"] = geo_redundant_backup

    @builtins.property
    def storage_mb(self) -> jsii.Number:
        result = self._values.get("storage_mb")
        assert result is not None, "Required property 'storage_mb' is missing"
        return result

    @builtins.property
    def auto_grow(self) -> typing.Optional[builtins.str]:
        result = self._values.get("auto_grow")
        return result

    @builtins.property
    def backup_retention_days(self) -> typing.Optional[jsii.Number]:
        result = self._values.get("backup_retention_days")
        return result

    @builtins.property
    def geo_redundant_backup(self) -> typing.Optional[builtins.str]:
        result = self._values.get("geo_redundant_backup")
        return result

    def __eq__(self, rhs: typing.Any) -> builtins.bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs: typing.Any) -> builtins.bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return "PostgresqlServerStorageProfile(%s)" % ", ".join(
            k + "=" + repr(v) for k, v in self._values.items()
        )


@jsii.data_type(
    jsii_type="@cdktf/provider-azurerm.PostgresqlServerTimeouts",
    jsii_struct_bases=[],
    name_mapping={
        "create": "create",
        "delete": "delete",
        "read": "read",
        "update": "update",
    },
)
class PostgresqlServerTimeouts:
    def __init__(
        self,
        *,
        create: typing.Optional[builtins.str] = None,
        delete: typing.Optional[builtins.str] = None,
        read: typing.Optional[builtins.str] = None,
        update: typing.Optional[builtins.str] = None,
    ) -> None:
        """
        :param create: 
        :param delete: 
        :param read: 
        :param update: 
        """
        self._values: typing.Dict[str, typing.Any] = {}
        if create is not None:
            self._values["create"] = create
        if delete is not None:
            self._values["delete"] = delete
        if read is not None:
            self._values["read"] = read
        if update is not None:
            self._values["update"] = update

    @builtins.property
    def create(self) -> typing.Optional[builtins.str]:
        result = self._values.get("create")
        return result

    @builtins.property
    def delete(self) -> typing.Optional[builtins.str]:
        result = self._values.get("delete")
        return result

    @builtins.property
    def read(self) -> typing.Optional[builtins.str]:
        result = self._values.get("read")
        return result

    @builtins.property
    def update(self) -> typing.Optional[builtins.str]:
        result = self._values.get("update")
        return result

    def __eq__(self, rhs: typing.Any) -> builtins.bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs: typing.Any) -> builtins.bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return "PostgresqlServerTimeouts(%s)" % ", ".join(
            k + "=" + repr(v) for k, v in self._values.items()
        )


class PostgresqlVirtualNetworkRule(
    cdktf.TerraformResource,
    metaclass=jsii.JSIIMeta,
    jsii_type="@cdktf/provider-azurerm.PostgresqlVirtualNetworkRule",
):
    def __init__(
        self,
        scope: constructs.Construct,
        id: builtins.str,
        *,
        name: builtins.str,
        resource_group_name: builtins.str,
        server_name: builtins.str,
        subnet_id: builtins.str,
        ignore_missing_vnet_service_endpoint: typing.Optional[builtins.bool] = None,
        timeouts: typing.Optional["PostgresqlVirtualNetworkRuleTimeouts"] = None,
        count: typing.Optional[jsii.Number] = None,
        depends_on: typing.Optional[typing.List[cdktf.TerraformResource]] = None,
        lifecycle: typing.Optional[cdktf.TerraformResourceLifecycle] = None,
        provider: typing.Optional[cdktf.TerraformProvider] = None,
    ) -> None:
        """
        :param scope: -
        :param id: -
        :param name: 
        :param resource_group_name: 
        :param server_name: 
        :param subnet_id: 
        :param ignore_missing_vnet_service_endpoint: 
        :param timeouts: timeouts block.
        :param count: 
        :param depends_on: 
        :param lifecycle: 
        :param provider: 
        """
        config = PostgresqlVirtualNetworkRuleConfig(
            name=name,
            resource_group_name=resource_group_name,
            server_name=server_name,
            subnet_id=subnet_id,
            ignore_missing_vnet_service_endpoint=ignore_missing_vnet_service_endpoint,
            timeouts=timeouts,
            count=count,
            depends_on=depends_on,
            lifecycle=lifecycle,
            provider=provider,
        )

        jsii.create(PostgresqlVirtualNetworkRule, self, [scope, id, config])

    @jsii.member(jsii_name="synthesizeAttributes")
    def _synthesize_attributes(self) -> typing.Mapping[builtins.str, typing.Any]:
        return jsii.invoke(self, "synthesizeAttributes", [])

    @builtins.property # type: ignore
    @jsii.member(jsii_name="name")
    def name(self) -> builtins.str:
        return jsii.get(self, "name")

    @name.setter # type: ignore
    def name(self, value: builtins.str) -> None:
        jsii.set(self, "name", value)

    @builtins.property # type: ignore
    @jsii.member(jsii_name="resourceGroupName")
    def resource_group_name(self) -> builtins.str:
        return jsii.get(self, "resourceGroupName")

    @resource_group_name.setter # type: ignore
    def resource_group_name(self, value: builtins.str) -> None:
        jsii.set(self, "resourceGroupName", value)

    @builtins.property # type: ignore
    @jsii.member(jsii_name="serverName")
    def server_name(self) -> builtins.str:
        return jsii.get(self, "serverName")

    @server_name.setter # type: ignore
    def server_name(self, value: builtins.str) -> None:
        jsii.set(self, "serverName", value)

    @builtins.property # type: ignore
    @jsii.member(jsii_name="subnetId")
    def subnet_id(self) -> builtins.str:
        return jsii.get(self, "subnetId")

    @subnet_id.setter # type: ignore
    def subnet_id(self, value: builtins.str) -> None:
        jsii.set(self, "subnetId", value)

    @builtins.property # type: ignore
    @jsii.member(jsii_name="id")
    def id(self) -> typing.Optional[builtins.str]:
        return jsii.get(self, "id")

    @id.setter # type: ignore
    def id(self, value: typing.Optional[builtins.str]) -> None:
        jsii.set(self, "id", value)

    @builtins.property # type: ignore
    @jsii.member(jsii_name="ignoreMissingVnetServiceEndpoint")
    def ignore_missing_vnet_service_endpoint(self) -> typing.Optional[builtins.bool]:
        return jsii.get(self, "ignoreMissingVnetServiceEndpoint")

    @ignore_missing_vnet_service_endpoint.setter # type: ignore
    def ignore_missing_vnet_service_endpoint(
        self,
        value: typing.Optional[builtins.bool],
    ) -> None:
        jsii.set(self, "ignoreMissingVnetServiceEndpoint", value)

    @builtins.property # type: ignore
    @jsii.member(jsii_name="timeouts")
    def timeouts(self) -> typing.Optional["PostgresqlVirtualNetworkRuleTimeouts"]:
        return jsii.get(self, "timeouts")

    @timeouts.setter # type: ignore
    def timeouts(
        self,
        value: typing.Optional["PostgresqlVirtualNetworkRuleTimeouts"],
    ) -> None:
        jsii.set(self, "timeouts", value)


@jsii.data_type(
    jsii_type="@cdktf/provider-azurerm.PostgresqlVirtualNetworkRuleConfig",
    jsii_struct_bases=[cdktf.TerraformMetaArguments],
    name_mapping={
        "count": "count",
        "depends_on": "dependsOn",
        "lifecycle": "lifecycle",
        "provider": "provider",
        "name": "name",
        "resource_group_name": "resourceGroupName",
        "server_name": "serverName",
        "subnet_id": "subnetId",
        "ignore_missing_vnet_service_endpoint": "ignoreMissingVnetServiceEndpoint",
        "timeouts": "timeouts",
    },
)
class PostgresqlVirtualNetworkRuleConfig(cdktf.TerraformMetaArguments):
    def __init__(
        self,
        *,
        count: typing.Optional[jsii.Number] = None,
        depends_on: typing.Optional[typing.List[cdktf.TerraformResource]] = None,
        lifecycle: typing.Optional[cdktf.TerraformResourceLifecycle] = None,
        provider: typing.Optional[cdktf.TerraformProvider] = None,
        name: builtins.str,
        resource_group_name: builtins.str,
        server_name: builtins.str,
        subnet_id: builtins.str,
        ignore_missing_vnet_service_endpoint: typing.Optional[builtins.bool] = None,
        timeouts: typing.Optional["PostgresqlVirtualNetworkRuleTimeouts"] = None,
    ) -> None:
        """
        :param count: 
        :param depends_on: 
        :param lifecycle: 
        :param provider: 
        :param name: 
        :param resource_group_name: 
        :param server_name: 
        :param subnet_id: 
        :param ignore_missing_vnet_service_endpoint: 
        :param timeouts: timeouts block.
        """
        if isinstance(lifecycle, dict):
            lifecycle = cdktf.TerraformResourceLifecycle(**lifecycle)
        if isinstance(timeouts, dict):
            timeouts = PostgresqlVirtualNetworkRuleTimeouts(**timeouts)
        self._values: typing.Dict[str, typing.Any] = {
            "name": name,
            "resource_group_name": resource_group_name,
            "server_name": server_name,
            "subnet_id": subnet_id,
        }
        if count is not None:
            self._values["count"] = count
        if depends_on is not None:
            self._values["depends_on"] = depends_on
        if lifecycle is not None:
            self._values["lifecycle"] = lifecycle
        if provider is not None:
            self._values["provider"] = provider
        if ignore_missing_vnet_service_endpoint is not None:
            self._values["ignore_missing_vnet_service_endpoint"] = ignore_missing_vnet_service_endpoint
        if timeouts is not None:
            self._values["timeouts"] = timeouts

    @builtins.property
    def count(self) -> typing.Optional[jsii.Number]:
        """
        :stability: experimental
        """
        result = self._values.get("count")
        return result

    @builtins.property
    def depends_on(self) -> typing.Optional[typing.List[cdktf.TerraformResource]]:
        """
        :stability: experimental
        """
        result = self._values.get("depends_on")
        return result

    @builtins.property
    def lifecycle(self) -> typing.Optional[cdktf.TerraformResourceLifecycle]:
        """
        :stability: experimental
        """
        result = self._values.get("lifecycle")
        return result

    @builtins.property
    def provider(self) -> typing.Optional[cdktf.TerraformProvider]:
        """
        :stability: experimental
        """
        result = self._values.get("provider")
        return result

    @builtins.property
    def name(self) -> builtins.str:
        result = self._values.get("name")
        assert result is not None, "Required property 'name' is missing"
        return result

    @builtins.property
    def resource_group_name(self) -> builtins.str:
        result = self._values.get("resource_group_name")
        assert result is not None, "Required property 'resource_group_name' is missing"
        return result

    @builtins.property
    def server_name(self) -> builtins.str:
        result = self._values.get("server_name")
        assert result is not None, "Required property 'server_name' is missing"
        return result

    @builtins.property
    def subnet_id(self) -> builtins.str:
        result = self._values.get("subnet_id")
        assert result is not None, "Required property 'subnet_id' is missing"
        return result

    @builtins.property
    def ignore_missing_vnet_service_endpoint(self) -> typing.Optional[builtins.bool]:
        result = self._values.get("ignore_missing_vnet_service_endpoint")
        return result

    @builtins.property
    def timeouts(self) -> typing.Optional["PostgresqlVirtualNetworkRuleTimeouts"]:
        """timeouts block."""
        result = self._values.get("timeouts")
        return result

    def __eq__(self, rhs: typing.Any) -> builtins.bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs: typing.Any) -> builtins.bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return "PostgresqlVirtualNetworkRuleConfig(%s)" % ", ".join(
            k + "=" + repr(v) for k, v in self._values.items()
        )


@jsii.data_type(
    jsii_type="@cdktf/provider-azurerm.PostgresqlVirtualNetworkRuleTimeouts",
    jsii_struct_bases=[],
    name_mapping={
        "create": "create",
        "delete": "delete",
        "read": "read",
        "update": "update",
    },
)
class PostgresqlVirtualNetworkRuleTimeouts:
    def __init__(
        self,
        *,
        create: typing.Optional[builtins.str] = None,
        delete: typing.Optional[builtins.str] = None,
        read: typing.Optional[builtins.str] = None,
        update: typing.Optional[builtins.str] = None,
    ) -> None:
        """
        :param create: 
        :param delete: 
        :param read: 
        :param update: 
        """
        self._values: typing.Dict[str, typing.Any] = {}
        if create is not None:
            self._values["create"] = create
        if delete is not None:
            self._values["delete"] = delete
        if read is not None:
            self._values["read"] = read
        if update is not None:
            self._values["update"] = update

    @builtins.property
    def create(self) -> typing.Optional[builtins.str]:
        result = self._values.get("create")
        return result

    @builtins.property
    def delete(self) -> typing.Optional[builtins.str]:
        result = self._values.get("delete")
        return result

    @builtins.property
    def read(self) -> typing.Optional[builtins.str]:
        result = self._values.get("read")
        return result

    @builtins.property
    def update(self) -> typing.Optional[builtins.str]:
        result = self._values.get("update")
        return result

    def __eq__(self, rhs: typing.Any) -> builtins.bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs: typing.Any) -> builtins.bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return "PostgresqlVirtualNetworkRuleTimeouts(%s)" % ", ".join(
            k + "=" + repr(v) for k, v in self._values.items()
        )


class PrivateDnsARecord(
    cdktf.TerraformResource,
    metaclass=jsii.JSIIMeta,
    jsii_type="@cdktf/provider-azurerm.PrivateDnsARecord",
):
    def __init__(
        self,
        scope: constructs.Construct,
        id: builtins.str,
        *,
        name: builtins.str,
        records: typing.List[builtins.str],
        resource_group_name: builtins.str,
        ttl: jsii.Number,
        zone_name: builtins.str,
        tags: typing.Optional[typing.Mapping[builtins.str, builtins.str]] = None,
        timeouts: typing.Optional["PrivateDnsARecordTimeouts"] = None,
        count: typing.Optional[jsii.Number] = None,
        depends_on: typing.Optional[typing.List[cdktf.TerraformResource]] = None,
        lifecycle: typing.Optional[cdktf.TerraformResourceLifecycle] = None,
        provider: typing.Optional[cdktf.TerraformProvider] = None,
    ) -> None:
        """
        :param scope: -
        :param id: -
        :param name: 
        :param records: 
        :param resource_group_name: 
        :param ttl: 
        :param zone_name: 
        :param tags: 
        :param timeouts: timeouts block.
        :param count: 
        :param depends_on: 
        :param lifecycle: 
        :param provider: 
        """
        config = PrivateDnsARecordConfig(
            name=name,
            records=records,
            resource_group_name=resource_group_name,
            ttl=ttl,
            zone_name=zone_name,
            tags=tags,
            timeouts=timeouts,
            count=count,
            depends_on=depends_on,
            lifecycle=lifecycle,
            provider=provider,
        )

        jsii.create(PrivateDnsARecord, self, [scope, id, config])

    @jsii.member(jsii_name="synthesizeAttributes")
    def _synthesize_attributes(self) -> typing.Mapping[builtins.str, typing.Any]:
        return jsii.invoke(self, "synthesizeAttributes", [])

    @builtins.property # type: ignore
    @jsii.member(jsii_name="name")
    def name(self) -> builtins.str:
        return jsii.get(self, "name")

    @name.setter # type: ignore
    def name(self, value: builtins.str) -> None:
        jsii.set(self, "name", value)

    @builtins.property # type: ignore
    @jsii.member(jsii_name="records")
    def records(self) -> typing.List[builtins.str]:
        return jsii.get(self, "records")

    @records.setter # type: ignore
    def records(self, value: typing.List[builtins.str]) -> None:
        jsii.set(self, "records", value)

    @builtins.property # type: ignore
    @jsii.member(jsii_name="resourceGroupName")
    def resource_group_name(self) -> builtins.str:
        return jsii.get(self, "resourceGroupName")

    @resource_group_name.setter # type: ignore
    def resource_group_name(self, value: builtins.str) -> None:
        jsii.set(self, "resourceGroupName", value)

    @builtins.property # type: ignore
    @jsii.member(jsii_name="ttl")
    def ttl(self) -> jsii.Number:
        return jsii.get(self, "ttl")

    @ttl.setter # type: ignore
    def ttl(self, value: jsii.Number) -> None:
        jsii.set(self, "ttl", value)

    @builtins.property # type: ignore
    @jsii.member(jsii_name="zoneName")
    def zone_name(self) -> builtins.str:
        return jsii.get(self, "zoneName")

    @zone_name.setter # type: ignore
    def zone_name(self, value: builtins.str) -> None:
        jsii.set(self, "zoneName", value)

    @builtins.property # type: ignore
    @jsii.member(jsii_name="id")
    def id(self) -> typing.Optional[builtins.str]:
        return jsii.get(self, "id")

    @id.setter # type: ignore
    def id(self, value: typing.Optional[builtins.str]) -> None:
        jsii.set(self, "id", value)

    @builtins.property # type: ignore
    @jsii.member(jsii_name="tags")
    def tags(self) -> typing.Optional[typing.Mapping[builtins.str, builtins.str]]:
        return jsii.get(self, "tags")

    @tags.setter # type: ignore
    def tags(
        self,
        value: typing.Optional[typing.Mapping[builtins.str, builtins.str]],
    ) -> None:
        jsii.set(self, "tags", value)

    @builtins.property # type: ignore
    @jsii.member(jsii_name="timeouts")
    def timeouts(self) -> typing.Optional["PrivateDnsARecordTimeouts"]:
        return jsii.get(self, "timeouts")

    @timeouts.setter # type: ignore
    def timeouts(self, value: typing.Optional["PrivateDnsARecordTimeouts"]) -> None:
        jsii.set(self, "timeouts", value)


@jsii.data_type(
    jsii_type="@cdktf/provider-azurerm.PrivateDnsARecordConfig",
    jsii_struct_bases=[cdktf.TerraformMetaArguments],
    name_mapping={
        "count": "count",
        "depends_on": "dependsOn",
        "lifecycle": "lifecycle",
        "provider": "provider",
        "name": "name",
        "records": "records",
        "resource_group_name": "resourceGroupName",
        "ttl": "ttl",
        "zone_name": "zoneName",
        "tags": "tags",
        "timeouts": "timeouts",
    },
)
class PrivateDnsARecordConfig(cdktf.TerraformMetaArguments):
    def __init__(
        self,
        *,
        count: typing.Optional[jsii.Number] = None,
        depends_on: typing.Optional[typing.List[cdktf.TerraformResource]] = None,
        lifecycle: typing.Optional[cdktf.TerraformResourceLifecycle] = None,
        provider: typing.Optional[cdktf.TerraformProvider] = None,
        name: builtins.str,
        records: typing.List[builtins.str],
        resource_group_name: builtins.str,
        ttl: jsii.Number,
        zone_name: builtins.str,
        tags: typing.Optional[typing.Mapping[builtins.str, builtins.str]] = None,
        timeouts: typing.Optional["PrivateDnsARecordTimeouts"] = None,
    ) -> None:
        """
        :param count: 
        :param depends_on: 
        :param lifecycle: 
        :param provider: 
        :param name: 
        :param records: 
        :param resource_group_name: 
        :param ttl: 
        :param zone_name: 
        :param tags: 
        :param timeouts: timeouts block.
        """
        if isinstance(lifecycle, dict):
            lifecycle = cdktf.TerraformResourceLifecycle(**lifecycle)
        if isinstance(timeouts, dict):
            timeouts = PrivateDnsARecordTimeouts(**timeouts)
        self._values: typing.Dict[str, typing.Any] = {
            "name": name,
            "records": records,
            "resource_group_name": resource_group_name,
            "ttl": ttl,
            "zone_name": zone_name,
        }
        if count is not None:
            self._values["count"] = count
        if depends_on is not None:
            self._values["depends_on"] = depends_on
        if lifecycle is not None:
            self._values["lifecycle"] = lifecycle
        if provider is not None:
            self._values["provider"] = provider
        if tags is not None:
            self._values["tags"] = tags
        if timeouts is not None:
            self._values["timeouts"] = timeouts

    @builtins.property
    def count(self) -> typing.Optional[jsii.Number]:
        """
        :stability: experimental
        """
        result = self._values.get("count")
        return result

    @builtins.property
    def depends_on(self) -> typing.Optional[typing.List[cdktf.TerraformResource]]:
        """
        :stability: experimental
        """
        result = self._values.get("depends_on")
        return result

    @builtins.property
    def lifecycle(self) -> typing.Optional[cdktf.TerraformResourceLifecycle]:
        """
        :stability: experimental
        """
        result = self._values.get("lifecycle")
        return result

    @builtins.property
    def provider(self) -> typing.Optional[cdktf.TerraformProvider]:
        """
        :stability: experimental
        """
        result = self._values.get("provider")
        return result

    @builtins.property
    def name(self) -> builtins.str:
        result = self._values.get("name")
        assert result is not None, "Required property 'name' is missing"
        return result

    @builtins.property
    def records(self) -> typing.List[builtins.str]:
        result = self._values.get("records")
        assert result is not None, "Required property 'records' is missing"
        return result

    @builtins.property
    def resource_group_name(self) -> builtins.str:
        result = self._values.get("resource_group_name")
        assert result is not None, "Required property 'resource_group_name' is missing"
        return result

    @builtins.property
    def ttl(self) -> jsii.Number:
        result = self._values.get("ttl")
        assert result is not None, "Required property 'ttl' is missing"
        return result

    @builtins.property
    def zone_name(self) -> builtins.str:
        result = self._values.get("zone_name")
        assert result is not None, "Required property 'zone_name' is missing"
        return result

    @builtins.property
    def tags(self) -> typing.Optional[typing.Mapping[builtins.str, builtins.str]]:
        result = self._values.get("tags")
        return result

    @builtins.property
    def timeouts(self) -> typing.Optional["PrivateDnsARecordTimeouts"]:
        """timeouts block."""
        result = self._values.get("timeouts")
        return result

    def __eq__(self, rhs: typing.Any) -> builtins.bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs: typing.Any) -> builtins.bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return "PrivateDnsARecordConfig(%s)" % ", ".join(
            k + "=" + repr(v) for k, v in self._values.items()
        )


@jsii.data_type(
    jsii_type="@cdktf/provider-azurerm.PrivateDnsARecordTimeouts",
    jsii_struct_bases=[],
    name_mapping={
        "create": "create",
        "delete": "delete",
        "read": "read",
        "update": "update",
    },
)
class PrivateDnsARecordTimeouts:
    def __init__(
        self,
        *,
        create: typing.Optional[builtins.str] = None,
        delete: typing.Optional[builtins.str] = None,
        read: typing.Optional[builtins.str] = None,
        update: typing.Optional[builtins.str] = None,
    ) -> None:
        """
        :param create: 
        :param delete: 
        :param read: 
        :param update: 
        """
        self._values: typing.Dict[str, typing.Any] = {}
        if create is not None:
            self._values["create"] = create
        if delete is not None:
            self._values["delete"] = delete
        if read is not None:
            self._values["read"] = read
        if update is not None:
            self._values["update"] = update

    @builtins.property
    def create(self) -> typing.Optional[builtins.str]:
        result = self._values.get("create")
        return result

    @builtins.property
    def delete(self) -> typing.Optional[builtins.str]:
        result = self._values.get("delete")
        return result

    @builtins.property
    def read(self) -> typing.Optional[builtins.str]:
        result = self._values.get("read")
        return result

    @builtins.property
    def update(self) -> typing.Optional[builtins.str]:
        result = self._values.get("update")
        return result

    def __eq__(self, rhs: typing.Any) -> builtins.bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs: typing.Any) -> builtins.bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return "PrivateDnsARecordTimeouts(%s)" % ", ".join(
            k + "=" + repr(v) for k, v in self._values.items()
        )


class PrivateDnsAaaaRecord(
    cdktf.TerraformResource,
    metaclass=jsii.JSIIMeta,
    jsii_type="@cdktf/provider-azurerm.PrivateDnsAaaaRecord",
):
    def __init__(
        self,
        scope: constructs.Construct,
        id: builtins.str,
        *,
        name: builtins.str,
        records: typing.List[builtins.str],
        resource_group_name: builtins.str,
        ttl: jsii.Number,
        zone_name: builtins.str,
        tags: typing.Optional[typing.Mapping[builtins.str, builtins.str]] = None,
        timeouts: typing.Optional["PrivateDnsAaaaRecordTimeouts"] = None,
        count: typing.Optional[jsii.Number] = None,
        depends_on: typing.Optional[typing.List[cdktf.TerraformResource]] = None,
        lifecycle: typing.Optional[cdktf.TerraformResourceLifecycle] = None,
        provider: typing.Optional[cdktf.TerraformProvider] = None,
    ) -> None:
        """
        :param scope: -
        :param id: -
        :param name: 
        :param records: 
        :param resource_group_name: 
        :param ttl: 
        :param zone_name: 
        :param tags: 
        :param timeouts: timeouts block.
        :param count: 
        :param depends_on: 
        :param lifecycle: 
        :param provider: 
        """
        config = PrivateDnsAaaaRecordConfig(
            name=name,
            records=records,
            resource_group_name=resource_group_name,
            ttl=ttl,
            zone_name=zone_name,
            tags=tags,
            timeouts=timeouts,
            count=count,
            depends_on=depends_on,
            lifecycle=lifecycle,
            provider=provider,
        )

        jsii.create(PrivateDnsAaaaRecord, self, [scope, id, config])

    @jsii.member(jsii_name="synthesizeAttributes")
    def _synthesize_attributes(self) -> typing.Mapping[builtins.str, typing.Any]:
        return jsii.invoke(self, "synthesizeAttributes", [])

    @builtins.property # type: ignore
    @jsii.member(jsii_name="name")
    def name(self) -> builtins.str:
        return jsii.get(self, "name")

    @name.setter # type: ignore
    def name(self, value: builtins.str) -> None:
        jsii.set(self, "name", value)

    @builtins.property # type: ignore
    @jsii.member(jsii_name="records")
    def records(self) -> typing.List[builtins.str]:
        return jsii.get(self, "records")

    @records.setter # type: ignore
    def records(self, value: typing.List[builtins.str]) -> None:
        jsii.set(self, "records", value)

    @builtins.property # type: ignore
    @jsii.member(jsii_name="resourceGroupName")
    def resource_group_name(self) -> builtins.str:
        return jsii.get(self, "resourceGroupName")

    @resource_group_name.setter # type: ignore
    def resource_group_name(self, value: builtins.str) -> None:
        jsii.set(self, "resourceGroupName", value)

    @builtins.property # type: ignore
    @jsii.member(jsii_name="ttl")
    def ttl(self) -> jsii.Number:
        return jsii.get(self, "ttl")

    @ttl.setter # type: ignore
    def ttl(self, value: jsii.Number) -> None:
        jsii.set(self, "ttl", value)

    @builtins.property # type: ignore
    @jsii.member(jsii_name="zoneName")
    def zone_name(self) -> builtins.str:
        return jsii.get(self, "zoneName")

    @zone_name.setter # type: ignore
    def zone_name(self, value: builtins.str) -> None:
        jsii.set(self, "zoneName", value)

    @builtins.property # type: ignore
    @jsii.member(jsii_name="id")
    def id(self) -> typing.Optional[builtins.str]:
        return jsii.get(self, "id")

    @id.setter # type: ignore
    def id(self, value: typing.Optional[builtins.str]) -> None:
        jsii.set(self, "id", value)

    @builtins.property # type: ignore
    @jsii.member(jsii_name="tags")
    def tags(self) -> typing.Optional[typing.Mapping[builtins.str, builtins.str]]:
        return jsii.get(self, "tags")

    @tags.setter # type: ignore
    def tags(
        self,
        value: typing.Optional[typing.Mapping[builtins.str, builtins.str]],
    ) -> None:
        jsii.set(self, "tags", value)

    @builtins.property # type: ignore
    @jsii.member(jsii_name="timeouts")
    def timeouts(self) -> typing.Optional["PrivateDnsAaaaRecordTimeouts"]:
        return jsii.get(self, "timeouts")

    @timeouts.setter # type: ignore
    def timeouts(self, value: typing.Optional["PrivateDnsAaaaRecordTimeouts"]) -> None:
        jsii.set(self, "timeouts", value)


@jsii.data_type(
    jsii_type="@cdktf/provider-azurerm.PrivateDnsAaaaRecordConfig",
    jsii_struct_bases=[cdktf.TerraformMetaArguments],
    name_mapping={
        "count": "count",
        "depends_on": "dependsOn",
        "lifecycle": "lifecycle",
        "provider": "provider",
        "name": "name",
        "records": "records",
        "resource_group_name": "resourceGroupName",
        "ttl": "ttl",
        "zone_name": "zoneName",
        "tags": "tags",
        "timeouts": "timeouts",
    },
)
class PrivateDnsAaaaRecordConfig(cdktf.TerraformMetaArguments):
    def __init__(
        self,
        *,
        count: typing.Optional[jsii.Number] = None,
        depends_on: typing.Optional[typing.List[cdktf.TerraformResource]] = None,
        lifecycle: typing.Optional[cdktf.TerraformResourceLifecycle] = None,
        provider: typing.Optional[cdktf.TerraformProvider] = None,
        name: builtins.str,
        records: typing.List[builtins.str],
        resource_group_name: builtins.str,
        ttl: jsii.Number,
        zone_name: builtins.str,
        tags: typing.Optional[typing.Mapping[builtins.str, builtins.str]] = None,
        timeouts: typing.Optional["PrivateDnsAaaaRecordTimeouts"] = None,
    ) -> None:
        """
        :param count: 
        :param depends_on: 
        :param lifecycle: 
        :param provider: 
        :param name: 
        :param records: 
        :param resource_group_name: 
        :param ttl: 
        :param zone_name: 
        :param tags: 
        :param timeouts: timeouts block.
        """
        if isinstance(lifecycle, dict):
            lifecycle = cdktf.TerraformResourceLifecycle(**lifecycle)
        if isinstance(timeouts, dict):
            timeouts = PrivateDnsAaaaRecordTimeouts(**timeouts)
        self._values: typing.Dict[str, typing.Any] = {
            "name": name,
            "records": records,
            "resource_group_name": resource_group_name,
            "ttl": ttl,
            "zone_name": zone_name,
        }
        if count is not None:
            self._values["count"] = count
        if depends_on is not None:
            self._values["depends_on"] = depends_on
        if lifecycle is not None:
            self._values["lifecycle"] = lifecycle
        if provider is not None:
            self._values["provider"] = provider
        if tags is not None:
            self._values["tags"] = tags
        if timeouts is not None:
            self._values["timeouts"] = timeouts

    @builtins.property
    def count(self) -> typing.Optional[jsii.Number]:
        """
        :stability: experimental
        """
        result = self._values.get("count")
        return result

    @builtins.property
    def depends_on(self) -> typing.Optional[typing.List[cdktf.TerraformResource]]:
        """
        :stability: experimental
        """
        result = self._values.get("depends_on")
        return result

    @builtins.property
    def lifecycle(self) -> typing.Optional[cdktf.TerraformResourceLifecycle]:
        """
        :stability: experimental
        """
        result = self._values.get("lifecycle")
        return result

    @builtins.property
    def provider(self) -> typing.Optional[cdktf.TerraformProvider]:
        """
        :stability: experimental
        """
        result = self._values.get("provider")
        return result

    @builtins.property
    def name(self) -> builtins.str:
        result = self._values.get("name")
        assert result is not None, "Required property 'name' is missing"
        return result

    @builtins.property
    def records(self) -> typing.List[builtins.str]:
        result = self._values.get("records")
        assert result is not None, "Required property 'records' is missing"
        return result

    @builtins.property
    def resource_group_name(self) -> builtins.str:
        result = self._values.get("resource_group_name")
        assert result is not None, "Required property 'resource_group_name' is missing"
        return result

    @builtins.property
    def ttl(self) -> jsii.Number:
        result = self._values.get("ttl")
        assert result is not None, "Required property 'ttl' is missing"
        return result

    @builtins.property
    def zone_name(self) -> builtins.str:
        result = self._values.get("zone_name")
        assert result is not None, "Required property 'zone_name' is missing"
        return result

    @builtins.property
    def tags(self) -> typing.Optional[typing.Mapping[builtins.str, builtins.str]]:
        result = self._values.get("tags")
        return result

    @builtins.property
    def timeouts(self) -> typing.Optional["PrivateDnsAaaaRecordTimeouts"]:
        """timeouts block."""
        result = self._values.get("timeouts")
        return result

    def __eq__(self, rhs: typing.Any) -> builtins.bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs: typing.Any) -> builtins.bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return "PrivateDnsAaaaRecordConfig(%s)" % ", ".join(
            k + "=" + repr(v) for k, v in self._values.items()
        )


@jsii.data_type(
    jsii_type="@cdktf/provider-azurerm.PrivateDnsAaaaRecordTimeouts",
    jsii_struct_bases=[],
    name_mapping={
        "create": "create",
        "delete": "delete",
        "read": "read",
        "update": "update",
    },
)
class PrivateDnsAaaaRecordTimeouts:
    def __init__(
        self,
        *,
        create: typing.Optional[builtins.str] = None,
        delete: typing.Optional[builtins.str] = None,
        read: typing.Optional[builtins.str] = None,
        update: typing.Optional[builtins.str] = None,
    ) -> None:
        """
        :param create: 
        :param delete: 
        :param read: 
        :param update: 
        """
        self._values: typing.Dict[str, typing.Any] = {}
        if create is not None:
            self._values["create"] = create
        if delete is not None:
            self._values["delete"] = delete
        if read is not None:
            self._values["read"] = read
        if update is not None:
            self._values["update"] = update

    @builtins.property
    def create(self) -> typing.Optional[builtins.str]:
        result = self._values.get("create")
        return result

    @builtins.property
    def delete(self) -> typing.Optional[builtins.str]:
        result = self._values.get("delete")
        return result

    @builtins.property
    def read(self) -> typing.Optional[builtins.str]:
        result = self._values.get("read")
        return result

    @builtins.property
    def update(self) -> typing.Optional[builtins.str]:
        result = self._values.get("update")
        return result

    def __eq__(self, rhs: typing.Any) -> builtins.bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs: typing.Any) -> builtins.bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return "PrivateDnsAaaaRecordTimeouts(%s)" % ", ".join(
            k + "=" + repr(v) for k, v in self._values.items()
        )


class PrivateDnsCnameRecord(
    cdktf.TerraformResource,
    metaclass=jsii.JSIIMeta,
    jsii_type="@cdktf/provider-azurerm.PrivateDnsCnameRecord",
):
    def __init__(
        self,
        scope: constructs.Construct,
        id: builtins.str,
        *,
        name: builtins.str,
        record: builtins.str,
        resource_group_name: builtins.str,
        ttl: jsii.Number,
        zone_name: builtins.str,
        tags: typing.Optional[typing.Mapping[builtins.str, builtins.str]] = None,
        timeouts: typing.Optional["PrivateDnsCnameRecordTimeouts"] = None,
        count: typing.Optional[jsii.Number] = None,
        depends_on: typing.Optional[typing.List[cdktf.TerraformResource]] = None,
        lifecycle: typing.Optional[cdktf.TerraformResourceLifecycle] = None,
        provider: typing.Optional[cdktf.TerraformProvider] = None,
    ) -> None:
        """
        :param scope: -
        :param id: -
        :param name: 
        :param record: 
        :param resource_group_name: 
        :param ttl: 
        :param zone_name: 
        :param tags: 
        :param timeouts: timeouts block.
        :param count: 
        :param depends_on: 
        :param lifecycle: 
        :param provider: 
        """
        config = PrivateDnsCnameRecordConfig(
            name=name,
            record=record,
            resource_group_name=resource_group_name,
            ttl=ttl,
            zone_name=zone_name,
            tags=tags,
            timeouts=timeouts,
            count=count,
            depends_on=depends_on,
            lifecycle=lifecycle,
            provider=provider,
        )

        jsii.create(PrivateDnsCnameRecord, self, [scope, id, config])

    @jsii.member(jsii_name="synthesizeAttributes")
    def _synthesize_attributes(self) -> typing.Mapping[builtins.str, typing.Any]:
        return jsii.invoke(self, "synthesizeAttributes", [])

    @builtins.property # type: ignore
    @jsii.member(jsii_name="name")
    def name(self) -> builtins.str:
        return jsii.get(self, "name")

    @name.setter # type: ignore
    def name(self, value: builtins.str) -> None:
        jsii.set(self, "name", value)

    @builtins.property # type: ignore
    @jsii.member(jsii_name="record")
    def record(self) -> builtins.str:
        return jsii.get(self, "record")

    @record.setter # type: ignore
    def record(self, value: builtins.str) -> None:
        jsii.set(self, "record", value)

    @builtins.property # type: ignore
    @jsii.member(jsii_name="resourceGroupName")
    def resource_group_name(self) -> builtins.str:
        return jsii.get(self, "resourceGroupName")

    @resource_group_name.setter # type: ignore
    def resource_group_name(self, value: builtins.str) -> None:
        jsii.set(self, "resourceGroupName", value)

    @builtins.property # type: ignore
    @jsii.member(jsii_name="ttl")
    def ttl(self) -> jsii.Number:
        return jsii.get(self, "ttl")

    @ttl.setter # type: ignore
    def ttl(self, value: jsii.Number) -> None:
        jsii.set(self, "ttl", value)

    @builtins.property # type: ignore
    @jsii.member(jsii_name="zoneName")
    def zone_name(self) -> builtins.str:
        return jsii.get(self, "zoneName")

    @zone_name.setter # type: ignore
    def zone_name(self, value: builtins.str) -> None:
        jsii.set(self, "zoneName", value)

    @builtins.property # type: ignore
    @jsii.member(jsii_name="id")
    def id(self) -> typing.Optional[builtins.str]:
        return jsii.get(self, "id")

    @id.setter # type: ignore
    def id(self, value: typing.Optional[builtins.str]) -> None:
        jsii.set(self, "id", value)

    @builtins.property # type: ignore
    @jsii.member(jsii_name="tags")
    def tags(self) -> typing.Optional[typing.Mapping[builtins.str, builtins.str]]:
        return jsii.get(self, "tags")

    @tags.setter # type: ignore
    def tags(
        self,
        value: typing.Optional[typing.Mapping[builtins.str, builtins.str]],
    ) -> None:
        jsii.set(self, "tags", value)

    @builtins.property # type: ignore
    @jsii.member(jsii_name="timeouts")
    def timeouts(self) -> typing.Optional["PrivateDnsCnameRecordTimeouts"]:
        return jsii.get(self, "timeouts")

    @timeouts.setter # type: ignore
    def timeouts(self, value: typing.Optional["PrivateDnsCnameRecordTimeouts"]) -> None:
        jsii.set(self, "timeouts", value)


@jsii.data_type(
    jsii_type="@cdktf/provider-azurerm.PrivateDnsCnameRecordConfig",
    jsii_struct_bases=[cdktf.TerraformMetaArguments],
    name_mapping={
        "count": "count",
        "depends_on": "dependsOn",
        "lifecycle": "lifecycle",
        "provider": "provider",
        "name": "name",
        "record": "record",
        "resource_group_name": "resourceGroupName",
        "ttl": "ttl",
        "zone_name": "zoneName",
        "tags": "tags",
        "timeouts": "timeouts",
    },
)
class PrivateDnsCnameRecordConfig(cdktf.TerraformMetaArguments):
    def __init__(
        self,
        *,
        count: typing.Optional[jsii.Number] = None,
        depends_on: typing.Optional[typing.List[cdktf.TerraformResource]] = None,
        lifecycle: typing.Optional[cdktf.TerraformResourceLifecycle] = None,
        provider: typing.Optional[cdktf.TerraformProvider] = None,
        name: builtins.str,
        record: builtins.str,
        resource_group_name: builtins.str,
        ttl: jsii.Number,
        zone_name: builtins.str,
        tags: typing.Optional[typing.Mapping[builtins.str, builtins.str]] = None,
        timeouts: typing.Optional["PrivateDnsCnameRecordTimeouts"] = None,
    ) -> None:
        """
        :param count: 
        :param depends_on: 
        :param lifecycle: 
        :param provider: 
        :param name: 
        :param record: 
        :param resource_group_name: 
        :param ttl: 
        :param zone_name: 
        :param tags: 
        :param timeouts: timeouts block.
        """
        if isinstance(lifecycle, dict):
            lifecycle = cdktf.TerraformResourceLifecycle(**lifecycle)
        if isinstance(timeouts, dict):
            timeouts = PrivateDnsCnameRecordTimeouts(**timeouts)
        self._values: typing.Dict[str, typing.Any] = {
            "name": name,
            "record": record,
            "resource_group_name": resource_group_name,
            "ttl": ttl,
            "zone_name": zone_name,
        }
        if count is not None:
            self._values["count"] = count
        if depends_on is not None:
            self._values["depends_on"] = depends_on
        if lifecycle is not None:
            self._values["lifecycle"] = lifecycle
        if provider is not None:
            self._values["provider"] = provider
        if tags is not None:
            self._values["tags"] = tags
        if timeouts is not None:
            self._values["timeouts"] = timeouts

    @builtins.property
    def count(self) -> typing.Optional[jsii.Number]:
        """
        :stability: experimental
        """
        result = self._values.get("count")
        return result

    @builtins.property
    def depends_on(self) -> typing.Optional[typing.List[cdktf.TerraformResource]]:
        """
        :stability: experimental
        """
        result = self._values.get("depends_on")
        return result

    @builtins.property
    def lifecycle(self) -> typing.Optional[cdktf.TerraformResourceLifecycle]:
        """
        :stability: experimental
        """
        result = self._values.get("lifecycle")
        return result

    @builtins.property
    def provider(self) -> typing.Optional[cdktf.TerraformProvider]:
        """
        :stability: experimental
        """
        result = self._values.get("provider")
        return result

    @builtins.property
    def name(self) -> builtins.str:
        result = self._values.get("name")
        assert result is not None, "Required property 'name' is missing"
        return result

    @builtins.property
    def record(self) -> builtins.str:
        result = self._values.get("record")
        assert result is not None, "Required property 'record' is missing"
        return result

    @builtins.property
    def resource_group_name(self) -> builtins.str:
        result = self._values.get("resource_group_name")
        assert result is not None, "Required property 'resource_group_name' is missing"
        return result

    @builtins.property
    def ttl(self) -> jsii.Number:
        result = self._values.get("ttl")
        assert result is not None, "Required property 'ttl' is missing"
        return result

    @builtins.property
    def zone_name(self) -> builtins.str:
        result = self._values.get("zone_name")
        assert result is not None, "Required property 'zone_name' is missing"
        return result

    @builtins.property
    def tags(self) -> typing.Optional[typing.Mapping[builtins.str, builtins.str]]:
        result = self._values.get("tags")
        return result

    @builtins.property
    def timeouts(self) -> typing.Optional["PrivateDnsCnameRecordTimeouts"]:
        """timeouts block."""
        result = self._values.get("timeouts")
        return result

    def __eq__(self, rhs: typing.Any) -> builtins.bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs: typing.Any) -> builtins.bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return "PrivateDnsCnameRecordConfig(%s)" % ", ".join(
            k + "=" + repr(v) for k, v in self._values.items()
        )


@jsii.data_type(
    jsii_type="@cdktf/provider-azurerm.PrivateDnsCnameRecordTimeouts",
    jsii_struct_bases=[],
    name_mapping={
        "create": "create",
        "delete": "delete",
        "read": "read",
        "update": "update",
    },
)
class PrivateDnsCnameRecordTimeouts:
    def __init__(
        self,
        *,
        create: typing.Optional[builtins.str] = None,
        delete: typing.Optional[builtins.str] = None,
        read: typing.Optional[builtins.str] = None,
        update: typing.Optional[builtins.str] = None,
    ) -> None:
        """
        :param create: 
        :param delete: 
        :param read: 
        :param update: 
        """
        self._values: typing.Dict[str, typing.Any] = {}
        if create is not None:
            self._values["create"] = create
        if delete is not None:
            self._values["delete"] = delete
        if read is not None:
            self._values["read"] = read
        if update is not None:
            self._values["update"] = update

    @builtins.property
    def create(self) -> typing.Optional[builtins.str]:
        result = self._values.get("create")
        return result

    @builtins.property
    def delete(self) -> typing.Optional[builtins.str]:
        result = self._values.get("delete")
        return result

    @builtins.property
    def read(self) -> typing.Optional[builtins.str]:
        result = self._values.get("read")
        return result

    @builtins.property
    def update(self) -> typing.Optional[builtins.str]:
        result = self._values.get("update")
        return result

    def __eq__(self, rhs: typing.Any) -> builtins.bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs: typing.Any) -> builtins.bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return "PrivateDnsCnameRecordTimeouts(%s)" % ", ".join(
            k + "=" + repr(v) for k, v in self._values.items()
        )


class PrivateDnsMxRecord(
    cdktf.TerraformResource,
    metaclass=jsii.JSIIMeta,
    jsii_type="@cdktf/provider-azurerm.PrivateDnsMxRecord",
):
    def __init__(
        self,
        scope: constructs.Construct,
        id: builtins.str,
        *,
        record: typing.List["PrivateDnsMxRecordRecord"],
        resource_group_name: builtins.str,
        ttl: jsii.Number,
        zone_name: builtins.str,
        name: typing.Optional[builtins.str] = None,
        tags: typing.Optional[typing.Mapping[builtins.str, builtins.str]] = None,
        timeouts: typing.Optional["PrivateDnsMxRecordTimeouts"] = None,
        count: typing.Optional[jsii.Number] = None,
        depends_on: typing.Optional[typing.List[cdktf.TerraformResource]] = None,
        lifecycle: typing.Optional[cdktf.TerraformResourceLifecycle] = None,
        provider: typing.Optional[cdktf.TerraformProvider] = None,
    ) -> None:
        """
        :param scope: -
        :param id: -
        :param record: record block.
        :param resource_group_name: 
        :param ttl: 
        :param zone_name: 
        :param name: 
        :param tags: 
        :param timeouts: timeouts block.
        :param count: 
        :param depends_on: 
        :param lifecycle: 
        :param provider: 
        """
        config = PrivateDnsMxRecordConfig(
            record=record,
            resource_group_name=resource_group_name,
            ttl=ttl,
            zone_name=zone_name,
            name=name,
            tags=tags,
            timeouts=timeouts,
            count=count,
            depends_on=depends_on,
            lifecycle=lifecycle,
            provider=provider,
        )

        jsii.create(PrivateDnsMxRecord, self, [scope, id, config])

    @jsii.member(jsii_name="synthesizeAttributes")
    def _synthesize_attributes(self) -> typing.Mapping[builtins.str, typing.Any]:
        return jsii.invoke(self, "synthesizeAttributes", [])

    @builtins.property # type: ignore
    @jsii.member(jsii_name="record")
    def record(self) -> typing.List["PrivateDnsMxRecordRecord"]:
        return jsii.get(self, "record")

    @record.setter # type: ignore
    def record(self, value: typing.List["PrivateDnsMxRecordRecord"]) -> None:
        jsii.set(self, "record", value)

    @builtins.property # type: ignore
    @jsii.member(jsii_name="resourceGroupName")
    def resource_group_name(self) -> builtins.str:
        return jsii.get(self, "resourceGroupName")

    @resource_group_name.setter # type: ignore
    def resource_group_name(self, value: builtins.str) -> None:
        jsii.set(self, "resourceGroupName", value)

    @builtins.property # type: ignore
    @jsii.member(jsii_name="ttl")
    def ttl(self) -> jsii.Number:
        return jsii.get(self, "ttl")

    @ttl.setter # type: ignore
    def ttl(self, value: jsii.Number) -> None:
        jsii.set(self, "ttl", value)

    @builtins.property # type: ignore
    @jsii.member(jsii_name="zoneName")
    def zone_name(self) -> builtins.str:
        return jsii.get(self, "zoneName")

    @zone_name.setter # type: ignore
    def zone_name(self, value: builtins.str) -> None:
        jsii.set(self, "zoneName", value)

    @builtins.property # type: ignore
    @jsii.member(jsii_name="id")
    def id(self) -> typing.Optional[builtins.str]:
        return jsii.get(self, "id")

    @id.setter # type: ignore
    def id(self, value: typing.Optional[builtins.str]) -> None:
        jsii.set(self, "id", value)

    @builtins.property # type: ignore
    @jsii.member(jsii_name="name")
    def name(self) -> typing.Optional[builtins.str]:
        return jsii.get(self, "name")

    @name.setter # type: ignore
    def name(self, value: typing.Optional[builtins.str]) -> None:
        jsii.set(self, "name", value)

    @builtins.property # type: ignore
    @jsii.member(jsii_name="tags")
    def tags(self) -> typing.Optional[typing.Mapping[builtins.str, builtins.str]]:
        return jsii.get(self, "tags")

    @tags.setter # type: ignore
    def tags(
        self,
        value: typing.Optional[typing.Mapping[builtins.str, builtins.str]],
    ) -> None:
        jsii.set(self, "tags", value)

    @builtins.property # type: ignore
    @jsii.member(jsii_name="timeouts")
    def timeouts(self) -> typing.Optional["PrivateDnsMxRecordTimeouts"]:
        return jsii.get(self, "timeouts")

    @timeouts.setter # type: ignore
    def timeouts(self, value: typing.Optional["PrivateDnsMxRecordTimeouts"]) -> None:
        jsii.set(self, "timeouts", value)


@jsii.data_type(
    jsii_type="@cdktf/provider-azurerm.PrivateDnsMxRecordConfig",
    jsii_struct_bases=[cdktf.TerraformMetaArguments],
    name_mapping={
        "count": "count",
        "depends_on": "dependsOn",
        "lifecycle": "lifecycle",
        "provider": "provider",
        "record": "record",
        "resource_group_name": "resourceGroupName",
        "ttl": "ttl",
        "zone_name": "zoneName",
        "name": "name",
        "tags": "tags",
        "timeouts": "timeouts",
    },
)
class PrivateDnsMxRecordConfig(cdktf.TerraformMetaArguments):
    def __init__(
        self,
        *,
        count: typing.Optional[jsii.Number] = None,
        depends_on: typing.Optional[typing.List[cdktf.TerraformResource]] = None,
        lifecycle: typing.Optional[cdktf.TerraformResourceLifecycle] = None,
        provider: typing.Optional[cdktf.TerraformProvider] = None,
        record: typing.List["PrivateDnsMxRecordRecord"],
        resource_group_name: builtins.str,
        ttl: jsii.Number,
        zone_name: builtins.str,
        name: typing.Optional[builtins.str] = None,
        tags: typing.Optional[typing.Mapping[builtins.str, builtins.str]] = None,
        timeouts: typing.Optional["PrivateDnsMxRecordTimeouts"] = None,
    ) -> None:
        """
        :param count: 
        :param depends_on: 
        :param lifecycle: 
        :param provider: 
        :param record: record block.
        :param resource_group_name: 
        :param ttl: 
        :param zone_name: 
        :param name: 
        :param tags: 
        :param timeouts: timeouts block.
        """
        if isinstance(lifecycle, dict):
            lifecycle = cdktf.TerraformResourceLifecycle(**lifecycle)
        if isinstance(timeouts, dict):
            timeouts = PrivateDnsMxRecordTimeouts(**timeouts)
        self._values: typing.Dict[str, typing.Any] = {
            "record": record,
            "resource_group_name": resource_group_name,
            "ttl": ttl,
            "zone_name": zone_name,
        }
        if count is not None:
            self._values["count"] = count
        if depends_on is not None:
            self._values["depends_on"] = depends_on
        if lifecycle is not None:
            self._values["lifecycle"] = lifecycle
        if provider is not None:
            self._values["provider"] = provider
        if name is not None:
            self._values["name"] = name
        if tags is not None:
            self._values["tags"] = tags
        if timeouts is not None:
            self._values["timeouts"] = timeouts

    @builtins.property
    def count(self) -> typing.Optional[jsii.Number]:
        """
        :stability: experimental
        """
        result = self._values.get("count")
        return result

    @builtins.property
    def depends_on(self) -> typing.Optional[typing.List[cdktf.TerraformResource]]:
        """
        :stability: experimental
        """
        result = self._values.get("depends_on")
        return result

    @builtins.property
    def lifecycle(self) -> typing.Optional[cdktf.TerraformResourceLifecycle]:
        """
        :stability: experimental
        """
        result = self._values.get("lifecycle")
        return result

    @builtins.property
    def provider(self) -> typing.Optional[cdktf.TerraformProvider]:
        """
        :stability: experimental
        """
        result = self._values.get("provider")
        return result

    @builtins.property
    def record(self) -> typing.List["PrivateDnsMxRecordRecord"]:
        """record block."""
        result = self._values.get("record")
        assert result is not None, "Required property 'record' is missing"
        return result

    @builtins.property
    def resource_group_name(self) -> builtins.str:
        result = self._values.get("resource_group_name")
        assert result is not None, "Required property 'resource_group_name' is missing"
        return result

    @builtins.property
    def ttl(self) -> jsii.Number:
        result = self._values.get("ttl")
        assert result is not None, "Required property 'ttl' is missing"
        return result

    @builtins.property
    def zone_name(self) -> builtins.str:
        result = self._values.get("zone_name")
        assert result is not None, "Required property 'zone_name' is missing"
        return result

    @builtins.property
    def name(self) -> typing.Optional[builtins.str]:
        result = self._values.get("name")
        return result

    @builtins.property
    def tags(self) -> typing.Optional[typing.Mapping[builtins.str, builtins.str]]:
        result = self._values.get("tags")
        return result

    @builtins.property
    def timeouts(self) -> typing.Optional["PrivateDnsMxRecordTimeouts"]:
        """timeouts block."""
        result = self._values.get("timeouts")
        return result

    def __eq__(self, rhs: typing.Any) -> builtins.bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs: typing.Any) -> builtins.bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return "PrivateDnsMxRecordConfig(%s)" % ", ".join(
            k + "=" + repr(v) for k, v in self._values.items()
        )


@jsii.data_type(
    jsii_type="@cdktf/provider-azurerm.PrivateDnsMxRecordRecord",
    jsii_struct_bases=[],
    name_mapping={"exchange": "exchange", "preference": "preference"},
)
class PrivateDnsMxRecordRecord:
    def __init__(self, *, exchange: builtins.str, preference: jsii.Number) -> None:
        """
        :param exchange: 
        :param preference: 
        """
        self._values: typing.Dict[str, typing.Any] = {
            "exchange": exchange,
            "preference": preference,
        }

    @builtins.property
    def exchange(self) -> builtins.str:
        result = self._values.get("exchange")
        assert result is not None, "Required property 'exchange' is missing"
        return result

    @builtins.property
    def preference(self) -> jsii.Number:
        result = self._values.get("preference")
        assert result is not None, "Required property 'preference' is missing"
        return result

    def __eq__(self, rhs: typing.Any) -> builtins.bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs: typing.Any) -> builtins.bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return "PrivateDnsMxRecordRecord(%s)" % ", ".join(
            k + "=" + repr(v) for k, v in self._values.items()
        )


@jsii.data_type(
    jsii_type="@cdktf/provider-azurerm.PrivateDnsMxRecordTimeouts",
    jsii_struct_bases=[],
    name_mapping={
        "create": "create",
        "delete": "delete",
        "read": "read",
        "update": "update",
    },
)
class PrivateDnsMxRecordTimeouts:
    def __init__(
        self,
        *,
        create: typing.Optional[builtins.str] = None,
        delete: typing.Optional[builtins.str] = None,
        read: typing.Optional[builtins.str] = None,
        update: typing.Optional[builtins.str] = None,
    ) -> None:
        """
        :param create: 
        :param delete: 
        :param read: 
        :param update: 
        """
        self._values: typing.Dict[str, typing.Any] = {}
        if create is not None:
            self._values["create"] = create
        if delete is not None:
            self._values["delete"] = delete
        if read is not None:
            self._values["read"] = read
        if update is not None:
            self._values["update"] = update

    @builtins.property
    def create(self) -> typing.Optional[builtins.str]:
        result = self._values.get("create")
        return result

    @builtins.property
    def delete(self) -> typing.Optional[builtins.str]:
        result = self._values.get("delete")
        return result

    @builtins.property
    def read(self) -> typing.Optional[builtins.str]:
        result = self._values.get("read")
        return result

    @builtins.property
    def update(self) -> typing.Optional[builtins.str]:
        result = self._values.get("update")
        return result

    def __eq__(self, rhs: typing.Any) -> builtins.bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs: typing.Any) -> builtins.bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return "PrivateDnsMxRecordTimeouts(%s)" % ", ".join(
            k + "=" + repr(v) for k, v in self._values.items()
        )


class PrivateDnsPtrRecord(
    cdktf.TerraformResource,
    metaclass=jsii.JSIIMeta,
    jsii_type="@cdktf/provider-azurerm.PrivateDnsPtrRecord",
):
    def __init__(
        self,
        scope: constructs.Construct,
        id: builtins.str,
        *,
        name: builtins.str,
        records: typing.List[builtins.str],
        resource_group_name: builtins.str,
        ttl: jsii.Number,
        zone_name: builtins.str,
        tags: typing.Optional[typing.Mapping[builtins.str, builtins.str]] = None,
        timeouts: typing.Optional["PrivateDnsPtrRecordTimeouts"] = None,
        count: typing.Optional[jsii.Number] = None,
        depends_on: typing.Optional[typing.List[cdktf.TerraformResource]] = None,
        lifecycle: typing.Optional[cdktf.TerraformResourceLifecycle] = None,
        provider: typing.Optional[cdktf.TerraformProvider] = None,
    ) -> None:
        """
        :param scope: -
        :param id: -
        :param name: 
        :param records: 
        :param resource_group_name: 
        :param ttl: 
        :param zone_name: 
        :param tags: 
        :param timeouts: timeouts block.
        :param count: 
        :param depends_on: 
        :param lifecycle: 
        :param provider: 
        """
        config = PrivateDnsPtrRecordConfig(
            name=name,
            records=records,
            resource_group_name=resource_group_name,
            ttl=ttl,
            zone_name=zone_name,
            tags=tags,
            timeouts=timeouts,
            count=count,
            depends_on=depends_on,
            lifecycle=lifecycle,
            provider=provider,
        )

        jsii.create(PrivateDnsPtrRecord, self, [scope, id, config])

    @jsii.member(jsii_name="synthesizeAttributes")
    def _synthesize_attributes(self) -> typing.Mapping[builtins.str, typing.Any]:
        return jsii.invoke(self, "synthesizeAttributes", [])

    @builtins.property # type: ignore
    @jsii.member(jsii_name="name")
    def name(self) -> builtins.str:
        return jsii.get(self, "name")

    @name.setter # type: ignore
    def name(self, value: builtins.str) -> None:
        jsii.set(self, "name", value)

    @builtins.property # type: ignore
    @jsii.member(jsii_name="records")
    def records(self) -> typing.List[builtins.str]:
        return jsii.get(self, "records")

    @records.setter # type: ignore
    def records(self, value: typing.List[builtins.str]) -> None:
        jsii.set(self, "records", value)

    @builtins.property # type: ignore
    @jsii.member(jsii_name="resourceGroupName")
    def resource_group_name(self) -> builtins.str:
        return jsii.get(self, "resourceGroupName")

    @resource_group_name.setter # type: ignore
    def resource_group_name(self, value: builtins.str) -> None:
        jsii.set(self, "resourceGroupName", value)

    @builtins.property # type: ignore
    @jsii.member(jsii_name="ttl")
    def ttl(self) -> jsii.Number:
        return jsii.get(self, "ttl")

    @ttl.setter # type: ignore
    def ttl(self, value: jsii.Number) -> None:
        jsii.set(self, "ttl", value)

    @builtins.property # type: ignore
    @jsii.member(jsii_name="zoneName")
    def zone_name(self) -> builtins.str:
        return jsii.get(self, "zoneName")

    @zone_name.setter # type: ignore
    def zone_name(self, value: builtins.str) -> None:
        jsii.set(self, "zoneName", value)

    @builtins.property # type: ignore
    @jsii.member(jsii_name="id")
    def id(self) -> typing.Optional[builtins.str]:
        return jsii.get(self, "id")

    @id.setter # type: ignore
    def id(self, value: typing.Optional[builtins.str]) -> None:
        jsii.set(self, "id", value)

    @builtins.property # type: ignore
    @jsii.member(jsii_name="tags")
    def tags(self) -> typing.Optional[typing.Mapping[builtins.str, builtins.str]]:
        return jsii.get(self, "tags")

    @tags.setter # type: ignore
    def tags(
        self,
        value: typing.Optional[typing.Mapping[builtins.str, builtins.str]],
    ) -> None:
        jsii.set(self, "tags", value)

    @builtins.property # type: ignore
    @jsii.member(jsii_name="timeouts")
    def timeouts(self) -> typing.Optional["PrivateDnsPtrRecordTimeouts"]:
        return jsii.get(self, "timeouts")

    @timeouts.setter # type: ignore
    def timeouts(self, value: typing.Optional["PrivateDnsPtrRecordTimeouts"]) -> None:
        jsii.set(self, "timeouts", value)


@jsii.data_type(
    jsii_type="@cdktf/provider-azurerm.PrivateDnsPtrRecordConfig",
    jsii_struct_bases=[cdktf.TerraformMetaArguments],
    name_mapping={
        "count": "count",
        "depends_on": "dependsOn",
        "lifecycle": "lifecycle",
        "provider": "provider",
        "name": "name",
        "records": "records",
        "resource_group_name": "resourceGroupName",
        "ttl": "ttl",
        "zone_name": "zoneName",
        "tags": "tags",
        "timeouts": "timeouts",
    },
)
class PrivateDnsPtrRecordConfig(cdktf.TerraformMetaArguments):
    def __init__(
        self,
        *,
        count: typing.Optional[jsii.Number] = None,
        depends_on: typing.Optional[typing.List[cdktf.TerraformResource]] = None,
        lifecycle: typing.Optional[cdktf.TerraformResourceLifecycle] = None,
        provider: typing.Optional[cdktf.TerraformProvider] = None,
        name: builtins.str,
        records: typing.List[builtins.str],
        resource_group_name: builtins.str,
        ttl: jsii.Number,
        zone_name: builtins.str,
        tags: typing.Optional[typing.Mapping[builtins.str, builtins.str]] = None,
        timeouts: typing.Optional["PrivateDnsPtrRecordTimeouts"] = None,
    ) -> None:
        """
        :param count: 
        :param depends_on: 
        :param lifecycle: 
        :param provider: 
        :param name: 
        :param records: 
        :param resource_group_name: 
        :param ttl: 
        :param zone_name: 
        :param tags: 
        :param timeouts: timeouts block.
        """
        if isinstance(lifecycle, dict):
            lifecycle = cdktf.TerraformResourceLifecycle(**lifecycle)
        if isinstance(timeouts, dict):
            timeouts = PrivateDnsPtrRecordTimeouts(**timeouts)
        self._values: typing.Dict[str, typing.Any] = {
            "name": name,
            "records": records,
            "resource_group_name": resource_group_name,
            "ttl": ttl,
            "zone_name": zone_name,
        }
        if count is not None:
            self._values["count"] = count
        if depends_on is not None:
            self._values["depends_on"] = depends_on
        if lifecycle is not None:
            self._values["lifecycle"] = lifecycle
        if provider is not None:
            self._values["provider"] = provider
        if tags is not None:
            self._values["tags"] = tags
        if timeouts is not None:
            self._values["timeouts"] = timeouts

    @builtins.property
    def count(self) -> typing.Optional[jsii.Number]:
        """
        :stability: experimental
        """
        result = self._values.get("count")
        return result

    @builtins.property
    def depends_on(self) -> typing.Optional[typing.List[cdktf.TerraformResource]]:
        """
        :stability: experimental
        """
        result = self._values.get("depends_on")
        return result

    @builtins.property
    def lifecycle(self) -> typing.Optional[cdktf.TerraformResourceLifecycle]:
        """
        :stability: experimental
        """
        result = self._values.get("lifecycle")
        return result

    @builtins.property
    def provider(self) -> typing.Optional[cdktf.TerraformProvider]:
        """
        :stability: experimental
        """
        result = self._values.get("provider")
        return result

    @builtins.property
    def name(self) -> builtins.str:
        result = self._values.get("name")
        assert result is not None, "Required property 'name' is missing"
        return result

    @builtins.property
    def records(self) -> typing.List[builtins.str]:
        result = self._values.get("records")
        assert result is not None, "Required property 'records' is missing"
        return result

    @builtins.property
    def resource_group_name(self) -> builtins.str:
        result = self._values.get("resource_group_name")
        assert result is not None, "Required property 'resource_group_name' is missing"
        return result

    @builtins.property
    def ttl(self) -> jsii.Number:
        result = self._values.get("ttl")
        assert result is not None, "Required property 'ttl' is missing"
        return result

    @builtins.property
    def zone_name(self) -> builtins.str:
        result = self._values.get("zone_name")
        assert result is not None, "Required property 'zone_name' is missing"
        return result

    @builtins.property
    def tags(self) -> typing.Optional[typing.Mapping[builtins.str, builtins.str]]:
        result = self._values.get("tags")
        return result

    @builtins.property
    def timeouts(self) -> typing.Optional["PrivateDnsPtrRecordTimeouts"]:
        """timeouts block."""
        result = self._values.get("timeouts")
        return result

    def __eq__(self, rhs: typing.Any) -> builtins.bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs: typing.Any) -> builtins.bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return "PrivateDnsPtrRecordConfig(%s)" % ", ".join(
            k + "=" + repr(v) for k, v in self._values.items()
        )


@jsii.data_type(
    jsii_type="@cdktf/provider-azurerm.PrivateDnsPtrRecordTimeouts",
    jsii_struct_bases=[],
    name_mapping={
        "create": "create",
        "delete": "delete",
        "read": "read",
        "update": "update",
    },
)
class PrivateDnsPtrRecordTimeouts:
    def __init__(
        self,
        *,
        create: typing.Optional[builtins.str] = None,
        delete: typing.Optional[builtins.str] = None,
        read: typing.Optional[builtins.str] = None,
        update: typing.Optional[builtins.str] = None,
    ) -> None:
        """
        :param create: 
        :param delete: 
        :param read: 
        :param update: 
        """
        self._values: typing.Dict[str, typing.Any] = {}
        if create is not None:
            self._values["create"] = create
        if delete is not None:
            self._values["delete"] = delete
        if read is not None:
            self._values["read"] = read
        if update is not None:
            self._values["update"] = update

    @builtins.property
    def create(self) -> typing.Optional[builtins.str]:
        result = self._values.get("create")
        return result

    @builtins.property
    def delete(self) -> typing.Optional[builtins.str]:
        result = self._values.get("delete")
        return result

    @builtins.property
    def read(self) -> typing.Optional[builtins.str]:
        result = self._values.get("read")
        return result

    @builtins.property
    def update(self) -> typing.Optional[builtins.str]:
        result = self._values.get("update")
        return result

    def __eq__(self, rhs: typing.Any) -> builtins.bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs: typing.Any) -> builtins.bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return "PrivateDnsPtrRecordTimeouts(%s)" % ", ".join(
            k + "=" + repr(v) for k, v in self._values.items()
        )


class PrivateDnsSrvRecord(
    cdktf.TerraformResource,
    metaclass=jsii.JSIIMeta,
    jsii_type="@cdktf/provider-azurerm.PrivateDnsSrvRecord",
):
    def __init__(
        self,
        scope: constructs.Construct,
        id: builtins.str,
        *,
        name: builtins.str,
        record: typing.List["PrivateDnsSrvRecordRecord"],
        resource_group_name: builtins.str,
        ttl: jsii.Number,
        zone_name: builtins.str,
        tags: typing.Optional[typing.Mapping[builtins.str, builtins.str]] = None,
        timeouts: typing.Optional["PrivateDnsSrvRecordTimeouts"] = None,
        count: typing.Optional[jsii.Number] = None,
        depends_on: typing.Optional[typing.List[cdktf.TerraformResource]] = None,
        lifecycle: typing.Optional[cdktf.TerraformResourceLifecycle] = None,
        provider: typing.Optional[cdktf.TerraformProvider] = None,
    ) -> None:
        """
        :param scope: -
        :param id: -
        :param name: 
        :param record: record block.
        :param resource_group_name: 
        :param ttl: 
        :param zone_name: 
        :param tags: 
        :param timeouts: timeouts block.
        :param count: 
        :param depends_on: 
        :param lifecycle: 
        :param provider: 
        """
        config = PrivateDnsSrvRecordConfig(
            name=name,
            record=record,
            resource_group_name=resource_group_name,
            ttl=ttl,
            zone_name=zone_name,
            tags=tags,
            timeouts=timeouts,
            count=count,
            depends_on=depends_on,
            lifecycle=lifecycle,
            provider=provider,
        )

        jsii.create(PrivateDnsSrvRecord, self, [scope, id, config])

    @jsii.member(jsii_name="synthesizeAttributes")
    def _synthesize_attributes(self) -> typing.Mapping[builtins.str, typing.Any]:
        return jsii.invoke(self, "synthesizeAttributes", [])

    @builtins.property # type: ignore
    @jsii.member(jsii_name="name")
    def name(self) -> builtins.str:
        return jsii.get(self, "name")

    @name.setter # type: ignore
    def name(self, value: builtins.str) -> None:
        jsii.set(self, "name", value)

    @builtins.property # type: ignore
    @jsii.member(jsii_name="record")
    def record(self) -> typing.List["PrivateDnsSrvRecordRecord"]:
        return jsii.get(self, "record")

    @record.setter # type: ignore
    def record(self, value: typing.List["PrivateDnsSrvRecordRecord"]) -> None:
        jsii.set(self, "record", value)

    @builtins.property # type: ignore
    @jsii.member(jsii_name="resourceGroupName")
    def resource_group_name(self) -> builtins.str:
        return jsii.get(self, "resourceGroupName")

    @resource_group_name.setter # type: ignore
    def resource_group_name(self, value: builtins.str) -> None:
        jsii.set(self, "resourceGroupName", value)

    @builtins.property # type: ignore
    @jsii.member(jsii_name="ttl")
    def ttl(self) -> jsii.Number:
        return jsii.get(self, "ttl")

    @ttl.setter # type: ignore
    def ttl(self, value: jsii.Number) -> None:
        jsii.set(self, "ttl", value)

    @builtins.property # type: ignore
    @jsii.member(jsii_name="zoneName")
    def zone_name(self) -> builtins.str:
        return jsii.get(self, "zoneName")

    @zone_name.setter # type: ignore
    def zone_name(self, value: builtins.str) -> None:
        jsii.set(self, "zoneName", value)

    @builtins.property # type: ignore
    @jsii.member(jsii_name="id")
    def id(self) -> typing.Optional[builtins.str]:
        return jsii.get(self, "id")

    @id.setter # type: ignore
    def id(self, value: typing.Optional[builtins.str]) -> None:
        jsii.set(self, "id", value)

    @builtins.property # type: ignore
    @jsii.member(jsii_name="tags")
    def tags(self) -> typing.Optional[typing.Mapping[builtins.str, builtins.str]]:
        return jsii.get(self, "tags")

    @tags.setter # type: ignore
    def tags(
        self,
        value: typing.Optional[typing.Mapping[builtins.str, builtins.str]],
    ) -> None:
        jsii.set(self, "tags", value)

    @builtins.property # type: ignore
    @jsii.member(jsii_name="timeouts")
    def timeouts(self) -> typing.Optional["PrivateDnsSrvRecordTimeouts"]:
        return jsii.get(self, "timeouts")

    @timeouts.setter # type: ignore
    def timeouts(self, value: typing.Optional["PrivateDnsSrvRecordTimeouts"]) -> None:
        jsii.set(self, "timeouts", value)


@jsii.data_type(
    jsii_type="@cdktf/provider-azurerm.PrivateDnsSrvRecordConfig",
    jsii_struct_bases=[cdktf.TerraformMetaArguments],
    name_mapping={
        "count": "count",
        "depends_on": "dependsOn",
        "lifecycle": "lifecycle",
        "provider": "provider",
        "name": "name",
        "record": "record",
        "resource_group_name": "resourceGroupName",
        "ttl": "ttl",
        "zone_name": "zoneName",
        "tags": "tags",
        "timeouts": "timeouts",
    },
)
class PrivateDnsSrvRecordConfig(cdktf.TerraformMetaArguments):
    def __init__(
        self,
        *,
        count: typing.Optional[jsii.Number] = None,
        depends_on: typing.Optional[typing.List[cdktf.TerraformResource]] = None,
        lifecycle: typing.Optional[cdktf.TerraformResourceLifecycle] = None,
        provider: typing.Optional[cdktf.TerraformProvider] = None,
        name: builtins.str,
        record: typing.List["PrivateDnsSrvRecordRecord"],
        resource_group_name: builtins.str,
        ttl: jsii.Number,
        zone_name: builtins.str,
        tags: typing.Optional[typing.Mapping[builtins.str, builtins.str]] = None,
        timeouts: typing.Optional["PrivateDnsSrvRecordTimeouts"] = None,
    ) -> None:
        """
        :param count: 
        :param depends_on: 
        :param lifecycle: 
        :param provider: 
        :param name: 
        :param record: record block.
        :param resource_group_name: 
        :param ttl: 
        :param zone_name: 
        :param tags: 
        :param timeouts: timeouts block.
        """
        if isinstance(lifecycle, dict):
            lifecycle = cdktf.TerraformResourceLifecycle(**lifecycle)
        if isinstance(timeouts, dict):
            timeouts = PrivateDnsSrvRecordTimeouts(**timeouts)
        self._values: typing.Dict[str, typing.Any] = {
            "name": name,
            "record": record,
            "resource_group_name": resource_group_name,
            "ttl": ttl,
            "zone_name": zone_name,
        }
        if count is not None:
            self._values["count"] = count
        if depends_on is not None:
            self._values["depends_on"] = depends_on
        if lifecycle is not None:
            self._values["lifecycle"] = lifecycle
        if provider is not None:
            self._values["provider"] = provider
        if tags is not None:
            self._values["tags"] = tags
        if timeouts is not None:
            self._values["timeouts"] = timeouts

    @builtins.property
    def count(self) -> typing.Optional[jsii.Number]:
        """
        :stability: experimental
        """
        result = self._values.get("count")
        return result

    @builtins.property
    def depends_on(self) -> typing.Optional[typing.List[cdktf.TerraformResource]]:
        """
        :stability: experimental
        """
        result = self._values.get("depends_on")
        return result

    @builtins.property
    def lifecycle(self) -> typing.Optional[cdktf.TerraformResourceLifecycle]:
        """
        :stability: experimental
        """
        result = self._values.get("lifecycle")
        return result

    @builtins.property
    def provider(self) -> typing.Optional[cdktf.TerraformProvider]:
        """
        :stability: experimental
        """
        result = self._values.get("provider")
        return result

    @builtins.property
    def name(self) -> builtins.str:
        result = self._values.get("name")
        assert result is not None, "Required property 'name' is missing"
        return result

    @builtins.property
    def record(self) -> typing.List["PrivateDnsSrvRecordRecord"]:
        """record block."""
        result = self._values.get("record")
        assert result is not None, "Required property 'record' is missing"
        return result

    @builtins.property
    def resource_group_name(self) -> builtins.str:
        result = self._values.get("resource_group_name")
        assert result is not None, "Required property 'resource_group_name' is missing"
        return result

    @builtins.property
    def ttl(self) -> jsii.Number:
        result = self._values.get("ttl")
        assert result is not None, "Required property 'ttl' is missing"
        return result

    @builtins.property
    def zone_name(self) -> builtins.str:
        result = self._values.get("zone_name")
        assert result is not None, "Required property 'zone_name' is missing"
        return result

    @builtins.property
    def tags(self) -> typing.Optional[typing.Mapping[builtins.str, builtins.str]]:
        result = self._values.get("tags")
        return result

    @builtins.property
    def timeouts(self) -> typing.Optional["PrivateDnsSrvRecordTimeouts"]:
        """timeouts block."""
        result = self._values.get("timeouts")
        return result

    def __eq__(self, rhs: typing.Any) -> builtins.bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs: typing.Any) -> builtins.bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return "PrivateDnsSrvRecordConfig(%s)" % ", ".join(
            k + "=" + repr(v) for k, v in self._values.items()
        )


@jsii.data_type(
    jsii_type="@cdktf/provider-azurerm.PrivateDnsSrvRecordRecord",
    jsii_struct_bases=[],
    name_mapping={
        "port": "port",
        "priority": "priority",
        "target": "target",
        "weight": "weight",
    },
)
class PrivateDnsSrvRecordRecord:
    def __init__(
        self,
        *,
        port: jsii.Number,
        priority: jsii.Number,
        target: builtins.str,
        weight: jsii.Number,
    ) -> None:
        """
        :param port: 
        :param priority: 
        :param target: 
        :param weight: 
        """
        self._values: typing.Dict[str, typing.Any] = {
            "port": port,
            "priority": priority,
            "target": target,
            "weight": weight,
        }

    @builtins.property
    def port(self) -> jsii.Number:
        result = self._values.get("port")
        assert result is not None, "Required property 'port' is missing"
        return result

    @builtins.property
    def priority(self) -> jsii.Number:
        result = self._values.get("priority")
        assert result is not None, "Required property 'priority' is missing"
        return result

    @builtins.property
    def target(self) -> builtins.str:
        result = self._values.get("target")
        assert result is not None, "Required property 'target' is missing"
        return result

    @builtins.property
    def weight(self) -> jsii.Number:
        result = self._values.get("weight")
        assert result is not None, "Required property 'weight' is missing"
        return result

    def __eq__(self, rhs: typing.Any) -> builtins.bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs: typing.Any) -> builtins.bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return "PrivateDnsSrvRecordRecord(%s)" % ", ".join(
            k + "=" + repr(v) for k, v in self._values.items()
        )


@jsii.data_type(
    jsii_type="@cdktf/provider-azurerm.PrivateDnsSrvRecordTimeouts",
    jsii_struct_bases=[],
    name_mapping={
        "create": "create",
        "delete": "delete",
        "read": "read",
        "update": "update",
    },
)
class PrivateDnsSrvRecordTimeouts:
    def __init__(
        self,
        *,
        create: typing.Optional[builtins.str] = None,
        delete: typing.Optional[builtins.str] = None,
        read: typing.Optional[builtins.str] = None,
        update: typing.Optional[builtins.str] = None,
    ) -> None:
        """
        :param create: 
        :param delete: 
        :param read: 
        :param update: 
        """
        self._values: typing.Dict[str, typing.Any] = {}
        if create is not None:
            self._values["create"] = create
        if delete is not None:
            self._values["delete"] = delete
        if read is not None:
            self._values["read"] = read
        if update is not None:
            self._values["update"] = update

    @builtins.property
    def create(self) -> typing.Optional[builtins.str]:
        result = self._values.get("create")
        return result

    @builtins.property
    def delete(self) -> typing.Optional[builtins.str]:
        result = self._values.get("delete")
        return result

    @builtins.property
    def read(self) -> typing.Optional[builtins.str]:
        result = self._values.get("read")
        return result

    @builtins.property
    def update(self) -> typing.Optional[builtins.str]:
        result = self._values.get("update")
        return result

    def __eq__(self, rhs: typing.Any) -> builtins.bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs: typing.Any) -> builtins.bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return "PrivateDnsSrvRecordTimeouts(%s)" % ", ".join(
            k + "=" + repr(v) for k, v in self._values.items()
        )


class PrivateDnsZone(
    cdktf.TerraformResource,
    metaclass=jsii.JSIIMeta,
    jsii_type="@cdktf/provider-azurerm.PrivateDnsZone",
):
    def __init__(
        self,
        scope: constructs.Construct,
        id: builtins.str,
        *,
        name: builtins.str,
        resource_group_name: builtins.str,
        tags: typing.Optional[typing.Mapping[builtins.str, builtins.str]] = None,
        timeouts: typing.Optional["PrivateDnsZoneTimeouts"] = None,
        count: typing.Optional[jsii.Number] = None,
        depends_on: typing.Optional[typing.List[cdktf.TerraformResource]] = None,
        lifecycle: typing.Optional[cdktf.TerraformResourceLifecycle] = None,
        provider: typing.Optional[cdktf.TerraformProvider] = None,
    ) -> None:
        """
        :param scope: -
        :param id: -
        :param name: 
        :param resource_group_name: 
        :param tags: 
        :param timeouts: timeouts block.
        :param count: 
        :param depends_on: 
        :param lifecycle: 
        :param provider: 
        """
        config = PrivateDnsZoneConfig(
            name=name,
            resource_group_name=resource_group_name,
            tags=tags,
            timeouts=timeouts,
            count=count,
            depends_on=depends_on,
            lifecycle=lifecycle,
            provider=provider,
        )

        jsii.create(PrivateDnsZone, self, [scope, id, config])

    @jsii.member(jsii_name="synthesizeAttributes")
    def _synthesize_attributes(self) -> typing.Mapping[builtins.str, typing.Any]:
        return jsii.invoke(self, "synthesizeAttributes", [])

    @builtins.property # type: ignore
    @jsii.member(jsii_name="maxNumberOfRecordSets")
    def max_number_of_record_sets(self) -> jsii.Number:
        return jsii.get(self, "maxNumberOfRecordSets")

    @builtins.property # type: ignore
    @jsii.member(jsii_name="maxNumberOfVirtualNetworkLinks")
    def max_number_of_virtual_network_links(self) -> jsii.Number:
        return jsii.get(self, "maxNumberOfVirtualNetworkLinks")

    @builtins.property # type: ignore
    @jsii.member(jsii_name="maxNumberOfVirtualNetworkLinksWithRegistration")
    def max_number_of_virtual_network_links_with_registration(self) -> jsii.Number:
        return jsii.get(self, "maxNumberOfVirtualNetworkLinksWithRegistration")

    @builtins.property # type: ignore
    @jsii.member(jsii_name="numberOfRecordSets")
    def number_of_record_sets(self) -> jsii.Number:
        return jsii.get(self, "numberOfRecordSets")

    @builtins.property # type: ignore
    @jsii.member(jsii_name="name")
    def name(self) -> builtins.str:
        return jsii.get(self, "name")

    @name.setter # type: ignore
    def name(self, value: builtins.str) -> None:
        jsii.set(self, "name", value)

    @builtins.property # type: ignore
    @jsii.member(jsii_name="resourceGroupName")
    def resource_group_name(self) -> builtins.str:
        return jsii.get(self, "resourceGroupName")

    @resource_group_name.setter # type: ignore
    def resource_group_name(self, value: builtins.str) -> None:
        jsii.set(self, "resourceGroupName", value)

    @builtins.property # type: ignore
    @jsii.member(jsii_name="id")
    def id(self) -> typing.Optional[builtins.str]:
        return jsii.get(self, "id")

    @id.setter # type: ignore
    def id(self, value: typing.Optional[builtins.str]) -> None:
        jsii.set(self, "id", value)

    @builtins.property # type: ignore
    @jsii.member(jsii_name="tags")
    def tags(self) -> typing.Optional[typing.Mapping[builtins.str, builtins.str]]:
        return jsii.get(self, "tags")

    @tags.setter # type: ignore
    def tags(
        self,
        value: typing.Optional[typing.Mapping[builtins.str, builtins.str]],
    ) -> None:
        jsii.set(self, "tags", value)

    @builtins.property # type: ignore
    @jsii.member(jsii_name="timeouts")
    def timeouts(self) -> typing.Optional["PrivateDnsZoneTimeouts"]:
        return jsii.get(self, "timeouts")

    @timeouts.setter # type: ignore
    def timeouts(self, value: typing.Optional["PrivateDnsZoneTimeouts"]) -> None:
        jsii.set(self, "timeouts", value)


@jsii.data_type(
    jsii_type="@cdktf/provider-azurerm.PrivateDnsZoneConfig",
    jsii_struct_bases=[cdktf.TerraformMetaArguments],
    name_mapping={
        "count": "count",
        "depends_on": "dependsOn",
        "lifecycle": "lifecycle",
        "provider": "provider",
        "name": "name",
        "resource_group_name": "resourceGroupName",
        "tags": "tags",
        "timeouts": "timeouts",
    },
)
class PrivateDnsZoneConfig(cdktf.TerraformMetaArguments):
    def __init__(
        self,
        *,
        count: typing.Optional[jsii.Number] = None,
        depends_on: typing.Optional[typing.List[cdktf.TerraformResource]] = None,
        lifecycle: typing.Optional[cdktf.TerraformResourceLifecycle] = None,
        provider: typing.Optional[cdktf.TerraformProvider] = None,
        name: builtins.str,
        resource_group_name: builtins.str,
        tags: typing.Optional[typing.Mapping[builtins.str, builtins.str]] = None,
        timeouts: typing.Optional["PrivateDnsZoneTimeouts"] = None,
    ) -> None:
        """
        :param count: 
        :param depends_on: 
        :param lifecycle: 
        :param provider: 
        :param name: 
        :param resource_group_name: 
        :param tags: 
        :param timeouts: timeouts block.
        """
        if isinstance(lifecycle, dict):
            lifecycle = cdktf.TerraformResourceLifecycle(**lifecycle)
        if isinstance(timeouts, dict):
            timeouts = PrivateDnsZoneTimeouts(**timeouts)
        self._values: typing.Dict[str, typing.Any] = {
            "name": name,
            "resource_group_name": resource_group_name,
        }
        if count is not None:
            self._values["count"] = count
        if depends_on is not None:
            self._values["depends_on"] = depends_on
        if lifecycle is not None:
            self._values["lifecycle"] = lifecycle
        if provider is not None:
            self._values["provider"] = provider
        if tags is not None:
            self._values["tags"] = tags
        if timeouts is not None:
            self._values["timeouts"] = timeouts

    @builtins.property
    def count(self) -> typing.Optional[jsii.Number]:
        """
        :stability: experimental
        """
        result = self._values.get("count")
        return result

    @builtins.property
    def depends_on(self) -> typing.Optional[typing.List[cdktf.TerraformResource]]:
        """
        :stability: experimental
        """
        result = self._values.get("depends_on")
        return result

    @builtins.property
    def lifecycle(self) -> typing.Optional[cdktf.TerraformResourceLifecycle]:
        """
        :stability: experimental
        """
        result = self._values.get("lifecycle")
        return result

    @builtins.property
    def provider(self) -> typing.Optional[cdktf.TerraformProvider]:
        """
        :stability: experimental
        """
        result = self._values.get("provider")
        return result

    @builtins.property
    def name(self) -> builtins.str:
        result = self._values.get("name")
        assert result is not None, "Required property 'name' is missing"
        return result

    @builtins.property
    def resource_group_name(self) -> builtins.str:
        result = self._values.get("resource_group_name")
        assert result is not None, "Required property 'resource_group_name' is missing"
        return result

    @builtins.property
    def tags(self) -> typing.Optional[typing.Mapping[builtins.str, builtins.str]]:
        result = self._values.get("tags")
        return result

    @builtins.property
    def timeouts(self) -> typing.Optional["PrivateDnsZoneTimeouts"]:
        """timeouts block."""
        result = self._values.get("timeouts")
        return result

    def __eq__(self, rhs: typing.Any) -> builtins.bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs: typing.Any) -> builtins.bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return "PrivateDnsZoneConfig(%s)" % ", ".join(
            k + "=" + repr(v) for k, v in self._values.items()
        )


@jsii.data_type(
    jsii_type="@cdktf/provider-azurerm.PrivateDnsZoneTimeouts",
    jsii_struct_bases=[],
    name_mapping={
        "create": "create",
        "delete": "delete",
        "read": "read",
        "update": "update",
    },
)
class PrivateDnsZoneTimeouts:
    def __init__(
        self,
        *,
        create: typing.Optional[builtins.str] = None,
        delete: typing.Optional[builtins.str] = None,
        read: typing.Optional[builtins.str] = None,
        update: typing.Optional[builtins.str] = None,
    ) -> None:
        """
        :param create: 
        :param delete: 
        :param read: 
        :param update: 
        """
        self._values: typing.Dict[str, typing.Any] = {}
        if create is not None:
            self._values["create"] = create
        if delete is not None:
            self._values["delete"] = delete
        if read is not None:
            self._values["read"] = read
        if update is not None:
            self._values["update"] = update

    @builtins.property
    def create(self) -> typing.Optional[builtins.str]:
        result = self._values.get("create")
        return result

    @builtins.property
    def delete(self) -> typing.Optional[builtins.str]:
        result = self._values.get("delete")
        return result

    @builtins.property
    def read(self) -> typing.Optional[builtins.str]:
        result = self._values.get("read")
        return result

    @builtins.property
    def update(self) -> typing.Optional[builtins.str]:
        result = self._values.get("update")
        return result

    def __eq__(self, rhs: typing.Any) -> builtins.bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs: typing.Any) -> builtins.bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return "PrivateDnsZoneTimeouts(%s)" % ", ".join(
            k + "=" + repr(v) for k, v in self._values.items()
        )


class PrivateDnsZoneVirtualNetworkLink(
    cdktf.TerraformResource,
    metaclass=jsii.JSIIMeta,
    jsii_type="@cdktf/provider-azurerm.PrivateDnsZoneVirtualNetworkLink",
):
    def __init__(
        self,
        scope: constructs.Construct,
        id: builtins.str,
        *,
        name: builtins.str,
        private_dns_zone_name: builtins.str,
        resource_group_name: builtins.str,
        virtual_network_id: builtins.str,
        registration_enabled: typing.Optional[builtins.bool] = None,
        tags: typing.Optional[typing.Mapping[builtins.str, builtins.str]] = None,
        timeouts: typing.Optional["PrivateDnsZoneVirtualNetworkLinkTimeouts"] = None,
        count: typing.Optional[jsii.Number] = None,
        depends_on: typing.Optional[typing.List[cdktf.TerraformResource]] = None,
        lifecycle: typing.Optional[cdktf.TerraformResourceLifecycle] = None,
        provider: typing.Optional[cdktf.TerraformProvider] = None,
    ) -> None:
        """
        :param scope: -
        :param id: -
        :param name: 
        :param private_dns_zone_name: 
        :param resource_group_name: 
        :param virtual_network_id: 
        :param registration_enabled: 
        :param tags: 
        :param timeouts: timeouts block.
        :param count: 
        :param depends_on: 
        :param lifecycle: 
        :param provider: 
        """
        config = PrivateDnsZoneVirtualNetworkLinkConfig(
            name=name,
            private_dns_zone_name=private_dns_zone_name,
            resource_group_name=resource_group_name,
            virtual_network_id=virtual_network_id,
            registration_enabled=registration_enabled,
            tags=tags,
            timeouts=timeouts,
            count=count,
            depends_on=depends_on,
            lifecycle=lifecycle,
            provider=provider,
        )

        jsii.create(PrivateDnsZoneVirtualNetworkLink, self, [scope, id, config])

    @jsii.member(jsii_name="synthesizeAttributes")
    def _synthesize_attributes(self) -> typing.Mapping[builtins.str, typing.Any]:
        return jsii.invoke(self, "synthesizeAttributes", [])

    @builtins.property # type: ignore
    @jsii.member(jsii_name="name")
    def name(self) -> builtins.str:
        return jsii.get(self, "name")

    @name.setter # type: ignore
    def name(self, value: builtins.str) -> None:
        jsii.set(self, "name", value)

    @builtins.property # type: ignore
    @jsii.member(jsii_name="privateDnsZoneName")
    def private_dns_zone_name(self) -> builtins.str:
        return jsii.get(self, "privateDnsZoneName")

    @private_dns_zone_name.setter # type: ignore
    def private_dns_zone_name(self, value: builtins.str) -> None:
        jsii.set(self, "privateDnsZoneName", value)

    @builtins.property # type: ignore
    @jsii.member(jsii_name="resourceGroupName")
    def resource_group_name(self) -> builtins.str:
        return jsii.get(self, "resourceGroupName")

    @resource_group_name.setter # type: ignore
    def resource_group_name(self, value: builtins.str) -> None:
        jsii.set(self, "resourceGroupName", value)

    @builtins.property # type: ignore
    @jsii.member(jsii_name="virtualNetworkId")
    def virtual_network_id(self) -> builtins.str:
        return jsii.get(self, "virtualNetworkId")

    @virtual_network_id.setter # type: ignore
    def virtual_network_id(self, value: builtins.str) -> None:
        jsii.set(self, "virtualNetworkId", value)

    @builtins.property # type: ignore
    @jsii.member(jsii_name="id")
    def id(self) -> typing.Optional[builtins.str]:
        return jsii.get(self, "id")

    @id.setter # type: ignore
    def id(self, value: typing.Optional[builtins.str]) -> None:
        jsii.set(self, "id", value)

    @builtins.property # type: ignore
    @jsii.member(jsii_name="registrationEnabled")
    def registration_enabled(self) -> typing.Optional[builtins.bool]:
        return jsii.get(self, "registrationEnabled")

    @registration_enabled.setter # type: ignore
    def registration_enabled(self, value: typing.Optional[builtins.bool]) -> None:
        jsii.set(self, "registrationEnabled", value)

    @builtins.property # type: ignore
    @jsii.member(jsii_name="tags")
    def tags(self) -> typing.Optional[typing.Mapping[builtins.str, builtins.str]]:
        return jsii.get(self, "tags")

    @tags.setter # type: ignore
    def tags(
        self,
        value: typing.Optional[typing.Mapping[builtins.str, builtins.str]],
    ) -> None:
        jsii.set(self, "tags", value)

    @builtins.property # type: ignore
    @jsii.member(jsii_name="timeouts")
    def timeouts(self) -> typing.Optional["PrivateDnsZoneVirtualNetworkLinkTimeouts"]:
        return jsii.get(self, "timeouts")

    @timeouts.setter # type: ignore
    def timeouts(
        self,
        value: typing.Optional["PrivateDnsZoneVirtualNetworkLinkTimeouts"],
    ) -> None:
        jsii.set(self, "timeouts", value)


@jsii.data_type(
    jsii_type="@cdktf/provider-azurerm.PrivateDnsZoneVirtualNetworkLinkConfig",
    jsii_struct_bases=[cdktf.TerraformMetaArguments],
    name_mapping={
        "count": "count",
        "depends_on": "dependsOn",
        "lifecycle": "lifecycle",
        "provider": "provider",
        "name": "name",
        "private_dns_zone_name": "privateDnsZoneName",
        "resource_group_name": "resourceGroupName",
        "virtual_network_id": "virtualNetworkId",
        "registration_enabled": "registrationEnabled",
        "tags": "tags",
        "timeouts": "timeouts",
    },
)
class PrivateDnsZoneVirtualNetworkLinkConfig(cdktf.TerraformMetaArguments):
    def __init__(
        self,
        *,
        count: typing.Optional[jsii.Number] = None,
        depends_on: typing.Optional[typing.List[cdktf.TerraformResource]] = None,
        lifecycle: typing.Optional[cdktf.TerraformResourceLifecycle] = None,
        provider: typing.Optional[cdktf.TerraformProvider] = None,
        name: builtins.str,
        private_dns_zone_name: builtins.str,
        resource_group_name: builtins.str,
        virtual_network_id: builtins.str,
        registration_enabled: typing.Optional[builtins.bool] = None,
        tags: typing.Optional[typing.Mapping[builtins.str, builtins.str]] = None,
        timeouts: typing.Optional["PrivateDnsZoneVirtualNetworkLinkTimeouts"] = None,
    ) -> None:
        """
        :param count: 
        :param depends_on: 
        :param lifecycle: 
        :param provider: 
        :param name: 
        :param private_dns_zone_name: 
        :param resource_group_name: 
        :param virtual_network_id: 
        :param registration_enabled: 
        :param tags: 
        :param timeouts: timeouts block.
        """
        if isinstance(lifecycle, dict):
            lifecycle = cdktf.TerraformResourceLifecycle(**lifecycle)
        if isinstance(timeouts, dict):
            timeouts = PrivateDnsZoneVirtualNetworkLinkTimeouts(**timeouts)
        self._values: typing.Dict[str, typing.Any] = {
            "name": name,
            "private_dns_zone_name": private_dns_zone_name,
            "resource_group_name": resource_group_name,
            "virtual_network_id": virtual_network_id,
        }
        if count is not None:
            self._values["count"] = count
        if depends_on is not None:
            self._values["depends_on"] = depends_on
        if lifecycle is not None:
            self._values["lifecycle"] = lifecycle
        if provider is not None:
            self._values["provider"] = provider
        if registration_enabled is not None:
            self._values["registration_enabled"] = registration_enabled
        if tags is not None:
            self._values["tags"] = tags
        if timeouts is not None:
            self._values["timeouts"] = timeouts

    @builtins.property
    def count(self) -> typing.Optional[jsii.Number]:
        """
        :stability: experimental
        """
        result = self._values.get("count")
        return result

    @builtins.property
    def depends_on(self) -> typing.Optional[typing.List[cdktf.TerraformResource]]:
        """
        :stability: experimental
        """
        result = self._values.get("depends_on")
        return result

    @builtins.property
    def lifecycle(self) -> typing.Optional[cdktf.TerraformResourceLifecycle]:
        """
        :stability: experimental
        """
        result = self._values.get("lifecycle")
        return result

    @builtins.property
    def provider(self) -> typing.Optional[cdktf.TerraformProvider]:
        """
        :stability: experimental
        """
        result = self._values.get("provider")
        return result

    @builtins.property
    def name(self) -> builtins.str:
        result = self._values.get("name")
        assert result is not None, "Required property 'name' is missing"
        return result

    @builtins.property
    def private_dns_zone_name(self) -> builtins.str:
        result = self._values.get("private_dns_zone_name")
        assert result is not None, "Required property 'private_dns_zone_name' is missing"
        return result

    @builtins.property
    def resource_group_name(self) -> builtins.str:
        result = self._values.get("resource_group_name")
        assert result is not None, "Required property 'resource_group_name' is missing"
        return result

    @builtins.property
    def virtual_network_id(self) -> builtins.str:
        result = self._values.get("virtual_network_id")
        assert result is not None, "Required property 'virtual_network_id' is missing"
        return result

    @builtins.property
    def registration_enabled(self) -> typing.Optional[builtins.bool]:
        result = self._values.get("registration_enabled")
        return result

    @builtins.property
    def tags(self) -> typing.Optional[typing.Mapping[builtins.str, builtins.str]]:
        result = self._values.get("tags")
        return result

    @builtins.property
    def timeouts(self) -> typing.Optional["PrivateDnsZoneVirtualNetworkLinkTimeouts"]:
        """timeouts block."""
        result = self._values.get("timeouts")
        return result

    def __eq__(self, rhs: typing.Any) -> builtins.bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs: typing.Any) -> builtins.bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return "PrivateDnsZoneVirtualNetworkLinkConfig(%s)" % ", ".join(
            k + "=" + repr(v) for k, v in self._values.items()
        )


@jsii.data_type(
    jsii_type="@cdktf/provider-azurerm.PrivateDnsZoneVirtualNetworkLinkTimeouts",
    jsii_struct_bases=[],
    name_mapping={
        "create": "create",
        "delete": "delete",
        "read": "read",
        "update": "update",
    },
)
class PrivateDnsZoneVirtualNetworkLinkTimeouts:
    def __init__(
        self,
        *,
        create: typing.Optional[builtins.str] = None,
        delete: typing.Optional[builtins.str] = None,
        read: typing.Optional[builtins.str] = None,
        update: typing.Optional[builtins.str] = None,
    ) -> None:
        """
        :param create: 
        :param delete: 
        :param read: 
        :param update: 
        """
        self._values: typing.Dict[str, typing.Any] = {}
        if create is not None:
            self._values["create"] = create
        if delete is not None:
            self._values["delete"] = delete
        if read is not None:
            self._values["read"] = read
        if update is not None:
            self._values["update"] = update

    @builtins.property
    def create(self) -> typing.Optional[builtins.str]:
        result = self._values.get("create")
        return result

    @builtins.property
    def delete(self) -> typing.Optional[builtins.str]:
        result = self._values.get("delete")
        return result

    @builtins.property
    def read(self) -> typing.Optional[builtins.str]:
        result = self._values.get("read")
        return result

    @builtins.property
    def update(self) -> typing.Optional[builtins.str]:
        result = self._values.get("update")
        return result

    def __eq__(self, rhs: typing.Any) -> builtins.bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs: typing.Any) -> builtins.bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return "PrivateDnsZoneVirtualNetworkLinkTimeouts(%s)" % ", ".join(
            k + "=" + repr(v) for k, v in self._values.items()
        )


class PrivateEndpoint(
    cdktf.TerraformResource,
    metaclass=jsii.JSIIMeta,
    jsii_type="@cdktf/provider-azurerm.PrivateEndpoint",
):
    def __init__(
        self,
        scope: constructs.Construct,
        id: builtins.str,
        *,
        location: builtins.str,
        name: builtins.str,
        private_service_connection: typing.List["PrivateEndpointPrivateServiceConnection"],
        resource_group_name: builtins.str,
        subnet_id: builtins.str,
        timeouts: typing.Optional["PrivateEndpointTimeouts"] = None,
        count: typing.Optional[jsii.Number] = None,
        depends_on: typing.Optional[typing.List[cdktf.TerraformResource]] = None,
        lifecycle: typing.Optional[cdktf.TerraformResourceLifecycle] = None,
        provider: typing.Optional[cdktf.TerraformProvider] = None,
    ) -> None:
        """
        :param scope: -
        :param id: -
        :param location: 
        :param name: 
        :param private_service_connection: private_service_connection block.
        :param resource_group_name: 
        :param subnet_id: 
        :param timeouts: timeouts block.
        :param count: 
        :param depends_on: 
        :param lifecycle: 
        :param provider: 
        """
        config = PrivateEndpointConfig(
            location=location,
            name=name,
            private_service_connection=private_service_connection,
            resource_group_name=resource_group_name,
            subnet_id=subnet_id,
            timeouts=timeouts,
            count=count,
            depends_on=depends_on,
            lifecycle=lifecycle,
            provider=provider,
        )

        jsii.create(PrivateEndpoint, self, [scope, id, config])

    @jsii.member(jsii_name="synthesizeAttributes")
    def _synthesize_attributes(self) -> typing.Mapping[builtins.str, typing.Any]:
        return jsii.invoke(self, "synthesizeAttributes", [])

    @builtins.property # type: ignore
    @jsii.member(jsii_name="location")
    def location(self) -> builtins.str:
        return jsii.get(self, "location")

    @location.setter # type: ignore
    def location(self, value: builtins.str) -> None:
        jsii.set(self, "location", value)

    @builtins.property # type: ignore
    @jsii.member(jsii_name="name")
    def name(self) -> builtins.str:
        return jsii.get(self, "name")

    @name.setter # type: ignore
    def name(self, value: builtins.str) -> None:
        jsii.set(self, "name", value)

    @builtins.property # type: ignore
    @jsii.member(jsii_name="privateServiceConnection")
    def private_service_connection(
        self,
    ) -> typing.List["PrivateEndpointPrivateServiceConnection"]:
        return jsii.get(self, "privateServiceConnection")

    @private_service_connection.setter # type: ignore
    def private_service_connection(
        self,
        value: typing.List["PrivateEndpointPrivateServiceConnection"],
    ) -> None:
        jsii.set(self, "privateServiceConnection", value)

    @builtins.property # type: ignore
    @jsii.member(jsii_name="resourceGroupName")
    def resource_group_name(self) -> builtins.str:
        return jsii.get(self, "resourceGroupName")

    @resource_group_name.setter # type: ignore
    def resource_group_name(self, value: builtins.str) -> None:
        jsii.set(self, "resourceGroupName", value)

    @builtins.property # type: ignore
    @jsii.member(jsii_name="subnetId")
    def subnet_id(self) -> builtins.str:
        return jsii.get(self, "subnetId")

    @subnet_id.setter # type: ignore
    def subnet_id(self, value: builtins.str) -> None:
        jsii.set(self, "subnetId", value)

    @builtins.property # type: ignore
    @jsii.member(jsii_name="id")
    def id(self) -> typing.Optional[builtins.str]:
        return jsii.get(self, "id")

    @id.setter # type: ignore
    def id(self, value: typing.Optional[builtins.str]) -> None:
        jsii.set(self, "id", value)

    @builtins.property # type: ignore
    @jsii.member(jsii_name="timeouts")
    def timeouts(self) -> typing.Optional["PrivateEndpointTimeouts"]:
        return jsii.get(self, "timeouts")

    @timeouts.setter # type: ignore
    def timeouts(self, value: typing.Optional["PrivateEndpointTimeouts"]) -> None:
        jsii.set(self, "timeouts", value)


@jsii.data_type(
    jsii_type="@cdktf/provider-azurerm.PrivateEndpointConfig",
    jsii_struct_bases=[cdktf.TerraformMetaArguments],
    name_mapping={
        "count": "count",
        "depends_on": "dependsOn",
        "lifecycle": "lifecycle",
        "provider": "provider",
        "location": "location",
        "name": "name",
        "private_service_connection": "privateServiceConnection",
        "resource_group_name": "resourceGroupName",
        "subnet_id": "subnetId",
        "timeouts": "timeouts",
    },
)
class PrivateEndpointConfig(cdktf.TerraformMetaArguments):
    def __init__(
        self,
        *,
        count: typing.Optional[jsii.Number] = None,
        depends_on: typing.Optional[typing.List[cdktf.TerraformResource]] = None,
        lifecycle: typing.Optional[cdktf.TerraformResourceLifecycle] = None,
        provider: typing.Optional[cdktf.TerraformProvider] = None,
        location: builtins.str,
        name: builtins.str,
        private_service_connection: typing.List["PrivateEndpointPrivateServiceConnection"],
        resource_group_name: builtins.str,
        subnet_id: builtins.str,
        timeouts: typing.Optional["PrivateEndpointTimeouts"] = None,
    ) -> None:
        """
        :param count: 
        :param depends_on: 
        :param lifecycle: 
        :param provider: 
        :param location: 
        :param name: 
        :param private_service_connection: private_service_connection block.
        :param resource_group_name: 
        :param subnet_id: 
        :param timeouts: timeouts block.
        """
        if isinstance(lifecycle, dict):
            lifecycle = cdktf.TerraformResourceLifecycle(**lifecycle)
        if isinstance(timeouts, dict):
            timeouts = PrivateEndpointTimeouts(**timeouts)
        self._values: typing.Dict[str, typing.Any] = {
            "location": location,
            "name": name,
            "private_service_connection": private_service_connection,
            "resource_group_name": resource_group_name,
            "subnet_id": subnet_id,
        }
        if count is not None:
            self._values["count"] = count
        if depends_on is not None:
            self._values["depends_on"] = depends_on
        if lifecycle is not None:
            self._values["lifecycle"] = lifecycle
        if provider is not None:
            self._values["provider"] = provider
        if timeouts is not None:
            self._values["timeouts"] = timeouts

    @builtins.property
    def count(self) -> typing.Optional[jsii.Number]:
        """
        :stability: experimental
        """
        result = self._values.get("count")
        return result

    @builtins.property
    def depends_on(self) -> typing.Optional[typing.List[cdktf.TerraformResource]]:
        """
        :stability: experimental
        """
        result = self._values.get("depends_on")
        return result

    @builtins.property
    def lifecycle(self) -> typing.Optional[cdktf.TerraformResourceLifecycle]:
        """
        :stability: experimental
        """
        result = self._values.get("lifecycle")
        return result

    @builtins.property
    def provider(self) -> typing.Optional[cdktf.TerraformProvider]:
        """
        :stability: experimental
        """
        result = self._values.get("provider")
        return result

    @builtins.property
    def location(self) -> builtins.str:
        result = self._values.get("location")
        assert result is not None, "Required property 'location' is missing"
        return result

    @builtins.property
    def name(self) -> builtins.str:
        result = self._values.get("name")
        assert result is not None, "Required property 'name' is missing"
        return result

    @builtins.property
    def private_service_connection(
        self,
    ) -> typing.List["PrivateEndpointPrivateServiceConnection"]:
        """private_service_connection block."""
        result = self._values.get("private_service_connection")
        assert result is not None, "Required property 'private_service_connection' is missing"
        return result

    @builtins.property
    def resource_group_name(self) -> builtins.str:
        result = self._values.get("resource_group_name")
        assert result is not None, "Required property 'resource_group_name' is missing"
        return result

    @builtins.property
    def subnet_id(self) -> builtins.str:
        result = self._values.get("subnet_id")
        assert result is not None, "Required property 'subnet_id' is missing"
        return result

    @builtins.property
    def timeouts(self) -> typing.Optional["PrivateEndpointTimeouts"]:
        """timeouts block."""
        result = self._values.get("timeouts")
        return result

    def __eq__(self, rhs: typing.Any) -> builtins.bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs: typing.Any) -> builtins.bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return "PrivateEndpointConfig(%s)" % ", ".join(
            k + "=" + repr(v) for k, v in self._values.items()
        )


@jsii.data_type(
    jsii_type="@cdktf/provider-azurerm.PrivateEndpointPrivateServiceConnection",
    jsii_struct_bases=[],
    name_mapping={
        "is_manual_connection": "isManualConnection",
        "name": "name",
        "private_connection_resource_id": "privateConnectionResourceId",
        "request_message": "requestMessage",
        "subresource_names": "subresourceNames",
    },
)
class PrivateEndpointPrivateServiceConnection:
    def __init__(
        self,
        *,
        is_manual_connection: builtins.bool,
        name: builtins.str,
        private_connection_resource_id: builtins.str,
        request_message: typing.Optional[builtins.str] = None,
        subresource_names: typing.Optional[typing.List[builtins.str]] = None,
    ) -> None:
        """
        :param is_manual_connection: 
        :param name: 
        :param private_connection_resource_id: 
        :param request_message: 
        :param subresource_names: 
        """
        self._values: typing.Dict[str, typing.Any] = {
            "is_manual_connection": is_manual_connection,
            "name": name,
            "private_connection_resource_id": private_connection_resource_id,
        }
        if request_message is not None:
            self._values["request_message"] = request_message
        if subresource_names is not None:
            self._values["subresource_names"] = subresource_names

    @builtins.property
    def is_manual_connection(self) -> builtins.bool:
        result = self._values.get("is_manual_connection")
        assert result is not None, "Required property 'is_manual_connection' is missing"
        return result

    @builtins.property
    def name(self) -> builtins.str:
        result = self._values.get("name")
        assert result is not None, "Required property 'name' is missing"
        return result

    @builtins.property
    def private_connection_resource_id(self) -> builtins.str:
        result = self._values.get("private_connection_resource_id")
        assert result is not None, "Required property 'private_connection_resource_id' is missing"
        return result

    @builtins.property
    def request_message(self) -> typing.Optional[builtins.str]:
        result = self._values.get("request_message")
        return result

    @builtins.property
    def subresource_names(self) -> typing.Optional[typing.List[builtins.str]]:
        result = self._values.get("subresource_names")
        return result

    def __eq__(self, rhs: typing.Any) -> builtins.bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs: typing.Any) -> builtins.bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return "PrivateEndpointPrivateServiceConnection(%s)" % ", ".join(
            k + "=" + repr(v) for k, v in self._values.items()
        )


@jsii.data_type(
    jsii_type="@cdktf/provider-azurerm.PrivateEndpointTimeouts",
    jsii_struct_bases=[],
    name_mapping={
        "create": "create",
        "delete": "delete",
        "read": "read",
        "update": "update",
    },
)
class PrivateEndpointTimeouts:
    def __init__(
        self,
        *,
        create: typing.Optional[builtins.str] = None,
        delete: typing.Optional[builtins.str] = None,
        read: typing.Optional[builtins.str] = None,
        update: typing.Optional[builtins.str] = None,
    ) -> None:
        """
        :param create: 
        :param delete: 
        :param read: 
        :param update: 
        """
        self._values: typing.Dict[str, typing.Any] = {}
        if create is not None:
            self._values["create"] = create
        if delete is not None:
            self._values["delete"] = delete
        if read is not None:
            self._values["read"] = read
        if update is not None:
            self._values["update"] = update

    @builtins.property
    def create(self) -> typing.Optional[builtins.str]:
        result = self._values.get("create")
        return result

    @builtins.property
    def delete(self) -> typing.Optional[builtins.str]:
        result = self._values.get("delete")
        return result

    @builtins.property
    def read(self) -> typing.Optional[builtins.str]:
        result = self._values.get("read")
        return result

    @builtins.property
    def update(self) -> typing.Optional[builtins.str]:
        result = self._values.get("update")
        return result

    def __eq__(self, rhs: typing.Any) -> builtins.bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs: typing.Any) -> builtins.bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return "PrivateEndpointTimeouts(%s)" % ", ".join(
            k + "=" + repr(v) for k, v in self._values.items()
        )


class PrivateLinkService(
    cdktf.TerraformResource,
    metaclass=jsii.JSIIMeta,
    jsii_type="@cdktf/provider-azurerm.PrivateLinkService",
):
    def __init__(
        self,
        scope: constructs.Construct,
        id: builtins.str,
        *,
        load_balancer_frontend_ip_configuration_ids: typing.List[builtins.str],
        location: builtins.str,
        name: builtins.str,
        nat_ip_configuration: typing.List["PrivateLinkServiceNatIpConfiguration"],
        resource_group_name: builtins.str,
        auto_approval_subscription_ids: typing.Optional[typing.List[builtins.str]] = None,
        enable_proxy_protocol: typing.Optional[builtins.bool] = None,
        tags: typing.Optional[typing.Mapping[builtins.str, builtins.str]] = None,
        timeouts: typing.Optional["PrivateLinkServiceTimeouts"] = None,
        visibility_subscription_ids: typing.Optional[typing.List[builtins.str]] = None,
        count: typing.Optional[jsii.Number] = None,
        depends_on: typing.Optional[typing.List[cdktf.TerraformResource]] = None,
        lifecycle: typing.Optional[cdktf.TerraformResourceLifecycle] = None,
        provider: typing.Optional[cdktf.TerraformProvider] = None,
    ) -> None:
        """
        :param scope: -
        :param id: -
        :param load_balancer_frontend_ip_configuration_ids: 
        :param location: 
        :param name: 
        :param nat_ip_configuration: nat_ip_configuration block.
        :param resource_group_name: 
        :param auto_approval_subscription_ids: 
        :param enable_proxy_protocol: 
        :param tags: 
        :param timeouts: timeouts block.
        :param visibility_subscription_ids: 
        :param count: 
        :param depends_on: 
        :param lifecycle: 
        :param provider: 
        """
        config = PrivateLinkServiceConfig(
            load_balancer_frontend_ip_configuration_ids=load_balancer_frontend_ip_configuration_ids,
            location=location,
            name=name,
            nat_ip_configuration=nat_ip_configuration,
            resource_group_name=resource_group_name,
            auto_approval_subscription_ids=auto_approval_subscription_ids,
            enable_proxy_protocol=enable_proxy_protocol,
            tags=tags,
            timeouts=timeouts,
            visibility_subscription_ids=visibility_subscription_ids,
            count=count,
            depends_on=depends_on,
            lifecycle=lifecycle,
            provider=provider,
        )

        jsii.create(PrivateLinkService, self, [scope, id, config])

    @jsii.member(jsii_name="synthesizeAttributes")
    def _synthesize_attributes(self) -> typing.Mapping[builtins.str, typing.Any]:
        return jsii.invoke(self, "synthesizeAttributes", [])

    @builtins.property # type: ignore
    @jsii.member(jsii_name="alias")
    def alias(self) -> builtins.str:
        return jsii.get(self, "alias")

    @builtins.property # type: ignore
    @jsii.member(jsii_name="loadBalancerFrontendIpConfigurationIds")
    def load_balancer_frontend_ip_configuration_ids(self) -> typing.List[builtins.str]:
        return jsii.get(self, "loadBalancerFrontendIpConfigurationIds")

    @load_balancer_frontend_ip_configuration_ids.setter # type: ignore
    def load_balancer_frontend_ip_configuration_ids(
        self,
        value: typing.List[builtins.str],
    ) -> None:
        jsii.set(self, "loadBalancerFrontendIpConfigurationIds", value)

    @builtins.property # type: ignore
    @jsii.member(jsii_name="location")
    def location(self) -> builtins.str:
        return jsii.get(self, "location")

    @location.setter # type: ignore
    def location(self, value: builtins.str) -> None:
        jsii.set(self, "location", value)

    @builtins.property # type: ignore
    @jsii.member(jsii_name="name")
    def name(self) -> builtins.str:
        return jsii.get(self, "name")

    @name.setter # type: ignore
    def name(self, value: builtins.str) -> None:
        jsii.set(self, "name", value)

    @builtins.property # type: ignore
    @jsii.member(jsii_name="natIpConfiguration")
    def nat_ip_configuration(
        self,
    ) -> typing.List["PrivateLinkServiceNatIpConfiguration"]:
        return jsii.get(self, "natIpConfiguration")

    @nat_ip_configuration.setter # type: ignore
    def nat_ip_configuration(
        self,
        value: typing.List["PrivateLinkServiceNatIpConfiguration"],
    ) -> None:
        jsii.set(self, "natIpConfiguration", value)

    @builtins.property # type: ignore
    @jsii.member(jsii_name="resourceGroupName")
    def resource_group_name(self) -> builtins.str:
        return jsii.get(self, "resourceGroupName")

    @resource_group_name.setter # type: ignore
    def resource_group_name(self, value: builtins.str) -> None:
        jsii.set(self, "resourceGroupName", value)

    @builtins.property # type: ignore
    @jsii.member(jsii_name="autoApprovalSubscriptionIds")
    def auto_approval_subscription_ids(
        self,
    ) -> typing.Optional[typing.List[builtins.str]]:
        return jsii.get(self, "autoApprovalSubscriptionIds")

    @auto_approval_subscription_ids.setter # type: ignore
    def auto_approval_subscription_ids(
        self,
        value: typing.Optional[typing.List[builtins.str]],
    ) -> None:
        jsii.set(self, "autoApprovalSubscriptionIds", value)

    @builtins.property # type: ignore
    @jsii.member(jsii_name="enableProxyProtocol")
    def enable_proxy_protocol(self) -> typing.Optional[builtins.bool]:
        return jsii.get(self, "enableProxyProtocol")

    @enable_proxy_protocol.setter # type: ignore
    def enable_proxy_protocol(self, value: typing.Optional[builtins.bool]) -> None:
        jsii.set(self, "enableProxyProtocol", value)

    @builtins.property # type: ignore
    @jsii.member(jsii_name="id")
    def id(self) -> typing.Optional[builtins.str]:
        return jsii.get(self, "id")

    @id.setter # type: ignore
    def id(self, value: typing.Optional[builtins.str]) -> None:
        jsii.set(self, "id", value)

    @builtins.property # type: ignore
    @jsii.member(jsii_name="tags")
    def tags(self) -> typing.Optional[typing.Mapping[builtins.str, builtins.str]]:
        return jsii.get(self, "tags")

    @tags.setter # type: ignore
    def tags(
        self,
        value: typing.Optional[typing.Mapping[builtins.str, builtins.str]],
    ) -> None:
        jsii.set(self, "tags", value)

    @builtins.property # type: ignore
    @jsii.member(jsii_name="timeouts")
    def timeouts(self) -> typing.Optional["PrivateLinkServiceTimeouts"]:
        return jsii.get(self, "timeouts")

    @timeouts.setter # type: ignore
    def timeouts(self, value: typing.Optional["PrivateLinkServiceTimeouts"]) -> None:
        jsii.set(self, "timeouts", value)

    @builtins.property # type: ignore
    @jsii.member(jsii_name="visibilitySubscriptionIds")
    def visibility_subscription_ids(self) -> typing.Optional[typing.List[builtins.str]]:
        return jsii.get(self, "visibilitySubscriptionIds")

    @visibility_subscription_ids.setter # type: ignore
    def visibility_subscription_ids(
        self,
        value: typing.Optional[typing.List[builtins.str]],
    ) -> None:
        jsii.set(self, "visibilitySubscriptionIds", value)


@jsii.data_type(
    jsii_type="@cdktf/provider-azurerm.PrivateLinkServiceConfig",
    jsii_struct_bases=[cdktf.TerraformMetaArguments],
    name_mapping={
        "count": "count",
        "depends_on": "dependsOn",
        "lifecycle": "lifecycle",
        "provider": "provider",
        "load_balancer_frontend_ip_configuration_ids": "loadBalancerFrontendIpConfigurationIds",
        "location": "location",
        "name": "name",
        "nat_ip_configuration": "natIpConfiguration",
        "resource_group_name": "resourceGroupName",
        "auto_approval_subscription_ids": "autoApprovalSubscriptionIds",
        "enable_proxy_protocol": "enableProxyProtocol",
        "tags": "tags",
        "timeouts": "timeouts",
        "visibility_subscription_ids": "visibilitySubscriptionIds",
    },
)
class PrivateLinkServiceConfig(cdktf.TerraformMetaArguments):
    def __init__(
        self,
        *,
        count: typing.Optional[jsii.Number] = None,
        depends_on: typing.Optional[typing.List[cdktf.TerraformResource]] = None,
        lifecycle: typing.Optional[cdktf.TerraformResourceLifecycle] = None,
        provider: typing.Optional[cdktf.TerraformProvider] = None,
        load_balancer_frontend_ip_configuration_ids: typing.List[builtins.str],
        location: builtins.str,
        name: builtins.str,
        nat_ip_configuration: typing.List["PrivateLinkServiceNatIpConfiguration"],
        resource_group_name: builtins.str,
        auto_approval_subscription_ids: typing.Optional[typing.List[builtins.str]] = None,
        enable_proxy_protocol: typing.Optional[builtins.bool] = None,
        tags: typing.Optional[typing.Mapping[builtins.str, builtins.str]] = None,
        timeouts: typing.Optional["PrivateLinkServiceTimeouts"] = None,
        visibility_subscription_ids: typing.Optional[typing.List[builtins.str]] = None,
    ) -> None:
        """
        :param count: 
        :param depends_on: 
        :param lifecycle: 
        :param provider: 
        :param load_balancer_frontend_ip_configuration_ids: 
        :param location: 
        :param name: 
        :param nat_ip_configuration: nat_ip_configuration block.
        :param resource_group_name: 
        :param auto_approval_subscription_ids: 
        :param enable_proxy_protocol: 
        :param tags: 
        :param timeouts: timeouts block.
        :param visibility_subscription_ids: 
        """
        if isinstance(lifecycle, dict):
            lifecycle = cdktf.TerraformResourceLifecycle(**lifecycle)
        if isinstance(timeouts, dict):
            timeouts = PrivateLinkServiceTimeouts(**timeouts)
        self._values: typing.Dict[str, typing.Any] = {
            "load_balancer_frontend_ip_configuration_ids": load_balancer_frontend_ip_configuration_ids,
            "location": location,
            "name": name,
            "nat_ip_configuration": nat_ip_configuration,
            "resource_group_name": resource_group_name,
        }
        if count is not None:
            self._values["count"] = count
        if depends_on is not None:
            self._values["depends_on"] = depends_on
        if lifecycle is not None:
            self._values["lifecycle"] = lifecycle
        if provider is not None:
            self._values["provider"] = provider
        if auto_approval_subscription_ids is not None:
            self._values["auto_approval_subscription_ids"] = auto_approval_subscription_ids
        if enable_proxy_protocol is not None:
            self._values["enable_proxy_protocol"] = enable_proxy_protocol
        if tags is not None:
            self._values["tags"] = tags
        if timeouts is not None:
            self._values["timeouts"] = timeouts
        if visibility_subscription_ids is not None:
            self._values["visibility_subscription_ids"] = visibility_subscription_ids

    @builtins.property
    def count(self) -> typing.Optional[jsii.Number]:
        """
        :stability: experimental
        """
        result = self._values.get("count")
        return result

    @builtins.property
    def depends_on(self) -> typing.Optional[typing.List[cdktf.TerraformResource]]:
        """
        :stability: experimental
        """
        result = self._values.get("depends_on")
        return result

    @builtins.property
    def lifecycle(self) -> typing.Optional[cdktf.TerraformResourceLifecycle]:
        """
        :stability: experimental
        """
        result = self._values.get("lifecycle")
        return result

    @builtins.property
    def provider(self) -> typing.Optional[cdktf.TerraformProvider]:
        """
        :stability: experimental
        """
        result = self._values.get("provider")
        return result

    @builtins.property
    def load_balancer_frontend_ip_configuration_ids(self) -> typing.List[builtins.str]:
        result = self._values.get("load_balancer_frontend_ip_configuration_ids")
        assert result is not None, "Required property 'load_balancer_frontend_ip_configuration_ids' is missing"
        return result

    @builtins.property
    def location(self) -> builtins.str:
        result = self._values.get("location")
        assert result is not None, "Required property 'location' is missing"
        return result

    @builtins.property
    def name(self) -> builtins.str:
        result = self._values.get("name")
        assert result is not None, "Required property 'name' is missing"
        return result

    @builtins.property
    def nat_ip_configuration(
        self,
    ) -> typing.List["PrivateLinkServiceNatIpConfiguration"]:
        """nat_ip_configuration block."""
        result = self._values.get("nat_ip_configuration")
        assert result is not None, "Required property 'nat_ip_configuration' is missing"
        return result

    @builtins.property
    def resource_group_name(self) -> builtins.str:
        result = self._values.get("resource_group_name")
        assert result is not None, "Required property 'resource_group_name' is missing"
        return result

    @builtins.property
    def auto_approval_subscription_ids(
        self,
    ) -> typing.Optional[typing.List[builtins.str]]:
        result = self._values.get("auto_approval_subscription_ids")
        return result

    @builtins.property
    def enable_proxy_protocol(self) -> typing.Optional[builtins.bool]:
        result = self._values.get("enable_proxy_protocol")
        return result

    @builtins.property
    def tags(self) -> typing.Optional[typing.Mapping[builtins.str, builtins.str]]:
        result = self._values.get("tags")
        return result

    @builtins.property
    def timeouts(self) -> typing.Optional["PrivateLinkServiceTimeouts"]:
        """timeouts block."""
        result = self._values.get("timeouts")
        return result

    @builtins.property
    def visibility_subscription_ids(self) -> typing.Optional[typing.List[builtins.str]]:
        result = self._values.get("visibility_subscription_ids")
        return result

    def __eq__(self, rhs: typing.Any) -> builtins.bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs: typing.Any) -> builtins.bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return "PrivateLinkServiceConfig(%s)" % ", ".join(
            k + "=" + repr(v) for k, v in self._values.items()
        )


@jsii.data_type(
    jsii_type="@cdktf/provider-azurerm.PrivateLinkServiceNatIpConfiguration",
    jsii_struct_bases=[],
    name_mapping={
        "name": "name",
        "primary": "primary",
        "subnet_id": "subnetId",
        "private_ip_address": "privateIpAddress",
        "private_ip_address_version": "privateIpAddressVersion",
    },
)
class PrivateLinkServiceNatIpConfiguration:
    def __init__(
        self,
        *,
        name: builtins.str,
        primary: builtins.bool,
        subnet_id: builtins.str,
        private_ip_address: typing.Optional[builtins.str] = None,
        private_ip_address_version: typing.Optional[builtins.str] = None,
    ) -> None:
        """
        :param name: 
        :param primary: 
        :param subnet_id: 
        :param private_ip_address: 
        :param private_ip_address_version: 
        """
        self._values: typing.Dict[str, typing.Any] = {
            "name": name,
            "primary": primary,
            "subnet_id": subnet_id,
        }
        if private_ip_address is not None:
            self._values["private_ip_address"] = private_ip_address
        if private_ip_address_version is not None:
            self._values["private_ip_address_version"] = private_ip_address_version

    @builtins.property
    def name(self) -> builtins.str:
        result = self._values.get("name")
        assert result is not None, "Required property 'name' is missing"
        return result

    @builtins.property
    def primary(self) -> builtins.bool:
        result = self._values.get("primary")
        assert result is not None, "Required property 'primary' is missing"
        return result

    @builtins.property
    def subnet_id(self) -> builtins.str:
        result = self._values.get("subnet_id")
        assert result is not None, "Required property 'subnet_id' is missing"
        return result

    @builtins.property
    def private_ip_address(self) -> typing.Optional[builtins.str]:
        result = self._values.get("private_ip_address")
        return result

    @builtins.property
    def private_ip_address_version(self) -> typing.Optional[builtins.str]:
        result = self._values.get("private_ip_address_version")
        return result

    def __eq__(self, rhs: typing.Any) -> builtins.bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs: typing.Any) -> builtins.bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return "PrivateLinkServiceNatIpConfiguration(%s)" % ", ".join(
            k + "=" + repr(v) for k, v in self._values.items()
        )


@jsii.data_type(
    jsii_type="@cdktf/provider-azurerm.PrivateLinkServiceTimeouts",
    jsii_struct_bases=[],
    name_mapping={
        "create": "create",
        "delete": "delete",
        "read": "read",
        "update": "update",
    },
)
class PrivateLinkServiceTimeouts:
    def __init__(
        self,
        *,
        create: typing.Optional[builtins.str] = None,
        delete: typing.Optional[builtins.str] = None,
        read: typing.Optional[builtins.str] = None,
        update: typing.Optional[builtins.str] = None,
    ) -> None:
        """
        :param create: 
        :param delete: 
        :param read: 
        :param update: 
        """
        self._values: typing.Dict[str, typing.Any] = {}
        if create is not None:
            self._values["create"] = create
        if delete is not None:
            self._values["delete"] = delete
        if read is not None:
            self._values["read"] = read
        if update is not None:
            self._values["update"] = update

    @builtins.property
    def create(self) -> typing.Optional[builtins.str]:
        result = self._values.get("create")
        return result

    @builtins.property
    def delete(self) -> typing.Optional[builtins.str]:
        result = self._values.get("delete")
        return result

    @builtins.property
    def read(self) -> typing.Optional[builtins.str]:
        result = self._values.get("read")
        return result

    @builtins.property
    def update(self) -> typing.Optional[builtins.str]:
        result = self._values.get("update")
        return result

    def __eq__(self, rhs: typing.Any) -> builtins.bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs: typing.Any) -> builtins.bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return "PrivateLinkServiceTimeouts(%s)" % ", ".join(
            k + "=" + repr(v) for k, v in self._values.items()
        )


class ProximityPlacementGroup(
    cdktf.TerraformResource,
    metaclass=jsii.JSIIMeta,
    jsii_type="@cdktf/provider-azurerm.ProximityPlacementGroup",
):
    def __init__(
        self,
        scope: constructs.Construct,
        id: builtins.str,
        *,
        location: builtins.str,
        name: builtins.str,
        resource_group_name: builtins.str,
        tags: typing.Optional[typing.Mapping[builtins.str, builtins.str]] = None,
        timeouts: typing.Optional["ProximityPlacementGroupTimeouts"] = None,
        count: typing.Optional[jsii.Number] = None,
        depends_on: typing.Optional[typing.List[cdktf.TerraformResource]] = None,
        lifecycle: typing.Optional[cdktf.TerraformResourceLifecycle] = None,
        provider: typing.Optional[cdktf.TerraformProvider] = None,
    ) -> None:
        """
        :param scope: -
        :param id: -
        :param location: 
        :param name: 
        :param resource_group_name: 
        :param tags: 
        :param timeouts: timeouts block.
        :param count: 
        :param depends_on: 
        :param lifecycle: 
        :param provider: 
        """
        config = ProximityPlacementGroupConfig(
            location=location,
            name=name,
            resource_group_name=resource_group_name,
            tags=tags,
            timeouts=timeouts,
            count=count,
            depends_on=depends_on,
            lifecycle=lifecycle,
            provider=provider,
        )

        jsii.create(ProximityPlacementGroup, self, [scope, id, config])

    @jsii.member(jsii_name="synthesizeAttributes")
    def _synthesize_attributes(self) -> typing.Mapping[builtins.str, typing.Any]:
        return jsii.invoke(self, "synthesizeAttributes", [])

    @builtins.property # type: ignore
    @jsii.member(jsii_name="location")
    def location(self) -> builtins.str:
        return jsii.get(self, "location")

    @location.setter # type: ignore
    def location(self, value: builtins.str) -> None:
        jsii.set(self, "location", value)

    @builtins.property # type: ignore
    @jsii.member(jsii_name="name")
    def name(self) -> builtins.str:
        return jsii.get(self, "name")

    @name.setter # type: ignore
    def name(self, value: builtins.str) -> None:
        jsii.set(self, "name", value)

    @builtins.property # type: ignore
    @jsii.member(jsii_name="resourceGroupName")
    def resource_group_name(self) -> builtins.str:
        return jsii.get(self, "resourceGroupName")

    @resource_group_name.setter # type: ignore
    def resource_group_name(self, value: builtins.str) -> None:
        jsii.set(self, "resourceGroupName", value)

    @builtins.property # type: ignore
    @jsii.member(jsii_name="id")
    def id(self) -> typing.Optional[builtins.str]:
        return jsii.get(self, "id")

    @id.setter # type: ignore
    def id(self, value: typing.Optional[builtins.str]) -> None:
        jsii.set(self, "id", value)

    @builtins.property # type: ignore
    @jsii.member(jsii_name="tags")
    def tags(self) -> typing.Optional[typing.Mapping[builtins.str, builtins.str]]:
        return jsii.get(self, "tags")

    @tags.setter # type: ignore
    def tags(
        self,
        value: typing.Optional[typing.Mapping[builtins.str, builtins.str]],
    ) -> None:
        jsii.set(self, "tags", value)

    @builtins.property # type: ignore
    @jsii.member(jsii_name="timeouts")
    def timeouts(self) -> typing.Optional["ProximityPlacementGroupTimeouts"]:
        return jsii.get(self, "timeouts")

    @timeouts.setter # type: ignore
    def timeouts(
        self,
        value: typing.Optional["ProximityPlacementGroupTimeouts"],
    ) -> None:
        jsii.set(self, "timeouts", value)


@jsii.data_type(
    jsii_type="@cdktf/provider-azurerm.ProximityPlacementGroupConfig",
    jsii_struct_bases=[cdktf.TerraformMetaArguments],
    name_mapping={
        "count": "count",
        "depends_on": "dependsOn",
        "lifecycle": "lifecycle",
        "provider": "provider",
        "location": "location",
        "name": "name",
        "resource_group_name": "resourceGroupName",
        "tags": "tags",
        "timeouts": "timeouts",
    },
)
class ProximityPlacementGroupConfig(cdktf.TerraformMetaArguments):
    def __init__(
        self,
        *,
        count: typing.Optional[jsii.Number] = None,
        depends_on: typing.Optional[typing.List[cdktf.TerraformResource]] = None,
        lifecycle: typing.Optional[cdktf.TerraformResourceLifecycle] = None,
        provider: typing.Optional[cdktf.TerraformProvider] = None,
        location: builtins.str,
        name: builtins.str,
        resource_group_name: builtins.str,
        tags: typing.Optional[typing.Mapping[builtins.str, builtins.str]] = None,
        timeouts: typing.Optional["ProximityPlacementGroupTimeouts"] = None,
    ) -> None:
        """
        :param count: 
        :param depends_on: 
        :param lifecycle: 
        :param provider: 
        :param location: 
        :param name: 
        :param resource_group_name: 
        :param tags: 
        :param timeouts: timeouts block.
        """
        if isinstance(lifecycle, dict):
            lifecycle = cdktf.TerraformResourceLifecycle(**lifecycle)
        if isinstance(timeouts, dict):
            timeouts = ProximityPlacementGroupTimeouts(**timeouts)
        self._values: typing.Dict[str, typing.Any] = {
            "location": location,
            "name": name,
            "resource_group_name": resource_group_name,
        }
        if count is not None:
            self._values["count"] = count
        if depends_on is not None:
            self._values["depends_on"] = depends_on
        if lifecycle is not None:
            self._values["lifecycle"] = lifecycle
        if provider is not None:
            self._values["provider"] = provider
        if tags is not None:
            self._values["tags"] = tags
        if timeouts is not None:
            self._values["timeouts"] = timeouts

    @builtins.property
    def count(self) -> typing.Optional[jsii.Number]:
        """
        :stability: experimental
        """
        result = self._values.get("count")
        return result

    @builtins.property
    def depends_on(self) -> typing.Optional[typing.List[cdktf.TerraformResource]]:
        """
        :stability: experimental
        """
        result = self._values.get("depends_on")
        return result

    @builtins.property
    def lifecycle(self) -> typing.Optional[cdktf.TerraformResourceLifecycle]:
        """
        :stability: experimental
        """
        result = self._values.get("lifecycle")
        return result

    @builtins.property
    def provider(self) -> typing.Optional[cdktf.TerraformProvider]:
        """
        :stability: experimental
        """
        result = self._values.get("provider")
        return result

    @builtins.property
    def location(self) -> builtins.str:
        result = self._values.get("location")
        assert result is not None, "Required property 'location' is missing"
        return result

    @builtins.property
    def name(self) -> builtins.str:
        result = self._values.get("name")
        assert result is not None, "Required property 'name' is missing"
        return result

    @builtins.property
    def resource_group_name(self) -> builtins.str:
        result = self._values.get("resource_group_name")
        assert result is not None, "Required property 'resource_group_name' is missing"
        return result

    @builtins.property
    def tags(self) -> typing.Optional[typing.Mapping[builtins.str, builtins.str]]:
        result = self._values.get("tags")
        return result

    @builtins.property
    def timeouts(self) -> typing.Optional["ProximityPlacementGroupTimeouts"]:
        """timeouts block."""
        result = self._values.get("timeouts")
        return result

    def __eq__(self, rhs: typing.Any) -> builtins.bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs: typing.Any) -> builtins.bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return "ProximityPlacementGroupConfig(%s)" % ", ".join(
            k + "=" + repr(v) for k, v in self._values.items()
        )


@jsii.data_type(
    jsii_type="@cdktf/provider-azurerm.ProximityPlacementGroupTimeouts",
    jsii_struct_bases=[],
    name_mapping={
        "create": "create",
        "delete": "delete",
        "read": "read",
        "update": "update",
    },
)
class ProximityPlacementGroupTimeouts:
    def __init__(
        self,
        *,
        create: typing.Optional[builtins.str] = None,
        delete: typing.Optional[builtins.str] = None,
        read: typing.Optional[builtins.str] = None,
        update: typing.Optional[builtins.str] = None,
    ) -> None:
        """
        :param create: 
        :param delete: 
        :param read: 
        :param update: 
        """
        self._values: typing.Dict[str, typing.Any] = {}
        if create is not None:
            self._values["create"] = create
        if delete is not None:
            self._values["delete"] = delete
        if read is not None:
            self._values["read"] = read
        if update is not None:
            self._values["update"] = update

    @builtins.property
    def create(self) -> typing.Optional[builtins.str]:
        result = self._values.get("create")
        return result

    @builtins.property
    def delete(self) -> typing.Optional[builtins.str]:
        result = self._values.get("delete")
        return result

    @builtins.property
    def read(self) -> typing.Optional[builtins.str]:
        result = self._values.get("read")
        return result

    @builtins.property
    def update(self) -> typing.Optional[builtins.str]:
        result = self._values.get("update")
        return result

    def __eq__(self, rhs: typing.Any) -> builtins.bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs: typing.Any) -> builtins.bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return "ProximityPlacementGroupTimeouts(%s)" % ", ".join(
            k + "=" + repr(v) for k, v in self._values.items()
        )


class PublicIp(
    cdktf.TerraformResource,
    metaclass=jsii.JSIIMeta,
    jsii_type="@cdktf/provider-azurerm.PublicIp",
):
    def __init__(
        self,
        scope: constructs.Construct,
        id: builtins.str,
        *,
        allocation_method: builtins.str,
        location: builtins.str,
        name: builtins.str,
        resource_group_name: builtins.str,
        domain_name_label: typing.Optional[builtins.str] = None,
        idle_timeout_in_minutes: typing.Optional[jsii.Number] = None,
        ip_version: typing.Optional[builtins.str] = None,
        public_ip_prefix_id: typing.Optional[builtins.str] = None,
        reverse_fqdn: typing.Optional[builtins.str] = None,
        sku: typing.Optional[builtins.str] = None,
        tags: typing.Optional[typing.Mapping[builtins.str, builtins.str]] = None,
        timeouts: typing.Optional["PublicIpTimeouts"] = None,
        zones: typing.Optional[typing.List[builtins.str]] = None,
        count: typing.Optional[jsii.Number] = None,
        depends_on: typing.Optional[typing.List[cdktf.TerraformResource]] = None,
        lifecycle: typing.Optional[cdktf.TerraformResourceLifecycle] = None,
        provider: typing.Optional[cdktf.TerraformProvider] = None,
    ) -> None:
        """
        :param scope: -
        :param id: -
        :param allocation_method: 
        :param location: 
        :param name: 
        :param resource_group_name: 
        :param domain_name_label: 
        :param idle_timeout_in_minutes: 
        :param ip_version: 
        :param public_ip_prefix_id: 
        :param reverse_fqdn: 
        :param sku: 
        :param tags: 
        :param timeouts: timeouts block.
        :param zones: 
        :param count: 
        :param depends_on: 
        :param lifecycle: 
        :param provider: 
        """
        config = PublicIpConfig(
            allocation_method=allocation_method,
            location=location,
            name=name,
            resource_group_name=resource_group_name,
            domain_name_label=domain_name_label,
            idle_timeout_in_minutes=idle_timeout_in_minutes,
            ip_version=ip_version,
            public_ip_prefix_id=public_ip_prefix_id,
            reverse_fqdn=reverse_fqdn,
            sku=sku,
            tags=tags,
            timeouts=timeouts,
            zones=zones,
            count=count,
            depends_on=depends_on,
            lifecycle=lifecycle,
            provider=provider,
        )

        jsii.create(PublicIp, self, [scope, id, config])

    @jsii.member(jsii_name="synthesizeAttributes")
    def _synthesize_attributes(self) -> typing.Mapping[builtins.str, typing.Any]:
        return jsii.invoke(self, "synthesizeAttributes", [])

    @builtins.property # type: ignore
    @jsii.member(jsii_name="fqdn")
    def fqdn(self) -> builtins.str:
        return jsii.get(self, "fqdn")

    @builtins.property # type: ignore
    @jsii.member(jsii_name="ipAddress")
    def ip_address(self) -> builtins.str:
        return jsii.get(self, "ipAddress")

    @builtins.property # type: ignore
    @jsii.member(jsii_name="allocationMethod")
    def allocation_method(self) -> builtins.str:
        return jsii.get(self, "allocationMethod")

    @allocation_method.setter # type: ignore
    def allocation_method(self, value: builtins.str) -> None:
        jsii.set(self, "allocationMethod", value)

    @builtins.property # type: ignore
    @jsii.member(jsii_name="location")
    def location(self) -> builtins.str:
        return jsii.get(self, "location")

    @location.setter # type: ignore
    def location(self, value: builtins.str) -> None:
        jsii.set(self, "location", value)

    @builtins.property # type: ignore
    @jsii.member(jsii_name="name")
    def name(self) -> builtins.str:
        return jsii.get(self, "name")

    @name.setter # type: ignore
    def name(self, value: builtins.str) -> None:
        jsii.set(self, "name", value)

    @builtins.property # type: ignore
    @jsii.member(jsii_name="resourceGroupName")
    def resource_group_name(self) -> builtins.str:
        return jsii.get(self, "resourceGroupName")

    @resource_group_name.setter # type: ignore
    def resource_group_name(self, value: builtins.str) -> None:
        jsii.set(self, "resourceGroupName", value)

    @builtins.property # type: ignore
    @jsii.member(jsii_name="domainNameLabel")
    def domain_name_label(self) -> typing.Optional[builtins.str]:
        return jsii.get(self, "domainNameLabel")

    @domain_name_label.setter # type: ignore
    def domain_name_label(self, value: typing.Optional[builtins.str]) -> None:
        jsii.set(self, "domainNameLabel", value)

    @builtins.property # type: ignore
    @jsii.member(jsii_name="id")
    def id(self) -> typing.Optional[builtins.str]:
        return jsii.get(self, "id")

    @id.setter # type: ignore
    def id(self, value: typing.Optional[builtins.str]) -> None:
        jsii.set(self, "id", value)

    @builtins.property # type: ignore
    @jsii.member(jsii_name="idleTimeoutInMinutes")
    def idle_timeout_in_minutes(self) -> typing.Optional[jsii.Number]:
        return jsii.get(self, "idleTimeoutInMinutes")

    @idle_timeout_in_minutes.setter # type: ignore
    def idle_timeout_in_minutes(self, value: typing.Optional[jsii.Number]) -> None:
        jsii.set(self, "idleTimeoutInMinutes", value)

    @builtins.property # type: ignore
    @jsii.member(jsii_name="ipVersion")
    def ip_version(self) -> typing.Optional[builtins.str]:
        return jsii.get(self, "ipVersion")

    @ip_version.setter # type: ignore
    def ip_version(self, value: typing.Optional[builtins.str]) -> None:
        jsii.set(self, "ipVersion", value)

    @builtins.property # type: ignore
    @jsii.member(jsii_name="publicIpPrefixId")
    def public_ip_prefix_id(self) -> typing.Optional[builtins.str]:
        return jsii.get(self, "publicIpPrefixId")

    @public_ip_prefix_id.setter # type: ignore
    def public_ip_prefix_id(self, value: typing.Optional[builtins.str]) -> None:
        jsii.set(self, "publicIpPrefixId", value)

    @builtins.property # type: ignore
    @jsii.member(jsii_name="reverseFqdn")
    def reverse_fqdn(self) -> typing.Optional[builtins.str]:
        return jsii.get(self, "reverseFqdn")

    @reverse_fqdn.setter # type: ignore
    def reverse_fqdn(self, value: typing.Optional[builtins.str]) -> None:
        jsii.set(self, "reverseFqdn", value)

    @builtins.property # type: ignore
    @jsii.member(jsii_name="sku")
    def sku(self) -> typing.Optional[builtins.str]:
        return jsii.get(self, "sku")

    @sku.setter # type: ignore
    def sku(self, value: typing.Optional[builtins.str]) -> None:
        jsii.set(self, "sku", value)

    @builtins.property # type: ignore
    @jsii.member(jsii_name="tags")
    def tags(self) -> typing.Optional[typing.Mapping[builtins.str, builtins.str]]:
        return jsii.get(self, "tags")

    @tags.setter # type: ignore
    def tags(
        self,
        value: typing.Optional[typing.Mapping[builtins.str, builtins.str]],
    ) -> None:
        jsii.set(self, "tags", value)

    @builtins.property # type: ignore
    @jsii.member(jsii_name="timeouts")
    def timeouts(self) -> typing.Optional["PublicIpTimeouts"]:
        return jsii.get(self, "timeouts")

    @timeouts.setter # type: ignore
    def timeouts(self, value: typing.Optional["PublicIpTimeouts"]) -> None:
        jsii.set(self, "timeouts", value)

    @builtins.property # type: ignore
    @jsii.member(jsii_name="zones")
    def zones(self) -> typing.Optional[typing.List[builtins.str]]:
        return jsii.get(self, "zones")

    @zones.setter # type: ignore
    def zones(self, value: typing.Optional[typing.List[builtins.str]]) -> None:
        jsii.set(self, "zones", value)


@jsii.data_type(
    jsii_type="@cdktf/provider-azurerm.PublicIpConfig",
    jsii_struct_bases=[cdktf.TerraformMetaArguments],
    name_mapping={
        "count": "count",
        "depends_on": "dependsOn",
        "lifecycle": "lifecycle",
        "provider": "provider",
        "allocation_method": "allocationMethod",
        "location": "location",
        "name": "name",
        "resource_group_name": "resourceGroupName",
        "domain_name_label": "domainNameLabel",
        "idle_timeout_in_minutes": "idleTimeoutInMinutes",
        "ip_version": "ipVersion",
        "public_ip_prefix_id": "publicIpPrefixId",
        "reverse_fqdn": "reverseFqdn",
        "sku": "sku",
        "tags": "tags",
        "timeouts": "timeouts",
        "zones": "zones",
    },
)
class PublicIpConfig(cdktf.TerraformMetaArguments):
    def __init__(
        self,
        *,
        count: typing.Optional[jsii.Number] = None,
        depends_on: typing.Optional[typing.List[cdktf.TerraformResource]] = None,
        lifecycle: typing.Optional[cdktf.TerraformResourceLifecycle] = None,
        provider: typing.Optional[cdktf.TerraformProvider] = None,
        allocation_method: builtins.str,
        location: builtins.str,
        name: builtins.str,
        resource_group_name: builtins.str,
        domain_name_label: typing.Optional[builtins.str] = None,
        idle_timeout_in_minutes: typing.Optional[jsii.Number] = None,
        ip_version: typing.Optional[builtins.str] = None,
        public_ip_prefix_id: typing.Optional[builtins.str] = None,
        reverse_fqdn: typing.Optional[builtins.str] = None,
        sku: typing.Optional[builtins.str] = None,
        tags: typing.Optional[typing.Mapping[builtins.str, builtins.str]] = None,
        timeouts: typing.Optional["PublicIpTimeouts"] = None,
        zones: typing.Optional[typing.List[builtins.str]] = None,
    ) -> None:
        """
        :param count: 
        :param depends_on: 
        :param lifecycle: 
        :param provider: 
        :param allocation_method: 
        :param location: 
        :param name: 
        :param resource_group_name: 
        :param domain_name_label: 
        :param idle_timeout_in_minutes: 
        :param ip_version: 
        :param public_ip_prefix_id: 
        :param reverse_fqdn: 
        :param sku: 
        :param tags: 
        :param timeouts: timeouts block.
        :param zones: 
        """
        if isinstance(lifecycle, dict):
            lifecycle = cdktf.TerraformResourceLifecycle(**lifecycle)
        if isinstance(timeouts, dict):
            timeouts = PublicIpTimeouts(**timeouts)
        self._values: typing.Dict[str, typing.Any] = {
            "allocation_method": allocation_method,
            "location": location,
            "name": name,
            "resource_group_name": resource_group_name,
        }
        if count is not None:
            self._values["count"] = count
        if depends_on is not None:
            self._values["depends_on"] = depends_on
        if lifecycle is not None:
            self._values["lifecycle"] = lifecycle
        if provider is not None:
            self._values["provider"] = provider
        if domain_name_label is not None:
            self._values["domain_name_label"] = domain_name_label
        if idle_timeout_in_minutes is not None:
            self._values["idle_timeout_in_minutes"] = idle_timeout_in_minutes
        if ip_version is not None:
            self._values["ip_version"] = ip_version
        if public_ip_prefix_id is not None:
            self._values["public_ip_prefix_id"] = public_ip_prefix_id
        if reverse_fqdn is not None:
            self._values["reverse_fqdn"] = reverse_fqdn
        if sku is not None:
            self._values["sku"] = sku
        if tags is not None:
            self._values["tags"] = tags
        if timeouts is not None:
            self._values["timeouts"] = timeouts
        if zones is not None:
            self._values["zones"] = zones

    @builtins.property
    def count(self) -> typing.Optional[jsii.Number]:
        """
        :stability: experimental
        """
        result = self._values.get("count")
        return result

    @builtins.property
    def depends_on(self) -> typing.Optional[typing.List[cdktf.TerraformResource]]:
        """
        :stability: experimental
        """
        result = self._values.get("depends_on")
        return result

    @builtins.property
    def lifecycle(self) -> typing.Optional[cdktf.TerraformResourceLifecycle]:
        """
        :stability: experimental
        """
        result = self._values.get("lifecycle")
        return result

    @builtins.property
    def provider(self) -> typing.Optional[cdktf.TerraformProvider]:
        """
        :stability: experimental
        """
        result = self._values.get("provider")
        return result

    @builtins.property
    def allocation_method(self) -> builtins.str:
        result = self._values.get("allocation_method")
        assert result is not None, "Required property 'allocation_method' is missing"
        return result

    @builtins.property
    def location(self) -> builtins.str:
        result = self._values.get("location")
        assert result is not None, "Required property 'location' is missing"
        return result

    @builtins.property
    def name(self) -> builtins.str:
        result = self._values.get("name")
        assert result is not None, "Required property 'name' is missing"
        return result

    @builtins.property
    def resource_group_name(self) -> builtins.str:
        result = self._values.get("resource_group_name")
        assert result is not None, "Required property 'resource_group_name' is missing"
        return result

    @builtins.property
    def domain_name_label(self) -> typing.Optional[builtins.str]:
        result = self._values.get("domain_name_label")
        return result

    @builtins.property
    def idle_timeout_in_minutes(self) -> typing.Optional[jsii.Number]:
        result = self._values.get("idle_timeout_in_minutes")
        return result

    @builtins.property
    def ip_version(self) -> typing.Optional[builtins.str]:
        result = self._values.get("ip_version")
        return result

    @builtins.property
    def public_ip_prefix_id(self) -> typing.Optional[builtins.str]:
        result = self._values.get("public_ip_prefix_id")
        return result

    @builtins.property
    def reverse_fqdn(self) -> typing.Optional[builtins.str]:
        result = self._values.get("reverse_fqdn")
        return result

    @builtins.property
    def sku(self) -> typing.Optional[builtins.str]:
        result = self._values.get("sku")
        return result

    @builtins.property
    def tags(self) -> typing.Optional[typing.Mapping[builtins.str, builtins.str]]:
        result = self._values.get("tags")
        return result

    @builtins.property
    def timeouts(self) -> typing.Optional["PublicIpTimeouts"]:
        """timeouts block."""
        result = self._values.get("timeouts")
        return result

    @builtins.property
    def zones(self) -> typing.Optional[typing.List[builtins.str]]:
        result = self._values.get("zones")
        return result

    def __eq__(self, rhs: typing.Any) -> builtins.bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs: typing.Any) -> builtins.bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return "PublicIpConfig(%s)" % ", ".join(
            k + "=" + repr(v) for k, v in self._values.items()
        )


class PublicIpPrefix(
    cdktf.TerraformResource,
    metaclass=jsii.JSIIMeta,
    jsii_type="@cdktf/provider-azurerm.PublicIpPrefix",
):
    def __init__(
        self,
        scope: constructs.Construct,
        id: builtins.str,
        *,
        location: builtins.str,
        name: builtins.str,
        resource_group_name: builtins.str,
        prefix_length: typing.Optional[jsii.Number] = None,
        sku: typing.Optional[builtins.str] = None,
        tags: typing.Optional[typing.Mapping[builtins.str, builtins.str]] = None,
        timeouts: typing.Optional["PublicIpPrefixTimeouts"] = None,
        zones: typing.Optional[typing.List[builtins.str]] = None,
        count: typing.Optional[jsii.Number] = None,
        depends_on: typing.Optional[typing.List[cdktf.TerraformResource]] = None,
        lifecycle: typing.Optional[cdktf.TerraformResourceLifecycle] = None,
        provider: typing.Optional[cdktf.TerraformProvider] = None,
    ) -> None:
        """
        :param scope: -
        :param id: -
        :param location: 
        :param name: 
        :param resource_group_name: 
        :param prefix_length: 
        :param sku: 
        :param tags: 
        :param timeouts: timeouts block.
        :param zones: 
        :param count: 
        :param depends_on: 
        :param lifecycle: 
        :param provider: 
        """
        config = PublicIpPrefixConfig(
            location=location,
            name=name,
            resource_group_name=resource_group_name,
            prefix_length=prefix_length,
            sku=sku,
            tags=tags,
            timeouts=timeouts,
            zones=zones,
            count=count,
            depends_on=depends_on,
            lifecycle=lifecycle,
            provider=provider,
        )

        jsii.create(PublicIpPrefix, self, [scope, id, config])

    @jsii.member(jsii_name="synthesizeAttributes")
    def _synthesize_attributes(self) -> typing.Mapping[builtins.str, typing.Any]:
        return jsii.invoke(self, "synthesizeAttributes", [])

    @builtins.property # type: ignore
    @jsii.member(jsii_name="ipPrefix")
    def ip_prefix(self) -> builtins.str:
        return jsii.get(self, "ipPrefix")

    @builtins.property # type: ignore
    @jsii.member(jsii_name="location")
    def location(self) -> builtins.str:
        return jsii.get(self, "location")

    @location.setter # type: ignore
    def location(self, value: builtins.str) -> None:
        jsii.set(self, "location", value)

    @builtins.property # type: ignore
    @jsii.member(jsii_name="name")
    def name(self) -> builtins.str:
        return jsii.get(self, "name")

    @name.setter # type: ignore
    def name(self, value: builtins.str) -> None:
        jsii.set(self, "name", value)

    @builtins.property # type: ignore
    @jsii.member(jsii_name="resourceGroupName")
    def resource_group_name(self) -> builtins.str:
        return jsii.get(self, "resourceGroupName")

    @resource_group_name.setter # type: ignore
    def resource_group_name(self, value: builtins.str) -> None:
        jsii.set(self, "resourceGroupName", value)

    @builtins.property # type: ignore
    @jsii.member(jsii_name="id")
    def id(self) -> typing.Optional[builtins.str]:
        return jsii.get(self, "id")

    @id.setter # type: ignore
    def id(self, value: typing.Optional[builtins.str]) -> None:
        jsii.set(self, "id", value)

    @builtins.property # type: ignore
    @jsii.member(jsii_name="prefixLength")
    def prefix_length(self) -> typing.Optional[jsii.Number]:
        return jsii.get(self, "prefixLength")

    @prefix_length.setter # type: ignore
    def prefix_length(self, value: typing.Optional[jsii.Number]) -> None:
        jsii.set(self, "prefixLength", value)

    @builtins.property # type: ignore
    @jsii.member(jsii_name="sku")
    def sku(self) -> typing.Optional[builtins.str]:
        return jsii.get(self, "sku")

    @sku.setter # type: ignore
    def sku(self, value: typing.Optional[builtins.str]) -> None:
        jsii.set(self, "sku", value)

    @builtins.property # type: ignore
    @jsii.member(jsii_name="tags")
    def tags(self) -> typing.Optional[typing.Mapping[builtins.str, builtins.str]]:
        return jsii.get(self, "tags")

    @tags.setter # type: ignore
    def tags(
        self,
        value: typing.Optional[typing.Mapping[builtins.str, builtins.str]],
    ) -> None:
        jsii.set(self, "tags", value)

    @builtins.property # type: ignore
    @jsii.member(jsii_name="timeouts")
    def timeouts(self) -> typing.Optional["PublicIpPrefixTimeouts"]:
        return jsii.get(self, "timeouts")

    @timeouts.setter # type: ignore
    def timeouts(self, value: typing.Optional["PublicIpPrefixTimeouts"]) -> None:
        jsii.set(self, "timeouts", value)

    @builtins.property # type: ignore
    @jsii.member(jsii_name="zones")
    def zones(self) -> typing.Optional[typing.List[builtins.str]]:
        return jsii.get(self, "zones")

    @zones.setter # type: ignore
    def zones(self, value: typing.Optional[typing.List[builtins.str]]) -> None:
        jsii.set(self, "zones", value)


@jsii.data_type(
    jsii_type="@cdktf/provider-azurerm.PublicIpPrefixConfig",
    jsii_struct_bases=[cdktf.TerraformMetaArguments],
    name_mapping={
        "count": "count",
        "depends_on": "dependsOn",
        "lifecycle": "lifecycle",
        "provider": "provider",
        "location": "location",
        "name": "name",
        "resource_group_name": "resourceGroupName",
        "prefix_length": "prefixLength",
        "sku": "sku",
        "tags": "tags",
        "timeouts": "timeouts",
        "zones": "zones",
    },
)
class PublicIpPrefixConfig(cdktf.TerraformMetaArguments):
    def __init__(
        self,
        *,
        count: typing.Optional[jsii.Number] = None,
        depends_on: typing.Optional[typing.List[cdktf.TerraformResource]] = None,
        lifecycle: typing.Optional[cdktf.TerraformResourceLifecycle] = None,
        provider: typing.Optional[cdktf.TerraformProvider] = None,
        location: builtins.str,
        name: builtins.str,
        resource_group_name: builtins.str,
        prefix_length: typing.Optional[jsii.Number] = None,
        sku: typing.Optional[builtins.str] = None,
        tags: typing.Optional[typing.Mapping[builtins.str, builtins.str]] = None,
        timeouts: typing.Optional["PublicIpPrefixTimeouts"] = None,
        zones: typing.Optional[typing.List[builtins.str]] = None,
    ) -> None:
        """
        :param count: 
        :param depends_on: 
        :param lifecycle: 
        :param provider: 
        :param location: 
        :param name: 
        :param resource_group_name: 
        :param prefix_length: 
        :param sku: 
        :param tags: 
        :param timeouts: timeouts block.
        :param zones: 
        """
        if isinstance(lifecycle, dict):
            lifecycle = cdktf.TerraformResourceLifecycle(**lifecycle)
        if isinstance(timeouts, dict):
            timeouts = PublicIpPrefixTimeouts(**timeouts)
        self._values: typing.Dict[str, typing.Any] = {
            "location": location,
            "name": name,
            "resource_group_name": resource_group_name,
        }
        if count is not None:
            self._values["count"] = count
        if depends_on is not None:
            self._values["depends_on"] = depends_on
        if lifecycle is not None:
            self._values["lifecycle"] = lifecycle
        if provider is not None:
            self._values["provider"] = provider
        if prefix_length is not None:
            self._values["prefix_length"] = prefix_length
        if sku is not None:
            self._values["sku"] = sku
        if tags is not None:
            self._values["tags"] = tags
        if timeouts is not None:
            self._values["timeouts"] = timeouts
        if zones is not None:
            self._values["zones"] = zones

    @builtins.property
    def count(self) -> typing.Optional[jsii.Number]:
        """
        :stability: experimental
        """
        result = self._values.get("count")
        return result

    @builtins.property
    def depends_on(self) -> typing.Optional[typing.List[cdktf.TerraformResource]]:
        """
        :stability: experimental
        """
        result = self._values.get("depends_on")
        return result

    @builtins.property
    def lifecycle(self) -> typing.Optional[cdktf.TerraformResourceLifecycle]:
        """
        :stability: experimental
        """
        result = self._values.get("lifecycle")
        return result

    @builtins.property
    def provider(self) -> typing.Optional[cdktf.TerraformProvider]:
        """
        :stability: experimental
        """
        result = self._values.get("provider")
        return result

    @builtins.property
    def location(self) -> builtins.str:
        result = self._values.get("location")
        assert result is not None, "Required property 'location' is missing"
        return result

    @builtins.property
    def name(self) -> builtins.str:
        result = self._values.get("name")
        assert result is not None, "Required property 'name' is missing"
        return result

    @builtins.property
    def resource_group_name(self) -> builtins.str:
        result = self._values.get("resource_group_name")
        assert result is not None, "Required property 'resource_group_name' is missing"
        return result

    @builtins.property
    def prefix_length(self) -> typing.Optional[jsii.Number]:
        result = self._values.get("prefix_length")
        return result

    @builtins.property
    def sku(self) -> typing.Optional[builtins.str]:
        result = self._values.get("sku")
        return result

    @builtins.property
    def tags(self) -> typing.Optional[typing.Mapping[builtins.str, builtins.str]]:
        result = self._values.get("tags")
        return result

    @builtins.property
    def timeouts(self) -> typing.Optional["PublicIpPrefixTimeouts"]:
        """timeouts block."""
        result = self._values.get("timeouts")
        return result

    @builtins.property
    def zones(self) -> typing.Optional[typing.List[builtins.str]]:
        result = self._values.get("zones")
        return result

    def __eq__(self, rhs: typing.Any) -> builtins.bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs: typing.Any) -> builtins.bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return "PublicIpPrefixConfig(%s)" % ", ".join(
            k + "=" + repr(v) for k, v in self._values.items()
        )


@jsii.data_type(
    jsii_type="@cdktf/provider-azurerm.PublicIpPrefixTimeouts",
    jsii_struct_bases=[],
    name_mapping={
        "create": "create",
        "delete": "delete",
        "read": "read",
        "update": "update",
    },
)
class PublicIpPrefixTimeouts:
    def __init__(
        self,
        *,
        create: typing.Optional[builtins.str] = None,
        delete: typing.Optional[builtins.str] = None,
        read: typing.Optional[builtins.str] = None,
        update: typing.Optional[builtins.str] = None,
    ) -> None:
        """
        :param create: 
        :param delete: 
        :param read: 
        :param update: 
        """
        self._values: typing.Dict[str, typing.Any] = {}
        if create is not None:
            self._values["create"] = create
        if delete is not None:
            self._values["delete"] = delete
        if read is not None:
            self._values["read"] = read
        if update is not None:
            self._values["update"] = update

    @builtins.property
    def create(self) -> typing.Optional[builtins.str]:
        result = self._values.get("create")
        return result

    @builtins.property
    def delete(self) -> typing.Optional[builtins.str]:
        result = self._values.get("delete")
        return result

    @builtins.property
    def read(self) -> typing.Optional[builtins.str]:
        result = self._values.get("read")
        return result

    @builtins.property
    def update(self) -> typing.Optional[builtins.str]:
        result = self._values.get("update")
        return result

    def __eq__(self, rhs: typing.Any) -> builtins.bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs: typing.Any) -> builtins.bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return "PublicIpPrefixTimeouts(%s)" % ", ".join(
            k + "=" + repr(v) for k, v in self._values.items()
        )


@jsii.data_type(
    jsii_type="@cdktf/provider-azurerm.PublicIpTimeouts",
    jsii_struct_bases=[],
    name_mapping={
        "create": "create",
        "delete": "delete",
        "read": "read",
        "update": "update",
    },
)
class PublicIpTimeouts:
    def __init__(
        self,
        *,
        create: typing.Optional[builtins.str] = None,
        delete: typing.Optional[builtins.str] = None,
        read: typing.Optional[builtins.str] = None,
        update: typing.Optional[builtins.str] = None,
    ) -> None:
        """
        :param create: 
        :param delete: 
        :param read: 
        :param update: 
        """
        self._values: typing.Dict[str, typing.Any] = {}
        if create is not None:
            self._values["create"] = create
        if delete is not None:
            self._values["delete"] = delete
        if read is not None:
            self._values["read"] = read
        if update is not None:
            self._values["update"] = update

    @builtins.property
    def create(self) -> typing.Optional[builtins.str]:
        result = self._values.get("create")
        return result

    @builtins.property
    def delete(self) -> typing.Optional[builtins.str]:
        result = self._values.get("delete")
        return result

    @builtins.property
    def read(self) -> typing.Optional[builtins.str]:
        result = self._values.get("read")
        return result

    @builtins.property
    def update(self) -> typing.Optional[builtins.str]:
        result = self._values.get("update")
        return result

    def __eq__(self, rhs: typing.Any) -> builtins.bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs: typing.Any) -> builtins.bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return "PublicIpTimeouts(%s)" % ", ".join(
            k + "=" + repr(v) for k, v in self._values.items()
        )


class RecoveryServicesVault(
    cdktf.TerraformResource,
    metaclass=jsii.JSIIMeta,
    jsii_type="@cdktf/provider-azurerm.RecoveryServicesVault",
):
    def __init__(
        self,
        scope: constructs.Construct,
        id: builtins.str,
        *,
        location: builtins.str,
        name: builtins.str,
        resource_group_name: builtins.str,
        sku: builtins.str,
        soft_delete_enabled: typing.Optional[builtins.bool] = None,
        tags: typing.Optional[typing.Mapping[builtins.str, builtins.str]] = None,
        timeouts: typing.Optional["RecoveryServicesVaultTimeouts"] = None,
        count: typing.Optional[jsii.Number] = None,
        depends_on: typing.Optional[typing.List[cdktf.TerraformResource]] = None,
        lifecycle: typing.Optional[cdktf.TerraformResourceLifecycle] = None,
        provider: typing.Optional[cdktf.TerraformProvider] = None,
    ) -> None:
        """
        :param scope: -
        :param id: -
        :param location: 
        :param name: 
        :param resource_group_name: 
        :param sku: 
        :param soft_delete_enabled: 
        :param tags: 
        :param timeouts: timeouts block.
        :param count: 
        :param depends_on: 
        :param lifecycle: 
        :param provider: 
        """
        config = RecoveryServicesVaultConfig(
            location=location,
            name=name,
            resource_group_name=resource_group_name,
            sku=sku,
            soft_delete_enabled=soft_delete_enabled,
            tags=tags,
            timeouts=timeouts,
            count=count,
            depends_on=depends_on,
            lifecycle=lifecycle,
            provider=provider,
        )

        jsii.create(RecoveryServicesVault, self, [scope, id, config])

    @jsii.member(jsii_name="synthesizeAttributes")
    def _synthesize_attributes(self) -> typing.Mapping[builtins.str, typing.Any]:
        return jsii.invoke(self, "synthesizeAttributes", [])

    @builtins.property # type: ignore
    @jsii.member(jsii_name="location")
    def location(self) -> builtins.str:
        return jsii.get(self, "location")

    @location.setter # type: ignore
    def location(self, value: builtins.str) -> None:
        jsii.set(self, "location", value)

    @builtins.property # type: ignore
    @jsii.member(jsii_name="name")
    def name(self) -> builtins.str:
        return jsii.get(self, "name")

    @name.setter # type: ignore
    def name(self, value: builtins.str) -> None:
        jsii.set(self, "name", value)

    @builtins.property # type: ignore
    @jsii.member(jsii_name="resourceGroupName")
    def resource_group_name(self) -> builtins.str:
        return jsii.get(self, "resourceGroupName")

    @resource_group_name.setter # type: ignore
    def resource_group_name(self, value: builtins.str) -> None:
        jsii.set(self, "resourceGroupName", value)

    @builtins.property # type: ignore
    @jsii.member(jsii_name="sku")
    def sku(self) -> builtins.str:
        return jsii.get(self, "sku")

    @sku.setter # type: ignore
    def sku(self, value: builtins.str) -> None:
        jsii.set(self, "sku", value)

    @builtins.property # type: ignore
    @jsii.member(jsii_name="id")
    def id(self) -> typing.Optional[builtins.str]:
        return jsii.get(self, "id")

    @id.setter # type: ignore
    def id(self, value: typing.Optional[builtins.str]) -> None:
        jsii.set(self, "id", value)

    @builtins.property # type: ignore
    @jsii.member(jsii_name="softDeleteEnabled")
    def soft_delete_enabled(self) -> typing.Optional[builtins.bool]:
        return jsii.get(self, "softDeleteEnabled")

    @soft_delete_enabled.setter # type: ignore
    def soft_delete_enabled(self, value: typing.Optional[builtins.bool]) -> None:
        jsii.set(self, "softDeleteEnabled", value)

    @builtins.property # type: ignore
    @jsii.member(jsii_name="tags")
    def tags(self) -> typing.Optional[typing.Mapping[builtins.str, builtins.str]]:
        return jsii.get(self, "tags")

    @tags.setter # type: ignore
    def tags(
        self,
        value: typing.Optional[typing.Mapping[builtins.str, builtins.str]],
    ) -> None:
        jsii.set(self, "tags", value)

    @builtins.property # type: ignore
    @jsii.member(jsii_name="timeouts")
    def timeouts(self) -> typing.Optional["RecoveryServicesVaultTimeouts"]:
        return jsii.get(self, "timeouts")

    @timeouts.setter # type: ignore
    def timeouts(self, value: typing.Optional["RecoveryServicesVaultTimeouts"]) -> None:
        jsii.set(self, "timeouts", value)


@jsii.data_type(
    jsii_type="@cdktf/provider-azurerm.RecoveryServicesVaultConfig",
    jsii_struct_bases=[cdktf.TerraformMetaArguments],
    name_mapping={
        "count": "count",
        "depends_on": "dependsOn",
        "lifecycle": "lifecycle",
        "provider": "provider",
        "location": "location",
        "name": "name",
        "resource_group_name": "resourceGroupName",
        "sku": "sku",
        "soft_delete_enabled": "softDeleteEnabled",
        "tags": "tags",
        "timeouts": "timeouts",
    },
)
class RecoveryServicesVaultConfig(cdktf.TerraformMetaArguments):
    def __init__(
        self,
        *,
        count: typing.Optional[jsii.Number] = None,
        depends_on: typing.Optional[typing.List[cdktf.TerraformResource]] = None,
        lifecycle: typing.Optional[cdktf.TerraformResourceLifecycle] = None,
        provider: typing.Optional[cdktf.TerraformProvider] = None,
        location: builtins.str,
        name: builtins.str,
        resource_group_name: builtins.str,
        sku: builtins.str,
        soft_delete_enabled: typing.Optional[builtins.bool] = None,
        tags: typing.Optional[typing.Mapping[builtins.str, builtins.str]] = None,
        timeouts: typing.Optional["RecoveryServicesVaultTimeouts"] = None,
    ) -> None:
        """
        :param count: 
        :param depends_on: 
        :param lifecycle: 
        :param provider: 
        :param location: 
        :param name: 
        :param resource_group_name: 
        :param sku: 
        :param soft_delete_enabled: 
        :param tags: 
        :param timeouts: timeouts block.
        """
        if isinstance(lifecycle, dict):
            lifecycle = cdktf.TerraformResourceLifecycle(**lifecycle)
        if isinstance(timeouts, dict):
            timeouts = RecoveryServicesVaultTimeouts(**timeouts)
        self._values: typing.Dict[str, typing.Any] = {
            "location": location,
            "name": name,
            "resource_group_name": resource_group_name,
            "sku": sku,
        }
        if count is not None:
            self._values["count"] = count
        if depends_on is not None:
            self._values["depends_on"] = depends_on
        if lifecycle is not None:
            self._values["lifecycle"] = lifecycle
        if provider is not None:
            self._values["provider"] = provider
        if soft_delete_enabled is not None:
            self._values["soft_delete_enabled"] = soft_delete_enabled
        if tags is not None:
            self._values["tags"] = tags
        if timeouts is not None:
            self._values["timeouts"] = timeouts

    @builtins.property
    def count(self) -> typing.Optional[jsii.Number]:
        """
        :stability: experimental
        """
        result = self._values.get("count")
        return result

    @builtins.property
    def depends_on(self) -> typing.Optional[typing.List[cdktf.TerraformResource]]:
        """
        :stability: experimental
        """
        result = self._values.get("depends_on")
        return result

    @builtins.property
    def lifecycle(self) -> typing.Optional[cdktf.TerraformResourceLifecycle]:
        """
        :stability: experimental
        """
        result = self._values.get("lifecycle")
        return result

    @builtins.property
    def provider(self) -> typing.Optional[cdktf.TerraformProvider]:
        """
        :stability: experimental
        """
        result = self._values.get("provider")
        return result

    @builtins.property
    def location(self) -> builtins.str:
        result = self._values.get("location")
        assert result is not None, "Required property 'location' is missing"
        return result

    @builtins.property
    def name(self) -> builtins.str:
        result = self._values.get("name")
        assert result is not None, "Required property 'name' is missing"
        return result

    @builtins.property
    def resource_group_name(self) -> builtins.str:
        result = self._values.get("resource_group_name")
        assert result is not None, "Required property 'resource_group_name' is missing"
        return result

    @builtins.property
    def sku(self) -> builtins.str:
        result = self._values.get("sku")
        assert result is not None, "Required property 'sku' is missing"
        return result

    @builtins.property
    def soft_delete_enabled(self) -> typing.Optional[builtins.bool]:
        result = self._values.get("soft_delete_enabled")
        return result

    @builtins.property
    def tags(self) -> typing.Optional[typing.Mapping[builtins.str, builtins.str]]:
        result = self._values.get("tags")
        return result

    @builtins.property
    def timeouts(self) -> typing.Optional["RecoveryServicesVaultTimeouts"]:
        """timeouts block."""
        result = self._values.get("timeouts")
        return result

    def __eq__(self, rhs: typing.Any) -> builtins.bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs: typing.Any) -> builtins.bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return "RecoveryServicesVaultConfig(%s)" % ", ".join(
            k + "=" + repr(v) for k, v in self._values.items()
        )


@jsii.data_type(
    jsii_type="@cdktf/provider-azurerm.RecoveryServicesVaultTimeouts",
    jsii_struct_bases=[],
    name_mapping={
        "create": "create",
        "delete": "delete",
        "read": "read",
        "update": "update",
    },
)
class RecoveryServicesVaultTimeouts:
    def __init__(
        self,
        *,
        create: typing.Optional[builtins.str] = None,
        delete: typing.Optional[builtins.str] = None,
        read: typing.Optional[builtins.str] = None,
        update: typing.Optional[builtins.str] = None,
    ) -> None:
        """
        :param create: 
        :param delete: 
        :param read: 
        :param update: 
        """
        self._values: typing.Dict[str, typing.Any] = {}
        if create is not None:
            self._values["create"] = create
        if delete is not None:
            self._values["delete"] = delete
        if read is not None:
            self._values["read"] = read
        if update is not None:
            self._values["update"] = update

    @builtins.property
    def create(self) -> typing.Optional[builtins.str]:
        result = self._values.get("create")
        return result

    @builtins.property
    def delete(self) -> typing.Optional[builtins.str]:
        result = self._values.get("delete")
        return result

    @builtins.property
    def read(self) -> typing.Optional[builtins.str]:
        result = self._values.get("read")
        return result

    @builtins.property
    def update(self) -> typing.Optional[builtins.str]:
        result = self._values.get("update")
        return result

    def __eq__(self, rhs: typing.Any) -> builtins.bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs: typing.Any) -> builtins.bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return "RecoveryServicesVaultTimeouts(%s)" % ", ".join(
            k + "=" + repr(v) for k, v in self._values.items()
        )


class RedisCache(
    cdktf.TerraformResource,
    metaclass=jsii.JSIIMeta,
    jsii_type="@cdktf/provider-azurerm.RedisCache",
):
    def __init__(
        self,
        scope: constructs.Construct,
        id: builtins.str,
        *,
        capacity: jsii.Number,
        family: builtins.str,
        location: builtins.str,
        name: builtins.str,
        resource_group_name: builtins.str,
        sku_name: builtins.str,
        enable_non_ssl_port: typing.Optional[builtins.bool] = None,
        minimum_tls_version: typing.Optional[builtins.str] = None,
        patch_schedule: typing.Optional[typing.List["RedisCachePatchSchedule"]] = None,
        private_static_ip_address: typing.Optional[builtins.str] = None,
        redis_configuration: typing.Optional[typing.List["RedisCacheRedisConfiguration"]] = None,
        shard_count: typing.Optional[jsii.Number] = None,
        subnet_id: typing.Optional[builtins.str] = None,
        tags: typing.Optional[typing.Mapping[builtins.str, builtins.str]] = None,
        timeouts: typing.Optional["RedisCacheTimeouts"] = None,
        zones: typing.Optional[typing.List[builtins.str]] = None,
        count: typing.Optional[jsii.Number] = None,
        depends_on: typing.Optional[typing.List[cdktf.TerraformResource]] = None,
        lifecycle: typing.Optional[cdktf.TerraformResourceLifecycle] = None,
        provider: typing.Optional[cdktf.TerraformProvider] = None,
    ) -> None:
        """
        :param scope: -
        :param id: -
        :param capacity: 
        :param family: 
        :param location: 
        :param name: 
        :param resource_group_name: 
        :param sku_name: 
        :param enable_non_ssl_port: 
        :param minimum_tls_version: 
        :param patch_schedule: patch_schedule block.
        :param private_static_ip_address: 
        :param redis_configuration: redis_configuration block.
        :param shard_count: 
        :param subnet_id: 
        :param tags: 
        :param timeouts: timeouts block.
        :param zones: 
        :param count: 
        :param depends_on: 
        :param lifecycle: 
        :param provider: 
        """
        config = RedisCacheConfig(
            capacity=capacity,
            family=family,
            location=location,
            name=name,
            resource_group_name=resource_group_name,
            sku_name=sku_name,
            enable_non_ssl_port=enable_non_ssl_port,
            minimum_tls_version=minimum_tls_version,
            patch_schedule=patch_schedule,
            private_static_ip_address=private_static_ip_address,
            redis_configuration=redis_configuration,
            shard_count=shard_count,
            subnet_id=subnet_id,
            tags=tags,
            timeouts=timeouts,
            zones=zones,
            count=count,
            depends_on=depends_on,
            lifecycle=lifecycle,
            provider=provider,
        )

        jsii.create(RedisCache, self, [scope, id, config])

    @jsii.member(jsii_name="synthesizeAttributes")
    def _synthesize_attributes(self) -> typing.Mapping[builtins.str, typing.Any]:
        return jsii.invoke(self, "synthesizeAttributes", [])

    @builtins.property # type: ignore
    @jsii.member(jsii_name="hostname")
    def hostname(self) -> builtins.str:
        return jsii.get(self, "hostname")

    @builtins.property # type: ignore
    @jsii.member(jsii_name="port")
    def port(self) -> jsii.Number:
        return jsii.get(self, "port")

    @builtins.property # type: ignore
    @jsii.member(jsii_name="primaryAccessKey")
    def primary_access_key(self) -> builtins.str:
        return jsii.get(self, "primaryAccessKey")

    @builtins.property # type: ignore
    @jsii.member(jsii_name="secondaryAccessKey")
    def secondary_access_key(self) -> builtins.str:
        return jsii.get(self, "secondaryAccessKey")

    @builtins.property # type: ignore
    @jsii.member(jsii_name="sslPort")
    def ssl_port(self) -> jsii.Number:
        return jsii.get(self, "sslPort")

    @builtins.property # type: ignore
    @jsii.member(jsii_name="capacity")
    def capacity(self) -> jsii.Number:
        return jsii.get(self, "capacity")

    @capacity.setter # type: ignore
    def capacity(self, value: jsii.Number) -> None:
        jsii.set(self, "capacity", value)

    @builtins.property # type: ignore
    @jsii.member(jsii_name="family")
    def family(self) -> builtins.str:
        return jsii.get(self, "family")

    @family.setter # type: ignore
    def family(self, value: builtins.str) -> None:
        jsii.set(self, "family", value)

    @builtins.property # type: ignore
    @jsii.member(jsii_name="location")
    def location(self) -> builtins.str:
        return jsii.get(self, "location")

    @location.setter # type: ignore
    def location(self, value: builtins.str) -> None:
        jsii.set(self, "location", value)

    @builtins.property # type: ignore
    @jsii.member(jsii_name="name")
    def name(self) -> builtins.str:
        return jsii.get(self, "name")

    @name.setter # type: ignore
    def name(self, value: builtins.str) -> None:
        jsii.set(self, "name", value)

    @builtins.property # type: ignore
    @jsii.member(jsii_name="resourceGroupName")
    def resource_group_name(self) -> builtins.str:
        return jsii.get(self, "resourceGroupName")

    @resource_group_name.setter # type: ignore
    def resource_group_name(self, value: builtins.str) -> None:
        jsii.set(self, "resourceGroupName", value)

    @builtins.property # type: ignore
    @jsii.member(jsii_name="skuName")
    def sku_name(self) -> builtins.str:
        return jsii.get(self, "skuName")

    @sku_name.setter # type: ignore
    def sku_name(self, value: builtins.str) -> None:
        jsii.set(self, "skuName", value)

    @builtins.property # type: ignore
    @jsii.member(jsii_name="enableNonSslPort")
    def enable_non_ssl_port(self) -> typing.Optional[builtins.bool]:
        return jsii.get(self, "enableNonSslPort")

    @enable_non_ssl_port.setter # type: ignore
    def enable_non_ssl_port(self, value: typing.Optional[builtins.bool]) -> None:
        jsii.set(self, "enableNonSslPort", value)

    @builtins.property # type: ignore
    @jsii.member(jsii_name="id")
    def id(self) -> typing.Optional[builtins.str]:
        return jsii.get(self, "id")

    @id.setter # type: ignore
    def id(self, value: typing.Optional[builtins.str]) -> None:
        jsii.set(self, "id", value)

    @builtins.property # type: ignore
    @jsii.member(jsii_name="minimumTlsVersion")
    def minimum_tls_version(self) -> typing.Optional[builtins.str]:
        return jsii.get(self, "minimumTlsVersion")

    @minimum_tls_version.setter # type: ignore
    def minimum_tls_version(self, value: typing.Optional[builtins.str]) -> None:
        jsii.set(self, "minimumTlsVersion", value)

    @builtins.property # type: ignore
    @jsii.member(jsii_name="patchSchedule")
    def patch_schedule(self) -> typing.Optional[typing.List["RedisCachePatchSchedule"]]:
        return jsii.get(self, "patchSchedule")

    @patch_schedule.setter # type: ignore
    def patch_schedule(
        self,
        value: typing.Optional[typing.List["RedisCachePatchSchedule"]],
    ) -> None:
        jsii.set(self, "patchSchedule", value)

    @builtins.property # type: ignore
    @jsii.member(jsii_name="privateStaticIpAddress")
    def private_static_ip_address(self) -> typing.Optional[builtins.str]:
        return jsii.get(self, "privateStaticIpAddress")

    @private_static_ip_address.setter # type: ignore
    def private_static_ip_address(self, value: typing.Optional[builtins.str]) -> None:
        jsii.set(self, "privateStaticIpAddress", value)

    @builtins.property # type: ignore
    @jsii.member(jsii_name="redisConfiguration")
    def redis_configuration(
        self,
    ) -> typing.Optional[typing.List["RedisCacheRedisConfiguration"]]:
        return jsii.get(self, "redisConfiguration")

    @redis_configuration.setter # type: ignore
    def redis_configuration(
        self,
        value: typing.Optional[typing.List["RedisCacheRedisConfiguration"]],
    ) -> None:
        jsii.set(self, "redisConfiguration", value)

    @builtins.property # type: ignore
    @jsii.member(jsii_name="shardCount")
    def shard_count(self) -> typing.Optional[jsii.Number]:
        return jsii.get(self, "shardCount")

    @shard_count.setter # type: ignore
    def shard_count(self, value: typing.Optional[jsii.Number]) -> None:
        jsii.set(self, "shardCount", value)

    @builtins.property # type: ignore
    @jsii.member(jsii_name="subnetId")
    def subnet_id(self) -> typing.Optional[builtins.str]:
        return jsii.get(self, "subnetId")

    @subnet_id.setter # type: ignore
    def subnet_id(self, value: typing.Optional[builtins.str]) -> None:
        jsii.set(self, "subnetId", value)

    @builtins.property # type: ignore
    @jsii.member(jsii_name="tags")
    def tags(self) -> typing.Optional[typing.Mapping[builtins.str, builtins.str]]:
        return jsii.get(self, "tags")

    @tags.setter # type: ignore
    def tags(
        self,
        value: typing.Optional[typing.Mapping[builtins.str, builtins.str]],
    ) -> None:
        jsii.set(self, "tags", value)

    @builtins.property # type: ignore
    @jsii.member(jsii_name="timeouts")
    def timeouts(self) -> typing.Optional["RedisCacheTimeouts"]:
        return jsii.get(self, "timeouts")

    @timeouts.setter # type: ignore
    def timeouts(self, value: typing.Optional["RedisCacheTimeouts"]) -> None:
        jsii.set(self, "timeouts", value)

    @builtins.property # type: ignore
    @jsii.member(jsii_name="zones")
    def zones(self) -> typing.Optional[typing.List[builtins.str]]:
        return jsii.get(self, "zones")

    @zones.setter # type: ignore
    def zones(self, value: typing.Optional[typing.List[builtins.str]]) -> None:
        jsii.set(self, "zones", value)


@jsii.data_type(
    jsii_type="@cdktf/provider-azurerm.RedisCacheConfig",
    jsii_struct_bases=[cdktf.TerraformMetaArguments],
    name_mapping={
        "count": "count",
        "depends_on": "dependsOn",
        "lifecycle": "lifecycle",
        "provider": "provider",
        "capacity": "capacity",
        "family": "family",
        "location": "location",
        "name": "name",
        "resource_group_name": "resourceGroupName",
        "sku_name": "skuName",
        "enable_non_ssl_port": "enableNonSslPort",
        "minimum_tls_version": "minimumTlsVersion",
        "patch_schedule": "patchSchedule",
        "private_static_ip_address": "privateStaticIpAddress",
        "redis_configuration": "redisConfiguration",
        "shard_count": "shardCount",
        "subnet_id": "subnetId",
        "tags": "tags",
        "timeouts": "timeouts",
        "zones": "zones",
    },
)
class RedisCacheConfig(cdktf.TerraformMetaArguments):
    def __init__(
        self,
        *,
        count: typing.Optional[jsii.Number] = None,
        depends_on: typing.Optional[typing.List[cdktf.TerraformResource]] = None,
        lifecycle: typing.Optional[cdktf.TerraformResourceLifecycle] = None,
        provider: typing.Optional[cdktf.TerraformProvider] = None,
        capacity: jsii.Number,
        family: builtins.str,
        location: builtins.str,
        name: builtins.str,
        resource_group_name: builtins.str,
        sku_name: builtins.str,
        enable_non_ssl_port: typing.Optional[builtins.bool] = None,
        minimum_tls_version: typing.Optional[builtins.str] = None,
        patch_schedule: typing.Optional[typing.List["RedisCachePatchSchedule"]] = None,
        private_static_ip_address: typing.Optional[builtins.str] = None,
        redis_configuration: typing.Optional[typing.List["RedisCacheRedisConfiguration"]] = None,
        shard_count: typing.Optional[jsii.Number] = None,
        subnet_id: typing.Optional[builtins.str] = None,
        tags: typing.Optional[typing.Mapping[builtins.str, builtins.str]] = None,
        timeouts: typing.Optional["RedisCacheTimeouts"] = None,
        zones: typing.Optional[typing.List[builtins.str]] = None,
    ) -> None:
        """
        :param count: 
        :param depends_on: 
        :param lifecycle: 
        :param provider: 
        :param capacity: 
        :param family: 
        :param location: 
        :param name: 
        :param resource_group_name: 
        :param sku_name: 
        :param enable_non_ssl_port: 
        :param minimum_tls_version: 
        :param patch_schedule: patch_schedule block.
        :param private_static_ip_address: 
        :param redis_configuration: redis_configuration block.
        :param shard_count: 
        :param subnet_id: 
        :param tags: 
        :param timeouts: timeouts block.
        :param zones: 
        """
        if isinstance(lifecycle, dict):
            lifecycle = cdktf.TerraformResourceLifecycle(**lifecycle)
        if isinstance(timeouts, dict):
            timeouts = RedisCacheTimeouts(**timeouts)
        self._values: typing.Dict[str, typing.Any] = {
            "capacity": capacity,
            "family": family,
            "location": location,
            "name": name,
            "resource_group_name": resource_group_name,
            "sku_name": sku_name,
        }
        if count is not None:
            self._values["count"] = count
        if depends_on is not None:
            self._values["depends_on"] = depends_on
        if lifecycle is not None:
            self._values["lifecycle"] = lifecycle
        if provider is not None:
            self._values["provider"] = provider
        if enable_non_ssl_port is not None:
            self._values["enable_non_ssl_port"] = enable_non_ssl_port
        if minimum_tls_version is not None:
            self._values["minimum_tls_version"] = minimum_tls_version
        if patch_schedule is not None:
            self._values["patch_schedule"] = patch_schedule
        if private_static_ip_address is not None:
            self._values["private_static_ip_address"] = private_static_ip_address
        if redis_configuration is not None:
            self._values["redis_configuration"] = redis_configuration
        if shard_count is not None:
            self._values["shard_count"] = shard_count
        if subnet_id is not None:
            self._values["subnet_id"] = subnet_id
        if tags is not None:
            self._values["tags"] = tags
        if timeouts is not None:
            self._values["timeouts"] = timeouts
        if zones is not None:
            self._values["zones"] = zones

    @builtins.property
    def count(self) -> typing.Optional[jsii.Number]:
        """
        :stability: experimental
        """
        result = self._values.get("count")
        return result

    @builtins.property
    def depends_on(self) -> typing.Optional[typing.List[cdktf.TerraformResource]]:
        """
        :stability: experimental
        """
        result = self._values.get("depends_on")
        return result

    @builtins.property
    def lifecycle(self) -> typing.Optional[cdktf.TerraformResourceLifecycle]:
        """
        :stability: experimental
        """
        result = self._values.get("lifecycle")
        return result

    @builtins.property
    def provider(self) -> typing.Optional[cdktf.TerraformProvider]:
        """
        :stability: experimental
        """
        result = self._values.get("provider")
        return result

    @builtins.property
    def capacity(self) -> jsii.Number:
        result = self._values.get("capacity")
        assert result is not None, "Required property 'capacity' is missing"
        return result

    @builtins.property
    def family(self) -> builtins.str:
        result = self._values.get("family")
        assert result is not None, "Required property 'family' is missing"
        return result

    @builtins.property
    def location(self) -> builtins.str:
        result = self._values.get("location")
        assert result is not None, "Required property 'location' is missing"
        return result

    @builtins.property
    def name(self) -> builtins.str:
        result = self._values.get("name")
        assert result is not None, "Required property 'name' is missing"
        return result

    @builtins.property
    def resource_group_name(self) -> builtins.str:
        result = self._values.get("resource_group_name")
        assert result is not None, "Required property 'resource_group_name' is missing"
        return result

    @builtins.property
    def sku_name(self) -> builtins.str:
        result = self._values.get("sku_name")
        assert result is not None, "Required property 'sku_name' is missing"
        return result

    @builtins.property
    def enable_non_ssl_port(self) -> typing.Optional[builtins.bool]:
        result = self._values.get("enable_non_ssl_port")
        return result

    @builtins.property
    def minimum_tls_version(self) -> typing.Optional[builtins.str]:
        result = self._values.get("minimum_tls_version")
        return result

    @builtins.property
    def patch_schedule(self) -> typing.Optional[typing.List["RedisCachePatchSchedule"]]:
        """patch_schedule block."""
        result = self._values.get("patch_schedule")
        return result

    @builtins.property
    def private_static_ip_address(self) -> typing.Optional[builtins.str]:
        result = self._values.get("private_static_ip_address")
        return result

    @builtins.property
    def redis_configuration(
        self,
    ) -> typing.Optional[typing.List["RedisCacheRedisConfiguration"]]:
        """redis_configuration block."""
        result = self._values.get("redis_configuration")
        return result

    @builtins.property
    def shard_count(self) -> typing.Optional[jsii.Number]:
        result = self._values.get("shard_count")
        return result

    @builtins.property
    def subnet_id(self) -> typing.Optional[builtins.str]:
        result = self._values.get("subnet_id")
        return result

    @builtins.property
    def tags(self) -> typing.Optional[typing.Mapping[builtins.str, builtins.str]]:
        result = self._values.get("tags")
        return result

    @builtins.property
    def timeouts(self) -> typing.Optional["RedisCacheTimeouts"]:
        """timeouts block."""
        result = self._values.get("timeouts")
        return result

    @builtins.property
    def zones(self) -> typing.Optional[typing.List[builtins.str]]:
        result = self._values.get("zones")
        return result

    def __eq__(self, rhs: typing.Any) -> builtins.bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs: typing.Any) -> builtins.bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return "RedisCacheConfig(%s)" % ", ".join(
            k + "=" + repr(v) for k, v in self._values.items()
        )


@jsii.data_type(
    jsii_type="@cdktf/provider-azurerm.RedisCachePatchSchedule",
    jsii_struct_bases=[],
    name_mapping={"day_of_week": "dayOfWeek", "start_hour_utc": "startHourUtc"},
)
class RedisCachePatchSchedule:
    def __init__(
        self,
        *,
        day_of_week: builtins.str,
        start_hour_utc: typing.Optional[jsii.Number] = None,
    ) -> None:
        """
        :param day_of_week: 
        :param start_hour_utc: 
        """
        self._values: typing.Dict[str, typing.Any] = {
            "day_of_week": day_of_week,
        }
        if start_hour_utc is not None:
            self._values["start_hour_utc"] = start_hour_utc

    @builtins.property
    def day_of_week(self) -> builtins.str:
        result = self._values.get("day_of_week")
        assert result is not None, "Required property 'day_of_week' is missing"
        return result

    @builtins.property
    def start_hour_utc(self) -> typing.Optional[jsii.Number]:
        result = self._values.get("start_hour_utc")
        return result

    def __eq__(self, rhs: typing.Any) -> builtins.bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs: typing.Any) -> builtins.bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return "RedisCachePatchSchedule(%s)" % ", ".join(
            k + "=" + repr(v) for k, v in self._values.items()
        )


@jsii.data_type(
    jsii_type="@cdktf/provider-azurerm.RedisCacheRedisConfiguration",
    jsii_struct_bases=[],
    name_mapping={
        "aof_backup_enabled": "aofBackupEnabled",
        "aof_storage_connection_string0": "aofStorageConnectionString0",
        "aof_storage_connection_string1": "aofStorageConnectionString1",
        "enable_authentication": "enableAuthentication",
        "maxfragmentationmemory_reserved": "maxfragmentationmemoryReserved",
        "maxmemory_delta": "maxmemoryDelta",
        "maxmemory_policy": "maxmemoryPolicy",
        "maxmemory_reserved": "maxmemoryReserved",
        "notify_keyspace_events": "notifyKeyspaceEvents",
        "rdb_backup_enabled": "rdbBackupEnabled",
        "rdb_backup_frequency": "rdbBackupFrequency",
        "rdb_backup_max_snapshot_count": "rdbBackupMaxSnapshotCount",
        "rdb_storage_connection_string": "rdbStorageConnectionString",
    },
)
class RedisCacheRedisConfiguration:
    def __init__(
        self,
        *,
        aof_backup_enabled: typing.Optional[builtins.bool] = None,
        aof_storage_connection_string0: typing.Optional[builtins.str] = None,
        aof_storage_connection_string1: typing.Optional[builtins.str] = None,
        enable_authentication: typing.Optional[builtins.bool] = None,
        maxfragmentationmemory_reserved: typing.Optional[jsii.Number] = None,
        maxmemory_delta: typing.Optional[jsii.Number] = None,
        maxmemory_policy: typing.Optional[builtins.str] = None,
        maxmemory_reserved: typing.Optional[jsii.Number] = None,
        notify_keyspace_events: typing.Optional[builtins.str] = None,
        rdb_backup_enabled: typing.Optional[builtins.bool] = None,
        rdb_backup_frequency: typing.Optional[jsii.Number] = None,
        rdb_backup_max_snapshot_count: typing.Optional[jsii.Number] = None,
        rdb_storage_connection_string: typing.Optional[builtins.str] = None,
    ) -> None:
        """
        :param aof_backup_enabled: 
        :param aof_storage_connection_string0: 
        :param aof_storage_connection_string1: 
        :param enable_authentication: 
        :param maxfragmentationmemory_reserved: 
        :param maxmemory_delta: 
        :param maxmemory_policy: 
        :param maxmemory_reserved: 
        :param notify_keyspace_events: 
        :param rdb_backup_enabled: 
        :param rdb_backup_frequency: 
        :param rdb_backup_max_snapshot_count: 
        :param rdb_storage_connection_string: 
        """
        self._values: typing.Dict[str, typing.Any] = {}
        if aof_backup_enabled is not None:
            self._values["aof_backup_enabled"] = aof_backup_enabled
        if aof_storage_connection_string0 is not None:
            self._values["aof_storage_connection_string0"] = aof_storage_connection_string0
        if aof_storage_connection_string1 is not None:
            self._values["aof_storage_connection_string1"] = aof_storage_connection_string1
        if enable_authentication is not None:
            self._values["enable_authentication"] = enable_authentication
        if maxfragmentationmemory_reserved is not None:
            self._values["maxfragmentationmemory_reserved"] = maxfragmentationmemory_reserved
        if maxmemory_delta is not None:
            self._values["maxmemory_delta"] = maxmemory_delta
        if maxmemory_policy is not None:
            self._values["maxmemory_policy"] = maxmemory_policy
        if maxmemory_reserved is not None:
            self._values["maxmemory_reserved"] = maxmemory_reserved
        if notify_keyspace_events is not None:
            self._values["notify_keyspace_events"] = notify_keyspace_events
        if rdb_backup_enabled is not None:
            self._values["rdb_backup_enabled"] = rdb_backup_enabled
        if rdb_backup_frequency is not None:
            self._values["rdb_backup_frequency"] = rdb_backup_frequency
        if rdb_backup_max_snapshot_count is not None:
            self._values["rdb_backup_max_snapshot_count"] = rdb_backup_max_snapshot_count
        if rdb_storage_connection_string is not None:
            self._values["rdb_storage_connection_string"] = rdb_storage_connection_string

    @builtins.property
    def aof_backup_enabled(self) -> typing.Optional[builtins.bool]:
        result = self._values.get("aof_backup_enabled")
        return result

    @builtins.property
    def aof_storage_connection_string0(self) -> typing.Optional[builtins.str]:
        result = self._values.get("aof_storage_connection_string0")
        return result

    @builtins.property
    def aof_storage_connection_string1(self) -> typing.Optional[builtins.str]:
        result = self._values.get("aof_storage_connection_string1")
        return result

    @builtins.property
    def enable_authentication(self) -> typing.Optional[builtins.bool]:
        result = self._values.get("enable_authentication")
        return result

    @builtins.property
    def maxfragmentationmemory_reserved(self) -> typing.Optional[jsii.Number]:
        result = self._values.get("maxfragmentationmemory_reserved")
        return result

    @builtins.property
    def maxmemory_delta(self) -> typing.Optional[jsii.Number]:
        result = self._values.get("maxmemory_delta")
        return result

    @builtins.property
    def maxmemory_policy(self) -> typing.Optional[builtins.str]:
        result = self._values.get("maxmemory_policy")
        return result

    @builtins.property
    def maxmemory_reserved(self) -> typing.Optional[jsii.Number]:
        result = self._values.get("maxmemory_reserved")
        return result

    @builtins.property
    def notify_keyspace_events(self) -> typing.Optional[builtins.str]:
        result = self._values.get("notify_keyspace_events")
        return result

    @builtins.property
    def rdb_backup_enabled(self) -> typing.Optional[builtins.bool]:
        result = self._values.get("rdb_backup_enabled")
        return result

    @builtins.property
    def rdb_backup_frequency(self) -> typing.Optional[jsii.Number]:
        result = self._values.get("rdb_backup_frequency")
        return result

    @builtins.property
    def rdb_backup_max_snapshot_count(self) -> typing.Optional[jsii.Number]:
        result = self._values.get("rdb_backup_max_snapshot_count")
        return result

    @builtins.property
    def rdb_storage_connection_string(self) -> typing.Optional[builtins.str]:
        result = self._values.get("rdb_storage_connection_string")
        return result

    def __eq__(self, rhs: typing.Any) -> builtins.bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs: typing.Any) -> builtins.bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return "RedisCacheRedisConfiguration(%s)" % ", ".join(
            k + "=" + repr(v) for k, v in self._values.items()
        )


@jsii.data_type(
    jsii_type="@cdktf/provider-azurerm.RedisCacheTimeouts",
    jsii_struct_bases=[],
    name_mapping={
        "create": "create",
        "delete": "delete",
        "read": "read",
        "update": "update",
    },
)
class RedisCacheTimeouts:
    def __init__(
        self,
        *,
        create: typing.Optional[builtins.str] = None,
        delete: typing.Optional[builtins.str] = None,
        read: typing.Optional[builtins.str] = None,
        update: typing.Optional[builtins.str] = None,
    ) -> None:
        """
        :param create: 
        :param delete: 
        :param read: 
        :param update: 
        """
        self._values: typing.Dict[str, typing.Any] = {}
        if create is not None:
            self._values["create"] = create
        if delete is not None:
            self._values["delete"] = delete
        if read is not None:
            self._values["read"] = read
        if update is not None:
            self._values["update"] = update

    @builtins.property
    def create(self) -> typing.Optional[builtins.str]:
        result = self._values.get("create")
        return result

    @builtins.property
    def delete(self) -> typing.Optional[builtins.str]:
        result = self._values.get("delete")
        return result

    @builtins.property
    def read(self) -> typing.Optional[builtins.str]:
        result = self._values.get("read")
        return result

    @builtins.property
    def update(self) -> typing.Optional[builtins.str]:
        result = self._values.get("update")
        return result

    def __eq__(self, rhs: typing.Any) -> builtins.bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs: typing.Any) -> builtins.bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return "RedisCacheTimeouts(%s)" % ", ".join(
            k + "=" + repr(v) for k, v in self._values.items()
        )


class RedisFirewallRule(
    cdktf.TerraformResource,
    metaclass=jsii.JSIIMeta,
    jsii_type="@cdktf/provider-azurerm.RedisFirewallRule",
):
    def __init__(
        self,
        scope: constructs.Construct,
        id: builtins.str,
        *,
        end_ip: builtins.str,
        name: builtins.str,
        redis_cache_name: builtins.str,
        resource_group_name: builtins.str,
        start_ip: builtins.str,
        timeouts: typing.Optional["RedisFirewallRuleTimeouts"] = None,
        count: typing.Optional[jsii.Number] = None,
        depends_on: typing.Optional[typing.List[cdktf.TerraformResource]] = None,
        lifecycle: typing.Optional[cdktf.TerraformResourceLifecycle] = None,
        provider: typing.Optional[cdktf.TerraformProvider] = None,
    ) -> None:
        """
        :param scope: -
        :param id: -
        :param end_ip: 
        :param name: 
        :param redis_cache_name: 
        :param resource_group_name: 
        :param start_ip: 
        :param timeouts: timeouts block.
        :param count: 
        :param depends_on: 
        :param lifecycle: 
        :param provider: 
        """
        config = RedisFirewallRuleConfig(
            end_ip=end_ip,
            name=name,
            redis_cache_name=redis_cache_name,
            resource_group_name=resource_group_name,
            start_ip=start_ip,
            timeouts=timeouts,
            count=count,
            depends_on=depends_on,
            lifecycle=lifecycle,
            provider=provider,
        )

        jsii.create(RedisFirewallRule, self, [scope, id, config])

    @jsii.member(jsii_name="synthesizeAttributes")
    def _synthesize_attributes(self) -> typing.Mapping[builtins.str, typing.Any]:
        return jsii.invoke(self, "synthesizeAttributes", [])

    @builtins.property # type: ignore
    @jsii.member(jsii_name="endIp")
    def end_ip(self) -> builtins.str:
        return jsii.get(self, "endIp")

    @end_ip.setter # type: ignore
    def end_ip(self, value: builtins.str) -> None:
        jsii.set(self, "endIp", value)

    @builtins.property # type: ignore
    @jsii.member(jsii_name="name")
    def name(self) -> builtins.str:
        return jsii.get(self, "name")

    @name.setter # type: ignore
    def name(self, value: builtins.str) -> None:
        jsii.set(self, "name", value)

    @builtins.property # type: ignore
    @jsii.member(jsii_name="redisCacheName")
    def redis_cache_name(self) -> builtins.str:
        return jsii.get(self, "redisCacheName")

    @redis_cache_name.setter # type: ignore
    def redis_cache_name(self, value: builtins.str) -> None:
        jsii.set(self, "redisCacheName", value)

    @builtins.property # type: ignore
    @jsii.member(jsii_name="resourceGroupName")
    def resource_group_name(self) -> builtins.str:
        return jsii.get(self, "resourceGroupName")

    @resource_group_name.setter # type: ignore
    def resource_group_name(self, value: builtins.str) -> None:
        jsii.set(self, "resourceGroupName", value)

    @builtins.property # type: ignore
    @jsii.member(jsii_name="startIp")
    def start_ip(self) -> builtins.str:
        return jsii.get(self, "startIp")

    @start_ip.setter # type: ignore
    def start_ip(self, value: builtins.str) -> None:
        jsii.set(self, "startIp", value)

    @builtins.property # type: ignore
    @jsii.member(jsii_name="id")
    def id(self) -> typing.Optional[builtins.str]:
        return jsii.get(self, "id")

    @id.setter # type: ignore
    def id(self, value: typing.Optional[builtins.str]) -> None:
        jsii.set(self, "id", value)

    @builtins.property # type: ignore
    @jsii.member(jsii_name="timeouts")
    def timeouts(self) -> typing.Optional["RedisFirewallRuleTimeouts"]:
        return jsii.get(self, "timeouts")

    @timeouts.setter # type: ignore
    def timeouts(self, value: typing.Optional["RedisFirewallRuleTimeouts"]) -> None:
        jsii.set(self, "timeouts", value)


@jsii.data_type(
    jsii_type="@cdktf/provider-azurerm.RedisFirewallRuleConfig",
    jsii_struct_bases=[cdktf.TerraformMetaArguments],
    name_mapping={
        "count": "count",
        "depends_on": "dependsOn",
        "lifecycle": "lifecycle",
        "provider": "provider",
        "end_ip": "endIp",
        "name": "name",
        "redis_cache_name": "redisCacheName",
        "resource_group_name": "resourceGroupName",
        "start_ip": "startIp",
        "timeouts": "timeouts",
    },
)
class RedisFirewallRuleConfig(cdktf.TerraformMetaArguments):
    def __init__(
        self,
        *,
        count: typing.Optional[jsii.Number] = None,
        depends_on: typing.Optional[typing.List[cdktf.TerraformResource]] = None,
        lifecycle: typing.Optional[cdktf.TerraformResourceLifecycle] = None,
        provider: typing.Optional[cdktf.TerraformProvider] = None,
        end_ip: builtins.str,
        name: builtins.str,
        redis_cache_name: builtins.str,
        resource_group_name: builtins.str,
        start_ip: builtins.str,
        timeouts: typing.Optional["RedisFirewallRuleTimeouts"] = None,
    ) -> None:
        """
        :param count: 
        :param depends_on: 
        :param lifecycle: 
        :param provider: 
        :param end_ip: 
        :param name: 
        :param redis_cache_name: 
        :param resource_group_name: 
        :param start_ip: 
        :param timeouts: timeouts block.
        """
        if isinstance(lifecycle, dict):
            lifecycle = cdktf.TerraformResourceLifecycle(**lifecycle)
        if isinstance(timeouts, dict):
            timeouts = RedisFirewallRuleTimeouts(**timeouts)
        self._values: typing.Dict[str, typing.Any] = {
            "end_ip": end_ip,
            "name": name,
            "redis_cache_name": redis_cache_name,
            "resource_group_name": resource_group_name,
            "start_ip": start_ip,
        }
        if count is not None:
            self._values["count"] = count
        if depends_on is not None:
            self._values["depends_on"] = depends_on
        if lifecycle is not None:
            self._values["lifecycle"] = lifecycle
        if provider is not None:
            self._values["provider"] = provider
        if timeouts is not None:
            self._values["timeouts"] = timeouts

    @builtins.property
    def count(self) -> typing.Optional[jsii.Number]:
        """
        :stability: experimental
        """
        result = self._values.get("count")
        return result

    @builtins.property
    def depends_on(self) -> typing.Optional[typing.List[cdktf.TerraformResource]]:
        """
        :stability: experimental
        """
        result = self._values.get("depends_on")
        return result

    @builtins.property
    def lifecycle(self) -> typing.Optional[cdktf.TerraformResourceLifecycle]:
        """
        :stability: experimental
        """
        result = self._values.get("lifecycle")
        return result

    @builtins.property
    def provider(self) -> typing.Optional[cdktf.TerraformProvider]:
        """
        :stability: experimental
        """
        result = self._values.get("provider")
        return result

    @builtins.property
    def end_ip(self) -> builtins.str:
        result = self._values.get("end_ip")
        assert result is not None, "Required property 'end_ip' is missing"
        return result

    @builtins.property
    def name(self) -> builtins.str:
        result = self._values.get("name")
        assert result is not None, "Required property 'name' is missing"
        return result

    @builtins.property
    def redis_cache_name(self) -> builtins.str:
        result = self._values.get("redis_cache_name")
        assert result is not None, "Required property 'redis_cache_name' is missing"
        return result

    @builtins.property
    def resource_group_name(self) -> builtins.str:
        result = self._values.get("resource_group_name")
        assert result is not None, "Required property 'resource_group_name' is missing"
        return result

    @builtins.property
    def start_ip(self) -> builtins.str:
        result = self._values.get("start_ip")
        assert result is not None, "Required property 'start_ip' is missing"
        return result

    @builtins.property
    def timeouts(self) -> typing.Optional["RedisFirewallRuleTimeouts"]:
        """timeouts block."""
        result = self._values.get("timeouts")
        return result

    def __eq__(self, rhs: typing.Any) -> builtins.bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs: typing.Any) -> builtins.bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return "RedisFirewallRuleConfig(%s)" % ", ".join(
            k + "=" + repr(v) for k, v in self._values.items()
        )


@jsii.data_type(
    jsii_type="@cdktf/provider-azurerm.RedisFirewallRuleTimeouts",
    jsii_struct_bases=[],
    name_mapping={
        "create": "create",
        "delete": "delete",
        "read": "read",
        "update": "update",
    },
)
class RedisFirewallRuleTimeouts:
    def __init__(
        self,
        *,
        create: typing.Optional[builtins.str] = None,
        delete: typing.Optional[builtins.str] = None,
        read: typing.Optional[builtins.str] = None,
        update: typing.Optional[builtins.str] = None,
    ) -> None:
        """
        :param create: 
        :param delete: 
        :param read: 
        :param update: 
        """
        self._values: typing.Dict[str, typing.Any] = {}
        if create is not None:
            self._values["create"] = create
        if delete is not None:
            self._values["delete"] = delete
        if read is not None:
            self._values["read"] = read
        if update is not None:
            self._values["update"] = update

    @builtins.property
    def create(self) -> typing.Optional[builtins.str]:
        result = self._values.get("create")
        return result

    @builtins.property
    def delete(self) -> typing.Optional[builtins.str]:
        result = self._values.get("delete")
        return result

    @builtins.property
    def read(self) -> typing.Optional[builtins.str]:
        result = self._values.get("read")
        return result

    @builtins.property
    def update(self) -> typing.Optional[builtins.str]:
        result = self._values.get("update")
        return result

    def __eq__(self, rhs: typing.Any) -> builtins.bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs: typing.Any) -> builtins.bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return "RedisFirewallRuleTimeouts(%s)" % ", ".join(
            k + "=" + repr(v) for k, v in self._values.items()
        )


class RelayHybridConnection(
    cdktf.TerraformResource,
    metaclass=jsii.JSIIMeta,
    jsii_type="@cdktf/provider-azurerm.RelayHybridConnection",
):
    def __init__(
        self,
        scope: constructs.Construct,
        id: builtins.str,
        *,
        name: builtins.str,
        relay_namespace_name: builtins.str,
        resource_group_name: builtins.str,
        requires_client_authorization: typing.Optional[builtins.bool] = None,
        timeouts: typing.Optional["RelayHybridConnectionTimeouts"] = None,
        user_metadata: typing.Optional[builtins.str] = None,
        count: typing.Optional[jsii.Number] = None,
        depends_on: typing.Optional[typing.List[cdktf.TerraformResource]] = None,
        lifecycle: typing.Optional[cdktf.TerraformResourceLifecycle] = None,
        provider: typing.Optional[cdktf.TerraformProvider] = None,
    ) -> None:
        """
        :param scope: -
        :param id: -
        :param name: 
        :param relay_namespace_name: 
        :param resource_group_name: 
        :param requires_client_authorization: 
        :param timeouts: timeouts block.
        :param user_metadata: 
        :param count: 
        :param depends_on: 
        :param lifecycle: 
        :param provider: 
        """
        config = RelayHybridConnectionConfig(
            name=name,
            relay_namespace_name=relay_namespace_name,
            resource_group_name=resource_group_name,
            requires_client_authorization=requires_client_authorization,
            timeouts=timeouts,
            user_metadata=user_metadata,
            count=count,
            depends_on=depends_on,
            lifecycle=lifecycle,
            provider=provider,
        )

        jsii.create(RelayHybridConnection, self, [scope, id, config])

    @jsii.member(jsii_name="synthesizeAttributes")
    def _synthesize_attributes(self) -> typing.Mapping[builtins.str, typing.Any]:
        return jsii.invoke(self, "synthesizeAttributes", [])

    @builtins.property # type: ignore
    @jsii.member(jsii_name="name")
    def name(self) -> builtins.str:
        return jsii.get(self, "name")

    @name.setter # type: ignore
    def name(self, value: builtins.str) -> None:
        jsii.set(self, "name", value)

    @builtins.property # type: ignore
    @jsii.member(jsii_name="relayNamespaceName")
    def relay_namespace_name(self) -> builtins.str:
        return jsii.get(self, "relayNamespaceName")

    @relay_namespace_name.setter # type: ignore
    def relay_namespace_name(self, value: builtins.str) -> None:
        jsii.set(self, "relayNamespaceName", value)

    @builtins.property # type: ignore
    @jsii.member(jsii_name="resourceGroupName")
    def resource_group_name(self) -> builtins.str:
        return jsii.get(self, "resourceGroupName")

    @resource_group_name.setter # type: ignore
    def resource_group_name(self, value: builtins.str) -> None:
        jsii.set(self, "resourceGroupName", value)

    @builtins.property # type: ignore
    @jsii.member(jsii_name="id")
    def id(self) -> typing.Optional[builtins.str]:
        return jsii.get(self, "id")

    @id.setter # type: ignore
    def id(self, value: typing.Optional[builtins.str]) -> None:
        jsii.set(self, "id", value)

    @builtins.property # type: ignore
    @jsii.member(jsii_name="requiresClientAuthorization")
    def requires_client_authorization(self) -> typing.Optional[builtins.bool]:
        return jsii.get(self, "requiresClientAuthorization")

    @requires_client_authorization.setter # type: ignore
    def requires_client_authorization(
        self,
        value: typing.Optional[builtins.bool],
    ) -> None:
        jsii.set(self, "requiresClientAuthorization", value)

    @builtins.property # type: ignore
    @jsii.member(jsii_name="timeouts")
    def timeouts(self) -> typing.Optional["RelayHybridConnectionTimeouts"]:
        return jsii.get(self, "timeouts")

    @timeouts.setter # type: ignore
    def timeouts(self, value: typing.Optional["RelayHybridConnectionTimeouts"]) -> None:
        jsii.set(self, "timeouts", value)

    @builtins.property # type: ignore
    @jsii.member(jsii_name="userMetadata")
    def user_metadata(self) -> typing.Optional[builtins.str]:
        return jsii.get(self, "userMetadata")

    @user_metadata.setter # type: ignore
    def user_metadata(self, value: typing.Optional[builtins.str]) -> None:
        jsii.set(self, "userMetadata", value)


@jsii.data_type(
    jsii_type="@cdktf/provider-azurerm.RelayHybridConnectionConfig",
    jsii_struct_bases=[cdktf.TerraformMetaArguments],
    name_mapping={
        "count": "count",
        "depends_on": "dependsOn",
        "lifecycle": "lifecycle",
        "provider": "provider",
        "name": "name",
        "relay_namespace_name": "relayNamespaceName",
        "resource_group_name": "resourceGroupName",
        "requires_client_authorization": "requiresClientAuthorization",
        "timeouts": "timeouts",
        "user_metadata": "userMetadata",
    },
)
class RelayHybridConnectionConfig(cdktf.TerraformMetaArguments):
    def __init__(
        self,
        *,
        count: typing.Optional[jsii.Number] = None,
        depends_on: typing.Optional[typing.List[cdktf.TerraformResource]] = None,
        lifecycle: typing.Optional[cdktf.TerraformResourceLifecycle] = None,
        provider: typing.Optional[cdktf.TerraformProvider] = None,
        name: builtins.str,
        relay_namespace_name: builtins.str,
        resource_group_name: builtins.str,
        requires_client_authorization: typing.Optional[builtins.bool] = None,
        timeouts: typing.Optional["RelayHybridConnectionTimeouts"] = None,
        user_metadata: typing.Optional[builtins.str] = None,
    ) -> None:
        """
        :param count: 
        :param depends_on: 
        :param lifecycle: 
        :param provider: 
        :param name: 
        :param relay_namespace_name: 
        :param resource_group_name: 
        :param requires_client_authorization: 
        :param timeouts: timeouts block.
        :param user_metadata: 
        """
        if isinstance(lifecycle, dict):
            lifecycle = cdktf.TerraformResourceLifecycle(**lifecycle)
        if isinstance(timeouts, dict):
            timeouts = RelayHybridConnectionTimeouts(**timeouts)
        self._values: typing.Dict[str, typing.Any] = {
            "name": name,
            "relay_namespace_name": relay_namespace_name,
            "resource_group_name": resource_group_name,
        }
        if count is not None:
            self._values["count"] = count
        if depends_on is not None:
            self._values["depends_on"] = depends_on
        if lifecycle is not None:
            self._values["lifecycle"] = lifecycle
        if provider is not None:
            self._values["provider"] = provider
        if requires_client_authorization is not None:
            self._values["requires_client_authorization"] = requires_client_authorization
        if timeouts is not None:
            self._values["timeouts"] = timeouts
        if user_metadata is not None:
            self._values["user_metadata"] = user_metadata

    @builtins.property
    def count(self) -> typing.Optional[jsii.Number]:
        """
        :stability: experimental
        """
        result = self._values.get("count")
        return result

    @builtins.property
    def depends_on(self) -> typing.Optional[typing.List[cdktf.TerraformResource]]:
        """
        :stability: experimental
        """
        result = self._values.get("depends_on")
        return result

    @builtins.property
    def lifecycle(self) -> typing.Optional[cdktf.TerraformResourceLifecycle]:
        """
        :stability: experimental
        """
        result = self._values.get("lifecycle")
        return result

    @builtins.property
    def provider(self) -> typing.Optional[cdktf.TerraformProvider]:
        """
        :stability: experimental
        """
        result = self._values.get("provider")
        return result

    @builtins.property
    def name(self) -> builtins.str:
        result = self._values.get("name")
        assert result is not None, "Required property 'name' is missing"
        return result

    @builtins.property
    def relay_namespace_name(self) -> builtins.str:
        result = self._values.get("relay_namespace_name")
        assert result is not None, "Required property 'relay_namespace_name' is missing"
        return result

    @builtins.property
    def resource_group_name(self) -> builtins.str:
        result = self._values.get("resource_group_name")
        assert result is not None, "Required property 'resource_group_name' is missing"
        return result

    @builtins.property
    def requires_client_authorization(self) -> typing.Optional[builtins.bool]:
        result = self._values.get("requires_client_authorization")
        return result

    @builtins.property
    def timeouts(self) -> typing.Optional["RelayHybridConnectionTimeouts"]:
        """timeouts block."""
        result = self._values.get("timeouts")
        return result

    @builtins.property
    def user_metadata(self) -> typing.Optional[builtins.str]:
        result = self._values.get("user_metadata")
        return result

    def __eq__(self, rhs: typing.Any) -> builtins.bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs: typing.Any) -> builtins.bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return "RelayHybridConnectionConfig(%s)" % ", ".join(
            k + "=" + repr(v) for k, v in self._values.items()
        )


@jsii.data_type(
    jsii_type="@cdktf/provider-azurerm.RelayHybridConnectionTimeouts",
    jsii_struct_bases=[],
    name_mapping={
        "create": "create",
        "delete": "delete",
        "read": "read",
        "update": "update",
    },
)
class RelayHybridConnectionTimeouts:
    def __init__(
        self,
        *,
        create: typing.Optional[builtins.str] = None,
        delete: typing.Optional[builtins.str] = None,
        read: typing.Optional[builtins.str] = None,
        update: typing.Optional[builtins.str] = None,
    ) -> None:
        """
        :param create: 
        :param delete: 
        :param read: 
        :param update: 
        """
        self._values: typing.Dict[str, typing.Any] = {}
        if create is not None:
            self._values["create"] = create
        if delete is not None:
            self._values["delete"] = delete
        if read is not None:
            self._values["read"] = read
        if update is not None:
            self._values["update"] = update

    @builtins.property
    def create(self) -> typing.Optional[builtins.str]:
        result = self._values.get("create")
        return result

    @builtins.property
    def delete(self) -> typing.Optional[builtins.str]:
        result = self._values.get("delete")
        return result

    @builtins.property
    def read(self) -> typing.Optional[builtins.str]:
        result = self._values.get("read")
        return result

    @builtins.property
    def update(self) -> typing.Optional[builtins.str]:
        result = self._values.get("update")
        return result

    def __eq__(self, rhs: typing.Any) -> builtins.bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs: typing.Any) -> builtins.bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return "RelayHybridConnectionTimeouts(%s)" % ", ".join(
            k + "=" + repr(v) for k, v in self._values.items()
        )


class RelayNamespace(
    cdktf.TerraformResource,
    metaclass=jsii.JSIIMeta,
    jsii_type="@cdktf/provider-azurerm.RelayNamespace",
):
    def __init__(
        self,
        scope: constructs.Construct,
        id: builtins.str,
        *,
        location: builtins.str,
        name: builtins.str,
        resource_group_name: builtins.str,
        sku_name: builtins.str,
        tags: typing.Optional[typing.Mapping[builtins.str, builtins.str]] = None,
        timeouts: typing.Optional["RelayNamespaceTimeouts"] = None,
        count: typing.Optional[jsii.Number] = None,
        depends_on: typing.Optional[typing.List[cdktf.TerraformResource]] = None,
        lifecycle: typing.Optional[cdktf.TerraformResourceLifecycle] = None,
        provider: typing.Optional[cdktf.TerraformProvider] = None,
    ) -> None:
        """
        :param scope: -
        :param id: -
        :param location: 
        :param name: 
        :param resource_group_name: 
        :param sku_name: 
        :param tags: 
        :param timeouts: timeouts block.
        :param count: 
        :param depends_on: 
        :param lifecycle: 
        :param provider: 
        """
        config = RelayNamespaceConfig(
            location=location,
            name=name,
            resource_group_name=resource_group_name,
            sku_name=sku_name,
            tags=tags,
            timeouts=timeouts,
            count=count,
            depends_on=depends_on,
            lifecycle=lifecycle,
            provider=provider,
        )

        jsii.create(RelayNamespace, self, [scope, id, config])

    @jsii.member(jsii_name="synthesizeAttributes")
    def _synthesize_attributes(self) -> typing.Mapping[builtins.str, typing.Any]:
        return jsii.invoke(self, "synthesizeAttributes", [])

    @builtins.property # type: ignore
    @jsii.member(jsii_name="metricId")
    def metric_id(self) -> builtins.str:
        return jsii.get(self, "metricId")

    @builtins.property # type: ignore
    @jsii.member(jsii_name="primaryConnectionString")
    def primary_connection_string(self) -> builtins.str:
        return jsii.get(self, "primaryConnectionString")

    @builtins.property # type: ignore
    @jsii.member(jsii_name="primaryKey")
    def primary_key(self) -> builtins.str:
        return jsii.get(self, "primaryKey")

    @builtins.property # type: ignore
    @jsii.member(jsii_name="secondaryConnectionString")
    def secondary_connection_string(self) -> builtins.str:
        return jsii.get(self, "secondaryConnectionString")

    @builtins.property # type: ignore
    @jsii.member(jsii_name="secondaryKey")
    def secondary_key(self) -> builtins.str:
        return jsii.get(self, "secondaryKey")

    @builtins.property # type: ignore
    @jsii.member(jsii_name="location")
    def location(self) -> builtins.str:
        return jsii.get(self, "location")

    @location.setter # type: ignore
    def location(self, value: builtins.str) -> None:
        jsii.set(self, "location", value)

    @builtins.property # type: ignore
    @jsii.member(jsii_name="name")
    def name(self) -> builtins.str:
        return jsii.get(self, "name")

    @name.setter # type: ignore
    def name(self, value: builtins.str) -> None:
        jsii.set(self, "name", value)

    @builtins.property # type: ignore
    @jsii.member(jsii_name="resourceGroupName")
    def resource_group_name(self) -> builtins.str:
        return jsii.get(self, "resourceGroupName")

    @resource_group_name.setter # type: ignore
    def resource_group_name(self, value: builtins.str) -> None:
        jsii.set(self, "resourceGroupName", value)

    @builtins.property # type: ignore
    @jsii.member(jsii_name="skuName")
    def sku_name(self) -> builtins.str:
        return jsii.get(self, "skuName")

    @sku_name.setter # type: ignore
    def sku_name(self, value: builtins.str) -> None:
        jsii.set(self, "skuName", value)

    @builtins.property # type: ignore
    @jsii.member(jsii_name="id")
    def id(self) -> typing.Optional[builtins.str]:
        return jsii.get(self, "id")

    @id.setter # type: ignore
    def id(self, value: typing.Optional[builtins.str]) -> None:
        jsii.set(self, "id", value)

    @builtins.property # type: ignore
    @jsii.member(jsii_name="tags")
    def tags(self) -> typing.Optional[typing.Mapping[builtins.str, builtins.str]]:
        return jsii.get(self, "tags")

    @tags.setter # type: ignore
    def tags(
        self,
        value: typing.Optional[typing.Mapping[builtins.str, builtins.str]],
    ) -> None:
        jsii.set(self, "tags", value)

    @builtins.property # type: ignore
    @jsii.member(jsii_name="timeouts")
    def timeouts(self) -> typing.Optional["RelayNamespaceTimeouts"]:
        return jsii.get(self, "timeouts")

    @timeouts.setter # type: ignore
    def timeouts(self, value: typing.Optional["RelayNamespaceTimeouts"]) -> None:
        jsii.set(self, "timeouts", value)


@jsii.data_type(
    jsii_type="@cdktf/provider-azurerm.RelayNamespaceConfig",
    jsii_struct_bases=[cdktf.TerraformMetaArguments],
    name_mapping={
        "count": "count",
        "depends_on": "dependsOn",
        "lifecycle": "lifecycle",
        "provider": "provider",
        "location": "location",
        "name": "name",
        "resource_group_name": "resourceGroupName",
        "sku_name": "skuName",
        "tags": "tags",
        "timeouts": "timeouts",
    },
)
class RelayNamespaceConfig(cdktf.TerraformMetaArguments):
    def __init__(
        self,
        *,
        count: typing.Optional[jsii.Number] = None,
        depends_on: typing.Optional[typing.List[cdktf.TerraformResource]] = None,
        lifecycle: typing.Optional[cdktf.TerraformResourceLifecycle] = None,
        provider: typing.Optional[cdktf.TerraformProvider] = None,
        location: builtins.str,
        name: builtins.str,
        resource_group_name: builtins.str,
        sku_name: builtins.str,
        tags: typing.Optional[typing.Mapping[builtins.str, builtins.str]] = None,
        timeouts: typing.Optional["RelayNamespaceTimeouts"] = None,
    ) -> None:
        """
        :param count: 
        :param depends_on: 
        :param lifecycle: 
        :param provider: 
        :param location: 
        :param name: 
        :param resource_group_name: 
        :param sku_name: 
        :param tags: 
        :param timeouts: timeouts block.
        """
        if isinstance(lifecycle, dict):
            lifecycle = cdktf.TerraformResourceLifecycle(**lifecycle)
        if isinstance(timeouts, dict):
            timeouts = RelayNamespaceTimeouts(**timeouts)
        self._values: typing.Dict[str, typing.Any] = {
            "location": location,
            "name": name,
            "resource_group_name": resource_group_name,
            "sku_name": sku_name,
        }
        if count is not None:
            self._values["count"] = count
        if depends_on is not None:
            self._values["depends_on"] = depends_on
        if lifecycle is not None:
            self._values["lifecycle"] = lifecycle
        if provider is not None:
            self._values["provider"] = provider
        if tags is not None:
            self._values["tags"] = tags
        if timeouts is not None:
            self._values["timeouts"] = timeouts

    @builtins.property
    def count(self) -> typing.Optional[jsii.Number]:
        """
        :stability: experimental
        """
        result = self._values.get("count")
        return result

    @builtins.property
    def depends_on(self) -> typing.Optional[typing.List[cdktf.TerraformResource]]:
        """
        :stability: experimental
        """
        result = self._values.get("depends_on")
        return result

    @builtins.property
    def lifecycle(self) -> typing.Optional[cdktf.TerraformResourceLifecycle]:
        """
        :stability: experimental
        """
        result = self._values.get("lifecycle")
        return result

    @builtins.property
    def provider(self) -> typing.Optional[cdktf.TerraformProvider]:
        """
        :stability: experimental
        """
        result = self._values.get("provider")
        return result

    @builtins.property
    def location(self) -> builtins.str:
        result = self._values.get("location")
        assert result is not None, "Required property 'location' is missing"
        return result

    @builtins.property
    def name(self) -> builtins.str:
        result = self._values.get("name")
        assert result is not None, "Required property 'name' is missing"
        return result

    @builtins.property
    def resource_group_name(self) -> builtins.str:
        result = self._values.get("resource_group_name")
        assert result is not None, "Required property 'resource_group_name' is missing"
        return result

    @builtins.property
    def sku_name(self) -> builtins.str:
        result = self._values.get("sku_name")
        assert result is not None, "Required property 'sku_name' is missing"
        return result

    @builtins.property
    def tags(self) -> typing.Optional[typing.Mapping[builtins.str, builtins.str]]:
        result = self._values.get("tags")
        return result

    @builtins.property
    def timeouts(self) -> typing.Optional["RelayNamespaceTimeouts"]:
        """timeouts block."""
        result = self._values.get("timeouts")
        return result

    def __eq__(self, rhs: typing.Any) -> builtins.bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs: typing.Any) -> builtins.bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return "RelayNamespaceConfig(%s)" % ", ".join(
            k + "=" + repr(v) for k, v in self._values.items()
        )


@jsii.data_type(
    jsii_type="@cdktf/provider-azurerm.RelayNamespaceTimeouts",
    jsii_struct_bases=[],
    name_mapping={
        "create": "create",
        "delete": "delete",
        "read": "read",
        "update": "update",
    },
)
class RelayNamespaceTimeouts:
    def __init__(
        self,
        *,
        create: typing.Optional[builtins.str] = None,
        delete: typing.Optional[builtins.str] = None,
        read: typing.Optional[builtins.str] = None,
        update: typing.Optional[builtins.str] = None,
    ) -> None:
        """
        :param create: 
        :param delete: 
        :param read: 
        :param update: 
        """
        self._values: typing.Dict[str, typing.Any] = {}
        if create is not None:
            self._values["create"] = create
        if delete is not None:
            self._values["delete"] = delete
        if read is not None:
            self._values["read"] = read
        if update is not None:
            self._values["update"] = update

    @builtins.property
    def create(self) -> typing.Optional[builtins.str]:
        result = self._values.get("create")
        return result

    @builtins.property
    def delete(self) -> typing.Optional[builtins.str]:
        result = self._values.get("delete")
        return result

    @builtins.property
    def read(self) -> typing.Optional[builtins.str]:
        result = self._values.get("read")
        return result

    @builtins.property
    def update(self) -> typing.Optional[builtins.str]:
        result = self._values.get("update")
        return result

    def __eq__(self, rhs: typing.Any) -> builtins.bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs: typing.Any) -> builtins.bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return "RelayNamespaceTimeouts(%s)" % ", ".join(
            k + "=" + repr(v) for k, v in self._values.items()
        )


class ResourceGroup(
    cdktf.TerraformResource,
    metaclass=jsii.JSIIMeta,
    jsii_type="@cdktf/provider-azurerm.ResourceGroup",
):
    def __init__(
        self,
        scope: constructs.Construct,
        id: builtins.str,
        *,
        location: builtins.str,
        name: builtins.str,
        tags: typing.Optional[typing.Mapping[builtins.str, builtins.str]] = None,
        timeouts: typing.Optional["ResourceGroupTimeouts"] = None,
        count: typing.Optional[jsii.Number] = None,
        depends_on: typing.Optional[typing.List[cdktf.TerraformResource]] = None,
        lifecycle: typing.Optional[cdktf.TerraformResourceLifecycle] = None,
        provider: typing.Optional[cdktf.TerraformProvider] = None,
    ) -> None:
        """
        :param scope: -
        :param id: -
        :param location: 
        :param name: 
        :param tags: 
        :param timeouts: timeouts block.
        :param count: 
        :param depends_on: 
        :param lifecycle: 
        :param provider: 
        """
        config = ResourceGroupConfig(
            location=location,
            name=name,
            tags=tags,
            timeouts=timeouts,
            count=count,
            depends_on=depends_on,
            lifecycle=lifecycle,
            provider=provider,
        )

        jsii.create(ResourceGroup, self, [scope, id, config])

    @jsii.member(jsii_name="synthesizeAttributes")
    def _synthesize_attributes(self) -> typing.Mapping[builtins.str, typing.Any]:
        return jsii.invoke(self, "synthesizeAttributes", [])

    @builtins.property # type: ignore
    @jsii.member(jsii_name="location")
    def location(self) -> builtins.str:
        return jsii.get(self, "location")

    @location.setter # type: ignore
    def location(self, value: builtins.str) -> None:
        jsii.set(self, "location", value)

    @builtins.property # type: ignore
    @jsii.member(jsii_name="name")
    def name(self) -> builtins.str:
        return jsii.get(self, "name")

    @name.setter # type: ignore
    def name(self, value: builtins.str) -> None:
        jsii.set(self, "name", value)

    @builtins.property # type: ignore
    @jsii.member(jsii_name="id")
    def id(self) -> typing.Optional[builtins.str]:
        return jsii.get(self, "id")

    @id.setter # type: ignore
    def id(self, value: typing.Optional[builtins.str]) -> None:
        jsii.set(self, "id", value)

    @builtins.property # type: ignore
    @jsii.member(jsii_name="tags")
    def tags(self) -> typing.Optional[typing.Mapping[builtins.str, builtins.str]]:
        return jsii.get(self, "tags")

    @tags.setter # type: ignore
    def tags(
        self,
        value: typing.Optional[typing.Mapping[builtins.str, builtins.str]],
    ) -> None:
        jsii.set(self, "tags", value)

    @builtins.property # type: ignore
    @jsii.member(jsii_name="timeouts")
    def timeouts(self) -> typing.Optional["ResourceGroupTimeouts"]:
        return jsii.get(self, "timeouts")

    @timeouts.setter # type: ignore
    def timeouts(self, value: typing.Optional["ResourceGroupTimeouts"]) -> None:
        jsii.set(self, "timeouts", value)


@jsii.data_type(
    jsii_type="@cdktf/provider-azurerm.ResourceGroupConfig",
    jsii_struct_bases=[cdktf.TerraformMetaArguments],
    name_mapping={
        "count": "count",
        "depends_on": "dependsOn",
        "lifecycle": "lifecycle",
        "provider": "provider",
        "location": "location",
        "name": "name",
        "tags": "tags",
        "timeouts": "timeouts",
    },
)
class ResourceGroupConfig(cdktf.TerraformMetaArguments):
    def __init__(
        self,
        *,
        count: typing.Optional[jsii.Number] = None,
        depends_on: typing.Optional[typing.List[cdktf.TerraformResource]] = None,
        lifecycle: typing.Optional[cdktf.TerraformResourceLifecycle] = None,
        provider: typing.Optional[cdktf.TerraformProvider] = None,
        location: builtins.str,
        name: builtins.str,
        tags: typing.Optional[typing.Mapping[builtins.str, builtins.str]] = None,
        timeouts: typing.Optional["ResourceGroupTimeouts"] = None,
    ) -> None:
        """
        :param count: 
        :param depends_on: 
        :param lifecycle: 
        :param provider: 
        :param location: 
        :param name: 
        :param tags: 
        :param timeouts: timeouts block.
        """
        if isinstance(lifecycle, dict):
            lifecycle = cdktf.TerraformResourceLifecycle(**lifecycle)
        if isinstance(timeouts, dict):
            timeouts = ResourceGroupTimeouts(**timeouts)
        self._values: typing.Dict[str, typing.Any] = {
            "location": location,
            "name": name,
        }
        if count is not None:
            self._values["count"] = count
        if depends_on is not None:
            self._values["depends_on"] = depends_on
        if lifecycle is not None:
            self._values["lifecycle"] = lifecycle
        if provider is not None:
            self._values["provider"] = provider
        if tags is not None:
            self._values["tags"] = tags
        if timeouts is not None:
            self._values["timeouts"] = timeouts

    @builtins.property
    def count(self) -> typing.Optional[jsii.Number]:
        """
        :stability: experimental
        """
        result = self._values.get("count")
        return result

    @builtins.property
    def depends_on(self) -> typing.Optional[typing.List[cdktf.TerraformResource]]:
        """
        :stability: experimental
        """
        result = self._values.get("depends_on")
        return result

    @builtins.property
    def lifecycle(self) -> typing.Optional[cdktf.TerraformResourceLifecycle]:
        """
        :stability: experimental
        """
        result = self._values.get("lifecycle")
        return result

    @builtins.property
    def provider(self) -> typing.Optional[cdktf.TerraformProvider]:
        """
        :stability: experimental
        """
        result = self._values.get("provider")
        return result

    @builtins.property
    def location(self) -> builtins.str:
        result = self._values.get("location")
        assert result is not None, "Required property 'location' is missing"
        return result

    @builtins.property
    def name(self) -> builtins.str:
        result = self._values.get("name")
        assert result is not None, "Required property 'name' is missing"
        return result

    @builtins.property
    def tags(self) -> typing.Optional[typing.Mapping[builtins.str, builtins.str]]:
        result = self._values.get("tags")
        return result

    @builtins.property
    def timeouts(self) -> typing.Optional["ResourceGroupTimeouts"]:
        """timeouts block."""
        result = self._values.get("timeouts")
        return result

    def __eq__(self, rhs: typing.Any) -> builtins.bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs: typing.Any) -> builtins.bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return "ResourceGroupConfig(%s)" % ", ".join(
            k + "=" + repr(v) for k, v in self._values.items()
        )


@jsii.data_type(
    jsii_type="@cdktf/provider-azurerm.ResourceGroupTimeouts",
    jsii_struct_bases=[],
    name_mapping={
        "create": "create",
        "delete": "delete",
        "read": "read",
        "update": "update",
    },
)
class ResourceGroupTimeouts:
    def __init__(
        self,
        *,
        create: typing.Optional[builtins.str] = None,
        delete: typing.Optional[builtins.str] = None,
        read: typing.Optional[builtins.str] = None,
        update: typing.Optional[builtins.str] = None,
    ) -> None:
        """
        :param create: 
        :param delete: 
        :param read: 
        :param update: 
        """
        self._values: typing.Dict[str, typing.Any] = {}
        if create is not None:
            self._values["create"] = create
        if delete is not None:
            self._values["delete"] = delete
        if read is not None:
            self._values["read"] = read
        if update is not None:
            self._values["update"] = update

    @builtins.property
    def create(self) -> typing.Optional[builtins.str]:
        result = self._values.get("create")
        return result

    @builtins.property
    def delete(self) -> typing.Optional[builtins.str]:
        result = self._values.get("delete")
        return result

    @builtins.property
    def read(self) -> typing.Optional[builtins.str]:
        result = self._values.get("read")
        return result

    @builtins.property
    def update(self) -> typing.Optional[builtins.str]:
        result = self._values.get("update")
        return result

    def __eq__(self, rhs: typing.Any) -> builtins.bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs: typing.Any) -> builtins.bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return "ResourceGroupTimeouts(%s)" % ", ".join(
            k + "=" + repr(v) for k, v in self._values.items()
        )


class RoleAssignment(
    cdktf.TerraformResource,
    metaclass=jsii.JSIIMeta,
    jsii_type="@cdktf/provider-azurerm.RoleAssignment",
):
    def __init__(
        self,
        scope_: constructs.Construct,
        id: builtins.str,
        *,
        principal_id: builtins.str,
        scope: builtins.str,
        name: typing.Optional[builtins.str] = None,
        role_definition_id: typing.Optional[builtins.str] = None,
        role_definition_name: typing.Optional[builtins.str] = None,
        skip_service_principal_aad_check: typing.Optional[builtins.bool] = None,
        timeouts: typing.Optional["RoleAssignmentTimeouts"] = None,
        count: typing.Optional[jsii.Number] = None,
        depends_on: typing.Optional[typing.List[cdktf.TerraformResource]] = None,
        lifecycle: typing.Optional[cdktf.TerraformResourceLifecycle] = None,
        provider: typing.Optional[cdktf.TerraformProvider] = None,
    ) -> None:
        """
        :param scope_: -
        :param id: -
        :param principal_id: 
        :param scope: 
        :param name: 
        :param role_definition_id: 
        :param role_definition_name: 
        :param skip_service_principal_aad_check: 
        :param timeouts: timeouts block.
        :param count: 
        :param depends_on: 
        :param lifecycle: 
        :param provider: 
        """
        config = RoleAssignmentConfig(
            principal_id=principal_id,
            scope=scope,
            name=name,
            role_definition_id=role_definition_id,
            role_definition_name=role_definition_name,
            skip_service_principal_aad_check=skip_service_principal_aad_check,
            timeouts=timeouts,
            count=count,
            depends_on=depends_on,
            lifecycle=lifecycle,
            provider=provider,
        )

        jsii.create(RoleAssignment, self, [scope_, id, config])

    @jsii.member(jsii_name="synthesizeAttributes")
    def _synthesize_attributes(self) -> typing.Mapping[builtins.str, typing.Any]:
        return jsii.invoke(self, "synthesizeAttributes", [])

    @builtins.property # type: ignore
    @jsii.member(jsii_name="principalType")
    def principal_type(self) -> builtins.str:
        return jsii.get(self, "principalType")

    @builtins.property # type: ignore
    @jsii.member(jsii_name="principalId")
    def principal_id(self) -> builtins.str:
        return jsii.get(self, "principalId")

    @principal_id.setter # type: ignore
    def principal_id(self, value: builtins.str) -> None:
        jsii.set(self, "principalId", value)

    @builtins.property # type: ignore
    @jsii.member(jsii_name="scope")
    def scope(self) -> builtins.str:
        return jsii.get(self, "scope")

    @scope.setter # type: ignore
    def scope(self, value: builtins.str) -> None:
        jsii.set(self, "scope", value)

    @builtins.property # type: ignore
    @jsii.member(jsii_name="id")
    def id(self) -> typing.Optional[builtins.str]:
        return jsii.get(self, "id")

    @id.setter # type: ignore
    def id(self, value: typing.Optional[builtins.str]) -> None:
        jsii.set(self, "id", value)

    @builtins.property # type: ignore
    @jsii.member(jsii_name="name")
    def name(self) -> typing.Optional[builtins.str]:
        return jsii.get(self, "name")

    @name.setter # type: ignore
    def name(self, value: typing.Optional[builtins.str]) -> None:
        jsii.set(self, "name", value)

    @builtins.property # type: ignore
    @jsii.member(jsii_name="roleDefinitionId")
    def role_definition_id(self) -> typing.Optional[builtins.str]:
        return jsii.get(self, "roleDefinitionId")

    @role_definition_id.setter # type: ignore
    def role_definition_id(self, value: typing.Optional[builtins.str]) -> None:
        jsii.set(self, "roleDefinitionId", value)

    @builtins.property # type: ignore
    @jsii.member(jsii_name="roleDefinitionName")
    def role_definition_name(self) -> typing.Optional[builtins.str]:
        return jsii.get(self, "roleDefinitionName")

    @role_definition_name.setter # type: ignore
    def role_definition_name(self, value: typing.Optional[builtins.str]) -> None:
        jsii.set(self, "roleDefinitionName", value)

    @builtins.property # type: ignore
    @jsii.member(jsii_name="skipServicePrincipalAadCheck")
    def skip_service_principal_aad_check(self) -> typing.Optional[builtins.bool]:
        return jsii.get(self, "skipServicePrincipalAadCheck")

    @skip_service_principal_aad_check.setter # type: ignore
    def skip_service_principal_aad_check(
        self,
        value: typing.Optional[builtins.bool],
    ) -> None:
        jsii.set(self, "skipServicePrincipalAadCheck", value)

    @builtins.property # type: ignore
    @jsii.member(jsii_name="timeouts")
    def timeouts(self) -> typing.Optional["RoleAssignmentTimeouts"]:
        return jsii.get(self, "timeouts")

    @timeouts.setter # type: ignore
    def timeouts(self, value: typing.Optional["RoleAssignmentTimeouts"]) -> None:
        jsii.set(self, "timeouts", value)


@jsii.data_type(
    jsii_type="@cdktf/provider-azurerm.RoleAssignmentConfig",
    jsii_struct_bases=[cdktf.TerraformMetaArguments],
    name_mapping={
        "count": "count",
        "depends_on": "dependsOn",
        "lifecycle": "lifecycle",
        "provider": "provider",
        "principal_id": "principalId",
        "scope": "scope",
        "name": "name",
        "role_definition_id": "roleDefinitionId",
        "role_definition_name": "roleDefinitionName",
        "skip_service_principal_aad_check": "skipServicePrincipalAadCheck",
        "timeouts": "timeouts",
    },
)
class RoleAssignmentConfig(cdktf.TerraformMetaArguments):
    def __init__(
        self,
        *,
        count: typing.Optional[jsii.Number] = None,
        depends_on: typing.Optional[typing.List[cdktf.TerraformResource]] = None,
        lifecycle: typing.Optional[cdktf.TerraformResourceLifecycle] = None,
        provider: typing.Optional[cdktf.TerraformProvider] = None,
        principal_id: builtins.str,
        scope: builtins.str,
        name: typing.Optional[builtins.str] = None,
        role_definition_id: typing.Optional[builtins.str] = None,
        role_definition_name: typing.Optional[builtins.str] = None,
        skip_service_principal_aad_check: typing.Optional[builtins.bool] = None,
        timeouts: typing.Optional["RoleAssignmentTimeouts"] = None,
    ) -> None:
        """
        :param count: 
        :param depends_on: 
        :param lifecycle: 
        :param provider: 
        :param principal_id: 
        :param scope: 
        :param name: 
        :param role_definition_id: 
        :param role_definition_name: 
        :param skip_service_principal_aad_check: 
        :param timeouts: timeouts block.
        """
        if isinstance(lifecycle, dict):
            lifecycle = cdktf.TerraformResourceLifecycle(**lifecycle)
        if isinstance(timeouts, dict):
            timeouts = RoleAssignmentTimeouts(**timeouts)
        self._values: typing.Dict[str, typing.Any] = {
            "principal_id": principal_id,
            "scope": scope,
        }
        if count is not None:
            self._values["count"] = count
        if depends_on is not None:
            self._values["depends_on"] = depends_on
        if lifecycle is not None:
            self._values["lifecycle"] = lifecycle
        if provider is not None:
            self._values["provider"] = provider
        if name is not None:
            self._values["name"] = name
        if role_definition_id is not None:
            self._values["role_definition_id"] = role_definition_id
        if role_definition_name is not None:
            self._values["role_definition_name"] = role_definition_name
        if skip_service_principal_aad_check is not None:
            self._values["skip_service_principal_aad_check"] = skip_service_principal_aad_check
        if timeouts is not None:
            self._values["timeouts"] = timeouts

    @builtins.property
    def count(self) -> typing.Optional[jsii.Number]:
        """
        :stability: experimental
        """
        result = self._values.get("count")
        return result

    @builtins.property
    def depends_on(self) -> typing.Optional[typing.List[cdktf.TerraformResource]]:
        """
        :stability: experimental
        """
        result = self._values.get("depends_on")
        return result

    @builtins.property
    def lifecycle(self) -> typing.Optional[cdktf.TerraformResourceLifecycle]:
        """
        :stability: experimental
        """
        result = self._values.get("lifecycle")
        return result

    @builtins.property
    def provider(self) -> typing.Optional[cdktf.TerraformProvider]:
        """
        :stability: experimental
        """
        result = self._values.get("provider")
        return result

    @builtins.property
    def principal_id(self) -> builtins.str:
        result = self._values.get("principal_id")
        assert result is not None, "Required property 'principal_id' is missing"
        return result

    @builtins.property
    def scope(self) -> builtins.str:
        result = self._values.get("scope")
        assert result is not None, "Required property 'scope' is missing"
        return result

    @builtins.property
    def name(self) -> typing.Optional[builtins.str]:
        result = self._values.get("name")
        return result

    @builtins.property
    def role_definition_id(self) -> typing.Optional[builtins.str]:
        result = self._values.get("role_definition_id")
        return result

    @builtins.property
    def role_definition_name(self) -> typing.Optional[builtins.str]:
        result = self._values.get("role_definition_name")
        return result

    @builtins.property
    def skip_service_principal_aad_check(self) -> typing.Optional[builtins.bool]:
        result = self._values.get("skip_service_principal_aad_check")
        return result

    @builtins.property
    def timeouts(self) -> typing.Optional["RoleAssignmentTimeouts"]:
        """timeouts block."""
        result = self._values.get("timeouts")
        return result

    def __eq__(self, rhs: typing.Any) -> builtins.bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs: typing.Any) -> builtins.bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return "RoleAssignmentConfig(%s)" % ", ".join(
            k + "=" + repr(v) for k, v in self._values.items()
        )


@jsii.data_type(
    jsii_type="@cdktf/provider-azurerm.RoleAssignmentTimeouts",
    jsii_struct_bases=[],
    name_mapping={
        "create": "create",
        "delete": "delete",
        "read": "read",
        "update": "update",
    },
)
class RoleAssignmentTimeouts:
    def __init__(
        self,
        *,
        create: typing.Optional[builtins.str] = None,
        delete: typing.Optional[builtins.str] = None,
        read: typing.Optional[builtins.str] = None,
        update: typing.Optional[builtins.str] = None,
    ) -> None:
        """
        :param create: 
        :param delete: 
        :param read: 
        :param update: 
        """
        self._values: typing.Dict[str, typing.Any] = {}
        if create is not None:
            self._values["create"] = create
        if delete is not None:
            self._values["delete"] = delete
        if read is not None:
            self._values["read"] = read
        if update is not None:
            self._values["update"] = update

    @builtins.property
    def create(self) -> typing.Optional[builtins.str]:
        result = self._values.get("create")
        return result

    @builtins.property
    def delete(self) -> typing.Optional[builtins.str]:
        result = self._values.get("delete")
        return result

    @builtins.property
    def read(self) -> typing.Optional[builtins.str]:
        result = self._values.get("read")
        return result

    @builtins.property
    def update(self) -> typing.Optional[builtins.str]:
        result = self._values.get("update")
        return result

    def __eq__(self, rhs: typing.Any) -> builtins.bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs: typing.Any) -> builtins.bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return "RoleAssignmentTimeouts(%s)" % ", ".join(
            k + "=" + repr(v) for k, v in self._values.items()
        )


class RoleDefinition(
    cdktf.TerraformResource,
    metaclass=jsii.JSIIMeta,
    jsii_type="@cdktf/provider-azurerm.RoleDefinition",
):
    def __init__(
        self,
        scope_: constructs.Construct,
        id: builtins.str,
        *,
        assignable_scopes: typing.List[builtins.str],
        name: builtins.str,
        permissions: typing.List["RoleDefinitionPermissions"],
        scope: builtins.str,
        description: typing.Optional[builtins.str] = None,
        role_definition_id: typing.Optional[builtins.str] = None,
        timeouts: typing.Optional["RoleDefinitionTimeouts"] = None,
        count: typing.Optional[jsii.Number] = None,
        depends_on: typing.Optional[typing.List[cdktf.TerraformResource]] = None,
        lifecycle: typing.Optional[cdktf.TerraformResourceLifecycle] = None,
        provider: typing.Optional[cdktf.TerraformProvider] = None,
    ) -> None:
        """
        :param scope_: -
        :param id: -
        :param assignable_scopes: 
        :param name: 
        :param permissions: permissions block.
        :param scope: 
        :param description: 
        :param role_definition_id: 
        :param timeouts: timeouts block.
        :param count: 
        :param depends_on: 
        :param lifecycle: 
        :param provider: 
        """
        config = RoleDefinitionConfig(
            assignable_scopes=assignable_scopes,
            name=name,
            permissions=permissions,
            scope=scope,
            description=description,
            role_definition_id=role_definition_id,
            timeouts=timeouts,
            count=count,
            depends_on=depends_on,
            lifecycle=lifecycle,
            provider=provider,
        )

        jsii.create(RoleDefinition, self, [scope_, id, config])

    @jsii.member(jsii_name="synthesizeAttributes")
    def _synthesize_attributes(self) -> typing.Mapping[builtins.str, typing.Any]:
        return jsii.invoke(self, "synthesizeAttributes", [])

    @builtins.property # type: ignore
    @jsii.member(jsii_name="assignableScopes")
    def assignable_scopes(self) -> typing.List[builtins.str]:
        return jsii.get(self, "assignableScopes")

    @assignable_scopes.setter # type: ignore
    def assignable_scopes(self, value: typing.List[builtins.str]) -> None:
        jsii.set(self, "assignableScopes", value)

    @builtins.property # type: ignore
    @jsii.member(jsii_name="name")
    def name(self) -> builtins.str:
        return jsii.get(self, "name")

    @name.setter # type: ignore
    def name(self, value: builtins.str) -> None:
        jsii.set(self, "name", value)

    @builtins.property # type: ignore
    @jsii.member(jsii_name="permissions")
    def permissions(self) -> typing.List["RoleDefinitionPermissions"]:
        return jsii.get(self, "permissions")

    @permissions.setter # type: ignore
    def permissions(self, value: typing.List["RoleDefinitionPermissions"]) -> None:
        jsii.set(self, "permissions", value)

    @builtins.property # type: ignore
    @jsii.member(jsii_name="scope")
    def scope(self) -> builtins.str:
        return jsii.get(self, "scope")

    @scope.setter # type: ignore
    def scope(self, value: builtins.str) -> None:
        jsii.set(self, "scope", value)

    @builtins.property # type: ignore
    @jsii.member(jsii_name="description")
    def description(self) -> typing.Optional[builtins.str]:
        return jsii.get(self, "description")

    @description.setter # type: ignore
    def description(self, value: typing.Optional[builtins.str]) -> None:
        jsii.set(self, "description", value)

    @builtins.property # type: ignore
    @jsii.member(jsii_name="id")
    def id(self) -> typing.Optional[builtins.str]:
        return jsii.get(self, "id")

    @id.setter # type: ignore
    def id(self, value: typing.Optional[builtins.str]) -> None:
        jsii.set(self, "id", value)

    @builtins.property # type: ignore
    @jsii.member(jsii_name="roleDefinitionId")
    def role_definition_id(self) -> typing.Optional[builtins.str]:
        return jsii.get(self, "roleDefinitionId")

    @role_definition_id.setter # type: ignore
    def role_definition_id(self, value: typing.Optional[builtins.str]) -> None:
        jsii.set(self, "roleDefinitionId", value)

    @builtins.property # type: ignore
    @jsii.member(jsii_name="timeouts")
    def timeouts(self) -> typing.Optional["RoleDefinitionTimeouts"]:
        return jsii.get(self, "timeouts")

    @timeouts.setter # type: ignore
    def timeouts(self, value: typing.Optional["RoleDefinitionTimeouts"]) -> None:
        jsii.set(self, "timeouts", value)


@jsii.data_type(
    jsii_type="@cdktf/provider-azurerm.RoleDefinitionConfig",
    jsii_struct_bases=[cdktf.TerraformMetaArguments],
    name_mapping={
        "count": "count",
        "depends_on": "dependsOn",
        "lifecycle": "lifecycle",
        "provider": "provider",
        "assignable_scopes": "assignableScopes",
        "name": "name",
        "permissions": "permissions",
        "scope": "scope",
        "description": "description",
        "role_definition_id": "roleDefinitionId",
        "timeouts": "timeouts",
    },
)
class RoleDefinitionConfig(cdktf.TerraformMetaArguments):
    def __init__(
        self,
        *,
        count: typing.Optional[jsii.Number] = None,
        depends_on: typing.Optional[typing.List[cdktf.TerraformResource]] = None,
        lifecycle: typing.Optional[cdktf.TerraformResourceLifecycle] = None,
        provider: typing.Optional[cdktf.TerraformProvider] = None,
        assignable_scopes: typing.List[builtins.str],
        name: builtins.str,
        permissions: typing.List["RoleDefinitionPermissions"],
        scope: builtins.str,
        description: typing.Optional[builtins.str] = None,
        role_definition_id: typing.Optional[builtins.str] = None,
        timeouts: typing.Optional["RoleDefinitionTimeouts"] = None,
    ) -> None:
        """
        :param count: 
        :param depends_on: 
        :param lifecycle: 
        :param provider: 
        :param assignable_scopes: 
        :param name: 
        :param permissions: permissions block.
        :param scope: 
        :param description: 
        :param role_definition_id: 
        :param timeouts: timeouts block.
        """
        if isinstance(lifecycle, dict):
            lifecycle = cdktf.TerraformResourceLifecycle(**lifecycle)
        if isinstance(timeouts, dict):
            timeouts = RoleDefinitionTimeouts(**timeouts)
        self._values: typing.Dict[str, typing.Any] = {
            "assignable_scopes": assignable_scopes,
            "name": name,
            "permissions": permissions,
            "scope": scope,
        }
        if count is not None:
            self._values["count"] = count
        if depends_on is not None:
            self._values["depends_on"] = depends_on
        if lifecycle is not None:
            self._values["lifecycle"] = lifecycle
        if provider is not None:
            self._values["provider"] = provider
        if description is not None:
            self._values["description"] = description
        if role_definition_id is not None:
            self._values["role_definition_id"] = role_definition_id
        if timeouts is not None:
            self._values["timeouts"] = timeouts

    @builtins.property
    def count(self) -> typing.Optional[jsii.Number]:
        """
        :stability: experimental
        """
        result = self._values.get("count")
        return result

    @builtins.property
    def depends_on(self) -> typing.Optional[typing.List[cdktf.TerraformResource]]:
        """
        :stability: experimental
        """
        result = self._values.get("depends_on")
        return result

    @builtins.property
    def lifecycle(self) -> typing.Optional[cdktf.TerraformResourceLifecycle]:
        """
        :stability: experimental
        """
        result = self._values.get("lifecycle")
        return result

    @builtins.property
    def provider(self) -> typing.Optional[cdktf.TerraformProvider]:
        """
        :stability: experimental
        """
        result = self._values.get("provider")
        return result

    @builtins.property
    def assignable_scopes(self) -> typing.List[builtins.str]:
        result = self._values.get("assignable_scopes")
        assert result is not None, "Required property 'assignable_scopes' is missing"
        return result

    @builtins.property
    def name(self) -> builtins.str:
        result = self._values.get("name")
        assert result is not None, "Required property 'name' is missing"
        return result

    @builtins.property
    def permissions(self) -> typing.List["RoleDefinitionPermissions"]:
        """permissions block."""
        result = self._values.get("permissions")
        assert result is not None, "Required property 'permissions' is missing"
        return result

    @builtins.property
    def scope(self) -> builtins.str:
        result = self._values.get("scope")
        assert result is not None, "Required property 'scope' is missing"
        return result

    @builtins.property
    def description(self) -> typing.Optional[builtins.str]:
        result = self._values.get("description")
        return result

    @builtins.property
    def role_definition_id(self) -> typing.Optional[builtins.str]:
        result = self._values.get("role_definition_id")
        return result

    @builtins.property
    def timeouts(self) -> typing.Optional["RoleDefinitionTimeouts"]:
        """timeouts block."""
        result = self._values.get("timeouts")
        return result

    def __eq__(self, rhs: typing.Any) -> builtins.bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs: typing.Any) -> builtins.bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return "RoleDefinitionConfig(%s)" % ", ".join(
            k + "=" + repr(v) for k, v in self._values.items()
        )


@jsii.data_type(
    jsii_type="@cdktf/provider-azurerm.RoleDefinitionPermissions",
    jsii_struct_bases=[],
    name_mapping={
        "actions": "actions",
        "data_actions": "dataActions",
        "not_actions": "notActions",
        "not_data_actions": "notDataActions",
    },
)
class RoleDefinitionPermissions:
    def __init__(
        self,
        *,
        actions: typing.Optional[typing.List[builtins.str]] = None,
        data_actions: typing.Optional[typing.List[builtins.str]] = None,
        not_actions: typing.Optional[typing.List[builtins.str]] = None,
        not_data_actions: typing.Optional[typing.List[builtins.str]] = None,
    ) -> None:
        """
        :param actions: 
        :param data_actions: 
        :param not_actions: 
        :param not_data_actions: 
        """
        self._values: typing.Dict[str, typing.Any] = {}
        if actions is not None:
            self._values["actions"] = actions
        if data_actions is not None:
            self._values["data_actions"] = data_actions
        if not_actions is not None:
            self._values["not_actions"] = not_actions
        if not_data_actions is not None:
            self._values["not_data_actions"] = not_data_actions

    @builtins.property
    def actions(self) -> typing.Optional[typing.List[builtins.str]]:
        result = self._values.get("actions")
        return result

    @builtins.property
    def data_actions(self) -> typing.Optional[typing.List[builtins.str]]:
        result = self._values.get("data_actions")
        return result

    @builtins.property
    def not_actions(self) -> typing.Optional[typing.List[builtins.str]]:
        result = self._values.get("not_actions")
        return result

    @builtins.property
    def not_data_actions(self) -> typing.Optional[typing.List[builtins.str]]:
        result = self._values.get("not_data_actions")
        return result

    def __eq__(self, rhs: typing.Any) -> builtins.bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs: typing.Any) -> builtins.bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return "RoleDefinitionPermissions(%s)" % ", ".join(
            k + "=" + repr(v) for k, v in self._values.items()
        )


@jsii.data_type(
    jsii_type="@cdktf/provider-azurerm.RoleDefinitionTimeouts",
    jsii_struct_bases=[],
    name_mapping={
        "create": "create",
        "delete": "delete",
        "read": "read",
        "update": "update",
    },
)
class RoleDefinitionTimeouts:
    def __init__(
        self,
        *,
        create: typing.Optional[builtins.str] = None,
        delete: typing.Optional[builtins.str] = None,
        read: typing.Optional[builtins.str] = None,
        update: typing.Optional[builtins.str] = None,
    ) -> None:
        """
        :param create: 
        :param delete: 
        :param read: 
        :param update: 
        """
        self._values: typing.Dict[str, typing.Any] = {}
        if create is not None:
            self._values["create"] = create
        if delete is not None:
            self._values["delete"] = delete
        if read is not None:
            self._values["read"] = read
        if update is not None:
            self._values["update"] = update

    @builtins.property
    def create(self) -> typing.Optional[builtins.str]:
        result = self._values.get("create")
        return result

    @builtins.property
    def delete(self) -> typing.Optional[builtins.str]:
        result = self._values.get("delete")
        return result

    @builtins.property
    def read(self) -> typing.Optional[builtins.str]:
        result = self._values.get("read")
        return result

    @builtins.property
    def update(self) -> typing.Optional[builtins.str]:
        result = self._values.get("update")
        return result

    def __eq__(self, rhs: typing.Any) -> builtins.bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs: typing.Any) -> builtins.bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return "RoleDefinitionTimeouts(%s)" % ", ".join(
            k + "=" + repr(v) for k, v in self._values.items()
        )


class Route(
    cdktf.TerraformResource,
    metaclass=jsii.JSIIMeta,
    jsii_type="@cdktf/provider-azurerm.Route",
):
    def __init__(
        self,
        scope: constructs.Construct,
        id: builtins.str,
        *,
        address_prefix: builtins.str,
        name: builtins.str,
        next_hop_type: builtins.str,
        resource_group_name: builtins.str,
        route_table_name: builtins.str,
        next_hop_in_ip_address: typing.Optional[builtins.str] = None,
        timeouts: typing.Optional["RouteTimeouts"] = None,
        count: typing.Optional[jsii.Number] = None,
        depends_on: typing.Optional[typing.List[cdktf.TerraformResource]] = None,
        lifecycle: typing.Optional[cdktf.TerraformResourceLifecycle] = None,
        provider: typing.Optional[cdktf.TerraformProvider] = None,
    ) -> None:
        """
        :param scope: -
        :param id: -
        :param address_prefix: 
        :param name: 
        :param next_hop_type: 
        :param resource_group_name: 
        :param route_table_name: 
        :param next_hop_in_ip_address: 
        :param timeouts: timeouts block.
        :param count: 
        :param depends_on: 
        :param lifecycle: 
        :param provider: 
        """
        config = RouteConfig(
            address_prefix=address_prefix,
            name=name,
            next_hop_type=next_hop_type,
            resource_group_name=resource_group_name,
            route_table_name=route_table_name,
            next_hop_in_ip_address=next_hop_in_ip_address,
            timeouts=timeouts,
            count=count,
            depends_on=depends_on,
            lifecycle=lifecycle,
            provider=provider,
        )

        jsii.create(Route, self, [scope, id, config])

    @jsii.member(jsii_name="synthesizeAttributes")
    def _synthesize_attributes(self) -> typing.Mapping[builtins.str, typing.Any]:
        return jsii.invoke(self, "synthesizeAttributes", [])

    @builtins.property # type: ignore
    @jsii.member(jsii_name="addressPrefix")
    def address_prefix(self) -> builtins.str:
        return jsii.get(self, "addressPrefix")

    @address_prefix.setter # type: ignore
    def address_prefix(self, value: builtins.str) -> None:
        jsii.set(self, "addressPrefix", value)

    @builtins.property # type: ignore
    @jsii.member(jsii_name="name")
    def name(self) -> builtins.str:
        return jsii.get(self, "name")

    @name.setter # type: ignore
    def name(self, value: builtins.str) -> None:
        jsii.set(self, "name", value)

    @builtins.property # type: ignore
    @jsii.member(jsii_name="nextHopType")
    def next_hop_type(self) -> builtins.str:
        return jsii.get(self, "nextHopType")

    @next_hop_type.setter # type: ignore
    def next_hop_type(self, value: builtins.str) -> None:
        jsii.set(self, "nextHopType", value)

    @builtins.property # type: ignore
    @jsii.member(jsii_name="resourceGroupName")
    def resource_group_name(self) -> builtins.str:
        return jsii.get(self, "resourceGroupName")

    @resource_group_name.setter # type: ignore
    def resource_group_name(self, value: builtins.str) -> None:
        jsii.set(self, "resourceGroupName", value)

    @builtins.property # type: ignore
    @jsii.member(jsii_name="routeTableName")
    def route_table_name(self) -> builtins.str:
        return jsii.get(self, "routeTableName")

    @route_table_name.setter # type: ignore
    def route_table_name(self, value: builtins.str) -> None:
        jsii.set(self, "routeTableName", value)

    @builtins.property # type: ignore
    @jsii.member(jsii_name="id")
    def id(self) -> typing.Optional[builtins.str]:
        return jsii.get(self, "id")

    @id.setter # type: ignore
    def id(self, value: typing.Optional[builtins.str]) -> None:
        jsii.set(self, "id", value)

    @builtins.property # type: ignore
    @jsii.member(jsii_name="nextHopInIpAddress")
    def next_hop_in_ip_address(self) -> typing.Optional[builtins.str]:
        return jsii.get(self, "nextHopInIpAddress")

    @next_hop_in_ip_address.setter # type: ignore
    def next_hop_in_ip_address(self, value: typing.Optional[builtins.str]) -> None:
        jsii.set(self, "nextHopInIpAddress", value)

    @builtins.property # type: ignore
    @jsii.member(jsii_name="timeouts")
    def timeouts(self) -> typing.Optional["RouteTimeouts"]:
        return jsii.get(self, "timeouts")

    @timeouts.setter # type: ignore
    def timeouts(self, value: typing.Optional["RouteTimeouts"]) -> None:
        jsii.set(self, "timeouts", value)


@jsii.data_type(
    jsii_type="@cdktf/provider-azurerm.RouteConfig",
    jsii_struct_bases=[cdktf.TerraformMetaArguments],
    name_mapping={
        "count": "count",
        "depends_on": "dependsOn",
        "lifecycle": "lifecycle",
        "provider": "provider",
        "address_prefix": "addressPrefix",
        "name": "name",
        "next_hop_type": "nextHopType",
        "resource_group_name": "resourceGroupName",
        "route_table_name": "routeTableName",
        "next_hop_in_ip_address": "nextHopInIpAddress",
        "timeouts": "timeouts",
    },
)
class RouteConfig(cdktf.TerraformMetaArguments):
    def __init__(
        self,
        *,
        count: typing.Optional[jsii.Number] = None,
        depends_on: typing.Optional[typing.List[cdktf.TerraformResource]] = None,
        lifecycle: typing.Optional[cdktf.TerraformResourceLifecycle] = None,
        provider: typing.Optional[cdktf.TerraformProvider] = None,
        address_prefix: builtins.str,
        name: builtins.str,
        next_hop_type: builtins.str,
        resource_group_name: builtins.str,
        route_table_name: builtins.str,
        next_hop_in_ip_address: typing.Optional[builtins.str] = None,
        timeouts: typing.Optional["RouteTimeouts"] = None,
    ) -> None:
        """
        :param count: 
        :param depends_on: 
        :param lifecycle: 
        :param provider: 
        :param address_prefix: 
        :param name: 
        :param next_hop_type: 
        :param resource_group_name: 
        :param route_table_name: 
        :param next_hop_in_ip_address: 
        :param timeouts: timeouts block.
        """
        if isinstance(lifecycle, dict):
            lifecycle = cdktf.TerraformResourceLifecycle(**lifecycle)
        if isinstance(timeouts, dict):
            timeouts = RouteTimeouts(**timeouts)
        self._values: typing.Dict[str, typing.Any] = {
            "address_prefix": address_prefix,
            "name": name,
            "next_hop_type": next_hop_type,
            "resource_group_name": resource_group_name,
            "route_table_name": route_table_name,
        }
        if count is not None:
            self._values["count"] = count
        if depends_on is not None:
            self._values["depends_on"] = depends_on
        if lifecycle is not None:
            self._values["lifecycle"] = lifecycle
        if provider is not None:
            self._values["provider"] = provider
        if next_hop_in_ip_address is not None:
            self._values["next_hop_in_ip_address"] = next_hop_in_ip_address
        if timeouts is not None:
            self._values["timeouts"] = timeouts

    @builtins.property
    def count(self) -> typing.Optional[jsii.Number]:
        """
        :stability: experimental
        """
        result = self._values.get("count")
        return result

    @builtins.property
    def depends_on(self) -> typing.Optional[typing.List[cdktf.TerraformResource]]:
        """
        :stability: experimental
        """
        result = self._values.get("depends_on")
        return result

    @builtins.property
    def lifecycle(self) -> typing.Optional[cdktf.TerraformResourceLifecycle]:
        """
        :stability: experimental
        """
        result = self._values.get("lifecycle")
        return result

    @builtins.property
    def provider(self) -> typing.Optional[cdktf.TerraformProvider]:
        """
        :stability: experimental
        """
        result = self._values.get("provider")
        return result

    @builtins.property
    def address_prefix(self) -> builtins.str:
        result = self._values.get("address_prefix")
        assert result is not None, "Required property 'address_prefix' is missing"
        return result

    @builtins.property
    def name(self) -> builtins.str:
        result = self._values.get("name")
        assert result is not None, "Required property 'name' is missing"
        return result

    @builtins.property
    def next_hop_type(self) -> builtins.str:
        result = self._values.get("next_hop_type")
        assert result is not None, "Required property 'next_hop_type' is missing"
        return result

    @builtins.property
    def resource_group_name(self) -> builtins.str:
        result = self._values.get("resource_group_name")
        assert result is not None, "Required property 'resource_group_name' is missing"
        return result

    @builtins.property
    def route_table_name(self) -> builtins.str:
        result = self._values.get("route_table_name")
        assert result is not None, "Required property 'route_table_name' is missing"
        return result

    @builtins.property
    def next_hop_in_ip_address(self) -> typing.Optional[builtins.str]:
        result = self._values.get("next_hop_in_ip_address")
        return result

    @builtins.property
    def timeouts(self) -> typing.Optional["RouteTimeouts"]:
        """timeouts block."""
        result = self._values.get("timeouts")
        return result

    def __eq__(self, rhs: typing.Any) -> builtins.bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs: typing.Any) -> builtins.bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return "RouteConfig(%s)" % ", ".join(
            k + "=" + repr(v) for k, v in self._values.items()
        )


class RouteTable(
    cdktf.TerraformResource,
    metaclass=jsii.JSIIMeta,
    jsii_type="@cdktf/provider-azurerm.RouteTable",
):
    def __init__(
        self,
        scope: constructs.Construct,
        id: builtins.str,
        *,
        location: builtins.str,
        name: builtins.str,
        resource_group_name: builtins.str,
        disable_bgp_route_propagation: typing.Optional[builtins.bool] = None,
        route: typing.Optional[typing.List["RouteTableRoute"]] = None,
        tags: typing.Optional[typing.Mapping[builtins.str, builtins.str]] = None,
        timeouts: typing.Optional["RouteTableTimeouts"] = None,
        count: typing.Optional[jsii.Number] = None,
        depends_on: typing.Optional[typing.List[cdktf.TerraformResource]] = None,
        lifecycle: typing.Optional[cdktf.TerraformResourceLifecycle] = None,
        provider: typing.Optional[cdktf.TerraformProvider] = None,
    ) -> None:
        """
        :param scope: -
        :param id: -
        :param location: 
        :param name: 
        :param resource_group_name: 
        :param disable_bgp_route_propagation: 
        :param route: 
        :param tags: 
        :param timeouts: timeouts block.
        :param count: 
        :param depends_on: 
        :param lifecycle: 
        :param provider: 
        """
        config = RouteTableConfig(
            location=location,
            name=name,
            resource_group_name=resource_group_name,
            disable_bgp_route_propagation=disable_bgp_route_propagation,
            route=route,
            tags=tags,
            timeouts=timeouts,
            count=count,
            depends_on=depends_on,
            lifecycle=lifecycle,
            provider=provider,
        )

        jsii.create(RouteTable, self, [scope, id, config])

    @jsii.member(jsii_name="synthesizeAttributes")
    def _synthesize_attributes(self) -> typing.Mapping[builtins.str, typing.Any]:
        return jsii.invoke(self, "synthesizeAttributes", [])

    @builtins.property # type: ignore
    @jsii.member(jsii_name="subnets")
    def subnets(self) -> typing.List[builtins.str]:
        return jsii.get(self, "subnets")

    @builtins.property # type: ignore
    @jsii.member(jsii_name="location")
    def location(self) -> builtins.str:
        return jsii.get(self, "location")

    @location.setter # type: ignore
    def location(self, value: builtins.str) -> None:
        jsii.set(self, "location", value)

    @builtins.property # type: ignore
    @jsii.member(jsii_name="name")
    def name(self) -> builtins.str:
        return jsii.get(self, "name")

    @name.setter # type: ignore
    def name(self, value: builtins.str) -> None:
        jsii.set(self, "name", value)

    @builtins.property # type: ignore
    @jsii.member(jsii_name="resourceGroupName")
    def resource_group_name(self) -> builtins.str:
        return jsii.get(self, "resourceGroupName")

    @resource_group_name.setter # type: ignore
    def resource_group_name(self, value: builtins.str) -> None:
        jsii.set(self, "resourceGroupName", value)

    @builtins.property # type: ignore
    @jsii.member(jsii_name="disableBgpRoutePropagation")
    def disable_bgp_route_propagation(self) -> typing.Optional[builtins.bool]:
        return jsii.get(self, "disableBgpRoutePropagation")

    @disable_bgp_route_propagation.setter # type: ignore
    def disable_bgp_route_propagation(
        self,
        value: typing.Optional[builtins.bool],
    ) -> None:
        jsii.set(self, "disableBgpRoutePropagation", value)

    @builtins.property # type: ignore
    @jsii.member(jsii_name="id")
    def id(self) -> typing.Optional[builtins.str]:
        return jsii.get(self, "id")

    @id.setter # type: ignore
    def id(self, value: typing.Optional[builtins.str]) -> None:
        jsii.set(self, "id", value)

    @builtins.property # type: ignore
    @jsii.member(jsii_name="route")
    def route(self) -> typing.Optional[typing.List["RouteTableRoute"]]:
        return jsii.get(self, "route")

    @route.setter # type: ignore
    def route(self, value: typing.Optional[typing.List["RouteTableRoute"]]) -> None:
        jsii.set(self, "route", value)

    @builtins.property # type: ignore
    @jsii.member(jsii_name="tags")
    def tags(self) -> typing.Optional[typing.Mapping[builtins.str, builtins.str]]:
        return jsii.get(self, "tags")

    @tags.setter # type: ignore
    def tags(
        self,
        value: typing.Optional[typing.Mapping[builtins.str, builtins.str]],
    ) -> None:
        jsii.set(self, "tags", value)

    @builtins.property # type: ignore
    @jsii.member(jsii_name="timeouts")
    def timeouts(self) -> typing.Optional["RouteTableTimeouts"]:
        return jsii.get(self, "timeouts")

    @timeouts.setter # type: ignore
    def timeouts(self, value: typing.Optional["RouteTableTimeouts"]) -> None:
        jsii.set(self, "timeouts", value)


@jsii.data_type(
    jsii_type="@cdktf/provider-azurerm.RouteTableConfig",
    jsii_struct_bases=[cdktf.TerraformMetaArguments],
    name_mapping={
        "count": "count",
        "depends_on": "dependsOn",
        "lifecycle": "lifecycle",
        "provider": "provider",
        "location": "location",
        "name": "name",
        "resource_group_name": "resourceGroupName",
        "disable_bgp_route_propagation": "disableBgpRoutePropagation",
        "route": "route",
        "tags": "tags",
        "timeouts": "timeouts",
    },
)
class RouteTableConfig(cdktf.TerraformMetaArguments):
    def __init__(
        self,
        *,
        count: typing.Optional[jsii.Number] = None,
        depends_on: typing.Optional[typing.List[cdktf.TerraformResource]] = None,
        lifecycle: typing.Optional[cdktf.TerraformResourceLifecycle] = None,
        provider: typing.Optional[cdktf.TerraformProvider] = None,
        location: builtins.str,
        name: builtins.str,
        resource_group_name: builtins.str,
        disable_bgp_route_propagation: typing.Optional[builtins.bool] = None,
        route: typing.Optional[typing.List["RouteTableRoute"]] = None,
        tags: typing.Optional[typing.Mapping[builtins.str, builtins.str]] = None,
        timeouts: typing.Optional["RouteTableTimeouts"] = None,
    ) -> None:
        """
        :param count: 
        :param depends_on: 
        :param lifecycle: 
        :param provider: 
        :param location: 
        :param name: 
        :param resource_group_name: 
        :param disable_bgp_route_propagation: 
        :param route: 
        :param tags: 
        :param timeouts: timeouts block.
        """
        if isinstance(lifecycle, dict):
            lifecycle = cdktf.TerraformResourceLifecycle(**lifecycle)
        if isinstance(timeouts, dict):
            timeouts = RouteTableTimeouts(**timeouts)
        self._values: typing.Dict[str, typing.Any] = {
            "location": location,
            "name": name,
            "resource_group_name": resource_group_name,
        }
        if count is not None:
            self._values["count"] = count
        if depends_on is not None:
            self._values["depends_on"] = depends_on
        if lifecycle is not None:
            self._values["lifecycle"] = lifecycle
        if provider is not None:
            self._values["provider"] = provider
        if disable_bgp_route_propagation is not None:
            self._values["disable_bgp_route_propagation"] = disable_bgp_route_propagation
        if route is not None:
            self._values["route"] = route
        if tags is not None:
            self._values["tags"] = tags
        if timeouts is not None:
            self._values["timeouts"] = timeouts

    @builtins.property
    def count(self) -> typing.Optional[jsii.Number]:
        """
        :stability: experimental
        """
        result = self._values.get("count")
        return result

    @builtins.property
    def depends_on(self) -> typing.Optional[typing.List[cdktf.TerraformResource]]:
        """
        :stability: experimental
        """
        result = self._values.get("depends_on")
        return result

    @builtins.property
    def lifecycle(self) -> typing.Optional[cdktf.TerraformResourceLifecycle]:
        """
        :stability: experimental
        """
        result = self._values.get("lifecycle")
        return result

    @builtins.property
    def provider(self) -> typing.Optional[cdktf.TerraformProvider]:
        """
        :stability: experimental
        """
        result = self._values.get("provider")
        return result

    @builtins.property
    def location(self) -> builtins.str:
        result = self._values.get("location")
        assert result is not None, "Required property 'location' is missing"
        return result

    @builtins.property
    def name(self) -> builtins.str:
        result = self._values.get("name")
        assert result is not None, "Required property 'name' is missing"
        return result

    @builtins.property
    def resource_group_name(self) -> builtins.str:
        result = self._values.get("resource_group_name")
        assert result is not None, "Required property 'resource_group_name' is missing"
        return result

    @builtins.property
    def disable_bgp_route_propagation(self) -> typing.Optional[builtins.bool]:
        result = self._values.get("disable_bgp_route_propagation")
        return result

    @builtins.property
    def route(self) -> typing.Optional[typing.List["RouteTableRoute"]]:
        result = self._values.get("route")
        return result

    @builtins.property
    def tags(self) -> typing.Optional[typing.Mapping[builtins.str, builtins.str]]:
        result = self._values.get("tags")
        return result

    @builtins.property
    def timeouts(self) -> typing.Optional["RouteTableTimeouts"]:
        """timeouts block."""
        result = self._values.get("timeouts")
        return result

    def __eq__(self, rhs: typing.Any) -> builtins.bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs: typing.Any) -> builtins.bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return "RouteTableConfig(%s)" % ", ".join(
            k + "=" + repr(v) for k, v in self._values.items()
        )


@jsii.data_type(
    jsii_type="@cdktf/provider-azurerm.RouteTableRoute",
    jsii_struct_bases=[],
    name_mapping={
        "address_prefix": "addressPrefix",
        "name": "name",
        "next_hop_in_ip_address": "nextHopInIpAddress",
        "next_hop_type": "nextHopType",
    },
)
class RouteTableRoute:
    def __init__(
        self,
        *,
        address_prefix: typing.Optional[builtins.str] = None,
        name: typing.Optional[builtins.str] = None,
        next_hop_in_ip_address: typing.Optional[builtins.str] = None,
        next_hop_type: typing.Optional[builtins.str] = None,
    ) -> None:
        """
        :param address_prefix: 
        :param name: 
        :param next_hop_in_ip_address: 
        :param next_hop_type: 
        """
        self._values: typing.Dict[str, typing.Any] = {}
        if address_prefix is not None:
            self._values["address_prefix"] = address_prefix
        if name is not None:
            self._values["name"] = name
        if next_hop_in_ip_address is not None:
            self._values["next_hop_in_ip_address"] = next_hop_in_ip_address
        if next_hop_type is not None:
            self._values["next_hop_type"] = next_hop_type

    @builtins.property
    def address_prefix(self) -> typing.Optional[builtins.str]:
        result = self._values.get("address_prefix")
        return result

    @builtins.property
    def name(self) -> typing.Optional[builtins.str]:
        result = self._values.get("name")
        return result

    @builtins.property
    def next_hop_in_ip_address(self) -> typing.Optional[builtins.str]:
        result = self._values.get("next_hop_in_ip_address")
        return result

    @builtins.property
    def next_hop_type(self) -> typing.Optional[builtins.str]:
        result = self._values.get("next_hop_type")
        return result

    def __eq__(self, rhs: typing.Any) -> builtins.bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs: typing.Any) -> builtins.bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return "RouteTableRoute(%s)" % ", ".join(
            k + "=" + repr(v) for k, v in self._values.items()
        )


@jsii.data_type(
    jsii_type="@cdktf/provider-azurerm.RouteTableTimeouts",
    jsii_struct_bases=[],
    name_mapping={
        "create": "create",
        "delete": "delete",
        "read": "read",
        "update": "update",
    },
)
class RouteTableTimeouts:
    def __init__(
        self,
        *,
        create: typing.Optional[builtins.str] = None,
        delete: typing.Optional[builtins.str] = None,
        read: typing.Optional[builtins.str] = None,
        update: typing.Optional[builtins.str] = None,
    ) -> None:
        """
        :param create: 
        :param delete: 
        :param read: 
        :param update: 
        """
        self._values: typing.Dict[str, typing.Any] = {}
        if create is not None:
            self._values["create"] = create
        if delete is not None:
            self._values["delete"] = delete
        if read is not None:
            self._values["read"] = read
        if update is not None:
            self._values["update"] = update

    @builtins.property
    def create(self) -> typing.Optional[builtins.str]:
        result = self._values.get("create")
        return result

    @builtins.property
    def delete(self) -> typing.Optional[builtins.str]:
        result = self._values.get("delete")
        return result

    @builtins.property
    def read(self) -> typing.Optional[builtins.str]:
        result = self._values.get("read")
        return result

    @builtins.property
    def update(self) -> typing.Optional[builtins.str]:
        result = self._values.get("update")
        return result

    def __eq__(self, rhs: typing.Any) -> builtins.bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs: typing.Any) -> builtins.bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return "RouteTableTimeouts(%s)" % ", ".join(
            k + "=" + repr(v) for k, v in self._values.items()
        )


@jsii.data_type(
    jsii_type="@cdktf/provider-azurerm.RouteTimeouts",
    jsii_struct_bases=[],
    name_mapping={
        "create": "create",
        "delete": "delete",
        "read": "read",
        "update": "update",
    },
)
class RouteTimeouts:
    def __init__(
        self,
        *,
        create: typing.Optional[builtins.str] = None,
        delete: typing.Optional[builtins.str] = None,
        read: typing.Optional[builtins.str] = None,
        update: typing.Optional[builtins.str] = None,
    ) -> None:
        """
        :param create: 
        :param delete: 
        :param read: 
        :param update: 
        """
        self._values: typing.Dict[str, typing.Any] = {}
        if create is not None:
            self._values["create"] = create
        if delete is not None:
            self._values["delete"] = delete
        if read is not None:
            self._values["read"] = read
        if update is not None:
            self._values["update"] = update

    @builtins.property
    def create(self) -> typing.Optional[builtins.str]:
        result = self._values.get("create")
        return result

    @builtins.property
    def delete(self) -> typing.Optional[builtins.str]:
        result = self._values.get("delete")
        return result

    @builtins.property
    def read(self) -> typing.Optional[builtins.str]:
        result = self._values.get("read")
        return result

    @builtins.property
    def update(self) -> typing.Optional[builtins.str]:
        result = self._values.get("update")
        return result

    def __eq__(self, rhs: typing.Any) -> builtins.bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs: typing.Any) -> builtins.bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return "RouteTimeouts(%s)" % ", ".join(
            k + "=" + repr(v) for k, v in self._values.items()
        )


class SearchService(
    cdktf.TerraformResource,
    metaclass=jsii.JSIIMeta,
    jsii_type="@cdktf/provider-azurerm.SearchService",
):
    def __init__(
        self,
        scope: constructs.Construct,
        id: builtins.str,
        *,
        location: builtins.str,
        name: builtins.str,
        resource_group_name: builtins.str,
        sku: builtins.str,
        partition_count: typing.Optional[jsii.Number] = None,
        replica_count: typing.Optional[jsii.Number] = None,
        tags: typing.Optional[typing.Mapping[builtins.str, builtins.str]] = None,
        timeouts: typing.Optional["SearchServiceTimeouts"] = None,
        count: typing.Optional[jsii.Number] = None,
        depends_on: typing.Optional[typing.List[cdktf.TerraformResource]] = None,
        lifecycle: typing.Optional[cdktf.TerraformResourceLifecycle] = None,
        provider: typing.Optional[cdktf.TerraformProvider] = None,
    ) -> None:
        """
        :param scope: -
        :param id: -
        :param location: 
        :param name: 
        :param resource_group_name: 
        :param sku: 
        :param partition_count: 
        :param replica_count: 
        :param tags: 
        :param timeouts: timeouts block.
        :param count: 
        :param depends_on: 
        :param lifecycle: 
        :param provider: 
        """
        config = SearchServiceConfig(
            location=location,
            name=name,
            resource_group_name=resource_group_name,
            sku=sku,
            partition_count=partition_count,
            replica_count=replica_count,
            tags=tags,
            timeouts=timeouts,
            count=count,
            depends_on=depends_on,
            lifecycle=lifecycle,
            provider=provider,
        )

        jsii.create(SearchService, self, [scope, id, config])

    @jsii.member(jsii_name="queryKeys")
    def query_keys(self, index: builtins.str) -> "SearchServiceQueryKeys":
        """
        :param index: -
        """
        return jsii.invoke(self, "queryKeys", [index])

    @jsii.member(jsii_name="synthesizeAttributes")
    def _synthesize_attributes(self) -> typing.Mapping[builtins.str, typing.Any]:
        return jsii.invoke(self, "synthesizeAttributes", [])

    @builtins.property # type: ignore
    @jsii.member(jsii_name="primaryKey")
    def primary_key(self) -> builtins.str:
        return jsii.get(self, "primaryKey")

    @builtins.property # type: ignore
    @jsii.member(jsii_name="secondaryKey")
    def secondary_key(self) -> builtins.str:
        return jsii.get(self, "secondaryKey")

    @builtins.property # type: ignore
    @jsii.member(jsii_name="location")
    def location(self) -> builtins.str:
        return jsii.get(self, "location")

    @location.setter # type: ignore
    def location(self, value: builtins.str) -> None:
        jsii.set(self, "location", value)

    @builtins.property # type: ignore
    @jsii.member(jsii_name="name")
    def name(self) -> builtins.str:
        return jsii.get(self, "name")

    @name.setter # type: ignore
    def name(self, value: builtins.str) -> None:
        jsii.set(self, "name", value)

    @builtins.property # type: ignore
    @jsii.member(jsii_name="resourceGroupName")
    def resource_group_name(self) -> builtins.str:
        return jsii.get(self, "resourceGroupName")

    @resource_group_name.setter # type: ignore
    def resource_group_name(self, value: builtins.str) -> None:
        jsii.set(self, "resourceGroupName", value)

    @builtins.property # type: ignore
    @jsii.member(jsii_name="sku")
    def sku(self) -> builtins.str:
        return jsii.get(self, "sku")

    @sku.setter # type: ignore
    def sku(self, value: builtins.str) -> None:
        jsii.set(self, "sku", value)

    @builtins.property # type: ignore
    @jsii.member(jsii_name="id")
    def id(self) -> typing.Optional[builtins.str]:
        return jsii.get(self, "id")

    @id.setter # type: ignore
    def id(self, value: typing.Optional[builtins.str]) -> None:
        jsii.set(self, "id", value)

    @builtins.property # type: ignore
    @jsii.member(jsii_name="partitionCount")
    def partition_count(self) -> typing.Optional[jsii.Number]:
        return jsii.get(self, "partitionCount")

    @partition_count.setter # type: ignore
    def partition_count(self, value: typing.Optional[jsii.Number]) -> None:
        jsii.set(self, "partitionCount", value)

    @builtins.property # type: ignore
    @jsii.member(jsii_name="replicaCount")
    def replica_count(self) -> typing.Optional[jsii.Number]:
        return jsii.get(self, "replicaCount")

    @replica_count.setter # type: ignore
    def replica_count(self, value: typing.Optional[jsii.Number]) -> None:
        jsii.set(self, "replicaCount", value)

    @builtins.property # type: ignore
    @jsii.member(jsii_name="tags")
    def tags(self) -> typing.Optional[typing.Mapping[builtins.str, builtins.str]]:
        return jsii.get(self, "tags")

    @tags.setter # type: ignore
    def tags(
        self,
        value: typing.Optional[typing.Mapping[builtins.str, builtins.str]],
    ) -> None:
        jsii.set(self, "tags", value)

    @builtins.property # type: ignore
    @jsii.member(jsii_name="timeouts")
    def timeouts(self) -> typing.Optional["SearchServiceTimeouts"]:
        return jsii.get(self, "timeouts")

    @timeouts.setter # type: ignore
    def timeouts(self, value: typing.Optional["SearchServiceTimeouts"]) -> None:
        jsii.set(self, "timeouts", value)


@jsii.data_type(
    jsii_type="@cdktf/provider-azurerm.SearchServiceConfig",
    jsii_struct_bases=[cdktf.TerraformMetaArguments],
    name_mapping={
        "count": "count",
        "depends_on": "dependsOn",
        "lifecycle": "lifecycle",
        "provider": "provider",
        "location": "location",
        "name": "name",
        "resource_group_name": "resourceGroupName",
        "sku": "sku",
        "partition_count": "partitionCount",
        "replica_count": "replicaCount",
        "tags": "tags",
        "timeouts": "timeouts",
    },
)
class SearchServiceConfig(cdktf.TerraformMetaArguments):
    def __init__(
        self,
        *,
        count: typing.Optional[jsii.Number] = None,
        depends_on: typing.Optional[typing.List[cdktf.TerraformResource]] = None,
        lifecycle: typing.Optional[cdktf.TerraformResourceLifecycle] = None,
        provider: typing.Optional[cdktf.TerraformProvider] = None,
        location: builtins.str,
        name: builtins.str,
        resource_group_name: builtins.str,
        sku: builtins.str,
        partition_count: typing.Optional[jsii.Number] = None,
        replica_count: typing.Optional[jsii.Number] = None,
        tags: typing.Optional[typing.Mapping[builtins.str, builtins.str]] = None,
        timeouts: typing.Optional["SearchServiceTimeouts"] = None,
    ) -> None:
        """
        :param count: 
        :param depends_on: 
        :param lifecycle: 
        :param provider: 
        :param location: 
        :param name: 
        :param resource_group_name: 
        :param sku: 
        :param partition_count: 
        :param replica_count: 
        :param tags: 
        :param timeouts: timeouts block.
        """
        if isinstance(lifecycle, dict):
            lifecycle = cdktf.TerraformResourceLifecycle(**lifecycle)
        if isinstance(timeouts, dict):
            timeouts = SearchServiceTimeouts(**timeouts)
        self._values: typing.Dict[str, typing.Any] = {
            "location": location,
            "name": name,
            "resource_group_name": resource_group_name,
            "sku": sku,
        }
        if count is not None:
            self._values["count"] = count
        if depends_on is not None:
            self._values["depends_on"] = depends_on
        if lifecycle is not None:
            self._values["lifecycle"] = lifecycle
        if provider is not None:
            self._values["provider"] = provider
        if partition_count is not None:
            self._values["partition_count"] = partition_count
        if replica_count is not None:
            self._values["replica_count"] = replica_count
        if tags is not None:
            self._values["tags"] = tags
        if timeouts is not None:
            self._values["timeouts"] = timeouts

    @builtins.property
    def count(self) -> typing.Optional[jsii.Number]:
        """
        :stability: experimental
        """
        result = self._values.get("count")
        return result

    @builtins.property
    def depends_on(self) -> typing.Optional[typing.List[cdktf.TerraformResource]]:
        """
        :stability: experimental
        """
        result = self._values.get("depends_on")
        return result

    @builtins.property
    def lifecycle(self) -> typing.Optional[cdktf.TerraformResourceLifecycle]:
        """
        :stability: experimental
        """
        result = self._values.get("lifecycle")
        return result

    @builtins.property
    def provider(self) -> typing.Optional[cdktf.TerraformProvider]:
        """
        :stability: experimental
        """
        result = self._values.get("provider")
        return result

    @builtins.property
    def location(self) -> builtins.str:
        result = self._values.get("location")
        assert result is not None, "Required property 'location' is missing"
        return result

    @builtins.property
    def name(self) -> builtins.str:
        result = self._values.get("name")
        assert result is not None, "Required property 'name' is missing"
        return result

    @builtins.property
    def resource_group_name(self) -> builtins.str:
        result = self._values.get("resource_group_name")
        assert result is not None, "Required property 'resource_group_name' is missing"
        return result

    @builtins.property
    def sku(self) -> builtins.str:
        result = self._values.get("sku")
        assert result is not None, "Required property 'sku' is missing"
        return result

    @builtins.property
    def partition_count(self) -> typing.Optional[jsii.Number]:
        result = self._values.get("partition_count")
        return result

    @builtins.property
    def replica_count(self) -> typing.Optional[jsii.Number]:
        result = self._values.get("replica_count")
        return result

    @builtins.property
    def tags(self) -> typing.Optional[typing.Mapping[builtins.str, builtins.str]]:
        result = self._values.get("tags")
        return result

    @builtins.property
    def timeouts(self) -> typing.Optional["SearchServiceTimeouts"]:
        """timeouts block."""
        result = self._values.get("timeouts")
        return result

    def __eq__(self, rhs: typing.Any) -> builtins.bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs: typing.Any) -> builtins.bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return "SearchServiceConfig(%s)" % ", ".join(
            k + "=" + repr(v) for k, v in self._values.items()
        )


class SearchServiceQueryKeys(
    cdktf.ComplexComputedList,
    metaclass=jsii.JSIIMeta,
    jsii_type="@cdktf/provider-azurerm.SearchServiceQueryKeys",
):
    def __init__(
        self,
        terraform_resource: cdktf.ITerraformResource,
        terraform_attribute: builtins.str,
        index: builtins.str,
    ) -> None:
        """
        :param terraform_resource: -
        :param terraform_attribute: -
        :param index: -

        :stability: experimental
        """
        jsii.create(SearchServiceQueryKeys, self, [terraform_resource, terraform_attribute, index])

    @builtins.property # type: ignore
    @jsii.member(jsii_name="key")
    def key(self) -> builtins.str:
        return jsii.get(self, "key")

    @builtins.property # type: ignore
    @jsii.member(jsii_name="name")
    def name(self) -> builtins.str:
        return jsii.get(self, "name")


@jsii.data_type(
    jsii_type="@cdktf/provider-azurerm.SearchServiceTimeouts",
    jsii_struct_bases=[],
    name_mapping={
        "create": "create",
        "delete": "delete",
        "read": "read",
        "update": "update",
    },
)
class SearchServiceTimeouts:
    def __init__(
        self,
        *,
        create: typing.Optional[builtins.str] = None,
        delete: typing.Optional[builtins.str] = None,
        read: typing.Optional[builtins.str] = None,
        update: typing.Optional[builtins.str] = None,
    ) -> None:
        """
        :param create: 
        :param delete: 
        :param read: 
        :param update: 
        """
        self._values: typing.Dict[str, typing.Any] = {}
        if create is not None:
            self._values["create"] = create
        if delete is not None:
            self._values["delete"] = delete
        if read is not None:
            self._values["read"] = read
        if update is not None:
            self._values["update"] = update

    @builtins.property
    def create(self) -> typing.Optional[builtins.str]:
        result = self._values.get("create")
        return result

    @builtins.property
    def delete(self) -> typing.Optional[builtins.str]:
        result = self._values.get("delete")
        return result

    @builtins.property
    def read(self) -> typing.Optional[builtins.str]:
        result = self._values.get("read")
        return result

    @builtins.property
    def update(self) -> typing.Optional[builtins.str]:
        result = self._values.get("update")
        return result

    def __eq__(self, rhs: typing.Any) -> builtins.bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs: typing.Any) -> builtins.bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return "SearchServiceTimeouts(%s)" % ", ".join(
            k + "=" + repr(v) for k, v in self._values.items()
        )


class SecurityCenterContact(
    cdktf.TerraformResource,
    metaclass=jsii.JSIIMeta,
    jsii_type="@cdktf/provider-azurerm.SecurityCenterContact",
):
    def __init__(
        self,
        scope: constructs.Construct,
        id: builtins.str,
        *,
        alert_notifications: builtins.bool,
        alerts_to_admins: builtins.bool,
        email: builtins.str,
        phone: typing.Optional[builtins.str] = None,
        timeouts: typing.Optional["SecurityCenterContactTimeouts"] = None,
        count: typing.Optional[jsii.Number] = None,
        depends_on: typing.Optional[typing.List[cdktf.TerraformResource]] = None,
        lifecycle: typing.Optional[cdktf.TerraformResourceLifecycle] = None,
        provider: typing.Optional[cdktf.TerraformProvider] = None,
    ) -> None:
        """
        :param scope: -
        :param id: -
        :param alert_notifications: 
        :param alerts_to_admins: 
        :param email: 
        :param phone: 
        :param timeouts: timeouts block.
        :param count: 
        :param depends_on: 
        :param lifecycle: 
        :param provider: 
        """
        config = SecurityCenterContactConfig(
            alert_notifications=alert_notifications,
            alerts_to_admins=alerts_to_admins,
            email=email,
            phone=phone,
            timeouts=timeouts,
            count=count,
            depends_on=depends_on,
            lifecycle=lifecycle,
            provider=provider,
        )

        jsii.create(SecurityCenterContact, self, [scope, id, config])

    @jsii.member(jsii_name="synthesizeAttributes")
    def _synthesize_attributes(self) -> typing.Mapping[builtins.str, typing.Any]:
        return jsii.invoke(self, "synthesizeAttributes", [])

    @builtins.property # type: ignore
    @jsii.member(jsii_name="alertNotifications")
    def alert_notifications(self) -> builtins.bool:
        return jsii.get(self, "alertNotifications")

    @alert_notifications.setter # type: ignore
    def alert_notifications(self, value: builtins.bool) -> None:
        jsii.set(self, "alertNotifications", value)

    @builtins.property # type: ignore
    @jsii.member(jsii_name="alertsToAdmins")
    def alerts_to_admins(self) -> builtins.bool:
        return jsii.get(self, "alertsToAdmins")

    @alerts_to_admins.setter # type: ignore
    def alerts_to_admins(self, value: builtins.bool) -> None:
        jsii.set(self, "alertsToAdmins", value)

    @builtins.property # type: ignore
    @jsii.member(jsii_name="email")
    def email(self) -> builtins.str:
        return jsii.get(self, "email")

    @email.setter # type: ignore
    def email(self, value: builtins.str) -> None:
        jsii.set(self, "email", value)

    @builtins.property # type: ignore
    @jsii.member(jsii_name="id")
    def id(self) -> typing.Optional[builtins.str]:
        return jsii.get(self, "id")

    @id.setter # type: ignore
    def id(self, value: typing.Optional[builtins.str]) -> None:
        jsii.set(self, "id", value)

    @builtins.property # type: ignore
    @jsii.member(jsii_name="phone")
    def phone(self) -> typing.Optional[builtins.str]:
        return jsii.get(self, "phone")

    @phone.setter # type: ignore
    def phone(self, value: typing.Optional[builtins.str]) -> None:
        jsii.set(self, "phone", value)

    @builtins.property # type: ignore
    @jsii.member(jsii_name="timeouts")
    def timeouts(self) -> typing.Optional["SecurityCenterContactTimeouts"]:
        return jsii.get(self, "timeouts")

    @timeouts.setter # type: ignore
    def timeouts(self, value: typing.Optional["SecurityCenterContactTimeouts"]) -> None:
        jsii.set(self, "timeouts", value)


@jsii.data_type(
    jsii_type="@cdktf/provider-azurerm.SecurityCenterContactConfig",
    jsii_struct_bases=[cdktf.TerraformMetaArguments],
    name_mapping={
        "count": "count",
        "depends_on": "dependsOn",
        "lifecycle": "lifecycle",
        "provider": "provider",
        "alert_notifications": "alertNotifications",
        "alerts_to_admins": "alertsToAdmins",
        "email": "email",
        "phone": "phone",
        "timeouts": "timeouts",
    },
)
class SecurityCenterContactConfig(cdktf.TerraformMetaArguments):
    def __init__(
        self,
        *,
        count: typing.Optional[jsii.Number] = None,
        depends_on: typing.Optional[typing.List[cdktf.TerraformResource]] = None,
        lifecycle: typing.Optional[cdktf.TerraformResourceLifecycle] = None,
        provider: typing.Optional[cdktf.TerraformProvider] = None,
        alert_notifications: builtins.bool,
        alerts_to_admins: builtins.bool,
        email: builtins.str,
        phone: typing.Optional[builtins.str] = None,
        timeouts: typing.Optional["SecurityCenterContactTimeouts"] = None,
    ) -> None:
        """
        :param count: 
        :param depends_on: 
        :param lifecycle: 
        :param provider: 
        :param alert_notifications: 
        :param alerts_to_admins: 
        :param email: 
        :param phone: 
        :param timeouts: timeouts block.
        """
        if isinstance(lifecycle, dict):
            lifecycle = cdktf.TerraformResourceLifecycle(**lifecycle)
        if isinstance(timeouts, dict):
            timeouts = SecurityCenterContactTimeouts(**timeouts)
        self._values: typing.Dict[str, typing.Any] = {
            "alert_notifications": alert_notifications,
            "alerts_to_admins": alerts_to_admins,
            "email": email,
        }
        if count is not None:
            self._values["count"] = count
        if depends_on is not None:
            self._values["depends_on"] = depends_on
        if lifecycle is not None:
            self._values["lifecycle"] = lifecycle
        if provider is not None:
            self._values["provider"] = provider
        if phone is not None:
            self._values["phone"] = phone
        if timeouts is not None:
            self._values["timeouts"] = timeouts

    @builtins.property
    def count(self) -> typing.Optional[jsii.Number]:
        """
        :stability: experimental
        """
        result = self._values.get("count")
        return result

    @builtins.property
    def depends_on(self) -> typing.Optional[typing.List[cdktf.TerraformResource]]:
        """
        :stability: experimental
        """
        result = self._values.get("depends_on")
        return result

    @builtins.property
    def lifecycle(self) -> typing.Optional[cdktf.TerraformResourceLifecycle]:
        """
        :stability: experimental
        """
        result = self._values.get("lifecycle")
        return result

    @builtins.property
    def provider(self) -> typing.Optional[cdktf.TerraformProvider]:
        """
        :stability: experimental
        """
        result = self._values.get("provider")
        return result

    @builtins.property
    def alert_notifications(self) -> builtins.bool:
        result = self._values.get("alert_notifications")
        assert result is not None, "Required property 'alert_notifications' is missing"
        return result

    @builtins.property
    def alerts_to_admins(self) -> builtins.bool:
        result = self._values.get("alerts_to_admins")
        assert result is not None, "Required property 'alerts_to_admins' is missing"
        return result

    @builtins.property
    def email(self) -> builtins.str:
        result = self._values.get("email")
        assert result is not None, "Required property 'email' is missing"
        return result

    @builtins.property
    def phone(self) -> typing.Optional[builtins.str]:
        result = self._values.get("phone")
        return result

    @builtins.property
    def timeouts(self) -> typing.Optional["SecurityCenterContactTimeouts"]:
        """timeouts block."""
        result = self._values.get("timeouts")
        return result

    def __eq__(self, rhs: typing.Any) -> builtins.bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs: typing.Any) -> builtins.bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return "SecurityCenterContactConfig(%s)" % ", ".join(
            k + "=" + repr(v) for k, v in self._values.items()
        )


@jsii.data_type(
    jsii_type="@cdktf/provider-azurerm.SecurityCenterContactTimeouts",
    jsii_struct_bases=[],
    name_mapping={
        "create": "create",
        "delete": "delete",
        "read": "read",
        "update": "update",
    },
)
class SecurityCenterContactTimeouts:
    def __init__(
        self,
        *,
        create: typing.Optional[builtins.str] = None,
        delete: typing.Optional[builtins.str] = None,
        read: typing.Optional[builtins.str] = None,
        update: typing.Optional[builtins.str] = None,
    ) -> None:
        """
        :param create: 
        :param delete: 
        :param read: 
        :param update: 
        """
        self._values: typing.Dict[str, typing.Any] = {}
        if create is not None:
            self._values["create"] = create
        if delete is not None:
            self._values["delete"] = delete
        if read is not None:
            self._values["read"] = read
        if update is not None:
            self._values["update"] = update

    @builtins.property
    def create(self) -> typing.Optional[builtins.str]:
        result = self._values.get("create")
        return result

    @builtins.property
    def delete(self) -> typing.Optional[builtins.str]:
        result = self._values.get("delete")
        return result

    @builtins.property
    def read(self) -> typing.Optional[builtins.str]:
        result = self._values.get("read")
        return result

    @builtins.property
    def update(self) -> typing.Optional[builtins.str]:
        result = self._values.get("update")
        return result

    def __eq__(self, rhs: typing.Any) -> builtins.bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs: typing.Any) -> builtins.bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return "SecurityCenterContactTimeouts(%s)" % ", ".join(
            k + "=" + repr(v) for k, v in self._values.items()
        )


class SecurityCenterSubscriptionPricing(
    cdktf.TerraformResource,
    metaclass=jsii.JSIIMeta,
    jsii_type="@cdktf/provider-azurerm.SecurityCenterSubscriptionPricing",
):
    def __init__(
        self,
        scope: constructs.Construct,
        id: builtins.str,
        *,
        tier: builtins.str,
        timeouts: typing.Optional["SecurityCenterSubscriptionPricingTimeouts"] = None,
        count: typing.Optional[jsii.Number] = None,
        depends_on: typing.Optional[typing.List[cdktf.TerraformResource]] = None,
        lifecycle: typing.Optional[cdktf.TerraformResourceLifecycle] = None,
        provider: typing.Optional[cdktf.TerraformProvider] = None,
    ) -> None:
        """
        :param scope: -
        :param id: -
        :param tier: 
        :param timeouts: timeouts block.
        :param count: 
        :param depends_on: 
        :param lifecycle: 
        :param provider: 
        """
        config = SecurityCenterSubscriptionPricingConfig(
            tier=tier,
            timeouts=timeouts,
            count=count,
            depends_on=depends_on,
            lifecycle=lifecycle,
            provider=provider,
        )

        jsii.create(SecurityCenterSubscriptionPricing, self, [scope, id, config])

    @jsii.member(jsii_name="synthesizeAttributes")
    def _synthesize_attributes(self) -> typing.Mapping[builtins.str, typing.Any]:
        return jsii.invoke(self, "synthesizeAttributes", [])

    @builtins.property # type: ignore
    @jsii.member(jsii_name="tier")
    def tier(self) -> builtins.str:
        return jsii.get(self, "tier")

    @tier.setter # type: ignore
    def tier(self, value: builtins.str) -> None:
        jsii.set(self, "tier", value)

    @builtins.property # type: ignore
    @jsii.member(jsii_name="id")
    def id(self) -> typing.Optional[builtins.str]:
        return jsii.get(self, "id")

    @id.setter # type: ignore
    def id(self, value: typing.Optional[builtins.str]) -> None:
        jsii.set(self, "id", value)

    @builtins.property # type: ignore
    @jsii.member(jsii_name="timeouts")
    def timeouts(self) -> typing.Optional["SecurityCenterSubscriptionPricingTimeouts"]:
        return jsii.get(self, "timeouts")

    @timeouts.setter # type: ignore
    def timeouts(
        self,
        value: typing.Optional["SecurityCenterSubscriptionPricingTimeouts"],
    ) -> None:
        jsii.set(self, "timeouts", value)


@jsii.data_type(
    jsii_type="@cdktf/provider-azurerm.SecurityCenterSubscriptionPricingConfig",
    jsii_struct_bases=[cdktf.TerraformMetaArguments],
    name_mapping={
        "count": "count",
        "depends_on": "dependsOn",
        "lifecycle": "lifecycle",
        "provider": "provider",
        "tier": "tier",
        "timeouts": "timeouts",
    },
)
class SecurityCenterSubscriptionPricingConfig(cdktf.TerraformMetaArguments):
    def __init__(
        self,
        *,
        count: typing.Optional[jsii.Number] = None,
        depends_on: typing.Optional[typing.List[cdktf.TerraformResource]] = None,
        lifecycle: typing.Optional[cdktf.TerraformResourceLifecycle] = None,
        provider: typing.Optional[cdktf.TerraformProvider] = None,
        tier: builtins.str,
        timeouts: typing.Optional["SecurityCenterSubscriptionPricingTimeouts"] = None,
    ) -> None:
        """
        :param count: 
        :param depends_on: 
        :param lifecycle: 
        :param provider: 
        :param tier: 
        :param timeouts: timeouts block.
        """
        if isinstance(lifecycle, dict):
            lifecycle = cdktf.TerraformResourceLifecycle(**lifecycle)
        if isinstance(timeouts, dict):
            timeouts = SecurityCenterSubscriptionPricingTimeouts(**timeouts)
        self._values: typing.Dict[str, typing.Any] = {
            "tier": tier,
        }
        if count is not None:
            self._values["count"] = count
        if depends_on is not None:
            self._values["depends_on"] = depends_on
        if lifecycle is not None:
            self._values["lifecycle"] = lifecycle
        if provider is not None:
            self._values["provider"] = provider
        if timeouts is not None:
            self._values["timeouts"] = timeouts

    @builtins.property
    def count(self) -> typing.Optional[jsii.Number]:
        """
        :stability: experimental
        """
        result = self._values.get("count")
        return result

    @builtins.property
    def depends_on(self) -> typing.Optional[typing.List[cdktf.TerraformResource]]:
        """
        :stability: experimental
        """
        result = self._values.get("depends_on")
        return result

    @builtins.property
    def lifecycle(self) -> typing.Optional[cdktf.TerraformResourceLifecycle]:
        """
        :stability: experimental
        """
        result = self._values.get("lifecycle")
        return result

    @builtins.property
    def provider(self) -> typing.Optional[cdktf.TerraformProvider]:
        """
        :stability: experimental
        """
        result = self._values.get("provider")
        return result

    @builtins.property
    def tier(self) -> builtins.str:
        result = self._values.get("tier")
        assert result is not None, "Required property 'tier' is missing"
        return result

    @builtins.property
    def timeouts(self) -> typing.Optional["SecurityCenterSubscriptionPricingTimeouts"]:
        """timeouts block."""
        result = self._values.get("timeouts")
        return result

    def __eq__(self, rhs: typing.Any) -> builtins.bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs: typing.Any) -> builtins.bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return "SecurityCenterSubscriptionPricingConfig(%s)" % ", ".join(
            k + "=" + repr(v) for k, v in self._values.items()
        )


@jsii.data_type(
    jsii_type="@cdktf/provider-azurerm.SecurityCenterSubscriptionPricingTimeouts",
    jsii_struct_bases=[],
    name_mapping={
        "create": "create",
        "delete": "delete",
        "read": "read",
        "update": "update",
    },
)
class SecurityCenterSubscriptionPricingTimeouts:
    def __init__(
        self,
        *,
        create: typing.Optional[builtins.str] = None,
        delete: typing.Optional[builtins.str] = None,
        read: typing.Optional[builtins.str] = None,
        update: typing.Optional[builtins.str] = None,
    ) -> None:
        """
        :param create: 
        :param delete: 
        :param read: 
        :param update: 
        """
        self._values: typing.Dict[str, typing.Any] = {}
        if create is not None:
            self._values["create"] = create
        if delete is not None:
            self._values["delete"] = delete
        if read is not None:
            self._values["read"] = read
        if update is not None:
            self._values["update"] = update

    @builtins.property
    def create(self) -> typing.Optional[builtins.str]:
        result = self._values.get("create")
        return result

    @builtins.property
    def delete(self) -> typing.Optional[builtins.str]:
        result = self._values.get("delete")
        return result

    @builtins.property
    def read(self) -> typing.Optional[builtins.str]:
        result = self._values.get("read")
        return result

    @builtins.property
    def update(self) -> typing.Optional[builtins.str]:
        result = self._values.get("update")
        return result

    def __eq__(self, rhs: typing.Any) -> builtins.bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs: typing.Any) -> builtins.bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return "SecurityCenterSubscriptionPricingTimeouts(%s)" % ", ".join(
            k + "=" + repr(v) for k, v in self._values.items()
        )


class SecurityCenterWorkspace(
    cdktf.TerraformResource,
    metaclass=jsii.JSIIMeta,
    jsii_type="@cdktf/provider-azurerm.SecurityCenterWorkspace",
):
    def __init__(
        self,
        scope_: constructs.Construct,
        id: builtins.str,
        *,
        scope: builtins.str,
        workspace_id: builtins.str,
        timeouts: typing.Optional["SecurityCenterWorkspaceTimeouts"] = None,
        count: typing.Optional[jsii.Number] = None,
        depends_on: typing.Optional[typing.List[cdktf.TerraformResource]] = None,
        lifecycle: typing.Optional[cdktf.TerraformResourceLifecycle] = None,
        provider: typing.Optional[cdktf.TerraformProvider] = None,
    ) -> None:
        """
        :param scope_: -
        :param id: -
        :param scope: 
        :param workspace_id: 
        :param timeouts: timeouts block.
        :param count: 
        :param depends_on: 
        :param lifecycle: 
        :param provider: 
        """
        config = SecurityCenterWorkspaceConfig(
            scope=scope,
            workspace_id=workspace_id,
            timeouts=timeouts,
            count=count,
            depends_on=depends_on,
            lifecycle=lifecycle,
            provider=provider,
        )

        jsii.create(SecurityCenterWorkspace, self, [scope_, id, config])

    @jsii.member(jsii_name="synthesizeAttributes")
    def _synthesize_attributes(self) -> typing.Mapping[builtins.str, typing.Any]:
        return jsii.invoke(self, "synthesizeAttributes", [])

    @builtins.property # type: ignore
    @jsii.member(jsii_name="scope")
    def scope(self) -> builtins.str:
        return jsii.get(self, "scope")

    @scope.setter # type: ignore
    def scope(self, value: builtins.str) -> None:
        jsii.set(self, "scope", value)

    @builtins.property # type: ignore
    @jsii.member(jsii_name="workspaceId")
    def workspace_id(self) -> builtins.str:
        return jsii.get(self, "workspaceId")

    @workspace_id.setter # type: ignore
    def workspace_id(self, value: builtins.str) -> None:
        jsii.set(self, "workspaceId", value)

    @builtins.property # type: ignore
    @jsii.member(jsii_name="id")
    def id(self) -> typing.Optional[builtins.str]:
        return jsii.get(self, "id")

    @id.setter # type: ignore
    def id(self, value: typing.Optional[builtins.str]) -> None:
        jsii.set(self, "id", value)

    @builtins.property # type: ignore
    @jsii.member(jsii_name="timeouts")
    def timeouts(self) -> typing.Optional["SecurityCenterWorkspaceTimeouts"]:
        return jsii.get(self, "timeouts")

    @timeouts.setter # type: ignore
    def timeouts(
        self,
        value: typing.Optional["SecurityCenterWorkspaceTimeouts"],
    ) -> None:
        jsii.set(self, "timeouts", value)


@jsii.data_type(
    jsii_type="@cdktf/provider-azurerm.SecurityCenterWorkspaceConfig",
    jsii_struct_bases=[cdktf.TerraformMetaArguments],
    name_mapping={
        "count": "count",
        "depends_on": "dependsOn",
        "lifecycle": "lifecycle",
        "provider": "provider",
        "scope": "scope",
        "workspace_id": "workspaceId",
        "timeouts": "timeouts",
    },
)
class SecurityCenterWorkspaceConfig(cdktf.TerraformMetaArguments):
    def __init__(
        self,
        *,
        count: typing.Optional[jsii.Number] = None,
        depends_on: typing.Optional[typing.List[cdktf.TerraformResource]] = None,
        lifecycle: typing.Optional[cdktf.TerraformResourceLifecycle] = None,
        provider: typing.Optional[cdktf.TerraformProvider] = None,
        scope: builtins.str,
        workspace_id: builtins.str,
        timeouts: typing.Optional["SecurityCenterWorkspaceTimeouts"] = None,
    ) -> None:
        """
        :param count: 
        :param depends_on: 
        :param lifecycle: 
        :param provider: 
        :param scope: 
        :param workspace_id: 
        :param timeouts: timeouts block.
        """
        if isinstance(lifecycle, dict):
            lifecycle = cdktf.TerraformResourceLifecycle(**lifecycle)
        if isinstance(timeouts, dict):
            timeouts = SecurityCenterWorkspaceTimeouts(**timeouts)
        self._values: typing.Dict[str, typing.Any] = {
            "scope": scope,
            "workspace_id": workspace_id,
        }
        if count is not None:
            self._values["count"] = count
        if depends_on is not None:
            self._values["depends_on"] = depends_on
        if lifecycle is not None:
            self._values["lifecycle"] = lifecycle
        if provider is not None:
            self._values["provider"] = provider
        if timeouts is not None:
            self._values["timeouts"] = timeouts

    @builtins.property
    def count(self) -> typing.Optional[jsii.Number]:
        """
        :stability: experimental
        """
        result = self._values.get("count")
        return result

    @builtins.property
    def depends_on(self) -> typing.Optional[typing.List[cdktf.TerraformResource]]:
        """
        :stability: experimental
        """
        result = self._values.get("depends_on")
        return result

    @builtins.property
    def lifecycle(self) -> typing.Optional[cdktf.TerraformResourceLifecycle]:
        """
        :stability: experimental
        """
        result = self._values.get("lifecycle")
        return result

    @builtins.property
    def provider(self) -> typing.Optional[cdktf.TerraformProvider]:
        """
        :stability: experimental
        """
        result = self._values.get("provider")
        return result

    @builtins.property
    def scope(self) -> builtins.str:
        result = self._values.get("scope")
        assert result is not None, "Required property 'scope' is missing"
        return result

    @builtins.property
    def workspace_id(self) -> builtins.str:
        result = self._values.get("workspace_id")
        assert result is not None, "Required property 'workspace_id' is missing"
        return result

    @builtins.property
    def timeouts(self) -> typing.Optional["SecurityCenterWorkspaceTimeouts"]:
        """timeouts block."""
        result = self._values.get("timeouts")
        return result

    def __eq__(self, rhs: typing.Any) -> builtins.bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs: typing.Any) -> builtins.bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return "SecurityCenterWorkspaceConfig(%s)" % ", ".join(
            k + "=" + repr(v) for k, v in self._values.items()
        )


@jsii.data_type(
    jsii_type="@cdktf/provider-azurerm.SecurityCenterWorkspaceTimeouts",
    jsii_struct_bases=[],
    name_mapping={
        "create": "create",
        "delete": "delete",
        "read": "read",
        "update": "update",
    },
)
class SecurityCenterWorkspaceTimeouts:
    def __init__(
        self,
        *,
        create: typing.Optional[builtins.str] = None,
        delete: typing.Optional[builtins.str] = None,
        read: typing.Optional[builtins.str] = None,
        update: typing.Optional[builtins.str] = None,
    ) -> None:
        """
        :param create: 
        :param delete: 
        :param read: 
        :param update: 
        """
        self._values: typing.Dict[str, typing.Any] = {}
        if create is not None:
            self._values["create"] = create
        if delete is not None:
            self._values["delete"] = delete
        if read is not None:
            self._values["read"] = read
        if update is not None:
            self._values["update"] = update

    @builtins.property
    def create(self) -> typing.Optional[builtins.str]:
        result = self._values.get("create")
        return result

    @builtins.property
    def delete(self) -> typing.Optional[builtins.str]:
        result = self._values.get("delete")
        return result

    @builtins.property
    def read(self) -> typing.Optional[builtins.str]:
        result = self._values.get("read")
        return result

    @builtins.property
    def update(self) -> typing.Optional[builtins.str]:
        result = self._values.get("update")
        return result

    def __eq__(self, rhs: typing.Any) -> builtins.bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs: typing.Any) -> builtins.bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return "SecurityCenterWorkspaceTimeouts(%s)" % ", ".join(
            k + "=" + repr(v) for k, v in self._values.items()
        )


class ServiceFabricCluster(
    cdktf.TerraformResource,
    metaclass=jsii.JSIIMeta,
    jsii_type="@cdktf/provider-azurerm.ServiceFabricCluster",
):
    def __init__(
        self,
        scope: constructs.Construct,
        id: builtins.str,
        *,
        location: builtins.str,
        management_endpoint: builtins.str,
        name: builtins.str,
        node_type: typing.List["ServiceFabricClusterNodeType"],
        reliability_level: builtins.str,
        resource_group_name: builtins.str,
        upgrade_mode: builtins.str,
        vm_image: builtins.str,
        add_on_features: typing.Optional[typing.List[builtins.str]] = None,
        azure_active_directory: typing.Optional[typing.List["ServiceFabricClusterAzureActiveDirectory"]] = None,
        certificate: typing.Optional[typing.List["ServiceFabricClusterCertificate"]] = None,
        certificate_common_names: typing.Optional[typing.List["ServiceFabricClusterCertificateCommonNames"]] = None,
        client_certificate_thumbprint: typing.Optional[typing.List["ServiceFabricClusterClientCertificateThumbprint"]] = None,
        cluster_code_version: typing.Optional[builtins.str] = None,
        diagnostics_config: typing.Optional[typing.List["ServiceFabricClusterDiagnosticsConfig"]] = None,
        fabric_settings: typing.Optional[typing.List["ServiceFabricClusterFabricSettings"]] = None,
        reverse_proxy_certificate: typing.Optional[typing.List["ServiceFabricClusterReverseProxyCertificate"]] = None,
        tags: typing.Optional[typing.Mapping[builtins.str, builtins.str]] = None,
        timeouts: typing.Optional["ServiceFabricClusterTimeouts"] = None,
        count: typing.Optional[jsii.Number] = None,
        depends_on: typing.Optional[typing.List[cdktf.TerraformResource]] = None,
        lifecycle: typing.Optional[cdktf.TerraformResourceLifecycle] = None,
        provider: typing.Optional[cdktf.TerraformProvider] = None,
    ) -> None:
        """
        :param scope: -
        :param id: -
        :param location: 
        :param management_endpoint: 
        :param name: 
        :param node_type: node_type block.
        :param reliability_level: 
        :param resource_group_name: 
        :param upgrade_mode: 
        :param vm_image: 
        :param add_on_features: 
        :param azure_active_directory: azure_active_directory block.
        :param certificate: certificate block.
        :param certificate_common_names: certificate_common_names block.
        :param client_certificate_thumbprint: client_certificate_thumbprint block.
        :param cluster_code_version: 
        :param diagnostics_config: diagnostics_config block.
        :param fabric_settings: fabric_settings block.
        :param reverse_proxy_certificate: reverse_proxy_certificate block.
        :param tags: 
        :param timeouts: timeouts block.
        :param count: 
        :param depends_on: 
        :param lifecycle: 
        :param provider: 
        """
        config = ServiceFabricClusterConfig(
            location=location,
            management_endpoint=management_endpoint,
            name=name,
            node_type=node_type,
            reliability_level=reliability_level,
            resource_group_name=resource_group_name,
            upgrade_mode=upgrade_mode,
            vm_image=vm_image,
            add_on_features=add_on_features,
            azure_active_directory=azure_active_directory,
            certificate=certificate,
            certificate_common_names=certificate_common_names,
            client_certificate_thumbprint=client_certificate_thumbprint,
            cluster_code_version=cluster_code_version,
            diagnostics_config=diagnostics_config,
            fabric_settings=fabric_settings,
            reverse_proxy_certificate=reverse_proxy_certificate,
            tags=tags,
            timeouts=timeouts,
            count=count,
            depends_on=depends_on,
            lifecycle=lifecycle,
            provider=provider,
        )

        jsii.create(ServiceFabricCluster, self, [scope, id, config])

    @jsii.member(jsii_name="synthesizeAttributes")
    def _synthesize_attributes(self) -> typing.Mapping[builtins.str, typing.Any]:
        return jsii.invoke(self, "synthesizeAttributes", [])

    @builtins.property # type: ignore
    @jsii.member(jsii_name="clusterEndpoint")
    def cluster_endpoint(self) -> builtins.str:
        return jsii.get(self, "clusterEndpoint")

    @builtins.property # type: ignore
    @jsii.member(jsii_name="location")
    def location(self) -> builtins.str:
        return jsii.get(self, "location")

    @location.setter # type: ignore
    def location(self, value: builtins.str) -> None:
        jsii.set(self, "location", value)

    @builtins.property # type: ignore
    @jsii.member(jsii_name="managementEndpoint")
    def management_endpoint(self) -> builtins.str:
        return jsii.get(self, "managementEndpoint")

    @management_endpoint.setter # type: ignore
    def management_endpoint(self, value: builtins.str) -> None:
        jsii.set(self, "managementEndpoint", value)

    @builtins.property # type: ignore
    @jsii.member(jsii_name="name")
    def name(self) -> builtins.str:
        return jsii.get(self, "name")

    @name.setter # type: ignore
    def name(self, value: builtins.str) -> None:
        jsii.set(self, "name", value)

    @builtins.property # type: ignore
    @jsii.member(jsii_name="nodeType")
    def node_type(self) -> typing.List["ServiceFabricClusterNodeType"]:
        return jsii.get(self, "nodeType")

    @node_type.setter # type: ignore
    def node_type(self, value: typing.List["ServiceFabricClusterNodeType"]) -> None:
        jsii.set(self, "nodeType", value)

    @builtins.property # type: ignore
    @jsii.member(jsii_name="reliabilityLevel")
    def reliability_level(self) -> builtins.str:
        return jsii.get(self, "reliabilityLevel")

    @reliability_level.setter # type: ignore
    def reliability_level(self, value: builtins.str) -> None:
        jsii.set(self, "reliabilityLevel", value)

    @builtins.property # type: ignore
    @jsii.member(jsii_name="resourceGroupName")
    def resource_group_name(self) -> builtins.str:
        return jsii.get(self, "resourceGroupName")

    @resource_group_name.setter # type: ignore
    def resource_group_name(self, value: builtins.str) -> None:
        jsii.set(self, "resourceGroupName", value)

    @builtins.property # type: ignore
    @jsii.member(jsii_name="upgradeMode")
    def upgrade_mode(self) -> builtins.str:
        return jsii.get(self, "upgradeMode")

    @upgrade_mode.setter # type: ignore
    def upgrade_mode(self, value: builtins.str) -> None:
        jsii.set(self, "upgradeMode", value)

    @builtins.property # type: ignore
    @jsii.member(jsii_name="vmImage")
    def vm_image(self) -> builtins.str:
        return jsii.get(self, "vmImage")

    @vm_image.setter # type: ignore
    def vm_image(self, value: builtins.str) -> None:
        jsii.set(self, "vmImage", value)

    @builtins.property # type: ignore
    @jsii.member(jsii_name="addOnFeatures")
    def add_on_features(self) -> typing.Optional[typing.List[builtins.str]]:
        return jsii.get(self, "addOnFeatures")

    @add_on_features.setter # type: ignore
    def add_on_features(
        self,
        value: typing.Optional[typing.List[builtins.str]],
    ) -> None:
        jsii.set(self, "addOnFeatures", value)

    @builtins.property # type: ignore
    @jsii.member(jsii_name="azureActiveDirectory")
    def azure_active_directory(
        self,
    ) -> typing.Optional[typing.List["ServiceFabricClusterAzureActiveDirectory"]]:
        return jsii.get(self, "azureActiveDirectory")

    @azure_active_directory.setter # type: ignore
    def azure_active_directory(
        self,
        value: typing.Optional[typing.List["ServiceFabricClusterAzureActiveDirectory"]],
    ) -> None:
        jsii.set(self, "azureActiveDirectory", value)

    @builtins.property # type: ignore
    @jsii.member(jsii_name="certificate")
    def certificate(
        self,
    ) -> typing.Optional[typing.List["ServiceFabricClusterCertificate"]]:
        return jsii.get(self, "certificate")

    @certificate.setter # type: ignore
    def certificate(
        self,
        value: typing.Optional[typing.List["ServiceFabricClusterCertificate"]],
    ) -> None:
        jsii.set(self, "certificate", value)

    @builtins.property # type: ignore
    @jsii.member(jsii_name="certificateCommonNames")
    def certificate_common_names(
        self,
    ) -> typing.Optional[typing.List["ServiceFabricClusterCertificateCommonNames"]]:
        return jsii.get(self, "certificateCommonNames")

    @certificate_common_names.setter # type: ignore
    def certificate_common_names(
        self,
        value: typing.Optional[typing.List["ServiceFabricClusterCertificateCommonNames"]],
    ) -> None:
        jsii.set(self, "certificateCommonNames", value)

    @builtins.property # type: ignore
    @jsii.member(jsii_name="clientCertificateThumbprint")
    def client_certificate_thumbprint(
        self,
    ) -> typing.Optional[typing.List["ServiceFabricClusterClientCertificateThumbprint"]]:
        return jsii.get(self, "clientCertificateThumbprint")

    @client_certificate_thumbprint.setter # type: ignore
    def client_certificate_thumbprint(
        self,
        value: typing.Optional[typing.List["ServiceFabricClusterClientCertificateThumbprint"]],
    ) -> None:
        jsii.set(self, "clientCertificateThumbprint", value)

    @builtins.property # type: ignore
    @jsii.member(jsii_name="clusterCodeVersion")
    def cluster_code_version(self) -> typing.Optional[builtins.str]:
        return jsii.get(self, "clusterCodeVersion")

    @cluster_code_version.setter # type: ignore
    def cluster_code_version(self, value: typing.Optional[builtins.str]) -> None:
        jsii.set(self, "clusterCodeVersion", value)

    @builtins.property # type: ignore
    @jsii.member(jsii_name="diagnosticsConfig")
    def diagnostics_config(
        self,
    ) -> typing.Optional[typing.List["ServiceFabricClusterDiagnosticsConfig"]]:
        return jsii.get(self, "diagnosticsConfig")

    @diagnostics_config.setter # type: ignore
    def diagnostics_config(
        self,
        value: typing.Optional[typing.List["ServiceFabricClusterDiagnosticsConfig"]],
    ) -> None:
        jsii.set(self, "diagnosticsConfig", value)

    @builtins.property # type: ignore
    @jsii.member(jsii_name="fabricSettings")
    def fabric_settings(
        self,
    ) -> typing.Optional[typing.List["ServiceFabricClusterFabricSettings"]]:
        return jsii.get(self, "fabricSettings")

    @fabric_settings.setter # type: ignore
    def fabric_settings(
        self,
        value: typing.Optional[typing.List["ServiceFabricClusterFabricSettings"]],
    ) -> None:
        jsii.set(self, "fabricSettings", value)

    @builtins.property # type: ignore
    @jsii.member(jsii_name="id")
    def id(self) -> typing.Optional[builtins.str]:
        return jsii.get(self, "id")

    @id.setter # type: ignore
    def id(self, value: typing.Optional[builtins.str]) -> None:
        jsii.set(self, "id", value)

    @builtins.property # type: ignore
    @jsii.member(jsii_name="reverseProxyCertificate")
    def reverse_proxy_certificate(
        self,
    ) -> typing.Optional[typing.List["ServiceFabricClusterReverseProxyCertificate"]]:
        return jsii.get(self, "reverseProxyCertificate")

    @reverse_proxy_certificate.setter # type: ignore
    def reverse_proxy_certificate(
        self,
        value: typing.Optional[typing.List["ServiceFabricClusterReverseProxyCertificate"]],
    ) -> None:
        jsii.set(self, "reverseProxyCertificate", value)

    @builtins.property # type: ignore
    @jsii.member(jsii_name="tags")
    def tags(self) -> typing.Optional[typing.Mapping[builtins.str, builtins.str]]:
        return jsii.get(self, "tags")

    @tags.setter # type: ignore
    def tags(
        self,
        value: typing.Optional[typing.Mapping[builtins.str, builtins.str]],
    ) -> None:
        jsii.set(self, "tags", value)

    @builtins.property # type: ignore
    @jsii.member(jsii_name="timeouts")
    def timeouts(self) -> typing.Optional["ServiceFabricClusterTimeouts"]:
        return jsii.get(self, "timeouts")

    @timeouts.setter # type: ignore
    def timeouts(self, value: typing.Optional["ServiceFabricClusterTimeouts"]) -> None:
        jsii.set(self, "timeouts", value)


@jsii.data_type(
    jsii_type="@cdktf/provider-azurerm.ServiceFabricClusterAzureActiveDirectory",
    jsii_struct_bases=[],
    name_mapping={
        "client_application_id": "clientApplicationId",
        "cluster_application_id": "clusterApplicationId",
        "tenant_id": "tenantId",
    },
)
class ServiceFabricClusterAzureActiveDirectory:
    def __init__(
        self,
        *,
        client_application_id: builtins.str,
        cluster_application_id: builtins.str,
        tenant_id: builtins.str,
    ) -> None:
        """
        :param client_application_id: 
        :param cluster_application_id: 
        :param tenant_id: 
        """
        self._values: typing.Dict[str, typing.Any] = {
            "client_application_id": client_application_id,
            "cluster_application_id": cluster_application_id,
            "tenant_id": tenant_id,
        }

    @builtins.property
    def client_application_id(self) -> builtins.str:
        result = self._values.get("client_application_id")
        assert result is not None, "Required property 'client_application_id' is missing"
        return result

    @builtins.property
    def cluster_application_id(self) -> builtins.str:
        result = self._values.get("cluster_application_id")
        assert result is not None, "Required property 'cluster_application_id' is missing"
        return result

    @builtins.property
    def tenant_id(self) -> builtins.str:
        result = self._values.get("tenant_id")
        assert result is not None, "Required property 'tenant_id' is missing"
        return result

    def __eq__(self, rhs: typing.Any) -> builtins.bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs: typing.Any) -> builtins.bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return "ServiceFabricClusterAzureActiveDirectory(%s)" % ", ".join(
            k + "=" + repr(v) for k, v in self._values.items()
        )


@jsii.data_type(
    jsii_type="@cdktf/provider-azurerm.ServiceFabricClusterCertificate",
    jsii_struct_bases=[],
    name_mapping={
        "thumbprint": "thumbprint",
        "x509_store_name": "x509StoreName",
        "thumbprint_secondary": "thumbprintSecondary",
    },
)
class ServiceFabricClusterCertificate:
    def __init__(
        self,
        *,
        thumbprint: builtins.str,
        x509_store_name: builtins.str,
        thumbprint_secondary: typing.Optional[builtins.str] = None,
    ) -> None:
        """
        :param thumbprint: 
        :param x509_store_name: 
        :param thumbprint_secondary: 
        """
        self._values: typing.Dict[str, typing.Any] = {
            "thumbprint": thumbprint,
            "x509_store_name": x509_store_name,
        }
        if thumbprint_secondary is not None:
            self._values["thumbprint_secondary"] = thumbprint_secondary

    @builtins.property
    def thumbprint(self) -> builtins.str:
        result = self._values.get("thumbprint")
        assert result is not None, "Required property 'thumbprint' is missing"
        return result

    @builtins.property
    def x509_store_name(self) -> builtins.str:
        result = self._values.get("x509_store_name")
        assert result is not None, "Required property 'x509_store_name' is missing"
        return result

    @builtins.property
    def thumbprint_secondary(self) -> typing.Optional[builtins.str]:
        result = self._values.get("thumbprint_secondary")
        return result

    def __eq__(self, rhs: typing.Any) -> builtins.bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs: typing.Any) -> builtins.bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return "ServiceFabricClusterCertificate(%s)" % ", ".join(
            k + "=" + repr(v) for k, v in self._values.items()
        )


@jsii.data_type(
    jsii_type="@cdktf/provider-azurerm.ServiceFabricClusterCertificateCommonNames",
    jsii_struct_bases=[],
    name_mapping={"common_names": "commonNames", "x509_store_name": "x509StoreName"},
)
class ServiceFabricClusterCertificateCommonNames:
    def __init__(
        self,
        *,
        common_names: typing.List["ServiceFabricClusterCertificateCommonNamesCommonNames"],
        x509_store_name: builtins.str,
    ) -> None:
        """
        :param common_names: common_names block.
        :param x509_store_name: 
        """
        self._values: typing.Dict[str, typing.Any] = {
            "common_names": common_names,
            "x509_store_name": x509_store_name,
        }

    @builtins.property
    def common_names(
        self,
    ) -> typing.List["ServiceFabricClusterCertificateCommonNamesCommonNames"]:
        """common_names block."""
        result = self._values.get("common_names")
        assert result is not None, "Required property 'common_names' is missing"
        return result

    @builtins.property
    def x509_store_name(self) -> builtins.str:
        result = self._values.get("x509_store_name")
        assert result is not None, "Required property 'x509_store_name' is missing"
        return result

    def __eq__(self, rhs: typing.Any) -> builtins.bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs: typing.Any) -> builtins.bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return "ServiceFabricClusterCertificateCommonNames(%s)" % ", ".join(
            k + "=" + repr(v) for k, v in self._values.items()
        )


@jsii.data_type(
    jsii_type="@cdktf/provider-azurerm.ServiceFabricClusterCertificateCommonNamesCommonNames",
    jsii_struct_bases=[],
    name_mapping={
        "certificate_common_name": "certificateCommonName",
        "certificate_issuer_thumbprint": "certificateIssuerThumbprint",
    },
)
class ServiceFabricClusterCertificateCommonNamesCommonNames:
    def __init__(
        self,
        *,
        certificate_common_name: builtins.str,
        certificate_issuer_thumbprint: typing.Optional[builtins.str] = None,
    ) -> None:
        """
        :param certificate_common_name: 
        :param certificate_issuer_thumbprint: 
        """
        self._values: typing.Dict[str, typing.Any] = {
            "certificate_common_name": certificate_common_name,
        }
        if certificate_issuer_thumbprint is not None:
            self._values["certificate_issuer_thumbprint"] = certificate_issuer_thumbprint

    @builtins.property
    def certificate_common_name(self) -> builtins.str:
        result = self._values.get("certificate_common_name")
        assert result is not None, "Required property 'certificate_common_name' is missing"
        return result

    @builtins.property
    def certificate_issuer_thumbprint(self) -> typing.Optional[builtins.str]:
        result = self._values.get("certificate_issuer_thumbprint")
        return result

    def __eq__(self, rhs: typing.Any) -> builtins.bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs: typing.Any) -> builtins.bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return "ServiceFabricClusterCertificateCommonNamesCommonNames(%s)" % ", ".join(
            k + "=" + repr(v) for k, v in self._values.items()
        )


@jsii.data_type(
    jsii_type="@cdktf/provider-azurerm.ServiceFabricClusterClientCertificateThumbprint",
    jsii_struct_bases=[],
    name_mapping={"is_admin": "isAdmin", "thumbprint": "thumbprint"},
)
class ServiceFabricClusterClientCertificateThumbprint:
    def __init__(self, *, is_admin: builtins.bool, thumbprint: builtins.str) -> None:
        """
        :param is_admin: 
        :param thumbprint: 
        """
        self._values: typing.Dict[str, typing.Any] = {
            "is_admin": is_admin,
            "thumbprint": thumbprint,
        }

    @builtins.property
    def is_admin(self) -> builtins.bool:
        result = self._values.get("is_admin")
        assert result is not None, "Required property 'is_admin' is missing"
        return result

    @builtins.property
    def thumbprint(self) -> builtins.str:
        result = self._values.get("thumbprint")
        assert result is not None, "Required property 'thumbprint' is missing"
        return result

    def __eq__(self, rhs: typing.Any) -> builtins.bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs: typing.Any) -> builtins.bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return "ServiceFabricClusterClientCertificateThumbprint(%s)" % ", ".join(
            k + "=" + repr(v) for k, v in self._values.items()
        )


@jsii.data_type(
    jsii_type="@cdktf/provider-azurerm.ServiceFabricClusterConfig",
    jsii_struct_bases=[cdktf.TerraformMetaArguments],
    name_mapping={
        "count": "count",
        "depends_on": "dependsOn",
        "lifecycle": "lifecycle",
        "provider": "provider",
        "location": "location",
        "management_endpoint": "managementEndpoint",
        "name": "name",
        "node_type": "nodeType",
        "reliability_level": "reliabilityLevel",
        "resource_group_name": "resourceGroupName",
        "upgrade_mode": "upgradeMode",
        "vm_image": "vmImage",
        "add_on_features": "addOnFeatures",
        "azure_active_directory": "azureActiveDirectory",
        "certificate": "certificate",
        "certificate_common_names": "certificateCommonNames",
        "client_certificate_thumbprint": "clientCertificateThumbprint",
        "cluster_code_version": "clusterCodeVersion",
        "diagnostics_config": "diagnosticsConfig",
        "fabric_settings": "fabricSettings",
        "reverse_proxy_certificate": "reverseProxyCertificate",
        "tags": "tags",
        "timeouts": "timeouts",
    },
)
class ServiceFabricClusterConfig(cdktf.TerraformMetaArguments):
    def __init__(
        self,
        *,
        count: typing.Optional[jsii.Number] = None,
        depends_on: typing.Optional[typing.List[cdktf.TerraformResource]] = None,
        lifecycle: typing.Optional[cdktf.TerraformResourceLifecycle] = None,
        provider: typing.Optional[cdktf.TerraformProvider] = None,
        location: builtins.str,
        management_endpoint: builtins.str,
        name: builtins.str,
        node_type: typing.List["ServiceFabricClusterNodeType"],
        reliability_level: builtins.str,
        resource_group_name: builtins.str,
        upgrade_mode: builtins.str,
        vm_image: builtins.str,
        add_on_features: typing.Optional[typing.List[builtins.str]] = None,
        azure_active_directory: typing.Optional[typing.List[ServiceFabricClusterAzureActiveDirectory]] = None,
        certificate: typing.Optional[typing.List[ServiceFabricClusterCertificate]] = None,
        certificate_common_names: typing.Optional[typing.List[ServiceFabricClusterCertificateCommonNames]] = None,
        client_certificate_thumbprint: typing.Optional[typing.List[ServiceFabricClusterClientCertificateThumbprint]] = None,
        cluster_code_version: typing.Optional[builtins.str] = None,
        diagnostics_config: typing.Optional[typing.List["ServiceFabricClusterDiagnosticsConfig"]] = None,
        fabric_settings: typing.Optional[typing.List["ServiceFabricClusterFabricSettings"]] = None,
        reverse_proxy_certificate: typing.Optional[typing.List["ServiceFabricClusterReverseProxyCertificate"]] = None,
        tags: typing.Optional[typing.Mapping[builtins.str, builtins.str]] = None,
        timeouts: typing.Optional["ServiceFabricClusterTimeouts"] = None,
    ) -> None:
        """
        :param count: 
        :param depends_on: 
        :param lifecycle: 
        :param provider: 
        :param location: 
        :param management_endpoint: 
        :param name: 
        :param node_type: node_type block.
        :param reliability_level: 
        :param resource_group_name: 
        :param upgrade_mode: 
        :param vm_image: 
        :param add_on_features: 
        :param azure_active_directory: azure_active_directory block.
        :param certificate: certificate block.
        :param certificate_common_names: certificate_common_names block.
        :param client_certificate_thumbprint: client_certificate_thumbprint block.
        :param cluster_code_version: 
        :param diagnostics_config: diagnostics_config block.
        :param fabric_settings: fabric_settings block.
        :param reverse_proxy_certificate: reverse_proxy_certificate block.
        :param tags: 
        :param timeouts: timeouts block.
        """
        if isinstance(lifecycle, dict):
            lifecycle = cdktf.TerraformResourceLifecycle(**lifecycle)
        if isinstance(timeouts, dict):
            timeouts = ServiceFabricClusterTimeouts(**timeouts)
        self._values: typing.Dict[str, typing.Any] = {
            "location": location,
            "management_endpoint": management_endpoint,
            "name": name,
            "node_type": node_type,
            "reliability_level": reliability_level,
            "resource_group_name": resource_group_name,
            "upgrade_mode": upgrade_mode,
            "vm_image": vm_image,
        }
        if count is not None:
            self._values["count"] = count
        if depends_on is not None:
            self._values["depends_on"] = depends_on
        if lifecycle is not None:
            self._values["lifecycle"] = lifecycle
        if provider is not None:
            self._values["provider"] = provider
        if add_on_features is not None:
            self._values["add_on_features"] = add_on_features
        if azure_active_directory is not None:
            self._values["azure_active_directory"] = azure_active_directory
        if certificate is not None:
            self._values["certificate"] = certificate
        if certificate_common_names is not None:
            self._values["certificate_common_names"] = certificate_common_names
        if client_certificate_thumbprint is not None:
            self._values["client_certificate_thumbprint"] = client_certificate_thumbprint
        if cluster_code_version is not None:
            self._values["cluster_code_version"] = cluster_code_version
        if diagnostics_config is not None:
            self._values["diagnostics_config"] = diagnostics_config
        if fabric_settings is not None:
            self._values["fabric_settings"] = fabric_settings
        if reverse_proxy_certificate is not None:
            self._values["reverse_proxy_certificate"] = reverse_proxy_certificate
        if tags is not None:
            self._values["tags"] = tags
        if timeouts is not None:
            self._values["timeouts"] = timeouts

    @builtins.property
    def count(self) -> typing.Optional[jsii.Number]:
        """
        :stability: experimental
        """
        result = self._values.get("count")
        return result

    @builtins.property
    def depends_on(self) -> typing.Optional[typing.List[cdktf.TerraformResource]]:
        """
        :stability: experimental
        """
        result = self._values.get("depends_on")
        return result

    @builtins.property
    def lifecycle(self) -> typing.Optional[cdktf.TerraformResourceLifecycle]:
        """
        :stability: experimental
        """
        result = self._values.get("lifecycle")
        return result

    @builtins.property
    def provider(self) -> typing.Optional[cdktf.TerraformProvider]:
        """
        :stability: experimental
        """
        result = self._values.get("provider")
        return result

    @builtins.property
    def location(self) -> builtins.str:
        result = self._values.get("location")
        assert result is not None, "Required property 'location' is missing"
        return result

    @builtins.property
    def management_endpoint(self) -> builtins.str:
        result = self._values.get("management_endpoint")
        assert result is not None, "Required property 'management_endpoint' is missing"
        return result

    @builtins.property
    def name(self) -> builtins.str:
        result = self._values.get("name")
        assert result is not None, "Required property 'name' is missing"
        return result

    @builtins.property
    def node_type(self) -> typing.List["ServiceFabricClusterNodeType"]:
        """node_type block."""
        result = self._values.get("node_type")
        assert result is not None, "Required property 'node_type' is missing"
        return result

    @builtins.property
    def reliability_level(self) -> builtins.str:
        result = self._values.get("reliability_level")
        assert result is not None, "Required property 'reliability_level' is missing"
        return result

    @builtins.property
    def resource_group_name(self) -> builtins.str:
        result = self._values.get("resource_group_name")
        assert result is not None, "Required property 'resource_group_name' is missing"
        return result

    @builtins.property
    def upgrade_mode(self) -> builtins.str:
        result = self._values.get("upgrade_mode")
        assert result is not None, "Required property 'upgrade_mode' is missing"
        return result

    @builtins.property
    def vm_image(self) -> builtins.str:
        result = self._values.get("vm_image")
        assert result is not None, "Required property 'vm_image' is missing"
        return result

    @builtins.property
    def add_on_features(self) -> typing.Optional[typing.List[builtins.str]]:
        result = self._values.get("add_on_features")
        return result

    @builtins.property
    def azure_active_directory(
        self,
    ) -> typing.Optional[typing.List[ServiceFabricClusterAzureActiveDirectory]]:
        """azure_active_directory block."""
        result = self._values.get("azure_active_directory")
        return result

    @builtins.property
    def certificate(
        self,
    ) -> typing.Optional[typing.List[ServiceFabricClusterCertificate]]:
        """certificate block."""
        result = self._values.get("certificate")
        return result

    @builtins.property
    def certificate_common_names(
        self,
    ) -> typing.Optional[typing.List[ServiceFabricClusterCertificateCommonNames]]:
        """certificate_common_names block."""
        result = self._values.get("certificate_common_names")
        return result

    @builtins.property
    def client_certificate_thumbprint(
        self,
    ) -> typing.Optional[typing.List[ServiceFabricClusterClientCertificateThumbprint]]:
        """client_certificate_thumbprint block."""
        result = self._values.get("client_certificate_thumbprint")
        return result

    @builtins.property
    def cluster_code_version(self) -> typing.Optional[builtins.str]:
        result = self._values.get("cluster_code_version")
        return result

    @builtins.property
    def diagnostics_config(
        self,
    ) -> typing.Optional[typing.List["ServiceFabricClusterDiagnosticsConfig"]]:
        """diagnostics_config block."""
        result = self._values.get("diagnostics_config")
        return result

    @builtins.property
    def fabric_settings(
        self,
    ) -> typing.Optional[typing.List["ServiceFabricClusterFabricSettings"]]:
        """fabric_settings block."""
        result = self._values.get("fabric_settings")
        return result

    @builtins.property
    def reverse_proxy_certificate(
        self,
    ) -> typing.Optional[typing.List["ServiceFabricClusterReverseProxyCertificate"]]:
        """reverse_proxy_certificate block."""
        result = self._values.get("reverse_proxy_certificate")
        return result

    @builtins.property
    def tags(self) -> typing.Optional[typing.Mapping[builtins.str, builtins.str]]:
        result = self._values.get("tags")
        return result

    @builtins.property
    def timeouts(self) -> typing.Optional["ServiceFabricClusterTimeouts"]:
        """timeouts block."""
        result = self._values.get("timeouts")
        return result

    def __eq__(self, rhs: typing.Any) -> builtins.bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs: typing.Any) -> builtins.bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return "ServiceFabricClusterConfig(%s)" % ", ".join(
            k + "=" + repr(v) for k, v in self._values.items()
        )


@jsii.data_type(
    jsii_type="@cdktf/provider-azurerm.ServiceFabricClusterDiagnosticsConfig",
    jsii_struct_bases=[],
    name_mapping={
        "blob_endpoint": "blobEndpoint",
        "protected_account_key_name": "protectedAccountKeyName",
        "queue_endpoint": "queueEndpoint",
        "storage_account_name": "storageAccountName",
        "table_endpoint": "tableEndpoint",
    },
)
class ServiceFabricClusterDiagnosticsConfig:
    def __init__(
        self,
        *,
        blob_endpoint: builtins.str,
        protected_account_key_name: builtins.str,
        queue_endpoint: builtins.str,
        storage_account_name: builtins.str,
        table_endpoint: builtins.str,
    ) -> None:
        """
        :param blob_endpoint: 
        :param protected_account_key_name: 
        :param queue_endpoint: 
        :param storage_account_name: 
        :param table_endpoint: 
        """
        self._values: typing.Dict[str, typing.Any] = {
            "blob_endpoint": blob_endpoint,
            "protected_account_key_name": protected_account_key_name,
            "queue_endpoint": queue_endpoint,
            "storage_account_name": storage_account_name,
            "table_endpoint": table_endpoint,
        }

    @builtins.property
    def blob_endpoint(self) -> builtins.str:
        result = self._values.get("blob_endpoint")
        assert result is not None, "Required property 'blob_endpoint' is missing"
        return result

    @builtins.property
    def protected_account_key_name(self) -> builtins.str:
        result = self._values.get("protected_account_key_name")
        assert result is not None, "Required property 'protected_account_key_name' is missing"
        return result

    @builtins.property
    def queue_endpoint(self) -> builtins.str:
        result = self._values.get("queue_endpoint")
        assert result is not None, "Required property 'queue_endpoint' is missing"
        return result

    @builtins.property
    def storage_account_name(self) -> builtins.str:
        result = self._values.get("storage_account_name")
        assert result is not None, "Required property 'storage_account_name' is missing"
        return result

    @builtins.property
    def table_endpoint(self) -> builtins.str:
        result = self._values.get("table_endpoint")
        assert result is not None, "Required property 'table_endpoint' is missing"
        return result

    def __eq__(self, rhs: typing.Any) -> builtins.bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs: typing.Any) -> builtins.bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return "ServiceFabricClusterDiagnosticsConfig(%s)" % ", ".join(
            k + "=" + repr(v) for k, v in self._values.items()
        )


@jsii.data_type(
    jsii_type="@cdktf/provider-azurerm.ServiceFabricClusterFabricSettings",
    jsii_struct_bases=[],
    name_mapping={"name": "name", "parameters": "parameters"},
)
class ServiceFabricClusterFabricSettings:
    def __init__(
        self,
        *,
        name: builtins.str,
        parameters: typing.Optional[typing.Mapping[builtins.str, builtins.str]] = None,
    ) -> None:
        """
        :param name: 
        :param parameters: 
        """
        self._values: typing.Dict[str, typing.Any] = {
            "name": name,
        }
        if parameters is not None:
            self._values["parameters"] = parameters

    @builtins.property
    def name(self) -> builtins.str:
        result = self._values.get("name")
        assert result is not None, "Required property 'name' is missing"
        return result

    @builtins.property
    def parameters(self) -> typing.Optional[typing.Mapping[builtins.str, builtins.str]]:
        result = self._values.get("parameters")
        return result

    def __eq__(self, rhs: typing.Any) -> builtins.bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs: typing.Any) -> builtins.bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return "ServiceFabricClusterFabricSettings(%s)" % ", ".join(
            k + "=" + repr(v) for k, v in self._values.items()
        )


@jsii.data_type(
    jsii_type="@cdktf/provider-azurerm.ServiceFabricClusterNodeType",
    jsii_struct_bases=[],
    name_mapping={
        "client_endpoint_port": "clientEndpointPort",
        "http_endpoint_port": "httpEndpointPort",
        "instance_count": "instanceCount",
        "is_primary": "isPrimary",
        "name": "name",
        "application_ports": "applicationPorts",
        "capacities": "capacities",
        "durability_level": "durabilityLevel",
        "ephemeral_ports": "ephemeralPorts",
        "placement_properties": "placementProperties",
        "reverse_proxy_endpoint_port": "reverseProxyEndpointPort",
    },
)
class ServiceFabricClusterNodeType:
    def __init__(
        self,
        *,
        client_endpoint_port: jsii.Number,
        http_endpoint_port: jsii.Number,
        instance_count: jsii.Number,
        is_primary: builtins.bool,
        name: builtins.str,
        application_ports: typing.Optional[typing.List["ServiceFabricClusterNodeTypeApplicationPorts"]] = None,
        capacities: typing.Optional[typing.Mapping[builtins.str, builtins.str]] = None,
        durability_level: typing.Optional[builtins.str] = None,
        ephemeral_ports: typing.Optional[typing.List["ServiceFabricClusterNodeTypeEphemeralPorts"]] = None,
        placement_properties: typing.Optional[typing.Mapping[builtins.str, builtins.str]] = None,
        reverse_proxy_endpoint_port: typing.Optional[jsii.Number] = None,
    ) -> None:
        """
        :param client_endpoint_port: 
        :param http_endpoint_port: 
        :param instance_count: 
        :param is_primary: 
        :param name: 
        :param application_ports: application_ports block.
        :param capacities: 
        :param durability_level: 
        :param ephemeral_ports: ephemeral_ports block.
        :param placement_properties: 
        :param reverse_proxy_endpoint_port: 
        """
        self._values: typing.Dict[str, typing.Any] = {
            "client_endpoint_port": client_endpoint_port,
            "http_endpoint_port": http_endpoint_port,
            "instance_count": instance_count,
            "is_primary": is_primary,
            "name": name,
        }
        if application_ports is not None:
            self._values["application_ports"] = application_ports
        if capacities is not None:
            self._values["capacities"] = capacities
        if durability_level is not None:
            self._values["durability_level"] = durability_level
        if ephemeral_ports is not None:
            self._values["ephemeral_ports"] = ephemeral_ports
        if placement_properties is not None:
            self._values["placement_properties"] = placement_properties
        if reverse_proxy_endpoint_port is not None:
            self._values["reverse_proxy_endpoint_port"] = reverse_proxy_endpoint_port

    @builtins.property
    def client_endpoint_port(self) -> jsii.Number:
        result = self._values.get("client_endpoint_port")
        assert result is not None, "Required property 'client_endpoint_port' is missing"
        return result

    @builtins.property
    def http_endpoint_port(self) -> jsii.Number:
        result = self._values.get("http_endpoint_port")
        assert result is not None, "Required property 'http_endpoint_port' is missing"
        return result

    @builtins.property
    def instance_count(self) -> jsii.Number:
        result = self._values.get("instance_count")
        assert result is not None, "Required property 'instance_count' is missing"
        return result

    @builtins.property
    def is_primary(self) -> builtins.bool:
        result = self._values.get("is_primary")
        assert result is not None, "Required property 'is_primary' is missing"
        return result

    @builtins.property
    def name(self) -> builtins.str:
        result = self._values.get("name")
        assert result is not None, "Required property 'name' is missing"
        return result

    @builtins.property
    def application_ports(
        self,
    ) -> typing.Optional[typing.List["ServiceFabricClusterNodeTypeApplicationPorts"]]:
        """application_ports block."""
        result = self._values.get("application_ports")
        return result

    @builtins.property
    def capacities(self) -> typing.Optional[typing.Mapping[builtins.str, builtins.str]]:
        result = self._values.get("capacities")
        return result

    @builtins.property
    def durability_level(self) -> typing.Optional[builtins.str]:
        result = self._values.get("durability_level")
        return result

    @builtins.property
    def ephemeral_ports(
        self,
    ) -> typing.Optional[typing.List["ServiceFabricClusterNodeTypeEphemeralPorts"]]:
        """ephemeral_ports block."""
        result = self._values.get("ephemeral_ports")
        return result

    @builtins.property
    def placement_properties(
        self,
    ) -> typing.Optional[typing.Mapping[builtins.str, builtins.str]]:
        result = self._values.get("placement_properties")
        return result

    @builtins.property
    def reverse_proxy_endpoint_port(self) -> typing.Optional[jsii.Number]:
        result = self._values.get("reverse_proxy_endpoint_port")
        return result

    def __eq__(self, rhs: typing.Any) -> builtins.bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs: typing.Any) -> builtins.bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return "ServiceFabricClusterNodeType(%s)" % ", ".join(
            k + "=" + repr(v) for k, v in self._values.items()
        )


@jsii.data_type(
    jsii_type="@cdktf/provider-azurerm.ServiceFabricClusterNodeTypeApplicationPorts",
    jsii_struct_bases=[],
    name_mapping={"end_port": "endPort", "start_port": "startPort"},
)
class ServiceFabricClusterNodeTypeApplicationPorts:
    def __init__(self, *, end_port: jsii.Number, start_port: jsii.Number) -> None:
        """
        :param end_port: 
        :param start_port: 
        """
        self._values: typing.Dict[str, typing.Any] = {
            "end_port": end_port,
            "start_port": start_port,
        }

    @builtins.property
    def end_port(self) -> jsii.Number:
        result = self._values.get("end_port")
        assert result is not None, "Required property 'end_port' is missing"
        return result

    @builtins.property
    def start_port(self) -> jsii.Number:
        result = self._values.get("start_port")
        assert result is not None, "Required property 'start_port' is missing"
        return result

    def __eq__(self, rhs: typing.Any) -> builtins.bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs: typing.Any) -> builtins.bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return "ServiceFabricClusterNodeTypeApplicationPorts(%s)" % ", ".join(
            k + "=" + repr(v) for k, v in self._values.items()
        )


@jsii.data_type(
    jsii_type="@cdktf/provider-azurerm.ServiceFabricClusterNodeTypeEphemeralPorts",
    jsii_struct_bases=[],
    name_mapping={"end_port": "endPort", "start_port": "startPort"},
)
class ServiceFabricClusterNodeTypeEphemeralPorts:
    def __init__(self, *, end_port: jsii.Number, start_port: jsii.Number) -> None:
        """
        :param end_port: 
        :param start_port: 
        """
        self._values: typing.Dict[str, typing.Any] = {
            "end_port": end_port,
            "start_port": start_port,
        }

    @builtins.property
    def end_port(self) -> jsii.Number:
        result = self._values.get("end_port")
        assert result is not None, "Required property 'end_port' is missing"
        return result

    @builtins.property
    def start_port(self) -> jsii.Number:
        result = self._values.get("start_port")
        assert result is not None, "Required property 'start_port' is missing"
        return result

    def __eq__(self, rhs: typing.Any) -> builtins.bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs: typing.Any) -> builtins.bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return "ServiceFabricClusterNodeTypeEphemeralPorts(%s)" % ", ".join(
            k + "=" + repr(v) for k, v in self._values.items()
        )


@jsii.data_type(
    jsii_type="@cdktf/provider-azurerm.ServiceFabricClusterReverseProxyCertificate",
    jsii_struct_bases=[],
    name_mapping={
        "thumbprint": "thumbprint",
        "x509_store_name": "x509StoreName",
        "thumbprint_secondary": "thumbprintSecondary",
    },
)
class ServiceFabricClusterReverseProxyCertificate:
    def __init__(
        self,
        *,
        thumbprint: builtins.str,
        x509_store_name: builtins.str,
        thumbprint_secondary: typing.Optional[builtins.str] = None,
    ) -> None:
        """
        :param thumbprint: 
        :param x509_store_name: 
        :param thumbprint_secondary: 
        """
        self._values: typing.Dict[str, typing.Any] = {
            "thumbprint": thumbprint,
            "x509_store_name": x509_store_name,
        }
        if thumbprint_secondary is not None:
            self._values["thumbprint_secondary"] = thumbprint_secondary

    @builtins.property
    def thumbprint(self) -> builtins.str:
        result = self._values.get("thumbprint")
        assert result is not None, "Required property 'thumbprint' is missing"
        return result

    @builtins.property
    def x509_store_name(self) -> builtins.str:
        result = self._values.get("x509_store_name")
        assert result is not None, "Required property 'x509_store_name' is missing"
        return result

    @builtins.property
    def thumbprint_secondary(self) -> typing.Optional[builtins.str]:
        result = self._values.get("thumbprint_secondary")
        return result

    def __eq__(self, rhs: typing.Any) -> builtins.bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs: typing.Any) -> builtins.bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return "ServiceFabricClusterReverseProxyCertificate(%s)" % ", ".join(
            k + "=" + repr(v) for k, v in self._values.items()
        )


@jsii.data_type(
    jsii_type="@cdktf/provider-azurerm.ServiceFabricClusterTimeouts",
    jsii_struct_bases=[],
    name_mapping={
        "create": "create",
        "delete": "delete",
        "read": "read",
        "update": "update",
    },
)
class ServiceFabricClusterTimeouts:
    def __init__(
        self,
        *,
        create: typing.Optional[builtins.str] = None,
        delete: typing.Optional[builtins.str] = None,
        read: typing.Optional[builtins.str] = None,
        update: typing.Optional[builtins.str] = None,
    ) -> None:
        """
        :param create: 
        :param delete: 
        :param read: 
        :param update: 
        """
        self._values: typing.Dict[str, typing.Any] = {}
        if create is not None:
            self._values["create"] = create
        if delete is not None:
            self._values["delete"] = delete
        if read is not None:
            self._values["read"] = read
        if update is not None:
            self._values["update"] = update

    @builtins.property
    def create(self) -> typing.Optional[builtins.str]:
        result = self._values.get("create")
        return result

    @builtins.property
    def delete(self) -> typing.Optional[builtins.str]:
        result = self._values.get("delete")
        return result

    @builtins.property
    def read(self) -> typing.Optional[builtins.str]:
        result = self._values.get("read")
        return result

    @builtins.property
    def update(self) -> typing.Optional[builtins.str]:
        result = self._values.get("update")
        return result

    def __eq__(self, rhs: typing.Any) -> builtins.bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs: typing.Any) -> builtins.bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return "ServiceFabricClusterTimeouts(%s)" % ", ".join(
            k + "=" + repr(v) for k, v in self._values.items()
        )


class ServicebusNamespace(
    cdktf.TerraformResource,
    metaclass=jsii.JSIIMeta,
    jsii_type="@cdktf/provider-azurerm.ServicebusNamespace",
):
    def __init__(
        self,
        scope: constructs.Construct,
        id: builtins.str,
        *,
        location: builtins.str,
        name: builtins.str,
        resource_group_name: builtins.str,
        sku: builtins.str,
        capacity: typing.Optional[jsii.Number] = None,
        tags: typing.Optional[typing.Mapping[builtins.str, builtins.str]] = None,
        timeouts: typing.Optional["ServicebusNamespaceTimeouts"] = None,
        zone_redundant: typing.Optional[builtins.bool] = None,
        count: typing.Optional[jsii.Number] = None,
        depends_on: typing.Optional[typing.List[cdktf.TerraformResource]] = None,
        lifecycle: typing.Optional[cdktf.TerraformResourceLifecycle] = None,
        provider: typing.Optional[cdktf.TerraformProvider] = None,
    ) -> None:
        """
        :param scope: -
        :param id: -
        :param location: 
        :param name: 
        :param resource_group_name: 
        :param sku: 
        :param capacity: 
        :param tags: 
        :param timeouts: timeouts block.
        :param zone_redundant: 
        :param count: 
        :param depends_on: 
        :param lifecycle: 
        :param provider: 
        """
        config = ServicebusNamespaceConfig(
            location=location,
            name=name,
            resource_group_name=resource_group_name,
            sku=sku,
            capacity=capacity,
            tags=tags,
            timeouts=timeouts,
            zone_redundant=zone_redundant,
            count=count,
            depends_on=depends_on,
            lifecycle=lifecycle,
            provider=provider,
        )

        jsii.create(ServicebusNamespace, self, [scope, id, config])

    @jsii.member(jsii_name="synthesizeAttributes")
    def _synthesize_attributes(self) -> typing.Mapping[builtins.str, typing.Any]:
        return jsii.invoke(self, "synthesizeAttributes", [])

    @builtins.property # type: ignore
    @jsii.member(jsii_name="defaultPrimaryConnectionString")
    def default_primary_connection_string(self) -> builtins.str:
        return jsii.get(self, "defaultPrimaryConnectionString")

    @builtins.property # type: ignore
    @jsii.member(jsii_name="defaultPrimaryKey")
    def default_primary_key(self) -> builtins.str:
        return jsii.get(self, "defaultPrimaryKey")

    @builtins.property # type: ignore
    @jsii.member(jsii_name="defaultSecondaryConnectionString")
    def default_secondary_connection_string(self) -> builtins.str:
        return jsii.get(self, "defaultSecondaryConnectionString")

    @builtins.property # type: ignore
    @jsii.member(jsii_name="defaultSecondaryKey")
    def default_secondary_key(self) -> builtins.str:
        return jsii.get(self, "defaultSecondaryKey")

    @builtins.property # type: ignore
    @jsii.member(jsii_name="location")
    def location(self) -> builtins.str:
        return jsii.get(self, "location")

    @location.setter # type: ignore
    def location(self, value: builtins.str) -> None:
        jsii.set(self, "location", value)

    @builtins.property # type: ignore
    @jsii.member(jsii_name="name")
    def name(self) -> builtins.str:
        return jsii.get(self, "name")

    @name.setter # type: ignore
    def name(self, value: builtins.str) -> None:
        jsii.set(self, "name", value)

    @builtins.property # type: ignore
    @jsii.member(jsii_name="resourceGroupName")
    def resource_group_name(self) -> builtins.str:
        return jsii.get(self, "resourceGroupName")

    @resource_group_name.setter # type: ignore
    def resource_group_name(self, value: builtins.str) -> None:
        jsii.set(self, "resourceGroupName", value)

    @builtins.property # type: ignore
    @jsii.member(jsii_name="sku")
    def sku(self) -> builtins.str:
        return jsii.get(self, "sku")

    @sku.setter # type: ignore
    def sku(self, value: builtins.str) -> None:
        jsii.set(self, "sku", value)

    @builtins.property # type: ignore
    @jsii.member(jsii_name="capacity")
    def capacity(self) -> typing.Optional[jsii.Number]:
        return jsii.get(self, "capacity")

    @capacity.setter # type: ignore
    def capacity(self, value: typing.Optional[jsii.Number]) -> None:
        jsii.set(self, "capacity", value)

    @builtins.property # type: ignore
    @jsii.member(jsii_name="id")
    def id(self) -> typing.Optional[builtins.str]:
        return jsii.get(self, "id")

    @id.setter # type: ignore
    def id(self, value: typing.Optional[builtins.str]) -> None:
        jsii.set(self, "id", value)

    @builtins.property # type: ignore
    @jsii.member(jsii_name="tags")
    def tags(self) -> typing.Optional[typing.Mapping[builtins.str, builtins.str]]:
        return jsii.get(self, "tags")

    @tags.setter # type: ignore
    def tags(
        self,
        value: typing.Optional[typing.Mapping[builtins.str, builtins.str]],
    ) -> None:
        jsii.set(self, "tags", value)

    @builtins.property # type: ignore
    @jsii.member(jsii_name="timeouts")
    def timeouts(self) -> typing.Optional["ServicebusNamespaceTimeouts"]:
        return jsii.get(self, "timeouts")

    @timeouts.setter # type: ignore
    def timeouts(self, value: typing.Optional["ServicebusNamespaceTimeouts"]) -> None:
        jsii.set(self, "timeouts", value)

    @builtins.property # type: ignore
    @jsii.member(jsii_name="zoneRedundant")
    def zone_redundant(self) -> typing.Optional[builtins.bool]:
        return jsii.get(self, "zoneRedundant")

    @zone_redundant.setter # type: ignore
    def zone_redundant(self, value: typing.Optional[builtins.bool]) -> None:
        jsii.set(self, "zoneRedundant", value)


class ServicebusNamespaceAuthorizationRule(
    cdktf.TerraformResource,
    metaclass=jsii.JSIIMeta,
    jsii_type="@cdktf/provider-azurerm.ServicebusNamespaceAuthorizationRule",
):
    def __init__(
        self,
        scope: constructs.Construct,
        id: builtins.str,
        *,
        name: builtins.str,
        namespace_name: builtins.str,
        resource_group_name: builtins.str,
        listen: typing.Optional[builtins.bool] = None,
        manage: typing.Optional[builtins.bool] = None,
        send: typing.Optional[builtins.bool] = None,
        timeouts: typing.Optional["ServicebusNamespaceAuthorizationRuleTimeouts"] = None,
        count: typing.Optional[jsii.Number] = None,
        depends_on: typing.Optional[typing.List[cdktf.TerraformResource]] = None,
        lifecycle: typing.Optional[cdktf.TerraformResourceLifecycle] = None,
        provider: typing.Optional[cdktf.TerraformProvider] = None,
    ) -> None:
        """
        :param scope: -
        :param id: -
        :param name: 
        :param namespace_name: 
        :param resource_group_name: 
        :param listen: 
        :param manage: 
        :param send: 
        :param timeouts: timeouts block.
        :param count: 
        :param depends_on: 
        :param lifecycle: 
        :param provider: 
        """
        config = ServicebusNamespaceAuthorizationRuleConfig(
            name=name,
            namespace_name=namespace_name,
            resource_group_name=resource_group_name,
            listen=listen,
            manage=manage,
            send=send,
            timeouts=timeouts,
            count=count,
            depends_on=depends_on,
            lifecycle=lifecycle,
            provider=provider,
        )

        jsii.create(ServicebusNamespaceAuthorizationRule, self, [scope, id, config])

    @jsii.member(jsii_name="synthesizeAttributes")
    def _synthesize_attributes(self) -> typing.Mapping[builtins.str, typing.Any]:
        return jsii.invoke(self, "synthesizeAttributes", [])

    @builtins.property # type: ignore
    @jsii.member(jsii_name="primaryConnectionString")
    def primary_connection_string(self) -> builtins.str:
        return jsii.get(self, "primaryConnectionString")

    @builtins.property # type: ignore
    @jsii.member(jsii_name="primaryKey")
    def primary_key(self) -> builtins.str:
        return jsii.get(self, "primaryKey")

    @builtins.property # type: ignore
    @jsii.member(jsii_name="secondaryConnectionString")
    def secondary_connection_string(self) -> builtins.str:
        return jsii.get(self, "secondaryConnectionString")

    @builtins.property # type: ignore
    @jsii.member(jsii_name="secondaryKey")
    def secondary_key(self) -> builtins.str:
        return jsii.get(self, "secondaryKey")

    @builtins.property # type: ignore
    @jsii.member(jsii_name="name")
    def name(self) -> builtins.str:
        return jsii.get(self, "name")

    @name.setter # type: ignore
    def name(self, value: builtins.str) -> None:
        jsii.set(self, "name", value)

    @builtins.property # type: ignore
    @jsii.member(jsii_name="namespaceName")
    def namespace_name(self) -> builtins.str:
        return jsii.get(self, "namespaceName")

    @namespace_name.setter # type: ignore
    def namespace_name(self, value: builtins.str) -> None:
        jsii.set(self, "namespaceName", value)

    @builtins.property # type: ignore
    @jsii.member(jsii_name="resourceGroupName")
    def resource_group_name(self) -> builtins.str:
        return jsii.get(self, "resourceGroupName")

    @resource_group_name.setter # type: ignore
    def resource_group_name(self, value: builtins.str) -> None:
        jsii.set(self, "resourceGroupName", value)

    @builtins.property # type: ignore
    @jsii.member(jsii_name="id")
    def id(self) -> typing.Optional[builtins.str]:
        return jsii.get(self, "id")

    @id.setter # type: ignore
    def id(self, value: typing.Optional[builtins.str]) -> None:
        jsii.set(self, "id", value)

    @builtins.property # type: ignore
    @jsii.member(jsii_name="listen")
    def listen(self) -> typing.Optional[builtins.bool]:
        return jsii.get(self, "listen")

    @listen.setter # type: ignore
    def listen(self, value: typing.Optional[builtins.bool]) -> None:
        jsii.set(self, "listen", value)

    @builtins.property # type: ignore
    @jsii.member(jsii_name="manage")
    def manage(self) -> typing.Optional[builtins.bool]:
        return jsii.get(self, "manage")

    @manage.setter # type: ignore
    def manage(self, value: typing.Optional[builtins.bool]) -> None:
        jsii.set(self, "manage", value)

    @builtins.property # type: ignore
    @jsii.member(jsii_name="send")
    def send(self) -> typing.Optional[builtins.bool]:
        return jsii.get(self, "send")

    @send.setter # type: ignore
    def send(self, value: typing.Optional[builtins.bool]) -> None:
        jsii.set(self, "send", value)

    @builtins.property # type: ignore
    @jsii.member(jsii_name="timeouts")
    def timeouts(
        self,
    ) -> typing.Optional["ServicebusNamespaceAuthorizationRuleTimeouts"]:
        return jsii.get(self, "timeouts")

    @timeouts.setter # type: ignore
    def timeouts(
        self,
        value: typing.Optional["ServicebusNamespaceAuthorizationRuleTimeouts"],
    ) -> None:
        jsii.set(self, "timeouts", value)


@jsii.data_type(
    jsii_type="@cdktf/provider-azurerm.ServicebusNamespaceAuthorizationRuleConfig",
    jsii_struct_bases=[cdktf.TerraformMetaArguments],
    name_mapping={
        "count": "count",
        "depends_on": "dependsOn",
        "lifecycle": "lifecycle",
        "provider": "provider",
        "name": "name",
        "namespace_name": "namespaceName",
        "resource_group_name": "resourceGroupName",
        "listen": "listen",
        "manage": "manage",
        "send": "send",
        "timeouts": "timeouts",
    },
)
class ServicebusNamespaceAuthorizationRuleConfig(cdktf.TerraformMetaArguments):
    def __init__(
        self,
        *,
        count: typing.Optional[jsii.Number] = None,
        depends_on: typing.Optional[typing.List[cdktf.TerraformResource]] = None,
        lifecycle: typing.Optional[cdktf.TerraformResourceLifecycle] = None,
        provider: typing.Optional[cdktf.TerraformProvider] = None,
        name: builtins.str,
        namespace_name: builtins.str,
        resource_group_name: builtins.str,
        listen: typing.Optional[builtins.bool] = None,
        manage: typing.Optional[builtins.bool] = None,
        send: typing.Optional[builtins.bool] = None,
        timeouts: typing.Optional["ServicebusNamespaceAuthorizationRuleTimeouts"] = None,
    ) -> None:
        """
        :param count: 
        :param depends_on: 
        :param lifecycle: 
        :param provider: 
        :param name: 
        :param namespace_name: 
        :param resource_group_name: 
        :param listen: 
        :param manage: 
        :param send: 
        :param timeouts: timeouts block.
        """
        if isinstance(lifecycle, dict):
            lifecycle = cdktf.TerraformResourceLifecycle(**lifecycle)
        if isinstance(timeouts, dict):
            timeouts = ServicebusNamespaceAuthorizationRuleTimeouts(**timeouts)
        self._values: typing.Dict[str, typing.Any] = {
            "name": name,
            "namespace_name": namespace_name,
            "resource_group_name": resource_group_name,
        }
        if count is not None:
            self._values["count"] = count
        if depends_on is not None:
            self._values["depends_on"] = depends_on
        if lifecycle is not None:
            self._values["lifecycle"] = lifecycle
        if provider is not None:
            self._values["provider"] = provider
        if listen is not None:
            self._values["listen"] = listen
        if manage is not None:
            self._values["manage"] = manage
        if send is not None:
            self._values["send"] = send
        if timeouts is not None:
            self._values["timeouts"] = timeouts

    @builtins.property
    def count(self) -> typing.Optional[jsii.Number]:
        """
        :stability: experimental
        """
        result = self._values.get("count")
        return result

    @builtins.property
    def depends_on(self) -> typing.Optional[typing.List[cdktf.TerraformResource]]:
        """
        :stability: experimental
        """
        result = self._values.get("depends_on")
        return result

    @builtins.property
    def lifecycle(self) -> typing.Optional[cdktf.TerraformResourceLifecycle]:
        """
        :stability: experimental
        """
        result = self._values.get("lifecycle")
        return result

    @builtins.property
    def provider(self) -> typing.Optional[cdktf.TerraformProvider]:
        """
        :stability: experimental
        """
        result = self._values.get("provider")
        return result

    @builtins.property
    def name(self) -> builtins.str:
        result = self._values.get("name")
        assert result is not None, "Required property 'name' is missing"
        return result

    @builtins.property
    def namespace_name(self) -> builtins.str:
        result = self._values.get("namespace_name")
        assert result is not None, "Required property 'namespace_name' is missing"
        return result

    @builtins.property
    def resource_group_name(self) -> builtins.str:
        result = self._values.get("resource_group_name")
        assert result is not None, "Required property 'resource_group_name' is missing"
        return result

    @builtins.property
    def listen(self) -> typing.Optional[builtins.bool]:
        result = self._values.get("listen")
        return result

    @builtins.property
    def manage(self) -> typing.Optional[builtins.bool]:
        result = self._values.get("manage")
        return result

    @builtins.property
    def send(self) -> typing.Optional[builtins.bool]:
        result = self._values.get("send")
        return result

    @builtins.property
    def timeouts(
        self,
    ) -> typing.Optional["ServicebusNamespaceAuthorizationRuleTimeouts"]:
        """timeouts block."""
        result = self._values.get("timeouts")
        return result

    def __eq__(self, rhs: typing.Any) -> builtins.bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs: typing.Any) -> builtins.bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return "ServicebusNamespaceAuthorizationRuleConfig(%s)" % ", ".join(
            k + "=" + repr(v) for k, v in self._values.items()
        )


@jsii.data_type(
    jsii_type="@cdktf/provider-azurerm.ServicebusNamespaceAuthorizationRuleTimeouts",
    jsii_struct_bases=[],
    name_mapping={
        "create": "create",
        "delete": "delete",
        "read": "read",
        "update": "update",
    },
)
class ServicebusNamespaceAuthorizationRuleTimeouts:
    def __init__(
        self,
        *,
        create: typing.Optional[builtins.str] = None,
        delete: typing.Optional[builtins.str] = None,
        read: typing.Optional[builtins.str] = None,
        update: typing.Optional[builtins.str] = None,
    ) -> None:
        """
        :param create: 
        :param delete: 
        :param read: 
        :param update: 
        """
        self._values: typing.Dict[str, typing.Any] = {}
        if create is not None:
            self._values["create"] = create
        if delete is not None:
            self._values["delete"] = delete
        if read is not None:
            self._values["read"] = read
        if update is not None:
            self._values["update"] = update

    @builtins.property
    def create(self) -> typing.Optional[builtins.str]:
        result = self._values.get("create")
        return result

    @builtins.property
    def delete(self) -> typing.Optional[builtins.str]:
        result = self._values.get("delete")
        return result

    @builtins.property
    def read(self) -> typing.Optional[builtins.str]:
        result = self._values.get("read")
        return result

    @builtins.property
    def update(self) -> typing.Optional[builtins.str]:
        result = self._values.get("update")
        return result

    def __eq__(self, rhs: typing.Any) -> builtins.bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs: typing.Any) -> builtins.bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return "ServicebusNamespaceAuthorizationRuleTimeouts(%s)" % ", ".join(
            k + "=" + repr(v) for k, v in self._values.items()
        )


@jsii.data_type(
    jsii_type="@cdktf/provider-azurerm.ServicebusNamespaceConfig",
    jsii_struct_bases=[cdktf.TerraformMetaArguments],
    name_mapping={
        "count": "count",
        "depends_on": "dependsOn",
        "lifecycle": "lifecycle",
        "provider": "provider",
        "location": "location",
        "name": "name",
        "resource_group_name": "resourceGroupName",
        "sku": "sku",
        "capacity": "capacity",
        "tags": "tags",
        "timeouts": "timeouts",
        "zone_redundant": "zoneRedundant",
    },
)
class ServicebusNamespaceConfig(cdktf.TerraformMetaArguments):
    def __init__(
        self,
        *,
        count: typing.Optional[jsii.Number] = None,
        depends_on: typing.Optional[typing.List[cdktf.TerraformResource]] = None,
        lifecycle: typing.Optional[cdktf.TerraformResourceLifecycle] = None,
        provider: typing.Optional[cdktf.TerraformProvider] = None,
        location: builtins.str,
        name: builtins.str,
        resource_group_name: builtins.str,
        sku: builtins.str,
        capacity: typing.Optional[jsii.Number] = None,
        tags: typing.Optional[typing.Mapping[builtins.str, builtins.str]] = None,
        timeouts: typing.Optional["ServicebusNamespaceTimeouts"] = None,
        zone_redundant: typing.Optional[builtins.bool] = None,
    ) -> None:
        """
        :param count: 
        :param depends_on: 
        :param lifecycle: 
        :param provider: 
        :param location: 
        :param name: 
        :param resource_group_name: 
        :param sku: 
        :param capacity: 
        :param tags: 
        :param timeouts: timeouts block.
        :param zone_redundant: 
        """
        if isinstance(lifecycle, dict):
            lifecycle = cdktf.TerraformResourceLifecycle(**lifecycle)
        if isinstance(timeouts, dict):
            timeouts = ServicebusNamespaceTimeouts(**timeouts)
        self._values: typing.Dict[str, typing.Any] = {
            "location": location,
            "name": name,
            "resource_group_name": resource_group_name,
            "sku": sku,
        }
        if count is not None:
            self._values["count"] = count
        if depends_on is not None:
            self._values["depends_on"] = depends_on
        if lifecycle is not None:
            self._values["lifecycle"] = lifecycle
        if provider is not None:
            self._values["provider"] = provider
        if capacity is not None:
            self._values["capacity"] = capacity
        if tags is not None:
            self._values["tags"] = tags
        if timeouts is not None:
            self._values["timeouts"] = timeouts
        if zone_redundant is not None:
            self._values["zone_redundant"] = zone_redundant

    @builtins.property
    def count(self) -> typing.Optional[jsii.Number]:
        """
        :stability: experimental
        """
        result = self._values.get("count")
        return result

    @builtins.property
    def depends_on(self) -> typing.Optional[typing.List[cdktf.TerraformResource]]:
        """
        :stability: experimental
        """
        result = self._values.get("depends_on")
        return result

    @builtins.property
    def lifecycle(self) -> typing.Optional[cdktf.TerraformResourceLifecycle]:
        """
        :stability: experimental
        """
        result = self._values.get("lifecycle")
        return result

    @builtins.property
    def provider(self) -> typing.Optional[cdktf.TerraformProvider]:
        """
        :stability: experimental
        """
        result = self._values.get("provider")
        return result

    @builtins.property
    def location(self) -> builtins.str:
        result = self._values.get("location")
        assert result is not None, "Required property 'location' is missing"
        return result

    @builtins.property
    def name(self) -> builtins.str:
        result = self._values.get("name")
        assert result is not None, "Required property 'name' is missing"
        return result

    @builtins.property
    def resource_group_name(self) -> builtins.str:
        result = self._values.get("resource_group_name")
        assert result is not None, "Required property 'resource_group_name' is missing"
        return result

    @builtins.property
    def sku(self) -> builtins.str:
        result = self._values.get("sku")
        assert result is not None, "Required property 'sku' is missing"
        return result

    @builtins.property
    def capacity(self) -> typing.Optional[jsii.Number]:
        result = self._values.get("capacity")
        return result

    @builtins.property
    def tags(self) -> typing.Optional[typing.Mapping[builtins.str, builtins.str]]:
        result = self._values.get("tags")
        return result

    @builtins.property
    def timeouts(self) -> typing.Optional["ServicebusNamespaceTimeouts"]:
        """timeouts block."""
        result = self._values.get("timeouts")
        return result

    @builtins.property
    def zone_redundant(self) -> typing.Optional[builtins.bool]:
        result = self._values.get("zone_redundant")
        return result

    def __eq__(self, rhs: typing.Any) -> builtins.bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs: typing.Any) -> builtins.bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return "ServicebusNamespaceConfig(%s)" % ", ".join(
            k + "=" + repr(v) for k, v in self._values.items()
        )


@jsii.data_type(
    jsii_type="@cdktf/provider-azurerm.ServicebusNamespaceTimeouts",
    jsii_struct_bases=[],
    name_mapping={
        "create": "create",
        "delete": "delete",
        "read": "read",
        "update": "update",
    },
)
class ServicebusNamespaceTimeouts:
    def __init__(
        self,
        *,
        create: typing.Optional[builtins.str] = None,
        delete: typing.Optional[builtins.str] = None,
        read: typing.Optional[builtins.str] = None,
        update: typing.Optional[builtins.str] = None,
    ) -> None:
        """
        :param create: 
        :param delete: 
        :param read: 
        :param update: 
        """
        self._values: typing.Dict[str, typing.Any] = {}
        if create is not None:
            self._values["create"] = create
        if delete is not None:
            self._values["delete"] = delete
        if read is not None:
            self._values["read"] = read
        if update is not None:
            self._values["update"] = update

    @builtins.property
    def create(self) -> typing.Optional[builtins.str]:
        result = self._values.get("create")
        return result

    @builtins.property
    def delete(self) -> typing.Optional[builtins.str]:
        result = self._values.get("delete")
        return result

    @builtins.property
    def read(self) -> typing.Optional[builtins.str]:
        result = self._values.get("read")
        return result

    @builtins.property
    def update(self) -> typing.Optional[builtins.str]:
        result = self._values.get("update")
        return result

    def __eq__(self, rhs: typing.Any) -> builtins.bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs: typing.Any) -> builtins.bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return "ServicebusNamespaceTimeouts(%s)" % ", ".join(
            k + "=" + repr(v) for k, v in self._values.items()
        )


class ServicebusQueue(
    cdktf.TerraformResource,
    metaclass=jsii.JSIIMeta,
    jsii_type="@cdktf/provider-azurerm.ServicebusQueue",
):
    def __init__(
        self,
        scope: constructs.Construct,
        id: builtins.str,
        *,
        name: builtins.str,
        namespace_name: builtins.str,
        resource_group_name: builtins.str,
        auto_delete_on_idle: typing.Optional[builtins.str] = None,
        dead_lettering_on_message_expiration: typing.Optional[builtins.bool] = None,
        default_message_ttl: typing.Optional[builtins.str] = None,
        duplicate_detection_history_time_window: typing.Optional[builtins.str] = None,
        enable_express: typing.Optional[builtins.bool] = None,
        enable_partitioning: typing.Optional[builtins.bool] = None,
        lock_duration: typing.Optional[builtins.str] = None,
        max_delivery_count: typing.Optional[jsii.Number] = None,
        max_size_in_megabytes: typing.Optional[jsii.Number] = None,
        requires_duplicate_detection: typing.Optional[builtins.bool] = None,
        requires_session: typing.Optional[builtins.bool] = None,
        timeouts: typing.Optional["ServicebusQueueTimeouts"] = None,
        count: typing.Optional[jsii.Number] = None,
        depends_on: typing.Optional[typing.List[cdktf.TerraformResource]] = None,
        lifecycle: typing.Optional[cdktf.TerraformResourceLifecycle] = None,
        provider: typing.Optional[cdktf.TerraformProvider] = None,
    ) -> None:
        """
        :param scope: -
        :param id: -
        :param name: 
        :param namespace_name: 
        :param resource_group_name: 
        :param auto_delete_on_idle: 
        :param dead_lettering_on_message_expiration: 
        :param default_message_ttl: 
        :param duplicate_detection_history_time_window: 
        :param enable_express: 
        :param enable_partitioning: 
        :param lock_duration: 
        :param max_delivery_count: 
        :param max_size_in_megabytes: 
        :param requires_duplicate_detection: 
        :param requires_session: 
        :param timeouts: timeouts block.
        :param count: 
        :param depends_on: 
        :param lifecycle: 
        :param provider: 
        """
        config = ServicebusQueueConfig(
            name=name,
            namespace_name=namespace_name,
            resource_group_name=resource_group_name,
            auto_delete_on_idle=auto_delete_on_idle,
            dead_lettering_on_message_expiration=dead_lettering_on_message_expiration,
            default_message_ttl=default_message_ttl,
            duplicate_detection_history_time_window=duplicate_detection_history_time_window,
            enable_express=enable_express,
            enable_partitioning=enable_partitioning,
            lock_duration=lock_duration,
            max_delivery_count=max_delivery_count,
            max_size_in_megabytes=max_size_in_megabytes,
            requires_duplicate_detection=requires_duplicate_detection,
            requires_session=requires_session,
            timeouts=timeouts,
            count=count,
            depends_on=depends_on,
            lifecycle=lifecycle,
            provider=provider,
        )

        jsii.create(ServicebusQueue, self, [scope, id, config])

    @jsii.member(jsii_name="synthesizeAttributes")
    def _synthesize_attributes(self) -> typing.Mapping[builtins.str, typing.Any]:
        return jsii.invoke(self, "synthesizeAttributes", [])

    @builtins.property # type: ignore
    @jsii.member(jsii_name="name")
    def name(self) -> builtins.str:
        return jsii.get(self, "name")

    @name.setter # type: ignore
    def name(self, value: builtins.str) -> None:
        jsii.set(self, "name", value)

    @builtins.property # type: ignore
    @jsii.member(jsii_name="namespaceName")
    def namespace_name(self) -> builtins.str:
        return jsii.get(self, "namespaceName")

    @namespace_name.setter # type: ignore
    def namespace_name(self, value: builtins.str) -> None:
        jsii.set(self, "namespaceName", value)

    @builtins.property # type: ignore
    @jsii.member(jsii_name="resourceGroupName")
    def resource_group_name(self) -> builtins.str:
        return jsii.get(self, "resourceGroupName")

    @resource_group_name.setter # type: ignore
    def resource_group_name(self, value: builtins.str) -> None:
        jsii.set(self, "resourceGroupName", value)

    @builtins.property # type: ignore
    @jsii.member(jsii_name="autoDeleteOnIdle")
    def auto_delete_on_idle(self) -> typing.Optional[builtins.str]:
        return jsii.get(self, "autoDeleteOnIdle")

    @auto_delete_on_idle.setter # type: ignore
    def auto_delete_on_idle(self, value: typing.Optional[builtins.str]) -> None:
        jsii.set(self, "autoDeleteOnIdle", value)

    @builtins.property # type: ignore
    @jsii.member(jsii_name="deadLetteringOnMessageExpiration")
    def dead_lettering_on_message_expiration(self) -> typing.Optional[builtins.bool]:
        return jsii.get(self, "deadLetteringOnMessageExpiration")

    @dead_lettering_on_message_expiration.setter # type: ignore
    def dead_lettering_on_message_expiration(
        self,
        value: typing.Optional[builtins.bool],
    ) -> None:
        jsii.set(self, "deadLetteringOnMessageExpiration", value)

    @builtins.property # type: ignore
    @jsii.member(jsii_name="defaultMessageTtl")
    def default_message_ttl(self) -> typing.Optional[builtins.str]:
        return jsii.get(self, "defaultMessageTtl")

    @default_message_ttl.setter # type: ignore
    def default_message_ttl(self, value: typing.Optional[builtins.str]) -> None:
        jsii.set(self, "defaultMessageTtl", value)

    @builtins.property # type: ignore
    @jsii.member(jsii_name="duplicateDetectionHistoryTimeWindow")
    def duplicate_detection_history_time_window(self) -> typing.Optional[builtins.str]:
        return jsii.get(self, "duplicateDetectionHistoryTimeWindow")

    @duplicate_detection_history_time_window.setter # type: ignore
    def duplicate_detection_history_time_window(
        self,
        value: typing.Optional[builtins.str],
    ) -> None:
        jsii.set(self, "duplicateDetectionHistoryTimeWindow", value)

    @builtins.property # type: ignore
    @jsii.member(jsii_name="enableExpress")
    def enable_express(self) -> typing.Optional[builtins.bool]:
        return jsii.get(self, "enableExpress")

    @enable_express.setter # type: ignore
    def enable_express(self, value: typing.Optional[builtins.bool]) -> None:
        jsii.set(self, "enableExpress", value)

    @builtins.property # type: ignore
    @jsii.member(jsii_name="enablePartitioning")
    def enable_partitioning(self) -> typing.Optional[builtins.bool]:
        return jsii.get(self, "enablePartitioning")

    @enable_partitioning.setter # type: ignore
    def enable_partitioning(self, value: typing.Optional[builtins.bool]) -> None:
        jsii.set(self, "enablePartitioning", value)

    @builtins.property # type: ignore
    @jsii.member(jsii_name="id")
    def id(self) -> typing.Optional[builtins.str]:
        return jsii.get(self, "id")

    @id.setter # type: ignore
    def id(self, value: typing.Optional[builtins.str]) -> None:
        jsii.set(self, "id", value)

    @builtins.property # type: ignore
    @jsii.member(jsii_name="lockDuration")
    def lock_duration(self) -> typing.Optional[builtins.str]:
        return jsii.get(self, "lockDuration")

    @lock_duration.setter # type: ignore
    def lock_duration(self, value: typing.Optional[builtins.str]) -> None:
        jsii.set(self, "lockDuration", value)

    @builtins.property # type: ignore
    @jsii.member(jsii_name="maxDeliveryCount")
    def max_delivery_count(self) -> typing.Optional[jsii.Number]:
        return jsii.get(self, "maxDeliveryCount")

    @max_delivery_count.setter # type: ignore
    def max_delivery_count(self, value: typing.Optional[jsii.Number]) -> None:
        jsii.set(self, "maxDeliveryCount", value)

    @builtins.property # type: ignore
    @jsii.member(jsii_name="maxSizeInMegabytes")
    def max_size_in_megabytes(self) -> typing.Optional[jsii.Number]:
        return jsii.get(self, "maxSizeInMegabytes")

    @max_size_in_megabytes.setter # type: ignore
    def max_size_in_megabytes(self, value: typing.Optional[jsii.Number]) -> None:
        jsii.set(self, "maxSizeInMegabytes", value)

    @builtins.property # type: ignore
    @jsii.member(jsii_name="requiresDuplicateDetection")
    def requires_duplicate_detection(self) -> typing.Optional[builtins.bool]:
        return jsii.get(self, "requiresDuplicateDetection")

    @requires_duplicate_detection.setter # type: ignore
    def requires_duplicate_detection(
        self,
        value: typing.Optional[builtins.bool],
    ) -> None:
        jsii.set(self, "requiresDuplicateDetection", value)

    @builtins.property # type: ignore
    @jsii.member(jsii_name="requiresSession")
    def requires_session(self) -> typing.Optional[builtins.bool]:
        return jsii.get(self, "requiresSession")

    @requires_session.setter # type: ignore
    def requires_session(self, value: typing.Optional[builtins.bool]) -> None:
        jsii.set(self, "requiresSession", value)

    @builtins.property # type: ignore
    @jsii.member(jsii_name="timeouts")
    def timeouts(self) -> typing.Optional["ServicebusQueueTimeouts"]:
        return jsii.get(self, "timeouts")

    @timeouts.setter # type: ignore
    def timeouts(self, value: typing.Optional["ServicebusQueueTimeouts"]) -> None:
        jsii.set(self, "timeouts", value)


class ServicebusQueueAuthorizationRule(
    cdktf.TerraformResource,
    metaclass=jsii.JSIIMeta,
    jsii_type="@cdktf/provider-azurerm.ServicebusQueueAuthorizationRule",
):
    def __init__(
        self,
        scope: constructs.Construct,
        id: builtins.str,
        *,
        name: builtins.str,
        namespace_name: builtins.str,
        queue_name: builtins.str,
        resource_group_name: builtins.str,
        listen: typing.Optional[builtins.bool] = None,
        manage: typing.Optional[builtins.bool] = None,
        send: typing.Optional[builtins.bool] = None,
        timeouts: typing.Optional["ServicebusQueueAuthorizationRuleTimeouts"] = None,
        count: typing.Optional[jsii.Number] = None,
        depends_on: typing.Optional[typing.List[cdktf.TerraformResource]] = None,
        lifecycle: typing.Optional[cdktf.TerraformResourceLifecycle] = None,
        provider: typing.Optional[cdktf.TerraformProvider] = None,
    ) -> None:
        """
        :param scope: -
        :param id: -
        :param name: 
        :param namespace_name: 
        :param queue_name: 
        :param resource_group_name: 
        :param listen: 
        :param manage: 
        :param send: 
        :param timeouts: timeouts block.
        :param count: 
        :param depends_on: 
        :param lifecycle: 
        :param provider: 
        """
        config = ServicebusQueueAuthorizationRuleConfig(
            name=name,
            namespace_name=namespace_name,
            queue_name=queue_name,
            resource_group_name=resource_group_name,
            listen=listen,
            manage=manage,
            send=send,
            timeouts=timeouts,
            count=count,
            depends_on=depends_on,
            lifecycle=lifecycle,
            provider=provider,
        )

        jsii.create(ServicebusQueueAuthorizationRule, self, [scope, id, config])

    @jsii.member(jsii_name="synthesizeAttributes")
    def _synthesize_attributes(self) -> typing.Mapping[builtins.str, typing.Any]:
        return jsii.invoke(self, "synthesizeAttributes", [])

    @builtins.property # type: ignore
    @jsii.member(jsii_name="primaryConnectionString")
    def primary_connection_string(self) -> builtins.str:
        return jsii.get(self, "primaryConnectionString")

    @builtins.property # type: ignore
    @jsii.member(jsii_name="primaryKey")
    def primary_key(self) -> builtins.str:
        return jsii.get(self, "primaryKey")

    @builtins.property # type: ignore
    @jsii.member(jsii_name="secondaryConnectionString")
    def secondary_connection_string(self) -> builtins.str:
        return jsii.get(self, "secondaryConnectionString")

    @builtins.property # type: ignore
    @jsii.member(jsii_name="secondaryKey")
    def secondary_key(self) -> builtins.str:
        return jsii.get(self, "secondaryKey")

    @builtins.property # type: ignore
    @jsii.member(jsii_name="name")
    def name(self) -> builtins.str:
        return jsii.get(self, "name")

    @name.setter # type: ignore
    def name(self, value: builtins.str) -> None:
        jsii.set(self, "name", value)

    @builtins.property # type: ignore
    @jsii.member(jsii_name="namespaceName")
    def namespace_name(self) -> builtins.str:
        return jsii.get(self, "namespaceName")

    @namespace_name.setter # type: ignore
    def namespace_name(self, value: builtins.str) -> None:
        jsii.set(self, "namespaceName", value)

    @builtins.property # type: ignore
    @jsii.member(jsii_name="queueName")
    def queue_name(self) -> builtins.str:
        return jsii.get(self, "queueName")

    @queue_name.setter # type: ignore
    def queue_name(self, value: builtins.str) -> None:
        jsii.set(self, "queueName", value)

    @builtins.property # type: ignore
    @jsii.member(jsii_name="resourceGroupName")
    def resource_group_name(self) -> builtins.str:
        return jsii.get(self, "resourceGroupName")

    @resource_group_name.setter # type: ignore
    def resource_group_name(self, value: builtins.str) -> None:
        jsii.set(self, "resourceGroupName", value)

    @builtins.property # type: ignore
    @jsii.member(jsii_name="id")
    def id(self) -> typing.Optional[builtins.str]:
        return jsii.get(self, "id")

    @id.setter # type: ignore
    def id(self, value: typing.Optional[builtins.str]) -> None:
        jsii.set(self, "id", value)

    @builtins.property # type: ignore
    @jsii.member(jsii_name="listen")
    def listen(self) -> typing.Optional[builtins.bool]:
        return jsii.get(self, "listen")

    @listen.setter # type: ignore
    def listen(self, value: typing.Optional[builtins.bool]) -> None:
        jsii.set(self, "listen", value)

    @builtins.property # type: ignore
    @jsii.member(jsii_name="manage")
    def manage(self) -> typing.Optional[builtins.bool]:
        return jsii.get(self, "manage")

    @manage.setter # type: ignore
    def manage(self, value: typing.Optional[builtins.bool]) -> None:
        jsii.set(self, "manage", value)

    @builtins.property # type: ignore
    @jsii.member(jsii_name="send")
    def send(self) -> typing.Optional[builtins.bool]:
        return jsii.get(self, "send")

    @send.setter # type: ignore
    def send(self, value: typing.Optional[builtins.bool]) -> None:
        jsii.set(self, "send", value)

    @builtins.property # type: ignore
    @jsii.member(jsii_name="timeouts")
    def timeouts(self) -> typing.Optional["ServicebusQueueAuthorizationRuleTimeouts"]:
        return jsii.get(self, "timeouts")

    @timeouts.setter # type: ignore
    def timeouts(
        self,
        value: typing.Optional["ServicebusQueueAuthorizationRuleTimeouts"],
    ) -> None:
        jsii.set(self, "timeouts", value)


@jsii.data_type(
    jsii_type="@cdktf/provider-azurerm.ServicebusQueueAuthorizationRuleConfig",
    jsii_struct_bases=[cdktf.TerraformMetaArguments],
    name_mapping={
        "count": "count",
        "depends_on": "dependsOn",
        "lifecycle": "lifecycle",
        "provider": "provider",
        "name": "name",
        "namespace_name": "namespaceName",
        "queue_name": "queueName",
        "resource_group_name": "resourceGroupName",
        "listen": "listen",
        "manage": "manage",
        "send": "send",
        "timeouts": "timeouts",
    },
)
class ServicebusQueueAuthorizationRuleConfig(cdktf.TerraformMetaArguments):
    def __init__(
        self,
        *,
        count: typing.Optional[jsii.Number] = None,
        depends_on: typing.Optional[typing.List[cdktf.TerraformResource]] = None,
        lifecycle: typing.Optional[cdktf.TerraformResourceLifecycle] = None,
        provider: typing.Optional[cdktf.TerraformProvider] = None,
        name: builtins.str,
        namespace_name: builtins.str,
        queue_name: builtins.str,
        resource_group_name: builtins.str,
        listen: typing.Optional[builtins.bool] = None,
        manage: typing.Optional[builtins.bool] = None,
        send: typing.Optional[builtins.bool] = None,
        timeouts: typing.Optional["ServicebusQueueAuthorizationRuleTimeouts"] = None,
    ) -> None:
        """
        :param count: 
        :param depends_on: 
        :param lifecycle: 
        :param provider: 
        :param name: 
        :param namespace_name: 
        :param queue_name: 
        :param resource_group_name: 
        :param listen: 
        :param manage: 
        :param send: 
        :param timeouts: timeouts block.
        """
        if isinstance(lifecycle, dict):
            lifecycle = cdktf.TerraformResourceLifecycle(**lifecycle)
        if isinstance(timeouts, dict):
            timeouts = ServicebusQueueAuthorizationRuleTimeouts(**timeouts)
        self._values: typing.Dict[str, typing.Any] = {
            "name": name,
            "namespace_name": namespace_name,
            "queue_name": queue_name,
            "resource_group_name": resource_group_name,
        }
        if count is not None:
            self._values["count"] = count
        if depends_on is not None:
            self._values["depends_on"] = depends_on
        if lifecycle is not None:
            self._values["lifecycle"] = lifecycle
        if provider is not None:
            self._values["provider"] = provider
        if listen is not None:
            self._values["listen"] = listen
        if manage is not None:
            self._values["manage"] = manage
        if send is not None:
            self._values["send"] = send
        if timeouts is not None:
            self._values["timeouts"] = timeouts

    @builtins.property
    def count(self) -> typing.Optional[jsii.Number]:
        """
        :stability: experimental
        """
        result = self._values.get("count")
        return result

    @builtins.property
    def depends_on(self) -> typing.Optional[typing.List[cdktf.TerraformResource]]:
        """
        :stability: experimental
        """
        result = self._values.get("depends_on")
        return result

    @builtins.property
    def lifecycle(self) -> typing.Optional[cdktf.TerraformResourceLifecycle]:
        """
        :stability: experimental
        """
        result = self._values.get("lifecycle")
        return result

    @builtins.property
    def provider(self) -> typing.Optional[cdktf.TerraformProvider]:
        """
        :stability: experimental
        """
        result = self._values.get("provider")
        return result

    @builtins.property
    def name(self) -> builtins.str:
        result = self._values.get("name")
        assert result is not None, "Required property 'name' is missing"
        return result

    @builtins.property
    def namespace_name(self) -> builtins.str:
        result = self._values.get("namespace_name")
        assert result is not None, "Required property 'namespace_name' is missing"
        return result

    @builtins.property
    def queue_name(self) -> builtins.str:
        result = self._values.get("queue_name")
        assert result is not None, "Required property 'queue_name' is missing"
        return result

    @builtins.property
    def resource_group_name(self) -> builtins.str:
        result = self._values.get("resource_group_name")
        assert result is not None, "Required property 'resource_group_name' is missing"
        return result

    @builtins.property
    def listen(self) -> typing.Optional[builtins.bool]:
        result = self._values.get("listen")
        return result

    @builtins.property
    def manage(self) -> typing.Optional[builtins.bool]:
        result = self._values.get("manage")
        return result

    @builtins.property
    def send(self) -> typing.Optional[builtins.bool]:
        result = self._values.get("send")
        return result

    @builtins.property
    def timeouts(self) -> typing.Optional["ServicebusQueueAuthorizationRuleTimeouts"]:
        """timeouts block."""
        result = self._values.get("timeouts")
        return result

    def __eq__(self, rhs: typing.Any) -> builtins.bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs: typing.Any) -> builtins.bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return "ServicebusQueueAuthorizationRuleConfig(%s)" % ", ".join(
            k + "=" + repr(v) for k, v in self._values.items()
        )


@jsii.data_type(
    jsii_type="@cdktf/provider-azurerm.ServicebusQueueAuthorizationRuleTimeouts",
    jsii_struct_bases=[],
    name_mapping={
        "create": "create",
        "delete": "delete",
        "read": "read",
        "update": "update",
    },
)
class ServicebusQueueAuthorizationRuleTimeouts:
    def __init__(
        self,
        *,
        create: typing.Optional[builtins.str] = None,
        delete: typing.Optional[builtins.str] = None,
        read: typing.Optional[builtins.str] = None,
        update: typing.Optional[builtins.str] = None,
    ) -> None:
        """
        :param create: 
        :param delete: 
        :param read: 
        :param update: 
        """
        self._values: typing.Dict[str, typing.Any] = {}
        if create is not None:
            self._values["create"] = create
        if delete is not None:
            self._values["delete"] = delete
        if read is not None:
            self._values["read"] = read
        if update is not None:
            self._values["update"] = update

    @builtins.property
    def create(self) -> typing.Optional[builtins.str]:
        result = self._values.get("create")
        return result

    @builtins.property
    def delete(self) -> typing.Optional[builtins.str]:
        result = self._values.get("delete")
        return result

    @builtins.property
    def read(self) -> typing.Optional[builtins.str]:
        result = self._values.get("read")
        return result

    @builtins.property
    def update(self) -> typing.Optional[builtins.str]:
        result = self._values.get("update")
        return result

    def __eq__(self, rhs: typing.Any) -> builtins.bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs: typing.Any) -> builtins.bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return "ServicebusQueueAuthorizationRuleTimeouts(%s)" % ", ".join(
            k + "=" + repr(v) for k, v in self._values.items()
        )


@jsii.data_type(
    jsii_type="@cdktf/provider-azurerm.ServicebusQueueConfig",
    jsii_struct_bases=[cdktf.TerraformMetaArguments],
    name_mapping={
        "count": "count",
        "depends_on": "dependsOn",
        "lifecycle": "lifecycle",
        "provider": "provider",
        "name": "name",
        "namespace_name": "namespaceName",
        "resource_group_name": "resourceGroupName",
        "auto_delete_on_idle": "autoDeleteOnIdle",
        "dead_lettering_on_message_expiration": "deadLetteringOnMessageExpiration",
        "default_message_ttl": "defaultMessageTtl",
        "duplicate_detection_history_time_window": "duplicateDetectionHistoryTimeWindow",
        "enable_express": "enableExpress",
        "enable_partitioning": "enablePartitioning",
        "lock_duration": "lockDuration",
        "max_delivery_count": "maxDeliveryCount",
        "max_size_in_megabytes": "maxSizeInMegabytes",
        "requires_duplicate_detection": "requiresDuplicateDetection",
        "requires_session": "requiresSession",
        "timeouts": "timeouts",
    },
)
class ServicebusQueueConfig(cdktf.TerraformMetaArguments):
    def __init__(
        self,
        *,
        count: typing.Optional[jsii.Number] = None,
        depends_on: typing.Optional[typing.List[cdktf.TerraformResource]] = None,
        lifecycle: typing.Optional[cdktf.TerraformResourceLifecycle] = None,
        provider: typing.Optional[cdktf.TerraformProvider] = None,
        name: builtins.str,
        namespace_name: builtins.str,
        resource_group_name: builtins.str,
        auto_delete_on_idle: typing.Optional[builtins.str] = None,
        dead_lettering_on_message_expiration: typing.Optional[builtins.bool] = None,
        default_message_ttl: typing.Optional[builtins.str] = None,
        duplicate_detection_history_time_window: typing.Optional[builtins.str] = None,
        enable_express: typing.Optional[builtins.bool] = None,
        enable_partitioning: typing.Optional[builtins.bool] = None,
        lock_duration: typing.Optional[builtins.str] = None,
        max_delivery_count: typing.Optional[jsii.Number] = None,
        max_size_in_megabytes: typing.Optional[jsii.Number] = None,
        requires_duplicate_detection: typing.Optional[builtins.bool] = None,
        requires_session: typing.Optional[builtins.bool] = None,
        timeouts: typing.Optional["ServicebusQueueTimeouts"] = None,
    ) -> None:
        """
        :param count: 
        :param depends_on: 
        :param lifecycle: 
        :param provider: 
        :param name: 
        :param namespace_name: 
        :param resource_group_name: 
        :param auto_delete_on_idle: 
        :param dead_lettering_on_message_expiration: 
        :param default_message_ttl: 
        :param duplicate_detection_history_time_window: 
        :param enable_express: 
        :param enable_partitioning: 
        :param lock_duration: 
        :param max_delivery_count: 
        :param max_size_in_megabytes: 
        :param requires_duplicate_detection: 
        :param requires_session: 
        :param timeouts: timeouts block.
        """
        if isinstance(lifecycle, dict):
            lifecycle = cdktf.TerraformResourceLifecycle(**lifecycle)
        if isinstance(timeouts, dict):
            timeouts = ServicebusQueueTimeouts(**timeouts)
        self._values: typing.Dict[str, typing.Any] = {
            "name": name,
            "namespace_name": namespace_name,
            "resource_group_name": resource_group_name,
        }
        if count is not None:
            self._values["count"] = count
        if depends_on is not None:
            self._values["depends_on"] = depends_on
        if lifecycle is not None:
            self._values["lifecycle"] = lifecycle
        if provider is not None:
            self._values["provider"] = provider
        if auto_delete_on_idle is not None:
            self._values["auto_delete_on_idle"] = auto_delete_on_idle
        if dead_lettering_on_message_expiration is not None:
            self._values["dead_lettering_on_message_expiration"] = dead_lettering_on_message_expiration
        if default_message_ttl is not None:
            self._values["default_message_ttl"] = default_message_ttl
        if duplicate_detection_history_time_window is not None:
            self._values["duplicate_detection_history_time_window"] = duplicate_detection_history_time_window
        if enable_express is not None:
            self._values["enable_express"] = enable_express
        if enable_partitioning is not None:
            self._values["enable_partitioning"] = enable_partitioning
        if lock_duration is not None:
            self._values["lock_duration"] = lock_duration
        if max_delivery_count is not None:
            self._values["max_delivery_count"] = max_delivery_count
        if max_size_in_megabytes is not None:
            self._values["max_size_in_megabytes"] = max_size_in_megabytes
        if requires_duplicate_detection is not None:
            self._values["requires_duplicate_detection"] = requires_duplicate_detection
        if requires_session is not None:
            self._values["requires_session"] = requires_session
        if timeouts is not None:
            self._values["timeouts"] = timeouts

    @builtins.property
    def count(self) -> typing.Optional[jsii.Number]:
        """
        :stability: experimental
        """
        result = self._values.get("count")
        return result

    @builtins.property
    def depends_on(self) -> typing.Optional[typing.List[cdktf.TerraformResource]]:
        """
        :stability: experimental
        """
        result = self._values.get("depends_on")
        return result

    @builtins.property
    def lifecycle(self) -> typing.Optional[cdktf.TerraformResourceLifecycle]:
        """
        :stability: experimental
        """
        result = self._values.get("lifecycle")
        return result

    @builtins.property
    def provider(self) -> typing.Optional[cdktf.TerraformProvider]:
        """
        :stability: experimental
        """
        result = self._values.get("provider")
        return result

    @builtins.property
    def name(self) -> builtins.str:
        result = self._values.get("name")
        assert result is not None, "Required property 'name' is missing"
        return result

    @builtins.property
    def namespace_name(self) -> builtins.str:
        result = self._values.get("namespace_name")
        assert result is not None, "Required property 'namespace_name' is missing"
        return result

    @builtins.property
    def resource_group_name(self) -> builtins.str:
        result = self._values.get("resource_group_name")
        assert result is not None, "Required property 'resource_group_name' is missing"
        return result

    @builtins.property
    def auto_delete_on_idle(self) -> typing.Optional[builtins.str]:
        result = self._values.get("auto_delete_on_idle")
        return result

    @builtins.property
    def dead_lettering_on_message_expiration(self) -> typing.Optional[builtins.bool]:
        result = self._values.get("dead_lettering_on_message_expiration")
        return result

    @builtins.property
    def default_message_ttl(self) -> typing.Optional[builtins.str]:
        result = self._values.get("default_message_ttl")
        return result

    @builtins.property
    def duplicate_detection_history_time_window(self) -> typing.Optional[builtins.str]:
        result = self._values.get("duplicate_detection_history_time_window")
        return result

    @builtins.property
    def enable_express(self) -> typing.Optional[builtins.bool]:
        result = self._values.get("enable_express")
        return result

    @builtins.property
    def enable_partitioning(self) -> typing.Optional[builtins.bool]:
        result = self._values.get("enable_partitioning")
        return result

    @builtins.property
    def lock_duration(self) -> typing.Optional[builtins.str]:
        result = self._values.get("lock_duration")
        return result

    @builtins.property
    def max_delivery_count(self) -> typing.Optional[jsii.Number]:
        result = self._values.get("max_delivery_count")
        return result

    @builtins.property
    def max_size_in_megabytes(self) -> typing.Optional[jsii.Number]:
        result = self._values.get("max_size_in_megabytes")
        return result

    @builtins.property
    def requires_duplicate_detection(self) -> typing.Optional[builtins.bool]:
        result = self._values.get("requires_duplicate_detection")
        return result

    @builtins.property
    def requires_session(self) -> typing.Optional[builtins.bool]:
        result = self._values.get("requires_session")
        return result

    @builtins.property
    def timeouts(self) -> typing.Optional["ServicebusQueueTimeouts"]:
        """timeouts block."""
        result = self._values.get("timeouts")
        return result

    def __eq__(self, rhs: typing.Any) -> builtins.bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs: typing.Any) -> builtins.bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return "ServicebusQueueConfig(%s)" % ", ".join(
            k + "=" + repr(v) for k, v in self._values.items()
        )


@jsii.data_type(
    jsii_type="@cdktf/provider-azurerm.ServicebusQueueTimeouts",
    jsii_struct_bases=[],
    name_mapping={
        "create": "create",
        "delete": "delete",
        "read": "read",
        "update": "update",
    },
)
class ServicebusQueueTimeouts:
    def __init__(
        self,
        *,
        create: typing.Optional[builtins.str] = None,
        delete: typing.Optional[builtins.str] = None,
        read: typing.Optional[builtins.str] = None,
        update: typing.Optional[builtins.str] = None,
    ) -> None:
        """
        :param create: 
        :param delete: 
        :param read: 
        :param update: 
        """
        self._values: typing.Dict[str, typing.Any] = {}
        if create is not None:
            self._values["create"] = create
        if delete is not None:
            self._values["delete"] = delete
        if read is not None:
            self._values["read"] = read
        if update is not None:
            self._values["update"] = update

    @builtins.property
    def create(self) -> typing.Optional[builtins.str]:
        result = self._values.get("create")
        return result

    @builtins.property
    def delete(self) -> typing.Optional[builtins.str]:
        result = self._values.get("delete")
        return result

    @builtins.property
    def read(self) -> typing.Optional[builtins.str]:
        result = self._values.get("read")
        return result

    @builtins.property
    def update(self) -> typing.Optional[builtins.str]:
        result = self._values.get("update")
        return result

    def __eq__(self, rhs: typing.Any) -> builtins.bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs: typing.Any) -> builtins.bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return "ServicebusQueueTimeouts(%s)" % ", ".join(
            k + "=" + repr(v) for k, v in self._values.items()
        )


class ServicebusSubscription(
    cdktf.TerraformResource,
    metaclass=jsii.JSIIMeta,
    jsii_type="@cdktf/provider-azurerm.ServicebusSubscription",
):
    def __init__(
        self,
        scope: constructs.Construct,
        id: builtins.str,
        *,
        max_delivery_count: jsii.Number,
        name: builtins.str,
        namespace_name: builtins.str,
        resource_group_name: builtins.str,
        topic_name: builtins.str,
        auto_delete_on_idle: typing.Optional[builtins.str] = None,
        dead_lettering_on_message_expiration: typing.Optional[builtins.bool] = None,
        default_message_ttl: typing.Optional[builtins.str] = None,
        enable_batched_operations: typing.Optional[builtins.bool] = None,
        forward_dead_lettered_messages_to: typing.Optional[builtins.str] = None,
        forward_to: typing.Optional[builtins.str] = None,
        lock_duration: typing.Optional[builtins.str] = None,
        requires_session: typing.Optional[builtins.bool] = None,
        timeouts: typing.Optional["ServicebusSubscriptionTimeouts"] = None,
        count: typing.Optional[jsii.Number] = None,
        depends_on: typing.Optional[typing.List[cdktf.TerraformResource]] = None,
        lifecycle: typing.Optional[cdktf.TerraformResourceLifecycle] = None,
        provider: typing.Optional[cdktf.TerraformProvider] = None,
    ) -> None:
        """
        :param scope: -
        :param id: -
        :param max_delivery_count: 
        :param name: 
        :param namespace_name: 
        :param resource_group_name: 
        :param topic_name: 
        :param auto_delete_on_idle: 
        :param dead_lettering_on_message_expiration: 
        :param default_message_ttl: 
        :param enable_batched_operations: 
        :param forward_dead_lettered_messages_to: 
        :param forward_to: 
        :param lock_duration: 
        :param requires_session: 
        :param timeouts: timeouts block.
        :param count: 
        :param depends_on: 
        :param lifecycle: 
        :param provider: 
        """
        config = ServicebusSubscriptionConfig(
            max_delivery_count=max_delivery_count,
            name=name,
            namespace_name=namespace_name,
            resource_group_name=resource_group_name,
            topic_name=topic_name,
            auto_delete_on_idle=auto_delete_on_idle,
            dead_lettering_on_message_expiration=dead_lettering_on_message_expiration,
            default_message_ttl=default_message_ttl,
            enable_batched_operations=enable_batched_operations,
            forward_dead_lettered_messages_to=forward_dead_lettered_messages_to,
            forward_to=forward_to,
            lock_duration=lock_duration,
            requires_session=requires_session,
            timeouts=timeouts,
            count=count,
            depends_on=depends_on,
            lifecycle=lifecycle,
            provider=provider,
        )

        jsii.create(ServicebusSubscription, self, [scope, id, config])

    @jsii.member(jsii_name="synthesizeAttributes")
    def _synthesize_attributes(self) -> typing.Mapping[builtins.str, typing.Any]:
        return jsii.invoke(self, "synthesizeAttributes", [])

    @builtins.property # type: ignore
    @jsii.member(jsii_name="maxDeliveryCount")
    def max_delivery_count(self) -> jsii.Number:
        return jsii.get(self, "maxDeliveryCount")

    @max_delivery_count.setter # type: ignore
    def max_delivery_count(self, value: jsii.Number) -> None:
        jsii.set(self, "maxDeliveryCount", value)

    @builtins.property # type: ignore
    @jsii.member(jsii_name="name")
    def name(self) -> builtins.str:
        return jsii.get(self, "name")

    @name.setter # type: ignore
    def name(self, value: builtins.str) -> None:
        jsii.set(self, "name", value)

    @builtins.property # type: ignore
    @jsii.member(jsii_name="namespaceName")
    def namespace_name(self) -> builtins.str:
        return jsii.get(self, "namespaceName")

    @namespace_name.setter # type: ignore
    def namespace_name(self, value: builtins.str) -> None:
        jsii.set(self, "namespaceName", value)

    @builtins.property # type: ignore
    @jsii.member(jsii_name="resourceGroupName")
    def resource_group_name(self) -> builtins.str:
        return jsii.get(self, "resourceGroupName")

    @resource_group_name.setter # type: ignore
    def resource_group_name(self, value: builtins.str) -> None:
        jsii.set(self, "resourceGroupName", value)

    @builtins.property # type: ignore
    @jsii.member(jsii_name="topicName")
    def topic_name(self) -> builtins.str:
        return jsii.get(self, "topicName")

    @topic_name.setter # type: ignore
    def topic_name(self, value: builtins.str) -> None:
        jsii.set(self, "topicName", value)

    @builtins.property # type: ignore
    @jsii.member(jsii_name="autoDeleteOnIdle")
    def auto_delete_on_idle(self) -> typing.Optional[builtins.str]:
        return jsii.get(self, "autoDeleteOnIdle")

    @auto_delete_on_idle.setter # type: ignore
    def auto_delete_on_idle(self, value: typing.Optional[builtins.str]) -> None:
        jsii.set(self, "autoDeleteOnIdle", value)

    @builtins.property # type: ignore
    @jsii.member(jsii_name="deadLetteringOnMessageExpiration")
    def dead_lettering_on_message_expiration(self) -> typing.Optional[builtins.bool]:
        return jsii.get(self, "deadLetteringOnMessageExpiration")

    @dead_lettering_on_message_expiration.setter # type: ignore
    def dead_lettering_on_message_expiration(
        self,
        value: typing.Optional[builtins.bool],
    ) -> None:
        jsii.set(self, "deadLetteringOnMessageExpiration", value)

    @builtins.property # type: ignore
    @jsii.member(jsii_name="defaultMessageTtl")
    def default_message_ttl(self) -> typing.Optional[builtins.str]:
        return jsii.get(self, "defaultMessageTtl")

    @default_message_ttl.setter # type: ignore
    def default_message_ttl(self, value: typing.Optional[builtins.str]) -> None:
        jsii.set(self, "defaultMessageTtl", value)

    @builtins.property # type: ignore
    @jsii.member(jsii_name="enableBatchedOperations")
    def enable_batched_operations(self) -> typing.Optional[builtins.bool]:
        return jsii.get(self, "enableBatchedOperations")

    @enable_batched_operations.setter # type: ignore
    def enable_batched_operations(self, value: typing.Optional[builtins.bool]) -> None:
        jsii.set(self, "enableBatchedOperations", value)

    @builtins.property # type: ignore
    @jsii.member(jsii_name="forwardDeadLetteredMessagesTo")
    def forward_dead_lettered_messages_to(self) -> typing.Optional[builtins.str]:
        return jsii.get(self, "forwardDeadLetteredMessagesTo")

    @forward_dead_lettered_messages_to.setter # type: ignore
    def forward_dead_lettered_messages_to(
        self,
        value: typing.Optional[builtins.str],
    ) -> None:
        jsii.set(self, "forwardDeadLetteredMessagesTo", value)

    @builtins.property # type: ignore
    @jsii.member(jsii_name="forwardTo")
    def forward_to(self) -> typing.Optional[builtins.str]:
        return jsii.get(self, "forwardTo")

    @forward_to.setter # type: ignore
    def forward_to(self, value: typing.Optional[builtins.str]) -> None:
        jsii.set(self, "forwardTo", value)

    @builtins.property # type: ignore
    @jsii.member(jsii_name="id")
    def id(self) -> typing.Optional[builtins.str]:
        return jsii.get(self, "id")

    @id.setter # type: ignore
    def id(self, value: typing.Optional[builtins.str]) -> None:
        jsii.set(self, "id", value)

    @builtins.property # type: ignore
    @jsii.member(jsii_name="lockDuration")
    def lock_duration(self) -> typing.Optional[builtins.str]:
        return jsii.get(self, "lockDuration")

    @lock_duration.setter # type: ignore
    def lock_duration(self, value: typing.Optional[builtins.str]) -> None:
        jsii.set(self, "lockDuration", value)

    @builtins.property # type: ignore
    @jsii.member(jsii_name="requiresSession")
    def requires_session(self) -> typing.Optional[builtins.bool]:
        return jsii.get(self, "requiresSession")

    @requires_session.setter # type: ignore
    def requires_session(self, value: typing.Optional[builtins.bool]) -> None:
        jsii.set(self, "requiresSession", value)

    @builtins.property # type: ignore
    @jsii.member(jsii_name="timeouts")
    def timeouts(self) -> typing.Optional["ServicebusSubscriptionTimeouts"]:
        return jsii.get(self, "timeouts")

    @timeouts.setter # type: ignore
    def timeouts(
        self,
        value: typing.Optional["ServicebusSubscriptionTimeouts"],
    ) -> None:
        jsii.set(self, "timeouts", value)


@jsii.data_type(
    jsii_type="@cdktf/provider-azurerm.ServicebusSubscriptionConfig",
    jsii_struct_bases=[cdktf.TerraformMetaArguments],
    name_mapping={
        "count": "count",
        "depends_on": "dependsOn",
        "lifecycle": "lifecycle",
        "provider": "provider",
        "max_delivery_count": "maxDeliveryCount",
        "name": "name",
        "namespace_name": "namespaceName",
        "resource_group_name": "resourceGroupName",
        "topic_name": "topicName",
        "auto_delete_on_idle": "autoDeleteOnIdle",
        "dead_lettering_on_message_expiration": "deadLetteringOnMessageExpiration",
        "default_message_ttl": "defaultMessageTtl",
        "enable_batched_operations": "enableBatchedOperations",
        "forward_dead_lettered_messages_to": "forwardDeadLetteredMessagesTo",
        "forward_to": "forwardTo",
        "lock_duration": "lockDuration",
        "requires_session": "requiresSession",
        "timeouts": "timeouts",
    },
)
class ServicebusSubscriptionConfig(cdktf.TerraformMetaArguments):
    def __init__(
        self,
        *,
        count: typing.Optional[jsii.Number] = None,
        depends_on: typing.Optional[typing.List[cdktf.TerraformResource]] = None,
        lifecycle: typing.Optional[cdktf.TerraformResourceLifecycle] = None,
        provider: typing.Optional[cdktf.TerraformProvider] = None,
        max_delivery_count: jsii.Number,
        name: builtins.str,
        namespace_name: builtins.str,
        resource_group_name: builtins.str,
        topic_name: builtins.str,
        auto_delete_on_idle: typing.Optional[builtins.str] = None,
        dead_lettering_on_message_expiration: typing.Optional[builtins.bool] = None,
        default_message_ttl: typing.Optional[builtins.str] = None,
        enable_batched_operations: typing.Optional[builtins.bool] = None,
        forward_dead_lettered_messages_to: typing.Optional[builtins.str] = None,
        forward_to: typing.Optional[builtins.str] = None,
        lock_duration: typing.Optional[builtins.str] = None,
        requires_session: typing.Optional[builtins.bool] = None,
        timeouts: typing.Optional["ServicebusSubscriptionTimeouts"] = None,
    ) -> None:
        """
        :param count: 
        :param depends_on: 
        :param lifecycle: 
        :param provider: 
        :param max_delivery_count: 
        :param name: 
        :param namespace_name: 
        :param resource_group_name: 
        :param topic_name: 
        :param auto_delete_on_idle: 
        :param dead_lettering_on_message_expiration: 
        :param default_message_ttl: 
        :param enable_batched_operations: 
        :param forward_dead_lettered_messages_to: 
        :param forward_to: 
        :param lock_duration: 
        :param requires_session: 
        :param timeouts: timeouts block.
        """
        if isinstance(lifecycle, dict):
            lifecycle = cdktf.TerraformResourceLifecycle(**lifecycle)
        if isinstance(timeouts, dict):
            timeouts = ServicebusSubscriptionTimeouts(**timeouts)
        self._values: typing.Dict[str, typing.Any] = {
            "max_delivery_count": max_delivery_count,
            "name": name,
            "namespace_name": namespace_name,
            "resource_group_name": resource_group_name,
            "topic_name": topic_name,
        }
        if count is not None:
            self._values["count"] = count
        if depends_on is not None:
            self._values["depends_on"] = depends_on
        if lifecycle is not None:
            self._values["lifecycle"] = lifecycle
        if provider is not None:
            self._values["provider"] = provider
        if auto_delete_on_idle is not None:
            self._values["auto_delete_on_idle"] = auto_delete_on_idle
        if dead_lettering_on_message_expiration is not None:
            self._values["dead_lettering_on_message_expiration"] = dead_lettering_on_message_expiration
        if default_message_ttl is not None:
            self._values["default_message_ttl"] = default_message_ttl
        if enable_batched_operations is not None:
            self._values["enable_batched_operations"] = enable_batched_operations
        if forward_dead_lettered_messages_to is not None:
            self._values["forward_dead_lettered_messages_to"] = forward_dead_lettered_messages_to
        if forward_to is not None:
            self._values["forward_to"] = forward_to
        if lock_duration is not None:
            self._values["lock_duration"] = lock_duration
        if requires_session is not None:
            self._values["requires_session"] = requires_session
        if timeouts is not None:
            self._values["timeouts"] = timeouts

    @builtins.property
    def count(self) -> typing.Optional[jsii.Number]:
        """
        :stability: experimental
        """
        result = self._values.get("count")
        return result

    @builtins.property
    def depends_on(self) -> typing.Optional[typing.List[cdktf.TerraformResource]]:
        """
        :stability: experimental
        """
        result = self._values.get("depends_on")
        return result

    @builtins.property
    def lifecycle(self) -> typing.Optional[cdktf.TerraformResourceLifecycle]:
        """
        :stability: experimental
        """
        result = self._values.get("lifecycle")
        return result

    @builtins.property
    def provider(self) -> typing.Optional[cdktf.TerraformProvider]:
        """
        :stability: experimental
        """
        result = self._values.get("provider")
        return result

    @builtins.property
    def max_delivery_count(self) -> jsii.Number:
        result = self._values.get("max_delivery_count")
        assert result is not None, "Required property 'max_delivery_count' is missing"
        return result

    @builtins.property
    def name(self) -> builtins.str:
        result = self._values.get("name")
        assert result is not None, "Required property 'name' is missing"
        return result

    @builtins.property
    def namespace_name(self) -> builtins.str:
        result = self._values.get("namespace_name")
        assert result is not None, "Required property 'namespace_name' is missing"
        return result

    @builtins.property
    def resource_group_name(self) -> builtins.str:
        result = self._values.get("resource_group_name")
        assert result is not None, "Required property 'resource_group_name' is missing"
        return result

    @builtins.property
    def topic_name(self) -> builtins.str:
        result = self._values.get("topic_name")
        assert result is not None, "Required property 'topic_name' is missing"
        return result

    @builtins.property
    def auto_delete_on_idle(self) -> typing.Optional[builtins.str]:
        result = self._values.get("auto_delete_on_idle")
        return result

    @builtins.property
    def dead_lettering_on_message_expiration(self) -> typing.Optional[builtins.bool]:
        result = self._values.get("dead_lettering_on_message_expiration")
        return result

    @builtins.property
    def default_message_ttl(self) -> typing.Optional[builtins.str]:
        result = self._values.get("default_message_ttl")
        return result

    @builtins.property
    def enable_batched_operations(self) -> typing.Optional[builtins.bool]:
        result = self._values.get("enable_batched_operations")
        return result

    @builtins.property
    def forward_dead_lettered_messages_to(self) -> typing.Optional[builtins.str]:
        result = self._values.get("forward_dead_lettered_messages_to")
        return result

    @builtins.property
    def forward_to(self) -> typing.Optional[builtins.str]:
        result = self._values.get("forward_to")
        return result

    @builtins.property
    def lock_duration(self) -> typing.Optional[builtins.str]:
        result = self._values.get("lock_duration")
        return result

    @builtins.property
    def requires_session(self) -> typing.Optional[builtins.bool]:
        result = self._values.get("requires_session")
        return result

    @builtins.property
    def timeouts(self) -> typing.Optional["ServicebusSubscriptionTimeouts"]:
        """timeouts block."""
        result = self._values.get("timeouts")
        return result

    def __eq__(self, rhs: typing.Any) -> builtins.bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs: typing.Any) -> builtins.bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return "ServicebusSubscriptionConfig(%s)" % ", ".join(
            k + "=" + repr(v) for k, v in self._values.items()
        )


class ServicebusSubscriptionRule(
    cdktf.TerraformResource,
    metaclass=jsii.JSIIMeta,
    jsii_type="@cdktf/provider-azurerm.ServicebusSubscriptionRule",
):
    def __init__(
        self,
        scope: constructs.Construct,
        id: builtins.str,
        *,
        filter_type: builtins.str,
        name: builtins.str,
        namespace_name: builtins.str,
        resource_group_name: builtins.str,
        subscription_name: builtins.str,
        topic_name: builtins.str,
        action: typing.Optional[builtins.str] = None,
        correlation_filter: typing.Optional[typing.List["ServicebusSubscriptionRuleCorrelationFilter"]] = None,
        sql_filter: typing.Optional[builtins.str] = None,
        timeouts: typing.Optional["ServicebusSubscriptionRuleTimeouts"] = None,
        count: typing.Optional[jsii.Number] = None,
        depends_on: typing.Optional[typing.List[cdktf.TerraformResource]] = None,
        lifecycle: typing.Optional[cdktf.TerraformResourceLifecycle] = None,
        provider: typing.Optional[cdktf.TerraformProvider] = None,
    ) -> None:
        """
        :param scope: -
        :param id: -
        :param filter_type: 
        :param name: 
        :param namespace_name: 
        :param resource_group_name: 
        :param subscription_name: 
        :param topic_name: 
        :param action: 
        :param correlation_filter: correlation_filter block.
        :param sql_filter: 
        :param timeouts: timeouts block.
        :param count: 
        :param depends_on: 
        :param lifecycle: 
        :param provider: 
        """
        config = ServicebusSubscriptionRuleConfig(
            filter_type=filter_type,
            name=name,
            namespace_name=namespace_name,
            resource_group_name=resource_group_name,
            subscription_name=subscription_name,
            topic_name=topic_name,
            action=action,
            correlation_filter=correlation_filter,
            sql_filter=sql_filter,
            timeouts=timeouts,
            count=count,
            depends_on=depends_on,
            lifecycle=lifecycle,
            provider=provider,
        )

        jsii.create(ServicebusSubscriptionRule, self, [scope, id, config])

    @jsii.member(jsii_name="synthesizeAttributes")
    def _synthesize_attributes(self) -> typing.Mapping[builtins.str, typing.Any]:
        return jsii.invoke(self, "synthesizeAttributes", [])

    @builtins.property # type: ignore
    @jsii.member(jsii_name="filterType")
    def filter_type(self) -> builtins.str:
        return jsii.get(self, "filterType")

    @filter_type.setter # type: ignore
    def filter_type(self, value: builtins.str) -> None:
        jsii.set(self, "filterType", value)

    @builtins.property # type: ignore
    @jsii.member(jsii_name="name")
    def name(self) -> builtins.str:
        return jsii.get(self, "name")

    @name.setter # type: ignore
    def name(self, value: builtins.str) -> None:
        jsii.set(self, "name", value)

    @builtins.property # type: ignore
    @jsii.member(jsii_name="namespaceName")
    def namespace_name(self) -> builtins.str:
        return jsii.get(self, "namespaceName")

    @namespace_name.setter # type: ignore
    def namespace_name(self, value: builtins.str) -> None:
        jsii.set(self, "namespaceName", value)

    @builtins.property # type: ignore
    @jsii.member(jsii_name="resourceGroupName")
    def resource_group_name(self) -> builtins.str:
        return jsii.get(self, "resourceGroupName")

    @resource_group_name.setter # type: ignore
    def resource_group_name(self, value: builtins.str) -> None:
        jsii.set(self, "resourceGroupName", value)

    @builtins.property # type: ignore
    @jsii.member(jsii_name="subscriptionName")
    def subscription_name(self) -> builtins.str:
        return jsii.get(self, "subscriptionName")

    @subscription_name.setter # type: ignore
    def subscription_name(self, value: builtins.str) -> None:
        jsii.set(self, "subscriptionName", value)

    @builtins.property # type: ignore
    @jsii.member(jsii_name="topicName")
    def topic_name(self) -> builtins.str:
        return jsii.get(self, "topicName")

    @topic_name.setter # type: ignore
    def topic_name(self, value: builtins.str) -> None:
        jsii.set(self, "topicName", value)

    @builtins.property # type: ignore
    @jsii.member(jsii_name="action")
    def action(self) -> typing.Optional[builtins.str]:
        return jsii.get(self, "action")

    @action.setter # type: ignore
    def action(self, value: typing.Optional[builtins.str]) -> None:
        jsii.set(self, "action", value)

    @builtins.property # type: ignore
    @jsii.member(jsii_name="correlationFilter")
    def correlation_filter(
        self,
    ) -> typing.Optional[typing.List["ServicebusSubscriptionRuleCorrelationFilter"]]:
        return jsii.get(self, "correlationFilter")

    @correlation_filter.setter # type: ignore
    def correlation_filter(
        self,
        value: typing.Optional[typing.List["ServicebusSubscriptionRuleCorrelationFilter"]],
    ) -> None:
        jsii.set(self, "correlationFilter", value)

    @builtins.property # type: ignore
    @jsii.member(jsii_name="id")
    def id(self) -> typing.Optional[builtins.str]:
        return jsii.get(self, "id")

    @id.setter # type: ignore
    def id(self, value: typing.Optional[builtins.str]) -> None:
        jsii.set(self, "id", value)

    @builtins.property # type: ignore
    @jsii.member(jsii_name="sqlFilter")
    def sql_filter(self) -> typing.Optional[builtins.str]:
        return jsii.get(self, "sqlFilter")

    @sql_filter.setter # type: ignore
    def sql_filter(self, value: typing.Optional[builtins.str]) -> None:
        jsii.set(self, "sqlFilter", value)

    @builtins.property # type: ignore
    @jsii.member(jsii_name="timeouts")
    def timeouts(self) -> typing.Optional["ServicebusSubscriptionRuleTimeouts"]:
        return jsii.get(self, "timeouts")

    @timeouts.setter # type: ignore
    def timeouts(
        self,
        value: typing.Optional["ServicebusSubscriptionRuleTimeouts"],
    ) -> None:
        jsii.set(self, "timeouts", value)


@jsii.data_type(
    jsii_type="@cdktf/provider-azurerm.ServicebusSubscriptionRuleConfig",
    jsii_struct_bases=[cdktf.TerraformMetaArguments],
    name_mapping={
        "count": "count",
        "depends_on": "dependsOn",
        "lifecycle": "lifecycle",
        "provider": "provider",
        "filter_type": "filterType",
        "name": "name",
        "namespace_name": "namespaceName",
        "resource_group_name": "resourceGroupName",
        "subscription_name": "subscriptionName",
        "topic_name": "topicName",
        "action": "action",
        "correlation_filter": "correlationFilter",
        "sql_filter": "sqlFilter",
        "timeouts": "timeouts",
    },
)
class ServicebusSubscriptionRuleConfig(cdktf.TerraformMetaArguments):
    def __init__(
        self,
        *,
        count: typing.Optional[jsii.Number] = None,
        depends_on: typing.Optional[typing.List[cdktf.TerraformResource]] = None,
        lifecycle: typing.Optional[cdktf.TerraformResourceLifecycle] = None,
        provider: typing.Optional[cdktf.TerraformProvider] = None,
        filter_type: builtins.str,
        name: builtins.str,
        namespace_name: builtins.str,
        resource_group_name: builtins.str,
        subscription_name: builtins.str,
        topic_name: builtins.str,
        action: typing.Optional[builtins.str] = None,
        correlation_filter: typing.Optional[typing.List["ServicebusSubscriptionRuleCorrelationFilter"]] = None,
        sql_filter: typing.Optional[builtins.str] = None,
        timeouts: typing.Optional["ServicebusSubscriptionRuleTimeouts"] = None,
    ) -> None:
        """
        :param count: 
        :param depends_on: 
        :param lifecycle: 
        :param provider: 
        :param filter_type: 
        :param name: 
        :param namespace_name: 
        :param resource_group_name: 
        :param subscription_name: 
        :param topic_name: 
        :param action: 
        :param correlation_filter: correlation_filter block.
        :param sql_filter: 
        :param timeouts: timeouts block.
        """
        if isinstance(lifecycle, dict):
            lifecycle = cdktf.TerraformResourceLifecycle(**lifecycle)
        if isinstance(timeouts, dict):
            timeouts = ServicebusSubscriptionRuleTimeouts(**timeouts)
        self._values: typing.Dict[str, typing.Any] = {
            "filter_type": filter_type,
            "name": name,
            "namespace_name": namespace_name,
            "resource_group_name": resource_group_name,
            "subscription_name": subscription_name,
            "topic_name": topic_name,
        }
        if count is not None:
            self._values["count"] = count
        if depends_on is not None:
            self._values["depends_on"] = depends_on
        if lifecycle is not None:
            self._values["lifecycle"] = lifecycle
        if provider is not None:
            self._values["provider"] = provider
        if action is not None:
            self._values["action"] = action
        if correlation_filter is not None:
            self._values["correlation_filter"] = correlation_filter
        if sql_filter is not None:
            self._values["sql_filter"] = sql_filter
        if timeouts is not None:
            self._values["timeouts"] = timeouts

    @builtins.property
    def count(self) -> typing.Optional[jsii.Number]:
        """
        :stability: experimental
        """
        result = self._values.get("count")
        return result

    @builtins.property
    def depends_on(self) -> typing.Optional[typing.List[cdktf.TerraformResource]]:
        """
        :stability: experimental
        """
        result = self._values.get("depends_on")
        return result

    @builtins.property
    def lifecycle(self) -> typing.Optional[cdktf.TerraformResourceLifecycle]:
        """
        :stability: experimental
        """
        result = self._values.get("lifecycle")
        return result

    @builtins.property
    def provider(self) -> typing.Optional[cdktf.TerraformProvider]:
        """
        :stability: experimental
        """
        result = self._values.get("provider")
        return result

    @builtins.property
    def filter_type(self) -> builtins.str:
        result = self._values.get("filter_type")
        assert result is not None, "Required property 'filter_type' is missing"
        return result

    @builtins.property
    def name(self) -> builtins.str:
        result = self._values.get("name")
        assert result is not None, "Required property 'name' is missing"
        return result

    @builtins.property
    def namespace_name(self) -> builtins.str:
        result = self._values.get("namespace_name")
        assert result is not None, "Required property 'namespace_name' is missing"
        return result

    @builtins.property
    def resource_group_name(self) -> builtins.str:
        result = self._values.get("resource_group_name")
        assert result is not None, "Required property 'resource_group_name' is missing"
        return result

    @builtins.property
    def subscription_name(self) -> builtins.str:
        result = self._values.get("subscription_name")
        assert result is not None, "Required property 'subscription_name' is missing"
        return result

    @builtins.property
    def topic_name(self) -> builtins.str:
        result = self._values.get("topic_name")
        assert result is not None, "Required property 'topic_name' is missing"
        return result

    @builtins.property
    def action(self) -> typing.Optional[builtins.str]:
        result = self._values.get("action")
        return result

    @builtins.property
    def correlation_filter(
        self,
    ) -> typing.Optional[typing.List["ServicebusSubscriptionRuleCorrelationFilter"]]:
        """correlation_filter block."""
        result = self._values.get("correlation_filter")
        return result

    @builtins.property
    def sql_filter(self) -> typing.Optional[builtins.str]:
        result = self._values.get("sql_filter")
        return result

    @builtins.property
    def timeouts(self) -> typing.Optional["ServicebusSubscriptionRuleTimeouts"]:
        """timeouts block."""
        result = self._values.get("timeouts")
        return result

    def __eq__(self, rhs: typing.Any) -> builtins.bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs: typing.Any) -> builtins.bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return "ServicebusSubscriptionRuleConfig(%s)" % ", ".join(
            k + "=" + repr(v) for k, v in self._values.items()
        )


@jsii.data_type(
    jsii_type="@cdktf/provider-azurerm.ServicebusSubscriptionRuleCorrelationFilter",
    jsii_struct_bases=[],
    name_mapping={
        "content_type": "contentType",
        "correlation_id": "correlationId",
        "label": "label",
        "message_id": "messageId",
        "reply_to": "replyTo",
        "reply_to_session_id": "replyToSessionId",
        "session_id": "sessionId",
        "to": "to",
    },
)
class ServicebusSubscriptionRuleCorrelationFilter:
    def __init__(
        self,
        *,
        content_type: typing.Optional[builtins.str] = None,
        correlation_id: typing.Optional[builtins.str] = None,
        label: typing.Optional[builtins.str] = None,
        message_id: typing.Optional[builtins.str] = None,
        reply_to: typing.Optional[builtins.str] = None,
        reply_to_session_id: typing.Optional[builtins.str] = None,
        session_id: typing.Optional[builtins.str] = None,
        to: typing.Optional[builtins.str] = None,
    ) -> None:
        """
        :param content_type: 
        :param correlation_id: 
        :param label: 
        :param message_id: 
        :param reply_to: 
        :param reply_to_session_id: 
        :param session_id: 
        :param to: 
        """
        self._values: typing.Dict[str, typing.Any] = {}
        if content_type is not None:
            self._values["content_type"] = content_type
        if correlation_id is not None:
            self._values["correlation_id"] = correlation_id
        if label is not None:
            self._values["label"] = label
        if message_id is not None:
            self._values["message_id"] = message_id
        if reply_to is not None:
            self._values["reply_to"] = reply_to
        if reply_to_session_id is not None:
            self._values["reply_to_session_id"] = reply_to_session_id
        if session_id is not None:
            self._values["session_id"] = session_id
        if to is not None:
            self._values["to"] = to

    @builtins.property
    def content_type(self) -> typing.Optional[builtins.str]:
        result = self._values.get("content_type")
        return result

    @builtins.property
    def correlation_id(self) -> typing.Optional[builtins.str]:
        result = self._values.get("correlation_id")
        return result

    @builtins.property
    def label(self) -> typing.Optional[builtins.str]:
        result = self._values.get("label")
        return result

    @builtins.property
    def message_id(self) -> typing.Optional[builtins.str]:
        result = self._values.get("message_id")
        return result

    @builtins.property
    def reply_to(self) -> typing.Optional[builtins.str]:
        result = self._values.get("reply_to")
        return result

    @builtins.property
    def reply_to_session_id(self) -> typing.Optional[builtins.str]:
        result = self._values.get("reply_to_session_id")
        return result

    @builtins.property
    def session_id(self) -> typing.Optional[builtins.str]:
        result = self._values.get("session_id")
        return result

    @builtins.property
    def to(self) -> typing.Optional[builtins.str]:
        result = self._values.get("to")
        return result

    def __eq__(self, rhs: typing.Any) -> builtins.bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs: typing.Any) -> builtins.bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return "ServicebusSubscriptionRuleCorrelationFilter(%s)" % ", ".join(
            k + "=" + repr(v) for k, v in self._values.items()
        )


@jsii.data_type(
    jsii_type="@cdktf/provider-azurerm.ServicebusSubscriptionRuleTimeouts",
    jsii_struct_bases=[],
    name_mapping={
        "create": "create",
        "delete": "delete",
        "read": "read",
        "update": "update",
    },
)
class ServicebusSubscriptionRuleTimeouts:
    def __init__(
        self,
        *,
        create: typing.Optional[builtins.str] = None,
        delete: typing.Optional[builtins.str] = None,
        read: typing.Optional[builtins.str] = None,
        update: typing.Optional[builtins.str] = None,
    ) -> None:
        """
        :param create: 
        :param delete: 
        :param read: 
        :param update: 
        """
        self._values: typing.Dict[str, typing.Any] = {}
        if create is not None:
            self._values["create"] = create
        if delete is not None:
            self._values["delete"] = delete
        if read is not None:
            self._values["read"] = read
        if update is not None:
            self._values["update"] = update

    @builtins.property
    def create(self) -> typing.Optional[builtins.str]:
        result = self._values.get("create")
        return result

    @builtins.property
    def delete(self) -> typing.Optional[builtins.str]:
        result = self._values.get("delete")
        return result

    @builtins.property
    def read(self) -> typing.Optional[builtins.str]:
        result = self._values.get("read")
        return result

    @builtins.property
    def update(self) -> typing.Optional[builtins.str]:
        result = self._values.get("update")
        return result

    def __eq__(self, rhs: typing.Any) -> builtins.bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs: typing.Any) -> builtins.bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return "ServicebusSubscriptionRuleTimeouts(%s)" % ", ".join(
            k + "=" + repr(v) for k, v in self._values.items()
        )


@jsii.data_type(
    jsii_type="@cdktf/provider-azurerm.ServicebusSubscriptionTimeouts",
    jsii_struct_bases=[],
    name_mapping={
        "create": "create",
        "delete": "delete",
        "read": "read",
        "update": "update",
    },
)
class ServicebusSubscriptionTimeouts:
    def __init__(
        self,
        *,
        create: typing.Optional[builtins.str] = None,
        delete: typing.Optional[builtins.str] = None,
        read: typing.Optional[builtins.str] = None,
        update: typing.Optional[builtins.str] = None,
    ) -> None:
        """
        :param create: 
        :param delete: 
        :param read: 
        :param update: 
        """
        self._values: typing.Dict[str, typing.Any] = {}
        if create is not None:
            self._values["create"] = create
        if delete is not None:
            self._values["delete"] = delete
        if read is not None:
            self._values["read"] = read
        if update is not None:
            self._values["update"] = update

    @builtins.property
    def create(self) -> typing.Optional[builtins.str]:
        result = self._values.get("create")
        return result

    @builtins.property
    def delete(self) -> typing.Optional[builtins.str]:
        result = self._values.get("delete")
        return result

    @builtins.property
    def read(self) -> typing.Optional[builtins.str]:
        result = self._values.get("read")
        return result

    @builtins.property
    def update(self) -> typing.Optional[builtins.str]:
        result = self._values.get("update")
        return result

    def __eq__(self, rhs: typing.Any) -> builtins.bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs: typing.Any) -> builtins.bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return "ServicebusSubscriptionTimeouts(%s)" % ", ".join(
            k + "=" + repr(v) for k, v in self._values.items()
        )


class ServicebusTopic(
    cdktf.TerraformResource,
    metaclass=jsii.JSIIMeta,
    jsii_type="@cdktf/provider-azurerm.ServicebusTopic",
):
    def __init__(
        self,
        scope: constructs.Construct,
        id: builtins.str,
        *,
        name: builtins.str,
        namespace_name: builtins.str,
        resource_group_name: builtins.str,
        auto_delete_on_idle: typing.Optional[builtins.str] = None,
        default_message_ttl: typing.Optional[builtins.str] = None,
        duplicate_detection_history_time_window: typing.Optional[builtins.str] = None,
        enable_batched_operations: typing.Optional[builtins.bool] = None,
        enable_express: typing.Optional[builtins.bool] = None,
        enable_partitioning: typing.Optional[builtins.bool] = None,
        max_size_in_megabytes: typing.Optional[jsii.Number] = None,
        requires_duplicate_detection: typing.Optional[builtins.bool] = None,
        status: typing.Optional[builtins.str] = None,
        support_ordering: typing.Optional[builtins.bool] = None,
        timeouts: typing.Optional["ServicebusTopicTimeouts"] = None,
        count: typing.Optional[jsii.Number] = None,
        depends_on: typing.Optional[typing.List[cdktf.TerraformResource]] = None,
        lifecycle: typing.Optional[cdktf.TerraformResourceLifecycle] = None,
        provider: typing.Optional[cdktf.TerraformProvider] = None,
    ) -> None:
        """
        :param scope: -
        :param id: -
        :param name: 
        :param namespace_name: 
        :param resource_group_name: 
        :param auto_delete_on_idle: 
        :param default_message_ttl: 
        :param duplicate_detection_history_time_window: 
        :param enable_batched_operations: 
        :param enable_express: 
        :param enable_partitioning: 
        :param max_size_in_megabytes: 
        :param requires_duplicate_detection: 
        :param status: 
        :param support_ordering: 
        :param timeouts: timeouts block.
        :param count: 
        :param depends_on: 
        :param lifecycle: 
        :param provider: 
        """
        config = ServicebusTopicConfig(
            name=name,
            namespace_name=namespace_name,
            resource_group_name=resource_group_name,
            auto_delete_on_idle=auto_delete_on_idle,
            default_message_ttl=default_message_ttl,
            duplicate_detection_history_time_window=duplicate_detection_history_time_window,
            enable_batched_operations=enable_batched_operations,
            enable_express=enable_express,
            enable_partitioning=enable_partitioning,
            max_size_in_megabytes=max_size_in_megabytes,
            requires_duplicate_detection=requires_duplicate_detection,
            status=status,
            support_ordering=support_ordering,
            timeouts=timeouts,
            count=count,
            depends_on=depends_on,
            lifecycle=lifecycle,
            provider=provider,
        )

        jsii.create(ServicebusTopic, self, [scope, id, config])

    @jsii.member(jsii_name="synthesizeAttributes")
    def _synthesize_attributes(self) -> typing.Mapping[builtins.str, typing.Any]:
        return jsii.invoke(self, "synthesizeAttributes", [])

    @builtins.property # type: ignore
    @jsii.member(jsii_name="name")
    def name(self) -> builtins.str:
        return jsii.get(self, "name")

    @name.setter # type: ignore
    def name(self, value: builtins.str) -> None:
        jsii.set(self, "name", value)

    @builtins.property # type: ignore
    @jsii.member(jsii_name="namespaceName")
    def namespace_name(self) -> builtins.str:
        return jsii.get(self, "namespaceName")

    @namespace_name.setter # type: ignore
    def namespace_name(self, value: builtins.str) -> None:
        jsii.set(self, "namespaceName", value)

    @builtins.property # type: ignore
    @jsii.member(jsii_name="resourceGroupName")
    def resource_group_name(self) -> builtins.str:
        return jsii.get(self, "resourceGroupName")

    @resource_group_name.setter # type: ignore
    def resource_group_name(self, value: builtins.str) -> None:
        jsii.set(self, "resourceGroupName", value)

    @builtins.property # type: ignore
    @jsii.member(jsii_name="autoDeleteOnIdle")
    def auto_delete_on_idle(self) -> typing.Optional[builtins.str]:
        return jsii.get(self, "autoDeleteOnIdle")

    @auto_delete_on_idle.setter # type: ignore
    def auto_delete_on_idle(self, value: typing.Optional[builtins.str]) -> None:
        jsii.set(self, "autoDeleteOnIdle", value)

    @builtins.property # type: ignore
    @jsii.member(jsii_name="defaultMessageTtl")
    def default_message_ttl(self) -> typing.Optional[builtins.str]:
        return jsii.get(self, "defaultMessageTtl")

    @default_message_ttl.setter # type: ignore
    def default_message_ttl(self, value: typing.Optional[builtins.str]) -> None:
        jsii.set(self, "defaultMessageTtl", value)

    @builtins.property # type: ignore
    @jsii.member(jsii_name="duplicateDetectionHistoryTimeWindow")
    def duplicate_detection_history_time_window(self) -> typing.Optional[builtins.str]:
        return jsii.get(self, "duplicateDetectionHistoryTimeWindow")

    @duplicate_detection_history_time_window.setter # type: ignore
    def duplicate_detection_history_time_window(
        self,
        value: typing.Optional[builtins.str],
    ) -> None:
        jsii.set(self, "duplicateDetectionHistoryTimeWindow", value)

    @builtins.property # type: ignore
    @jsii.member(jsii_name="enableBatchedOperations")
    def enable_batched_operations(self) -> typing.Optional[builtins.bool]:
        return jsii.get(self, "enableBatchedOperations")

    @enable_batched_operations.setter # type: ignore
    def enable_batched_operations(self, value: typing.Optional[builtins.bool]) -> None:
        jsii.set(self, "enableBatchedOperations", value)

    @builtins.property # type: ignore
    @jsii.member(jsii_name="enableExpress")
    def enable_express(self) -> typing.Optional[builtins.bool]:
        return jsii.get(self, "enableExpress")

    @enable_express.setter # type: ignore
    def enable_express(self, value: typing.Optional[builtins.bool]) -> None:
        jsii.set(self, "enableExpress", value)

    @builtins.property # type: ignore
    @jsii.member(jsii_name="enablePartitioning")
    def enable_partitioning(self) -> typing.Optional[builtins.bool]:
        return jsii.get(self, "enablePartitioning")

    @enable_partitioning.setter # type: ignore
    def enable_partitioning(self, value: typing.Optional[builtins.bool]) -> None:
        jsii.set(self, "enablePartitioning", value)

    @builtins.property # type: ignore
    @jsii.member(jsii_name="id")
    def id(self) -> typing.Optional[builtins.str]:
        return jsii.get(self, "id")

    @id.setter # type: ignore
    def id(self, value: typing.Optional[builtins.str]) -> None:
        jsii.set(self, "id", value)

    @builtins.property # type: ignore
    @jsii.member(jsii_name="maxSizeInMegabytes")
    def max_size_in_megabytes(self) -> typing.Optional[jsii.Number]:
        return jsii.get(self, "maxSizeInMegabytes")

    @max_size_in_megabytes.setter # type: ignore
    def max_size_in_megabytes(self, value: typing.Optional[jsii.Number]) -> None:
        jsii.set(self, "maxSizeInMegabytes", value)

    @builtins.property # type: ignore
    @jsii.member(jsii_name="requiresDuplicateDetection")
    def requires_duplicate_detection(self) -> typing.Optional[builtins.bool]:
        return jsii.get(self, "requiresDuplicateDetection")

    @requires_duplicate_detection.setter # type: ignore
    def requires_duplicate_detection(
        self,
        value: typing.Optional[builtins.bool],
    ) -> None:
        jsii.set(self, "requiresDuplicateDetection", value)

    @builtins.property # type: ignore
    @jsii.member(jsii_name="status")
    def status(self) -> typing.Optional[builtins.str]:
        return jsii.get(self, "status")

    @status.setter # type: ignore
    def status(self, value: typing.Optional[builtins.str]) -> None:
        jsii.set(self, "status", value)

    @builtins.property # type: ignore
    @jsii.member(jsii_name="supportOrdering")
    def support_ordering(self) -> typing.Optional[builtins.bool]:
        return jsii.get(self, "supportOrdering")

    @support_ordering.setter # type: ignore
    def support_ordering(self, value: typing.Optional[builtins.bool]) -> None:
        jsii.set(self, "supportOrdering", value)

    @builtins.property # type: ignore
    @jsii.member(jsii_name="timeouts")
    def timeouts(self) -> typing.Optional["ServicebusTopicTimeouts"]:
        return jsii.get(self, "timeouts")

    @timeouts.setter # type: ignore
    def timeouts(self, value: typing.Optional["ServicebusTopicTimeouts"]) -> None:
        jsii.set(self, "timeouts", value)


class ServicebusTopicAuthorizationRule(
    cdktf.TerraformResource,
    metaclass=jsii.JSIIMeta,
    jsii_type="@cdktf/provider-azurerm.ServicebusTopicAuthorizationRule",
):
    def __init__(
        self,
        scope: constructs.Construct,
        id: builtins.str,
        *,
        name: builtins.str,
        namespace_name: builtins.str,
        resource_group_name: builtins.str,
        topic_name: builtins.str,
        listen: typing.Optional[builtins.bool] = None,
        manage: typing.Optional[builtins.bool] = None,
        send: typing.Optional[builtins.bool] = None,
        timeouts: typing.Optional["ServicebusTopicAuthorizationRuleTimeouts"] = None,
        count: typing.Optional[jsii.Number] = None,
        depends_on: typing.Optional[typing.List[cdktf.TerraformResource]] = None,
        lifecycle: typing.Optional[cdktf.TerraformResourceLifecycle] = None,
        provider: typing.Optional[cdktf.TerraformProvider] = None,
    ) -> None:
        """
        :param scope: -
        :param id: -
        :param name: 
        :param namespace_name: 
        :param resource_group_name: 
        :param topic_name: 
        :param listen: 
        :param manage: 
        :param send: 
        :param timeouts: timeouts block.
        :param count: 
        :param depends_on: 
        :param lifecycle: 
        :param provider: 
        """
        config = ServicebusTopicAuthorizationRuleConfig(
            name=name,
            namespace_name=namespace_name,
            resource_group_name=resource_group_name,
            topic_name=topic_name,
            listen=listen,
            manage=manage,
            send=send,
            timeouts=timeouts,
            count=count,
            depends_on=depends_on,
            lifecycle=lifecycle,
            provider=provider,
        )

        jsii.create(ServicebusTopicAuthorizationRule, self, [scope, id, config])

    @jsii.member(jsii_name="synthesizeAttributes")
    def _synthesize_attributes(self) -> typing.Mapping[builtins.str, typing.Any]:
        return jsii.invoke(self, "synthesizeAttributes", [])

    @builtins.property # type: ignore
    @jsii.member(jsii_name="primaryConnectionString")
    def primary_connection_string(self) -> builtins.str:
        return jsii.get(self, "primaryConnectionString")

    @builtins.property # type: ignore
    @jsii.member(jsii_name="primaryKey")
    def primary_key(self) -> builtins.str:
        return jsii.get(self, "primaryKey")

    @builtins.property # type: ignore
    @jsii.member(jsii_name="secondaryConnectionString")
    def secondary_connection_string(self) -> builtins.str:
        return jsii.get(self, "secondaryConnectionString")

    @builtins.property # type: ignore
    @jsii.member(jsii_name="secondaryKey")
    def secondary_key(self) -> builtins.str:
        return jsii.get(self, "secondaryKey")

    @builtins.property # type: ignore
    @jsii.member(jsii_name="name")
    def name(self) -> builtins.str:
        return jsii.get(self, "name")

    @name.setter # type: ignore
    def name(self, value: builtins.str) -> None:
        jsii.set(self, "name", value)

    @builtins.property # type: ignore
    @jsii.member(jsii_name="namespaceName")
    def namespace_name(self) -> builtins.str:
        return jsii.get(self, "namespaceName")

    @namespace_name.setter # type: ignore
    def namespace_name(self, value: builtins.str) -> None:
        jsii.set(self, "namespaceName", value)

    @builtins.property # type: ignore
    @jsii.member(jsii_name="resourceGroupName")
    def resource_group_name(self) -> builtins.str:
        return jsii.get(self, "resourceGroupName")

    @resource_group_name.setter # type: ignore
    def resource_group_name(self, value: builtins.str) -> None:
        jsii.set(self, "resourceGroupName", value)

    @builtins.property # type: ignore
    @jsii.member(jsii_name="topicName")
    def topic_name(self) -> builtins.str:
        return jsii.get(self, "topicName")

    @topic_name.setter # type: ignore
    def topic_name(self, value: builtins.str) -> None:
        jsii.set(self, "topicName", value)

    @builtins.property # type: ignore
    @jsii.member(jsii_name="id")
    def id(self) -> typing.Optional[builtins.str]:
        return jsii.get(self, "id")

    @id.setter # type: ignore
    def id(self, value: typing.Optional[builtins.str]) -> None:
        jsii.set(self, "id", value)

    @builtins.property # type: ignore
    @jsii.member(jsii_name="listen")
    def listen(self) -> typing.Optional[builtins.bool]:
        return jsii.get(self, "listen")

    @listen.setter # type: ignore
    def listen(self, value: typing.Optional[builtins.bool]) -> None:
        jsii.set(self, "listen", value)

    @builtins.property # type: ignore
    @jsii.member(jsii_name="manage")
    def manage(self) -> typing.Optional[builtins.bool]:
        return jsii.get(self, "manage")

    @manage.setter # type: ignore
    def manage(self, value: typing.Optional[builtins.bool]) -> None:
        jsii.set(self, "manage", value)

    @builtins.property # type: ignore
    @jsii.member(jsii_name="send")
    def send(self) -> typing.Optional[builtins.bool]:
        return jsii.get(self, "send")

    @send.setter # type: ignore
    def send(self, value: typing.Optional[builtins.bool]) -> None:
        jsii.set(self, "send", value)

    @builtins.property # type: ignore
    @jsii.member(jsii_name="timeouts")
    def timeouts(self) -> typing.Optional["ServicebusTopicAuthorizationRuleTimeouts"]:
        return jsii.get(self, "timeouts")

    @timeouts.setter # type: ignore
    def timeouts(
        self,
        value: typing.Optional["ServicebusTopicAuthorizationRuleTimeouts"],
    ) -> None:
        jsii.set(self, "timeouts", value)


@jsii.data_type(
    jsii_type="@cdktf/provider-azurerm.ServicebusTopicAuthorizationRuleConfig",
    jsii_struct_bases=[cdktf.TerraformMetaArguments],
    name_mapping={
        "count": "count",
        "depends_on": "dependsOn",
        "lifecycle": "lifecycle",
        "provider": "provider",
        "name": "name",
        "namespace_name": "namespaceName",
        "resource_group_name": "resourceGroupName",
        "topic_name": "topicName",
        "listen": "listen",
        "manage": "manage",
        "send": "send",
        "timeouts": "timeouts",
    },
)
class ServicebusTopicAuthorizationRuleConfig(cdktf.TerraformMetaArguments):
    def __init__(
        self,
        *,
        count: typing.Optional[jsii.Number] = None,
        depends_on: typing.Optional[typing.List[cdktf.TerraformResource]] = None,
        lifecycle: typing.Optional[cdktf.TerraformResourceLifecycle] = None,
        provider: typing.Optional[cdktf.TerraformProvider] = None,
        name: builtins.str,
        namespace_name: builtins.str,
        resource_group_name: builtins.str,
        topic_name: builtins.str,
        listen: typing.Optional[builtins.bool] = None,
        manage: typing.Optional[builtins.bool] = None,
        send: typing.Optional[builtins.bool] = None,
        timeouts: typing.Optional["ServicebusTopicAuthorizationRuleTimeouts"] = None,
    ) -> None:
        """
        :param count: 
        :param depends_on: 
        :param lifecycle: 
        :param provider: 
        :param name: 
        :param namespace_name: 
        :param resource_group_name: 
        :param topic_name: 
        :param listen: 
        :param manage: 
        :param send: 
        :param timeouts: timeouts block.
        """
        if isinstance(lifecycle, dict):
            lifecycle = cdktf.TerraformResourceLifecycle(**lifecycle)
        if isinstance(timeouts, dict):
            timeouts = ServicebusTopicAuthorizationRuleTimeouts(**timeouts)
        self._values: typing.Dict[str, typing.Any] = {
            "name": name,
            "namespace_name": namespace_name,
            "resource_group_name": resource_group_name,
            "topic_name": topic_name,
        }
        if count is not None:
            self._values["count"] = count
        if depends_on is not None:
            self._values["depends_on"] = depends_on
        if lifecycle is not None:
            self._values["lifecycle"] = lifecycle
        if provider is not None:
            self._values["provider"] = provider
        if listen is not None:
            self._values["listen"] = listen
        if manage is not None:
            self._values["manage"] = manage
        if send is not None:
            self._values["send"] = send
        if timeouts is not None:
            self._values["timeouts"] = timeouts

    @builtins.property
    def count(self) -> typing.Optional[jsii.Number]:
        """
        :stability: experimental
        """
        result = self._values.get("count")
        return result

    @builtins.property
    def depends_on(self) -> typing.Optional[typing.List[cdktf.TerraformResource]]:
        """
        :stability: experimental
        """
        result = self._values.get("depends_on")
        return result

    @builtins.property
    def lifecycle(self) -> typing.Optional[cdktf.TerraformResourceLifecycle]:
        """
        :stability: experimental
        """
        result = self._values.get("lifecycle")
        return result

    @builtins.property
    def provider(self) -> typing.Optional[cdktf.TerraformProvider]:
        """
        :stability: experimental
        """
        result = self._values.get("provider")
        return result

    @builtins.property
    def name(self) -> builtins.str:
        result = self._values.get("name")
        assert result is not None, "Required property 'name' is missing"
        return result

    @builtins.property
    def namespace_name(self) -> builtins.str:
        result = self._values.get("namespace_name")
        assert result is not None, "Required property 'namespace_name' is missing"
        return result

    @builtins.property
    def resource_group_name(self) -> builtins.str:
        result = self._values.get("resource_group_name")
        assert result is not None, "Required property 'resource_group_name' is missing"
        return result

    @builtins.property
    def topic_name(self) -> builtins.str:
        result = self._values.get("topic_name")
        assert result is not None, "Required property 'topic_name' is missing"
        return result

    @builtins.property
    def listen(self) -> typing.Optional[builtins.bool]:
        result = self._values.get("listen")
        return result

    @builtins.property
    def manage(self) -> typing.Optional[builtins.bool]:
        result = self._values.get("manage")
        return result

    @builtins.property
    def send(self) -> typing.Optional[builtins.bool]:
        result = self._values.get("send")
        return result

    @builtins.property
    def timeouts(self) -> typing.Optional["ServicebusTopicAuthorizationRuleTimeouts"]:
        """timeouts block."""
        result = self._values.get("timeouts")
        return result

    def __eq__(self, rhs: typing.Any) -> builtins.bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs: typing.Any) -> builtins.bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return "ServicebusTopicAuthorizationRuleConfig(%s)" % ", ".join(
            k + "=" + repr(v) for k, v in self._values.items()
        )


@jsii.data_type(
    jsii_type="@cdktf/provider-azurerm.ServicebusTopicAuthorizationRuleTimeouts",
    jsii_struct_bases=[],
    name_mapping={
        "create": "create",
        "delete": "delete",
        "read": "read",
        "update": "update",
    },
)
class ServicebusTopicAuthorizationRuleTimeouts:
    def __init__(
        self,
        *,
        create: typing.Optional[builtins.str] = None,
        delete: typing.Optional[builtins.str] = None,
        read: typing.Optional[builtins.str] = None,
        update: typing.Optional[builtins.str] = None,
    ) -> None:
        """
        :param create: 
        :param delete: 
        :param read: 
        :param update: 
        """
        self._values: typing.Dict[str, typing.Any] = {}
        if create is not None:
            self._values["create"] = create
        if delete is not None:
            self._values["delete"] = delete
        if read is not None:
            self._values["read"] = read
        if update is not None:
            self._values["update"] = update

    @builtins.property
    def create(self) -> typing.Optional[builtins.str]:
        result = self._values.get("create")
        return result

    @builtins.property
    def delete(self) -> typing.Optional[builtins.str]:
        result = self._values.get("delete")
        return result

    @builtins.property
    def read(self) -> typing.Optional[builtins.str]:
        result = self._values.get("read")
        return result

    @builtins.property
    def update(self) -> typing.Optional[builtins.str]:
        result = self._values.get("update")
        return result

    def __eq__(self, rhs: typing.Any) -> builtins.bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs: typing.Any) -> builtins.bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return "ServicebusTopicAuthorizationRuleTimeouts(%s)" % ", ".join(
            k + "=" + repr(v) for k, v in self._values.items()
        )


@jsii.data_type(
    jsii_type="@cdktf/provider-azurerm.ServicebusTopicConfig",
    jsii_struct_bases=[cdktf.TerraformMetaArguments],
    name_mapping={
        "count": "count",
        "depends_on": "dependsOn",
        "lifecycle": "lifecycle",
        "provider": "provider",
        "name": "name",
        "namespace_name": "namespaceName",
        "resource_group_name": "resourceGroupName",
        "auto_delete_on_idle": "autoDeleteOnIdle",
        "default_message_ttl": "defaultMessageTtl",
        "duplicate_detection_history_time_window": "duplicateDetectionHistoryTimeWindow",
        "enable_batched_operations": "enableBatchedOperations",
        "enable_express": "enableExpress",
        "enable_partitioning": "enablePartitioning",
        "max_size_in_megabytes": "maxSizeInMegabytes",
        "requires_duplicate_detection": "requiresDuplicateDetection",
        "status": "status",
        "support_ordering": "supportOrdering",
        "timeouts": "timeouts",
    },
)
class ServicebusTopicConfig(cdktf.TerraformMetaArguments):
    def __init__(
        self,
        *,
        count: typing.Optional[jsii.Number] = None,
        depends_on: typing.Optional[typing.List[cdktf.TerraformResource]] = None,
        lifecycle: typing.Optional[cdktf.TerraformResourceLifecycle] = None,
        provider: typing.Optional[cdktf.TerraformProvider] = None,
        name: builtins.str,
        namespace_name: builtins.str,
        resource_group_name: builtins.str,
        auto_delete_on_idle: typing.Optional[builtins.str] = None,
        default_message_ttl: typing.Optional[builtins.str] = None,
        duplicate_detection_history_time_window: typing.Optional[builtins.str] = None,
        enable_batched_operations: typing.Optional[builtins.bool] = None,
        enable_express: typing.Optional[builtins.bool] = None,
        enable_partitioning: typing.Optional[builtins.bool] = None,
        max_size_in_megabytes: typing.Optional[jsii.Number] = None,
        requires_duplicate_detection: typing.Optional[builtins.bool] = None,
        status: typing.Optional[builtins.str] = None,
        support_ordering: typing.Optional[builtins.bool] = None,
        timeouts: typing.Optional["ServicebusTopicTimeouts"] = None,
    ) -> None:
        """
        :param count: 
        :param depends_on: 
        :param lifecycle: 
        :param provider: 
        :param name: 
        :param namespace_name: 
        :param resource_group_name: 
        :param auto_delete_on_idle: 
        :param default_message_ttl: 
        :param duplicate_detection_history_time_window: 
        :param enable_batched_operations: 
        :param enable_express: 
        :param enable_partitioning: 
        :param max_size_in_megabytes: 
        :param requires_duplicate_detection: 
        :param status: 
        :param support_ordering: 
        :param timeouts: timeouts block.
        """
        if isinstance(lifecycle, dict):
            lifecycle = cdktf.TerraformResourceLifecycle(**lifecycle)
        if isinstance(timeouts, dict):
            timeouts = ServicebusTopicTimeouts(**timeouts)
        self._values: typing.Dict[str, typing.Any] = {
            "name": name,
            "namespace_name": namespace_name,
            "resource_group_name": resource_group_name,
        }
        if count is not None:
            self._values["count"] = count
        if depends_on is not None:
            self._values["depends_on"] = depends_on
        if lifecycle is not None:
            self._values["lifecycle"] = lifecycle
        if provider is not None:
            self._values["provider"] = provider
        if auto_delete_on_idle is not None:
            self._values["auto_delete_on_idle"] = auto_delete_on_idle
        if default_message_ttl is not None:
            self._values["default_message_ttl"] = default_message_ttl
        if duplicate_detection_history_time_window is not None:
            self._values["duplicate_detection_history_time_window"] = duplicate_detection_history_time_window
        if enable_batched_operations is not None:
            self._values["enable_batched_operations"] = enable_batched_operations
        if enable_express is not None:
            self._values["enable_express"] = enable_express
        if enable_partitioning is not None:
            self._values["enable_partitioning"] = enable_partitioning
        if max_size_in_megabytes is not None:
            self._values["max_size_in_megabytes"] = max_size_in_megabytes
        if requires_duplicate_detection is not None:
            self._values["requires_duplicate_detection"] = requires_duplicate_detection
        if status is not None:
            self._values["status"] = status
        if support_ordering is not None:
            self._values["support_ordering"] = support_ordering
        if timeouts is not None:
            self._values["timeouts"] = timeouts

    @builtins.property
    def count(self) -> typing.Optional[jsii.Number]:
        """
        :stability: experimental
        """
        result = self._values.get("count")
        return result

    @builtins.property
    def depends_on(self) -> typing.Optional[typing.List[cdktf.TerraformResource]]:
        """
        :stability: experimental
        """
        result = self._values.get("depends_on")
        return result

    @builtins.property
    def lifecycle(self) -> typing.Optional[cdktf.TerraformResourceLifecycle]:
        """
        :stability: experimental
        """
        result = self._values.get("lifecycle")
        return result

    @builtins.property
    def provider(self) -> typing.Optional[cdktf.TerraformProvider]:
        """
        :stability: experimental
        """
        result = self._values.get("provider")
        return result

    @builtins.property
    def name(self) -> builtins.str:
        result = self._values.get("name")
        assert result is not None, "Required property 'name' is missing"
        return result

    @builtins.property
    def namespace_name(self) -> builtins.str:
        result = self._values.get("namespace_name")
        assert result is not None, "Required property 'namespace_name' is missing"
        return result

    @builtins.property
    def resource_group_name(self) -> builtins.str:
        result = self._values.get("resource_group_name")
        assert result is not None, "Required property 'resource_group_name' is missing"
        return result

    @builtins.property
    def auto_delete_on_idle(self) -> typing.Optional[builtins.str]:
        result = self._values.get("auto_delete_on_idle")
        return result

    @builtins.property
    def default_message_ttl(self) -> typing.Optional[builtins.str]:
        result = self._values.get("default_message_ttl")
        return result

    @builtins.property
    def duplicate_detection_history_time_window(self) -> typing.Optional[builtins.str]:
        result = self._values.get("duplicate_detection_history_time_window")
        return result

    @builtins.property
    def enable_batched_operations(self) -> typing.Optional[builtins.bool]:
        result = self._values.get("enable_batched_operations")
        return result

    @builtins.property
    def enable_express(self) -> typing.Optional[builtins.bool]:
        result = self._values.get("enable_express")
        return result

    @builtins.property
    def enable_partitioning(self) -> typing.Optional[builtins.bool]:
        result = self._values.get("enable_partitioning")
        return result

    @builtins.property
    def max_size_in_megabytes(self) -> typing.Optional[jsii.Number]:
        result = self._values.get("max_size_in_megabytes")
        return result

    @builtins.property
    def requires_duplicate_detection(self) -> typing.Optional[builtins.bool]:
        result = self._values.get("requires_duplicate_detection")
        return result

    @builtins.property
    def status(self) -> typing.Optional[builtins.str]:
        result = self._values.get("status")
        return result

    @builtins.property
    def support_ordering(self) -> typing.Optional[builtins.bool]:
        result = self._values.get("support_ordering")
        return result

    @builtins.property
    def timeouts(self) -> typing.Optional["ServicebusTopicTimeouts"]:
        """timeouts block."""
        result = self._values.get("timeouts")
        return result

    def __eq__(self, rhs: typing.Any) -> builtins.bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs: typing.Any) -> builtins.bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return "ServicebusTopicConfig(%s)" % ", ".join(
            k + "=" + repr(v) for k, v in self._values.items()
        )


@jsii.data_type(
    jsii_type="@cdktf/provider-azurerm.ServicebusTopicTimeouts",
    jsii_struct_bases=[],
    name_mapping={
        "create": "create",
        "delete": "delete",
        "read": "read",
        "update": "update",
    },
)
class ServicebusTopicTimeouts:
    def __init__(
        self,
        *,
        create: typing.Optional[builtins.str] = None,
        delete: typing.Optional[builtins.str] = None,
        read: typing.Optional[builtins.str] = None,
        update: typing.Optional[builtins.str] = None,
    ) -> None:
        """
        :param create: 
        :param delete: 
        :param read: 
        :param update: 
        """
        self._values: typing.Dict[str, typing.Any] = {}
        if create is not None:
            self._values["create"] = create
        if delete is not None:
            self._values["delete"] = delete
        if read is not None:
            self._values["read"] = read
        if update is not None:
            self._values["update"] = update

    @builtins.property
    def create(self) -> typing.Optional[builtins.str]:
        result = self._values.get("create")
        return result

    @builtins.property
    def delete(self) -> typing.Optional[builtins.str]:
        result = self._values.get("delete")
        return result

    @builtins.property
    def read(self) -> typing.Optional[builtins.str]:
        result = self._values.get("read")
        return result

    @builtins.property
    def update(self) -> typing.Optional[builtins.str]:
        result = self._values.get("update")
        return result

    def __eq__(self, rhs: typing.Any) -> builtins.bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs: typing.Any) -> builtins.bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return "ServicebusTopicTimeouts(%s)" % ", ".join(
            k + "=" + repr(v) for k, v in self._values.items()
        )


class SharedImage(
    cdktf.TerraformResource,
    metaclass=jsii.JSIIMeta,
    jsii_type="@cdktf/provider-azurerm.SharedImage",
):
    def __init__(
        self,
        scope: constructs.Construct,
        id: builtins.str,
        *,
        gallery_name: builtins.str,
        identifier: typing.List["SharedImageIdentifier"],
        location: builtins.str,
        name: builtins.str,
        os_type: builtins.str,
        resource_group_name: builtins.str,
        description: typing.Optional[builtins.str] = None,
        eula: typing.Optional[builtins.str] = None,
        privacy_statement_uri: typing.Optional[builtins.str] = None,
        release_note_uri: typing.Optional[builtins.str] = None,
        tags: typing.Optional[typing.Mapping[builtins.str, builtins.str]] = None,
        timeouts: typing.Optional["SharedImageTimeouts"] = None,
        count: typing.Optional[jsii.Number] = None,
        depends_on: typing.Optional[typing.List[cdktf.TerraformResource]] = None,
        lifecycle: typing.Optional[cdktf.TerraformResourceLifecycle] = None,
        provider: typing.Optional[cdktf.TerraformProvider] = None,
    ) -> None:
        """
        :param scope: -
        :param id: -
        :param gallery_name: 
        :param identifier: identifier block.
        :param location: 
        :param name: 
        :param os_type: 
        :param resource_group_name: 
        :param description: 
        :param eula: 
        :param privacy_statement_uri: 
        :param release_note_uri: 
        :param tags: 
        :param timeouts: timeouts block.
        :param count: 
        :param depends_on: 
        :param lifecycle: 
        :param provider: 
        """
        config = SharedImageConfig(
            gallery_name=gallery_name,
            identifier=identifier,
            location=location,
            name=name,
            os_type=os_type,
            resource_group_name=resource_group_name,
            description=description,
            eula=eula,
            privacy_statement_uri=privacy_statement_uri,
            release_note_uri=release_note_uri,
            tags=tags,
            timeouts=timeouts,
            count=count,
            depends_on=depends_on,
            lifecycle=lifecycle,
            provider=provider,
        )

        jsii.create(SharedImage, self, [scope, id, config])

    @jsii.member(jsii_name="synthesizeAttributes")
    def _synthesize_attributes(self) -> typing.Mapping[builtins.str, typing.Any]:
        return jsii.invoke(self, "synthesizeAttributes", [])

    @builtins.property # type: ignore
    @jsii.member(jsii_name="galleryName")
    def gallery_name(self) -> builtins.str:
        return jsii.get(self, "galleryName")

    @gallery_name.setter # type: ignore
    def gallery_name(self, value: builtins.str) -> None:
        jsii.set(self, "galleryName", value)

    @builtins.property # type: ignore
    @jsii.member(jsii_name="identifier")
    def identifier(self) -> typing.List["SharedImageIdentifier"]:
        return jsii.get(self, "identifier")

    @identifier.setter # type: ignore
    def identifier(self, value: typing.List["SharedImageIdentifier"]) -> None:
        jsii.set(self, "identifier", value)

    @builtins.property # type: ignore
    @jsii.member(jsii_name="location")
    def location(self) -> builtins.str:
        return jsii.get(self, "location")

    @location.setter # type: ignore
    def location(self, value: builtins.str) -> None:
        jsii.set(self, "location", value)

    @builtins.property # type: ignore
    @jsii.member(jsii_name="name")
    def name(self) -> builtins.str:
        return jsii.get(self, "name")

    @name.setter # type: ignore
    def name(self, value: builtins.str) -> None:
        jsii.set(self, "name", value)

    @builtins.property # type: ignore
    @jsii.member(jsii_name="osType")
    def os_type(self) -> builtins.str:
        return jsii.get(self, "osType")

    @os_type.setter # type: ignore
    def os_type(self, value: builtins.str) -> None:
        jsii.set(self, "osType", value)

    @builtins.property # type: ignore
    @jsii.member(jsii_name="resourceGroupName")
    def resource_group_name(self) -> builtins.str:
        return jsii.get(self, "resourceGroupName")

    @resource_group_name.setter # type: ignore
    def resource_group_name(self, value: builtins.str) -> None:
        jsii.set(self, "resourceGroupName", value)

    @builtins.property # type: ignore
    @jsii.member(jsii_name="description")
    def description(self) -> typing.Optional[builtins.str]:
        return jsii.get(self, "description")

    @description.setter # type: ignore
    def description(self, value: typing.Optional[builtins.str]) -> None:
        jsii.set(self, "description", value)

    @builtins.property # type: ignore
    @jsii.member(jsii_name="eula")
    def eula(self) -> typing.Optional[builtins.str]:
        return jsii.get(self, "eula")

    @eula.setter # type: ignore
    def eula(self, value: typing.Optional[builtins.str]) -> None:
        jsii.set(self, "eula", value)

    @builtins.property # type: ignore
    @jsii.member(jsii_name="id")
    def id(self) -> typing.Optional[builtins.str]:
        return jsii.get(self, "id")

    @id.setter # type: ignore
    def id(self, value: typing.Optional[builtins.str]) -> None:
        jsii.set(self, "id", value)

    @builtins.property # type: ignore
    @jsii.member(jsii_name="privacyStatementUri")
    def privacy_statement_uri(self) -> typing.Optional[builtins.str]:
        return jsii.get(self, "privacyStatementUri")

    @privacy_statement_uri.setter # type: ignore
    def privacy_statement_uri(self, value: typing.Optional[builtins.str]) -> None:
        jsii.set(self, "privacyStatementUri", value)

    @builtins.property # type: ignore
    @jsii.member(jsii_name="releaseNoteUri")
    def release_note_uri(self) -> typing.Optional[builtins.str]:
        return jsii.get(self, "releaseNoteUri")

    @release_note_uri.setter # type: ignore
    def release_note_uri(self, value: typing.Optional[builtins.str]) -> None:
        jsii.set(self, "releaseNoteUri", value)

    @builtins.property # type: ignore
    @jsii.member(jsii_name="tags")
    def tags(self) -> typing.Optional[typing.Mapping[builtins.str, builtins.str]]:
        return jsii.get(self, "tags")

    @tags.setter # type: ignore
    def tags(
        self,
        value: typing.Optional[typing.Mapping[builtins.str, builtins.str]],
    ) -> None:
        jsii.set(self, "tags", value)

    @builtins.property # type: ignore
    @jsii.member(jsii_name="timeouts")
    def timeouts(self) -> typing.Optional["SharedImageTimeouts"]:
        return jsii.get(self, "timeouts")

    @timeouts.setter # type: ignore
    def timeouts(self, value: typing.Optional["SharedImageTimeouts"]) -> None:
        jsii.set(self, "timeouts", value)


@jsii.data_type(
    jsii_type="@cdktf/provider-azurerm.SharedImageConfig",
    jsii_struct_bases=[cdktf.TerraformMetaArguments],
    name_mapping={
        "count": "count",
        "depends_on": "dependsOn",
        "lifecycle": "lifecycle",
        "provider": "provider",
        "gallery_name": "galleryName",
        "identifier": "identifier",
        "location": "location",
        "name": "name",
        "os_type": "osType",
        "resource_group_name": "resourceGroupName",
        "description": "description",
        "eula": "eula",
        "privacy_statement_uri": "privacyStatementUri",
        "release_note_uri": "releaseNoteUri",
        "tags": "tags",
        "timeouts": "timeouts",
    },
)
class SharedImageConfig(cdktf.TerraformMetaArguments):
    def __init__(
        self,
        *,
        count: typing.Optional[jsii.Number] = None,
        depends_on: typing.Optional[typing.List[cdktf.TerraformResource]] = None,
        lifecycle: typing.Optional[cdktf.TerraformResourceLifecycle] = None,
        provider: typing.Optional[cdktf.TerraformProvider] = None,
        gallery_name: builtins.str,
        identifier: typing.List["SharedImageIdentifier"],
        location: builtins.str,
        name: builtins.str,
        os_type: builtins.str,
        resource_group_name: builtins.str,
        description: typing.Optional[builtins.str] = None,
        eula: typing.Optional[builtins.str] = None,
        privacy_statement_uri: typing.Optional[builtins.str] = None,
        release_note_uri: typing.Optional[builtins.str] = None,
        tags: typing.Optional[typing.Mapping[builtins.str, builtins.str]] = None,
        timeouts: typing.Optional["SharedImageTimeouts"] = None,
    ) -> None:
        """
        :param count: 
        :param depends_on: 
        :param lifecycle: 
        :param provider: 
        :param gallery_name: 
        :param identifier: identifier block.
        :param location: 
        :param name: 
        :param os_type: 
        :param resource_group_name: 
        :param description: 
        :param eula: 
        :param privacy_statement_uri: 
        :param release_note_uri: 
        :param tags: 
        :param timeouts: timeouts block.
        """
        if isinstance(lifecycle, dict):
            lifecycle = cdktf.TerraformResourceLifecycle(**lifecycle)
        if isinstance(timeouts, dict):
            timeouts = SharedImageTimeouts(**timeouts)
        self._values: typing.Dict[str, typing.Any] = {
            "gallery_name": gallery_name,
            "identifier": identifier,
            "location": location,
            "name": name,
            "os_type": os_type,
            "resource_group_name": resource_group_name,
        }
        if count is not None:
            self._values["count"] = count
        if depends_on is not None:
            self._values["depends_on"] = depends_on
        if lifecycle is not None:
            self._values["lifecycle"] = lifecycle
        if provider is not None:
            self._values["provider"] = provider
        if description is not None:
            self._values["description"] = description
        if eula is not None:
            self._values["eula"] = eula
        if privacy_statement_uri is not None:
            self._values["privacy_statement_uri"] = privacy_statement_uri
        if release_note_uri is not None:
            self._values["release_note_uri"] = release_note_uri
        if tags is not None:
            self._values["tags"] = tags
        if timeouts is not None:
            self._values["timeouts"] = timeouts

    @builtins.property
    def count(self) -> typing.Optional[jsii.Number]:
        """
        :stability: experimental
        """
        result = self._values.get("count")
        return result

    @builtins.property
    def depends_on(self) -> typing.Optional[typing.List[cdktf.TerraformResource]]:
        """
        :stability: experimental
        """
        result = self._values.get("depends_on")
        return result

    @builtins.property
    def lifecycle(self) -> typing.Optional[cdktf.TerraformResourceLifecycle]:
        """
        :stability: experimental
        """
        result = self._values.get("lifecycle")
        return result

    @builtins.property
    def provider(self) -> typing.Optional[cdktf.TerraformProvider]:
        """
        :stability: experimental
        """
        result = self._values.get("provider")
        return result

    @builtins.property
    def gallery_name(self) -> builtins.str:
        result = self._values.get("gallery_name")
        assert result is not None, "Required property 'gallery_name' is missing"
        return result

    @builtins.property
    def identifier(self) -> typing.List["SharedImageIdentifier"]:
        """identifier block."""
        result = self._values.get("identifier")
        assert result is not None, "Required property 'identifier' is missing"
        return result

    @builtins.property
    def location(self) -> builtins.str:
        result = self._values.get("location")
        assert result is not None, "Required property 'location' is missing"
        return result

    @builtins.property
    def name(self) -> builtins.str:
        result = self._values.get("name")
        assert result is not None, "Required property 'name' is missing"
        return result

    @builtins.property
    def os_type(self) -> builtins.str:
        result = self._values.get("os_type")
        assert result is not None, "Required property 'os_type' is missing"
        return result

    @builtins.property
    def resource_group_name(self) -> builtins.str:
        result = self._values.get("resource_group_name")
        assert result is not None, "Required property 'resource_group_name' is missing"
        return result

    @builtins.property
    def description(self) -> typing.Optional[builtins.str]:
        result = self._values.get("description")
        return result

    @builtins.property
    def eula(self) -> typing.Optional[builtins.str]:
        result = self._values.get("eula")
        return result

    @builtins.property
    def privacy_statement_uri(self) -> typing.Optional[builtins.str]:
        result = self._values.get("privacy_statement_uri")
        return result

    @builtins.property
    def release_note_uri(self) -> typing.Optional[builtins.str]:
        result = self._values.get("release_note_uri")
        return result

    @builtins.property
    def tags(self) -> typing.Optional[typing.Mapping[builtins.str, builtins.str]]:
        result = self._values.get("tags")
        return result

    @builtins.property
    def timeouts(self) -> typing.Optional["SharedImageTimeouts"]:
        """timeouts block."""
        result = self._values.get("timeouts")
        return result

    def __eq__(self, rhs: typing.Any) -> builtins.bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs: typing.Any) -> builtins.bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return "SharedImageConfig(%s)" % ", ".join(
            k + "=" + repr(v) for k, v in self._values.items()
        )


class SharedImageGallery(
    cdktf.TerraformResource,
    metaclass=jsii.JSIIMeta,
    jsii_type="@cdktf/provider-azurerm.SharedImageGallery",
):
    def __init__(
        self,
        scope: constructs.Construct,
        id: builtins.str,
        *,
        location: builtins.str,
        name: builtins.str,
        resource_group_name: builtins.str,
        description: typing.Optional[builtins.str] = None,
        tags: typing.Optional[typing.Mapping[builtins.str, builtins.str]] = None,
        timeouts: typing.Optional["SharedImageGalleryTimeouts"] = None,
        count: typing.Optional[jsii.Number] = None,
        depends_on: typing.Optional[typing.List[cdktf.TerraformResource]] = None,
        lifecycle: typing.Optional[cdktf.TerraformResourceLifecycle] = None,
        provider: typing.Optional[cdktf.TerraformProvider] = None,
    ) -> None:
        """
        :param scope: -
        :param id: -
        :param location: 
        :param name: 
        :param resource_group_name: 
        :param description: 
        :param tags: 
        :param timeouts: timeouts block.
        :param count: 
        :param depends_on: 
        :param lifecycle: 
        :param provider: 
        """
        config = SharedImageGalleryConfig(
            location=location,
            name=name,
            resource_group_name=resource_group_name,
            description=description,
            tags=tags,
            timeouts=timeouts,
            count=count,
            depends_on=depends_on,
            lifecycle=lifecycle,
            provider=provider,
        )

        jsii.create(SharedImageGallery, self, [scope, id, config])

    @jsii.member(jsii_name="synthesizeAttributes")
    def _synthesize_attributes(self) -> typing.Mapping[builtins.str, typing.Any]:
        return jsii.invoke(self, "synthesizeAttributes", [])

    @builtins.property # type: ignore
    @jsii.member(jsii_name="uniqueName")
    def unique_name(self) -> builtins.str:
        return jsii.get(self, "uniqueName")

    @builtins.property # type: ignore
    @jsii.member(jsii_name="location")
    def location(self) -> builtins.str:
        return jsii.get(self, "location")

    @location.setter # type: ignore
    def location(self, value: builtins.str) -> None:
        jsii.set(self, "location", value)

    @builtins.property # type: ignore
    @jsii.member(jsii_name="name")
    def name(self) -> builtins.str:
        return jsii.get(self, "name")

    @name.setter # type: ignore
    def name(self, value: builtins.str) -> None:
        jsii.set(self, "name", value)

    @builtins.property # type: ignore
    @jsii.member(jsii_name="resourceGroupName")
    def resource_group_name(self) -> builtins.str:
        return jsii.get(self, "resourceGroupName")

    @resource_group_name.setter # type: ignore
    def resource_group_name(self, value: builtins.str) -> None:
        jsii.set(self, "resourceGroupName", value)

    @builtins.property # type: ignore
    @jsii.member(jsii_name="description")
    def description(self) -> typing.Optional[builtins.str]:
        return jsii.get(self, "description")

    @description.setter # type: ignore
    def description(self, value: typing.Optional[builtins.str]) -> None:
        jsii.set(self, "description", value)

    @builtins.property # type: ignore
    @jsii.member(jsii_name="id")
    def id(self) -> typing.Optional[builtins.str]:
        return jsii.get(self, "id")

    @id.setter # type: ignore
    def id(self, value: typing.Optional[builtins.str]) -> None:
        jsii.set(self, "id", value)

    @builtins.property # type: ignore
    @jsii.member(jsii_name="tags")
    def tags(self) -> typing.Optional[typing.Mapping[builtins.str, builtins.str]]:
        return jsii.get(self, "tags")

    @tags.setter # type: ignore
    def tags(
        self,
        value: typing.Optional[typing.Mapping[builtins.str, builtins.str]],
    ) -> None:
        jsii.set(self, "tags", value)

    @builtins.property # type: ignore
    @jsii.member(jsii_name="timeouts")
    def timeouts(self) -> typing.Optional["SharedImageGalleryTimeouts"]:
        return jsii.get(self, "timeouts")

    @timeouts.setter # type: ignore
    def timeouts(self, value: typing.Optional["SharedImageGalleryTimeouts"]) -> None:
        jsii.set(self, "timeouts", value)


@jsii.data_type(
    jsii_type="@cdktf/provider-azurerm.SharedImageGalleryConfig",
    jsii_struct_bases=[cdktf.TerraformMetaArguments],
    name_mapping={
        "count": "count",
        "depends_on": "dependsOn",
        "lifecycle": "lifecycle",
        "provider": "provider",
        "location": "location",
        "name": "name",
        "resource_group_name": "resourceGroupName",
        "description": "description",
        "tags": "tags",
        "timeouts": "timeouts",
    },
)
class SharedImageGalleryConfig(cdktf.TerraformMetaArguments):
    def __init__(
        self,
        *,
        count: typing.Optional[jsii.Number] = None,
        depends_on: typing.Optional[typing.List[cdktf.TerraformResource]] = None,
        lifecycle: typing.Optional[cdktf.TerraformResourceLifecycle] = None,
        provider: typing.Optional[cdktf.TerraformProvider] = None,
        location: builtins.str,
        name: builtins.str,
        resource_group_name: builtins.str,
        description: typing.Optional[builtins.str] = None,
        tags: typing.Optional[typing.Mapping[builtins.str, builtins.str]] = None,
        timeouts: typing.Optional["SharedImageGalleryTimeouts"] = None,
    ) -> None:
        """
        :param count: 
        :param depends_on: 
        :param lifecycle: 
        :param provider: 
        :param location: 
        :param name: 
        :param resource_group_name: 
        :param description: 
        :param tags: 
        :param timeouts: timeouts block.
        """
        if isinstance(lifecycle, dict):
            lifecycle = cdktf.TerraformResourceLifecycle(**lifecycle)
        if isinstance(timeouts, dict):
            timeouts = SharedImageGalleryTimeouts(**timeouts)
        self._values: typing.Dict[str, typing.Any] = {
            "location": location,
            "name": name,
            "resource_group_name": resource_group_name,
        }
        if count is not None:
            self._values["count"] = count
        if depends_on is not None:
            self._values["depends_on"] = depends_on
        if lifecycle is not None:
            self._values["lifecycle"] = lifecycle
        if provider is not None:
            self._values["provider"] = provider
        if description is not None:
            self._values["description"] = description
        if tags is not None:
            self._values["tags"] = tags
        if timeouts is not None:
            self._values["timeouts"] = timeouts

    @builtins.property
    def count(self) -> typing.Optional[jsii.Number]:
        """
        :stability: experimental
        """
        result = self._values.get("count")
        return result

    @builtins.property
    def depends_on(self) -> typing.Optional[typing.List[cdktf.TerraformResource]]:
        """
        :stability: experimental
        """
        result = self._values.get("depends_on")
        return result

    @builtins.property
    def lifecycle(self) -> typing.Optional[cdktf.TerraformResourceLifecycle]:
        """
        :stability: experimental
        """
        result = self._values.get("lifecycle")
        return result

    @builtins.property
    def provider(self) -> typing.Optional[cdktf.TerraformProvider]:
        """
        :stability: experimental
        """
        result = self._values.get("provider")
        return result

    @builtins.property
    def location(self) -> builtins.str:
        result = self._values.get("location")
        assert result is not None, "Required property 'location' is missing"
        return result

    @builtins.property
    def name(self) -> builtins.str:
        result = self._values.get("name")
        assert result is not None, "Required property 'name' is missing"
        return result

    @builtins.property
    def resource_group_name(self) -> builtins.str:
        result = self._values.get("resource_group_name")
        assert result is not None, "Required property 'resource_group_name' is missing"
        return result

    @builtins.property
    def description(self) -> typing.Optional[builtins.str]:
        result = self._values.get("description")
        return result

    @builtins.property
    def tags(self) -> typing.Optional[typing.Mapping[builtins.str, builtins.str]]:
        result = self._values.get("tags")
        return result

    @builtins.property
    def timeouts(self) -> typing.Optional["SharedImageGalleryTimeouts"]:
        """timeouts block."""
        result = self._values.get("timeouts")
        return result

    def __eq__(self, rhs: typing.Any) -> builtins.bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs: typing.Any) -> builtins.bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return "SharedImageGalleryConfig(%s)" % ", ".join(
            k + "=" + repr(v) for k, v in self._values.items()
        )


@jsii.data_type(
    jsii_type="@cdktf/provider-azurerm.SharedImageGalleryTimeouts",
    jsii_struct_bases=[],
    name_mapping={
        "create": "create",
        "delete": "delete",
        "read": "read",
        "update": "update",
    },
)
class SharedImageGalleryTimeouts:
    def __init__(
        self,
        *,
        create: typing.Optional[builtins.str] = None,
        delete: typing.Optional[builtins.str] = None,
        read: typing.Optional[builtins.str] = None,
        update: typing.Optional[builtins.str] = None,
    ) -> None:
        """
        :param create: 
        :param delete: 
        :param read: 
        :param update: 
        """
        self._values: typing.Dict[str, typing.Any] = {}
        if create is not None:
            self._values["create"] = create
        if delete is not None:
            self._values["delete"] = delete
        if read is not None:
            self._values["read"] = read
        if update is not None:
            self._values["update"] = update

    @builtins.property
    def create(self) -> typing.Optional[builtins.str]:
        result = self._values.get("create")
        return result

    @builtins.property
    def delete(self) -> typing.Optional[builtins.str]:
        result = self._values.get("delete")
        return result

    @builtins.property
    def read(self) -> typing.Optional[builtins.str]:
        result = self._values.get("read")
        return result

    @builtins.property
    def update(self) -> typing.Optional[builtins.str]:
        result = self._values.get("update")
        return result

    def __eq__(self, rhs: typing.Any) -> builtins.bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs: typing.Any) -> builtins.bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return "SharedImageGalleryTimeouts(%s)" % ", ".join(
            k + "=" + repr(v) for k, v in self._values.items()
        )


@jsii.data_type(
    jsii_type="@cdktf/provider-azurerm.SharedImageIdentifier",
    jsii_struct_bases=[],
    name_mapping={"offer": "offer", "publisher": "publisher", "sku": "sku"},
)
class SharedImageIdentifier:
    def __init__(
        self,
        *,
        offer: builtins.str,
        publisher: builtins.str,
        sku: builtins.str,
    ) -> None:
        """
        :param offer: 
        :param publisher: 
        :param sku: 
        """
        self._values: typing.Dict[str, typing.Any] = {
            "offer": offer,
            "publisher": publisher,
            "sku": sku,
        }

    @builtins.property
    def offer(self) -> builtins.str:
        result = self._values.get("offer")
        assert result is not None, "Required property 'offer' is missing"
        return result

    @builtins.property
    def publisher(self) -> builtins.str:
        result = self._values.get("publisher")
        assert result is not None, "Required property 'publisher' is missing"
        return result

    @builtins.property
    def sku(self) -> builtins.str:
        result = self._values.get("sku")
        assert result is not None, "Required property 'sku' is missing"
        return result

    def __eq__(self, rhs: typing.Any) -> builtins.bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs: typing.Any) -> builtins.bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return "SharedImageIdentifier(%s)" % ", ".join(
            k + "=" + repr(v) for k, v in self._values.items()
        )


@jsii.data_type(
    jsii_type="@cdktf/provider-azurerm.SharedImageTimeouts",
    jsii_struct_bases=[],
    name_mapping={
        "create": "create",
        "delete": "delete",
        "read": "read",
        "update": "update",
    },
)
class SharedImageTimeouts:
    def __init__(
        self,
        *,
        create: typing.Optional[builtins.str] = None,
        delete: typing.Optional[builtins.str] = None,
        read: typing.Optional[builtins.str] = None,
        update: typing.Optional[builtins.str] = None,
    ) -> None:
        """
        :param create: 
        :param delete: 
        :param read: 
        :param update: 
        """
        self._values: typing.Dict[str, typing.Any] = {}
        if create is not None:
            self._values["create"] = create
        if delete is not None:
            self._values["delete"] = delete
        if read is not None:
            self._values["read"] = read
        if update is not None:
            self._values["update"] = update

    @builtins.property
    def create(self) -> typing.Optional[builtins.str]:
        result = self._values.get("create")
        return result

    @builtins.property
    def delete(self) -> typing.Optional[builtins.str]:
        result = self._values.get("delete")
        return result

    @builtins.property
    def read(self) -> typing.Optional[builtins.str]:
        result = self._values.get("read")
        return result

    @builtins.property
    def update(self) -> typing.Optional[builtins.str]:
        result = self._values.get("update")
        return result

    def __eq__(self, rhs: typing.Any) -> builtins.bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs: typing.Any) -> builtins.bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return "SharedImageTimeouts(%s)" % ", ".join(
            k + "=" + repr(v) for k, v in self._values.items()
        )


class SharedImageVersion(
    cdktf.TerraformResource,
    metaclass=jsii.JSIIMeta,
    jsii_type="@cdktf/provider-azurerm.SharedImageVersion",
):
    def __init__(
        self,
        scope: constructs.Construct,
        id: builtins.str,
        *,
        gallery_name: builtins.str,
        image_name: builtins.str,
        location: builtins.str,
        managed_image_id: builtins.str,
        name: builtins.str,
        resource_group_name: builtins.str,
        target_region: typing.List["SharedImageVersionTargetRegion"],
        exclude_from_latest: typing.Optional[builtins.bool] = None,
        tags: typing.Optional[typing.Mapping[builtins.str, builtins.str]] = None,
        timeouts: typing.Optional["SharedImageVersionTimeouts"] = None,
        count: typing.Optional[jsii.Number] = None,
        depends_on: typing.Optional[typing.List[cdktf.TerraformResource]] = None,
        lifecycle: typing.Optional[cdktf.TerraformResourceLifecycle] = None,
        provider: typing.Optional[cdktf.TerraformProvider] = None,
    ) -> None:
        """
        :param scope: -
        :param id: -
        :param gallery_name: 
        :param image_name: 
        :param location: 
        :param managed_image_id: 
        :param name: 
        :param resource_group_name: 
        :param target_region: target_region block.
        :param exclude_from_latest: 
        :param tags: 
        :param timeouts: timeouts block.
        :param count: 
        :param depends_on: 
        :param lifecycle: 
        :param provider: 
        """
        config = SharedImageVersionConfig(
            gallery_name=gallery_name,
            image_name=image_name,
            location=location,
            managed_image_id=managed_image_id,
            name=name,
            resource_group_name=resource_group_name,
            target_region=target_region,
            exclude_from_latest=exclude_from_latest,
            tags=tags,
            timeouts=timeouts,
            count=count,
            depends_on=depends_on,
            lifecycle=lifecycle,
            provider=provider,
        )

        jsii.create(SharedImageVersion, self, [scope, id, config])

    @jsii.member(jsii_name="synthesizeAttributes")
    def _synthesize_attributes(self) -> typing.Mapping[builtins.str, typing.Any]:
        return jsii.invoke(self, "synthesizeAttributes", [])

    @builtins.property # type: ignore
    @jsii.member(jsii_name="galleryName")
    def gallery_name(self) -> builtins.str:
        return jsii.get(self, "galleryName")

    @gallery_name.setter # type: ignore
    def gallery_name(self, value: builtins.str) -> None:
        jsii.set(self, "galleryName", value)

    @builtins.property # type: ignore
    @jsii.member(jsii_name="imageName")
    def image_name(self) -> builtins.str:
        return jsii.get(self, "imageName")

    @image_name.setter # type: ignore
    def image_name(self, value: builtins.str) -> None:
        jsii.set(self, "imageName", value)

    @builtins.property # type: ignore
    @jsii.member(jsii_name="location")
    def location(self) -> builtins.str:
        return jsii.get(self, "location")

    @location.setter # type: ignore
    def location(self, value: builtins.str) -> None:
        jsii.set(self, "location", value)

    @builtins.property # type: ignore
    @jsii.member(jsii_name="managedImageId")
    def managed_image_id(self) -> builtins.str:
        return jsii.get(self, "managedImageId")

    @managed_image_id.setter # type: ignore
    def managed_image_id(self, value: builtins.str) -> None:
        jsii.set(self, "managedImageId", value)

    @builtins.property # type: ignore
    @jsii.member(jsii_name="name")
    def name(self) -> builtins.str:
        return jsii.get(self, "name")

    @name.setter # type: ignore
    def name(self, value: builtins.str) -> None:
        jsii.set(self, "name", value)

    @builtins.property # type: ignore
    @jsii.member(jsii_name="resourceGroupName")
    def resource_group_name(self) -> builtins.str:
        return jsii.get(self, "resourceGroupName")

    @resource_group_name.setter # type: ignore
    def resource_group_name(self, value: builtins.str) -> None:
        jsii.set(self, "resourceGroupName", value)

    @builtins.property # type: ignore
    @jsii.member(jsii_name="targetRegion")
    def target_region(self) -> typing.List["SharedImageVersionTargetRegion"]:
        return jsii.get(self, "targetRegion")

    @target_region.setter # type: ignore
    def target_region(
        self,
        value: typing.List["SharedImageVersionTargetRegion"],
    ) -> None:
        jsii.set(self, "targetRegion", value)

    @builtins.property # type: ignore
    @jsii.member(jsii_name="excludeFromLatest")
    def exclude_from_latest(self) -> typing.Optional[builtins.bool]:
        return jsii.get(self, "excludeFromLatest")

    @exclude_from_latest.setter # type: ignore
    def exclude_from_latest(self, value: typing.Optional[builtins.bool]) -> None:
        jsii.set(self, "excludeFromLatest", value)

    @builtins.property # type: ignore
    @jsii.member(jsii_name="id")
    def id(self) -> typing.Optional[builtins.str]:
        return jsii.get(self, "id")

    @id.setter # type: ignore
    def id(self, value: typing.Optional[builtins.str]) -> None:
        jsii.set(self, "id", value)

    @builtins.property # type: ignore
    @jsii.member(jsii_name="tags")
    def tags(self) -> typing.Optional[typing.Mapping[builtins.str, builtins.str]]:
        return jsii.get(self, "tags")

    @tags.setter # type: ignore
    def tags(
        self,
        value: typing.Optional[typing.Mapping[builtins.str, builtins.str]],
    ) -> None:
        jsii.set(self, "tags", value)

    @builtins.property # type: ignore
    @jsii.member(jsii_name="timeouts")
    def timeouts(self) -> typing.Optional["SharedImageVersionTimeouts"]:
        return jsii.get(self, "timeouts")

    @timeouts.setter # type: ignore
    def timeouts(self, value: typing.Optional["SharedImageVersionTimeouts"]) -> None:
        jsii.set(self, "timeouts", value)


@jsii.data_type(
    jsii_type="@cdktf/provider-azurerm.SharedImageVersionConfig",
    jsii_struct_bases=[cdktf.TerraformMetaArguments],
    name_mapping={
        "count": "count",
        "depends_on": "dependsOn",
        "lifecycle": "lifecycle",
        "provider": "provider",
        "gallery_name": "galleryName",
        "image_name": "imageName",
        "location": "location",
        "managed_image_id": "managedImageId",
        "name": "name",
        "resource_group_name": "resourceGroupName",
        "target_region": "targetRegion",
        "exclude_from_latest": "excludeFromLatest",
        "tags": "tags",
        "timeouts": "timeouts",
    },
)
class SharedImageVersionConfig(cdktf.TerraformMetaArguments):
    def __init__(
        self,
        *,
        count: typing.Optional[jsii.Number] = None,
        depends_on: typing.Optional[typing.List[cdktf.TerraformResource]] = None,
        lifecycle: typing.Optional[cdktf.TerraformResourceLifecycle] = None,
        provider: typing.Optional[cdktf.TerraformProvider] = None,
        gallery_name: builtins.str,
        image_name: builtins.str,
        location: builtins.str,
        managed_image_id: builtins.str,
        name: builtins.str,
        resource_group_name: builtins.str,
        target_region: typing.List["SharedImageVersionTargetRegion"],
        exclude_from_latest: typing.Optional[builtins.bool] = None,
        tags: typing.Optional[typing.Mapping[builtins.str, builtins.str]] = None,
        timeouts: typing.Optional["SharedImageVersionTimeouts"] = None,
    ) -> None:
        """
        :param count: 
        :param depends_on: 
        :param lifecycle: 
        :param provider: 
        :param gallery_name: 
        :param image_name: 
        :param location: 
        :param managed_image_id: 
        :param name: 
        :param resource_group_name: 
        :param target_region: target_region block.
        :param exclude_from_latest: 
        :param tags: 
        :param timeouts: timeouts block.
        """
        if isinstance(lifecycle, dict):
            lifecycle = cdktf.TerraformResourceLifecycle(**lifecycle)
        if isinstance(timeouts, dict):
            timeouts = SharedImageVersionTimeouts(**timeouts)
        self._values: typing.Dict[str, typing.Any] = {
            "gallery_name": gallery_name,
            "image_name": image_name,
            "location": location,
            "managed_image_id": managed_image_id,
            "name": name,
            "resource_group_name": resource_group_name,
            "target_region": target_region,
        }
        if count is not None:
            self._values["count"] = count
        if depends_on is not None:
            self._values["depends_on"] = depends_on
        if lifecycle is not None:
            self._values["lifecycle"] = lifecycle
        if provider is not None:
            self._values["provider"] = provider
        if exclude_from_latest is not None:
            self._values["exclude_from_latest"] = exclude_from_latest
        if tags is not None:
            self._values["tags"] = tags
        if timeouts is not None:
            self._values["timeouts"] = timeouts

    @builtins.property
    def count(self) -> typing.Optional[jsii.Number]:
        """
        :stability: experimental
        """
        result = self._values.get("count")
        return result

    @builtins.property
    def depends_on(self) -> typing.Optional[typing.List[cdktf.TerraformResource]]:
        """
        :stability: experimental
        """
        result = self._values.get("depends_on")
        return result

    @builtins.property
    def lifecycle(self) -> typing.Optional[cdktf.TerraformResourceLifecycle]:
        """
        :stability: experimental
        """
        result = self._values.get("lifecycle")
        return result

    @builtins.property
    def provider(self) -> typing.Optional[cdktf.TerraformProvider]:
        """
        :stability: experimental
        """
        result = self._values.get("provider")
        return result

    @builtins.property
    def gallery_name(self) -> builtins.str:
        result = self._values.get("gallery_name")
        assert result is not None, "Required property 'gallery_name' is missing"
        return result

    @builtins.property
    def image_name(self) -> builtins.str:
        result = self._values.get("image_name")
        assert result is not None, "Required property 'image_name' is missing"
        return result

    @builtins.property
    def location(self) -> builtins.str:
        result = self._values.get("location")
        assert result is not None, "Required property 'location' is missing"
        return result

    @builtins.property
    def managed_image_id(self) -> builtins.str:
        result = self._values.get("managed_image_id")
        assert result is not None, "Required property 'managed_image_id' is missing"
        return result

    @builtins.property
    def name(self) -> builtins.str:
        result = self._values.get("name")
        assert result is not None, "Required property 'name' is missing"
        return result

    @builtins.property
    def resource_group_name(self) -> builtins.str:
        result = self._values.get("resource_group_name")
        assert result is not None, "Required property 'resource_group_name' is missing"
        return result

    @builtins.property
    def target_region(self) -> typing.List["SharedImageVersionTargetRegion"]:
        """target_region block."""
        result = self._values.get("target_region")
        assert result is not None, "Required property 'target_region' is missing"
        return result

    @builtins.property
    def exclude_from_latest(self) -> typing.Optional[builtins.bool]:
        result = self._values.get("exclude_from_latest")
        return result

    @builtins.property
    def tags(self) -> typing.Optional[typing.Mapping[builtins.str, builtins.str]]:
        result = self._values.get("tags")
        return result

    @builtins.property
    def timeouts(self) -> typing.Optional["SharedImageVersionTimeouts"]:
        """timeouts block."""
        result = self._values.get("timeouts")
        return result

    def __eq__(self, rhs: typing.Any) -> builtins.bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs: typing.Any) -> builtins.bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return "SharedImageVersionConfig(%s)" % ", ".join(
            k + "=" + repr(v) for k, v in self._values.items()
        )


@jsii.data_type(
    jsii_type="@cdktf/provider-azurerm.SharedImageVersionTargetRegion",
    jsii_struct_bases=[],
    name_mapping={
        "name": "name",
        "regional_replica_count": "regionalReplicaCount",
        "storage_account_type": "storageAccountType",
    },
)
class SharedImageVersionTargetRegion:
    def __init__(
        self,
        *,
        name: builtins.str,
        regional_replica_count: jsii.Number,
        storage_account_type: typing.Optional[builtins.str] = None,
    ) -> None:
        """
        :param name: 
        :param regional_replica_count: 
        :param storage_account_type: 
        """
        self._values: typing.Dict[str, typing.Any] = {
            "name": name,
            "regional_replica_count": regional_replica_count,
        }
        if storage_account_type is not None:
            self._values["storage_account_type"] = storage_account_type

    @builtins.property
    def name(self) -> builtins.str:
        result = self._values.get("name")
        assert result is not None, "Required property 'name' is missing"
        return result

    @builtins.property
    def regional_replica_count(self) -> jsii.Number:
        result = self._values.get("regional_replica_count")
        assert result is not None, "Required property 'regional_replica_count' is missing"
        return result

    @builtins.property
    def storage_account_type(self) -> typing.Optional[builtins.str]:
        result = self._values.get("storage_account_type")
        return result

    def __eq__(self, rhs: typing.Any) -> builtins.bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs: typing.Any) -> builtins.bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return "SharedImageVersionTargetRegion(%s)" % ", ".join(
            k + "=" + repr(v) for k, v in self._values.items()
        )


@jsii.data_type(
    jsii_type="@cdktf/provider-azurerm.SharedImageVersionTimeouts",
    jsii_struct_bases=[],
    name_mapping={
        "create": "create",
        "delete": "delete",
        "read": "read",
        "update": "update",
    },
)
class SharedImageVersionTimeouts:
    def __init__(
        self,
        *,
        create: typing.Optional[builtins.str] = None,
        delete: typing.Optional[builtins.str] = None,
        read: typing.Optional[builtins.str] = None,
        update: typing.Optional[builtins.str] = None,
    ) -> None:
        """
        :param create: 
        :param delete: 
        :param read: 
        :param update: 
        """
        self._values: typing.Dict[str, typing.Any] = {}
        if create is not None:
            self._values["create"] = create
        if delete is not None:
            self._values["delete"] = delete
        if read is not None:
            self._values["read"] = read
        if update is not None:
            self._values["update"] = update

    @builtins.property
    def create(self) -> typing.Optional[builtins.str]:
        result = self._values.get("create")
        return result

    @builtins.property
    def delete(self) -> typing.Optional[builtins.str]:
        result = self._values.get("delete")
        return result

    @builtins.property
    def read(self) -> typing.Optional[builtins.str]:
        result = self._values.get("read")
        return result

    @builtins.property
    def update(self) -> typing.Optional[builtins.str]:
        result = self._values.get("update")
        return result

    def __eq__(self, rhs: typing.Any) -> builtins.bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs: typing.Any) -> builtins.bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return "SharedImageVersionTimeouts(%s)" % ", ".join(
            k + "=" + repr(v) for k, v in self._values.items()
        )


class SignalrService(
    cdktf.TerraformResource,
    metaclass=jsii.JSIIMeta,
    jsii_type="@cdktf/provider-azurerm.SignalrService",
):
    def __init__(
        self,
        scope: constructs.Construct,
        id: builtins.str,
        *,
        location: builtins.str,
        name: builtins.str,
        resource_group_name: builtins.str,
        sku: typing.List["SignalrServiceSku"],
        cors: typing.Optional[typing.List["SignalrServiceCors"]] = None,
        features: typing.Optional[typing.List["SignalrServiceFeatures"]] = None,
        tags: typing.Optional[typing.Mapping[builtins.str, builtins.str]] = None,
        timeouts: typing.Optional["SignalrServiceTimeouts"] = None,
        count: typing.Optional[jsii.Number] = None,
        depends_on: typing.Optional[typing.List[cdktf.TerraformResource]] = None,
        lifecycle: typing.Optional[cdktf.TerraformResourceLifecycle] = None,
        provider: typing.Optional[cdktf.TerraformProvider] = None,
    ) -> None:
        """
        :param scope: -
        :param id: -
        :param location: 
        :param name: 
        :param resource_group_name: 
        :param sku: sku block.
        :param cors: cors block.
        :param features: features block.
        :param tags: 
        :param timeouts: timeouts block.
        :param count: 
        :param depends_on: 
        :param lifecycle: 
        :param provider: 
        """
        config = SignalrServiceConfig(
            location=location,
            name=name,
            resource_group_name=resource_group_name,
            sku=sku,
            cors=cors,
            features=features,
            tags=tags,
            timeouts=timeouts,
            count=count,
            depends_on=depends_on,
            lifecycle=lifecycle,
            provider=provider,
        )

        jsii.create(SignalrService, self, [scope, id, config])

    @jsii.member(jsii_name="synthesizeAttributes")
    def _synthesize_attributes(self) -> typing.Mapping[builtins.str, typing.Any]:
        return jsii.invoke(self, "synthesizeAttributes", [])

    @builtins.property # type: ignore
    @jsii.member(jsii_name="hostname")
    def hostname(self) -> builtins.str:
        return jsii.get(self, "hostname")

    @builtins.property # type: ignore
    @jsii.member(jsii_name="ipAddress")
    def ip_address(self) -> builtins.str:
        return jsii.get(self, "ipAddress")

    @builtins.property # type: ignore
    @jsii.member(jsii_name="primaryAccessKey")
    def primary_access_key(self) -> builtins.str:
        return jsii.get(self, "primaryAccessKey")

    @builtins.property # type: ignore
    @jsii.member(jsii_name="primaryConnectionString")
    def primary_connection_string(self) -> builtins.str:
        return jsii.get(self, "primaryConnectionString")

    @builtins.property # type: ignore
    @jsii.member(jsii_name="publicPort")
    def public_port(self) -> jsii.Number:
        return jsii.get(self, "publicPort")

    @builtins.property # type: ignore
    @jsii.member(jsii_name="secondaryAccessKey")
    def secondary_access_key(self) -> builtins.str:
        return jsii.get(self, "secondaryAccessKey")

    @builtins.property # type: ignore
    @jsii.member(jsii_name="secondaryConnectionString")
    def secondary_connection_string(self) -> builtins.str:
        return jsii.get(self, "secondaryConnectionString")

    @builtins.property # type: ignore
    @jsii.member(jsii_name="serverPort")
    def server_port(self) -> jsii.Number:
        return jsii.get(self, "serverPort")

    @builtins.property # type: ignore
    @jsii.member(jsii_name="location")
    def location(self) -> builtins.str:
        return jsii.get(self, "location")

    @location.setter # type: ignore
    def location(self, value: builtins.str) -> None:
        jsii.set(self, "location", value)

    @builtins.property # type: ignore
    @jsii.member(jsii_name="name")
    def name(self) -> builtins.str:
        return jsii.get(self, "name")

    @name.setter # type: ignore
    def name(self, value: builtins.str) -> None:
        jsii.set(self, "name", value)

    @builtins.property # type: ignore
    @jsii.member(jsii_name="resourceGroupName")
    def resource_group_name(self) -> builtins.str:
        return jsii.get(self, "resourceGroupName")

    @resource_group_name.setter # type: ignore
    def resource_group_name(self, value: builtins.str) -> None:
        jsii.set(self, "resourceGroupName", value)

    @builtins.property # type: ignore
    @jsii.member(jsii_name="sku")
    def sku(self) -> typing.List["SignalrServiceSku"]:
        return jsii.get(self, "sku")

    @sku.setter # type: ignore
    def sku(self, value: typing.List["SignalrServiceSku"]) -> None:
        jsii.set(self, "sku", value)

    @builtins.property # type: ignore
    @jsii.member(jsii_name="cors")
    def cors(self) -> typing.Optional[typing.List["SignalrServiceCors"]]:
        return jsii.get(self, "cors")

    @cors.setter # type: ignore
    def cors(self, value: typing.Optional[typing.List["SignalrServiceCors"]]) -> None:
        jsii.set(self, "cors", value)

    @builtins.property # type: ignore
    @jsii.member(jsii_name="features")
    def features(self) -> typing.Optional[typing.List["SignalrServiceFeatures"]]:
        return jsii.get(self, "features")

    @features.setter # type: ignore
    def features(
        self,
        value: typing.Optional[typing.List["SignalrServiceFeatures"]],
    ) -> None:
        jsii.set(self, "features", value)

    @builtins.property # type: ignore
    @jsii.member(jsii_name="id")
    def id(self) -> typing.Optional[builtins.str]:
        return jsii.get(self, "id")

    @id.setter # type: ignore
    def id(self, value: typing.Optional[builtins.str]) -> None:
        jsii.set(self, "id", value)

    @builtins.property # type: ignore
    @jsii.member(jsii_name="tags")
    def tags(self) -> typing.Optional[typing.Mapping[builtins.str, builtins.str]]:
        return jsii.get(self, "tags")

    @tags.setter # type: ignore
    def tags(
        self,
        value: typing.Optional[typing.Mapping[builtins.str, builtins.str]],
    ) -> None:
        jsii.set(self, "tags", value)

    @builtins.property # type: ignore
    @jsii.member(jsii_name="timeouts")
    def timeouts(self) -> typing.Optional["SignalrServiceTimeouts"]:
        return jsii.get(self, "timeouts")

    @timeouts.setter # type: ignore
    def timeouts(self, value: typing.Optional["SignalrServiceTimeouts"]) -> None:
        jsii.set(self, "timeouts", value)


@jsii.data_type(
    jsii_type="@cdktf/provider-azurerm.SignalrServiceConfig",
    jsii_struct_bases=[cdktf.TerraformMetaArguments],
    name_mapping={
        "count": "count",
        "depends_on": "dependsOn",
        "lifecycle": "lifecycle",
        "provider": "provider",
        "location": "location",
        "name": "name",
        "resource_group_name": "resourceGroupName",
        "sku": "sku",
        "cors": "cors",
        "features": "features",
        "tags": "tags",
        "timeouts": "timeouts",
    },
)
class SignalrServiceConfig(cdktf.TerraformMetaArguments):
    def __init__(
        self,
        *,
        count: typing.Optional[jsii.Number] = None,
        depends_on: typing.Optional[typing.List[cdktf.TerraformResource]] = None,
        lifecycle: typing.Optional[cdktf.TerraformResourceLifecycle] = None,
        provider: typing.Optional[cdktf.TerraformProvider] = None,
        location: builtins.str,
        name: builtins.str,
        resource_group_name: builtins.str,
        sku: typing.List["SignalrServiceSku"],
        cors: typing.Optional[typing.List["SignalrServiceCors"]] = None,
        features: typing.Optional[typing.List["SignalrServiceFeatures"]] = None,
        tags: typing.Optional[typing.Mapping[builtins.str, builtins.str]] = None,
        timeouts: typing.Optional["SignalrServiceTimeouts"] = None,
    ) -> None:
        """
        :param count: 
        :param depends_on: 
        :param lifecycle: 
        :param provider: 
        :param location: 
        :param name: 
        :param resource_group_name: 
        :param sku: sku block.
        :param cors: cors block.
        :param features: features block.
        :param tags: 
        :param timeouts: timeouts block.
        """
        if isinstance(lifecycle, dict):
            lifecycle = cdktf.TerraformResourceLifecycle(**lifecycle)
        if isinstance(timeouts, dict):
            timeouts = SignalrServiceTimeouts(**timeouts)
        self._values: typing.Dict[str, typing.Any] = {
            "location": location,
            "name": name,
            "resource_group_name": resource_group_name,
            "sku": sku,
        }
        if count is not None:
            self._values["count"] = count
        if depends_on is not None:
            self._values["depends_on"] = depends_on
        if lifecycle is not None:
            self._values["lifecycle"] = lifecycle
        if provider is not None:
            self._values["provider"] = provider
        if cors is not None:
            self._values["cors"] = cors
        if features is not None:
            self._values["features"] = features
        if tags is not None:
            self._values["tags"] = tags
        if timeouts is not None:
            self._values["timeouts"] = timeouts

    @builtins.property
    def count(self) -> typing.Optional[jsii.Number]:
        """
        :stability: experimental
        """
        result = self._values.get("count")
        return result

    @builtins.property
    def depends_on(self) -> typing.Optional[typing.List[cdktf.TerraformResource]]:
        """
        :stability: experimental
        """
        result = self._values.get("depends_on")
        return result

    @builtins.property
    def lifecycle(self) -> typing.Optional[cdktf.TerraformResourceLifecycle]:
        """
        :stability: experimental
        """
        result = self._values.get("lifecycle")
        return result

    @builtins.property
    def provider(self) -> typing.Optional[cdktf.TerraformProvider]:
        """
        :stability: experimental
        """
        result = self._values.get("provider")
        return result

    @builtins.property
    def location(self) -> builtins.str:
        result = self._values.get("location")
        assert result is not None, "Required property 'location' is missing"
        return result

    @builtins.property
    def name(self) -> builtins.str:
        result = self._values.get("name")
        assert result is not None, "Required property 'name' is missing"
        return result

    @builtins.property
    def resource_group_name(self) -> builtins.str:
        result = self._values.get("resource_group_name")
        assert result is not None, "Required property 'resource_group_name' is missing"
        return result

    @builtins.property
    def sku(self) -> typing.List["SignalrServiceSku"]:
        """sku block."""
        result = self._values.get("sku")
        assert result is not None, "Required property 'sku' is missing"
        return result

    @builtins.property
    def cors(self) -> typing.Optional[typing.List["SignalrServiceCors"]]:
        """cors block."""
        result = self._values.get("cors")
        return result

    @builtins.property
    def features(self) -> typing.Optional[typing.List["SignalrServiceFeatures"]]:
        """features block."""
        result = self._values.get("features")
        return result

    @builtins.property
    def tags(self) -> typing.Optional[typing.Mapping[builtins.str, builtins.str]]:
        result = self._values.get("tags")
        return result

    @builtins.property
    def timeouts(self) -> typing.Optional["SignalrServiceTimeouts"]:
        """timeouts block."""
        result = self._values.get("timeouts")
        return result

    def __eq__(self, rhs: typing.Any) -> builtins.bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs: typing.Any) -> builtins.bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return "SignalrServiceConfig(%s)" % ", ".join(
            k + "=" + repr(v) for k, v in self._values.items()
        )


@jsii.data_type(
    jsii_type="@cdktf/provider-azurerm.SignalrServiceCors",
    jsii_struct_bases=[],
    name_mapping={"allowed_origins": "allowedOrigins"},
)
class SignalrServiceCors:
    def __init__(self, *, allowed_origins: typing.List[builtins.str]) -> None:
        """
        :param allowed_origins: 
        """
        self._values: typing.Dict[str, typing.Any] = {
            "allowed_origins": allowed_origins,
        }

    @builtins.property
    def allowed_origins(self) -> typing.List[builtins.str]:
        result = self._values.get("allowed_origins")
        assert result is not None, "Required property 'allowed_origins' is missing"
        return result

    def __eq__(self, rhs: typing.Any) -> builtins.bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs: typing.Any) -> builtins.bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return "SignalrServiceCors(%s)" % ", ".join(
            k + "=" + repr(v) for k, v in self._values.items()
        )


@jsii.data_type(
    jsii_type="@cdktf/provider-azurerm.SignalrServiceFeatures",
    jsii_struct_bases=[],
    name_mapping={"flag": "flag", "value": "value"},
)
class SignalrServiceFeatures:
    def __init__(self, *, flag: builtins.str, value: builtins.str) -> None:
        """
        :param flag: 
        :param value: 
        """
        self._values: typing.Dict[str, typing.Any] = {
            "flag": flag,
            "value": value,
        }

    @builtins.property
    def flag(self) -> builtins.str:
        result = self._values.get("flag")
        assert result is not None, "Required property 'flag' is missing"
        return result

    @builtins.property
    def value(self) -> builtins.str:
        result = self._values.get("value")
        assert result is not None, "Required property 'value' is missing"
        return result

    def __eq__(self, rhs: typing.Any) -> builtins.bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs: typing.Any) -> builtins.bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return "SignalrServiceFeatures(%s)" % ", ".join(
            k + "=" + repr(v) for k, v in self._values.items()
        )


@jsii.data_type(
    jsii_type="@cdktf/provider-azurerm.SignalrServiceSku",
    jsii_struct_bases=[],
    name_mapping={"capacity": "capacity", "name": "name"},
)
class SignalrServiceSku:
    def __init__(self, *, capacity: jsii.Number, name: builtins.str) -> None:
        """
        :param capacity: 
        :param name: 
        """
        self._values: typing.Dict[str, typing.Any] = {
            "capacity": capacity,
            "name": name,
        }

    @builtins.property
    def capacity(self) -> jsii.Number:
        result = self._values.get("capacity")
        assert result is not None, "Required property 'capacity' is missing"
        return result

    @builtins.property
    def name(self) -> builtins.str:
        result = self._values.get("name")
        assert result is not None, "Required property 'name' is missing"
        return result

    def __eq__(self, rhs: typing.Any) -> builtins.bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs: typing.Any) -> builtins.bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return "SignalrServiceSku(%s)" % ", ".join(
            k + "=" + repr(v) for k, v in self._values.items()
        )


@jsii.data_type(
    jsii_type="@cdktf/provider-azurerm.SignalrServiceTimeouts",
    jsii_struct_bases=[],
    name_mapping={
        "create": "create",
        "delete": "delete",
        "read": "read",
        "update": "update",
    },
)
class SignalrServiceTimeouts:
    def __init__(
        self,
        *,
        create: typing.Optional[builtins.str] = None,
        delete: typing.Optional[builtins.str] = None,
        read: typing.Optional[builtins.str] = None,
        update: typing.Optional[builtins.str] = None,
    ) -> None:
        """
        :param create: 
        :param delete: 
        :param read: 
        :param update: 
        """
        self._values: typing.Dict[str, typing.Any] = {}
        if create is not None:
            self._values["create"] = create
        if delete is not None:
            self._values["delete"] = delete
        if read is not None:
            self._values["read"] = read
        if update is not None:
            self._values["update"] = update

    @builtins.property
    def create(self) -> typing.Optional[builtins.str]:
        result = self._values.get("create")
        return result

    @builtins.property
    def delete(self) -> typing.Optional[builtins.str]:
        result = self._values.get("delete")
        return result

    @builtins.property
    def read(self) -> typing.Optional[builtins.str]:
        result = self._values.get("read")
        return result

    @builtins.property
    def update(self) -> typing.Optional[builtins.str]:
        result = self._values.get("update")
        return result

    def __eq__(self, rhs: typing.Any) -> builtins.bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs: typing.Any) -> builtins.bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return "SignalrServiceTimeouts(%s)" % ", ".join(
            k + "=" + repr(v) for k, v in self._values.items()
        )


class SiteRecoveryFabric(
    cdktf.TerraformResource,
    metaclass=jsii.JSIIMeta,
    jsii_type="@cdktf/provider-azurerm.SiteRecoveryFabric",
):
    def __init__(
        self,
        scope: constructs.Construct,
        id: builtins.str,
        *,
        location: builtins.str,
        name: builtins.str,
        recovery_vault_name: builtins.str,
        resource_group_name: builtins.str,
        timeouts: typing.Optional["SiteRecoveryFabricTimeouts"] = None,
        count: typing.Optional[jsii.Number] = None,
        depends_on: typing.Optional[typing.List[cdktf.TerraformResource]] = None,
        lifecycle: typing.Optional[cdktf.TerraformResourceLifecycle] = None,
        provider: typing.Optional[cdktf.TerraformProvider] = None,
    ) -> None:
        """
        :param scope: -
        :param id: -
        :param location: 
        :param name: 
        :param recovery_vault_name: 
        :param resource_group_name: 
        :param timeouts: timeouts block.
        :param count: 
        :param depends_on: 
        :param lifecycle: 
        :param provider: 
        """
        config = SiteRecoveryFabricConfig(
            location=location,
            name=name,
            recovery_vault_name=recovery_vault_name,
            resource_group_name=resource_group_name,
            timeouts=timeouts,
            count=count,
            depends_on=depends_on,
            lifecycle=lifecycle,
            provider=provider,
        )

        jsii.create(SiteRecoveryFabric, self, [scope, id, config])

    @jsii.member(jsii_name="synthesizeAttributes")
    def _synthesize_attributes(self) -> typing.Mapping[builtins.str, typing.Any]:
        return jsii.invoke(self, "synthesizeAttributes", [])

    @builtins.property # type: ignore
    @jsii.member(jsii_name="location")
    def location(self) -> builtins.str:
        return jsii.get(self, "location")

    @location.setter # type: ignore
    def location(self, value: builtins.str) -> None:
        jsii.set(self, "location", value)

    @builtins.property # type: ignore
    @jsii.member(jsii_name="name")
    def name(self) -> builtins.str:
        return jsii.get(self, "name")

    @name.setter # type: ignore
    def name(self, value: builtins.str) -> None:
        jsii.set(self, "name", value)

    @builtins.property # type: ignore
    @jsii.member(jsii_name="recoveryVaultName")
    def recovery_vault_name(self) -> builtins.str:
        return jsii.get(self, "recoveryVaultName")

    @recovery_vault_name.setter # type: ignore
    def recovery_vault_name(self, value: builtins.str) -> None:
        jsii.set(self, "recoveryVaultName", value)

    @builtins.property # type: ignore
    @jsii.member(jsii_name="resourceGroupName")
    def resource_group_name(self) -> builtins.str:
        return jsii.get(self, "resourceGroupName")

    @resource_group_name.setter # type: ignore
    def resource_group_name(self, value: builtins.str) -> None:
        jsii.set(self, "resourceGroupName", value)

    @builtins.property # type: ignore
    @jsii.member(jsii_name="id")
    def id(self) -> typing.Optional[builtins.str]:
        return jsii.get(self, "id")

    @id.setter # type: ignore
    def id(self, value: typing.Optional[builtins.str]) -> None:
        jsii.set(self, "id", value)

    @builtins.property # type: ignore
    @jsii.member(jsii_name="timeouts")
    def timeouts(self) -> typing.Optional["SiteRecoveryFabricTimeouts"]:
        return jsii.get(self, "timeouts")

    @timeouts.setter # type: ignore
    def timeouts(self, value: typing.Optional["SiteRecoveryFabricTimeouts"]) -> None:
        jsii.set(self, "timeouts", value)


@jsii.data_type(
    jsii_type="@cdktf/provider-azurerm.SiteRecoveryFabricConfig",
    jsii_struct_bases=[cdktf.TerraformMetaArguments],
    name_mapping={
        "count": "count",
        "depends_on": "dependsOn",
        "lifecycle": "lifecycle",
        "provider": "provider",
        "location": "location",
        "name": "name",
        "recovery_vault_name": "recoveryVaultName",
        "resource_group_name": "resourceGroupName",
        "timeouts": "timeouts",
    },
)
class SiteRecoveryFabricConfig(cdktf.TerraformMetaArguments):
    def __init__(
        self,
        *,
        count: typing.Optional[jsii.Number] = None,
        depends_on: typing.Optional[typing.List[cdktf.TerraformResource]] = None,
        lifecycle: typing.Optional[cdktf.TerraformResourceLifecycle] = None,
        provider: typing.Optional[cdktf.TerraformProvider] = None,
        location: builtins.str,
        name: builtins.str,
        recovery_vault_name: builtins.str,
        resource_group_name: builtins.str,
        timeouts: typing.Optional["SiteRecoveryFabricTimeouts"] = None,
    ) -> None:
        """
        :param count: 
        :param depends_on: 
        :param lifecycle: 
        :param provider: 
        :param location: 
        :param name: 
        :param recovery_vault_name: 
        :param resource_group_name: 
        :param timeouts: timeouts block.
        """
        if isinstance(lifecycle, dict):
            lifecycle = cdktf.TerraformResourceLifecycle(**lifecycle)
        if isinstance(timeouts, dict):
            timeouts = SiteRecoveryFabricTimeouts(**timeouts)
        self._values: typing.Dict[str, typing.Any] = {
            "location": location,
            "name": name,
            "recovery_vault_name": recovery_vault_name,
            "resource_group_name": resource_group_name,
        }
        if count is not None:
            self._values["count"] = count
        if depends_on is not None:
            self._values["depends_on"] = depends_on
        if lifecycle is not None:
            self._values["lifecycle"] = lifecycle
        if provider is not None:
            self._values["provider"] = provider
        if timeouts is not None:
            self._values["timeouts"] = timeouts

    @builtins.property
    def count(self) -> typing.Optional[jsii.Number]:
        """
        :stability: experimental
        """
        result = self._values.get("count")
        return result

    @builtins.property
    def depends_on(self) -> typing.Optional[typing.List[cdktf.TerraformResource]]:
        """
        :stability: experimental
        """
        result = self._values.get("depends_on")
        return result

    @builtins.property
    def lifecycle(self) -> typing.Optional[cdktf.TerraformResourceLifecycle]:
        """
        :stability: experimental
        """
        result = self._values.get("lifecycle")
        return result

    @builtins.property
    def provider(self) -> typing.Optional[cdktf.TerraformProvider]:
        """
        :stability: experimental
        """
        result = self._values.get("provider")
        return result

    @builtins.property
    def location(self) -> builtins.str:
        result = self._values.get("location")
        assert result is not None, "Required property 'location' is missing"
        return result

    @builtins.property
    def name(self) -> builtins.str:
        result = self._values.get("name")
        assert result is not None, "Required property 'name' is missing"
        return result

    @builtins.property
    def recovery_vault_name(self) -> builtins.str:
        result = self._values.get("recovery_vault_name")
        assert result is not None, "Required property 'recovery_vault_name' is missing"
        return result

    @builtins.property
    def resource_group_name(self) -> builtins.str:
        result = self._values.get("resource_group_name")
        assert result is not None, "Required property 'resource_group_name' is missing"
        return result

    @builtins.property
    def timeouts(self) -> typing.Optional["SiteRecoveryFabricTimeouts"]:
        """timeouts block."""
        result = self._values.get("timeouts")
        return result

    def __eq__(self, rhs: typing.Any) -> builtins.bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs: typing.Any) -> builtins.bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return "SiteRecoveryFabricConfig(%s)" % ", ".join(
            k + "=" + repr(v) for k, v in self._values.items()
        )


@jsii.data_type(
    jsii_type="@cdktf/provider-azurerm.SiteRecoveryFabricTimeouts",
    jsii_struct_bases=[],
    name_mapping={
        "create": "create",
        "delete": "delete",
        "read": "read",
        "update": "update",
    },
)
class SiteRecoveryFabricTimeouts:
    def __init__(
        self,
        *,
        create: typing.Optional[builtins.str] = None,
        delete: typing.Optional[builtins.str] = None,
        read: typing.Optional[builtins.str] = None,
        update: typing.Optional[builtins.str] = None,
    ) -> None:
        """
        :param create: 
        :param delete: 
        :param read: 
        :param update: 
        """
        self._values: typing.Dict[str, typing.Any] = {}
        if create is not None:
            self._values["create"] = create
        if delete is not None:
            self._values["delete"] = delete
        if read is not None:
            self._values["read"] = read
        if update is not None:
            self._values["update"] = update

    @builtins.property
    def create(self) -> typing.Optional[builtins.str]:
        result = self._values.get("create")
        return result

    @builtins.property
    def delete(self) -> typing.Optional[builtins.str]:
        result = self._values.get("delete")
        return result

    @builtins.property
    def read(self) -> typing.Optional[builtins.str]:
        result = self._values.get("read")
        return result

    @builtins.property
    def update(self) -> typing.Optional[builtins.str]:
        result = self._values.get("update")
        return result

    def __eq__(self, rhs: typing.Any) -> builtins.bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs: typing.Any) -> builtins.bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return "SiteRecoveryFabricTimeouts(%s)" % ", ".join(
            k + "=" + repr(v) for k, v in self._values.items()
        )


class SiteRecoveryNetworkMapping(
    cdktf.TerraformResource,
    metaclass=jsii.JSIIMeta,
    jsii_type="@cdktf/provider-azurerm.SiteRecoveryNetworkMapping",
):
    def __init__(
        self,
        scope: constructs.Construct,
        id: builtins.str,
        *,
        name: builtins.str,
        recovery_vault_name: builtins.str,
        resource_group_name: builtins.str,
        source_network_id: builtins.str,
        source_recovery_fabric_name: builtins.str,
        target_network_id: builtins.str,
        target_recovery_fabric_name: builtins.str,
        timeouts: typing.Optional["SiteRecoveryNetworkMappingTimeouts"] = None,
        count: typing.Optional[jsii.Number] = None,
        depends_on: typing.Optional[typing.List[cdktf.TerraformResource]] = None,
        lifecycle: typing.Optional[cdktf.TerraformResourceLifecycle] = None,
        provider: typing.Optional[cdktf.TerraformProvider] = None,
    ) -> None:
        """
        :param scope: -
        :param id: -
        :param name: 
        :param recovery_vault_name: 
        :param resource_group_name: 
        :param source_network_id: 
        :param source_recovery_fabric_name: 
        :param target_network_id: 
        :param target_recovery_fabric_name: 
        :param timeouts: timeouts block.
        :param count: 
        :param depends_on: 
        :param lifecycle: 
        :param provider: 
        """
        config = SiteRecoveryNetworkMappingConfig(
            name=name,
            recovery_vault_name=recovery_vault_name,
            resource_group_name=resource_group_name,
            source_network_id=source_network_id,
            source_recovery_fabric_name=source_recovery_fabric_name,
            target_network_id=target_network_id,
            target_recovery_fabric_name=target_recovery_fabric_name,
            timeouts=timeouts,
            count=count,
            depends_on=depends_on,
            lifecycle=lifecycle,
            provider=provider,
        )

        jsii.create(SiteRecoveryNetworkMapping, self, [scope, id, config])

    @jsii.member(jsii_name="synthesizeAttributes")
    def _synthesize_attributes(self) -> typing.Mapping[builtins.str, typing.Any]:
        return jsii.invoke(self, "synthesizeAttributes", [])

    @builtins.property # type: ignore
    @jsii.member(jsii_name="name")
    def name(self) -> builtins.str:
        return jsii.get(self, "name")

    @name.setter # type: ignore
    def name(self, value: builtins.str) -> None:
        jsii.set(self, "name", value)

    @builtins.property # type: ignore
    @jsii.member(jsii_name="recoveryVaultName")
    def recovery_vault_name(self) -> builtins.str:
        return jsii.get(self, "recoveryVaultName")

    @recovery_vault_name.setter # type: ignore
    def recovery_vault_name(self, value: builtins.str) -> None:
        jsii.set(self, "recoveryVaultName", value)

    @builtins.property # type: ignore
    @jsii.member(jsii_name="resourceGroupName")
    def resource_group_name(self) -> builtins.str:
        return jsii.get(self, "resourceGroupName")

    @resource_group_name.setter # type: ignore
    def resource_group_name(self, value: builtins.str) -> None:
        jsii.set(self, "resourceGroupName", value)

    @builtins.property # type: ignore
    @jsii.member(jsii_name="sourceNetworkId")
    def source_network_id(self) -> builtins.str:
        return jsii.get(self, "sourceNetworkId")

    @source_network_id.setter # type: ignore
    def source_network_id(self, value: builtins.str) -> None:
        jsii.set(self, "sourceNetworkId", value)

    @builtins.property # type: ignore
    @jsii.member(jsii_name="sourceRecoveryFabricName")
    def source_recovery_fabric_name(self) -> builtins.str:
        return jsii.get(self, "sourceRecoveryFabricName")

    @source_recovery_fabric_name.setter # type: ignore
    def source_recovery_fabric_name(self, value: builtins.str) -> None:
        jsii.set(self, "sourceRecoveryFabricName", value)

    @builtins.property # type: ignore
    @jsii.member(jsii_name="targetNetworkId")
    def target_network_id(self) -> builtins.str:
        return jsii.get(self, "targetNetworkId")

    @target_network_id.setter # type: ignore
    def target_network_id(self, value: builtins.str) -> None:
        jsii.set(self, "targetNetworkId", value)

    @builtins.property # type: ignore
    @jsii.member(jsii_name="targetRecoveryFabricName")
    def target_recovery_fabric_name(self) -> builtins.str:
        return jsii.get(self, "targetRecoveryFabricName")

    @target_recovery_fabric_name.setter # type: ignore
    def target_recovery_fabric_name(self, value: builtins.str) -> None:
        jsii.set(self, "targetRecoveryFabricName", value)

    @builtins.property # type: ignore
    @jsii.member(jsii_name="id")
    def id(self) -> typing.Optional[builtins.str]:
        return jsii.get(self, "id")

    @id.setter # type: ignore
    def id(self, value: typing.Optional[builtins.str]) -> None:
        jsii.set(self, "id", value)

    @builtins.property # type: ignore
    @jsii.member(jsii_name="timeouts")
    def timeouts(self) -> typing.Optional["SiteRecoveryNetworkMappingTimeouts"]:
        return jsii.get(self, "timeouts")

    @timeouts.setter # type: ignore
    def timeouts(
        self,
        value: typing.Optional["SiteRecoveryNetworkMappingTimeouts"],
    ) -> None:
        jsii.set(self, "timeouts", value)


@jsii.data_type(
    jsii_type="@cdktf/provider-azurerm.SiteRecoveryNetworkMappingConfig",
    jsii_struct_bases=[cdktf.TerraformMetaArguments],
    name_mapping={
        "count": "count",
        "depends_on": "dependsOn",
        "lifecycle": "lifecycle",
        "provider": "provider",
        "name": "name",
        "recovery_vault_name": "recoveryVaultName",
        "resource_group_name": "resourceGroupName",
        "source_network_id": "sourceNetworkId",
        "source_recovery_fabric_name": "sourceRecoveryFabricName",
        "target_network_id": "targetNetworkId",
        "target_recovery_fabric_name": "targetRecoveryFabricName",
        "timeouts": "timeouts",
    },
)
class SiteRecoveryNetworkMappingConfig(cdktf.TerraformMetaArguments):
    def __init__(
        self,
        *,
        count: typing.Optional[jsii.Number] = None,
        depends_on: typing.Optional[typing.List[cdktf.TerraformResource]] = None,
        lifecycle: typing.Optional[cdktf.TerraformResourceLifecycle] = None,
        provider: typing.Optional[cdktf.TerraformProvider] = None,
        name: builtins.str,
        recovery_vault_name: builtins.str,
        resource_group_name: builtins.str,
        source_network_id: builtins.str,
        source_recovery_fabric_name: builtins.str,
        target_network_id: builtins.str,
        target_recovery_fabric_name: builtins.str,
        timeouts: typing.Optional["SiteRecoveryNetworkMappingTimeouts"] = None,
    ) -> None:
        """
        :param count: 
        :param depends_on: 
        :param lifecycle: 
        :param provider: 
        :param name: 
        :param recovery_vault_name: 
        :param resource_group_name: 
        :param source_network_id: 
        :param source_recovery_fabric_name: 
        :param target_network_id: 
        :param target_recovery_fabric_name: 
        :param timeouts: timeouts block.
        """
        if isinstance(lifecycle, dict):
            lifecycle = cdktf.TerraformResourceLifecycle(**lifecycle)
        if isinstance(timeouts, dict):
            timeouts = SiteRecoveryNetworkMappingTimeouts(**timeouts)
        self._values: typing.Dict[str, typing.Any] = {
            "name": name,
            "recovery_vault_name": recovery_vault_name,
            "resource_group_name": resource_group_name,
            "source_network_id": source_network_id,
            "source_recovery_fabric_name": source_recovery_fabric_name,
            "target_network_id": target_network_id,
            "target_recovery_fabric_name": target_recovery_fabric_name,
        }
        if count is not None:
            self._values["count"] = count
        if depends_on is not None:
            self._values["depends_on"] = depends_on
        if lifecycle is not None:
            self._values["lifecycle"] = lifecycle
        if provider is not None:
            self._values["provider"] = provider
        if timeouts is not None:
            self._values["timeouts"] = timeouts

    @builtins.property
    def count(self) -> typing.Optional[jsii.Number]:
        """
        :stability: experimental
        """
        result = self._values.get("count")
        return result

    @builtins.property
    def depends_on(self) -> typing.Optional[typing.List[cdktf.TerraformResource]]:
        """
        :stability: experimental
        """
        result = self._values.get("depends_on")
        return result

    @builtins.property
    def lifecycle(self) -> typing.Optional[cdktf.TerraformResourceLifecycle]:
        """
        :stability: experimental
        """
        result = self._values.get("lifecycle")
        return result

    @builtins.property
    def provider(self) -> typing.Optional[cdktf.TerraformProvider]:
        """
        :stability: experimental
        """
        result = self._values.get("provider")
        return result

    @builtins.property
    def name(self) -> builtins.str:
        result = self._values.get("name")
        assert result is not None, "Required property 'name' is missing"
        return result

    @builtins.property
    def recovery_vault_name(self) -> builtins.str:
        result = self._values.get("recovery_vault_name")
        assert result is not None, "Required property 'recovery_vault_name' is missing"
        return result

    @builtins.property
    def resource_group_name(self) -> builtins.str:
        result = self._values.get("resource_group_name")
        assert result is not None, "Required property 'resource_group_name' is missing"
        return result

    @builtins.property
    def source_network_id(self) -> builtins.str:
        result = self._values.get("source_network_id")
        assert result is not None, "Required property 'source_network_id' is missing"
        return result

    @builtins.property
    def source_recovery_fabric_name(self) -> builtins.str:
        result = self._values.get("source_recovery_fabric_name")
        assert result is not None, "Required property 'source_recovery_fabric_name' is missing"
        return result

    @builtins.property
    def target_network_id(self) -> builtins.str:
        result = self._values.get("target_network_id")
        assert result is not None, "Required property 'target_network_id' is missing"
        return result

    @builtins.property
    def target_recovery_fabric_name(self) -> builtins.str:
        result = self._values.get("target_recovery_fabric_name")
        assert result is not None, "Required property 'target_recovery_fabric_name' is missing"
        return result

    @builtins.property
    def timeouts(self) -> typing.Optional["SiteRecoveryNetworkMappingTimeouts"]:
        """timeouts block."""
        result = self._values.get("timeouts")
        return result

    def __eq__(self, rhs: typing.Any) -> builtins.bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs: typing.Any) -> builtins.bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return "SiteRecoveryNetworkMappingConfig(%s)" % ", ".join(
            k + "=" + repr(v) for k, v in self._values.items()
        )


@jsii.data_type(
    jsii_type="@cdktf/provider-azurerm.SiteRecoveryNetworkMappingTimeouts",
    jsii_struct_bases=[],
    name_mapping={
        "create": "create",
        "delete": "delete",
        "read": "read",
        "update": "update",
    },
)
class SiteRecoveryNetworkMappingTimeouts:
    def __init__(
        self,
        *,
        create: typing.Optional[builtins.str] = None,
        delete: typing.Optional[builtins.str] = None,
        read: typing.Optional[builtins.str] = None,
        update: typing.Optional[builtins.str] = None,
    ) -> None:
        """
        :param create: 
        :param delete: 
        :param read: 
        :param update: 
        """
        self._values: typing.Dict[str, typing.Any] = {}
        if create is not None:
            self._values["create"] = create
        if delete is not None:
            self._values["delete"] = delete
        if read is not None:
            self._values["read"] = read
        if update is not None:
            self._values["update"] = update

    @builtins.property
    def create(self) -> typing.Optional[builtins.str]:
        result = self._values.get("create")
        return result

    @builtins.property
    def delete(self) -> typing.Optional[builtins.str]:
        result = self._values.get("delete")
        return result

    @builtins.property
    def read(self) -> typing.Optional[builtins.str]:
        result = self._values.get("read")
        return result

    @builtins.property
    def update(self) -> typing.Optional[builtins.str]:
        result = self._values.get("update")
        return result

    def __eq__(self, rhs: typing.Any) -> builtins.bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs: typing.Any) -> builtins.bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return "SiteRecoveryNetworkMappingTimeouts(%s)" % ", ".join(
            k + "=" + repr(v) for k, v in self._values.items()
        )


class SiteRecoveryProtectionContainer(
    cdktf.TerraformResource,
    metaclass=jsii.JSIIMeta,
    jsii_type="@cdktf/provider-azurerm.SiteRecoveryProtectionContainer",
):
    def __init__(
        self,
        scope: constructs.Construct,
        id: builtins.str,
        *,
        name: builtins.str,
        recovery_fabric_name: builtins.str,
        recovery_vault_name: builtins.str,
        resource_group_name: builtins.str,
        timeouts: typing.Optional["SiteRecoveryProtectionContainerTimeouts"] = None,
        count: typing.Optional[jsii.Number] = None,
        depends_on: typing.Optional[typing.List[cdktf.TerraformResource]] = None,
        lifecycle: typing.Optional[cdktf.TerraformResourceLifecycle] = None,
        provider: typing.Optional[cdktf.TerraformProvider] = None,
    ) -> None:
        """
        :param scope: -
        :param id: -
        :param name: 
        :param recovery_fabric_name: 
        :param recovery_vault_name: 
        :param resource_group_name: 
        :param timeouts: timeouts block.
        :param count: 
        :param depends_on: 
        :param lifecycle: 
        :param provider: 
        """
        config = SiteRecoveryProtectionContainerConfig(
            name=name,
            recovery_fabric_name=recovery_fabric_name,
            recovery_vault_name=recovery_vault_name,
            resource_group_name=resource_group_name,
            timeouts=timeouts,
            count=count,
            depends_on=depends_on,
            lifecycle=lifecycle,
            provider=provider,
        )

        jsii.create(SiteRecoveryProtectionContainer, self, [scope, id, config])

    @jsii.member(jsii_name="synthesizeAttributes")
    def _synthesize_attributes(self) -> typing.Mapping[builtins.str, typing.Any]:
        return jsii.invoke(self, "synthesizeAttributes", [])

    @builtins.property # type: ignore
    @jsii.member(jsii_name="name")
    def name(self) -> builtins.str:
        return jsii.get(self, "name")

    @name.setter # type: ignore
    def name(self, value: builtins.str) -> None:
        jsii.set(self, "name", value)

    @builtins.property # type: ignore
    @jsii.member(jsii_name="recoveryFabricName")
    def recovery_fabric_name(self) -> builtins.str:
        return jsii.get(self, "recoveryFabricName")

    @recovery_fabric_name.setter # type: ignore
    def recovery_fabric_name(self, value: builtins.str) -> None:
        jsii.set(self, "recoveryFabricName", value)

    @builtins.property # type: ignore
    @jsii.member(jsii_name="recoveryVaultName")
    def recovery_vault_name(self) -> builtins.str:
        return jsii.get(self, "recoveryVaultName")

    @recovery_vault_name.setter # type: ignore
    def recovery_vault_name(self, value: builtins.str) -> None:
        jsii.set(self, "recoveryVaultName", value)

    @builtins.property # type: ignore
    @jsii.member(jsii_name="resourceGroupName")
    def resource_group_name(self) -> builtins.str:
        return jsii.get(self, "resourceGroupName")

    @resource_group_name.setter # type: ignore
    def resource_group_name(self, value: builtins.str) -> None:
        jsii.set(self, "resourceGroupName", value)

    @builtins.property # type: ignore
    @jsii.member(jsii_name="id")
    def id(self) -> typing.Optional[builtins.str]:
        return jsii.get(self, "id")

    @id.setter # type: ignore
    def id(self, value: typing.Optional[builtins.str]) -> None:
        jsii.set(self, "id", value)

    @builtins.property # type: ignore
    @jsii.member(jsii_name="timeouts")
    def timeouts(self) -> typing.Optional["SiteRecoveryProtectionContainerTimeouts"]:
        return jsii.get(self, "timeouts")

    @timeouts.setter # type: ignore
    def timeouts(
        self,
        value: typing.Optional["SiteRecoveryProtectionContainerTimeouts"],
    ) -> None:
        jsii.set(self, "timeouts", value)


@jsii.data_type(
    jsii_type="@cdktf/provider-azurerm.SiteRecoveryProtectionContainerConfig",
    jsii_struct_bases=[cdktf.TerraformMetaArguments],
    name_mapping={
        "count": "count",
        "depends_on": "dependsOn",
        "lifecycle": "lifecycle",
        "provider": "provider",
        "name": "name",
        "recovery_fabric_name": "recoveryFabricName",
        "recovery_vault_name": "recoveryVaultName",
        "resource_group_name": "resourceGroupName",
        "timeouts": "timeouts",
    },
)
class SiteRecoveryProtectionContainerConfig(cdktf.TerraformMetaArguments):
    def __init__(
        self,
        *,
        count: typing.Optional[jsii.Number] = None,
        depends_on: typing.Optional[typing.List[cdktf.TerraformResource]] = None,
        lifecycle: typing.Optional[cdktf.TerraformResourceLifecycle] = None,
        provider: typing.Optional[cdktf.TerraformProvider] = None,
        name: builtins.str,
        recovery_fabric_name: builtins.str,
        recovery_vault_name: builtins.str,
        resource_group_name: builtins.str,
        timeouts: typing.Optional["SiteRecoveryProtectionContainerTimeouts"] = None,
    ) -> None:
        """
        :param count: 
        :param depends_on: 
        :param lifecycle: 
        :param provider: 
        :param name: 
        :param recovery_fabric_name: 
        :param recovery_vault_name: 
        :param resource_group_name: 
        :param timeouts: timeouts block.
        """
        if isinstance(lifecycle, dict):
            lifecycle = cdktf.TerraformResourceLifecycle(**lifecycle)
        if isinstance(timeouts, dict):
            timeouts = SiteRecoveryProtectionContainerTimeouts(**timeouts)
        self._values: typing.Dict[str, typing.Any] = {
            "name": name,
            "recovery_fabric_name": recovery_fabric_name,
            "recovery_vault_name": recovery_vault_name,
            "resource_group_name": resource_group_name,
        }
        if count is not None:
            self._values["count"] = count
        if depends_on is not None:
            self._values["depends_on"] = depends_on
        if lifecycle is not None:
            self._values["lifecycle"] = lifecycle
        if provider is not None:
            self._values["provider"] = provider
        if timeouts is not None:
            self._values["timeouts"] = timeouts

    @builtins.property
    def count(self) -> typing.Optional[jsii.Number]:
        """
        :stability: experimental
        """
        result = self._values.get("count")
        return result

    @builtins.property
    def depends_on(self) -> typing.Optional[typing.List[cdktf.TerraformResource]]:
        """
        :stability: experimental
        """
        result = self._values.get("depends_on")
        return result

    @builtins.property
    def lifecycle(self) -> typing.Optional[cdktf.TerraformResourceLifecycle]:
        """
        :stability: experimental
        """
        result = self._values.get("lifecycle")
        return result

    @builtins.property
    def provider(self) -> typing.Optional[cdktf.TerraformProvider]:
        """
        :stability: experimental
        """
        result = self._values.get("provider")
        return result

    @builtins.property
    def name(self) -> builtins.str:
        result = self._values.get("name")
        assert result is not None, "Required property 'name' is missing"
        return result

    @builtins.property
    def recovery_fabric_name(self) -> builtins.str:
        result = self._values.get("recovery_fabric_name")
        assert result is not None, "Required property 'recovery_fabric_name' is missing"
        return result

    @builtins.property
    def recovery_vault_name(self) -> builtins.str:
        result = self._values.get("recovery_vault_name")
        assert result is not None, "Required property 'recovery_vault_name' is missing"
        return result

    @builtins.property
    def resource_group_name(self) -> builtins.str:
        result = self._values.get("resource_group_name")
        assert result is not None, "Required property 'resource_group_name' is missing"
        return result

    @builtins.property
    def timeouts(self) -> typing.Optional["SiteRecoveryProtectionContainerTimeouts"]:
        """timeouts block."""
        result = self._values.get("timeouts")
        return result

    def __eq__(self, rhs: typing.Any) -> builtins.bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs: typing.Any) -> builtins.bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return "SiteRecoveryProtectionContainerConfig(%s)" % ", ".join(
            k + "=" + repr(v) for k, v in self._values.items()
        )


class SiteRecoveryProtectionContainerMapping(
    cdktf.TerraformResource,
    metaclass=jsii.JSIIMeta,
    jsii_type="@cdktf/provider-azurerm.SiteRecoveryProtectionContainerMapping",
):
    def __init__(
        self,
        scope: constructs.Construct,
        id: builtins.str,
        *,
        name: builtins.str,
        recovery_fabric_name: builtins.str,
        recovery_replication_policy_id: builtins.str,
        recovery_source_protection_container_name: builtins.str,
        recovery_target_protection_container_id: builtins.str,
        recovery_vault_name: builtins.str,
        resource_group_name: builtins.str,
        timeouts: typing.Optional["SiteRecoveryProtectionContainerMappingTimeouts"] = None,
        count: typing.Optional[jsii.Number] = None,
        depends_on: typing.Optional[typing.List[cdktf.TerraformResource]] = None,
        lifecycle: typing.Optional[cdktf.TerraformResourceLifecycle] = None,
        provider: typing.Optional[cdktf.TerraformProvider] = None,
    ) -> None:
        """
        :param scope: -
        :param id: -
        :param name: 
        :param recovery_fabric_name: 
        :param recovery_replication_policy_id: 
        :param recovery_source_protection_container_name: 
        :param recovery_target_protection_container_id: 
        :param recovery_vault_name: 
        :param resource_group_name: 
        :param timeouts: timeouts block.
        :param count: 
        :param depends_on: 
        :param lifecycle: 
        :param provider: 
        """
        config = SiteRecoveryProtectionContainerMappingConfig(
            name=name,
            recovery_fabric_name=recovery_fabric_name,
            recovery_replication_policy_id=recovery_replication_policy_id,
            recovery_source_protection_container_name=recovery_source_protection_container_name,
            recovery_target_protection_container_id=recovery_target_protection_container_id,
            recovery_vault_name=recovery_vault_name,
            resource_group_name=resource_group_name,
            timeouts=timeouts,
            count=count,
            depends_on=depends_on,
            lifecycle=lifecycle,
            provider=provider,
        )

        jsii.create(SiteRecoveryProtectionContainerMapping, self, [scope, id, config])

    @jsii.member(jsii_name="synthesizeAttributes")
    def _synthesize_attributes(self) -> typing.Mapping[builtins.str, typing.Any]:
        return jsii.invoke(self, "synthesizeAttributes", [])

    @builtins.property # type: ignore
    @jsii.member(jsii_name="name")
    def name(self) -> builtins.str:
        return jsii.get(self, "name")

    @name.setter # type: ignore
    def name(self, value: builtins.str) -> None:
        jsii.set(self, "name", value)

    @builtins.property # type: ignore
    @jsii.member(jsii_name="recoveryFabricName")
    def recovery_fabric_name(self) -> builtins.str:
        return jsii.get(self, "recoveryFabricName")

    @recovery_fabric_name.setter # type: ignore
    def recovery_fabric_name(self, value: builtins.str) -> None:
        jsii.set(self, "recoveryFabricName", value)

    @builtins.property # type: ignore
    @jsii.member(jsii_name="recoveryReplicationPolicyId")
    def recovery_replication_policy_id(self) -> builtins.str:
        return jsii.get(self, "recoveryReplicationPolicyId")

    @recovery_replication_policy_id.setter # type: ignore
    def recovery_replication_policy_id(self, value: builtins.str) -> None:
        jsii.set(self, "recoveryReplicationPolicyId", value)

    @builtins.property # type: ignore
    @jsii.member(jsii_name="recoverySourceProtectionContainerName")
    def recovery_source_protection_container_name(self) -> builtins.str:
        return jsii.get(self, "recoverySourceProtectionContainerName")

    @recovery_source_protection_container_name.setter # type: ignore
    def recovery_source_protection_container_name(self, value: builtins.str) -> None:
        jsii.set(self, "recoverySourceProtectionContainerName", value)

    @builtins.property # type: ignore
    @jsii.member(jsii_name="recoveryTargetProtectionContainerId")
    def recovery_target_protection_container_id(self) -> builtins.str:
        return jsii.get(self, "recoveryTargetProtectionContainerId")

    @recovery_target_protection_container_id.setter # type: ignore
    def recovery_target_protection_container_id(self, value: builtins.str) -> None:
        jsii.set(self, "recoveryTargetProtectionContainerId", value)

    @builtins.property # type: ignore
    @jsii.member(jsii_name="recoveryVaultName")
    def recovery_vault_name(self) -> builtins.str:
        return jsii.get(self, "recoveryVaultName")

    @recovery_vault_name.setter # type: ignore
    def recovery_vault_name(self, value: builtins.str) -> None:
        jsii.set(self, "recoveryVaultName", value)

    @builtins.property # type: ignore
    @jsii.member(jsii_name="resourceGroupName")
    def resource_group_name(self) -> builtins.str:
        return jsii.get(self, "resourceGroupName")

    @resource_group_name.setter # type: ignore
    def resource_group_name(self, value: builtins.str) -> None:
        jsii.set(self, "resourceGroupName", value)

    @builtins.property # type: ignore
    @jsii.member(jsii_name="id")
    def id(self) -> typing.Optional[builtins.str]:
        return jsii.get(self, "id")

    @id.setter # type: ignore
    def id(self, value: typing.Optional[builtins.str]) -> None:
        jsii.set(self, "id", value)

    @builtins.property # type: ignore
    @jsii.member(jsii_name="timeouts")
    def timeouts(
        self,
    ) -> typing.Optional["SiteRecoveryProtectionContainerMappingTimeouts"]:
        return jsii.get(self, "timeouts")

    @timeouts.setter # type: ignore
    def timeouts(
        self,
        value: typing.Optional["SiteRecoveryProtectionContainerMappingTimeouts"],
    ) -> None:
        jsii.set(self, "timeouts", value)


@jsii.data_type(
    jsii_type="@cdktf/provider-azurerm.SiteRecoveryProtectionContainerMappingConfig",
    jsii_struct_bases=[cdktf.TerraformMetaArguments],
    name_mapping={
        "count": "count",
        "depends_on": "dependsOn",
        "lifecycle": "lifecycle",
        "provider": "provider",
        "name": "name",
        "recovery_fabric_name": "recoveryFabricName",
        "recovery_replication_policy_id": "recoveryReplicationPolicyId",
        "recovery_source_protection_container_name": "recoverySourceProtectionContainerName",
        "recovery_target_protection_container_id": "recoveryTargetProtectionContainerId",
        "recovery_vault_name": "recoveryVaultName",
        "resource_group_name": "resourceGroupName",
        "timeouts": "timeouts",
    },
)
class SiteRecoveryProtectionContainerMappingConfig(cdktf.TerraformMetaArguments):
    def __init__(
        self,
        *,
        count: typing.Optional[jsii.Number] = None,
        depends_on: typing.Optional[typing.List[cdktf.TerraformResource]] = None,
        lifecycle: typing.Optional[cdktf.TerraformResourceLifecycle] = None,
        provider: typing.Optional[cdktf.TerraformProvider] = None,
        name: builtins.str,
        recovery_fabric_name: builtins.str,
        recovery_replication_policy_id: builtins.str,
        recovery_source_protection_container_name: builtins.str,
        recovery_target_protection_container_id: builtins.str,
        recovery_vault_name: builtins.str,
        resource_group_name: builtins.str,
        timeouts: typing.Optional["SiteRecoveryProtectionContainerMappingTimeouts"] = None,
    ) -> None:
        """
        :param count: 
        :param depends_on: 
        :param lifecycle: 
        :param provider: 
        :param name: 
        :param recovery_fabric_name: 
        :param recovery_replication_policy_id: 
        :param recovery_source_protection_container_name: 
        :param recovery_target_protection_container_id: 
        :param recovery_vault_name: 
        :param resource_group_name: 
        :param timeouts: timeouts block.
        """
        if isinstance(lifecycle, dict):
            lifecycle = cdktf.TerraformResourceLifecycle(**lifecycle)
        if isinstance(timeouts, dict):
            timeouts = SiteRecoveryProtectionContainerMappingTimeouts(**timeouts)
        self._values: typing.Dict[str, typing.Any] = {
            "name": name,
            "recovery_fabric_name": recovery_fabric_name,
            "recovery_replication_policy_id": recovery_replication_policy_id,
            "recovery_source_protection_container_name": recovery_source_protection_container_name,
            "recovery_target_protection_container_id": recovery_target_protection_container_id,
            "recovery_vault_name": recovery_vault_name,
            "resource_group_name": resource_group_name,
        }
        if count is not None:
            self._values["count"] = count
        if depends_on is not None:
            self._values["depends_on"] = depends_on
        if lifecycle is not None:
            self._values["lifecycle"] = lifecycle
        if provider is not None:
            self._values["provider"] = provider
        if timeouts is not None:
            self._values["timeouts"] = timeouts

    @builtins.property
    def count(self) -> typing.Optional[jsii.Number]:
        """
        :stability: experimental
        """
        result = self._values.get("count")
        return result

    @builtins.property
    def depends_on(self) -> typing.Optional[typing.List[cdktf.TerraformResource]]:
        """
        :stability: experimental
        """
        result = self._values.get("depends_on")
        return result

    @builtins.property
    def lifecycle(self) -> typing.Optional[cdktf.TerraformResourceLifecycle]:
        """
        :stability: experimental
        """
        result = self._values.get("lifecycle")
        return result

    @builtins.property
    def provider(self) -> typing.Optional[cdktf.TerraformProvider]:
        """
        :stability: experimental
        """
        result = self._values.get("provider")
        return result

    @builtins.property
    def name(self) -> builtins.str:
        result = self._values.get("name")
        assert result is not None, "Required property 'name' is missing"
        return result

    @builtins.property
    def recovery_fabric_name(self) -> builtins.str:
        result = self._values.get("recovery_fabric_name")
        assert result is not None, "Required property 'recovery_fabric_name' is missing"
        return result

    @builtins.property
    def recovery_replication_policy_id(self) -> builtins.str:
        result = self._values.get("recovery_replication_policy_id")
        assert result is not None, "Required property 'recovery_replication_policy_id' is missing"
        return result

    @builtins.property
    def recovery_source_protection_container_name(self) -> builtins.str:
        result = self._values.get("recovery_source_protection_container_name")
        assert result is not None, "Required property 'recovery_source_protection_container_name' is missing"
        return result

    @builtins.property
    def recovery_target_protection_container_id(self) -> builtins.str:
        result = self._values.get("recovery_target_protection_container_id")
        assert result is not None, "Required property 'recovery_target_protection_container_id' is missing"
        return result

    @builtins.property
    def recovery_vault_name(self) -> builtins.str:
        result = self._values.get("recovery_vault_name")
        assert result is not None, "Required property 'recovery_vault_name' is missing"
        return result

    @builtins.property
    def resource_group_name(self) -> builtins.str:
        result = self._values.get("resource_group_name")
        assert result is not None, "Required property 'resource_group_name' is missing"
        return result

    @builtins.property
    def timeouts(
        self,
    ) -> typing.Optional["SiteRecoveryProtectionContainerMappingTimeouts"]:
        """timeouts block."""
        result = self._values.get("timeouts")
        return result

    def __eq__(self, rhs: typing.Any) -> builtins.bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs: typing.Any) -> builtins.bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return "SiteRecoveryProtectionContainerMappingConfig(%s)" % ", ".join(
            k + "=" + repr(v) for k, v in self._values.items()
        )


@jsii.data_type(
    jsii_type="@cdktf/provider-azurerm.SiteRecoveryProtectionContainerMappingTimeouts",
    jsii_struct_bases=[],
    name_mapping={
        "create": "create",
        "delete": "delete",
        "read": "read",
        "update": "update",
    },
)
class SiteRecoveryProtectionContainerMappingTimeouts:
    def __init__(
        self,
        *,
        create: typing.Optional[builtins.str] = None,
        delete: typing.Optional[builtins.str] = None,
        read: typing.Optional[builtins.str] = None,
        update: typing.Optional[builtins.str] = None,
    ) -> None:
        """
        :param create: 
        :param delete: 
        :param read: 
        :param update: 
        """
        self._values: typing.Dict[str, typing.Any] = {}
        if create is not None:
            self._values["create"] = create
        if delete is not None:
            self._values["delete"] = delete
        if read is not None:
            self._values["read"] = read
        if update is not None:
            self._values["update"] = update

    @builtins.property
    def create(self) -> typing.Optional[builtins.str]:
        result = self._values.get("create")
        return result

    @builtins.property
    def delete(self) -> typing.Optional[builtins.str]:
        result = self._values.get("delete")
        return result

    @builtins.property
    def read(self) -> typing.Optional[builtins.str]:
        result = self._values.get("read")
        return result

    @builtins.property
    def update(self) -> typing.Optional[builtins.str]:
        result = self._values.get("update")
        return result

    def __eq__(self, rhs: typing.Any) -> builtins.bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs: typing.Any) -> builtins.bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return "SiteRecoveryProtectionContainerMappingTimeouts(%s)" % ", ".join(
            k + "=" + repr(v) for k, v in self._values.items()
        )


@jsii.data_type(
    jsii_type="@cdktf/provider-azurerm.SiteRecoveryProtectionContainerTimeouts",
    jsii_struct_bases=[],
    name_mapping={
        "create": "create",
        "delete": "delete",
        "read": "read",
        "update": "update",
    },
)
class SiteRecoveryProtectionContainerTimeouts:
    def __init__(
        self,
        *,
        create: typing.Optional[builtins.str] = None,
        delete: typing.Optional[builtins.str] = None,
        read: typing.Optional[builtins.str] = None,
        update: typing.Optional[builtins.str] = None,
    ) -> None:
        """
        :param create: 
        :param delete: 
        :param read: 
        :param update: 
        """
        self._values: typing.Dict[str, typing.Any] = {}
        if create is not None:
            self._values["create"] = create
        if delete is not None:
            self._values["delete"] = delete
        if read is not None:
            self._values["read"] = read
        if update is not None:
            self._values["update"] = update

    @builtins.property
    def create(self) -> typing.Optional[builtins.str]:
        result = self._values.get("create")
        return result

    @builtins.property
    def delete(self) -> typing.Optional[builtins.str]:
        result = self._values.get("delete")
        return result

    @builtins.property
    def read(self) -> typing.Optional[builtins.str]:
        result = self._values.get("read")
        return result

    @builtins.property
    def update(self) -> typing.Optional[builtins.str]:
        result = self._values.get("update")
        return result

    def __eq__(self, rhs: typing.Any) -> builtins.bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs: typing.Any) -> builtins.bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return "SiteRecoveryProtectionContainerTimeouts(%s)" % ", ".join(
            k + "=" + repr(v) for k, v in self._values.items()
        )


class SiteRecoveryReplicatedVm(
    cdktf.TerraformResource,
    metaclass=jsii.JSIIMeta,
    jsii_type="@cdktf/provider-azurerm.SiteRecoveryReplicatedVm",
):
    def __init__(
        self,
        scope: constructs.Construct,
        id: builtins.str,
        *,
        name: builtins.str,
        recovery_replication_policy_id: builtins.str,
        recovery_vault_name: builtins.str,
        resource_group_name: builtins.str,
        source_recovery_fabric_name: builtins.str,
        source_recovery_protection_container_name: builtins.str,
        source_vm_id: builtins.str,
        target_recovery_fabric_id: builtins.str,
        target_recovery_protection_container_id: builtins.str,
        target_resource_group_id: builtins.str,
        managed_disk: typing.Optional[typing.List["SiteRecoveryReplicatedVmManagedDisk"]] = None,
        target_availability_set_id: typing.Optional[builtins.str] = None,
        timeouts: typing.Optional["SiteRecoveryReplicatedVmTimeouts"] = None,
        count: typing.Optional[jsii.Number] = None,
        depends_on: typing.Optional[typing.List[cdktf.TerraformResource]] = None,
        lifecycle: typing.Optional[cdktf.TerraformResourceLifecycle] = None,
        provider: typing.Optional[cdktf.TerraformProvider] = None,
    ) -> None:
        """
        :param scope: -
        :param id: -
        :param name: 
        :param recovery_replication_policy_id: 
        :param recovery_vault_name: 
        :param resource_group_name: 
        :param source_recovery_fabric_name: 
        :param source_recovery_protection_container_name: 
        :param source_vm_id: 
        :param target_recovery_fabric_id: 
        :param target_recovery_protection_container_id: 
        :param target_resource_group_id: 
        :param managed_disk: 
        :param target_availability_set_id: 
        :param timeouts: timeouts block.
        :param count: 
        :param depends_on: 
        :param lifecycle: 
        :param provider: 
        """
        config = SiteRecoveryReplicatedVmConfig(
            name=name,
            recovery_replication_policy_id=recovery_replication_policy_id,
            recovery_vault_name=recovery_vault_name,
            resource_group_name=resource_group_name,
            source_recovery_fabric_name=source_recovery_fabric_name,
            source_recovery_protection_container_name=source_recovery_protection_container_name,
            source_vm_id=source_vm_id,
            target_recovery_fabric_id=target_recovery_fabric_id,
            target_recovery_protection_container_id=target_recovery_protection_container_id,
            target_resource_group_id=target_resource_group_id,
            managed_disk=managed_disk,
            target_availability_set_id=target_availability_set_id,
            timeouts=timeouts,
            count=count,
            depends_on=depends_on,
            lifecycle=lifecycle,
            provider=provider,
        )

        jsii.create(SiteRecoveryReplicatedVm, self, [scope, id, config])

    @jsii.member(jsii_name="synthesizeAttributes")
    def _synthesize_attributes(self) -> typing.Mapping[builtins.str, typing.Any]:
        return jsii.invoke(self, "synthesizeAttributes", [])

    @builtins.property # type: ignore
    @jsii.member(jsii_name="name")
    def name(self) -> builtins.str:
        return jsii.get(self, "name")

    @name.setter # type: ignore
    def name(self, value: builtins.str) -> None:
        jsii.set(self, "name", value)

    @builtins.property # type: ignore
    @jsii.member(jsii_name="recoveryReplicationPolicyId")
    def recovery_replication_policy_id(self) -> builtins.str:
        return jsii.get(self, "recoveryReplicationPolicyId")

    @recovery_replication_policy_id.setter # type: ignore
    def recovery_replication_policy_id(self, value: builtins.str) -> None:
        jsii.set(self, "recoveryReplicationPolicyId", value)

    @builtins.property # type: ignore
    @jsii.member(jsii_name="recoveryVaultName")
    def recovery_vault_name(self) -> builtins.str:
        return jsii.get(self, "recoveryVaultName")

    @recovery_vault_name.setter # type: ignore
    def recovery_vault_name(self, value: builtins.str) -> None:
        jsii.set(self, "recoveryVaultName", value)

    @builtins.property # type: ignore
    @jsii.member(jsii_name="resourceGroupName")
    def resource_group_name(self) -> builtins.str:
        return jsii.get(self, "resourceGroupName")

    @resource_group_name.setter # type: ignore
    def resource_group_name(self, value: builtins.str) -> None:
        jsii.set(self, "resourceGroupName", value)

    @builtins.property # type: ignore
    @jsii.member(jsii_name="sourceRecoveryFabricName")
    def source_recovery_fabric_name(self) -> builtins.str:
        return jsii.get(self, "sourceRecoveryFabricName")

    @source_recovery_fabric_name.setter # type: ignore
    def source_recovery_fabric_name(self, value: builtins.str) -> None:
        jsii.set(self, "sourceRecoveryFabricName", value)

    @builtins.property # type: ignore
    @jsii.member(jsii_name="sourceRecoveryProtectionContainerName")
    def source_recovery_protection_container_name(self) -> builtins.str:
        return jsii.get(self, "sourceRecoveryProtectionContainerName")

    @source_recovery_protection_container_name.setter # type: ignore
    def source_recovery_protection_container_name(self, value: builtins.str) -> None:
        jsii.set(self, "sourceRecoveryProtectionContainerName", value)

    @builtins.property # type: ignore
    @jsii.member(jsii_name="sourceVmId")
    def source_vm_id(self) -> builtins.str:
        return jsii.get(self, "sourceVmId")

    @source_vm_id.setter # type: ignore
    def source_vm_id(self, value: builtins.str) -> None:
        jsii.set(self, "sourceVmId", value)

    @builtins.property # type: ignore
    @jsii.member(jsii_name="targetRecoveryFabricId")
    def target_recovery_fabric_id(self) -> builtins.str:
        return jsii.get(self, "targetRecoveryFabricId")

    @target_recovery_fabric_id.setter # type: ignore
    def target_recovery_fabric_id(self, value: builtins.str) -> None:
        jsii.set(self, "targetRecoveryFabricId", value)

    @builtins.property # type: ignore
    @jsii.member(jsii_name="targetRecoveryProtectionContainerId")
    def target_recovery_protection_container_id(self) -> builtins.str:
        return jsii.get(self, "targetRecoveryProtectionContainerId")

    @target_recovery_protection_container_id.setter # type: ignore
    def target_recovery_protection_container_id(self, value: builtins.str) -> None:
        jsii.set(self, "targetRecoveryProtectionContainerId", value)

    @builtins.property # type: ignore
    @jsii.member(jsii_name="targetResourceGroupId")
    def target_resource_group_id(self) -> builtins.str:
        return jsii.get(self, "targetResourceGroupId")

    @target_resource_group_id.setter # type: ignore
    def target_resource_group_id(self, value: builtins.str) -> None:
        jsii.set(self, "targetResourceGroupId", value)

    @builtins.property # type: ignore
    @jsii.member(jsii_name="id")
    def id(self) -> typing.Optional[builtins.str]:
        return jsii.get(self, "id")

    @id.setter # type: ignore
    def id(self, value: typing.Optional[builtins.str]) -> None:
        jsii.set(self, "id", value)

    @builtins.property # type: ignore
    @jsii.member(jsii_name="managedDisk")
    def managed_disk(
        self,
    ) -> typing.Optional[typing.List["SiteRecoveryReplicatedVmManagedDisk"]]:
        return jsii.get(self, "managedDisk")

    @managed_disk.setter # type: ignore
    def managed_disk(
        self,
        value: typing.Optional[typing.List["SiteRecoveryReplicatedVmManagedDisk"]],
    ) -> None:
        jsii.set(self, "managedDisk", value)

    @builtins.property # type: ignore
    @jsii.member(jsii_name="targetAvailabilitySetId")
    def target_availability_set_id(self) -> typing.Optional[builtins.str]:
        return jsii.get(self, "targetAvailabilitySetId")

    @target_availability_set_id.setter # type: ignore
    def target_availability_set_id(self, value: typing.Optional[builtins.str]) -> None:
        jsii.set(self, "targetAvailabilitySetId", value)

    @builtins.property # type: ignore
    @jsii.member(jsii_name="timeouts")
    def timeouts(self) -> typing.Optional["SiteRecoveryReplicatedVmTimeouts"]:
        return jsii.get(self, "timeouts")

    @timeouts.setter # type: ignore
    def timeouts(
        self,
        value: typing.Optional["SiteRecoveryReplicatedVmTimeouts"],
    ) -> None:
        jsii.set(self, "timeouts", value)


@jsii.data_type(
    jsii_type="@cdktf/provider-azurerm.SiteRecoveryReplicatedVmConfig",
    jsii_struct_bases=[cdktf.TerraformMetaArguments],
    name_mapping={
        "count": "count",
        "depends_on": "dependsOn",
        "lifecycle": "lifecycle",
        "provider": "provider",
        "name": "name",
        "recovery_replication_policy_id": "recoveryReplicationPolicyId",
        "recovery_vault_name": "recoveryVaultName",
        "resource_group_name": "resourceGroupName",
        "source_recovery_fabric_name": "sourceRecoveryFabricName",
        "source_recovery_protection_container_name": "sourceRecoveryProtectionContainerName",
        "source_vm_id": "sourceVmId",
        "target_recovery_fabric_id": "targetRecoveryFabricId",
        "target_recovery_protection_container_id": "targetRecoveryProtectionContainerId",
        "target_resource_group_id": "targetResourceGroupId",
        "managed_disk": "managedDisk",
        "target_availability_set_id": "targetAvailabilitySetId",
        "timeouts": "timeouts",
    },
)
class SiteRecoveryReplicatedVmConfig(cdktf.TerraformMetaArguments):
    def __init__(
        self,
        *,
        count: typing.Optional[jsii.Number] = None,
        depends_on: typing.Optional[typing.List[cdktf.TerraformResource]] = None,
        lifecycle: typing.Optional[cdktf.TerraformResourceLifecycle] = None,
        provider: typing.Optional[cdktf.TerraformProvider] = None,
        name: builtins.str,
        recovery_replication_policy_id: builtins.str,
        recovery_vault_name: builtins.str,
        resource_group_name: builtins.str,
        source_recovery_fabric_name: builtins.str,
        source_recovery_protection_container_name: builtins.str,
        source_vm_id: builtins.str,
        target_recovery_fabric_id: builtins.str,
        target_recovery_protection_container_id: builtins.str,
        target_resource_group_id: builtins.str,
        managed_disk: typing.Optional[typing.List["SiteRecoveryReplicatedVmManagedDisk"]] = None,
        target_availability_set_id: typing.Optional[builtins.str] = None,
        timeouts: typing.Optional["SiteRecoveryReplicatedVmTimeouts"] = None,
    ) -> None:
        """
        :param count: 
        :param depends_on: 
        :param lifecycle: 
        :param provider: 
        :param name: 
        :param recovery_replication_policy_id: 
        :param recovery_vault_name: 
        :param resource_group_name: 
        :param source_recovery_fabric_name: 
        :param source_recovery_protection_container_name: 
        :param source_vm_id: 
        :param target_recovery_fabric_id: 
        :param target_recovery_protection_container_id: 
        :param target_resource_group_id: 
        :param managed_disk: 
        :param target_availability_set_id: 
        :param timeouts: timeouts block.
        """
        if isinstance(lifecycle, dict):
            lifecycle = cdktf.TerraformResourceLifecycle(**lifecycle)
        if isinstance(timeouts, dict):
            timeouts = SiteRecoveryReplicatedVmTimeouts(**timeouts)
        self._values: typing.Dict[str, typing.Any] = {
            "name": name,
            "recovery_replication_policy_id": recovery_replication_policy_id,
            "recovery_vault_name": recovery_vault_name,
            "resource_group_name": resource_group_name,
            "source_recovery_fabric_name": source_recovery_fabric_name,
            "source_recovery_protection_container_name": source_recovery_protection_container_name,
            "source_vm_id": source_vm_id,
            "target_recovery_fabric_id": target_recovery_fabric_id,
            "target_recovery_protection_container_id": target_recovery_protection_container_id,
            "target_resource_group_id": target_resource_group_id,
        }
        if count is not None:
            self._values["count"] = count
        if depends_on is not None:
            self._values["depends_on"] = depends_on
        if lifecycle is not None:
            self._values["lifecycle"] = lifecycle
        if provider is not None:
            self._values["provider"] = provider
        if managed_disk is not None:
            self._values["managed_disk"] = managed_disk
        if target_availability_set_id is not None:
            self._values["target_availability_set_id"] = target_availability_set_id
        if timeouts is not None:
            self._values["timeouts"] = timeouts

    @builtins.property
    def count(self) -> typing.Optional[jsii.Number]:
        """
        :stability: experimental
        """
        result = self._values.get("count")
        return result

    @builtins.property
    def depends_on(self) -> typing.Optional[typing.List[cdktf.TerraformResource]]:
        """
        :stability: experimental
        """
        result = self._values.get("depends_on")
        return result

    @builtins.property
    def lifecycle(self) -> typing.Optional[cdktf.TerraformResourceLifecycle]:
        """
        :stability: experimental
        """
        result = self._values.get("lifecycle")
        return result

    @builtins.property
    def provider(self) -> typing.Optional[cdktf.TerraformProvider]:
        """
        :stability: experimental
        """
        result = self._values.get("provider")
        return result

    @builtins.property
    def name(self) -> builtins.str:
        result = self._values.get("name")
        assert result is not None, "Required property 'name' is missing"
        return result

    @builtins.property
    def recovery_replication_policy_id(self) -> builtins.str:
        result = self._values.get("recovery_replication_policy_id")
        assert result is not None, "Required property 'recovery_replication_policy_id' is missing"
        return result

    @builtins.property
    def recovery_vault_name(self) -> builtins.str:
        result = self._values.get("recovery_vault_name")
        assert result is not None, "Required property 'recovery_vault_name' is missing"
        return result

    @builtins.property
    def resource_group_name(self) -> builtins.str:
        result = self._values.get("resource_group_name")
        assert result is not None, "Required property 'resource_group_name' is missing"
        return result

    @builtins.property
    def source_recovery_fabric_name(self) -> builtins.str:
        result = self._values.get("source_recovery_fabric_name")
        assert result is not None, "Required property 'source_recovery_fabric_name' is missing"
        return result

    @builtins.property
    def source_recovery_protection_container_name(self) -> builtins.str:
        result = self._values.get("source_recovery_protection_container_name")
        assert result is not None, "Required property 'source_recovery_protection_container_name' is missing"
        return result

    @builtins.property
    def source_vm_id(self) -> builtins.str:
        result = self._values.get("source_vm_id")
        assert result is not None, "Required property 'source_vm_id' is missing"
        return result

    @builtins.property
    def target_recovery_fabric_id(self) -> builtins.str:
        result = self._values.get("target_recovery_fabric_id")
        assert result is not None, "Required property 'target_recovery_fabric_id' is missing"
        return result

    @builtins.property
    def target_recovery_protection_container_id(self) -> builtins.str:
        result = self._values.get("target_recovery_protection_container_id")
        assert result is not None, "Required property 'target_recovery_protection_container_id' is missing"
        return result

    @builtins.property
    def target_resource_group_id(self) -> builtins.str:
        result = self._values.get("target_resource_group_id")
        assert result is not None, "Required property 'target_resource_group_id' is missing"
        return result

    @builtins.property
    def managed_disk(
        self,
    ) -> typing.Optional[typing.List["SiteRecoveryReplicatedVmManagedDisk"]]:
        result = self._values.get("managed_disk")
        return result

    @builtins.property
    def target_availability_set_id(self) -> typing.Optional[builtins.str]:
        result = self._values.get("target_availability_set_id")
        return result

    @builtins.property
    def timeouts(self) -> typing.Optional["SiteRecoveryReplicatedVmTimeouts"]:
        """timeouts block."""
        result = self._values.get("timeouts")
        return result

    def __eq__(self, rhs: typing.Any) -> builtins.bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs: typing.Any) -> builtins.bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return "SiteRecoveryReplicatedVmConfig(%s)" % ", ".join(
            k + "=" + repr(v) for k, v in self._values.items()
        )


@jsii.data_type(
    jsii_type="@cdktf/provider-azurerm.SiteRecoveryReplicatedVmManagedDisk",
    jsii_struct_bases=[],
    name_mapping={
        "disk_id": "diskId",
        "staging_storage_account_id": "stagingStorageAccountId",
        "target_disk_type": "targetDiskType",
        "target_replica_disk_type": "targetReplicaDiskType",
        "target_resource_group_id": "targetResourceGroupId",
    },
)
class SiteRecoveryReplicatedVmManagedDisk:
    def __init__(
        self,
        *,
        disk_id: typing.Optional[builtins.str] = None,
        staging_storage_account_id: typing.Optional[builtins.str] = None,
        target_disk_type: typing.Optional[builtins.str] = None,
        target_replica_disk_type: typing.Optional[builtins.str] = None,
        target_resource_group_id: typing.Optional[builtins.str] = None,
    ) -> None:
        """
        :param disk_id: 
        :param staging_storage_account_id: 
        :param target_disk_type: 
        :param target_replica_disk_type: 
        :param target_resource_group_id: 
        """
        self._values: typing.Dict[str, typing.Any] = {}
        if disk_id is not None:
            self._values["disk_id"] = disk_id
        if staging_storage_account_id is not None:
            self._values["staging_storage_account_id"] = staging_storage_account_id
        if target_disk_type is not None:
            self._values["target_disk_type"] = target_disk_type
        if target_replica_disk_type is not None:
            self._values["target_replica_disk_type"] = target_replica_disk_type
        if target_resource_group_id is not None:
            self._values["target_resource_group_id"] = target_resource_group_id

    @builtins.property
    def disk_id(self) -> typing.Optional[builtins.str]:
        result = self._values.get("disk_id")
        return result

    @builtins.property
    def staging_storage_account_id(self) -> typing.Optional[builtins.str]:
        result = self._values.get("staging_storage_account_id")
        return result

    @builtins.property
    def target_disk_type(self) -> typing.Optional[builtins.str]:
        result = self._values.get("target_disk_type")
        return result

    @builtins.property
    def target_replica_disk_type(self) -> typing.Optional[builtins.str]:
        result = self._values.get("target_replica_disk_type")
        return result

    @builtins.property
    def target_resource_group_id(self) -> typing.Optional[builtins.str]:
        result = self._values.get("target_resource_group_id")
        return result

    def __eq__(self, rhs: typing.Any) -> builtins.bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs: typing.Any) -> builtins.bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return "SiteRecoveryReplicatedVmManagedDisk(%s)" % ", ".join(
            k + "=" + repr(v) for k, v in self._values.items()
        )


@jsii.data_type(
    jsii_type="@cdktf/provider-azurerm.SiteRecoveryReplicatedVmTimeouts",
    jsii_struct_bases=[],
    name_mapping={
        "create": "create",
        "delete": "delete",
        "read": "read",
        "update": "update",
    },
)
class SiteRecoveryReplicatedVmTimeouts:
    def __init__(
        self,
        *,
        create: typing.Optional[builtins.str] = None,
        delete: typing.Optional[builtins.str] = None,
        read: typing.Optional[builtins.str] = None,
        update: typing.Optional[builtins.str] = None,
    ) -> None:
        """
        :param create: 
        :param delete: 
        :param read: 
        :param update: 
        """
        self._values: typing.Dict[str, typing.Any] = {}
        if create is not None:
            self._values["create"] = create
        if delete is not None:
            self._values["delete"] = delete
        if read is not None:
            self._values["read"] = read
        if update is not None:
            self._values["update"] = update

    @builtins.property
    def create(self) -> typing.Optional[builtins.str]:
        result = self._values.get("create")
        return result

    @builtins.property
    def delete(self) -> typing.Optional[builtins.str]:
        result = self._values.get("delete")
        return result

    @builtins.property
    def read(self) -> typing.Optional[builtins.str]:
        result = self._values.get("read")
        return result

    @builtins.property
    def update(self) -> typing.Optional[builtins.str]:
        result = self._values.get("update")
        return result

    def __eq__(self, rhs: typing.Any) -> builtins.bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs: typing.Any) -> builtins.bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return "SiteRecoveryReplicatedVmTimeouts(%s)" % ", ".join(
            k + "=" + repr(v) for k, v in self._values.items()
        )


class SiteRecoveryReplicationPolicy(
    cdktf.TerraformResource,
    metaclass=jsii.JSIIMeta,
    jsii_type="@cdktf/provider-azurerm.SiteRecoveryReplicationPolicy",
):
    def __init__(
        self,
        scope: constructs.Construct,
        id: builtins.str,
        *,
        application_consistent_snapshot_frequency_in_minutes: jsii.Number,
        name: builtins.str,
        recovery_point_retention_in_minutes: jsii.Number,
        recovery_vault_name: builtins.str,
        resource_group_name: builtins.str,
        timeouts: typing.Optional["SiteRecoveryReplicationPolicyTimeouts"] = None,
        count: typing.Optional[jsii.Number] = None,
        depends_on: typing.Optional[typing.List[cdktf.TerraformResource]] = None,
        lifecycle: typing.Optional[cdktf.TerraformResourceLifecycle] = None,
        provider: typing.Optional[cdktf.TerraformProvider] = None,
    ) -> None:
        """
        :param scope: -
        :param id: -
        :param application_consistent_snapshot_frequency_in_minutes: 
        :param name: 
        :param recovery_point_retention_in_minutes: 
        :param recovery_vault_name: 
        :param resource_group_name: 
        :param timeouts: timeouts block.
        :param count: 
        :param depends_on: 
        :param lifecycle: 
        :param provider: 
        """
        config = SiteRecoveryReplicationPolicyConfig(
            application_consistent_snapshot_frequency_in_minutes=application_consistent_snapshot_frequency_in_minutes,
            name=name,
            recovery_point_retention_in_minutes=recovery_point_retention_in_minutes,
            recovery_vault_name=recovery_vault_name,
            resource_group_name=resource_group_name,
            timeouts=timeouts,
            count=count,
            depends_on=depends_on,
            lifecycle=lifecycle,
            provider=provider,
        )

        jsii.create(SiteRecoveryReplicationPolicy, self, [scope, id, config])

    @jsii.member(jsii_name="synthesizeAttributes")
    def _synthesize_attributes(self) -> typing.Mapping[builtins.str, typing.Any]:
        return jsii.invoke(self, "synthesizeAttributes", [])

    @builtins.property # type: ignore
    @jsii.member(jsii_name="applicationConsistentSnapshotFrequencyInMinutes")
    def application_consistent_snapshot_frequency_in_minutes(self) -> jsii.Number:
        return jsii.get(self, "applicationConsistentSnapshotFrequencyInMinutes")

    @application_consistent_snapshot_frequency_in_minutes.setter # type: ignore
    def application_consistent_snapshot_frequency_in_minutes(
        self,
        value: jsii.Number,
    ) -> None:
        jsii.set(self, "applicationConsistentSnapshotFrequencyInMinutes", value)

    @builtins.property # type: ignore
    @jsii.member(jsii_name="name")
    def name(self) -> builtins.str:
        return jsii.get(self, "name")

    @name.setter # type: ignore
    def name(self, value: builtins.str) -> None:
        jsii.set(self, "name", value)

    @builtins.property # type: ignore
    @jsii.member(jsii_name="recoveryPointRetentionInMinutes")
    def recovery_point_retention_in_minutes(self) -> jsii.Number:
        return jsii.get(self, "recoveryPointRetentionInMinutes")

    @recovery_point_retention_in_minutes.setter # type: ignore
    def recovery_point_retention_in_minutes(self, value: jsii.Number) -> None:
        jsii.set(self, "recoveryPointRetentionInMinutes", value)

    @builtins.property # type: ignore
    @jsii.member(jsii_name="recoveryVaultName")
    def recovery_vault_name(self) -> builtins.str:
        return jsii.get(self, "recoveryVaultName")

    @recovery_vault_name.setter # type: ignore
    def recovery_vault_name(self, value: builtins.str) -> None:
        jsii.set(self, "recoveryVaultName", value)

    @builtins.property # type: ignore
    @jsii.member(jsii_name="resourceGroupName")
    def resource_group_name(self) -> builtins.str:
        return jsii.get(self, "resourceGroupName")

    @resource_group_name.setter # type: ignore
    def resource_group_name(self, value: builtins.str) -> None:
        jsii.set(self, "resourceGroupName", value)

    @builtins.property # type: ignore
    @jsii.member(jsii_name="id")
    def id(self) -> typing.Optional[builtins.str]:
        return jsii.get(self, "id")

    @id.setter # type: ignore
    def id(self, value: typing.Optional[builtins.str]) -> None:
        jsii.set(self, "id", value)

    @builtins.property # type: ignore
    @jsii.member(jsii_name="timeouts")
    def timeouts(self) -> typing.Optional["SiteRecoveryReplicationPolicyTimeouts"]:
        return jsii.get(self, "timeouts")

    @timeouts.setter # type: ignore
    def timeouts(
        self,
        value: typing.Optional["SiteRecoveryReplicationPolicyTimeouts"],
    ) -> None:
        jsii.set(self, "timeouts", value)


@jsii.data_type(
    jsii_type="@cdktf/provider-azurerm.SiteRecoveryReplicationPolicyConfig",
    jsii_struct_bases=[cdktf.TerraformMetaArguments],
    name_mapping={
        "count": "count",
        "depends_on": "dependsOn",
        "lifecycle": "lifecycle",
        "provider": "provider",
        "application_consistent_snapshot_frequency_in_minutes": "applicationConsistentSnapshotFrequencyInMinutes",
        "name": "name",
        "recovery_point_retention_in_minutes": "recoveryPointRetentionInMinutes",
        "recovery_vault_name": "recoveryVaultName",
        "resource_group_name": "resourceGroupName",
        "timeouts": "timeouts",
    },
)
class SiteRecoveryReplicationPolicyConfig(cdktf.TerraformMetaArguments):
    def __init__(
        self,
        *,
        count: typing.Optional[jsii.Number] = None,
        depends_on: typing.Optional[typing.List[cdktf.TerraformResource]] = None,
        lifecycle: typing.Optional[cdktf.TerraformResourceLifecycle] = None,
        provider: typing.Optional[cdktf.TerraformProvider] = None,
        application_consistent_snapshot_frequency_in_minutes: jsii.Number,
        name: builtins.str,
        recovery_point_retention_in_minutes: jsii.Number,
        recovery_vault_name: builtins.str,
        resource_group_name: builtins.str,
        timeouts: typing.Optional["SiteRecoveryReplicationPolicyTimeouts"] = None,
    ) -> None:
        """
        :param count: 
        :param depends_on: 
        :param lifecycle: 
        :param provider: 
        :param application_consistent_snapshot_frequency_in_minutes: 
        :param name: 
        :param recovery_point_retention_in_minutes: 
        :param recovery_vault_name: 
        :param resource_group_name: 
        :param timeouts: timeouts block.
        """
        if isinstance(lifecycle, dict):
            lifecycle = cdktf.TerraformResourceLifecycle(**lifecycle)
        if isinstance(timeouts, dict):
            timeouts = SiteRecoveryReplicationPolicyTimeouts(**timeouts)
        self._values: typing.Dict[str, typing.Any] = {
            "application_consistent_snapshot_frequency_in_minutes": application_consistent_snapshot_frequency_in_minutes,
            "name": name,
            "recovery_point_retention_in_minutes": recovery_point_retention_in_minutes,
            "recovery_vault_name": recovery_vault_name,
            "resource_group_name": resource_group_name,
        }
        if count is not None:
            self._values["count"] = count
        if depends_on is not None:
            self._values["depends_on"] = depends_on
        if lifecycle is not None:
            self._values["lifecycle"] = lifecycle
        if provider is not None:
            self._values["provider"] = provider
        if timeouts is not None:
            self._values["timeouts"] = timeouts

    @builtins.property
    def count(self) -> typing.Optional[jsii.Number]:
        """
        :stability: experimental
        """
        result = self._values.get("count")
        return result

    @builtins.property
    def depends_on(self) -> typing.Optional[typing.List[cdktf.TerraformResource]]:
        """
        :stability: experimental
        """
        result = self._values.get("depends_on")
        return result

    @builtins.property
    def lifecycle(self) -> typing.Optional[cdktf.TerraformResourceLifecycle]:
        """
        :stability: experimental
        """
        result = self._values.get("lifecycle")
        return result

    @builtins.property
    def provider(self) -> typing.Optional[cdktf.TerraformProvider]:
        """
        :stability: experimental
        """
        result = self._values.get("provider")
        return result

    @builtins.property
    def application_consistent_snapshot_frequency_in_minutes(self) -> jsii.Number:
        result = self._values.get("application_consistent_snapshot_frequency_in_minutes")
        assert result is not None, "Required property 'application_consistent_snapshot_frequency_in_minutes' is missing"
        return result

    @builtins.property
    def name(self) -> builtins.str:
        result = self._values.get("name")
        assert result is not None, "Required property 'name' is missing"
        return result

    @builtins.property
    def recovery_point_retention_in_minutes(self) -> jsii.Number:
        result = self._values.get("recovery_point_retention_in_minutes")
        assert result is not None, "Required property 'recovery_point_retention_in_minutes' is missing"
        return result

    @builtins.property
    def recovery_vault_name(self) -> builtins.str:
        result = self._values.get("recovery_vault_name")
        assert result is not None, "Required property 'recovery_vault_name' is missing"
        return result

    @builtins.property
    def resource_group_name(self) -> builtins.str:
        result = self._values.get("resource_group_name")
        assert result is not None, "Required property 'resource_group_name' is missing"
        return result

    @builtins.property
    def timeouts(self) -> typing.Optional["SiteRecoveryReplicationPolicyTimeouts"]:
        """timeouts block."""
        result = self._values.get("timeouts")
        return result

    def __eq__(self, rhs: typing.Any) -> builtins.bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs: typing.Any) -> builtins.bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return "SiteRecoveryReplicationPolicyConfig(%s)" % ", ".join(
            k + "=" + repr(v) for k, v in self._values.items()
        )


@jsii.data_type(
    jsii_type="@cdktf/provider-azurerm.SiteRecoveryReplicationPolicyTimeouts",
    jsii_struct_bases=[],
    name_mapping={
        "create": "create",
        "delete": "delete",
        "read": "read",
        "update": "update",
    },
)
class SiteRecoveryReplicationPolicyTimeouts:
    def __init__(
        self,
        *,
        create: typing.Optional[builtins.str] = None,
        delete: typing.Optional[builtins.str] = None,
        read: typing.Optional[builtins.str] = None,
        update: typing.Optional[builtins.str] = None,
    ) -> None:
        """
        :param create: 
        :param delete: 
        :param read: 
        :param update: 
        """
        self._values: typing.Dict[str, typing.Any] = {}
        if create is not None:
            self._values["create"] = create
        if delete is not None:
            self._values["delete"] = delete
        if read is not None:
            self._values["read"] = read
        if update is not None:
            self._values["update"] = update

    @builtins.property
    def create(self) -> typing.Optional[builtins.str]:
        result = self._values.get("create")
        return result

    @builtins.property
    def delete(self) -> typing.Optional[builtins.str]:
        result = self._values.get("delete")
        return result

    @builtins.property
    def read(self) -> typing.Optional[builtins.str]:
        result = self._values.get("read")
        return result

    @builtins.property
    def update(self) -> typing.Optional[builtins.str]:
        result = self._values.get("update")
        return result

    def __eq__(self, rhs: typing.Any) -> builtins.bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs: typing.Any) -> builtins.bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return "SiteRecoveryReplicationPolicyTimeouts(%s)" % ", ".join(
            k + "=" + repr(v) for k, v in self._values.items()
        )


class Snapshot(
    cdktf.TerraformResource,
    metaclass=jsii.JSIIMeta,
    jsii_type="@cdktf/provider-azurerm.Snapshot",
):
    def __init__(
        self,
        scope: constructs.Construct,
        id: builtins.str,
        *,
        create_option: builtins.str,
        location: builtins.str,
        name: builtins.str,
        resource_group_name: builtins.str,
        disk_size_gb: typing.Optional[jsii.Number] = None,
        encryption_settings: typing.Optional[typing.List["SnapshotEncryptionSettings"]] = None,
        source_resource_id: typing.Optional[builtins.str] = None,
        source_uri: typing.Optional[builtins.str] = None,
        storage_account_id: typing.Optional[builtins.str] = None,
        tags: typing.Optional[typing.Mapping[builtins.str, builtins.str]] = None,
        timeouts: typing.Optional["SnapshotTimeouts"] = None,
        count: typing.Optional[jsii.Number] = None,
        depends_on: typing.Optional[typing.List[cdktf.TerraformResource]] = None,
        lifecycle: typing.Optional[cdktf.TerraformResourceLifecycle] = None,
        provider: typing.Optional[cdktf.TerraformProvider] = None,
    ) -> None:
        """
        :param scope: -
        :param id: -
        :param create_option: 
        :param location: 
        :param name: 
        :param resource_group_name: 
        :param disk_size_gb: 
        :param encryption_settings: encryption_settings block.
        :param source_resource_id: 
        :param source_uri: 
        :param storage_account_id: 
        :param tags: 
        :param timeouts: timeouts block.
        :param count: 
        :param depends_on: 
        :param lifecycle: 
        :param provider: 
        """
        config = SnapshotConfig(
            create_option=create_option,
            location=location,
            name=name,
            resource_group_name=resource_group_name,
            disk_size_gb=disk_size_gb,
            encryption_settings=encryption_settings,
            source_resource_id=source_resource_id,
            source_uri=source_uri,
            storage_account_id=storage_account_id,
            tags=tags,
            timeouts=timeouts,
            count=count,
            depends_on=depends_on,
            lifecycle=lifecycle,
            provider=provider,
        )

        jsii.create(Snapshot, self, [scope, id, config])

    @jsii.member(jsii_name="synthesizeAttributes")
    def _synthesize_attributes(self) -> typing.Mapping[builtins.str, typing.Any]:
        return jsii.invoke(self, "synthesizeAttributes", [])

    @builtins.property # type: ignore
    @jsii.member(jsii_name="createOption")
    def create_option(self) -> builtins.str:
        return jsii.get(self, "createOption")

    @create_option.setter # type: ignore
    def create_option(self, value: builtins.str) -> None:
        jsii.set(self, "createOption", value)

    @builtins.property # type: ignore
    @jsii.member(jsii_name="location")
    def location(self) -> builtins.str:
        return jsii.get(self, "location")

    @location.setter # type: ignore
    def location(self, value: builtins.str) -> None:
        jsii.set(self, "location", value)

    @builtins.property # type: ignore
    @jsii.member(jsii_name="name")
    def name(self) -> builtins.str:
        return jsii.get(self, "name")

    @name.setter # type: ignore
    def name(self, value: builtins.str) -> None:
        jsii.set(self, "name", value)

    @builtins.property # type: ignore
    @jsii.member(jsii_name="resourceGroupName")
    def resource_group_name(self) -> builtins.str:
        return jsii.get(self, "resourceGroupName")

    @resource_group_name.setter # type: ignore
    def resource_group_name(self, value: builtins.str) -> None:
        jsii.set(self, "resourceGroupName", value)

    @builtins.property # type: ignore
    @jsii.member(jsii_name="diskSizeGb")
    def disk_size_gb(self) -> typing.Optional[jsii.Number]:
        return jsii.get(self, "diskSizeGb")

    @disk_size_gb.setter # type: ignore
    def disk_size_gb(self, value: typing.Optional[jsii.Number]) -> None:
        jsii.set(self, "diskSizeGb", value)

    @builtins.property # type: ignore
    @jsii.member(jsii_name="encryptionSettings")
    def encryption_settings(
        self,
    ) -> typing.Optional[typing.List["SnapshotEncryptionSettings"]]:
        return jsii.get(self, "encryptionSettings")

    @encryption_settings.setter # type: ignore
    def encryption_settings(
        self,
        value: typing.Optional[typing.List["SnapshotEncryptionSettings"]],
    ) -> None:
        jsii.set(self, "encryptionSettings", value)

    @builtins.property # type: ignore
    @jsii.member(jsii_name="id")
    def id(self) -> typing.Optional[builtins.str]:
        return jsii.get(self, "id")

    @id.setter # type: ignore
    def id(self, value: typing.Optional[builtins.str]) -> None:
        jsii.set(self, "id", value)

    @builtins.property # type: ignore
    @jsii.member(jsii_name="sourceResourceId")
    def source_resource_id(self) -> typing.Optional[builtins.str]:
        return jsii.get(self, "sourceResourceId")

    @source_resource_id.setter # type: ignore
    def source_resource_id(self, value: typing.Optional[builtins.str]) -> None:
        jsii.set(self, "sourceResourceId", value)

    @builtins.property # type: ignore
    @jsii.member(jsii_name="sourceUri")
    def source_uri(self) -> typing.Optional[builtins.str]:
        return jsii.get(self, "sourceUri")

    @source_uri.setter # type: ignore
    def source_uri(self, value: typing.Optional[builtins.str]) -> None:
        jsii.set(self, "sourceUri", value)

    @builtins.property # type: ignore
    @jsii.member(jsii_name="storageAccountId")
    def storage_account_id(self) -> typing.Optional[builtins.str]:
        return jsii.get(self, "storageAccountId")

    @storage_account_id.setter # type: ignore
    def storage_account_id(self, value: typing.Optional[builtins.str]) -> None:
        jsii.set(self, "storageAccountId", value)

    @builtins.property # type: ignore
    @jsii.member(jsii_name="tags")
    def tags(self) -> typing.Optional[typing.Mapping[builtins.str, builtins.str]]:
        return jsii.get(self, "tags")

    @tags.setter # type: ignore
    def tags(
        self,
        value: typing.Optional[typing.Mapping[builtins.str, builtins.str]],
    ) -> None:
        jsii.set(self, "tags", value)

    @builtins.property # type: ignore
    @jsii.member(jsii_name="timeouts")
    def timeouts(self) -> typing.Optional["SnapshotTimeouts"]:
        return jsii.get(self, "timeouts")

    @timeouts.setter # type: ignore
    def timeouts(self, value: typing.Optional["SnapshotTimeouts"]) -> None:
        jsii.set(self, "timeouts", value)


@jsii.data_type(
    jsii_type="@cdktf/provider-azurerm.SnapshotConfig",
    jsii_struct_bases=[cdktf.TerraformMetaArguments],
    name_mapping={
        "count": "count",
        "depends_on": "dependsOn",
        "lifecycle": "lifecycle",
        "provider": "provider",
        "create_option": "createOption",
        "location": "location",
        "name": "name",
        "resource_group_name": "resourceGroupName",
        "disk_size_gb": "diskSizeGb",
        "encryption_settings": "encryptionSettings",
        "source_resource_id": "sourceResourceId",
        "source_uri": "sourceUri",
        "storage_account_id": "storageAccountId",
        "tags": "tags",
        "timeouts": "timeouts",
    },
)
class SnapshotConfig(cdktf.TerraformMetaArguments):
    def __init__(
        self,
        *,
        count: typing.Optional[jsii.Number] = None,
        depends_on: typing.Optional[typing.List[cdktf.TerraformResource]] = None,
        lifecycle: typing.Optional[cdktf.TerraformResourceLifecycle] = None,
        provider: typing.Optional[cdktf.TerraformProvider] = None,
        create_option: builtins.str,
        location: builtins.str,
        name: builtins.str,
        resource_group_name: builtins.str,
        disk_size_gb: typing.Optional[jsii.Number] = None,
        encryption_settings: typing.Optional[typing.List["SnapshotEncryptionSettings"]] = None,
        source_resource_id: typing.Optional[builtins.str] = None,
        source_uri: typing.Optional[builtins.str] = None,
        storage_account_id: typing.Optional[builtins.str] = None,
        tags: typing.Optional[typing.Mapping[builtins.str, builtins.str]] = None,
        timeouts: typing.Optional["SnapshotTimeouts"] = None,
    ) -> None:
        """
        :param count: 
        :param depends_on: 
        :param lifecycle: 
        :param provider: 
        :param create_option: 
        :param location: 
        :param name: 
        :param resource_group_name: 
        :param disk_size_gb: 
        :param encryption_settings: encryption_settings block.
        :param source_resource_id: 
        :param source_uri: 
        :param storage_account_id: 
        :param tags: 
        :param timeouts: timeouts block.
        """
        if isinstance(lifecycle, dict):
            lifecycle = cdktf.TerraformResourceLifecycle(**lifecycle)
        if isinstance(timeouts, dict):
            timeouts = SnapshotTimeouts(**timeouts)
        self._values: typing.Dict[str, typing.Any] = {
            "create_option": create_option,
            "location": location,
            "name": name,
            "resource_group_name": resource_group_name,
        }
        if count is not None:
            self._values["count"] = count
        if depends_on is not None:
            self._values["depends_on"] = depends_on
        if lifecycle is not None:
            self._values["lifecycle"] = lifecycle
        if provider is not None:
            self._values["provider"] = provider
        if disk_size_gb is not None:
            self._values["disk_size_gb"] = disk_size_gb
        if encryption_settings is not None:
            self._values["encryption_settings"] = encryption_settings
        if source_resource_id is not None:
            self._values["source_resource_id"] = source_resource_id
        if source_uri is not None:
            self._values["source_uri"] = source_uri
        if storage_account_id is not None:
            self._values["storage_account_id"] = storage_account_id
        if tags is not None:
            self._values["tags"] = tags
        if timeouts is not None:
            self._values["timeouts"] = timeouts

    @builtins.property
    def count(self) -> typing.Optional[jsii.Number]:
        """
        :stability: experimental
        """
        result = self._values.get("count")
        return result

    @builtins.property
    def depends_on(self) -> typing.Optional[typing.List[cdktf.TerraformResource]]:
        """
        :stability: experimental
        """
        result = self._values.get("depends_on")
        return result

    @builtins.property
    def lifecycle(self) -> typing.Optional[cdktf.TerraformResourceLifecycle]:
        """
        :stability: experimental
        """
        result = self._values.get("lifecycle")
        return result

    @builtins.property
    def provider(self) -> typing.Optional[cdktf.TerraformProvider]:
        """
        :stability: experimental
        """
        result = self._values.get("provider")
        return result

    @builtins.property
    def create_option(self) -> builtins.str:
        result = self._values.get("create_option")
        assert result is not None, "Required property 'create_option' is missing"
        return result

    @builtins.property
    def location(self) -> builtins.str:
        result = self._values.get("location")
        assert result is not None, "Required property 'location' is missing"
        return result

    @builtins.property
    def name(self) -> builtins.str:
        result = self._values.get("name")
        assert result is not None, "Required property 'name' is missing"
        return result

    @builtins.property
    def resource_group_name(self) -> builtins.str:
        result = self._values.get("resource_group_name")
        assert result is not None, "Required property 'resource_group_name' is missing"
        return result

    @builtins.property
    def disk_size_gb(self) -> typing.Optional[jsii.Number]:
        result = self._values.get("disk_size_gb")
        return result

    @builtins.property
    def encryption_settings(
        self,
    ) -> typing.Optional[typing.List["SnapshotEncryptionSettings"]]:
        """encryption_settings block."""
        result = self._values.get("encryption_settings")
        return result

    @builtins.property
    def source_resource_id(self) -> typing.Optional[builtins.str]:
        result = self._values.get("source_resource_id")
        return result

    @builtins.property
    def source_uri(self) -> typing.Optional[builtins.str]:
        result = self._values.get("source_uri")
        return result

    @builtins.property
    def storage_account_id(self) -> typing.Optional[builtins.str]:
        result = self._values.get("storage_account_id")
        return result

    @builtins.property
    def tags(self) -> typing.Optional[typing.Mapping[builtins.str, builtins.str]]:
        result = self._values.get("tags")
        return result

    @builtins.property
    def timeouts(self) -> typing.Optional["SnapshotTimeouts"]:
        """timeouts block."""
        result = self._values.get("timeouts")
        return result

    def __eq__(self, rhs: typing.Any) -> builtins.bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs: typing.Any) -> builtins.bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return "SnapshotConfig(%s)" % ", ".join(
            k + "=" + repr(v) for k, v in self._values.items()
        )


@jsii.data_type(
    jsii_type="@cdktf/provider-azurerm.SnapshotEncryptionSettings",
    jsii_struct_bases=[],
    name_mapping={
        "enabled": "enabled",
        "disk_encryption_key": "diskEncryptionKey",
        "key_encryption_key": "keyEncryptionKey",
    },
)
class SnapshotEncryptionSettings:
    def __init__(
        self,
        *,
        enabled: builtins.bool,
        disk_encryption_key: typing.Optional[typing.List["SnapshotEncryptionSettingsDiskEncryptionKey"]] = None,
        key_encryption_key: typing.Optional[typing.List["SnapshotEncryptionSettingsKeyEncryptionKey"]] = None,
    ) -> None:
        """
        :param enabled: 
        :param disk_encryption_key: disk_encryption_key block.
        :param key_encryption_key: key_encryption_key block.
        """
        self._values: typing.Dict[str, typing.Any] = {
            "enabled": enabled,
        }
        if disk_encryption_key is not None:
            self._values["disk_encryption_key"] = disk_encryption_key
        if key_encryption_key is not None:
            self._values["key_encryption_key"] = key_encryption_key

    @builtins.property
    def enabled(self) -> builtins.bool:
        result = self._values.get("enabled")
        assert result is not None, "Required property 'enabled' is missing"
        return result

    @builtins.property
    def disk_encryption_key(
        self,
    ) -> typing.Optional[typing.List["SnapshotEncryptionSettingsDiskEncryptionKey"]]:
        """disk_encryption_key block."""
        result = self._values.get("disk_encryption_key")
        return result

    @builtins.property
    def key_encryption_key(
        self,
    ) -> typing.Optional[typing.List["SnapshotEncryptionSettingsKeyEncryptionKey"]]:
        """key_encryption_key block."""
        result = self._values.get("key_encryption_key")
        return result

    def __eq__(self, rhs: typing.Any) -> builtins.bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs: typing.Any) -> builtins.bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return "SnapshotEncryptionSettings(%s)" % ", ".join(
            k + "=" + repr(v) for k, v in self._values.items()
        )


@jsii.data_type(
    jsii_type="@cdktf/provider-azurerm.SnapshotEncryptionSettingsDiskEncryptionKey",
    jsii_struct_bases=[],
    name_mapping={"secret_url": "secretUrl", "source_vault_id": "sourceVaultId"},
)
class SnapshotEncryptionSettingsDiskEncryptionKey:
    def __init__(
        self,
        *,
        secret_url: builtins.str,
        source_vault_id: builtins.str,
    ) -> None:
        """
        :param secret_url: 
        :param source_vault_id: 
        """
        self._values: typing.Dict[str, typing.Any] = {
            "secret_url": secret_url,
            "source_vault_id": source_vault_id,
        }

    @builtins.property
    def secret_url(self) -> builtins.str:
        result = self._values.get("secret_url")
        assert result is not None, "Required property 'secret_url' is missing"
        return result

    @builtins.property
    def source_vault_id(self) -> builtins.str:
        result = self._values.get("source_vault_id")
        assert result is not None, "Required property 'source_vault_id' is missing"
        return result

    def __eq__(self, rhs: typing.Any) -> builtins.bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs: typing.Any) -> builtins.bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return "SnapshotEncryptionSettingsDiskEncryptionKey(%s)" % ", ".join(
            k + "=" + repr(v) for k, v in self._values.items()
        )


@jsii.data_type(
    jsii_type="@cdktf/provider-azurerm.SnapshotEncryptionSettingsKeyEncryptionKey",
    jsii_struct_bases=[],
    name_mapping={"key_url": "keyUrl", "source_vault_id": "sourceVaultId"},
)
class SnapshotEncryptionSettingsKeyEncryptionKey:
    def __init__(self, *, key_url: builtins.str, source_vault_id: builtins.str) -> None:
        """
        :param key_url: 
        :param source_vault_id: 
        """
        self._values: typing.Dict[str, typing.Any] = {
            "key_url": key_url,
            "source_vault_id": source_vault_id,
        }

    @builtins.property
    def key_url(self) -> builtins.str:
        result = self._values.get("key_url")
        assert result is not None, "Required property 'key_url' is missing"
        return result

    @builtins.property
    def source_vault_id(self) -> builtins.str:
        result = self._values.get("source_vault_id")
        assert result is not None, "Required property 'source_vault_id' is missing"
        return result

    def __eq__(self, rhs: typing.Any) -> builtins.bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs: typing.Any) -> builtins.bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return "SnapshotEncryptionSettingsKeyEncryptionKey(%s)" % ", ".join(
            k + "=" + repr(v) for k, v in self._values.items()
        )


@jsii.data_type(
    jsii_type="@cdktf/provider-azurerm.SnapshotTimeouts",
    jsii_struct_bases=[],
    name_mapping={
        "create": "create",
        "delete": "delete",
        "read": "read",
        "update": "update",
    },
)
class SnapshotTimeouts:
    def __init__(
        self,
        *,
        create: typing.Optional[builtins.str] = None,
        delete: typing.Optional[builtins.str] = None,
        read: typing.Optional[builtins.str] = None,
        update: typing.Optional[builtins.str] = None,
    ) -> None:
        """
        :param create: 
        :param delete: 
        :param read: 
        :param update: 
        """
        self._values: typing.Dict[str, typing.Any] = {}
        if create is not None:
            self._values["create"] = create
        if delete is not None:
            self._values["delete"] = delete
        if read is not None:
            self._values["read"] = read
        if update is not None:
            self._values["update"] = update

    @builtins.property
    def create(self) -> typing.Optional[builtins.str]:
        result = self._values.get("create")
        return result

    @builtins.property
    def delete(self) -> typing.Optional[builtins.str]:
        result = self._values.get("delete")
        return result

    @builtins.property
    def read(self) -> typing.Optional[builtins.str]:
        result = self._values.get("read")
        return result

    @builtins.property
    def update(self) -> typing.Optional[builtins.str]:
        result = self._values.get("update")
        return result

    def __eq__(self, rhs: typing.Any) -> builtins.bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs: typing.Any) -> builtins.bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return "SnapshotTimeouts(%s)" % ", ".join(
            k + "=" + repr(v) for k, v in self._values.items()
        )


class SqlActiveDirectoryAdministrator(
    cdktf.TerraformResource,
    metaclass=jsii.JSIIMeta,
    jsii_type="@cdktf/provider-azurerm.SqlActiveDirectoryAdministrator",
):
    def __init__(
        self,
        scope: constructs.Construct,
        id: builtins.str,
        *,
        login: builtins.str,
        object_id: builtins.str,
        resource_group_name: builtins.str,
        server_name: builtins.str,
        tenant_id: builtins.str,
        timeouts: typing.Optional["SqlActiveDirectoryAdministratorTimeouts"] = None,
        count: typing.Optional[jsii.Number] = None,
        depends_on: typing.Optional[typing.List[cdktf.TerraformResource]] = None,
        lifecycle: typing.Optional[cdktf.TerraformResourceLifecycle] = None,
        provider: typing.Optional[cdktf.TerraformProvider] = None,
    ) -> None:
        """
        :param scope: -
        :param id: -
        :param login: 
        :param object_id: 
        :param resource_group_name: 
        :param server_name: 
        :param tenant_id: 
        :param timeouts: timeouts block.
        :param count: 
        :param depends_on: 
        :param lifecycle: 
        :param provider: 
        """
        config = SqlActiveDirectoryAdministratorConfig(
            login=login,
            object_id=object_id,
            resource_group_name=resource_group_name,
            server_name=server_name,
            tenant_id=tenant_id,
            timeouts=timeouts,
            count=count,
            depends_on=depends_on,
            lifecycle=lifecycle,
            provider=provider,
        )

        jsii.create(SqlActiveDirectoryAdministrator, self, [scope, id, config])

    @jsii.member(jsii_name="synthesizeAttributes")
    def _synthesize_attributes(self) -> typing.Mapping[builtins.str, typing.Any]:
        return jsii.invoke(self, "synthesizeAttributes", [])

    @builtins.property # type: ignore
    @jsii.member(jsii_name="login")
    def login(self) -> builtins.str:
        return jsii.get(self, "login")

    @login.setter # type: ignore
    def login(self, value: builtins.str) -> None:
        jsii.set(self, "login", value)

    @builtins.property # type: ignore
    @jsii.member(jsii_name="objectId")
    def object_id(self) -> builtins.str:
        return jsii.get(self, "objectId")

    @object_id.setter # type: ignore
    def object_id(self, value: builtins.str) -> None:
        jsii.set(self, "objectId", value)

    @builtins.property # type: ignore
    @jsii.member(jsii_name="resourceGroupName")
    def resource_group_name(self) -> builtins.str:
        return jsii.get(self, "resourceGroupName")

    @resource_group_name.setter # type: ignore
    def resource_group_name(self, value: builtins.str) -> None:
        jsii.set(self, "resourceGroupName", value)

    @builtins.property # type: ignore
    @jsii.member(jsii_name="serverName")
    def server_name(self) -> builtins.str:
        return jsii.get(self, "serverName")

    @server_name.setter # type: ignore
    def server_name(self, value: builtins.str) -> None:
        jsii.set(self, "serverName", value)

    @builtins.property # type: ignore
    @jsii.member(jsii_name="tenantId")
    def tenant_id(self) -> builtins.str:
        return jsii.get(self, "tenantId")

    @tenant_id.setter # type: ignore
    def tenant_id(self, value: builtins.str) -> None:
        jsii.set(self, "tenantId", value)

    @builtins.property # type: ignore
    @jsii.member(jsii_name="id")
    def id(self) -> typing.Optional[builtins.str]:
        return jsii.get(self, "id")

    @id.setter # type: ignore
    def id(self, value: typing.Optional[builtins.str]) -> None:
        jsii.set(self, "id", value)

    @builtins.property # type: ignore
    @jsii.member(jsii_name="timeouts")
    def timeouts(self) -> typing.Optional["SqlActiveDirectoryAdministratorTimeouts"]:
        return jsii.get(self, "timeouts")

    @timeouts.setter # type: ignore
    def timeouts(
        self,
        value: typing.Optional["SqlActiveDirectoryAdministratorTimeouts"],
    ) -> None:
        jsii.set(self, "timeouts", value)


@jsii.data_type(
    jsii_type="@cdktf/provider-azurerm.SqlActiveDirectoryAdministratorConfig",
    jsii_struct_bases=[cdktf.TerraformMetaArguments],
    name_mapping={
        "count": "count",
        "depends_on": "dependsOn",
        "lifecycle": "lifecycle",
        "provider": "provider",
        "login": "login",
        "object_id": "objectId",
        "resource_group_name": "resourceGroupName",
        "server_name": "serverName",
        "tenant_id": "tenantId",
        "timeouts": "timeouts",
    },
)
class SqlActiveDirectoryAdministratorConfig(cdktf.TerraformMetaArguments):
    def __init__(
        self,
        *,
        count: typing.Optional[jsii.Number] = None,
        depends_on: typing.Optional[typing.List[cdktf.TerraformResource]] = None,
        lifecycle: typing.Optional[cdktf.TerraformResourceLifecycle] = None,
        provider: typing.Optional[cdktf.TerraformProvider] = None,
        login: builtins.str,
        object_id: builtins.str,
        resource_group_name: builtins.str,
        server_name: builtins.str,
        tenant_id: builtins.str,
        timeouts: typing.Optional["SqlActiveDirectoryAdministratorTimeouts"] = None,
    ) -> None:
        """
        :param count: 
        :param depends_on: 
        :param lifecycle: 
        :param provider: 
        :param login: 
        :param object_id: 
        :param resource_group_name: 
        :param server_name: 
        :param tenant_id: 
        :param timeouts: timeouts block.
        """
        if isinstance(lifecycle, dict):
            lifecycle = cdktf.TerraformResourceLifecycle(**lifecycle)
        if isinstance(timeouts, dict):
            timeouts = SqlActiveDirectoryAdministratorTimeouts(**timeouts)
        self._values: typing.Dict[str, typing.Any] = {
            "login": login,
            "object_id": object_id,
            "resource_group_name": resource_group_name,
            "server_name": server_name,
            "tenant_id": tenant_id,
        }
        if count is not None:
            self._values["count"] = count
        if depends_on is not None:
            self._values["depends_on"] = depends_on
        if lifecycle is not None:
            self._values["lifecycle"] = lifecycle
        if provider is not None:
            self._values["provider"] = provider
        if timeouts is not None:
            self._values["timeouts"] = timeouts

    @builtins.property
    def count(self) -> typing.Optional[jsii.Number]:
        """
        :stability: experimental
        """
        result = self._values.get("count")
        return result

    @builtins.property
    def depends_on(self) -> typing.Optional[typing.List[cdktf.TerraformResource]]:
        """
        :stability: experimental
        """
        result = self._values.get("depends_on")
        return result

    @builtins.property
    def lifecycle(self) -> typing.Optional[cdktf.TerraformResourceLifecycle]:
        """
        :stability: experimental
        """
        result = self._values.get("lifecycle")
        return result

    @builtins.property
    def provider(self) -> typing.Optional[cdktf.TerraformProvider]:
        """
        :stability: experimental
        """
        result = self._values.get("provider")
        return result

    @builtins.property
    def login(self) -> builtins.str:
        result = self._values.get("login")
        assert result is not None, "Required property 'login' is missing"
        return result

    @builtins.property
    def object_id(self) -> builtins.str:
        result = self._values.get("object_id")
        assert result is not None, "Required property 'object_id' is missing"
        return result

    @builtins.property
    def resource_group_name(self) -> builtins.str:
        result = self._values.get("resource_group_name")
        assert result is not None, "Required property 'resource_group_name' is missing"
        return result

    @builtins.property
    def server_name(self) -> builtins.str:
        result = self._values.get("server_name")
        assert result is not None, "Required property 'server_name' is missing"
        return result

    @builtins.property
    def tenant_id(self) -> builtins.str:
        result = self._values.get("tenant_id")
        assert result is not None, "Required property 'tenant_id' is missing"
        return result

    @builtins.property
    def timeouts(self) -> typing.Optional["SqlActiveDirectoryAdministratorTimeouts"]:
        """timeouts block."""
        result = self._values.get("timeouts")
        return result

    def __eq__(self, rhs: typing.Any) -> builtins.bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs: typing.Any) -> builtins.bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return "SqlActiveDirectoryAdministratorConfig(%s)" % ", ".join(
            k + "=" + repr(v) for k, v in self._values.items()
        )


@jsii.data_type(
    jsii_type="@cdktf/provider-azurerm.SqlActiveDirectoryAdministratorTimeouts",
    jsii_struct_bases=[],
    name_mapping={
        "create": "create",
        "delete": "delete",
        "read": "read",
        "update": "update",
    },
)
class SqlActiveDirectoryAdministratorTimeouts:
    def __init__(
        self,
        *,
        create: typing.Optional[builtins.str] = None,
        delete: typing.Optional[builtins.str] = None,
        read: typing.Optional[builtins.str] = None,
        update: typing.Optional[builtins.str] = None,
    ) -> None:
        """
        :param create: 
        :param delete: 
        :param read: 
        :param update: 
        """
        self._values: typing.Dict[str, typing.Any] = {}
        if create is not None:
            self._values["create"] = create
        if delete is not None:
            self._values["delete"] = delete
        if read is not None:
            self._values["read"] = read
        if update is not None:
            self._values["update"] = update

    @builtins.property
    def create(self) -> typing.Optional[builtins.str]:
        result = self._values.get("create")
        return result

    @builtins.property
    def delete(self) -> typing.Optional[builtins.str]:
        result = self._values.get("delete")
        return result

    @builtins.property
    def read(self) -> typing.Optional[builtins.str]:
        result = self._values.get("read")
        return result

    @builtins.property
    def update(self) -> typing.Optional[builtins.str]:
        result = self._values.get("update")
        return result

    def __eq__(self, rhs: typing.Any) -> builtins.bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs: typing.Any) -> builtins.bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return "SqlActiveDirectoryAdministratorTimeouts(%s)" % ", ".join(
            k + "=" + repr(v) for k, v in self._values.items()
        )


class SqlDatabase(
    cdktf.TerraformResource,
    metaclass=jsii.JSIIMeta,
    jsii_type="@cdktf/provider-azurerm.SqlDatabase",
):
    def __init__(
        self,
        scope: constructs.Construct,
        id: builtins.str,
        *,
        location: builtins.str,
        name: builtins.str,
        resource_group_name: builtins.str,
        server_name: builtins.str,
        collation: typing.Optional[builtins.str] = None,
        create_mode: typing.Optional[builtins.str] = None,
        edition: typing.Optional[builtins.str] = None,
        elastic_pool_name: typing.Optional[builtins.str] = None,
        import_: typing.Optional[typing.List["SqlDatabaseImport"]] = None,
        max_size_bytes: typing.Optional[builtins.str] = None,
        read_scale: typing.Optional[builtins.bool] = None,
        requested_service_objective_id: typing.Optional[builtins.str] = None,
        requested_service_objective_name: typing.Optional[builtins.str] = None,
        restore_point_in_time: typing.Optional[builtins.str] = None,
        source_database_deletion_date: typing.Optional[builtins.str] = None,
        source_database_id: typing.Optional[builtins.str] = None,
        tags: typing.Optional[typing.Mapping[builtins.str, builtins.str]] = None,
        threat_detection_policy: typing.Optional[typing.List["SqlDatabaseThreatDetectionPolicy"]] = None,
        timeouts: typing.Optional["SqlDatabaseTimeouts"] = None,
        zone_redundant: typing.Optional[builtins.bool] = None,
        count: typing.Optional[jsii.Number] = None,
        depends_on: typing.Optional[typing.List[cdktf.TerraformResource]] = None,
        lifecycle: typing.Optional[cdktf.TerraformResourceLifecycle] = None,
        provider: typing.Optional[cdktf.TerraformProvider] = None,
    ) -> None:
        """
        :param scope: -
        :param id: -
        :param location: 
        :param name: 
        :param resource_group_name: 
        :param server_name: 
        :param collation: 
        :param create_mode: 
        :param edition: 
        :param elastic_pool_name: 
        :param import_: import block.
        :param max_size_bytes: 
        :param read_scale: 
        :param requested_service_objective_id: 
        :param requested_service_objective_name: 
        :param restore_point_in_time: 
        :param source_database_deletion_date: 
        :param source_database_id: 
        :param tags: 
        :param threat_detection_policy: threat_detection_policy block.
        :param timeouts: timeouts block.
        :param zone_redundant: 
        :param count: 
        :param depends_on: 
        :param lifecycle: 
        :param provider: 
        """
        config = SqlDatabaseConfig(
            location=location,
            name=name,
            resource_group_name=resource_group_name,
            server_name=server_name,
            collation=collation,
            create_mode=create_mode,
            edition=edition,
            elastic_pool_name=elastic_pool_name,
            import_=import_,
            max_size_bytes=max_size_bytes,
            read_scale=read_scale,
            requested_service_objective_id=requested_service_objective_id,
            requested_service_objective_name=requested_service_objective_name,
            restore_point_in_time=restore_point_in_time,
            source_database_deletion_date=source_database_deletion_date,
            source_database_id=source_database_id,
            tags=tags,
            threat_detection_policy=threat_detection_policy,
            timeouts=timeouts,
            zone_redundant=zone_redundant,
            count=count,
            depends_on=depends_on,
            lifecycle=lifecycle,
            provider=provider,
        )

        jsii.create(SqlDatabase, self, [scope, id, config])

    @jsii.member(jsii_name="synthesizeAttributes")
    def _synthesize_attributes(self) -> typing.Mapping[builtins.str, typing.Any]:
        return jsii.invoke(self, "synthesizeAttributes", [])

    @builtins.property # type: ignore
    @jsii.member(jsii_name="creationDate")
    def creation_date(self) -> builtins.str:
        return jsii.get(self, "creationDate")

    @builtins.property # type: ignore
    @jsii.member(jsii_name="defaultSecondaryLocation")
    def default_secondary_location(self) -> builtins.str:
        return jsii.get(self, "defaultSecondaryLocation")

    @builtins.property # type: ignore
    @jsii.member(jsii_name="encryption")
    def encryption(self) -> builtins.str:
        return jsii.get(self, "encryption")

    @builtins.property # type: ignore
    @jsii.member(jsii_name="location")
    def location(self) -> builtins.str:
        return jsii.get(self, "location")

    @location.setter # type: ignore
    def location(self, value: builtins.str) -> None:
        jsii.set(self, "location", value)

    @builtins.property # type: ignore
    @jsii.member(jsii_name="name")
    def name(self) -> builtins.str:
        return jsii.get(self, "name")

    @name.setter # type: ignore
    def name(self, value: builtins.str) -> None:
        jsii.set(self, "name", value)

    @builtins.property # type: ignore
    @jsii.member(jsii_name="resourceGroupName")
    def resource_group_name(self) -> builtins.str:
        return jsii.get(self, "resourceGroupName")

    @resource_group_name.setter # type: ignore
    def resource_group_name(self, value: builtins.str) -> None:
        jsii.set(self, "resourceGroupName", value)

    @builtins.property # type: ignore
    @jsii.member(jsii_name="serverName")
    def server_name(self) -> builtins.str:
        return jsii.get(self, "serverName")

    @server_name.setter # type: ignore
    def server_name(self, value: builtins.str) -> None:
        jsii.set(self, "serverName", value)

    @builtins.property # type: ignore
    @jsii.member(jsii_name="collation")
    def collation(self) -> typing.Optional[builtins.str]:
        return jsii.get(self, "collation")

    @collation.setter # type: ignore
    def collation(self, value: typing.Optional[builtins.str]) -> None:
        jsii.set(self, "collation", value)

    @builtins.property # type: ignore
    @jsii.member(jsii_name="createMode")
    def create_mode(self) -> typing.Optional[builtins.str]:
        return jsii.get(self, "createMode")

    @create_mode.setter # type: ignore
    def create_mode(self, value: typing.Optional[builtins.str]) -> None:
        jsii.set(self, "createMode", value)

    @builtins.property # type: ignore
    @jsii.member(jsii_name="edition")
    def edition(self) -> typing.Optional[builtins.str]:
        return jsii.get(self, "edition")

    @edition.setter # type: ignore
    def edition(self, value: typing.Optional[builtins.str]) -> None:
        jsii.set(self, "edition", value)

    @builtins.property # type: ignore
    @jsii.member(jsii_name="elasticPoolName")
    def elastic_pool_name(self) -> typing.Optional[builtins.str]:
        return jsii.get(self, "elasticPoolName")

    @elastic_pool_name.setter # type: ignore
    def elastic_pool_name(self, value: typing.Optional[builtins.str]) -> None:
        jsii.set(self, "elasticPoolName", value)

    @builtins.property # type: ignore
    @jsii.member(jsii_name="id")
    def id(self) -> typing.Optional[builtins.str]:
        return jsii.get(self, "id")

    @id.setter # type: ignore
    def id(self, value: typing.Optional[builtins.str]) -> None:
        jsii.set(self, "id", value)

    @builtins.property # type: ignore
    @jsii.member(jsii_name="import")
    def import_(self) -> typing.Optional[typing.List["SqlDatabaseImport"]]:
        return jsii.get(self, "import")

    @import_.setter # type: ignore
    def import_(self, value: typing.Optional[typing.List["SqlDatabaseImport"]]) -> None:
        jsii.set(self, "import", value)

    @builtins.property # type: ignore
    @jsii.member(jsii_name="maxSizeBytes")
    def max_size_bytes(self) -> typing.Optional[builtins.str]:
        return jsii.get(self, "maxSizeBytes")

    @max_size_bytes.setter # type: ignore
    def max_size_bytes(self, value: typing.Optional[builtins.str]) -> None:
        jsii.set(self, "maxSizeBytes", value)

    @builtins.property # type: ignore
    @jsii.member(jsii_name="readScale")
    def read_scale(self) -> typing.Optional[builtins.bool]:
        return jsii.get(self, "readScale")

    @read_scale.setter # type: ignore
    def read_scale(self, value: typing.Optional[builtins.bool]) -> None:
        jsii.set(self, "readScale", value)

    @builtins.property # type: ignore
    @jsii.member(jsii_name="requestedServiceObjectiveId")
    def requested_service_objective_id(self) -> typing.Optional[builtins.str]:
        return jsii.get(self, "requestedServiceObjectiveId")

    @requested_service_objective_id.setter # type: ignore
    def requested_service_objective_id(
        self,
        value: typing.Optional[builtins.str],
    ) -> None:
        jsii.set(self, "requestedServiceObjectiveId", value)

    @builtins.property # type: ignore
    @jsii.member(jsii_name="requestedServiceObjectiveName")
    def requested_service_objective_name(self) -> typing.Optional[builtins.str]:
        return jsii.get(self, "requestedServiceObjectiveName")

    @requested_service_objective_name.setter # type: ignore
    def requested_service_objective_name(
        self,
        value: typing.Optional[builtins.str],
    ) -> None:
        jsii.set(self, "requestedServiceObjectiveName", value)

    @builtins.property # type: ignore
    @jsii.member(jsii_name="restorePointInTime")
    def restore_point_in_time(self) -> typing.Optional[builtins.str]:
        return jsii.get(self, "restorePointInTime")

    @restore_point_in_time.setter # type: ignore
    def restore_point_in_time(self, value: typing.Optional[builtins.str]) -> None:
        jsii.set(self, "restorePointInTime", value)

    @builtins.property # type: ignore
    @jsii.member(jsii_name="sourceDatabaseDeletionDate")
    def source_database_deletion_date(self) -> typing.Optional[builtins.str]:
        return jsii.get(self, "sourceDatabaseDeletionDate")

    @source_database_deletion_date.setter # type: ignore
    def source_database_deletion_date(
        self,
        value: typing.Optional[builtins.str],
    ) -> None:
        jsii.set(self, "sourceDatabaseDeletionDate", value)

    @builtins.property # type: ignore
    @jsii.member(jsii_name="sourceDatabaseId")
    def source_database_id(self) -> typing.Optional[builtins.str]:
        return jsii.get(self, "sourceDatabaseId")

    @source_database_id.setter # type: ignore
    def source_database_id(self, value: typing.Optional[builtins.str]) -> None:
        jsii.set(self, "sourceDatabaseId", value)

    @builtins.property # type: ignore
    @jsii.member(jsii_name="tags")
    def tags(self) -> typing.Optional[typing.Mapping[builtins.str, builtins.str]]:
        return jsii.get(self, "tags")

    @tags.setter # type: ignore
    def tags(
        self,
        value: typing.Optional[typing.Mapping[builtins.str, builtins.str]],
    ) -> None:
        jsii.set(self, "tags", value)

    @builtins.property # type: ignore
    @jsii.member(jsii_name="threatDetectionPolicy")
    def threat_detection_policy(
        self,
    ) -> typing.Optional[typing.List["SqlDatabaseThreatDetectionPolicy"]]:
        return jsii.get(self, "threatDetectionPolicy")

    @threat_detection_policy.setter # type: ignore
    def threat_detection_policy(
        self,
        value: typing.Optional[typing.List["SqlDatabaseThreatDetectionPolicy"]],
    ) -> None:
        jsii.set(self, "threatDetectionPolicy", value)

    @builtins.property # type: ignore
    @jsii.member(jsii_name="timeouts")
    def timeouts(self) -> typing.Optional["SqlDatabaseTimeouts"]:
        return jsii.get(self, "timeouts")

    @timeouts.setter # type: ignore
    def timeouts(self, value: typing.Optional["SqlDatabaseTimeouts"]) -> None:
        jsii.set(self, "timeouts", value)

    @builtins.property # type: ignore
    @jsii.member(jsii_name="zoneRedundant")
    def zone_redundant(self) -> typing.Optional[builtins.bool]:
        return jsii.get(self, "zoneRedundant")

    @zone_redundant.setter # type: ignore
    def zone_redundant(self, value: typing.Optional[builtins.bool]) -> None:
        jsii.set(self, "zoneRedundant", value)


@jsii.data_type(
    jsii_type="@cdktf/provider-azurerm.SqlDatabaseConfig",
    jsii_struct_bases=[cdktf.TerraformMetaArguments],
    name_mapping={
        "count": "count",
        "depends_on": "dependsOn",
        "lifecycle": "lifecycle",
        "provider": "provider",
        "location": "location",
        "name": "name",
        "resource_group_name": "resourceGroupName",
        "server_name": "serverName",
        "collation": "collation",
        "create_mode": "createMode",
        "edition": "edition",
        "elastic_pool_name": "elasticPoolName",
        "import_": "import",
        "max_size_bytes": "maxSizeBytes",
        "read_scale": "readScale",
        "requested_service_objective_id": "requestedServiceObjectiveId",
        "requested_service_objective_name": "requestedServiceObjectiveName",
        "restore_point_in_time": "restorePointInTime",
        "source_database_deletion_date": "sourceDatabaseDeletionDate",
        "source_database_id": "sourceDatabaseId",
        "tags": "tags",
        "threat_detection_policy": "threatDetectionPolicy",
        "timeouts": "timeouts",
        "zone_redundant": "zoneRedundant",
    },
)
class SqlDatabaseConfig(cdktf.TerraformMetaArguments):
    def __init__(
        self,
        *,
        count: typing.Optional[jsii.Number] = None,
        depends_on: typing.Optional[typing.List[cdktf.TerraformResource]] = None,
        lifecycle: typing.Optional[cdktf.TerraformResourceLifecycle] = None,
        provider: typing.Optional[cdktf.TerraformProvider] = None,
        location: builtins.str,
        name: builtins.str,
        resource_group_name: builtins.str,
        server_name: builtins.str,
        collation: typing.Optional[builtins.str] = None,
        create_mode: typing.Optional[builtins.str] = None,
        edition: typing.Optional[builtins.str] = None,
        elastic_pool_name: typing.Optional[builtins.str] = None,
        import_: typing.Optional[typing.List["SqlDatabaseImport"]] = None,
        max_size_bytes: typing.Optional[builtins.str] = None,
        read_scale: typing.Optional[builtins.bool] = None,
        requested_service_objective_id: typing.Optional[builtins.str] = None,
        requested_service_objective_name: typing.Optional[builtins.str] = None,
        restore_point_in_time: typing.Optional[builtins.str] = None,
        source_database_deletion_date: typing.Optional[builtins.str] = None,
        source_database_id: typing.Optional[builtins.str] = None,
        tags: typing.Optional[typing.Mapping[builtins.str, builtins.str]] = None,
        threat_detection_policy: typing.Optional[typing.List["SqlDatabaseThreatDetectionPolicy"]] = None,
        timeouts: typing.Optional["SqlDatabaseTimeouts"] = None,
        zone_redundant: typing.Optional[builtins.bool] = None,
    ) -> None:
        """
        :param count: 
        :param depends_on: 
        :param lifecycle: 
        :param provider: 
        :param location: 
        :param name: 
        :param resource_group_name: 
        :param server_name: 
        :param collation: 
        :param create_mode: 
        :param edition: 
        :param elastic_pool_name: 
        :param import_: import block.
        :param max_size_bytes: 
        :param read_scale: 
        :param requested_service_objective_id: 
        :param requested_service_objective_name: 
        :param restore_point_in_time: 
        :param source_database_deletion_date: 
        :param source_database_id: 
        :param tags: 
        :param threat_detection_policy: threat_detection_policy block.
        :param timeouts: timeouts block.
        :param zone_redundant: 
        """
        if isinstance(lifecycle, dict):
            lifecycle = cdktf.TerraformResourceLifecycle(**lifecycle)
        if isinstance(timeouts, dict):
            timeouts = SqlDatabaseTimeouts(**timeouts)
        self._values: typing.Dict[str, typing.Any] = {
            "location": location,
            "name": name,
            "resource_group_name": resource_group_name,
            "server_name": server_name,
        }
        if count is not None:
            self._values["count"] = count
        if depends_on is not None:
            self._values["depends_on"] = depends_on
        if lifecycle is not None:
            self._values["lifecycle"] = lifecycle
        if provider is not None:
            self._values["provider"] = provider
        if collation is not None:
            self._values["collation"] = collation
        if create_mode is not None:
            self._values["create_mode"] = create_mode
        if edition is not None:
            self._values["edition"] = edition
        if elastic_pool_name is not None:
            self._values["elastic_pool_name"] = elastic_pool_name
        if import_ is not None:
            self._values["import_"] = import_
        if max_size_bytes is not None:
            self._values["max_size_bytes"] = max_size_bytes
        if read_scale is not None:
            self._values["read_scale"] = read_scale
        if requested_service_objective_id is not None:
            self._values["requested_service_objective_id"] = requested_service_objective_id
        if requested_service_objective_name is not None:
            self._values["requested_service_objective_name"] = requested_service_objective_name
        if restore_point_in_time is not None:
            self._values["restore_point_in_time"] = restore_point_in_time
        if source_database_deletion_date is not None:
            self._values["source_database_deletion_date"] = source_database_deletion_date
        if source_database_id is not None:
            self._values["source_database_id"] = source_database_id
        if tags is not None:
            self._values["tags"] = tags
        if threat_detection_policy is not None:
            self._values["threat_detection_policy"] = threat_detection_policy
        if timeouts is not None:
            self._values["timeouts"] = timeouts
        if zone_redundant is not None:
            self._values["zone_redundant"] = zone_redundant

    @builtins.property
    def count(self) -> typing.Optional[jsii.Number]:
        """
        :stability: experimental
        """
        result = self._values.get("count")
        return result

    @builtins.property
    def depends_on(self) -> typing.Optional[typing.List[cdktf.TerraformResource]]:
        """
        :stability: experimental
        """
        result = self._values.get("depends_on")
        return result

    @builtins.property
    def lifecycle(self) -> typing.Optional[cdktf.TerraformResourceLifecycle]:
        """
        :stability: experimental
        """
        result = self._values.get("lifecycle")
        return result

    @builtins.property
    def provider(self) -> typing.Optional[cdktf.TerraformProvider]:
        """
        :stability: experimental
        """
        result = self._values.get("provider")
        return result

    @builtins.property
    def location(self) -> builtins.str:
        result = self._values.get("location")
        assert result is not None, "Required property 'location' is missing"
        return result

    @builtins.property
    def name(self) -> builtins.str:
        result = self._values.get("name")
        assert result is not None, "Required property 'name' is missing"
        return result

    @builtins.property
    def resource_group_name(self) -> builtins.str:
        result = self._values.get("resource_group_name")
        assert result is not None, "Required property 'resource_group_name' is missing"
        return result

    @builtins.property
    def server_name(self) -> builtins.str:
        result = self._values.get("server_name")
        assert result is not None, "Required property 'server_name' is missing"
        return result

    @builtins.property
    def collation(self) -> typing.Optional[builtins.str]:
        result = self._values.get("collation")
        return result

    @builtins.property
    def create_mode(self) -> typing.Optional[builtins.str]:
        result = self._values.get("create_mode")
        return result

    @builtins.property
    def edition(self) -> typing.Optional[builtins.str]:
        result = self._values.get("edition")
        return result

    @builtins.property
    def elastic_pool_name(self) -> typing.Optional[builtins.str]:
        result = self._values.get("elastic_pool_name")
        return result

    @builtins.property
    def import_(self) -> typing.Optional[typing.List["SqlDatabaseImport"]]:
        """import block."""
        result = self._values.get("import_")
        return result

    @builtins.property
    def max_size_bytes(self) -> typing.Optional[builtins.str]:
        result = self._values.get("max_size_bytes")
        return result

    @builtins.property
    def read_scale(self) -> typing.Optional[builtins.bool]:
        result = self._values.get("read_scale")
        return result

    @builtins.property
    def requested_service_objective_id(self) -> typing.Optional[builtins.str]:
        result = self._values.get("requested_service_objective_id")
        return result

    @builtins.property
    def requested_service_objective_name(self) -> typing.Optional[builtins.str]:
        result = self._values.get("requested_service_objective_name")
        return result

    @builtins.property
    def restore_point_in_time(self) -> typing.Optional[builtins.str]:
        result = self._values.get("restore_point_in_time")
        return result

    @builtins.property
    def source_database_deletion_date(self) -> typing.Optional[builtins.str]:
        result = self._values.get("source_database_deletion_date")
        return result

    @builtins.property
    def source_database_id(self) -> typing.Optional[builtins.str]:
        result = self._values.get("source_database_id")
        return result

    @builtins.property
    def tags(self) -> typing.Optional[typing.Mapping[builtins.str, builtins.str]]:
        result = self._values.get("tags")
        return result

    @builtins.property
    def threat_detection_policy(
        self,
    ) -> typing.Optional[typing.List["SqlDatabaseThreatDetectionPolicy"]]:
        """threat_detection_policy block."""
        result = self._values.get("threat_detection_policy")
        return result

    @builtins.property
    def timeouts(self) -> typing.Optional["SqlDatabaseTimeouts"]:
        """timeouts block."""
        result = self._values.get("timeouts")
        return result

    @builtins.property
    def zone_redundant(self) -> typing.Optional[builtins.bool]:
        result = self._values.get("zone_redundant")
        return result

    def __eq__(self, rhs: typing.Any) -> builtins.bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs: typing.Any) -> builtins.bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return "SqlDatabaseConfig(%s)" % ", ".join(
            k + "=" + repr(v) for k, v in self._values.items()
        )


@jsii.data_type(
    jsii_type="@cdktf/provider-azurerm.SqlDatabaseImport",
    jsii_struct_bases=[],
    name_mapping={
        "administrator_login": "administratorLogin",
        "administrator_login_password": "administratorLoginPassword",
        "authentication_type": "authenticationType",
        "storage_key": "storageKey",
        "storage_key_type": "storageKeyType",
        "storage_uri": "storageUri",
        "operation_mode": "operationMode",
    },
)
class SqlDatabaseImport:
    def __init__(
        self,
        *,
        administrator_login: builtins.str,
        administrator_login_password: builtins.str,
        authentication_type: builtins.str,
        storage_key: builtins.str,
        storage_key_type: builtins.str,
        storage_uri: builtins.str,
        operation_mode: typing.Optional[builtins.str] = None,
    ) -> None:
        """
        :param administrator_login: 
        :param administrator_login_password: 
        :param authentication_type: 
        :param storage_key: 
        :param storage_key_type: 
        :param storage_uri: 
        :param operation_mode: 
        """
        self._values: typing.Dict[str, typing.Any] = {
            "administrator_login": administrator_login,
            "administrator_login_password": administrator_login_password,
            "authentication_type": authentication_type,
            "storage_key": storage_key,
            "storage_key_type": storage_key_type,
            "storage_uri": storage_uri,
        }
        if operation_mode is not None:
            self._values["operation_mode"] = operation_mode

    @builtins.property
    def administrator_login(self) -> builtins.str:
        result = self._values.get("administrator_login")
        assert result is not None, "Required property 'administrator_login' is missing"
        return result

    @builtins.property
    def administrator_login_password(self) -> builtins.str:
        result = self._values.get("administrator_login_password")
        assert result is not None, "Required property 'administrator_login_password' is missing"
        return result

    @builtins.property
    def authentication_type(self) -> builtins.str:
        result = self._values.get("authentication_type")
        assert result is not None, "Required property 'authentication_type' is missing"
        return result

    @builtins.property
    def storage_key(self) -> builtins.str:
        result = self._values.get("storage_key")
        assert result is not None, "Required property 'storage_key' is missing"
        return result

    @builtins.property
    def storage_key_type(self) -> builtins.str:
        result = self._values.get("storage_key_type")
        assert result is not None, "Required property 'storage_key_type' is missing"
        return result

    @builtins.property
    def storage_uri(self) -> builtins.str:
        result = self._values.get("storage_uri")
        assert result is not None, "Required property 'storage_uri' is missing"
        return result

    @builtins.property
    def operation_mode(self) -> typing.Optional[builtins.str]:
        result = self._values.get("operation_mode")
        return result

    def __eq__(self, rhs: typing.Any) -> builtins.bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs: typing.Any) -> builtins.bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return "SqlDatabaseImport(%s)" % ", ".join(
            k + "=" + repr(v) for k, v in self._values.items()
        )


@jsii.data_type(
    jsii_type="@cdktf/provider-azurerm.SqlDatabaseThreatDetectionPolicy",
    jsii_struct_bases=[],
    name_mapping={
        "disabled_alerts": "disabledAlerts",
        "email_account_admins": "emailAccountAdmins",
        "email_addresses": "emailAddresses",
        "retention_days": "retentionDays",
        "state": "state",
        "storage_account_access_key": "storageAccountAccessKey",
        "storage_endpoint": "storageEndpoint",
        "use_server_default": "useServerDefault",
    },
)
class SqlDatabaseThreatDetectionPolicy:
    def __init__(
        self,
        *,
        disabled_alerts: typing.Optional[typing.List[builtins.str]] = None,
        email_account_admins: typing.Optional[builtins.str] = None,
        email_addresses: typing.Optional[typing.List[builtins.str]] = None,
        retention_days: typing.Optional[jsii.Number] = None,
        state: typing.Optional[builtins.str] = None,
        storage_account_access_key: typing.Optional[builtins.str] = None,
        storage_endpoint: typing.Optional[builtins.str] = None,
        use_server_default: typing.Optional[builtins.str] = None,
    ) -> None:
        """
        :param disabled_alerts: 
        :param email_account_admins: 
        :param email_addresses: 
        :param retention_days: 
        :param state: 
        :param storage_account_access_key: 
        :param storage_endpoint: 
        :param use_server_default: 
        """
        self._values: typing.Dict[str, typing.Any] = {}
        if disabled_alerts is not None:
            self._values["disabled_alerts"] = disabled_alerts
        if email_account_admins is not None:
            self._values["email_account_admins"] = email_account_admins
        if email_addresses is not None:
            self._values["email_addresses"] = email_addresses
        if retention_days is not None:
            self._values["retention_days"] = retention_days
        if state is not None:
            self._values["state"] = state
        if storage_account_access_key is not None:
            self._values["storage_account_access_key"] = storage_account_access_key
        if storage_endpoint is not None:
            self._values["storage_endpoint"] = storage_endpoint
        if use_server_default is not None:
            self._values["use_server_default"] = use_server_default

    @builtins.property
    def disabled_alerts(self) -> typing.Optional[typing.List[builtins.str]]:
        result = self._values.get("disabled_alerts")
        return result

    @builtins.property
    def email_account_admins(self) -> typing.Optional[builtins.str]:
        result = self._values.get("email_account_admins")
        return result

    @builtins.property
    def email_addresses(self) -> typing.Optional[typing.List[builtins.str]]:
        result = self._values.get("email_addresses")
        return result

    @builtins.property
    def retention_days(self) -> typing.Optional[jsii.Number]:
        result = self._values.get("retention_days")
        return result

    @builtins.property
    def state(self) -> typing.Optional[builtins.str]:
        result = self._values.get("state")
        return result

    @builtins.property
    def storage_account_access_key(self) -> typing.Optional[builtins.str]:
        result = self._values.get("storage_account_access_key")
        return result

    @builtins.property
    def storage_endpoint(self) -> typing.Optional[builtins.str]:
        result = self._values.get("storage_endpoint")
        return result

    @builtins.property
    def use_server_default(self) -> typing.Optional[builtins.str]:
        result = self._values.get("use_server_default")
        return result

    def __eq__(self, rhs: typing.Any) -> builtins.bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs: typing.Any) -> builtins.bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return "SqlDatabaseThreatDetectionPolicy(%s)" % ", ".join(
            k + "=" + repr(v) for k, v in self._values.items()
        )


@jsii.data_type(
    jsii_type="@cdktf/provider-azurerm.SqlDatabaseTimeouts",
    jsii_struct_bases=[],
    name_mapping={
        "create": "create",
        "delete": "delete",
        "read": "read",
        "update": "update",
    },
)
class SqlDatabaseTimeouts:
    def __init__(
        self,
        *,
        create: typing.Optional[builtins.str] = None,
        delete: typing.Optional[builtins.str] = None,
        read: typing.Optional[builtins.str] = None,
        update: typing.Optional[builtins.str] = None,
    ) -> None:
        """
        :param create: 
        :param delete: 
        :param read: 
        :param update: 
        """
        self._values: typing.Dict[str, typing.Any] = {}
        if create is not None:
            self._values["create"] = create
        if delete is not None:
            self._values["delete"] = delete
        if read is not None:
            self._values["read"] = read
        if update is not None:
            self._values["update"] = update

    @builtins.property
    def create(self) -> typing.Optional[builtins.str]:
        result = self._values.get("create")
        return result

    @builtins.property
    def delete(self) -> typing.Optional[builtins.str]:
        result = self._values.get("delete")
        return result

    @builtins.property
    def read(self) -> typing.Optional[builtins.str]:
        result = self._values.get("read")
        return result

    @builtins.property
    def update(self) -> typing.Optional[builtins.str]:
        result = self._values.get("update")
        return result

    def __eq__(self, rhs: typing.Any) -> builtins.bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs: typing.Any) -> builtins.bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return "SqlDatabaseTimeouts(%s)" % ", ".join(
            k + "=" + repr(v) for k, v in self._values.items()
        )


class SqlElasticpool(
    cdktf.TerraformResource,
    metaclass=jsii.JSIIMeta,
    jsii_type="@cdktf/provider-azurerm.SqlElasticpool",
):
    def __init__(
        self,
        scope: constructs.Construct,
        id: builtins.str,
        *,
        dtu: jsii.Number,
        edition: builtins.str,
        location: builtins.str,
        name: builtins.str,
        resource_group_name: builtins.str,
        server_name: builtins.str,
        db_dtu_max: typing.Optional[jsii.Number] = None,
        db_dtu_min: typing.Optional[jsii.Number] = None,
        pool_size: typing.Optional[jsii.Number] = None,
        tags: typing.Optional[typing.Mapping[builtins.str, builtins.str]] = None,
        timeouts: typing.Optional["SqlElasticpoolTimeouts"] = None,
        count: typing.Optional[jsii.Number] = None,
        depends_on: typing.Optional[typing.List[cdktf.TerraformResource]] = None,
        lifecycle: typing.Optional[cdktf.TerraformResourceLifecycle] = None,
        provider: typing.Optional[cdktf.TerraformProvider] = None,
    ) -> None:
        """
        :param scope: -
        :param id: -
        :param dtu: 
        :param edition: 
        :param location: 
        :param name: 
        :param resource_group_name: 
        :param server_name: 
        :param db_dtu_max: 
        :param db_dtu_min: 
        :param pool_size: 
        :param tags: 
        :param timeouts: timeouts block.
        :param count: 
        :param depends_on: 
        :param lifecycle: 
        :param provider: 
        """
        config = SqlElasticpoolConfig(
            dtu=dtu,
            edition=edition,
            location=location,
            name=name,
            resource_group_name=resource_group_name,
            server_name=server_name,
            db_dtu_max=db_dtu_max,
            db_dtu_min=db_dtu_min,
            pool_size=pool_size,
            tags=tags,
            timeouts=timeouts,
            count=count,
            depends_on=depends_on,
            lifecycle=lifecycle,
            provider=provider,
        )

        jsii.create(SqlElasticpool, self, [scope, id, config])

    @jsii.member(jsii_name="synthesizeAttributes")
    def _synthesize_attributes(self) -> typing.Mapping[builtins.str, typing.Any]:
        return jsii.invoke(self, "synthesizeAttributes", [])

    @builtins.property # type: ignore
    @jsii.member(jsii_name="creationDate")
    def creation_date(self) -> builtins.str:
        return jsii.get(self, "creationDate")

    @builtins.property # type: ignore
    @jsii.member(jsii_name="dtu")
    def dtu(self) -> jsii.Number:
        return jsii.get(self, "dtu")

    @dtu.setter # type: ignore
    def dtu(self, value: jsii.Number) -> None:
        jsii.set(self, "dtu", value)

    @builtins.property # type: ignore
    @jsii.member(jsii_name="edition")
    def edition(self) -> builtins.str:
        return jsii.get(self, "edition")

    @edition.setter # type: ignore
    def edition(self, value: builtins.str) -> None:
        jsii.set(self, "edition", value)

    @builtins.property # type: ignore
    @jsii.member(jsii_name="location")
    def location(self) -> builtins.str:
        return jsii.get(self, "location")

    @location.setter # type: ignore
    def location(self, value: builtins.str) -> None:
        jsii.set(self, "location", value)

    @builtins.property # type: ignore
    @jsii.member(jsii_name="name")
    def name(self) -> builtins.str:
        return jsii.get(self, "name")

    @name.setter # type: ignore
    def name(self, value: builtins.str) -> None:
        jsii.set(self, "name", value)

    @builtins.property # type: ignore
    @jsii.member(jsii_name="resourceGroupName")
    def resource_group_name(self) -> builtins.str:
        return jsii.get(self, "resourceGroupName")

    @resource_group_name.setter # type: ignore
    def resource_group_name(self, value: builtins.str) -> None:
        jsii.set(self, "resourceGroupName", value)

    @builtins.property # type: ignore
    @jsii.member(jsii_name="serverName")
    def server_name(self) -> builtins.str:
        return jsii.get(self, "serverName")

    @server_name.setter # type: ignore
    def server_name(self, value: builtins.str) -> None:
        jsii.set(self, "serverName", value)

    @builtins.property # type: ignore
    @jsii.member(jsii_name="dbDtuMax")
    def db_dtu_max(self) -> typing.Optional[jsii.Number]:
        return jsii.get(self, "dbDtuMax")

    @db_dtu_max.setter # type: ignore
    def db_dtu_max(self, value: typing.Optional[jsii.Number]) -> None:
        jsii.set(self, "dbDtuMax", value)

    @builtins.property # type: ignore
    @jsii.member(jsii_name="dbDtuMin")
    def db_dtu_min(self) -> typing.Optional[jsii.Number]:
        return jsii.get(self, "dbDtuMin")

    @db_dtu_min.setter # type: ignore
    def db_dtu_min(self, value: typing.Optional[jsii.Number]) -> None:
        jsii.set(self, "dbDtuMin", value)

    @builtins.property # type: ignore
    @jsii.member(jsii_name="id")
    def id(self) -> typing.Optional[builtins.str]:
        return jsii.get(self, "id")

    @id.setter # type: ignore
    def id(self, value: typing.Optional[builtins.str]) -> None:
        jsii.set(self, "id", value)

    @builtins.property # type: ignore
    @jsii.member(jsii_name="poolSize")
    def pool_size(self) -> typing.Optional[jsii.Number]:
        return jsii.get(self, "poolSize")

    @pool_size.setter # type: ignore
    def pool_size(self, value: typing.Optional[jsii.Number]) -> None:
        jsii.set(self, "poolSize", value)

    @builtins.property # type: ignore
    @jsii.member(jsii_name="tags")
    def tags(self) -> typing.Optional[typing.Mapping[builtins.str, builtins.str]]:
        return jsii.get(self, "tags")

    @tags.setter # type: ignore
    def tags(
        self,
        value: typing.Optional[typing.Mapping[builtins.str, builtins.str]],
    ) -> None:
        jsii.set(self, "tags", value)

    @builtins.property # type: ignore
    @jsii.member(jsii_name="timeouts")
    def timeouts(self) -> typing.Optional["SqlElasticpoolTimeouts"]:
        return jsii.get(self, "timeouts")

    @timeouts.setter # type: ignore
    def timeouts(self, value: typing.Optional["SqlElasticpoolTimeouts"]) -> None:
        jsii.set(self, "timeouts", value)


@jsii.data_type(
    jsii_type="@cdktf/provider-azurerm.SqlElasticpoolConfig",
    jsii_struct_bases=[cdktf.TerraformMetaArguments],
    name_mapping={
        "count": "count",
        "depends_on": "dependsOn",
        "lifecycle": "lifecycle",
        "provider": "provider",
        "dtu": "dtu",
        "edition": "edition",
        "location": "location",
        "name": "name",
        "resource_group_name": "resourceGroupName",
        "server_name": "serverName",
        "db_dtu_max": "dbDtuMax",
        "db_dtu_min": "dbDtuMin",
        "pool_size": "poolSize",
        "tags": "tags",
        "timeouts": "timeouts",
    },
)
class SqlElasticpoolConfig(cdktf.TerraformMetaArguments):
    def __init__(
        self,
        *,
        count: typing.Optional[jsii.Number] = None,
        depends_on: typing.Optional[typing.List[cdktf.TerraformResource]] = None,
        lifecycle: typing.Optional[cdktf.TerraformResourceLifecycle] = None,
        provider: typing.Optional[cdktf.TerraformProvider] = None,
        dtu: jsii.Number,
        edition: builtins.str,
        location: builtins.str,
        name: builtins.str,
        resource_group_name: builtins.str,
        server_name: builtins.str,
        db_dtu_max: typing.Optional[jsii.Number] = None,
        db_dtu_min: typing.Optional[jsii.Number] = None,
        pool_size: typing.Optional[jsii.Number] = None,
        tags: typing.Optional[typing.Mapping[builtins.str, builtins.str]] = None,
        timeouts: typing.Optional["SqlElasticpoolTimeouts"] = None,
    ) -> None:
        """
        :param count: 
        :param depends_on: 
        :param lifecycle: 
        :param provider: 
        :param dtu: 
        :param edition: 
        :param location: 
        :param name: 
        :param resource_group_name: 
        :param server_name: 
        :param db_dtu_max: 
        :param db_dtu_min: 
        :param pool_size: 
        :param tags: 
        :param timeouts: timeouts block.
        """
        if isinstance(lifecycle, dict):
            lifecycle = cdktf.TerraformResourceLifecycle(**lifecycle)
        if isinstance(timeouts, dict):
            timeouts = SqlElasticpoolTimeouts(**timeouts)
        self._values: typing.Dict[str, typing.Any] = {
            "dtu": dtu,
            "edition": edition,
            "location": location,
            "name": name,
            "resource_group_name": resource_group_name,
            "server_name": server_name,
        }
        if count is not None:
            self._values["count"] = count
        if depends_on is not None:
            self._values["depends_on"] = depends_on
        if lifecycle is not None:
            self._values["lifecycle"] = lifecycle
        if provider is not None:
            self._values["provider"] = provider
        if db_dtu_max is not None:
            self._values["db_dtu_max"] = db_dtu_max
        if db_dtu_min is not None:
            self._values["db_dtu_min"] = db_dtu_min
        if pool_size is not None:
            self._values["pool_size"] = pool_size
        if tags is not None:
            self._values["tags"] = tags
        if timeouts is not None:
            self._values["timeouts"] = timeouts

    @builtins.property
    def count(self) -> typing.Optional[jsii.Number]:
        """
        :stability: experimental
        """
        result = self._values.get("count")
        return result

    @builtins.property
    def depends_on(self) -> typing.Optional[typing.List[cdktf.TerraformResource]]:
        """
        :stability: experimental
        """
        result = self._values.get("depends_on")
        return result

    @builtins.property
    def lifecycle(self) -> typing.Optional[cdktf.TerraformResourceLifecycle]:
        """
        :stability: experimental
        """
        result = self._values.get("lifecycle")
        return result

    @builtins.property
    def provider(self) -> typing.Optional[cdktf.TerraformProvider]:
        """
        :stability: experimental
        """
        result = self._values.get("provider")
        return result

    @builtins.property
    def dtu(self) -> jsii.Number:
        result = self._values.get("dtu")
        assert result is not None, "Required property 'dtu' is missing"
        return result

    @builtins.property
    def edition(self) -> builtins.str:
        result = self._values.get("edition")
        assert result is not None, "Required property 'edition' is missing"
        return result

    @builtins.property
    def location(self) -> builtins.str:
        result = self._values.get("location")
        assert result is not None, "Required property 'location' is missing"
        return result

    @builtins.property
    def name(self) -> builtins.str:
        result = self._values.get("name")
        assert result is not None, "Required property 'name' is missing"
        return result

    @builtins.property
    def resource_group_name(self) -> builtins.str:
        result = self._values.get("resource_group_name")
        assert result is not None, "Required property 'resource_group_name' is missing"
        return result

    @builtins.property
    def server_name(self) -> builtins.str:
        result = self._values.get("server_name")
        assert result is not None, "Required property 'server_name' is missing"
        return result

    @builtins.property
    def db_dtu_max(self) -> typing.Optional[jsii.Number]:
        result = self._values.get("db_dtu_max")
        return result

    @builtins.property
    def db_dtu_min(self) -> typing.Optional[jsii.Number]:
        result = self._values.get("db_dtu_min")
        return result

    @builtins.property
    def pool_size(self) -> typing.Optional[jsii.Number]:
        result = self._values.get("pool_size")
        return result

    @builtins.property
    def tags(self) -> typing.Optional[typing.Mapping[builtins.str, builtins.str]]:
        result = self._values.get("tags")
        return result

    @builtins.property
    def timeouts(self) -> typing.Optional["SqlElasticpoolTimeouts"]:
        """timeouts block."""
        result = self._values.get("timeouts")
        return result

    def __eq__(self, rhs: typing.Any) -> builtins.bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs: typing.Any) -> builtins.bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return "SqlElasticpoolConfig(%s)" % ", ".join(
            k + "=" + repr(v) for k, v in self._values.items()
        )


@jsii.data_type(
    jsii_type="@cdktf/provider-azurerm.SqlElasticpoolTimeouts",
    jsii_struct_bases=[],
    name_mapping={
        "create": "create",
        "delete": "delete",
        "read": "read",
        "update": "update",
    },
)
class SqlElasticpoolTimeouts:
    def __init__(
        self,
        *,
        create: typing.Optional[builtins.str] = None,
        delete: typing.Optional[builtins.str] = None,
        read: typing.Optional[builtins.str] = None,
        update: typing.Optional[builtins.str] = None,
    ) -> None:
        """
        :param create: 
        :param delete: 
        :param read: 
        :param update: 
        """
        self._values: typing.Dict[str, typing.Any] = {}
        if create is not None:
            self._values["create"] = create
        if delete is not None:
            self._values["delete"] = delete
        if read is not None:
            self._values["read"] = read
        if update is not None:
            self._values["update"] = update

    @builtins.property
    def create(self) -> typing.Optional[builtins.str]:
        result = self._values.get("create")
        return result

    @builtins.property
    def delete(self) -> typing.Optional[builtins.str]:
        result = self._values.get("delete")
        return result

    @builtins.property
    def read(self) -> typing.Optional[builtins.str]:
        result = self._values.get("read")
        return result

    @builtins.property
    def update(self) -> typing.Optional[builtins.str]:
        result = self._values.get("update")
        return result

    def __eq__(self, rhs: typing.Any) -> builtins.bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs: typing.Any) -> builtins.bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return "SqlElasticpoolTimeouts(%s)" % ", ".join(
            k + "=" + repr(v) for k, v in self._values.items()
        )


class SqlFailoverGroup(
    cdktf.TerraformResource,
    metaclass=jsii.JSIIMeta,
    jsii_type="@cdktf/provider-azurerm.SqlFailoverGroup",
):
    def __init__(
        self,
        scope: constructs.Construct,
        id: builtins.str,
        *,
        name: builtins.str,
        partner_servers: typing.List["SqlFailoverGroupPartnerServers"],
        read_write_endpoint_failover_policy: typing.List["SqlFailoverGroupReadWriteEndpointFailoverPolicy"],
        resource_group_name: builtins.str,
        server_name: builtins.str,
        databases: typing.Optional[typing.List[builtins.str]] = None,
        readonly_endpoint_failover_policy: typing.Optional[typing.List["SqlFailoverGroupReadonlyEndpointFailoverPolicy"]] = None,
        tags: typing.Optional[typing.Mapping[builtins.str, builtins.str]] = None,
        timeouts: typing.Optional["SqlFailoverGroupTimeouts"] = None,
        count: typing.Optional[jsii.Number] = None,
        depends_on: typing.Optional[typing.List[cdktf.TerraformResource]] = None,
        lifecycle: typing.Optional[cdktf.TerraformResourceLifecycle] = None,
        provider: typing.Optional[cdktf.TerraformProvider] = None,
    ) -> None:
        """
        :param scope: -
        :param id: -
        :param name: 
        :param partner_servers: partner_servers block.
        :param read_write_endpoint_failover_policy: read_write_endpoint_failover_policy block.
        :param resource_group_name: 
        :param server_name: 
        :param databases: 
        :param readonly_endpoint_failover_policy: readonly_endpoint_failover_policy block.
        :param tags: 
        :param timeouts: timeouts block.
        :param count: 
        :param depends_on: 
        :param lifecycle: 
        :param provider: 
        """
        config = SqlFailoverGroupConfig(
            name=name,
            partner_servers=partner_servers,
            read_write_endpoint_failover_policy=read_write_endpoint_failover_policy,
            resource_group_name=resource_group_name,
            server_name=server_name,
            databases=databases,
            readonly_endpoint_failover_policy=readonly_endpoint_failover_policy,
            tags=tags,
            timeouts=timeouts,
            count=count,
            depends_on=depends_on,
            lifecycle=lifecycle,
            provider=provider,
        )

        jsii.create(SqlFailoverGroup, self, [scope, id, config])

    @jsii.member(jsii_name="synthesizeAttributes")
    def _synthesize_attributes(self) -> typing.Mapping[builtins.str, typing.Any]:
        return jsii.invoke(self, "synthesizeAttributes", [])

    @builtins.property # type: ignore
    @jsii.member(jsii_name="location")
    def location(self) -> builtins.str:
        return jsii.get(self, "location")

    @builtins.property # type: ignore
    @jsii.member(jsii_name="role")
    def role(self) -> builtins.str:
        return jsii.get(self, "role")

    @builtins.property # type: ignore
    @jsii.member(jsii_name="name")
    def name(self) -> builtins.str:
        return jsii.get(self, "name")

    @name.setter # type: ignore
    def name(self, value: builtins.str) -> None:
        jsii.set(self, "name", value)

    @builtins.property # type: ignore
    @jsii.member(jsii_name="partnerServers")
    def partner_servers(self) -> typing.List["SqlFailoverGroupPartnerServers"]:
        return jsii.get(self, "partnerServers")

    @partner_servers.setter # type: ignore
    def partner_servers(
        self,
        value: typing.List["SqlFailoverGroupPartnerServers"],
    ) -> None:
        jsii.set(self, "partnerServers", value)

    @builtins.property # type: ignore
    @jsii.member(jsii_name="readWriteEndpointFailoverPolicy")
    def read_write_endpoint_failover_policy(
        self,
    ) -> typing.List["SqlFailoverGroupReadWriteEndpointFailoverPolicy"]:
        return jsii.get(self, "readWriteEndpointFailoverPolicy")

    @read_write_endpoint_failover_policy.setter # type: ignore
    def read_write_endpoint_failover_policy(
        self,
        value: typing.List["SqlFailoverGroupReadWriteEndpointFailoverPolicy"],
    ) -> None:
        jsii.set(self, "readWriteEndpointFailoverPolicy", value)

    @builtins.property # type: ignore
    @jsii.member(jsii_name="resourceGroupName")
    def resource_group_name(self) -> builtins.str:
        return jsii.get(self, "resourceGroupName")

    @resource_group_name.setter # type: ignore
    def resource_group_name(self, value: builtins.str) -> None:
        jsii.set(self, "resourceGroupName", value)

    @builtins.property # type: ignore
    @jsii.member(jsii_name="serverName")
    def server_name(self) -> builtins.str:
        return jsii.get(self, "serverName")

    @server_name.setter # type: ignore
    def server_name(self, value: builtins.str) -> None:
        jsii.set(self, "serverName", value)

    @builtins.property # type: ignore
    @jsii.member(jsii_name="databases")
    def databases(self) -> typing.Optional[typing.List[builtins.str]]:
        return jsii.get(self, "databases")

    @databases.setter # type: ignore
    def databases(self, value: typing.Optional[typing.List[builtins.str]]) -> None:
        jsii.set(self, "databases", value)

    @builtins.property # type: ignore
    @jsii.member(jsii_name="id")
    def id(self) -> typing.Optional[builtins.str]:
        return jsii.get(self, "id")

    @id.setter # type: ignore
    def id(self, value: typing.Optional[builtins.str]) -> None:
        jsii.set(self, "id", value)

    @builtins.property # type: ignore
    @jsii.member(jsii_name="readonlyEndpointFailoverPolicy")
    def readonly_endpoint_failover_policy(
        self,
    ) -> typing.Optional[typing.List["SqlFailoverGroupReadonlyEndpointFailoverPolicy"]]:
        return jsii.get(self, "readonlyEndpointFailoverPolicy")

    @readonly_endpoint_failover_policy.setter # type: ignore
    def readonly_endpoint_failover_policy(
        self,
        value: typing.Optional[typing.List["SqlFailoverGroupReadonlyEndpointFailoverPolicy"]],
    ) -> None:
        jsii.set(self, "readonlyEndpointFailoverPolicy", value)

    @builtins.property # type: ignore
    @jsii.member(jsii_name="tags")
    def tags(self) -> typing.Optional[typing.Mapping[builtins.str, builtins.str]]:
        return jsii.get(self, "tags")

    @tags.setter # type: ignore
    def tags(
        self,
        value: typing.Optional[typing.Mapping[builtins.str, builtins.str]],
    ) -> None:
        jsii.set(self, "tags", value)

    @builtins.property # type: ignore
    @jsii.member(jsii_name="timeouts")
    def timeouts(self) -> typing.Optional["SqlFailoverGroupTimeouts"]:
        return jsii.get(self, "timeouts")

    @timeouts.setter # type: ignore
    def timeouts(self, value: typing.Optional["SqlFailoverGroupTimeouts"]) -> None:
        jsii.set(self, "timeouts", value)


@jsii.data_type(
    jsii_type="@cdktf/provider-azurerm.SqlFailoverGroupConfig",
    jsii_struct_bases=[cdktf.TerraformMetaArguments],
    name_mapping={
        "count": "count",
        "depends_on": "dependsOn",
        "lifecycle": "lifecycle",
        "provider": "provider",
        "name": "name",
        "partner_servers": "partnerServers",
        "read_write_endpoint_failover_policy": "readWriteEndpointFailoverPolicy",
        "resource_group_name": "resourceGroupName",
        "server_name": "serverName",
        "databases": "databases",
        "readonly_endpoint_failover_policy": "readonlyEndpointFailoverPolicy",
        "tags": "tags",
        "timeouts": "timeouts",
    },
)
class SqlFailoverGroupConfig(cdktf.TerraformMetaArguments):
    def __init__(
        self,
        *,
        count: typing.Optional[jsii.Number] = None,
        depends_on: typing.Optional[typing.List[cdktf.TerraformResource]] = None,
        lifecycle: typing.Optional[cdktf.TerraformResourceLifecycle] = None,
        provider: typing.Optional[cdktf.TerraformProvider] = None,
        name: builtins.str,
        partner_servers: typing.List["SqlFailoverGroupPartnerServers"],
        read_write_endpoint_failover_policy: typing.List["SqlFailoverGroupReadWriteEndpointFailoverPolicy"],
        resource_group_name: builtins.str,
        server_name: builtins.str,
        databases: typing.Optional[typing.List[builtins.str]] = None,
        readonly_endpoint_failover_policy: typing.Optional[typing.List["SqlFailoverGroupReadonlyEndpointFailoverPolicy"]] = None,
        tags: typing.Optional[typing.Mapping[builtins.str, builtins.str]] = None,
        timeouts: typing.Optional["SqlFailoverGroupTimeouts"] = None,
    ) -> None:
        """
        :param count: 
        :param depends_on: 
        :param lifecycle: 
        :param provider: 
        :param name: 
        :param partner_servers: partner_servers block.
        :param read_write_endpoint_failover_policy: read_write_endpoint_failover_policy block.
        :param resource_group_name: 
        :param server_name: 
        :param databases: 
        :param readonly_endpoint_failover_policy: readonly_endpoint_failover_policy block.
        :param tags: 
        :param timeouts: timeouts block.
        """
        if isinstance(lifecycle, dict):
            lifecycle = cdktf.TerraformResourceLifecycle(**lifecycle)
        if isinstance(timeouts, dict):
            timeouts = SqlFailoverGroupTimeouts(**timeouts)
        self._values: typing.Dict[str, typing.Any] = {
            "name": name,
            "partner_servers": partner_servers,
            "read_write_endpoint_failover_policy": read_write_endpoint_failover_policy,
            "resource_group_name": resource_group_name,
            "server_name": server_name,
        }
        if count is not None:
            self._values["count"] = count
        if depends_on is not None:
            self._values["depends_on"] = depends_on
        if lifecycle is not None:
            self._values["lifecycle"] = lifecycle
        if provider is not None:
            self._values["provider"] = provider
        if databases is not None:
            self._values["databases"] = databases
        if readonly_endpoint_failover_policy is not None:
            self._values["readonly_endpoint_failover_policy"] = readonly_endpoint_failover_policy
        if tags is not None:
            self._values["tags"] = tags
        if timeouts is not None:
            self._values["timeouts"] = timeouts

    @builtins.property
    def count(self) -> typing.Optional[jsii.Number]:
        """
        :stability: experimental
        """
        result = self._values.get("count")
        return result

    @builtins.property
    def depends_on(self) -> typing.Optional[typing.List[cdktf.TerraformResource]]:
        """
        :stability: experimental
        """
        result = self._values.get("depends_on")
        return result

    @builtins.property
    def lifecycle(self) -> typing.Optional[cdktf.TerraformResourceLifecycle]:
        """
        :stability: experimental
        """
        result = self._values.get("lifecycle")
        return result

    @builtins.property
    def provider(self) -> typing.Optional[cdktf.TerraformProvider]:
        """
        :stability: experimental
        """
        result = self._values.get("provider")
        return result

    @builtins.property
    def name(self) -> builtins.str:
        result = self._values.get("name")
        assert result is not None, "Required property 'name' is missing"
        return result

    @builtins.property
    def partner_servers(self) -> typing.List["SqlFailoverGroupPartnerServers"]:
        """partner_servers block."""
        result = self._values.get("partner_servers")
        assert result is not None, "Required property 'partner_servers' is missing"
        return result

    @builtins.property
    def read_write_endpoint_failover_policy(
        self,
    ) -> typing.List["SqlFailoverGroupReadWriteEndpointFailoverPolicy"]:
        """read_write_endpoint_failover_policy block."""
        result = self._values.get("read_write_endpoint_failover_policy")
        assert result is not None, "Required property 'read_write_endpoint_failover_policy' is missing"
        return result

    @builtins.property
    def resource_group_name(self) -> builtins.str:
        result = self._values.get("resource_group_name")
        assert result is not None, "Required property 'resource_group_name' is missing"
        return result

    @builtins.property
    def server_name(self) -> builtins.str:
        result = self._values.get("server_name")
        assert result is not None, "Required property 'server_name' is missing"
        return result

    @builtins.property
    def databases(self) -> typing.Optional[typing.List[builtins.str]]:
        result = self._values.get("databases")
        return result

    @builtins.property
    def readonly_endpoint_failover_policy(
        self,
    ) -> typing.Optional[typing.List["SqlFailoverGroupReadonlyEndpointFailoverPolicy"]]:
        """readonly_endpoint_failover_policy block."""
        result = self._values.get("readonly_endpoint_failover_policy")
        return result

    @builtins.property
    def tags(self) -> typing.Optional[typing.Mapping[builtins.str, builtins.str]]:
        result = self._values.get("tags")
        return result

    @builtins.property
    def timeouts(self) -> typing.Optional["SqlFailoverGroupTimeouts"]:
        """timeouts block."""
        result = self._values.get("timeouts")
        return result

    def __eq__(self, rhs: typing.Any) -> builtins.bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs: typing.Any) -> builtins.bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return "SqlFailoverGroupConfig(%s)" % ", ".join(
            k + "=" + repr(v) for k, v in self._values.items()
        )


@jsii.data_type(
    jsii_type="@cdktf/provider-azurerm.SqlFailoverGroupPartnerServers",
    jsii_struct_bases=[],
    name_mapping={"id": "id"},
)
class SqlFailoverGroupPartnerServers:
    def __init__(self, *, id: builtins.str) -> None:
        """
        :param id: 
        """
        self._values: typing.Dict[str, typing.Any] = {
            "id": id,
        }

    @builtins.property
    def id(self) -> builtins.str:
        result = self._values.get("id")
        assert result is not None, "Required property 'id' is missing"
        return result

    def __eq__(self, rhs: typing.Any) -> builtins.bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs: typing.Any) -> builtins.bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return "SqlFailoverGroupPartnerServers(%s)" % ", ".join(
            k + "=" + repr(v) for k, v in self._values.items()
        )


@jsii.data_type(
    jsii_type="@cdktf/provider-azurerm.SqlFailoverGroupReadWriteEndpointFailoverPolicy",
    jsii_struct_bases=[],
    name_mapping={"mode": "mode", "grace_minutes": "graceMinutes"},
)
class SqlFailoverGroupReadWriteEndpointFailoverPolicy:
    def __init__(
        self,
        *,
        mode: builtins.str,
        grace_minutes: typing.Optional[jsii.Number] = None,
    ) -> None:
        """
        :param mode: 
        :param grace_minutes: 
        """
        self._values: typing.Dict[str, typing.Any] = {
            "mode": mode,
        }
        if grace_minutes is not None:
            self._values["grace_minutes"] = grace_minutes

    @builtins.property
    def mode(self) -> builtins.str:
        result = self._values.get("mode")
        assert result is not None, "Required property 'mode' is missing"
        return result

    @builtins.property
    def grace_minutes(self) -> typing.Optional[jsii.Number]:
        result = self._values.get("grace_minutes")
        return result

    def __eq__(self, rhs: typing.Any) -> builtins.bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs: typing.Any) -> builtins.bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return "SqlFailoverGroupReadWriteEndpointFailoverPolicy(%s)" % ", ".join(
            k + "=" + repr(v) for k, v in self._values.items()
        )


@jsii.data_type(
    jsii_type="@cdktf/provider-azurerm.SqlFailoverGroupReadonlyEndpointFailoverPolicy",
    jsii_struct_bases=[],
    name_mapping={"mode": "mode"},
)
class SqlFailoverGroupReadonlyEndpointFailoverPolicy:
    def __init__(self, *, mode: builtins.str) -> None:
        """
        :param mode: 
        """
        self._values: typing.Dict[str, typing.Any] = {
            "mode": mode,
        }

    @builtins.property
    def mode(self) -> builtins.str:
        result = self._values.get("mode")
        assert result is not None, "Required property 'mode' is missing"
        return result

    def __eq__(self, rhs: typing.Any) -> builtins.bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs: typing.Any) -> builtins.bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return "SqlFailoverGroupReadonlyEndpointFailoverPolicy(%s)" % ", ".join(
            k + "=" + repr(v) for k, v in self._values.items()
        )


@jsii.data_type(
    jsii_type="@cdktf/provider-azurerm.SqlFailoverGroupTimeouts",
    jsii_struct_bases=[],
    name_mapping={
        "create": "create",
        "delete": "delete",
        "read": "read",
        "update": "update",
    },
)
class SqlFailoverGroupTimeouts:
    def __init__(
        self,
        *,
        create: typing.Optional[builtins.str] = None,
        delete: typing.Optional[builtins.str] = None,
        read: typing.Optional[builtins.str] = None,
        update: typing.Optional[builtins.str] = None,
    ) -> None:
        """
        :param create: 
        :param delete: 
        :param read: 
        :param update: 
        """
        self._values: typing.Dict[str, typing.Any] = {}
        if create is not None:
            self._values["create"] = create
        if delete is not None:
            self._values["delete"] = delete
        if read is not None:
            self._values["read"] = read
        if update is not None:
            self._values["update"] = update

    @builtins.property
    def create(self) -> typing.Optional[builtins.str]:
        result = self._values.get("create")
        return result

    @builtins.property
    def delete(self) -> typing.Optional[builtins.str]:
        result = self._values.get("delete")
        return result

    @builtins.property
    def read(self) -> typing.Optional[builtins.str]:
        result = self._values.get("read")
        return result

    @builtins.property
    def update(self) -> typing.Optional[builtins.str]:
        result = self._values.get("update")
        return result

    def __eq__(self, rhs: typing.Any) -> builtins.bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs: typing.Any) -> builtins.bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return "SqlFailoverGroupTimeouts(%s)" % ", ".join(
            k + "=" + repr(v) for k, v in self._values.items()
        )


class SqlFirewallRule(
    cdktf.TerraformResource,
    metaclass=jsii.JSIIMeta,
    jsii_type="@cdktf/provider-azurerm.SqlFirewallRule",
):
    def __init__(
        self,
        scope: constructs.Construct,
        id: builtins.str,
        *,
        end_ip_address: builtins.str,
        name: builtins.str,
        resource_group_name: builtins.str,
        server_name: builtins.str,
        start_ip_address: builtins.str,
        timeouts: typing.Optional["SqlFirewallRuleTimeouts"] = None,
        count: typing.Optional[jsii.Number] = None,
        depends_on: typing.Optional[typing.List[cdktf.TerraformResource]] = None,
        lifecycle: typing.Optional[cdktf.TerraformResourceLifecycle] = None,
        provider: typing.Optional[cdktf.TerraformProvider] = None,
    ) -> None:
        """
        :param scope: -
        :param id: -
        :param end_ip_address: 
        :param name: 
        :param resource_group_name: 
        :param server_name: 
        :param start_ip_address: 
        :param timeouts: timeouts block.
        :param count: 
        :param depends_on: 
        :param lifecycle: 
        :param provider: 
        """
        config = SqlFirewallRuleConfig(
            end_ip_address=end_ip_address,
            name=name,
            resource_group_name=resource_group_name,
            server_name=server_name,
            start_ip_address=start_ip_address,
            timeouts=timeouts,
            count=count,
            depends_on=depends_on,
            lifecycle=lifecycle,
            provider=provider,
        )

        jsii.create(SqlFirewallRule, self, [scope, id, config])

    @jsii.member(jsii_name="synthesizeAttributes")
    def _synthesize_attributes(self) -> typing.Mapping[builtins.str, typing.Any]:
        return jsii.invoke(self, "synthesizeAttributes", [])

    @builtins.property # type: ignore
    @jsii.member(jsii_name="endIpAddress")
    def end_ip_address(self) -> builtins.str:
        return jsii.get(self, "endIpAddress")

    @end_ip_address.setter # type: ignore
    def end_ip_address(self, value: builtins.str) -> None:
        jsii.set(self, "endIpAddress", value)

    @builtins.property # type: ignore
    @jsii.member(jsii_name="name")
    def name(self) -> builtins.str:
        return jsii.get(self, "name")

    @name.setter # type: ignore
    def name(self, value: builtins.str) -> None:
        jsii.set(self, "name", value)

    @builtins.property # type: ignore
    @jsii.member(jsii_name="resourceGroupName")
    def resource_group_name(self) -> builtins.str:
        return jsii.get(self, "resourceGroupName")

    @resource_group_name.setter # type: ignore
    def resource_group_name(self, value: builtins.str) -> None:
        jsii.set(self, "resourceGroupName", value)

    @builtins.property # type: ignore
    @jsii.member(jsii_name="serverName")
    def server_name(self) -> builtins.str:
        return jsii.get(self, "serverName")

    @server_name.setter # type: ignore
    def server_name(self, value: builtins.str) -> None:
        jsii.set(self, "serverName", value)

    @builtins.property # type: ignore
    @jsii.member(jsii_name="startIpAddress")
    def start_ip_address(self) -> builtins.str:
        return jsii.get(self, "startIpAddress")

    @start_ip_address.setter # type: ignore
    def start_ip_address(self, value: builtins.str) -> None:
        jsii.set(self, "startIpAddress", value)

    @builtins.property # type: ignore
    @jsii.member(jsii_name="id")
    def id(self) -> typing.Optional[builtins.str]:
        return jsii.get(self, "id")

    @id.setter # type: ignore
    def id(self, value: typing.Optional[builtins.str]) -> None:
        jsii.set(self, "id", value)

    @builtins.property # type: ignore
    @jsii.member(jsii_name="timeouts")
    def timeouts(self) -> typing.Optional["SqlFirewallRuleTimeouts"]:
        return jsii.get(self, "timeouts")

    @timeouts.setter # type: ignore
    def timeouts(self, value: typing.Optional["SqlFirewallRuleTimeouts"]) -> None:
        jsii.set(self, "timeouts", value)


@jsii.data_type(
    jsii_type="@cdktf/provider-azurerm.SqlFirewallRuleConfig",
    jsii_struct_bases=[cdktf.TerraformMetaArguments],
    name_mapping={
        "count": "count",
        "depends_on": "dependsOn",
        "lifecycle": "lifecycle",
        "provider": "provider",
        "end_ip_address": "endIpAddress",
        "name": "name",
        "resource_group_name": "resourceGroupName",
        "server_name": "serverName",
        "start_ip_address": "startIpAddress",
        "timeouts": "timeouts",
    },
)
class SqlFirewallRuleConfig(cdktf.TerraformMetaArguments):
    def __init__(
        self,
        *,
        count: typing.Optional[jsii.Number] = None,
        depends_on: typing.Optional[typing.List[cdktf.TerraformResource]] = None,
        lifecycle: typing.Optional[cdktf.TerraformResourceLifecycle] = None,
        provider: typing.Optional[cdktf.TerraformProvider] = None,
        end_ip_address: builtins.str,
        name: builtins.str,
        resource_group_name: builtins.str,
        server_name: builtins.str,
        start_ip_address: builtins.str,
        timeouts: typing.Optional["SqlFirewallRuleTimeouts"] = None,
    ) -> None:
        """
        :param count: 
        :param depends_on: 
        :param lifecycle: 
        :param provider: 
        :param end_ip_address: 
        :param name: 
        :param resource_group_name: 
        :param server_name: 
        :param start_ip_address: 
        :param timeouts: timeouts block.
        """
        if isinstance(lifecycle, dict):
            lifecycle = cdktf.TerraformResourceLifecycle(**lifecycle)
        if isinstance(timeouts, dict):
            timeouts = SqlFirewallRuleTimeouts(**timeouts)
        self._values: typing.Dict[str, typing.Any] = {
            "end_ip_address": end_ip_address,
            "name": name,
            "resource_group_name": resource_group_name,
            "server_name": server_name,
            "start_ip_address": start_ip_address,
        }
        if count is not None:
            self._values["count"] = count
        if depends_on is not None:
            self._values["depends_on"] = depends_on
        if lifecycle is not None:
            self._values["lifecycle"] = lifecycle
        if provider is not None:
            self._values["provider"] = provider
        if timeouts is not None:
            self._values["timeouts"] = timeouts

    @builtins.property
    def count(self) -> typing.Optional[jsii.Number]:
        """
        :stability: experimental
        """
        result = self._values.get("count")
        return result

    @builtins.property
    def depends_on(self) -> typing.Optional[typing.List[cdktf.TerraformResource]]:
        """
        :stability: experimental
        """
        result = self._values.get("depends_on")
        return result

    @builtins.property
    def lifecycle(self) -> typing.Optional[cdktf.TerraformResourceLifecycle]:
        """
        :stability: experimental
        """
        result = self._values.get("lifecycle")
        return result

    @builtins.property
    def provider(self) -> typing.Optional[cdktf.TerraformProvider]:
        """
        :stability: experimental
        """
        result = self._values.get("provider")
        return result

    @builtins.property
    def end_ip_address(self) -> builtins.str:
        result = self._values.get("end_ip_address")
        assert result is not None, "Required property 'end_ip_address' is missing"
        return result

    @builtins.property
    def name(self) -> builtins.str:
        result = self._values.get("name")
        assert result is not None, "Required property 'name' is missing"
        return result

    @builtins.property
    def resource_group_name(self) -> builtins.str:
        result = self._values.get("resource_group_name")
        assert result is not None, "Required property 'resource_group_name' is missing"
        return result

    @builtins.property
    def server_name(self) -> builtins.str:
        result = self._values.get("server_name")
        assert result is not None, "Required property 'server_name' is missing"
        return result

    @builtins.property
    def start_ip_address(self) -> builtins.str:
        result = self._values.get("start_ip_address")
        assert result is not None, "Required property 'start_ip_address' is missing"
        return result

    @builtins.property
    def timeouts(self) -> typing.Optional["SqlFirewallRuleTimeouts"]:
        """timeouts block."""
        result = self._values.get("timeouts")
        return result

    def __eq__(self, rhs: typing.Any) -> builtins.bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs: typing.Any) -> builtins.bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return "SqlFirewallRuleConfig(%s)" % ", ".join(
            k + "=" + repr(v) for k, v in self._values.items()
        )


@jsii.data_type(
    jsii_type="@cdktf/provider-azurerm.SqlFirewallRuleTimeouts",
    jsii_struct_bases=[],
    name_mapping={
        "create": "create",
        "delete": "delete",
        "read": "read",
        "update": "update",
    },
)
class SqlFirewallRuleTimeouts:
    def __init__(
        self,
        *,
        create: typing.Optional[builtins.str] = None,
        delete: typing.Optional[builtins.str] = None,
        read: typing.Optional[builtins.str] = None,
        update: typing.Optional[builtins.str] = None,
    ) -> None:
        """
        :param create: 
        :param delete: 
        :param read: 
        :param update: 
        """
        self._values: typing.Dict[str, typing.Any] = {}
        if create is not None:
            self._values["create"] = create
        if delete is not None:
            self._values["delete"] = delete
        if read is not None:
            self._values["read"] = read
        if update is not None:
            self._values["update"] = update

    @builtins.property
    def create(self) -> typing.Optional[builtins.str]:
        result = self._values.get("create")
        return result

    @builtins.property
    def delete(self) -> typing.Optional[builtins.str]:
        result = self._values.get("delete")
        return result

    @builtins.property
    def read(self) -> typing.Optional[builtins.str]:
        result = self._values.get("read")
        return result

    @builtins.property
    def update(self) -> typing.Optional[builtins.str]:
        result = self._values.get("update")
        return result

    def __eq__(self, rhs: typing.Any) -> builtins.bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs: typing.Any) -> builtins.bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return "SqlFirewallRuleTimeouts(%s)" % ", ".join(
            k + "=" + repr(v) for k, v in self._values.items()
        )


class SqlServer(
    cdktf.TerraformResource,
    metaclass=jsii.JSIIMeta,
    jsii_type="@cdktf/provider-azurerm.SqlServer",
):
    def __init__(
        self,
        scope: constructs.Construct,
        id: builtins.str,
        *,
        administrator_login: builtins.str,
        administrator_login_password: builtins.str,
        location: builtins.str,
        name: builtins.str,
        resource_group_name: builtins.str,
        version: builtins.str,
        identity: typing.Optional[typing.List["SqlServerIdentity"]] = None,
        tags: typing.Optional[typing.Mapping[builtins.str, builtins.str]] = None,
        timeouts: typing.Optional["SqlServerTimeouts"] = None,
        count: typing.Optional[jsii.Number] = None,
        depends_on: typing.Optional[typing.List[cdktf.TerraformResource]] = None,
        lifecycle: typing.Optional[cdktf.TerraformResourceLifecycle] = None,
        provider: typing.Optional[cdktf.TerraformProvider] = None,
    ) -> None:
        """
        :param scope: -
        :param id: -
        :param administrator_login: 
        :param administrator_login_password: 
        :param location: 
        :param name: 
        :param resource_group_name: 
        :param version: 
        :param identity: identity block.
        :param tags: 
        :param timeouts: timeouts block.
        :param count: 
        :param depends_on: 
        :param lifecycle: 
        :param provider: 
        """
        config = SqlServerConfig(
            administrator_login=administrator_login,
            administrator_login_password=administrator_login_password,
            location=location,
            name=name,
            resource_group_name=resource_group_name,
            version=version,
            identity=identity,
            tags=tags,
            timeouts=timeouts,
            count=count,
            depends_on=depends_on,
            lifecycle=lifecycle,
            provider=provider,
        )

        jsii.create(SqlServer, self, [scope, id, config])

    @jsii.member(jsii_name="synthesizeAttributes")
    def _synthesize_attributes(self) -> typing.Mapping[builtins.str, typing.Any]:
        return jsii.invoke(self, "synthesizeAttributes", [])

    @builtins.property # type: ignore
    @jsii.member(jsii_name="fullyQualifiedDomainName")
    def fully_qualified_domain_name(self) -> builtins.str:
        return jsii.get(self, "fullyQualifiedDomainName")

    @builtins.property # type: ignore
    @jsii.member(jsii_name="administratorLogin")
    def administrator_login(self) -> builtins.str:
        return jsii.get(self, "administratorLogin")

    @administrator_login.setter # type: ignore
    def administrator_login(self, value: builtins.str) -> None:
        jsii.set(self, "administratorLogin", value)

    @builtins.property # type: ignore
    @jsii.member(jsii_name="administratorLoginPassword")
    def administrator_login_password(self) -> builtins.str:
        return jsii.get(self, "administratorLoginPassword")

    @administrator_login_password.setter # type: ignore
    def administrator_login_password(self, value: builtins.str) -> None:
        jsii.set(self, "administratorLoginPassword", value)

    @builtins.property # type: ignore
    @jsii.member(jsii_name="location")
    def location(self) -> builtins.str:
        return jsii.get(self, "location")

    @location.setter # type: ignore
    def location(self, value: builtins.str) -> None:
        jsii.set(self, "location", value)

    @builtins.property # type: ignore
    @jsii.member(jsii_name="name")
    def name(self) -> builtins.str:
        return jsii.get(self, "name")

    @name.setter # type: ignore
    def name(self, value: builtins.str) -> None:
        jsii.set(self, "name", value)

    @builtins.property # type: ignore
    @jsii.member(jsii_name="resourceGroupName")
    def resource_group_name(self) -> builtins.str:
        return jsii.get(self, "resourceGroupName")

    @resource_group_name.setter # type: ignore
    def resource_group_name(self, value: builtins.str) -> None:
        jsii.set(self, "resourceGroupName", value)

    @builtins.property # type: ignore
    @jsii.member(jsii_name="version")
    def version(self) -> builtins.str:
        return jsii.get(self, "version")

    @version.setter # type: ignore
    def version(self, value: builtins.str) -> None:
        jsii.set(self, "version", value)

    @builtins.property # type: ignore
    @jsii.member(jsii_name="id")
    def id(self) -> typing.Optional[builtins.str]:
        return jsii.get(self, "id")

    @id.setter # type: ignore
    def id(self, value: typing.Optional[builtins.str]) -> None:
        jsii.set(self, "id", value)

    @builtins.property # type: ignore
    @jsii.member(jsii_name="identity")
    def identity(self) -> typing.Optional[typing.List["SqlServerIdentity"]]:
        return jsii.get(self, "identity")

    @identity.setter # type: ignore
    def identity(
        self,
        value: typing.Optional[typing.List["SqlServerIdentity"]],
    ) -> None:
        jsii.set(self, "identity", value)

    @builtins.property # type: ignore
    @jsii.member(jsii_name="tags")
    def tags(self) -> typing.Optional[typing.Mapping[builtins.str, builtins.str]]:
        return jsii.get(self, "tags")

    @tags.setter # type: ignore
    def tags(
        self,
        value: typing.Optional[typing.Mapping[builtins.str, builtins.str]],
    ) -> None:
        jsii.set(self, "tags", value)

    @builtins.property # type: ignore
    @jsii.member(jsii_name="timeouts")
    def timeouts(self) -> typing.Optional["SqlServerTimeouts"]:
        return jsii.get(self, "timeouts")

    @timeouts.setter # type: ignore
    def timeouts(self, value: typing.Optional["SqlServerTimeouts"]) -> None:
        jsii.set(self, "timeouts", value)


@jsii.data_type(
    jsii_type="@cdktf/provider-azurerm.SqlServerConfig",
    jsii_struct_bases=[cdktf.TerraformMetaArguments],
    name_mapping={
        "count": "count",
        "depends_on": "dependsOn",
        "lifecycle": "lifecycle",
        "provider": "provider",
        "administrator_login": "administratorLogin",
        "administrator_login_password": "administratorLoginPassword",
        "location": "location",
        "name": "name",
        "resource_group_name": "resourceGroupName",
        "version": "version",
        "identity": "identity",
        "tags": "tags",
        "timeouts": "timeouts",
    },
)
class SqlServerConfig(cdktf.TerraformMetaArguments):
    def __init__(
        self,
        *,
        count: typing.Optional[jsii.Number] = None,
        depends_on: typing.Optional[typing.List[cdktf.TerraformResource]] = None,
        lifecycle: typing.Optional[cdktf.TerraformResourceLifecycle] = None,
        provider: typing.Optional[cdktf.TerraformProvider] = None,
        administrator_login: builtins.str,
        administrator_login_password: builtins.str,
        location: builtins.str,
        name: builtins.str,
        resource_group_name: builtins.str,
        version: builtins.str,
        identity: typing.Optional[typing.List["SqlServerIdentity"]] = None,
        tags: typing.Optional[typing.Mapping[builtins.str, builtins.str]] = None,
        timeouts: typing.Optional["SqlServerTimeouts"] = None,
    ) -> None:
        """
        :param count: 
        :param depends_on: 
        :param lifecycle: 
        :param provider: 
        :param administrator_login: 
        :param administrator_login_password: 
        :param location: 
        :param name: 
        :param resource_group_name: 
        :param version: 
        :param identity: identity block.
        :param tags: 
        :param timeouts: timeouts block.
        """
        if isinstance(lifecycle, dict):
            lifecycle = cdktf.TerraformResourceLifecycle(**lifecycle)
        if isinstance(timeouts, dict):
            timeouts = SqlServerTimeouts(**timeouts)
        self._values: typing.Dict[str, typing.Any] = {
            "administrator_login": administrator_login,
            "administrator_login_password": administrator_login_password,
            "location": location,
            "name": name,
            "resource_group_name": resource_group_name,
            "version": version,
        }
        if count is not None:
            self._values["count"] = count
        if depends_on is not None:
            self._values["depends_on"] = depends_on
        if lifecycle is not None:
            self._values["lifecycle"] = lifecycle
        if provider is not None:
            self._values["provider"] = provider
        if identity is not None:
            self._values["identity"] = identity
        if tags is not None:
            self._values["tags"] = tags
        if timeouts is not None:
            self._values["timeouts"] = timeouts

    @builtins.property
    def count(self) -> typing.Optional[jsii.Number]:
        """
        :stability: experimental
        """
        result = self._values.get("count")
        return result

    @builtins.property
    def depends_on(self) -> typing.Optional[typing.List[cdktf.TerraformResource]]:
        """
        :stability: experimental
        """
        result = self._values.get("depends_on")
        return result

    @builtins.property
    def lifecycle(self) -> typing.Optional[cdktf.TerraformResourceLifecycle]:
        """
        :stability: experimental
        """
        result = self._values.get("lifecycle")
        return result

    @builtins.property
    def provider(self) -> typing.Optional[cdktf.TerraformProvider]:
        """
        :stability: experimental
        """
        result = self._values.get("provider")
        return result

    @builtins.property
    def administrator_login(self) -> builtins.str:
        result = self._values.get("administrator_login")
        assert result is not None, "Required property 'administrator_login' is missing"
        return result

    @builtins.property
    def administrator_login_password(self) -> builtins.str:
        result = self._values.get("administrator_login_password")
        assert result is not None, "Required property 'administrator_login_password' is missing"
        return result

    @builtins.property
    def location(self) -> builtins.str:
        result = self._values.get("location")
        assert result is not None, "Required property 'location' is missing"
        return result

    @builtins.property
    def name(self) -> builtins.str:
        result = self._values.get("name")
        assert result is not None, "Required property 'name' is missing"
        return result

    @builtins.property
    def resource_group_name(self) -> builtins.str:
        result = self._values.get("resource_group_name")
        assert result is not None, "Required property 'resource_group_name' is missing"
        return result

    @builtins.property
    def version(self) -> builtins.str:
        result = self._values.get("version")
        assert result is not None, "Required property 'version' is missing"
        return result

    @builtins.property
    def identity(self) -> typing.Optional[typing.List["SqlServerIdentity"]]:
        """identity block."""
        result = self._values.get("identity")
        return result

    @builtins.property
    def tags(self) -> typing.Optional[typing.Mapping[builtins.str, builtins.str]]:
        result = self._values.get("tags")
        return result

    @builtins.property
    def timeouts(self) -> typing.Optional["SqlServerTimeouts"]:
        """timeouts block."""
        result = self._values.get("timeouts")
        return result

    def __eq__(self, rhs: typing.Any) -> builtins.bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs: typing.Any) -> builtins.bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return "SqlServerConfig(%s)" % ", ".join(
            k + "=" + repr(v) for k, v in self._values.items()
        )


@jsii.data_type(
    jsii_type="@cdktf/provider-azurerm.SqlServerIdentity",
    jsii_struct_bases=[],
    name_mapping={"type": "type"},
)
class SqlServerIdentity:
    def __init__(self, *, type: builtins.str) -> None:
        """
        :param type: 
        """
        self._values: typing.Dict[str, typing.Any] = {
            "type": type,
        }

    @builtins.property
    def type(self) -> builtins.str:
        result = self._values.get("type")
        assert result is not None, "Required property 'type' is missing"
        return result

    def __eq__(self, rhs: typing.Any) -> builtins.bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs: typing.Any) -> builtins.bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return "SqlServerIdentity(%s)" % ", ".join(
            k + "=" + repr(v) for k, v in self._values.items()
        )


@jsii.data_type(
    jsii_type="@cdktf/provider-azurerm.SqlServerTimeouts",
    jsii_struct_bases=[],
    name_mapping={
        "create": "create",
        "delete": "delete",
        "read": "read",
        "update": "update",
    },
)
class SqlServerTimeouts:
    def __init__(
        self,
        *,
        create: typing.Optional[builtins.str] = None,
        delete: typing.Optional[builtins.str] = None,
        read: typing.Optional[builtins.str] = None,
        update: typing.Optional[builtins.str] = None,
    ) -> None:
        """
        :param create: 
        :param delete: 
        :param read: 
        :param update: 
        """
        self._values: typing.Dict[str, typing.Any] = {}
        if create is not None:
            self._values["create"] = create
        if delete is not None:
            self._values["delete"] = delete
        if read is not None:
            self._values["read"] = read
        if update is not None:
            self._values["update"] = update

    @builtins.property
    def create(self) -> typing.Optional[builtins.str]:
        result = self._values.get("create")
        return result

    @builtins.property
    def delete(self) -> typing.Optional[builtins.str]:
        result = self._values.get("delete")
        return result

    @builtins.property
    def read(self) -> typing.Optional[builtins.str]:
        result = self._values.get("read")
        return result

    @builtins.property
    def update(self) -> typing.Optional[builtins.str]:
        result = self._values.get("update")
        return result

    def __eq__(self, rhs: typing.Any) -> builtins.bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs: typing.Any) -> builtins.bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return "SqlServerTimeouts(%s)" % ", ".join(
            k + "=" + repr(v) for k, v in self._values.items()
        )


class SqlVirtualNetworkRule(
    cdktf.TerraformResource,
    metaclass=jsii.JSIIMeta,
    jsii_type="@cdktf/provider-azurerm.SqlVirtualNetworkRule",
):
    def __init__(
        self,
        scope: constructs.Construct,
        id: builtins.str,
        *,
        name: builtins.str,
        resource_group_name: builtins.str,
        server_name: builtins.str,
        subnet_id: builtins.str,
        ignore_missing_vnet_service_endpoint: typing.Optional[builtins.bool] = None,
        timeouts: typing.Optional["SqlVirtualNetworkRuleTimeouts"] = None,
        count: typing.Optional[jsii.Number] = None,
        depends_on: typing.Optional[typing.List[cdktf.TerraformResource]] = None,
        lifecycle: typing.Optional[cdktf.TerraformResourceLifecycle] = None,
        provider: typing.Optional[cdktf.TerraformProvider] = None,
    ) -> None:
        """
        :param scope: -
        :param id: -
        :param name: 
        :param resource_group_name: 
        :param server_name: 
        :param subnet_id: 
        :param ignore_missing_vnet_service_endpoint: 
        :param timeouts: timeouts block.
        :param count: 
        :param depends_on: 
        :param lifecycle: 
        :param provider: 
        """
        config = SqlVirtualNetworkRuleConfig(
            name=name,
            resource_group_name=resource_group_name,
            server_name=server_name,
            subnet_id=subnet_id,
            ignore_missing_vnet_service_endpoint=ignore_missing_vnet_service_endpoint,
            timeouts=timeouts,
            count=count,
            depends_on=depends_on,
            lifecycle=lifecycle,
            provider=provider,
        )

        jsii.create(SqlVirtualNetworkRule, self, [scope, id, config])

    @jsii.member(jsii_name="synthesizeAttributes")
    def _synthesize_attributes(self) -> typing.Mapping[builtins.str, typing.Any]:
        return jsii.invoke(self, "synthesizeAttributes", [])

    @builtins.property # type: ignore
    @jsii.member(jsii_name="name")
    def name(self) -> builtins.str:
        return jsii.get(self, "name")

    @name.setter # type: ignore
    def name(self, value: builtins.str) -> None:
        jsii.set(self, "name", value)

    @builtins.property # type: ignore
    @jsii.member(jsii_name="resourceGroupName")
    def resource_group_name(self) -> builtins.str:
        return jsii.get(self, "resourceGroupName")

    @resource_group_name.setter # type: ignore
    def resource_group_name(self, value: builtins.str) -> None:
        jsii.set(self, "resourceGroupName", value)

    @builtins.property # type: ignore
    @jsii.member(jsii_name="serverName")
    def server_name(self) -> builtins.str:
        return jsii.get(self, "serverName")

    @server_name.setter # type: ignore
    def server_name(self, value: builtins.str) -> None:
        jsii.set(self, "serverName", value)

    @builtins.property # type: ignore
    @jsii.member(jsii_name="subnetId")
    def subnet_id(self) -> builtins.str:
        return jsii.get(self, "subnetId")

    @subnet_id.setter # type: ignore
    def subnet_id(self, value: builtins.str) -> None:
        jsii.set(self, "subnetId", value)

    @builtins.property # type: ignore
    @jsii.member(jsii_name="id")
    def id(self) -> typing.Optional[builtins.str]:
        return jsii.get(self, "id")

    @id.setter # type: ignore
    def id(self, value: typing.Optional[builtins.str]) -> None:
        jsii.set(self, "id", value)

    @builtins.property # type: ignore
    @jsii.member(jsii_name="ignoreMissingVnetServiceEndpoint")
    def ignore_missing_vnet_service_endpoint(self) -> typing.Optional[builtins.bool]:
        return jsii.get(self, "ignoreMissingVnetServiceEndpoint")

    @ignore_missing_vnet_service_endpoint.setter # type: ignore
    def ignore_missing_vnet_service_endpoint(
        self,
        value: typing.Optional[builtins.bool],
    ) -> None:
        jsii.set(self, "ignoreMissingVnetServiceEndpoint", value)

    @builtins.property # type: ignore
    @jsii.member(jsii_name="timeouts")
    def timeouts(self) -> typing.Optional["SqlVirtualNetworkRuleTimeouts"]:
        return jsii.get(self, "timeouts")

    @timeouts.setter # type: ignore
    def timeouts(self, value: typing.Optional["SqlVirtualNetworkRuleTimeouts"]) -> None:
        jsii.set(self, "timeouts", value)


@jsii.data_type(
    jsii_type="@cdktf/provider-azurerm.SqlVirtualNetworkRuleConfig",
    jsii_struct_bases=[cdktf.TerraformMetaArguments],
    name_mapping={
        "count": "count",
        "depends_on": "dependsOn",
        "lifecycle": "lifecycle",
        "provider": "provider",
        "name": "name",
        "resource_group_name": "resourceGroupName",
        "server_name": "serverName",
        "subnet_id": "subnetId",
        "ignore_missing_vnet_service_endpoint": "ignoreMissingVnetServiceEndpoint",
        "timeouts": "timeouts",
    },
)
class SqlVirtualNetworkRuleConfig(cdktf.TerraformMetaArguments):
    def __init__(
        self,
        *,
        count: typing.Optional[jsii.Number] = None,
        depends_on: typing.Optional[typing.List[cdktf.TerraformResource]] = None,
        lifecycle: typing.Optional[cdktf.TerraformResourceLifecycle] = None,
        provider: typing.Optional[cdktf.TerraformProvider] = None,
        name: builtins.str,
        resource_group_name: builtins.str,
        server_name: builtins.str,
        subnet_id: builtins.str,
        ignore_missing_vnet_service_endpoint: typing.Optional[builtins.bool] = None,
        timeouts: typing.Optional["SqlVirtualNetworkRuleTimeouts"] = None,
    ) -> None:
        """
        :param count: 
        :param depends_on: 
        :param lifecycle: 
        :param provider: 
        :param name: 
        :param resource_group_name: 
        :param server_name: 
        :param subnet_id: 
        :param ignore_missing_vnet_service_endpoint: 
        :param timeouts: timeouts block.
        """
        if isinstance(lifecycle, dict):
            lifecycle = cdktf.TerraformResourceLifecycle(**lifecycle)
        if isinstance(timeouts, dict):
            timeouts = SqlVirtualNetworkRuleTimeouts(**timeouts)
        self._values: typing.Dict[str, typing.Any] = {
            "name": name,
            "resource_group_name": resource_group_name,
            "server_name": server_name,
            "subnet_id": subnet_id,
        }
        if count is not None:
            self._values["count"] = count
        if depends_on is not None:
            self._values["depends_on"] = depends_on
        if lifecycle is not None:
            self._values["lifecycle"] = lifecycle
        if provider is not None:
            self._values["provider"] = provider
        if ignore_missing_vnet_service_endpoint is not None:
            self._values["ignore_missing_vnet_service_endpoint"] = ignore_missing_vnet_service_endpoint
        if timeouts is not None:
            self._values["timeouts"] = timeouts

    @builtins.property
    def count(self) -> typing.Optional[jsii.Number]:
        """
        :stability: experimental
        """
        result = self._values.get("count")
        return result

    @builtins.property
    def depends_on(self) -> typing.Optional[typing.List[cdktf.TerraformResource]]:
        """
        :stability: experimental
        """
        result = self._values.get("depends_on")
        return result

    @builtins.property
    def lifecycle(self) -> typing.Optional[cdktf.TerraformResourceLifecycle]:
        """
        :stability: experimental
        """
        result = self._values.get("lifecycle")
        return result

    @builtins.property
    def provider(self) -> typing.Optional[cdktf.TerraformProvider]:
        """
        :stability: experimental
        """
        result = self._values.get("provider")
        return result

    @builtins.property
    def name(self) -> builtins.str:
        result = self._values.get("name")
        assert result is not None, "Required property 'name' is missing"
        return result

    @builtins.property
    def resource_group_name(self) -> builtins.str:
        result = self._values.get("resource_group_name")
        assert result is not None, "Required property 'resource_group_name' is missing"
        return result

    @builtins.property
    def server_name(self) -> builtins.str:
        result = self._values.get("server_name")
        assert result is not None, "Required property 'server_name' is missing"
        return result

    @builtins.property
    def subnet_id(self) -> builtins.str:
        result = self._values.get("subnet_id")
        assert result is not None, "Required property 'subnet_id' is missing"
        return result

    @builtins.property
    def ignore_missing_vnet_service_endpoint(self) -> typing.Optional[builtins.bool]:
        result = self._values.get("ignore_missing_vnet_service_endpoint")
        return result

    @builtins.property
    def timeouts(self) -> typing.Optional["SqlVirtualNetworkRuleTimeouts"]:
        """timeouts block."""
        result = self._values.get("timeouts")
        return result

    def __eq__(self, rhs: typing.Any) -> builtins.bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs: typing.Any) -> builtins.bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return "SqlVirtualNetworkRuleConfig(%s)" % ", ".join(
            k + "=" + repr(v) for k, v in self._values.items()
        )


@jsii.data_type(
    jsii_type="@cdktf/provider-azurerm.SqlVirtualNetworkRuleTimeouts",
    jsii_struct_bases=[],
    name_mapping={
        "create": "create",
        "delete": "delete",
        "read": "read",
        "update": "update",
    },
)
class SqlVirtualNetworkRuleTimeouts:
    def __init__(
        self,
        *,
        create: typing.Optional[builtins.str] = None,
        delete: typing.Optional[builtins.str] = None,
        read: typing.Optional[builtins.str] = None,
        update: typing.Optional[builtins.str] = None,
    ) -> None:
        """
        :param create: 
        :param delete: 
        :param read: 
        :param update: 
        """
        self._values: typing.Dict[str, typing.Any] = {}
        if create is not None:
            self._values["create"] = create
        if delete is not None:
            self._values["delete"] = delete
        if read is not None:
            self._values["read"] = read
        if update is not None:
            self._values["update"] = update

    @builtins.property
    def create(self) -> typing.Optional[builtins.str]:
        result = self._values.get("create")
        return result

    @builtins.property
    def delete(self) -> typing.Optional[builtins.str]:
        result = self._values.get("delete")
        return result

    @builtins.property
    def read(self) -> typing.Optional[builtins.str]:
        result = self._values.get("read")
        return result

    @builtins.property
    def update(self) -> typing.Optional[builtins.str]:
        result = self._values.get("update")
        return result

    def __eq__(self, rhs: typing.Any) -> builtins.bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs: typing.Any) -> builtins.bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return "SqlVirtualNetworkRuleTimeouts(%s)" % ", ".join(
            k + "=" + repr(v) for k, v in self._values.items()
        )


class StorageAccount(
    cdktf.TerraformResource,
    metaclass=jsii.JSIIMeta,
    jsii_type="@cdktf/provider-azurerm.StorageAccount",
):
    def __init__(
        self,
        scope: constructs.Construct,
        id: builtins.str,
        *,
        account_replication_type: builtins.str,
        account_tier: builtins.str,
        location: builtins.str,
        name: builtins.str,
        resource_group_name: builtins.str,
        access_tier: typing.Optional[builtins.str] = None,
        account_kind: typing.Optional[builtins.str] = None,
        blob_properties: typing.Optional[typing.List["StorageAccountBlobProperties"]] = None,
        custom_domain: typing.Optional[typing.List["StorageAccountCustomDomain"]] = None,
        enable_https_traffic_only: typing.Optional[builtins.bool] = None,
        identity: typing.Optional[typing.List["StorageAccountIdentity"]] = None,
        is_hns_enabled: typing.Optional[builtins.bool] = None,
        network_rules: typing.Optional[typing.List["StorageAccountNetworkRules"]] = None,
        queue_properties: typing.Optional[typing.List["StorageAccountQueueProperties"]] = None,
        static_website: typing.Optional[typing.List["StorageAccountStaticWebsite"]] = None,
        tags: typing.Optional[typing.Mapping[builtins.str, builtins.str]] = None,
        timeouts: typing.Optional["StorageAccountTimeouts"] = None,
        count: typing.Optional[jsii.Number] = None,
        depends_on: typing.Optional[typing.List[cdktf.TerraformResource]] = None,
        lifecycle: typing.Optional[cdktf.TerraformResourceLifecycle] = None,
        provider: typing.Optional[cdktf.TerraformProvider] = None,
    ) -> None:
        """
        :param scope: -
        :param id: -
        :param account_replication_type: 
        :param account_tier: 
        :param location: 
        :param name: 
        :param resource_group_name: 
        :param access_tier: 
        :param account_kind: 
        :param blob_properties: blob_properties block.
        :param custom_domain: custom_domain block.
        :param enable_https_traffic_only: 
        :param identity: identity block.
        :param is_hns_enabled: 
        :param network_rules: network_rules block.
        :param queue_properties: queue_properties block.
        :param static_website: static_website block.
        :param tags: 
        :param timeouts: timeouts block.
        :param count: 
        :param depends_on: 
        :param lifecycle: 
        :param provider: 
        """
        config = StorageAccountConfig(
            account_replication_type=account_replication_type,
            account_tier=account_tier,
            location=location,
            name=name,
            resource_group_name=resource_group_name,
            access_tier=access_tier,
            account_kind=account_kind,
            blob_properties=blob_properties,
            custom_domain=custom_domain,
            enable_https_traffic_only=enable_https_traffic_only,
            identity=identity,
            is_hns_enabled=is_hns_enabled,
            network_rules=network_rules,
            queue_properties=queue_properties,
            static_website=static_website,
            tags=tags,
            timeouts=timeouts,
            count=count,
            depends_on=depends_on,
            lifecycle=lifecycle,
            provider=provider,
        )

        jsii.create(StorageAccount, self, [scope, id, config])

    @jsii.member(jsii_name="synthesizeAttributes")
    def _synthesize_attributes(self) -> typing.Mapping[builtins.str, typing.Any]:
        return jsii.invoke(self, "synthesizeAttributes", [])

    @builtins.property # type: ignore
    @jsii.member(jsii_name="primaryAccessKey")
    def primary_access_key(self) -> builtins.str:
        return jsii.get(self, "primaryAccessKey")

    @builtins.property # type: ignore
    @jsii.member(jsii_name="primaryBlobConnectionString")
    def primary_blob_connection_string(self) -> builtins.str:
        return jsii.get(self, "primaryBlobConnectionString")

    @builtins.property # type: ignore
    @jsii.member(jsii_name="primaryBlobEndpoint")
    def primary_blob_endpoint(self) -> builtins.str:
        return jsii.get(self, "primaryBlobEndpoint")

    @builtins.property # type: ignore
    @jsii.member(jsii_name="primaryBlobHost")
    def primary_blob_host(self) -> builtins.str:
        return jsii.get(self, "primaryBlobHost")

    @builtins.property # type: ignore
    @jsii.member(jsii_name="primaryConnectionString")
    def primary_connection_string(self) -> builtins.str:
        return jsii.get(self, "primaryConnectionString")

    @builtins.property # type: ignore
    @jsii.member(jsii_name="primaryDfsEndpoint")
    def primary_dfs_endpoint(self) -> builtins.str:
        return jsii.get(self, "primaryDfsEndpoint")

    @builtins.property # type: ignore
    @jsii.member(jsii_name="primaryDfsHost")
    def primary_dfs_host(self) -> builtins.str:
        return jsii.get(self, "primaryDfsHost")

    @builtins.property # type: ignore
    @jsii.member(jsii_name="primaryFileEndpoint")
    def primary_file_endpoint(self) -> builtins.str:
        return jsii.get(self, "primaryFileEndpoint")

    @builtins.property # type: ignore
    @jsii.member(jsii_name="primaryFileHost")
    def primary_file_host(self) -> builtins.str:
        return jsii.get(self, "primaryFileHost")

    @builtins.property # type: ignore
    @jsii.member(jsii_name="primaryLocation")
    def primary_location(self) -> builtins.str:
        return jsii.get(self, "primaryLocation")

    @builtins.property # type: ignore
    @jsii.member(jsii_name="primaryQueueEndpoint")
    def primary_queue_endpoint(self) -> builtins.str:
        return jsii.get(self, "primaryQueueEndpoint")

    @builtins.property # type: ignore
    @jsii.member(jsii_name="primaryQueueHost")
    def primary_queue_host(self) -> builtins.str:
        return jsii.get(self, "primaryQueueHost")

    @builtins.property # type: ignore
    @jsii.member(jsii_name="primaryTableEndpoint")
    def primary_table_endpoint(self) -> builtins.str:
        return jsii.get(self, "primaryTableEndpoint")

    @builtins.property # type: ignore
    @jsii.member(jsii_name="primaryTableHost")
    def primary_table_host(self) -> builtins.str:
        return jsii.get(self, "primaryTableHost")

    @builtins.property # type: ignore
    @jsii.member(jsii_name="primaryWebEndpoint")
    def primary_web_endpoint(self) -> builtins.str:
        return jsii.get(self, "primaryWebEndpoint")

    @builtins.property # type: ignore
    @jsii.member(jsii_name="primaryWebHost")
    def primary_web_host(self) -> builtins.str:
        return jsii.get(self, "primaryWebHost")

    @builtins.property # type: ignore
    @jsii.member(jsii_name="secondaryAccessKey")
    def secondary_access_key(self) -> builtins.str:
        return jsii.get(self, "secondaryAccessKey")

    @builtins.property # type: ignore
    @jsii.member(jsii_name="secondaryBlobConnectionString")
    def secondary_blob_connection_string(self) -> builtins.str:
        return jsii.get(self, "secondaryBlobConnectionString")

    @builtins.property # type: ignore
    @jsii.member(jsii_name="secondaryBlobEndpoint")
    def secondary_blob_endpoint(self) -> builtins.str:
        return jsii.get(self, "secondaryBlobEndpoint")

    @builtins.property # type: ignore
    @jsii.member(jsii_name="secondaryBlobHost")
    def secondary_blob_host(self) -> builtins.str:
        return jsii.get(self, "secondaryBlobHost")

    @builtins.property # type: ignore
    @jsii.member(jsii_name="secondaryConnectionString")
    def secondary_connection_string(self) -> builtins.str:
        return jsii.get(self, "secondaryConnectionString")

    @builtins.property # type: ignore
    @jsii.member(jsii_name="secondaryDfsEndpoint")
    def secondary_dfs_endpoint(self) -> builtins.str:
        return jsii.get(self, "secondaryDfsEndpoint")

    @builtins.property # type: ignore
    @jsii.member(jsii_name="secondaryDfsHost")
    def secondary_dfs_host(self) -> builtins.str:
        return jsii.get(self, "secondaryDfsHost")

    @builtins.property # type: ignore
    @jsii.member(jsii_name="secondaryFileEndpoint")
    def secondary_file_endpoint(self) -> builtins.str:
        return jsii.get(self, "secondaryFileEndpoint")

    @builtins.property # type: ignore
    @jsii.member(jsii_name="secondaryFileHost")
    def secondary_file_host(self) -> builtins.str:
        return jsii.get(self, "secondaryFileHost")

    @builtins.property # type: ignore
    @jsii.member(jsii_name="secondaryLocation")
    def secondary_location(self) -> builtins.str:
        return jsii.get(self, "secondaryLocation")

    @builtins.property # type: ignore
    @jsii.member(jsii_name="secondaryQueueEndpoint")
    def secondary_queue_endpoint(self) -> builtins.str:
        return jsii.get(self, "secondaryQueueEndpoint")

    @builtins.property # type: ignore
    @jsii.member(jsii_name="secondaryQueueHost")
    def secondary_queue_host(self) -> builtins.str:
        return jsii.get(self, "secondaryQueueHost")

    @builtins.property # type: ignore
    @jsii.member(jsii_name="secondaryTableEndpoint")
    def secondary_table_endpoint(self) -> builtins.str:
        return jsii.get(self, "secondaryTableEndpoint")

    @builtins.property # type: ignore
    @jsii.member(jsii_name="secondaryTableHost")
    def secondary_table_host(self) -> builtins.str:
        return jsii.get(self, "secondaryTableHost")

    @builtins.property # type: ignore
    @jsii.member(jsii_name="secondaryWebEndpoint")
    def secondary_web_endpoint(self) -> builtins.str:
        return jsii.get(self, "secondaryWebEndpoint")

    @builtins.property # type: ignore
    @jsii.member(jsii_name="secondaryWebHost")
    def secondary_web_host(self) -> builtins.str:
        return jsii.get(self, "secondaryWebHost")

    @builtins.property # type: ignore
    @jsii.member(jsii_name="accountReplicationType")
    def account_replication_type(self) -> builtins.str:
        return jsii.get(self, "accountReplicationType")

    @account_replication_type.setter # type: ignore
    def account_replication_type(self, value: builtins.str) -> None:
        jsii.set(self, "accountReplicationType", value)

    @builtins.property # type: ignore
    @jsii.member(jsii_name="accountTier")
    def account_tier(self) -> builtins.str:
        return jsii.get(self, "accountTier")

    @account_tier.setter # type: ignore
    def account_tier(self, value: builtins.str) -> None:
        jsii.set(self, "accountTier", value)

    @builtins.property # type: ignore
    @jsii.member(jsii_name="location")
    def location(self) -> builtins.str:
        return jsii.get(self, "location")

    @location.setter # type: ignore
    def location(self, value: builtins.str) -> None:
        jsii.set(self, "location", value)

    @builtins.property # type: ignore
    @jsii.member(jsii_name="name")
    def name(self) -> builtins.str:
        return jsii.get(self, "name")

    @name.setter # type: ignore
    def name(self, value: builtins.str) -> None:
        jsii.set(self, "name", value)

    @builtins.property # type: ignore
    @jsii.member(jsii_name="resourceGroupName")
    def resource_group_name(self) -> builtins.str:
        return jsii.get(self, "resourceGroupName")

    @resource_group_name.setter # type: ignore
    def resource_group_name(self, value: builtins.str) -> None:
        jsii.set(self, "resourceGroupName", value)

    @builtins.property # type: ignore
    @jsii.member(jsii_name="accessTier")
    def access_tier(self) -> typing.Optional[builtins.str]:
        return jsii.get(self, "accessTier")

    @access_tier.setter # type: ignore
    def access_tier(self, value: typing.Optional[builtins.str]) -> None:
        jsii.set(self, "accessTier", value)

    @builtins.property # type: ignore
    @jsii.member(jsii_name="accountKind")
    def account_kind(self) -> typing.Optional[builtins.str]:
        return jsii.get(self, "accountKind")

    @account_kind.setter # type: ignore
    def account_kind(self, value: typing.Optional[builtins.str]) -> None:
        jsii.set(self, "accountKind", value)

    @builtins.property # type: ignore
    @jsii.member(jsii_name="blobProperties")
    def blob_properties(
        self,
    ) -> typing.Optional[typing.List["StorageAccountBlobProperties"]]:
        return jsii.get(self, "blobProperties")

    @blob_properties.setter # type: ignore
    def blob_properties(
        self,
        value: typing.Optional[typing.List["StorageAccountBlobProperties"]],
    ) -> None:
        jsii.set(self, "blobProperties", value)

    @builtins.property # type: ignore
    @jsii.member(jsii_name="customDomain")
    def custom_domain(
        self,
    ) -> typing.Optional[typing.List["StorageAccountCustomDomain"]]:
        return jsii.get(self, "customDomain")

    @custom_domain.setter # type: ignore
    def custom_domain(
        self,
        value: typing.Optional[typing.List["StorageAccountCustomDomain"]],
    ) -> None:
        jsii.set(self, "customDomain", value)

    @builtins.property # type: ignore
    @jsii.member(jsii_name="enableHttpsTrafficOnly")
    def enable_https_traffic_only(self) -> typing.Optional[builtins.bool]:
        return jsii.get(self, "enableHttpsTrafficOnly")

    @enable_https_traffic_only.setter # type: ignore
    def enable_https_traffic_only(self, value: typing.Optional[builtins.bool]) -> None:
        jsii.set(self, "enableHttpsTrafficOnly", value)

    @builtins.property # type: ignore
    @jsii.member(jsii_name="id")
    def id(self) -> typing.Optional[builtins.str]:
        return jsii.get(self, "id")

    @id.setter # type: ignore
    def id(self, value: typing.Optional[builtins.str]) -> None:
        jsii.set(self, "id", value)

    @builtins.property # type: ignore
    @jsii.member(jsii_name="identity")
    def identity(self) -> typing.Optional[typing.List["StorageAccountIdentity"]]:
        return jsii.get(self, "identity")

    @identity.setter # type: ignore
    def identity(
        self,
        value: typing.Optional[typing.List["StorageAccountIdentity"]],
    ) -> None:
        jsii.set(self, "identity", value)

    @builtins.property # type: ignore
    @jsii.member(jsii_name="isHnsEnabled")
    def is_hns_enabled(self) -> typing.Optional[builtins.bool]:
        return jsii.get(self, "isHnsEnabled")

    @is_hns_enabled.setter # type: ignore
    def is_hns_enabled(self, value: typing.Optional[builtins.bool]) -> None:
        jsii.set(self, "isHnsEnabled", value)

    @builtins.property # type: ignore
    @jsii.member(jsii_name="networkRules")
    def network_rules(
        self,
    ) -> typing.Optional[typing.List["StorageAccountNetworkRules"]]:
        return jsii.get(self, "networkRules")

    @network_rules.setter # type: ignore
    def network_rules(
        self,
        value: typing.Optional[typing.List["StorageAccountNetworkRules"]],
    ) -> None:
        jsii.set(self, "networkRules", value)

    @builtins.property # type: ignore
    @jsii.member(jsii_name="queueProperties")
    def queue_properties(
        self,
    ) -> typing.Optional[typing.List["StorageAccountQueueProperties"]]:
        return jsii.get(self, "queueProperties")

    @queue_properties.setter # type: ignore
    def queue_properties(
        self,
        value: typing.Optional[typing.List["StorageAccountQueueProperties"]],
    ) -> None:
        jsii.set(self, "queueProperties", value)

    @builtins.property # type: ignore
    @jsii.member(jsii_name="staticWebsite")
    def static_website(
        self,
    ) -> typing.Optional[typing.List["StorageAccountStaticWebsite"]]:
        return jsii.get(self, "staticWebsite")

    @static_website.setter # type: ignore
    def static_website(
        self,
        value: typing.Optional[typing.List["StorageAccountStaticWebsite"]],
    ) -> None:
        jsii.set(self, "staticWebsite", value)

    @builtins.property # type: ignore
    @jsii.member(jsii_name="tags")
    def tags(self) -> typing.Optional[typing.Mapping[builtins.str, builtins.str]]:
        return jsii.get(self, "tags")

    @tags.setter # type: ignore
    def tags(
        self,
        value: typing.Optional[typing.Mapping[builtins.str, builtins.str]],
    ) -> None:
        jsii.set(self, "tags", value)

    @builtins.property # type: ignore
    @jsii.member(jsii_name="timeouts")
    def timeouts(self) -> typing.Optional["StorageAccountTimeouts"]:
        return jsii.get(self, "timeouts")

    @timeouts.setter # type: ignore
    def timeouts(self, value: typing.Optional["StorageAccountTimeouts"]) -> None:
        jsii.set(self, "timeouts", value)


@jsii.data_type(
    jsii_type="@cdktf/provider-azurerm.StorageAccountBlobProperties",
    jsii_struct_bases=[],
    name_mapping={
        "cors_rule": "corsRule",
        "delete_retention_policy": "deleteRetentionPolicy",
    },
)
class StorageAccountBlobProperties:
    def __init__(
        self,
        *,
        cors_rule: typing.Optional[typing.List["StorageAccountBlobPropertiesCorsRule"]] = None,
        delete_retention_policy: typing.Optional[typing.List["StorageAccountBlobPropertiesDeleteRetentionPolicy"]] = None,
    ) -> None:
        """
        :param cors_rule: cors_rule block.
        :param delete_retention_policy: delete_retention_policy block.
        """
        self._values: typing.Dict[str, typing.Any] = {}
        if cors_rule is not None:
            self._values["cors_rule"] = cors_rule
        if delete_retention_policy is not None:
            self._values["delete_retention_policy"] = delete_retention_policy

    @builtins.property
    def cors_rule(
        self,
    ) -> typing.Optional[typing.List["StorageAccountBlobPropertiesCorsRule"]]:
        """cors_rule block."""
        result = self._values.get("cors_rule")
        return result

    @builtins.property
    def delete_retention_policy(
        self,
    ) -> typing.Optional[typing.List["StorageAccountBlobPropertiesDeleteRetentionPolicy"]]:
        """delete_retention_policy block."""
        result = self._values.get("delete_retention_policy")
        return result

    def __eq__(self, rhs: typing.Any) -> builtins.bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs: typing.Any) -> builtins.bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return "StorageAccountBlobProperties(%s)" % ", ".join(
            k + "=" + repr(v) for k, v in self._values.items()
        )


@jsii.data_type(
    jsii_type="@cdktf/provider-azurerm.StorageAccountBlobPropertiesCorsRule",
    jsii_struct_bases=[],
    name_mapping={
        "allowed_headers": "allowedHeaders",
        "allowed_methods": "allowedMethods",
        "allowed_origins": "allowedOrigins",
        "exposed_headers": "exposedHeaders",
        "max_age_in_seconds": "maxAgeInSeconds",
    },
)
class StorageAccountBlobPropertiesCorsRule:
    def __init__(
        self,
        *,
        allowed_headers: typing.List[builtins.str],
        allowed_methods: typing.List[builtins.str],
        allowed_origins: typing.List[builtins.str],
        exposed_headers: typing.List[builtins.str],
        max_age_in_seconds: jsii.Number,
    ) -> None:
        """
        :param allowed_headers: 
        :param allowed_methods: 
        :param allowed_origins: 
        :param exposed_headers: 
        :param max_age_in_seconds: 
        """
        self._values: typing.Dict[str, typing.Any] = {
            "allowed_headers": allowed_headers,
            "allowed_methods": allowed_methods,
            "allowed_origins": allowed_origins,
            "exposed_headers": exposed_headers,
            "max_age_in_seconds": max_age_in_seconds,
        }

    @builtins.property
    def allowed_headers(self) -> typing.List[builtins.str]:
        result = self._values.get("allowed_headers")
        assert result is not None, "Required property 'allowed_headers' is missing"
        return result

    @builtins.property
    def allowed_methods(self) -> typing.List[builtins.str]:
        result = self._values.get("allowed_methods")
        assert result is not None, "Required property 'allowed_methods' is missing"
        return result

    @builtins.property
    def allowed_origins(self) -> typing.List[builtins.str]:
        result = self._values.get("allowed_origins")
        assert result is not None, "Required property 'allowed_origins' is missing"
        return result

    @builtins.property
    def exposed_headers(self) -> typing.List[builtins.str]:
        result = self._values.get("exposed_headers")
        assert result is not None, "Required property 'exposed_headers' is missing"
        return result

    @builtins.property
    def max_age_in_seconds(self) -> jsii.Number:
        result = self._values.get("max_age_in_seconds")
        assert result is not None, "Required property 'max_age_in_seconds' is missing"
        return result

    def __eq__(self, rhs: typing.Any) -> builtins.bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs: typing.Any) -> builtins.bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return "StorageAccountBlobPropertiesCorsRule(%s)" % ", ".join(
            k + "=" + repr(v) for k, v in self._values.items()
        )


@jsii.data_type(
    jsii_type="@cdktf/provider-azurerm.StorageAccountBlobPropertiesDeleteRetentionPolicy",
    jsii_struct_bases=[],
    name_mapping={"days": "days"},
)
class StorageAccountBlobPropertiesDeleteRetentionPolicy:
    def __init__(self, *, days: typing.Optional[jsii.Number] = None) -> None:
        """
        :param days: 
        """
        self._values: typing.Dict[str, typing.Any] = {}
        if days is not None:
            self._values["days"] = days

    @builtins.property
    def days(self) -> typing.Optional[jsii.Number]:
        result = self._values.get("days")
        return result

    def __eq__(self, rhs: typing.Any) -> builtins.bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs: typing.Any) -> builtins.bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return "StorageAccountBlobPropertiesDeleteRetentionPolicy(%s)" % ", ".join(
            k + "=" + repr(v) for k, v in self._values.items()
        )


@jsii.data_type(
    jsii_type="@cdktf/provider-azurerm.StorageAccountConfig",
    jsii_struct_bases=[cdktf.TerraformMetaArguments],
    name_mapping={
        "count": "count",
        "depends_on": "dependsOn",
        "lifecycle": "lifecycle",
        "provider": "provider",
        "account_replication_type": "accountReplicationType",
        "account_tier": "accountTier",
        "location": "location",
        "name": "name",
        "resource_group_name": "resourceGroupName",
        "access_tier": "accessTier",
        "account_kind": "accountKind",
        "blob_properties": "blobProperties",
        "custom_domain": "customDomain",
        "enable_https_traffic_only": "enableHttpsTrafficOnly",
        "identity": "identity",
        "is_hns_enabled": "isHnsEnabled",
        "network_rules": "networkRules",
        "queue_properties": "queueProperties",
        "static_website": "staticWebsite",
        "tags": "tags",
        "timeouts": "timeouts",
    },
)
class StorageAccountConfig(cdktf.TerraformMetaArguments):
    def __init__(
        self,
        *,
        count: typing.Optional[jsii.Number] = None,
        depends_on: typing.Optional[typing.List[cdktf.TerraformResource]] = None,
        lifecycle: typing.Optional[cdktf.TerraformResourceLifecycle] = None,
        provider: typing.Optional[cdktf.TerraformProvider] = None,
        account_replication_type: builtins.str,
        account_tier: builtins.str,
        location: builtins.str,
        name: builtins.str,
        resource_group_name: builtins.str,
        access_tier: typing.Optional[builtins.str] = None,
        account_kind: typing.Optional[builtins.str] = None,
        blob_properties: typing.Optional[typing.List[StorageAccountBlobProperties]] = None,
        custom_domain: typing.Optional[typing.List["StorageAccountCustomDomain"]] = None,
        enable_https_traffic_only: typing.Optional[builtins.bool] = None,
        identity: typing.Optional[typing.List["StorageAccountIdentity"]] = None,
        is_hns_enabled: typing.Optional[builtins.bool] = None,
        network_rules: typing.Optional[typing.List["StorageAccountNetworkRules"]] = None,
        queue_properties: typing.Optional[typing.List["StorageAccountQueueProperties"]] = None,
        static_website: typing.Optional[typing.List["StorageAccountStaticWebsite"]] = None,
        tags: typing.Optional[typing.Mapping[builtins.str, builtins.str]] = None,
        timeouts: typing.Optional["StorageAccountTimeouts"] = None,
    ) -> None:
        """
        :param count: 
        :param depends_on: 
        :param lifecycle: 
        :param provider: 
        :param account_replication_type: 
        :param account_tier: 
        :param location: 
        :param name: 
        :param resource_group_name: 
        :param access_tier: 
        :param account_kind: 
        :param blob_properties: blob_properties block.
        :param custom_domain: custom_domain block.
        :param enable_https_traffic_only: 
        :param identity: identity block.
        :param is_hns_enabled: 
        :param network_rules: network_rules block.
        :param queue_properties: queue_properties block.
        :param static_website: static_website block.
        :param tags: 
        :param timeouts: timeouts block.
        """
        if isinstance(lifecycle, dict):
            lifecycle = cdktf.TerraformResourceLifecycle(**lifecycle)
        if isinstance(timeouts, dict):
            timeouts = StorageAccountTimeouts(**timeouts)
        self._values: typing.Dict[str, typing.Any] = {
            "account_replication_type": account_replication_type,
            "account_tier": account_tier,
            "location": location,
            "name": name,
            "resource_group_name": resource_group_name,
        }
        if count is not None:
            self._values["count"] = count
        if depends_on is not None:
            self._values["depends_on"] = depends_on
        if lifecycle is not None:
            self._values["lifecycle"] = lifecycle
        if provider is not None:
            self._values["provider"] = provider
        if access_tier is not None:
            self._values["access_tier"] = access_tier
        if account_kind is not None:
            self._values["account_kind"] = account_kind
        if blob_properties is not None:
            self._values["blob_properties"] = blob_properties
        if custom_domain is not None:
            self._values["custom_domain"] = custom_domain
        if enable_https_traffic_only is not None:
            self._values["enable_https_traffic_only"] = enable_https_traffic_only
        if identity is not None:
            self._values["identity"] = identity
        if is_hns_enabled is not None:
            self._values["is_hns_enabled"] = is_hns_enabled
        if network_rules is not None:
            self._values["network_rules"] = network_rules
        if queue_properties is not None:
            self._values["queue_properties"] = queue_properties
        if static_website is not None:
            self._values["static_website"] = static_website
        if tags is not None:
            self._values["tags"] = tags
        if timeouts is not None:
            self._values["timeouts"] = timeouts

    @builtins.property
    def count(self) -> typing.Optional[jsii.Number]:
        """
        :stability: experimental
        """
        result = self._values.get("count")
        return result

    @builtins.property
    def depends_on(self) -> typing.Optional[typing.List[cdktf.TerraformResource]]:
        """
        :stability: experimental
        """
        result = self._values.get("depends_on")
        return result

    @builtins.property
    def lifecycle(self) -> typing.Optional[cdktf.TerraformResourceLifecycle]:
        """
        :stability: experimental
        """
        result = self._values.get("lifecycle")
        return result

    @builtins.property
    def provider(self) -> typing.Optional[cdktf.TerraformProvider]:
        """
        :stability: experimental
        """
        result = self._values.get("provider")
        return result

    @builtins.property
    def account_replication_type(self) -> builtins.str:
        result = self._values.get("account_replication_type")
        assert result is not None, "Required property 'account_replication_type' is missing"
        return result

    @builtins.property
    def account_tier(self) -> builtins.str:
        result = self._values.get("account_tier")
        assert result is not None, "Required property 'account_tier' is missing"
        return result

    @builtins.property
    def location(self) -> builtins.str:
        result = self._values.get("location")
        assert result is not None, "Required property 'location' is missing"
        return result

    @builtins.property
    def name(self) -> builtins.str:
        result = self._values.get("name")
        assert result is not None, "Required property 'name' is missing"
        return result

    @builtins.property
    def resource_group_name(self) -> builtins.str:
        result = self._values.get("resource_group_name")
        assert result is not None, "Required property 'resource_group_name' is missing"
        return result

    @builtins.property
    def access_tier(self) -> typing.Optional[builtins.str]:
        result = self._values.get("access_tier")
        return result

    @builtins.property
    def account_kind(self) -> typing.Optional[builtins.str]:
        result = self._values.get("account_kind")
        return result

    @builtins.property
    def blob_properties(
        self,
    ) -> typing.Optional[typing.List[StorageAccountBlobProperties]]:
        """blob_properties block."""
        result = self._values.get("blob_properties")
        return result

    @builtins.property
    def custom_domain(
        self,
    ) -> typing.Optional[typing.List["StorageAccountCustomDomain"]]:
        """custom_domain block."""
        result = self._values.get("custom_domain")
        return result

    @builtins.property
    def enable_https_traffic_only(self) -> typing.Optional[builtins.bool]:
        result = self._values.get("enable_https_traffic_only")
        return result

    @builtins.property
    def identity(self) -> typing.Optional[typing.List["StorageAccountIdentity"]]:
        """identity block."""
        result = self._values.get("identity")
        return result

    @builtins.property
    def is_hns_enabled(self) -> typing.Optional[builtins.bool]:
        result = self._values.get("is_hns_enabled")
        return result

    @builtins.property
    def network_rules(
        self,
    ) -> typing.Optional[typing.List["StorageAccountNetworkRules"]]:
        """network_rules block."""
        result = self._values.get("network_rules")
        return result

    @builtins.property
    def queue_properties(
        self,
    ) -> typing.Optional[typing.List["StorageAccountQueueProperties"]]:
        """queue_properties block."""
        result = self._values.get("queue_properties")
        return result

    @builtins.property
    def static_website(
        self,
    ) -> typing.Optional[typing.List["StorageAccountStaticWebsite"]]:
        """static_website block."""
        result = self._values.get("static_website")
        return result

    @builtins.property
    def tags(self) -> typing.Optional[typing.Mapping[builtins.str, builtins.str]]:
        result = self._values.get("tags")
        return result

    @builtins.property
    def timeouts(self) -> typing.Optional["StorageAccountTimeouts"]:
        """timeouts block."""
        result = self._values.get("timeouts")
        return result

    def __eq__(self, rhs: typing.Any) -> builtins.bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs: typing.Any) -> builtins.bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return "StorageAccountConfig(%s)" % ", ".join(
            k + "=" + repr(v) for k, v in self._values.items()
        )


@jsii.data_type(
    jsii_type="@cdktf/provider-azurerm.StorageAccountCustomDomain",
    jsii_struct_bases=[],
    name_mapping={"name": "name", "use_subdomain": "useSubdomain"},
)
class StorageAccountCustomDomain:
    def __init__(
        self,
        *,
        name: builtins.str,
        use_subdomain: typing.Optional[builtins.bool] = None,
    ) -> None:
        """
        :param name: 
        :param use_subdomain: 
        """
        self._values: typing.Dict[str, typing.Any] = {
            "name": name,
        }
        if use_subdomain is not None:
            self._values["use_subdomain"] = use_subdomain

    @builtins.property
    def name(self) -> builtins.str:
        result = self._values.get("name")
        assert result is not None, "Required property 'name' is missing"
        return result

    @builtins.property
    def use_subdomain(self) -> typing.Optional[builtins.bool]:
        result = self._values.get("use_subdomain")
        return result

    def __eq__(self, rhs: typing.Any) -> builtins.bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs: typing.Any) -> builtins.bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return "StorageAccountCustomDomain(%s)" % ", ".join(
            k + "=" + repr(v) for k, v in self._values.items()
        )


class StorageAccountCustomerManagedKey(
    cdktf.TerraformResource,
    metaclass=jsii.JSIIMeta,
    jsii_type="@cdktf/provider-azurerm.StorageAccountCustomerManagedKey",
):
    def __init__(
        self,
        scope: constructs.Construct,
        id: builtins.str,
        *,
        key_name: builtins.str,
        key_vault_id: builtins.str,
        key_version: builtins.str,
        storage_account_id: builtins.str,
        timeouts: typing.Optional["StorageAccountCustomerManagedKeyTimeouts"] = None,
        count: typing.Optional[jsii.Number] = None,
        depends_on: typing.Optional[typing.List[cdktf.TerraformResource]] = None,
        lifecycle: typing.Optional[cdktf.TerraformResourceLifecycle] = None,
        provider: typing.Optional[cdktf.TerraformProvider] = None,
    ) -> None:
        """
        :param scope: -
        :param id: -
        :param key_name: 
        :param key_vault_id: 
        :param key_version: 
        :param storage_account_id: 
        :param timeouts: timeouts block.
        :param count: 
        :param depends_on: 
        :param lifecycle: 
        :param provider: 
        """
        config = StorageAccountCustomerManagedKeyConfig(
            key_name=key_name,
            key_vault_id=key_vault_id,
            key_version=key_version,
            storage_account_id=storage_account_id,
            timeouts=timeouts,
            count=count,
            depends_on=depends_on,
            lifecycle=lifecycle,
            provider=provider,
        )

        jsii.create(StorageAccountCustomerManagedKey, self, [scope, id, config])

    @jsii.member(jsii_name="synthesizeAttributes")
    def _synthesize_attributes(self) -> typing.Mapping[builtins.str, typing.Any]:
        return jsii.invoke(self, "synthesizeAttributes", [])

    @builtins.property # type: ignore
    @jsii.member(jsii_name="keyName")
    def key_name(self) -> builtins.str:
        return jsii.get(self, "keyName")

    @key_name.setter # type: ignore
    def key_name(self, value: builtins.str) -> None:
        jsii.set(self, "keyName", value)

    @builtins.property # type: ignore
    @jsii.member(jsii_name="keyVaultId")
    def key_vault_id(self) -> builtins.str:
        return jsii.get(self, "keyVaultId")

    @key_vault_id.setter # type: ignore
    def key_vault_id(self, value: builtins.str) -> None:
        jsii.set(self, "keyVaultId", value)

    @builtins.property # type: ignore
    @jsii.member(jsii_name="keyVersion")
    def key_version(self) -> builtins.str:
        return jsii.get(self, "keyVersion")

    @key_version.setter # type: ignore
    def key_version(self, value: builtins.str) -> None:
        jsii.set(self, "keyVersion", value)

    @builtins.property # type: ignore
    @jsii.member(jsii_name="storageAccountId")
    def storage_account_id(self) -> builtins.str:
        return jsii.get(self, "storageAccountId")

    @storage_account_id.setter # type: ignore
    def storage_account_id(self, value: builtins.str) -> None:
        jsii.set(self, "storageAccountId", value)

    @builtins.property # type: ignore
    @jsii.member(jsii_name="id")
    def id(self) -> typing.Optional[builtins.str]:
        return jsii.get(self, "id")

    @id.setter # type: ignore
    def id(self, value: typing.Optional[builtins.str]) -> None:
        jsii.set(self, "id", value)

    @builtins.property # type: ignore
    @jsii.member(jsii_name="timeouts")
    def timeouts(self) -> typing.Optional["StorageAccountCustomerManagedKeyTimeouts"]:
        return jsii.get(self, "timeouts")

    @timeouts.setter # type: ignore
    def timeouts(
        self,
        value: typing.Optional["StorageAccountCustomerManagedKeyTimeouts"],
    ) -> None:
        jsii.set(self, "timeouts", value)


@jsii.data_type(
    jsii_type="@cdktf/provider-azurerm.StorageAccountCustomerManagedKeyConfig",
    jsii_struct_bases=[cdktf.TerraformMetaArguments],
    name_mapping={
        "count": "count",
        "depends_on": "dependsOn",
        "lifecycle": "lifecycle",
        "provider": "provider",
        "key_name": "keyName",
        "key_vault_id": "keyVaultId",
        "key_version": "keyVersion",
        "storage_account_id": "storageAccountId",
        "timeouts": "timeouts",
    },
)
class StorageAccountCustomerManagedKeyConfig(cdktf.TerraformMetaArguments):
    def __init__(
        self,
        *,
        count: typing.Optional[jsii.Number] = None,
        depends_on: typing.Optional[typing.List[cdktf.TerraformResource]] = None,
        lifecycle: typing.Optional[cdktf.TerraformResourceLifecycle] = None,
        provider: typing.Optional[cdktf.TerraformProvider] = None,
        key_name: builtins.str,
        key_vault_id: builtins.str,
        key_version: builtins.str,
        storage_account_id: builtins.str,
        timeouts: typing.Optional["StorageAccountCustomerManagedKeyTimeouts"] = None,
    ) -> None:
        """
        :param count: 
        :param depends_on: 
        :param lifecycle: 
        :param provider: 
        :param key_name: 
        :param key_vault_id: 
        :param key_version: 
        :param storage_account_id: 
        :param timeouts: timeouts block.
        """
        if isinstance(lifecycle, dict):
            lifecycle = cdktf.TerraformResourceLifecycle(**lifecycle)
        if isinstance(timeouts, dict):
            timeouts = StorageAccountCustomerManagedKeyTimeouts(**timeouts)
        self._values: typing.Dict[str, typing.Any] = {
            "key_name": key_name,
            "key_vault_id": key_vault_id,
            "key_version": key_version,
            "storage_account_id": storage_account_id,
        }
        if count is not None:
            self._values["count"] = count
        if depends_on is not None:
            self._values["depends_on"] = depends_on
        if lifecycle is not None:
            self._values["lifecycle"] = lifecycle
        if provider is not None:
            self._values["provider"] = provider
        if timeouts is not None:
            self._values["timeouts"] = timeouts

    @builtins.property
    def count(self) -> typing.Optional[jsii.Number]:
        """
        :stability: experimental
        """
        result = self._values.get("count")
        return result

    @builtins.property
    def depends_on(self) -> typing.Optional[typing.List[cdktf.TerraformResource]]:
        """
        :stability: experimental
        """
        result = self._values.get("depends_on")
        return result

    @builtins.property
    def lifecycle(self) -> typing.Optional[cdktf.TerraformResourceLifecycle]:
        """
        :stability: experimental
        """
        result = self._values.get("lifecycle")
        return result

    @builtins.property
    def provider(self) -> typing.Optional[cdktf.TerraformProvider]:
        """
        :stability: experimental
        """
        result = self._values.get("provider")
        return result

    @builtins.property
    def key_name(self) -> builtins.str:
        result = self._values.get("key_name")
        assert result is not None, "Required property 'key_name' is missing"
        return result

    @builtins.property
    def key_vault_id(self) -> builtins.str:
        result = self._values.get("key_vault_id")
        assert result is not None, "Required property 'key_vault_id' is missing"
        return result

    @builtins.property
    def key_version(self) -> builtins.str:
        result = self._values.get("key_version")
        assert result is not None, "Required property 'key_version' is missing"
        return result

    @builtins.property
    def storage_account_id(self) -> builtins.str:
        result = self._values.get("storage_account_id")
        assert result is not None, "Required property 'storage_account_id' is missing"
        return result

    @builtins.property
    def timeouts(self) -> typing.Optional["StorageAccountCustomerManagedKeyTimeouts"]:
        """timeouts block."""
        result = self._values.get("timeouts")
        return result

    def __eq__(self, rhs: typing.Any) -> builtins.bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs: typing.Any) -> builtins.bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return "StorageAccountCustomerManagedKeyConfig(%s)" % ", ".join(
            k + "=" + repr(v) for k, v in self._values.items()
        )


@jsii.data_type(
    jsii_type="@cdktf/provider-azurerm.StorageAccountCustomerManagedKeyTimeouts",
    jsii_struct_bases=[],
    name_mapping={
        "create": "create",
        "delete": "delete",
        "read": "read",
        "update": "update",
    },
)
class StorageAccountCustomerManagedKeyTimeouts:
    def __init__(
        self,
        *,
        create: typing.Optional[builtins.str] = None,
        delete: typing.Optional[builtins.str] = None,
        read: typing.Optional[builtins.str] = None,
        update: typing.Optional[builtins.str] = None,
    ) -> None:
        """
        :param create: 
        :param delete: 
        :param read: 
        :param update: 
        """
        self._values: typing.Dict[str, typing.Any] = {}
        if create is not None:
            self._values["create"] = create
        if delete is not None:
            self._values["delete"] = delete
        if read is not None:
            self._values["read"] = read
        if update is not None:
            self._values["update"] = update

    @builtins.property
    def create(self) -> typing.Optional[builtins.str]:
        result = self._values.get("create")
        return result

    @builtins.property
    def delete(self) -> typing.Optional[builtins.str]:
        result = self._values.get("delete")
        return result

    @builtins.property
    def read(self) -> typing.Optional[builtins.str]:
        result = self._values.get("read")
        return result

    @builtins.property
    def update(self) -> typing.Optional[builtins.str]:
        result = self._values.get("update")
        return result

    def __eq__(self, rhs: typing.Any) -> builtins.bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs: typing.Any) -> builtins.bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return "StorageAccountCustomerManagedKeyTimeouts(%s)" % ", ".join(
            k + "=" + repr(v) for k, v in self._values.items()
        )


@jsii.data_type(
    jsii_type="@cdktf/provider-azurerm.StorageAccountIdentity",
    jsii_struct_bases=[],
    name_mapping={"type": "type"},
)
class StorageAccountIdentity:
    def __init__(self, *, type: builtins.str) -> None:
        """
        :param type: 
        """
        self._values: typing.Dict[str, typing.Any] = {
            "type": type,
        }

    @builtins.property
    def type(self) -> builtins.str:
        result = self._values.get("type")
        assert result is not None, "Required property 'type' is missing"
        return result

    def __eq__(self, rhs: typing.Any) -> builtins.bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs: typing.Any) -> builtins.bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return "StorageAccountIdentity(%s)" % ", ".join(
            k + "=" + repr(v) for k, v in self._values.items()
        )


@jsii.data_type(
    jsii_type="@cdktf/provider-azurerm.StorageAccountNetworkRules",
    jsii_struct_bases=[],
    name_mapping={
        "default_action": "defaultAction",
        "bypass": "bypass",
        "ip_rules": "ipRules",
        "virtual_network_subnet_ids": "virtualNetworkSubnetIds",
    },
)
class StorageAccountNetworkRules:
    def __init__(
        self,
        *,
        default_action: builtins.str,
        bypass: typing.Optional[typing.List[builtins.str]] = None,
        ip_rules: typing.Optional[typing.List[builtins.str]] = None,
        virtual_network_subnet_ids: typing.Optional[typing.List[builtins.str]] = None,
    ) -> None:
        """
        :param default_action: 
        :param bypass: 
        :param ip_rules: 
        :param virtual_network_subnet_ids: 
        """
        self._values: typing.Dict[str, typing.Any] = {
            "default_action": default_action,
        }
        if bypass is not None:
            self._values["bypass"] = bypass
        if ip_rules is not None:
            self._values["ip_rules"] = ip_rules
        if virtual_network_subnet_ids is not None:
            self._values["virtual_network_subnet_ids"] = virtual_network_subnet_ids

    @builtins.property
    def default_action(self) -> builtins.str:
        result = self._values.get("default_action")
        assert result is not None, "Required property 'default_action' is missing"
        return result

    @builtins.property
    def bypass(self) -> typing.Optional[typing.List[builtins.str]]:
        result = self._values.get("bypass")
        return result

    @builtins.property
    def ip_rules(self) -> typing.Optional[typing.List[builtins.str]]:
        result = self._values.get("ip_rules")
        return result

    @builtins.property
    def virtual_network_subnet_ids(self) -> typing.Optional[typing.List[builtins.str]]:
        result = self._values.get("virtual_network_subnet_ids")
        return result

    def __eq__(self, rhs: typing.Any) -> builtins.bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs: typing.Any) -> builtins.bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return "StorageAccountNetworkRules(%s)" % ", ".join(
            k + "=" + repr(v) for k, v in self._values.items()
        )


class StorageAccountNetworkRulesA(
    cdktf.TerraformResource,
    metaclass=jsii.JSIIMeta,
    jsii_type="@cdktf/provider-azurerm.StorageAccountNetworkRulesA",
):
    def __init__(
        self,
        scope: constructs.Construct,
        id: builtins.str,
        *,
        default_action: builtins.str,
        resource_group_name: builtins.str,
        storage_account_name: builtins.str,
        bypass: typing.Optional[typing.List[builtins.str]] = None,
        ip_rules: typing.Optional[typing.List[builtins.str]] = None,
        timeouts: typing.Optional["StorageAccountNetworkRulesTimeouts"] = None,
        virtual_network_subnet_ids: typing.Optional[typing.List[builtins.str]] = None,
        count: typing.Optional[jsii.Number] = None,
        depends_on: typing.Optional[typing.List[cdktf.TerraformResource]] = None,
        lifecycle: typing.Optional[cdktf.TerraformResourceLifecycle] = None,
        provider: typing.Optional[cdktf.TerraformProvider] = None,
    ) -> None:
        """
        :param scope: -
        :param id: -
        :param default_action: 
        :param resource_group_name: 
        :param storage_account_name: 
        :param bypass: 
        :param ip_rules: 
        :param timeouts: timeouts block.
        :param virtual_network_subnet_ids: 
        :param count: 
        :param depends_on: 
        :param lifecycle: 
        :param provider: 
        """
        config = StorageAccountNetworkRulesAConfig(
            default_action=default_action,
            resource_group_name=resource_group_name,
            storage_account_name=storage_account_name,
            bypass=bypass,
            ip_rules=ip_rules,
            timeouts=timeouts,
            virtual_network_subnet_ids=virtual_network_subnet_ids,
            count=count,
            depends_on=depends_on,
            lifecycle=lifecycle,
            provider=provider,
        )

        jsii.create(StorageAccountNetworkRulesA, self, [scope, id, config])

    @jsii.member(jsii_name="synthesizeAttributes")
    def _synthesize_attributes(self) -> typing.Mapping[builtins.str, typing.Any]:
        return jsii.invoke(self, "synthesizeAttributes", [])

    @builtins.property # type: ignore
    @jsii.member(jsii_name="defaultAction")
    def default_action(self) -> builtins.str:
        return jsii.get(self, "defaultAction")

    @default_action.setter # type: ignore
    def default_action(self, value: builtins.str) -> None:
        jsii.set(self, "defaultAction", value)

    @builtins.property # type: ignore
    @jsii.member(jsii_name="resourceGroupName")
    def resource_group_name(self) -> builtins.str:
        return jsii.get(self, "resourceGroupName")

    @resource_group_name.setter # type: ignore
    def resource_group_name(self, value: builtins.str) -> None:
        jsii.set(self, "resourceGroupName", value)

    @builtins.property # type: ignore
    @jsii.member(jsii_name="storageAccountName")
    def storage_account_name(self) -> builtins.str:
        return jsii.get(self, "storageAccountName")

    @storage_account_name.setter # type: ignore
    def storage_account_name(self, value: builtins.str) -> None:
        jsii.set(self, "storageAccountName", value)

    @builtins.property # type: ignore
    @jsii.member(jsii_name="bypass")
    def bypass(self) -> typing.Optional[typing.List[builtins.str]]:
        return jsii.get(self, "bypass")

    @bypass.setter # type: ignore
    def bypass(self, value: typing.Optional[typing.List[builtins.str]]) -> None:
        jsii.set(self, "bypass", value)

    @builtins.property # type: ignore
    @jsii.member(jsii_name="id")
    def id(self) -> typing.Optional[builtins.str]:
        return jsii.get(self, "id")

    @id.setter # type: ignore
    def id(self, value: typing.Optional[builtins.str]) -> None:
        jsii.set(self, "id", value)

    @builtins.property # type: ignore
    @jsii.member(jsii_name="ipRules")
    def ip_rules(self) -> typing.Optional[typing.List[builtins.str]]:
        return jsii.get(self, "ipRules")

    @ip_rules.setter # type: ignore
    def ip_rules(self, value: typing.Optional[typing.List[builtins.str]]) -> None:
        jsii.set(self, "ipRules", value)

    @builtins.property # type: ignore
    @jsii.member(jsii_name="timeouts")
    def timeouts(self) -> typing.Optional["StorageAccountNetworkRulesTimeouts"]:
        return jsii.get(self, "timeouts")

    @timeouts.setter # type: ignore
    def timeouts(
        self,
        value: typing.Optional["StorageAccountNetworkRulesTimeouts"],
    ) -> None:
        jsii.set(self, "timeouts", value)

    @builtins.property # type: ignore
    @jsii.member(jsii_name="virtualNetworkSubnetIds")
    def virtual_network_subnet_ids(self) -> typing.Optional[typing.List[builtins.str]]:
        return jsii.get(self, "virtualNetworkSubnetIds")

    @virtual_network_subnet_ids.setter # type: ignore
    def virtual_network_subnet_ids(
        self,
        value: typing.Optional[typing.List[builtins.str]],
    ) -> None:
        jsii.set(self, "virtualNetworkSubnetIds", value)


@jsii.data_type(
    jsii_type="@cdktf/provider-azurerm.StorageAccountNetworkRulesAConfig",
    jsii_struct_bases=[cdktf.TerraformMetaArguments],
    name_mapping={
        "count": "count",
        "depends_on": "dependsOn",
        "lifecycle": "lifecycle",
        "provider": "provider",
        "default_action": "defaultAction",
        "resource_group_name": "resourceGroupName",
        "storage_account_name": "storageAccountName",
        "bypass": "bypass",
        "ip_rules": "ipRules",
        "timeouts": "timeouts",
        "virtual_network_subnet_ids": "virtualNetworkSubnetIds",
    },
)
class StorageAccountNetworkRulesAConfig(cdktf.TerraformMetaArguments):
    def __init__(
        self,
        *,
        count: typing.Optional[jsii.Number] = None,
        depends_on: typing.Optional[typing.List[cdktf.TerraformResource]] = None,
        lifecycle: typing.Optional[cdktf.TerraformResourceLifecycle] = None,
        provider: typing.Optional[cdktf.TerraformProvider] = None,
        default_action: builtins.str,
        resource_group_name: builtins.str,
        storage_account_name: builtins.str,
        bypass: typing.Optional[typing.List[builtins.str]] = None,
        ip_rules: typing.Optional[typing.List[builtins.str]] = None,
        timeouts: typing.Optional["StorageAccountNetworkRulesTimeouts"] = None,
        virtual_network_subnet_ids: typing.Optional[typing.List[builtins.str]] = None,
    ) -> None:
        """
        :param count: 
        :param depends_on: 
        :param lifecycle: 
        :param provider: 
        :param default_action: 
        :param resource_group_name: 
        :param storage_account_name: 
        :param bypass: 
        :param ip_rules: 
        :param timeouts: timeouts block.
        :param virtual_network_subnet_ids: 
        """
        if isinstance(lifecycle, dict):
            lifecycle = cdktf.TerraformResourceLifecycle(**lifecycle)
        if isinstance(timeouts, dict):
            timeouts = StorageAccountNetworkRulesTimeouts(**timeouts)
        self._values: typing.Dict[str, typing.Any] = {
            "default_action": default_action,
            "resource_group_name": resource_group_name,
            "storage_account_name": storage_account_name,
        }
        if count is not None:
            self._values["count"] = count
        if depends_on is not None:
            self._values["depends_on"] = depends_on
        if lifecycle is not None:
            self._values["lifecycle"] = lifecycle
        if provider is not None:
            self._values["provider"] = provider
        if bypass is not None:
            self._values["bypass"] = bypass
        if ip_rules is not None:
            self._values["ip_rules"] = ip_rules
        if timeouts is not None:
            self._values["timeouts"] = timeouts
        if virtual_network_subnet_ids is not None:
            self._values["virtual_network_subnet_ids"] = virtual_network_subnet_ids

    @builtins.property
    def count(self) -> typing.Optional[jsii.Number]:
        """
        :stability: experimental
        """
        result = self._values.get("count")
        return result

    @builtins.property
    def depends_on(self) -> typing.Optional[typing.List[cdktf.TerraformResource]]:
        """
        :stability: experimental
        """
        result = self._values.get("depends_on")
        return result

    @builtins.property
    def lifecycle(self) -> typing.Optional[cdktf.TerraformResourceLifecycle]:
        """
        :stability: experimental
        """
        result = self._values.get("lifecycle")
        return result

    @builtins.property
    def provider(self) -> typing.Optional[cdktf.TerraformProvider]:
        """
        :stability: experimental
        """
        result = self._values.get("provider")
        return result

    @builtins.property
    def default_action(self) -> builtins.str:
        result = self._values.get("default_action")
        assert result is not None, "Required property 'default_action' is missing"
        return result

    @builtins.property
    def resource_group_name(self) -> builtins.str:
        result = self._values.get("resource_group_name")
        assert result is not None, "Required property 'resource_group_name' is missing"
        return result

    @builtins.property
    def storage_account_name(self) -> builtins.str:
        result = self._values.get("storage_account_name")
        assert result is not None, "Required property 'storage_account_name' is missing"
        return result

    @builtins.property
    def bypass(self) -> typing.Optional[typing.List[builtins.str]]:
        result = self._values.get("bypass")
        return result

    @builtins.property
    def ip_rules(self) -> typing.Optional[typing.List[builtins.str]]:
        result = self._values.get("ip_rules")
        return result

    @builtins.property
    def timeouts(self) -> typing.Optional["StorageAccountNetworkRulesTimeouts"]:
        """timeouts block."""
        result = self._values.get("timeouts")
        return result

    @builtins.property
    def virtual_network_subnet_ids(self) -> typing.Optional[typing.List[builtins.str]]:
        result = self._values.get("virtual_network_subnet_ids")
        return result

    def __eq__(self, rhs: typing.Any) -> builtins.bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs: typing.Any) -> builtins.bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return "StorageAccountNetworkRulesAConfig(%s)" % ", ".join(
            k + "=" + repr(v) for k, v in self._values.items()
        )


@jsii.data_type(
    jsii_type="@cdktf/provider-azurerm.StorageAccountNetworkRulesTimeouts",
    jsii_struct_bases=[],
    name_mapping={
        "create": "create",
        "delete": "delete",
        "read": "read",
        "update": "update",
    },
)
class StorageAccountNetworkRulesTimeouts:
    def __init__(
        self,
        *,
        create: typing.Optional[builtins.str] = None,
        delete: typing.Optional[builtins.str] = None,
        read: typing.Optional[builtins.str] = None,
        update: typing.Optional[builtins.str] = None,
    ) -> None:
        """
        :param create: 
        :param delete: 
        :param read: 
        :param update: 
        """
        self._values: typing.Dict[str, typing.Any] = {}
        if create is not None:
            self._values["create"] = create
        if delete is not None:
            self._values["delete"] = delete
        if read is not None:
            self._values["read"] = read
        if update is not None:
            self._values["update"] = update

    @builtins.property
    def create(self) -> typing.Optional[builtins.str]:
        result = self._values.get("create")
        return result

    @builtins.property
    def delete(self) -> typing.Optional[builtins.str]:
        result = self._values.get("delete")
        return result

    @builtins.property
    def read(self) -> typing.Optional[builtins.str]:
        result = self._values.get("read")
        return result

    @builtins.property
    def update(self) -> typing.Optional[builtins.str]:
        result = self._values.get("update")
        return result

    def __eq__(self, rhs: typing.Any) -> builtins.bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs: typing.Any) -> builtins.bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return "StorageAccountNetworkRulesTimeouts(%s)" % ", ".join(
            k + "=" + repr(v) for k, v in self._values.items()
        )


@jsii.data_type(
    jsii_type="@cdktf/provider-azurerm.StorageAccountQueueProperties",
    jsii_struct_bases=[],
    name_mapping={
        "cors_rule": "corsRule",
        "hour_metrics": "hourMetrics",
        "logging": "logging",
        "minute_metrics": "minuteMetrics",
    },
)
class StorageAccountQueueProperties:
    def __init__(
        self,
        *,
        cors_rule: typing.Optional[typing.List["StorageAccountQueuePropertiesCorsRule"]] = None,
        hour_metrics: typing.Optional[typing.List["StorageAccountQueuePropertiesHourMetrics"]] = None,
        logging: typing.Optional[typing.List["StorageAccountQueuePropertiesLogging"]] = None,
        minute_metrics: typing.Optional[typing.List["StorageAccountQueuePropertiesMinuteMetrics"]] = None,
    ) -> None:
        """
        :param cors_rule: cors_rule block.
        :param hour_metrics: hour_metrics block.
        :param logging: logging block.
        :param minute_metrics: minute_metrics block.
        """
        self._values: typing.Dict[str, typing.Any] = {}
        if cors_rule is not None:
            self._values["cors_rule"] = cors_rule
        if hour_metrics is not None:
            self._values["hour_metrics"] = hour_metrics
        if logging is not None:
            self._values["logging"] = logging
        if minute_metrics is not None:
            self._values["minute_metrics"] = minute_metrics

    @builtins.property
    def cors_rule(
        self,
    ) -> typing.Optional[typing.List["StorageAccountQueuePropertiesCorsRule"]]:
        """cors_rule block."""
        result = self._values.get("cors_rule")
        return result

    @builtins.property
    def hour_metrics(
        self,
    ) -> typing.Optional[typing.List["StorageAccountQueuePropertiesHourMetrics"]]:
        """hour_metrics block."""
        result = self._values.get("hour_metrics")
        return result

    @builtins.property
    def logging(
        self,
    ) -> typing.Optional[typing.List["StorageAccountQueuePropertiesLogging"]]:
        """logging block."""
        result = self._values.get("logging")
        return result

    @builtins.property
    def minute_metrics(
        self,
    ) -> typing.Optional[typing.List["StorageAccountQueuePropertiesMinuteMetrics"]]:
        """minute_metrics block."""
        result = self._values.get("minute_metrics")
        return result

    def __eq__(self, rhs: typing.Any) -> builtins.bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs: typing.Any) -> builtins.bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return "StorageAccountQueueProperties(%s)" % ", ".join(
            k + "=" + repr(v) for k, v in self._values.items()
        )


@jsii.data_type(
    jsii_type="@cdktf/provider-azurerm.StorageAccountQueuePropertiesCorsRule",
    jsii_struct_bases=[],
    name_mapping={
        "allowed_headers": "allowedHeaders",
        "allowed_methods": "allowedMethods",
        "allowed_origins": "allowedOrigins",
        "exposed_headers": "exposedHeaders",
        "max_age_in_seconds": "maxAgeInSeconds",
    },
)
class StorageAccountQueuePropertiesCorsRule:
    def __init__(
        self,
        *,
        allowed_headers: typing.List[builtins.str],
        allowed_methods: typing.List[builtins.str],
        allowed_origins: typing.List[builtins.str],
        exposed_headers: typing.List[builtins.str],
        max_age_in_seconds: jsii.Number,
    ) -> None:
        """
        :param allowed_headers: 
        :param allowed_methods: 
        :param allowed_origins: 
        :param exposed_headers: 
        :param max_age_in_seconds: 
        """
        self._values: typing.Dict[str, typing.Any] = {
            "allowed_headers": allowed_headers,
            "allowed_methods": allowed_methods,
            "allowed_origins": allowed_origins,
            "exposed_headers": exposed_headers,
            "max_age_in_seconds": max_age_in_seconds,
        }

    @builtins.property
    def allowed_headers(self) -> typing.List[builtins.str]:
        result = self._values.get("allowed_headers")
        assert result is not None, "Required property 'allowed_headers' is missing"
        return result

    @builtins.property
    def allowed_methods(self) -> typing.List[builtins.str]:
        result = self._values.get("allowed_methods")
        assert result is not None, "Required property 'allowed_methods' is missing"
        return result

    @builtins.property
    def allowed_origins(self) -> typing.List[builtins.str]:
        result = self._values.get("allowed_origins")
        assert result is not None, "Required property 'allowed_origins' is missing"
        return result

    @builtins.property
    def exposed_headers(self) -> typing.List[builtins.str]:
        result = self._values.get("exposed_headers")
        assert result is not None, "Required property 'exposed_headers' is missing"
        return result

    @builtins.property
    def max_age_in_seconds(self) -> jsii.Number:
        result = self._values.get("max_age_in_seconds")
        assert result is not None, "Required property 'max_age_in_seconds' is missing"
        return result

    def __eq__(self, rhs: typing.Any) -> builtins.bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs: typing.Any) -> builtins.bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return "StorageAccountQueuePropertiesCorsRule(%s)" % ", ".join(
            k + "=" + repr(v) for k, v in self._values.items()
        )


@jsii.data_type(
    jsii_type="@cdktf/provider-azurerm.StorageAccountQueuePropertiesHourMetrics",
    jsii_struct_bases=[],
    name_mapping={
        "enabled": "enabled",
        "version": "version",
        "include_apis": "includeApis",
        "retention_policy_days": "retentionPolicyDays",
    },
)
class StorageAccountQueuePropertiesHourMetrics:
    def __init__(
        self,
        *,
        enabled: builtins.bool,
        version: builtins.str,
        include_apis: typing.Optional[builtins.bool] = None,
        retention_policy_days: typing.Optional[jsii.Number] = None,
    ) -> None:
        """
        :param enabled: 
        :param version: 
        :param include_apis: 
        :param retention_policy_days: 
        """
        self._values: typing.Dict[str, typing.Any] = {
            "enabled": enabled,
            "version": version,
        }
        if include_apis is not None:
            self._values["include_apis"] = include_apis
        if retention_policy_days is not None:
            self._values["retention_policy_days"] = retention_policy_days

    @builtins.property
    def enabled(self) -> builtins.bool:
        result = self._values.get("enabled")
        assert result is not None, "Required property 'enabled' is missing"
        return result

    @builtins.property
    def version(self) -> builtins.str:
        result = self._values.get("version")
        assert result is not None, "Required property 'version' is missing"
        return result

    @builtins.property
    def include_apis(self) -> typing.Optional[builtins.bool]:
        result = self._values.get("include_apis")
        return result

    @builtins.property
    def retention_policy_days(self) -> typing.Optional[jsii.Number]:
        result = self._values.get("retention_policy_days")
        return result

    def __eq__(self, rhs: typing.Any) -> builtins.bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs: typing.Any) -> builtins.bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return "StorageAccountQueuePropertiesHourMetrics(%s)" % ", ".join(
            k + "=" + repr(v) for k, v in self._values.items()
        )


@jsii.data_type(
    jsii_type="@cdktf/provider-azurerm.StorageAccountQueuePropertiesLogging",
    jsii_struct_bases=[],
    name_mapping={
        "delete": "delete",
        "read": "read",
        "version": "version",
        "write": "write",
        "retention_policy_days": "retentionPolicyDays",
    },
)
class StorageAccountQueuePropertiesLogging:
    def __init__(
        self,
        *,
        delete: builtins.bool,
        read: builtins.bool,
        version: builtins.str,
        write: builtins.bool,
        retention_policy_days: typing.Optional[jsii.Number] = None,
    ) -> None:
        """
        :param delete: 
        :param read: 
        :param version: 
        :param write: 
        :param retention_policy_days: 
        """
        self._values: typing.Dict[str, typing.Any] = {
            "delete": delete,
            "read": read,
            "version": version,
            "write": write,
        }
        if retention_policy_days is not None:
            self._values["retention_policy_days"] = retention_policy_days

    @builtins.property
    def delete(self) -> builtins.bool:
        result = self._values.get("delete")
        assert result is not None, "Required property 'delete' is missing"
        return result

    @builtins.property
    def read(self) -> builtins.bool:
        result = self._values.get("read")
        assert result is not None, "Required property 'read' is missing"
        return result

    @builtins.property
    def version(self) -> builtins.str:
        result = self._values.get("version")
        assert result is not None, "Required property 'version' is missing"
        return result

    @builtins.property
    def write(self) -> builtins.bool:
        result = self._values.get("write")
        assert result is not None, "Required property 'write' is missing"
        return result

    @builtins.property
    def retention_policy_days(self) -> typing.Optional[jsii.Number]:
        result = self._values.get("retention_policy_days")
        return result

    def __eq__(self, rhs: typing.Any) -> builtins.bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs: typing.Any) -> builtins.bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return "StorageAccountQueuePropertiesLogging(%s)" % ", ".join(
            k + "=" + repr(v) for k, v in self._values.items()
        )


@jsii.data_type(
    jsii_type="@cdktf/provider-azurerm.StorageAccountQueuePropertiesMinuteMetrics",
    jsii_struct_bases=[],
    name_mapping={
        "enabled": "enabled",
        "version": "version",
        "include_apis": "includeApis",
        "retention_policy_days": "retentionPolicyDays",
    },
)
class StorageAccountQueuePropertiesMinuteMetrics:
    def __init__(
        self,
        *,
        enabled: builtins.bool,
        version: builtins.str,
        include_apis: typing.Optional[builtins.bool] = None,
        retention_policy_days: typing.Optional[jsii.Number] = None,
    ) -> None:
        """
        :param enabled: 
        :param version: 
        :param include_apis: 
        :param retention_policy_days: 
        """
        self._values: typing.Dict[str, typing.Any] = {
            "enabled": enabled,
            "version": version,
        }
        if include_apis is not None:
            self._values["include_apis"] = include_apis
        if retention_policy_days is not None:
            self._values["retention_policy_days"] = retention_policy_days

    @builtins.property
    def enabled(self) -> builtins.bool:
        result = self._values.get("enabled")
        assert result is not None, "Required property 'enabled' is missing"
        return result

    @builtins.property
    def version(self) -> builtins.str:
        result = self._values.get("version")
        assert result is not None, "Required property 'version' is missing"
        return result

    @builtins.property
    def include_apis(self) -> typing.Optional[builtins.bool]:
        result = self._values.get("include_apis")
        return result

    @builtins.property
    def retention_policy_days(self) -> typing.Optional[jsii.Number]:
        result = self._values.get("retention_policy_days")
        return result

    def __eq__(self, rhs: typing.Any) -> builtins.bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs: typing.Any) -> builtins.bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return "StorageAccountQueuePropertiesMinuteMetrics(%s)" % ", ".join(
            k + "=" + repr(v) for k, v in self._values.items()
        )


@jsii.data_type(
    jsii_type="@cdktf/provider-azurerm.StorageAccountStaticWebsite",
    jsii_struct_bases=[],
    name_mapping={
        "error404_document": "error404Document",
        "index_document": "indexDocument",
    },
)
class StorageAccountStaticWebsite:
    def __init__(
        self,
        *,
        error404_document: typing.Optional[builtins.str] = None,
        index_document: typing.Optional[builtins.str] = None,
    ) -> None:
        """
        :param error404_document: 
        :param index_document: 
        """
        self._values: typing.Dict[str, typing.Any] = {}
        if error404_document is not None:
            self._values["error404_document"] = error404_document
        if index_document is not None:
            self._values["index_document"] = index_document

    @builtins.property
    def error404_document(self) -> typing.Optional[builtins.str]:
        result = self._values.get("error404_document")
        return result

    @builtins.property
    def index_document(self) -> typing.Optional[builtins.str]:
        result = self._values.get("index_document")
        return result

    def __eq__(self, rhs: typing.Any) -> builtins.bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs: typing.Any) -> builtins.bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return "StorageAccountStaticWebsite(%s)" % ", ".join(
            k + "=" + repr(v) for k, v in self._values.items()
        )


@jsii.data_type(
    jsii_type="@cdktf/provider-azurerm.StorageAccountTimeouts",
    jsii_struct_bases=[],
    name_mapping={
        "create": "create",
        "delete": "delete",
        "read": "read",
        "update": "update",
    },
)
class StorageAccountTimeouts:
    def __init__(
        self,
        *,
        create: typing.Optional[builtins.str] = None,
        delete: typing.Optional[builtins.str] = None,
        read: typing.Optional[builtins.str] = None,
        update: typing.Optional[builtins.str] = None,
    ) -> None:
        """
        :param create: 
        :param delete: 
        :param read: 
        :param update: 
        """
        self._values: typing.Dict[str, typing.Any] = {}
        if create is not None:
            self._values["create"] = create
        if delete is not None:
            self._values["delete"] = delete
        if read is not None:
            self._values["read"] = read
        if update is not None:
            self._values["update"] = update

    @builtins.property
    def create(self) -> typing.Optional[builtins.str]:
        result = self._values.get("create")
        return result

    @builtins.property
    def delete(self) -> typing.Optional[builtins.str]:
        result = self._values.get("delete")
        return result

    @builtins.property
    def read(self) -> typing.Optional[builtins.str]:
        result = self._values.get("read")
        return result

    @builtins.property
    def update(self) -> typing.Optional[builtins.str]:
        result = self._values.get("update")
        return result

    def __eq__(self, rhs: typing.Any) -> builtins.bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs: typing.Any) -> builtins.bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return "StorageAccountTimeouts(%s)" % ", ".join(
            k + "=" + repr(v) for k, v in self._values.items()
        )


class StorageBlob(
    cdktf.TerraformResource,
    metaclass=jsii.JSIIMeta,
    jsii_type="@cdktf/provider-azurerm.StorageBlob",
):
    def __init__(
        self,
        scope: constructs.Construct,
        id: builtins.str,
        *,
        name: builtins.str,
        storage_account_name: builtins.str,
        storage_container_name: builtins.str,
        type: builtins.str,
        access_tier: typing.Optional[builtins.str] = None,
        content_type: typing.Optional[builtins.str] = None,
        metadata: typing.Optional[typing.Mapping[builtins.str, builtins.str]] = None,
        parallelism: typing.Optional[jsii.Number] = None,
        size: typing.Optional[jsii.Number] = None,
        source: typing.Optional[builtins.str] = None,
        source_content: typing.Optional[builtins.str] = None,
        source_uri: typing.Optional[builtins.str] = None,
        timeouts: typing.Optional["StorageBlobTimeouts"] = None,
        count: typing.Optional[jsii.Number] = None,
        depends_on: typing.Optional[typing.List[cdktf.TerraformResource]] = None,
        lifecycle: typing.Optional[cdktf.TerraformResourceLifecycle] = None,
        provider: typing.Optional[cdktf.TerraformProvider] = None,
    ) -> None:
        """
        :param scope: -
        :param id: -
        :param name: 
        :param storage_account_name: 
        :param storage_container_name: 
        :param type: 
        :param access_tier: 
        :param content_type: 
        :param metadata: 
        :param parallelism: 
        :param size: 
        :param source: 
        :param source_content: 
        :param source_uri: 
        :param timeouts: timeouts block.
        :param count: 
        :param depends_on: 
        :param lifecycle: 
        :param provider: 
        """
        config = StorageBlobConfig(
            name=name,
            storage_account_name=storage_account_name,
            storage_container_name=storage_container_name,
            type=type,
            access_tier=access_tier,
            content_type=content_type,
            metadata=metadata,
            parallelism=parallelism,
            size=size,
            source=source,
            source_content=source_content,
            source_uri=source_uri,
            timeouts=timeouts,
            count=count,
            depends_on=depends_on,
            lifecycle=lifecycle,
            provider=provider,
        )

        jsii.create(StorageBlob, self, [scope, id, config])

    @jsii.member(jsii_name="synthesizeAttributes")
    def _synthesize_attributes(self) -> typing.Mapping[builtins.str, typing.Any]:
        return jsii.invoke(self, "synthesizeAttributes", [])

    @builtins.property # type: ignore
    @jsii.member(jsii_name="url")
    def url(self) -> builtins.str:
        return jsii.get(self, "url")

    @builtins.property # type: ignore
    @jsii.member(jsii_name="name")
    def name(self) -> builtins.str:
        return jsii.get(self, "name")

    @name.setter # type: ignore
    def name(self, value: builtins.str) -> None:
        jsii.set(self, "name", value)

    @builtins.property # type: ignore
    @jsii.member(jsii_name="storageAccountName")
    def storage_account_name(self) -> builtins.str:
        return jsii.get(self, "storageAccountName")

    @storage_account_name.setter # type: ignore
    def storage_account_name(self, value: builtins.str) -> None:
        jsii.set(self, "storageAccountName", value)

    @builtins.property # type: ignore
    @jsii.member(jsii_name="storageContainerName")
    def storage_container_name(self) -> builtins.str:
        return jsii.get(self, "storageContainerName")

    @storage_container_name.setter # type: ignore
    def storage_container_name(self, value: builtins.str) -> None:
        jsii.set(self, "storageContainerName", value)

    @builtins.property # type: ignore
    @jsii.member(jsii_name="type")
    def type(self) -> builtins.str:
        return jsii.get(self, "type")

    @type.setter # type: ignore
    def type(self, value: builtins.str) -> None:
        jsii.set(self, "type", value)

    @builtins.property # type: ignore
    @jsii.member(jsii_name="accessTier")
    def access_tier(self) -> typing.Optional[builtins.str]:
        return jsii.get(self, "accessTier")

    @access_tier.setter # type: ignore
    def access_tier(self, value: typing.Optional[builtins.str]) -> None:
        jsii.set(self, "accessTier", value)

    @builtins.property # type: ignore
    @jsii.member(jsii_name="contentType")
    def content_type(self) -> typing.Optional[builtins.str]:
        return jsii.get(self, "contentType")

    @content_type.setter # type: ignore
    def content_type(self, value: typing.Optional[builtins.str]) -> None:
        jsii.set(self, "contentType", value)

    @builtins.property # type: ignore
    @jsii.member(jsii_name="id")
    def id(self) -> typing.Optional[builtins.str]:
        return jsii.get(self, "id")

    @id.setter # type: ignore
    def id(self, value: typing.Optional[builtins.str]) -> None:
        jsii.set(self, "id", value)

    @builtins.property # type: ignore
    @jsii.member(jsii_name="metadata")
    def metadata(self) -> typing.Optional[typing.Mapping[builtins.str, builtins.str]]:
        return jsii.get(self, "metadata")

    @metadata.setter # type: ignore
    def metadata(
        self,
        value: typing.Optional[typing.Mapping[builtins.str, builtins.str]],
    ) -> None:
        jsii.set(self, "metadata", value)

    @builtins.property # type: ignore
    @jsii.member(jsii_name="parallelism")
    def parallelism(self) -> typing.Optional[jsii.Number]:
        return jsii.get(self, "parallelism")

    @parallelism.setter # type: ignore
    def parallelism(self, value: typing.Optional[jsii.Number]) -> None:
        jsii.set(self, "parallelism", value)

    @builtins.property # type: ignore
    @jsii.member(jsii_name="size")
    def size(self) -> typing.Optional[jsii.Number]:
        return jsii.get(self, "size")

    @size.setter # type: ignore
    def size(self, value: typing.Optional[jsii.Number]) -> None:
        jsii.set(self, "size", value)

    @builtins.property # type: ignore
    @jsii.member(jsii_name="source")
    def source(self) -> typing.Optional[builtins.str]:
        return jsii.get(self, "source")

    @source.setter # type: ignore
    def source(self, value: typing.Optional[builtins.str]) -> None:
        jsii.set(self, "source", value)

    @builtins.property # type: ignore
    @jsii.member(jsii_name="sourceContent")
    def source_content(self) -> typing.Optional[builtins.str]:
        return jsii.get(self, "sourceContent")

    @source_content.setter # type: ignore
    def source_content(self, value: typing.Optional[builtins.str]) -> None:
        jsii.set(self, "sourceContent", value)

    @builtins.property # type: ignore
    @jsii.member(jsii_name="sourceUri")
    def source_uri(self) -> typing.Optional[builtins.str]:
        return jsii.get(self, "sourceUri")

    @source_uri.setter # type: ignore
    def source_uri(self, value: typing.Optional[builtins.str]) -> None:
        jsii.set(self, "sourceUri", value)

    @builtins.property # type: ignore
    @jsii.member(jsii_name="timeouts")
    def timeouts(self) -> typing.Optional["StorageBlobTimeouts"]:
        return jsii.get(self, "timeouts")

    @timeouts.setter # type: ignore
    def timeouts(self, value: typing.Optional["StorageBlobTimeouts"]) -> None:
        jsii.set(self, "timeouts", value)


@jsii.data_type(
    jsii_type="@cdktf/provider-azurerm.StorageBlobConfig",
    jsii_struct_bases=[cdktf.TerraformMetaArguments],
    name_mapping={
        "count": "count",
        "depends_on": "dependsOn",
        "lifecycle": "lifecycle",
        "provider": "provider",
        "name": "name",
        "storage_account_name": "storageAccountName",
        "storage_container_name": "storageContainerName",
        "type": "type",
        "access_tier": "accessTier",
        "content_type": "contentType",
        "metadata": "metadata",
        "parallelism": "parallelism",
        "size": "size",
        "source": "source",
        "source_content": "sourceContent",
        "source_uri": "sourceUri",
        "timeouts": "timeouts",
    },
)
class StorageBlobConfig(cdktf.TerraformMetaArguments):
    def __init__(
        self,
        *,
        count: typing.Optional[jsii.Number] = None,
        depends_on: typing.Optional[typing.List[cdktf.TerraformResource]] = None,
        lifecycle: typing.Optional[cdktf.TerraformResourceLifecycle] = None,
        provider: typing.Optional[cdktf.TerraformProvider] = None,
        name: builtins.str,
        storage_account_name: builtins.str,
        storage_container_name: builtins.str,
        type: builtins.str,
        access_tier: typing.Optional[builtins.str] = None,
        content_type: typing.Optional[builtins.str] = None,
        metadata: typing.Optional[typing.Mapping[builtins.str, builtins.str]] = None,
        parallelism: typing.Optional[jsii.Number] = None,
        size: typing.Optional[jsii.Number] = None,
        source: typing.Optional[builtins.str] = None,
        source_content: typing.Optional[builtins.str] = None,
        source_uri: typing.Optional[builtins.str] = None,
        timeouts: typing.Optional["StorageBlobTimeouts"] = None,
    ) -> None:
        """
        :param count: 
        :param depends_on: 
        :param lifecycle: 
        :param provider: 
        :param name: 
        :param storage_account_name: 
        :param storage_container_name: 
        :param type: 
        :param access_tier: 
        :param content_type: 
        :param metadata: 
        :param parallelism: 
        :param size: 
        :param source: 
        :param source_content: 
        :param source_uri: 
        :param timeouts: timeouts block.
        """
        if isinstance(lifecycle, dict):
            lifecycle = cdktf.TerraformResourceLifecycle(**lifecycle)
        if isinstance(timeouts, dict):
            timeouts = StorageBlobTimeouts(**timeouts)
        self._values: typing.Dict[str, typing.Any] = {
            "name": name,
            "storage_account_name": storage_account_name,
            "storage_container_name": storage_container_name,
            "type": type,
        }
        if count is not None:
            self._values["count"] = count
        if depends_on is not None:
            self._values["depends_on"] = depends_on
        if lifecycle is not None:
            self._values["lifecycle"] = lifecycle
        if provider is not None:
            self._values["provider"] = provider
        if access_tier is not None:
            self._values["access_tier"] = access_tier
        if content_type is not None:
            self._values["content_type"] = content_type
        if metadata is not None:
            self._values["metadata"] = metadata
        if parallelism is not None:
            self._values["parallelism"] = parallelism
        if size is not None:
            self._values["size"] = size
        if source is not None:
            self._values["source"] = source
        if source_content is not None:
            self._values["source_content"] = source_content
        if source_uri is not None:
            self._values["source_uri"] = source_uri
        if timeouts is not None:
            self._values["timeouts"] = timeouts

    @builtins.property
    def count(self) -> typing.Optional[jsii.Number]:
        """
        :stability: experimental
        """
        result = self._values.get("count")
        return result

    @builtins.property
    def depends_on(self) -> typing.Optional[typing.List[cdktf.TerraformResource]]:
        """
        :stability: experimental
        """
        result = self._values.get("depends_on")
        return result

    @builtins.property
    def lifecycle(self) -> typing.Optional[cdktf.TerraformResourceLifecycle]:
        """
        :stability: experimental
        """
        result = self._values.get("lifecycle")
        return result

    @builtins.property
    def provider(self) -> typing.Optional[cdktf.TerraformProvider]:
        """
        :stability: experimental
        """
        result = self._values.get("provider")
        return result

    @builtins.property
    def name(self) -> builtins.str:
        result = self._values.get("name")
        assert result is not None, "Required property 'name' is missing"
        return result

    @builtins.property
    def storage_account_name(self) -> builtins.str:
        result = self._values.get("storage_account_name")
        assert result is not None, "Required property 'storage_account_name' is missing"
        return result

    @builtins.property
    def storage_container_name(self) -> builtins.str:
        result = self._values.get("storage_container_name")
        assert result is not None, "Required property 'storage_container_name' is missing"
        return result

    @builtins.property
    def type(self) -> builtins.str:
        result = self._values.get("type")
        assert result is not None, "Required property 'type' is missing"
        return result

    @builtins.property
    def access_tier(self) -> typing.Optional[builtins.str]:
        result = self._values.get("access_tier")
        return result

    @builtins.property
    def content_type(self) -> typing.Optional[builtins.str]:
        result = self._values.get("content_type")
        return result

    @builtins.property
    def metadata(self) -> typing.Optional[typing.Mapping[builtins.str, builtins.str]]:
        result = self._values.get("metadata")
        return result

    @builtins.property
    def parallelism(self) -> typing.Optional[jsii.Number]:
        result = self._values.get("parallelism")
        return result

    @builtins.property
    def size(self) -> typing.Optional[jsii.Number]:
        result = self._values.get("size")
        return result

    @builtins.property
    def source(self) -> typing.Optional[builtins.str]:
        result = self._values.get("source")
        return result

    @builtins.property
    def source_content(self) -> typing.Optional[builtins.str]:
        result = self._values.get("source_content")
        return result

    @builtins.property
    def source_uri(self) -> typing.Optional[builtins.str]:
        result = self._values.get("source_uri")
        return result

    @builtins.property
    def timeouts(self) -> typing.Optional["StorageBlobTimeouts"]:
        """timeouts block."""
        result = self._values.get("timeouts")
        return result

    def __eq__(self, rhs: typing.Any) -> builtins.bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs: typing.Any) -> builtins.bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return "StorageBlobConfig(%s)" % ", ".join(
            k + "=" + repr(v) for k, v in self._values.items()
        )


@jsii.data_type(
    jsii_type="@cdktf/provider-azurerm.StorageBlobTimeouts",
    jsii_struct_bases=[],
    name_mapping={
        "create": "create",
        "delete": "delete",
        "read": "read",
        "update": "update",
    },
)
class StorageBlobTimeouts:
    def __init__(
        self,
        *,
        create: typing.Optional[builtins.str] = None,
        delete: typing.Optional[builtins.str] = None,
        read: typing.Optional[builtins.str] = None,
        update: typing.Optional[builtins.str] = None,
    ) -> None:
        """
        :param create: 
        :param delete: 
        :param read: 
        :param update: 
        """
        self._values: typing.Dict[str, typing.Any] = {}
        if create is not None:
            self._values["create"] = create
        if delete is not None:
            self._values["delete"] = delete
        if read is not None:
            self._values["read"] = read
        if update is not None:
            self._values["update"] = update

    @builtins.property
    def create(self) -> typing.Optional[builtins.str]:
        result = self._values.get("create")
        return result

    @builtins.property
    def delete(self) -> typing.Optional[builtins.str]:
        result = self._values.get("delete")
        return result

    @builtins.property
    def read(self) -> typing.Optional[builtins.str]:
        result = self._values.get("read")
        return result

    @builtins.property
    def update(self) -> typing.Optional[builtins.str]:
        result = self._values.get("update")
        return result

    def __eq__(self, rhs: typing.Any) -> builtins.bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs: typing.Any) -> builtins.bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return "StorageBlobTimeouts(%s)" % ", ".join(
            k + "=" + repr(v) for k, v in self._values.items()
        )


class StorageContainer(
    cdktf.TerraformResource,
    metaclass=jsii.JSIIMeta,
    jsii_type="@cdktf/provider-azurerm.StorageContainer",
):
    def __init__(
        self,
        scope: constructs.Construct,
        id: builtins.str,
        *,
        name: builtins.str,
        storage_account_name: builtins.str,
        container_access_type: typing.Optional[builtins.str] = None,
        metadata: typing.Optional[typing.Mapping[builtins.str, builtins.str]] = None,
        timeouts: typing.Optional["StorageContainerTimeouts"] = None,
        count: typing.Optional[jsii.Number] = None,
        depends_on: typing.Optional[typing.List[cdktf.TerraformResource]] = None,
        lifecycle: typing.Optional[cdktf.TerraformResourceLifecycle] = None,
        provider: typing.Optional[cdktf.TerraformProvider] = None,
    ) -> None:
        """
        :param scope: -
        :param id: -
        :param name: 
        :param storage_account_name: 
        :param container_access_type: 
        :param metadata: 
        :param timeouts: timeouts block.
        :param count: 
        :param depends_on: 
        :param lifecycle: 
        :param provider: 
        """
        config = StorageContainerConfig(
            name=name,
            storage_account_name=storage_account_name,
            container_access_type=container_access_type,
            metadata=metadata,
            timeouts=timeouts,
            count=count,
            depends_on=depends_on,
            lifecycle=lifecycle,
            provider=provider,
        )

        jsii.create(StorageContainer, self, [scope, id, config])

    @jsii.member(jsii_name="synthesizeAttributes")
    def _synthesize_attributes(self) -> typing.Mapping[builtins.str, typing.Any]:
        return jsii.invoke(self, "synthesizeAttributes", [])

    @builtins.property # type: ignore
    @jsii.member(jsii_name="hasImmutabilityPolicy")
    def has_immutability_policy(self) -> builtins.bool:
        return jsii.get(self, "hasImmutabilityPolicy")

    @builtins.property # type: ignore
    @jsii.member(jsii_name="hasLegalHold")
    def has_legal_hold(self) -> builtins.bool:
        return jsii.get(self, "hasLegalHold")

    @builtins.property # type: ignore
    @jsii.member(jsii_name="name")
    def name(self) -> builtins.str:
        return jsii.get(self, "name")

    @name.setter # type: ignore
    def name(self, value: builtins.str) -> None:
        jsii.set(self, "name", value)

    @builtins.property # type: ignore
    @jsii.member(jsii_name="storageAccountName")
    def storage_account_name(self) -> builtins.str:
        return jsii.get(self, "storageAccountName")

    @storage_account_name.setter # type: ignore
    def storage_account_name(self, value: builtins.str) -> None:
        jsii.set(self, "storageAccountName", value)

    @builtins.property # type: ignore
    @jsii.member(jsii_name="containerAccessType")
    def container_access_type(self) -> typing.Optional[builtins.str]:
        return jsii.get(self, "containerAccessType")

    @container_access_type.setter # type: ignore
    def container_access_type(self, value: typing.Optional[builtins.str]) -> None:
        jsii.set(self, "containerAccessType", value)

    @builtins.property # type: ignore
    @jsii.member(jsii_name="id")
    def id(self) -> typing.Optional[builtins.str]:
        return jsii.get(self, "id")

    @id.setter # type: ignore
    def id(self, value: typing.Optional[builtins.str]) -> None:
        jsii.set(self, "id", value)

    @builtins.property # type: ignore
    @jsii.member(jsii_name="metadata")
    def metadata(self) -> typing.Optional[typing.Mapping[builtins.str, builtins.str]]:
        return jsii.get(self, "metadata")

    @metadata.setter # type: ignore
    def metadata(
        self,
        value: typing.Optional[typing.Mapping[builtins.str, builtins.str]],
    ) -> None:
        jsii.set(self, "metadata", value)

    @builtins.property # type: ignore
    @jsii.member(jsii_name="timeouts")
    def timeouts(self) -> typing.Optional["StorageContainerTimeouts"]:
        return jsii.get(self, "timeouts")

    @timeouts.setter # type: ignore
    def timeouts(self, value: typing.Optional["StorageContainerTimeouts"]) -> None:
        jsii.set(self, "timeouts", value)


@jsii.data_type(
    jsii_type="@cdktf/provider-azurerm.StorageContainerConfig",
    jsii_struct_bases=[cdktf.TerraformMetaArguments],
    name_mapping={
        "count": "count",
        "depends_on": "dependsOn",
        "lifecycle": "lifecycle",
        "provider": "provider",
        "name": "name",
        "storage_account_name": "storageAccountName",
        "container_access_type": "containerAccessType",
        "metadata": "metadata",
        "timeouts": "timeouts",
    },
)
class StorageContainerConfig(cdktf.TerraformMetaArguments):
    def __init__(
        self,
        *,
        count: typing.Optional[jsii.Number] = None,
        depends_on: typing.Optional[typing.List[cdktf.TerraformResource]] = None,
        lifecycle: typing.Optional[cdktf.TerraformResourceLifecycle] = None,
        provider: typing.Optional[cdktf.TerraformProvider] = None,
        name: builtins.str,
        storage_account_name: builtins.str,
        container_access_type: typing.Optional[builtins.str] = None,
        metadata: typing.Optional[typing.Mapping[builtins.str, builtins.str]] = None,
        timeouts: typing.Optional["StorageContainerTimeouts"] = None,
    ) -> None:
        """
        :param count: 
        :param depends_on: 
        :param lifecycle: 
        :param provider: 
        :param name: 
        :param storage_account_name: 
        :param container_access_type: 
        :param metadata: 
        :param timeouts: timeouts block.
        """
        if isinstance(lifecycle, dict):
            lifecycle = cdktf.TerraformResourceLifecycle(**lifecycle)
        if isinstance(timeouts, dict):
            timeouts = StorageContainerTimeouts(**timeouts)
        self._values: typing.Dict[str, typing.Any] = {
            "name": name,
            "storage_account_name": storage_account_name,
        }
        if count is not None:
            self._values["count"] = count
        if depends_on is not None:
            self._values["depends_on"] = depends_on
        if lifecycle is not None:
            self._values["lifecycle"] = lifecycle
        if provider is not None:
            self._values["provider"] = provider
        if container_access_type is not None:
            self._values["container_access_type"] = container_access_type
        if metadata is not None:
            self._values["metadata"] = metadata
        if timeouts is not None:
            self._values["timeouts"] = timeouts

    @builtins.property
    def count(self) -> typing.Optional[jsii.Number]:
        """
        :stability: experimental
        """
        result = self._values.get("count")
        return result

    @builtins.property
    def depends_on(self) -> typing.Optional[typing.List[cdktf.TerraformResource]]:
        """
        :stability: experimental
        """
        result = self._values.get("depends_on")
        return result

    @builtins.property
    def lifecycle(self) -> typing.Optional[cdktf.TerraformResourceLifecycle]:
        """
        :stability: experimental
        """
        result = self._values.get("lifecycle")
        return result

    @builtins.property
    def provider(self) -> typing.Optional[cdktf.TerraformProvider]:
        """
        :stability: experimental
        """
        result = self._values.get("provider")
        return result

    @builtins.property
    def name(self) -> builtins.str:
        result = self._values.get("name")
        assert result is not None, "Required property 'name' is missing"
        return result

    @builtins.property
    def storage_account_name(self) -> builtins.str:
        result = self._values.get("storage_account_name")
        assert result is not None, "Required property 'storage_account_name' is missing"
        return result

    @builtins.property
    def container_access_type(self) -> typing.Optional[builtins.str]:
        result = self._values.get("container_access_type")
        return result

    @builtins.property
    def metadata(self) -> typing.Optional[typing.Mapping[builtins.str, builtins.str]]:
        result = self._values.get("metadata")
        return result

    @builtins.property
    def timeouts(self) -> typing.Optional["StorageContainerTimeouts"]:
        """timeouts block."""
        result = self._values.get("timeouts")
        return result

    def __eq__(self, rhs: typing.Any) -> builtins.bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs: typing.Any) -> builtins.bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return "StorageContainerConfig(%s)" % ", ".join(
            k + "=" + repr(v) for k, v in self._values.items()
        )


@jsii.data_type(
    jsii_type="@cdktf/provider-azurerm.StorageContainerTimeouts",
    jsii_struct_bases=[],
    name_mapping={
        "create": "create",
        "delete": "delete",
        "read": "read",
        "update": "update",
    },
)
class StorageContainerTimeouts:
    def __init__(
        self,
        *,
        create: typing.Optional[builtins.str] = None,
        delete: typing.Optional[builtins.str] = None,
        read: typing.Optional[builtins.str] = None,
        update: typing.Optional[builtins.str] = None,
    ) -> None:
        """
        :param create: 
        :param delete: 
        :param read: 
        :param update: 
        """
        self._values: typing.Dict[str, typing.Any] = {}
        if create is not None:
            self._values["create"] = create
        if delete is not None:
            self._values["delete"] = delete
        if read is not None:
            self._values["read"] = read
        if update is not None:
            self._values["update"] = update

    @builtins.property
    def create(self) -> typing.Optional[builtins.str]:
        result = self._values.get("create")
        return result

    @builtins.property
    def delete(self) -> typing.Optional[builtins.str]:
        result = self._values.get("delete")
        return result

    @builtins.property
    def read(self) -> typing.Optional[builtins.str]:
        result = self._values.get("read")
        return result

    @builtins.property
    def update(self) -> typing.Optional[builtins.str]:
        result = self._values.get("update")
        return result

    def __eq__(self, rhs: typing.Any) -> builtins.bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs: typing.Any) -> builtins.bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return "StorageContainerTimeouts(%s)" % ", ".join(
            k + "=" + repr(v) for k, v in self._values.items()
        )


class StorageDataLakeGen2Filesystem(
    cdktf.TerraformResource,
    metaclass=jsii.JSIIMeta,
    jsii_type="@cdktf/provider-azurerm.StorageDataLakeGen2Filesystem",
):
    def __init__(
        self,
        scope: constructs.Construct,
        id: builtins.str,
        *,
        name: builtins.str,
        storage_account_id: builtins.str,
        properties: typing.Optional[typing.Mapping[builtins.str, builtins.str]] = None,
        timeouts: typing.Optional["StorageDataLakeGen2FilesystemTimeouts"] = None,
        count: typing.Optional[jsii.Number] = None,
        depends_on: typing.Optional[typing.List[cdktf.TerraformResource]] = None,
        lifecycle: typing.Optional[cdktf.TerraformResourceLifecycle] = None,
        provider: typing.Optional[cdktf.TerraformProvider] = None,
    ) -> None:
        """
        :param scope: -
        :param id: -
        :param name: 
        :param storage_account_id: 
        :param properties: 
        :param timeouts: timeouts block.
        :param count: 
        :param depends_on: 
        :param lifecycle: 
        :param provider: 
        """
        config = StorageDataLakeGen2FilesystemConfig(
            name=name,
            storage_account_id=storage_account_id,
            properties=properties,
            timeouts=timeouts,
            count=count,
            depends_on=depends_on,
            lifecycle=lifecycle,
            provider=provider,
        )

        jsii.create(StorageDataLakeGen2Filesystem, self, [scope, id, config])

    @jsii.member(jsii_name="synthesizeAttributes")
    def _synthesize_attributes(self) -> typing.Mapping[builtins.str, typing.Any]:
        return jsii.invoke(self, "synthesizeAttributes", [])

    @builtins.property # type: ignore
    @jsii.member(jsii_name="name")
    def name(self) -> builtins.str:
        return jsii.get(self, "name")

    @name.setter # type: ignore
    def name(self, value: builtins.str) -> None:
        jsii.set(self, "name", value)

    @builtins.property # type: ignore
    @jsii.member(jsii_name="storageAccountId")
    def storage_account_id(self) -> builtins.str:
        return jsii.get(self, "storageAccountId")

    @storage_account_id.setter # type: ignore
    def storage_account_id(self, value: builtins.str) -> None:
        jsii.set(self, "storageAccountId", value)

    @builtins.property # type: ignore
    @jsii.member(jsii_name="id")
    def id(self) -> typing.Optional[builtins.str]:
        return jsii.get(self, "id")

    @id.setter # type: ignore
    def id(self, value: typing.Optional[builtins.str]) -> None:
        jsii.set(self, "id", value)

    @builtins.property # type: ignore
    @jsii.member(jsii_name="properties")
    def properties(self) -> typing.Optional[typing.Mapping[builtins.str, builtins.str]]:
        return jsii.get(self, "properties")

    @properties.setter # type: ignore
    def properties(
        self,
        value: typing.Optional[typing.Mapping[builtins.str, builtins.str]],
    ) -> None:
        jsii.set(self, "properties", value)

    @builtins.property # type: ignore
    @jsii.member(jsii_name="timeouts")
    def timeouts(self) -> typing.Optional["StorageDataLakeGen2FilesystemTimeouts"]:
        return jsii.get(self, "timeouts")

    @timeouts.setter # type: ignore
    def timeouts(
        self,
        value: typing.Optional["StorageDataLakeGen2FilesystemTimeouts"],
    ) -> None:
        jsii.set(self, "timeouts", value)


@jsii.data_type(
    jsii_type="@cdktf/provider-azurerm.StorageDataLakeGen2FilesystemConfig",
    jsii_struct_bases=[cdktf.TerraformMetaArguments],
    name_mapping={
        "count": "count",
        "depends_on": "dependsOn",
        "lifecycle": "lifecycle",
        "provider": "provider",
        "name": "name",
        "storage_account_id": "storageAccountId",
        "properties": "properties",
        "timeouts": "timeouts",
    },
)
class StorageDataLakeGen2FilesystemConfig(cdktf.TerraformMetaArguments):
    def __init__(
        self,
        *,
        count: typing.Optional[jsii.Number] = None,
        depends_on: typing.Optional[typing.List[cdktf.TerraformResource]] = None,
        lifecycle: typing.Optional[cdktf.TerraformResourceLifecycle] = None,
        provider: typing.Optional[cdktf.TerraformProvider] = None,
        name: builtins.str,
        storage_account_id: builtins.str,
        properties: typing.Optional[typing.Mapping[builtins.str, builtins.str]] = None,
        timeouts: typing.Optional["StorageDataLakeGen2FilesystemTimeouts"] = None,
    ) -> None:
        """
        :param count: 
        :param depends_on: 
        :param lifecycle: 
        :param provider: 
        :param name: 
        :param storage_account_id: 
        :param properties: 
        :param timeouts: timeouts block.
        """
        if isinstance(lifecycle, dict):
            lifecycle = cdktf.TerraformResourceLifecycle(**lifecycle)
        if isinstance(timeouts, dict):
            timeouts = StorageDataLakeGen2FilesystemTimeouts(**timeouts)
        self._values: typing.Dict[str, typing.Any] = {
            "name": name,
            "storage_account_id": storage_account_id,
        }
        if count is not None:
            self._values["count"] = count
        if depends_on is not None:
            self._values["depends_on"] = depends_on
        if lifecycle is not None:
            self._values["lifecycle"] = lifecycle
        if provider is not None:
            self._values["provider"] = provider
        if properties is not None:
            self._values["properties"] = properties
        if timeouts is not None:
            self._values["timeouts"] = timeouts

    @builtins.property
    def count(self) -> typing.Optional[jsii.Number]:
        """
        :stability: experimental
        """
        result = self._values.get("count")
        return result

    @builtins.property
    def depends_on(self) -> typing.Optional[typing.List[cdktf.TerraformResource]]:
        """
        :stability: experimental
        """
        result = self._values.get("depends_on")
        return result

    @builtins.property
    def lifecycle(self) -> typing.Optional[cdktf.TerraformResourceLifecycle]:
        """
        :stability: experimental
        """
        result = self._values.get("lifecycle")
        return result

    @builtins.property
    def provider(self) -> typing.Optional[cdktf.TerraformProvider]:
        """
        :stability: experimental
        """
        result = self._values.get("provider")
        return result

    @builtins.property
    def name(self) -> builtins.str:
        result = self._values.get("name")
        assert result is not None, "Required property 'name' is missing"
        return result

    @builtins.property
    def storage_account_id(self) -> builtins.str:
        result = self._values.get("storage_account_id")
        assert result is not None, "Required property 'storage_account_id' is missing"
        return result

    @builtins.property
    def properties(self) -> typing.Optional[typing.Mapping[builtins.str, builtins.str]]:
        result = self._values.get("properties")
        return result

    @builtins.property
    def timeouts(self) -> typing.Optional["StorageDataLakeGen2FilesystemTimeouts"]:
        """timeouts block."""
        result = self._values.get("timeouts")
        return result

    def __eq__(self, rhs: typing.Any) -> builtins.bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs: typing.Any) -> builtins.bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return "StorageDataLakeGen2FilesystemConfig(%s)" % ", ".join(
            k + "=" + repr(v) for k, v in self._values.items()
        )


@jsii.data_type(
    jsii_type="@cdktf/provider-azurerm.StorageDataLakeGen2FilesystemTimeouts",
    jsii_struct_bases=[],
    name_mapping={
        "create": "create",
        "delete": "delete",
        "read": "read",
        "update": "update",
    },
)
class StorageDataLakeGen2FilesystemTimeouts:
    def __init__(
        self,
        *,
        create: typing.Optional[builtins.str] = None,
        delete: typing.Optional[builtins.str] = None,
        read: typing.Optional[builtins.str] = None,
        update: typing.Optional[builtins.str] = None,
    ) -> None:
        """
        :param create: 
        :param delete: 
        :param read: 
        :param update: 
        """
        self._values: typing.Dict[str, typing.Any] = {}
        if create is not None:
            self._values["create"] = create
        if delete is not None:
            self._values["delete"] = delete
        if read is not None:
            self._values["read"] = read
        if update is not None:
            self._values["update"] = update

    @builtins.property
    def create(self) -> typing.Optional[builtins.str]:
        result = self._values.get("create")
        return result

    @builtins.property
    def delete(self) -> typing.Optional[builtins.str]:
        result = self._values.get("delete")
        return result

    @builtins.property
    def read(self) -> typing.Optional[builtins.str]:
        result = self._values.get("read")
        return result

    @builtins.property
    def update(self) -> typing.Optional[builtins.str]:
        result = self._values.get("update")
        return result

    def __eq__(self, rhs: typing.Any) -> builtins.bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs: typing.Any) -> builtins.bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return "StorageDataLakeGen2FilesystemTimeouts(%s)" % ", ".join(
            k + "=" + repr(v) for k, v in self._values.items()
        )


class StorageManagementPolicy(
    cdktf.TerraformResource,
    metaclass=jsii.JSIIMeta,
    jsii_type="@cdktf/provider-azurerm.StorageManagementPolicy",
):
    def __init__(
        self,
        scope: constructs.Construct,
        id: builtins.str,
        *,
        storage_account_id: builtins.str,
        rule: typing.Optional[typing.List["StorageManagementPolicyRule"]] = None,
        timeouts: typing.Optional["StorageManagementPolicyTimeouts"] = None,
        count: typing.Optional[jsii.Number] = None,
        depends_on: typing.Optional[typing.List[cdktf.TerraformResource]] = None,
        lifecycle: typing.Optional[cdktf.TerraformResourceLifecycle] = None,
        provider: typing.Optional[cdktf.TerraformProvider] = None,
    ) -> None:
        """
        :param scope: -
        :param id: -
        :param storage_account_id: 
        :param rule: rule block.
        :param timeouts: timeouts block.
        :param count: 
        :param depends_on: 
        :param lifecycle: 
        :param provider: 
        """
        config = StorageManagementPolicyConfig(
            storage_account_id=storage_account_id,
            rule=rule,
            timeouts=timeouts,
            count=count,
            depends_on=depends_on,
            lifecycle=lifecycle,
            provider=provider,
        )

        jsii.create(StorageManagementPolicy, self, [scope, id, config])

    @jsii.member(jsii_name="synthesizeAttributes")
    def _synthesize_attributes(self) -> typing.Mapping[builtins.str, typing.Any]:
        return jsii.invoke(self, "synthesizeAttributes", [])

    @builtins.property # type: ignore
    @jsii.member(jsii_name="storageAccountId")
    def storage_account_id(self) -> builtins.str:
        return jsii.get(self, "storageAccountId")

    @storage_account_id.setter # type: ignore
    def storage_account_id(self, value: builtins.str) -> None:
        jsii.set(self, "storageAccountId", value)

    @builtins.property # type: ignore
    @jsii.member(jsii_name="id")
    def id(self) -> typing.Optional[builtins.str]:
        return jsii.get(self, "id")

    @id.setter # type: ignore
    def id(self, value: typing.Optional[builtins.str]) -> None:
        jsii.set(self, "id", value)

    @builtins.property # type: ignore
    @jsii.member(jsii_name="rule")
    def rule(self) -> typing.Optional[typing.List["StorageManagementPolicyRule"]]:
        return jsii.get(self, "rule")

    @rule.setter # type: ignore
    def rule(
        self,
        value: typing.Optional[typing.List["StorageManagementPolicyRule"]],
    ) -> None:
        jsii.set(self, "rule", value)

    @builtins.property # type: ignore
    @jsii.member(jsii_name="timeouts")
    def timeouts(self) -> typing.Optional["StorageManagementPolicyTimeouts"]:
        return jsii.get(self, "timeouts")

    @timeouts.setter # type: ignore
    def timeouts(
        self,
        value: typing.Optional["StorageManagementPolicyTimeouts"],
    ) -> None:
        jsii.set(self, "timeouts", value)


@jsii.data_type(
    jsii_type="@cdktf/provider-azurerm.StorageManagementPolicyConfig",
    jsii_struct_bases=[cdktf.TerraformMetaArguments],
    name_mapping={
        "count": "count",
        "depends_on": "dependsOn",
        "lifecycle": "lifecycle",
        "provider": "provider",
        "storage_account_id": "storageAccountId",
        "rule": "rule",
        "timeouts": "timeouts",
    },
)
class StorageManagementPolicyConfig(cdktf.TerraformMetaArguments):
    def __init__(
        self,
        *,
        count: typing.Optional[jsii.Number] = None,
        depends_on: typing.Optional[typing.List[cdktf.TerraformResource]] = None,
        lifecycle: typing.Optional[cdktf.TerraformResourceLifecycle] = None,
        provider: typing.Optional[cdktf.TerraformProvider] = None,
        storage_account_id: builtins.str,
        rule: typing.Optional[typing.List["StorageManagementPolicyRule"]] = None,
        timeouts: typing.Optional["StorageManagementPolicyTimeouts"] = None,
    ) -> None:
        """
        :param count: 
        :param depends_on: 
        :param lifecycle: 
        :param provider: 
        :param storage_account_id: 
        :param rule: rule block.
        :param timeouts: timeouts block.
        """
        if isinstance(lifecycle, dict):
            lifecycle = cdktf.TerraformResourceLifecycle(**lifecycle)
        if isinstance(timeouts, dict):
            timeouts = StorageManagementPolicyTimeouts(**timeouts)
        self._values: typing.Dict[str, typing.Any] = {
            "storage_account_id": storage_account_id,
        }
        if count is not None:
            self._values["count"] = count
        if depends_on is not None:
            self._values["depends_on"] = depends_on
        if lifecycle is not None:
            self._values["lifecycle"] = lifecycle
        if provider is not None:
            self._values["provider"] = provider
        if rule is not None:
            self._values["rule"] = rule
        if timeouts is not None:
            self._values["timeouts"] = timeouts

    @builtins.property
    def count(self) -> typing.Optional[jsii.Number]:
        """
        :stability: experimental
        """
        result = self._values.get("count")
        return result

    @builtins.property
    def depends_on(self) -> typing.Optional[typing.List[cdktf.TerraformResource]]:
        """
        :stability: experimental
        """
        result = self._values.get("depends_on")
        return result

    @builtins.property
    def lifecycle(self) -> typing.Optional[cdktf.TerraformResourceLifecycle]:
        """
        :stability: experimental
        """
        result = self._values.get("lifecycle")
        return result

    @builtins.property
    def provider(self) -> typing.Optional[cdktf.TerraformProvider]:
        """
        :stability: experimental
        """
        result = self._values.get("provider")
        return result

    @builtins.property
    def storage_account_id(self) -> builtins.str:
        result = self._values.get("storage_account_id")
        assert result is not None, "Required property 'storage_account_id' is missing"
        return result

    @builtins.property
    def rule(self) -> typing.Optional[typing.List["StorageManagementPolicyRule"]]:
        """rule block."""
        result = self._values.get("rule")
        return result

    @builtins.property
    def timeouts(self) -> typing.Optional["StorageManagementPolicyTimeouts"]:
        """timeouts block."""
        result = self._values.get("timeouts")
        return result

    def __eq__(self, rhs: typing.Any) -> builtins.bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs: typing.Any) -> builtins.bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return "StorageManagementPolicyConfig(%s)" % ", ".join(
            k + "=" + repr(v) for k, v in self._values.items()
        )


@jsii.data_type(
    jsii_type="@cdktf/provider-azurerm.StorageManagementPolicyRule",
    jsii_struct_bases=[],
    name_mapping={
        "actions": "actions",
        "enabled": "enabled",
        "name": "name",
        "filters": "filters",
    },
)
class StorageManagementPolicyRule:
    def __init__(
        self,
        *,
        actions: typing.List["StorageManagementPolicyRuleActions"],
        enabled: builtins.bool,
        name: builtins.str,
        filters: typing.Optional[typing.List["StorageManagementPolicyRuleFilters"]] = None,
    ) -> None:
        """
        :param actions: actions block.
        :param enabled: 
        :param name: 
        :param filters: filters block.
        """
        self._values: typing.Dict[str, typing.Any] = {
            "actions": actions,
            "enabled": enabled,
            "name": name,
        }
        if filters is not None:
            self._values["filters"] = filters

    @builtins.property
    def actions(self) -> typing.List["StorageManagementPolicyRuleActions"]:
        """actions block."""
        result = self._values.get("actions")
        assert result is not None, "Required property 'actions' is missing"
        return result

    @builtins.property
    def enabled(self) -> builtins.bool:
        result = self._values.get("enabled")
        assert result is not None, "Required property 'enabled' is missing"
        return result

    @builtins.property
    def name(self) -> builtins.str:
        result = self._values.get("name")
        assert result is not None, "Required property 'name' is missing"
        return result

    @builtins.property
    def filters(
        self,
    ) -> typing.Optional[typing.List["StorageManagementPolicyRuleFilters"]]:
        """filters block."""
        result = self._values.get("filters")
        return result

    def __eq__(self, rhs: typing.Any) -> builtins.bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs: typing.Any) -> builtins.bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return "StorageManagementPolicyRule(%s)" % ", ".join(
            k + "=" + repr(v) for k, v in self._values.items()
        )


@jsii.data_type(
    jsii_type="@cdktf/provider-azurerm.StorageManagementPolicyRuleActions",
    jsii_struct_bases=[],
    name_mapping={"base_blob": "baseBlob", "snapshot": "snapshot"},
)
class StorageManagementPolicyRuleActions:
    def __init__(
        self,
        *,
        base_blob: typing.Optional[typing.List["StorageManagementPolicyRuleActionsBaseBlob"]] = None,
        snapshot: typing.Optional[typing.List["StorageManagementPolicyRuleActionsSnapshot"]] = None,
    ) -> None:
        """
        :param base_blob: base_blob block.
        :param snapshot: snapshot block.
        """
        self._values: typing.Dict[str, typing.Any] = {}
        if base_blob is not None:
            self._values["base_blob"] = base_blob
        if snapshot is not None:
            self._values["snapshot"] = snapshot

    @builtins.property
    def base_blob(
        self,
    ) -> typing.Optional[typing.List["StorageManagementPolicyRuleActionsBaseBlob"]]:
        """base_blob block."""
        result = self._values.get("base_blob")
        return result

    @builtins.property
    def snapshot(
        self,
    ) -> typing.Optional[typing.List["StorageManagementPolicyRuleActionsSnapshot"]]:
        """snapshot block."""
        result = self._values.get("snapshot")
        return result

    def __eq__(self, rhs: typing.Any) -> builtins.bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs: typing.Any) -> builtins.bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return "StorageManagementPolicyRuleActions(%s)" % ", ".join(
            k + "=" + repr(v) for k, v in self._values.items()
        )


@jsii.data_type(
    jsii_type="@cdktf/provider-azurerm.StorageManagementPolicyRuleActionsBaseBlob",
    jsii_struct_bases=[],
    name_mapping={
        "delete_after_days_since_modification_greater_than": "deleteAfterDaysSinceModificationGreaterThan",
        "tier_to_archive_after_days_since_modification_greater_than": "tierToArchiveAfterDaysSinceModificationGreaterThan",
        "tier_to_cool_after_days_since_modification_greater_than": "tierToCoolAfterDaysSinceModificationGreaterThan",
    },
)
class StorageManagementPolicyRuleActionsBaseBlob:
    def __init__(
        self,
        *,
        delete_after_days_since_modification_greater_than: typing.Optional[jsii.Number] = None,
        tier_to_archive_after_days_since_modification_greater_than: typing.Optional[jsii.Number] = None,
        tier_to_cool_after_days_since_modification_greater_than: typing.Optional[jsii.Number] = None,
    ) -> None:
        """
        :param delete_after_days_since_modification_greater_than: 
        :param tier_to_archive_after_days_since_modification_greater_than: 
        :param tier_to_cool_after_days_since_modification_greater_than: 
        """
        self._values: typing.Dict[str, typing.Any] = {}
        if delete_after_days_since_modification_greater_than is not None:
            self._values["delete_after_days_since_modification_greater_than"] = delete_after_days_since_modification_greater_than
        if tier_to_archive_after_days_since_modification_greater_than is not None:
            self._values["tier_to_archive_after_days_since_modification_greater_than"] = tier_to_archive_after_days_since_modification_greater_than
        if tier_to_cool_after_days_since_modification_greater_than is not None:
            self._values["tier_to_cool_after_days_since_modification_greater_than"] = tier_to_cool_after_days_since_modification_greater_than

    @builtins.property
    def delete_after_days_since_modification_greater_than(
        self,
    ) -> typing.Optional[jsii.Number]:
        result = self._values.get("delete_after_days_since_modification_greater_than")
        return result

    @builtins.property
    def tier_to_archive_after_days_since_modification_greater_than(
        self,
    ) -> typing.Optional[jsii.Number]:
        result = self._values.get("tier_to_archive_after_days_since_modification_greater_than")
        return result

    @builtins.property
    def tier_to_cool_after_days_since_modification_greater_than(
        self,
    ) -> typing.Optional[jsii.Number]:
        result = self._values.get("tier_to_cool_after_days_since_modification_greater_than")
        return result

    def __eq__(self, rhs: typing.Any) -> builtins.bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs: typing.Any) -> builtins.bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return "StorageManagementPolicyRuleActionsBaseBlob(%s)" % ", ".join(
            k + "=" + repr(v) for k, v in self._values.items()
        )


@jsii.data_type(
    jsii_type="@cdktf/provider-azurerm.StorageManagementPolicyRuleActionsSnapshot",
    jsii_struct_bases=[],
    name_mapping={
        "delete_after_days_since_creation_greater_than": "deleteAfterDaysSinceCreationGreaterThan",
    },
)
class StorageManagementPolicyRuleActionsSnapshot:
    def __init__(
        self,
        *,
        delete_after_days_since_creation_greater_than: typing.Optional[jsii.Number] = None,
    ) -> None:
        """
        :param delete_after_days_since_creation_greater_than: 
        """
        self._values: typing.Dict[str, typing.Any] = {}
        if delete_after_days_since_creation_greater_than is not None:
            self._values["delete_after_days_since_creation_greater_than"] = delete_after_days_since_creation_greater_than

    @builtins.property
    def delete_after_days_since_creation_greater_than(
        self,
    ) -> typing.Optional[jsii.Number]:
        result = self._values.get("delete_after_days_since_creation_greater_than")
        return result

    def __eq__(self, rhs: typing.Any) -> builtins.bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs: typing.Any) -> builtins.bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return "StorageManagementPolicyRuleActionsSnapshot(%s)" % ", ".join(
            k + "=" + repr(v) for k, v in self._values.items()
        )


@jsii.data_type(
    jsii_type="@cdktf/provider-azurerm.StorageManagementPolicyRuleFilters",
    jsii_struct_bases=[],
    name_mapping={"blob_types": "blobTypes", "prefix_match": "prefixMatch"},
)
class StorageManagementPolicyRuleFilters:
    def __init__(
        self,
        *,
        blob_types: typing.Optional[typing.List[builtins.str]] = None,
        prefix_match: typing.Optional[typing.List[builtins.str]] = None,
    ) -> None:
        """
        :param blob_types: 
        :param prefix_match: 
        """
        self._values: typing.Dict[str, typing.Any] = {}
        if blob_types is not None:
            self._values["blob_types"] = blob_types
        if prefix_match is not None:
            self._values["prefix_match"] = prefix_match

    @builtins.property
    def blob_types(self) -> typing.Optional[typing.List[builtins.str]]:
        result = self._values.get("blob_types")
        return result

    @builtins.property
    def prefix_match(self) -> typing.Optional[typing.List[builtins.str]]:
        result = self._values.get("prefix_match")
        return result

    def __eq__(self, rhs: typing.Any) -> builtins.bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs: typing.Any) -> builtins.bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return "StorageManagementPolicyRuleFilters(%s)" % ", ".join(
            k + "=" + repr(v) for k, v in self._values.items()
        )


@jsii.data_type(
    jsii_type="@cdktf/provider-azurerm.StorageManagementPolicyTimeouts",
    jsii_struct_bases=[],
    name_mapping={
        "create": "create",
        "delete": "delete",
        "read": "read",
        "update": "update",
    },
)
class StorageManagementPolicyTimeouts:
    def __init__(
        self,
        *,
        create: typing.Optional[builtins.str] = None,
        delete: typing.Optional[builtins.str] = None,
        read: typing.Optional[builtins.str] = None,
        update: typing.Optional[builtins.str] = None,
    ) -> None:
        """
        :param create: 
        :param delete: 
        :param read: 
        :param update: 
        """
        self._values: typing.Dict[str, typing.Any] = {}
        if create is not None:
            self._values["create"] = create
        if delete is not None:
            self._values["delete"] = delete
        if read is not None:
            self._values["read"] = read
        if update is not None:
            self._values["update"] = update

    @builtins.property
    def create(self) -> typing.Optional[builtins.str]:
        result = self._values.get("create")
        return result

    @builtins.property
    def delete(self) -> typing.Optional[builtins.str]:
        result = self._values.get("delete")
        return result

    @builtins.property
    def read(self) -> typing.Optional[builtins.str]:
        result = self._values.get("read")
        return result

    @builtins.property
    def update(self) -> typing.Optional[builtins.str]:
        result = self._values.get("update")
        return result

    def __eq__(self, rhs: typing.Any) -> builtins.bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs: typing.Any) -> builtins.bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return "StorageManagementPolicyTimeouts(%s)" % ", ".join(
            k + "=" + repr(v) for k, v in self._values.items()
        )


class StorageQueue(
    cdktf.TerraformResource,
    metaclass=jsii.JSIIMeta,
    jsii_type="@cdktf/provider-azurerm.StorageQueue",
):
    def __init__(
        self,
        scope: constructs.Construct,
        id: builtins.str,
        *,
        name: builtins.str,
        storage_account_name: builtins.str,
        metadata: typing.Optional[typing.Mapping[builtins.str, builtins.str]] = None,
        timeouts: typing.Optional["StorageQueueTimeouts"] = None,
        count: typing.Optional[jsii.Number] = None,
        depends_on: typing.Optional[typing.List[cdktf.TerraformResource]] = None,
        lifecycle: typing.Optional[cdktf.TerraformResourceLifecycle] = None,
        provider: typing.Optional[cdktf.TerraformProvider] = None,
    ) -> None:
        """
        :param scope: -
        :param id: -
        :param name: 
        :param storage_account_name: 
        :param metadata: 
        :param timeouts: timeouts block.
        :param count: 
        :param depends_on: 
        :param lifecycle: 
        :param provider: 
        """
        config = StorageQueueConfig(
            name=name,
            storage_account_name=storage_account_name,
            metadata=metadata,
            timeouts=timeouts,
            count=count,
            depends_on=depends_on,
            lifecycle=lifecycle,
            provider=provider,
        )

        jsii.create(StorageQueue, self, [scope, id, config])

    @jsii.member(jsii_name="synthesizeAttributes")
    def _synthesize_attributes(self) -> typing.Mapping[builtins.str, typing.Any]:
        return jsii.invoke(self, "synthesizeAttributes", [])

    @builtins.property # type: ignore
    @jsii.member(jsii_name="name")
    def name(self) -> builtins.str:
        return jsii.get(self, "name")

    @name.setter # type: ignore
    def name(self, value: builtins.str) -> None:
        jsii.set(self, "name", value)

    @builtins.property # type: ignore
    @jsii.member(jsii_name="storageAccountName")
    def storage_account_name(self) -> builtins.str:
        return jsii.get(self, "storageAccountName")

    @storage_account_name.setter # type: ignore
    def storage_account_name(self, value: builtins.str) -> None:
        jsii.set(self, "storageAccountName", value)

    @builtins.property # type: ignore
    @jsii.member(jsii_name="id")
    def id(self) -> typing.Optional[builtins.str]:
        return jsii.get(self, "id")

    @id.setter # type: ignore
    def id(self, value: typing.Optional[builtins.str]) -> None:
        jsii.set(self, "id", value)

    @builtins.property # type: ignore
    @jsii.member(jsii_name="metadata")
    def metadata(self) -> typing.Optional[typing.Mapping[builtins.str, builtins.str]]:
        return jsii.get(self, "metadata")

    @metadata.setter # type: ignore
    def metadata(
        self,
        value: typing.Optional[typing.Mapping[builtins.str, builtins.str]],
    ) -> None:
        jsii.set(self, "metadata", value)

    @builtins.property # type: ignore
    @jsii.member(jsii_name="timeouts")
    def timeouts(self) -> typing.Optional["StorageQueueTimeouts"]:
        return jsii.get(self, "timeouts")

    @timeouts.setter # type: ignore
    def timeouts(self, value: typing.Optional["StorageQueueTimeouts"]) -> None:
        jsii.set(self, "timeouts", value)


@jsii.data_type(
    jsii_type="@cdktf/provider-azurerm.StorageQueueConfig",
    jsii_struct_bases=[cdktf.TerraformMetaArguments],
    name_mapping={
        "count": "count",
        "depends_on": "dependsOn",
        "lifecycle": "lifecycle",
        "provider": "provider",
        "name": "name",
        "storage_account_name": "storageAccountName",
        "metadata": "metadata",
        "timeouts": "timeouts",
    },
)
class StorageQueueConfig(cdktf.TerraformMetaArguments):
    def __init__(
        self,
        *,
        count: typing.Optional[jsii.Number] = None,
        depends_on: typing.Optional[typing.List[cdktf.TerraformResource]] = None,
        lifecycle: typing.Optional[cdktf.TerraformResourceLifecycle] = None,
        provider: typing.Optional[cdktf.TerraformProvider] = None,
        name: builtins.str,
        storage_account_name: builtins.str,
        metadata: typing.Optional[typing.Mapping[builtins.str, builtins.str]] = None,
        timeouts: typing.Optional["StorageQueueTimeouts"] = None,
    ) -> None:
        """
        :param count: 
        :param depends_on: 
        :param lifecycle: 
        :param provider: 
        :param name: 
        :param storage_account_name: 
        :param metadata: 
        :param timeouts: timeouts block.
        """
        if isinstance(lifecycle, dict):
            lifecycle = cdktf.TerraformResourceLifecycle(**lifecycle)
        if isinstance(timeouts, dict):
            timeouts = StorageQueueTimeouts(**timeouts)
        self._values: typing.Dict[str, typing.Any] = {
            "name": name,
            "storage_account_name": storage_account_name,
        }
        if count is not None:
            self._values["count"] = count
        if depends_on is not None:
            self._values["depends_on"] = depends_on
        if lifecycle is not None:
            self._values["lifecycle"] = lifecycle
        if provider is not None:
            self._values["provider"] = provider
        if metadata is not None:
            self._values["metadata"] = metadata
        if timeouts is not None:
            self._values["timeouts"] = timeouts

    @builtins.property
    def count(self) -> typing.Optional[jsii.Number]:
        """
        :stability: experimental
        """
        result = self._values.get("count")
        return result

    @builtins.property
    def depends_on(self) -> typing.Optional[typing.List[cdktf.TerraformResource]]:
        """
        :stability: experimental
        """
        result = self._values.get("depends_on")
        return result

    @builtins.property
    def lifecycle(self) -> typing.Optional[cdktf.TerraformResourceLifecycle]:
        """
        :stability: experimental
        """
        result = self._values.get("lifecycle")
        return result

    @builtins.property
    def provider(self) -> typing.Optional[cdktf.TerraformProvider]:
        """
        :stability: experimental
        """
        result = self._values.get("provider")
        return result

    @builtins.property
    def name(self) -> builtins.str:
        result = self._values.get("name")
        assert result is not None, "Required property 'name' is missing"
        return result

    @builtins.property
    def storage_account_name(self) -> builtins.str:
        result = self._values.get("storage_account_name")
        assert result is not None, "Required property 'storage_account_name' is missing"
        return result

    @builtins.property
    def metadata(self) -> typing.Optional[typing.Mapping[builtins.str, builtins.str]]:
        result = self._values.get("metadata")
        return result

    @builtins.property
    def timeouts(self) -> typing.Optional["StorageQueueTimeouts"]:
        """timeouts block."""
        result = self._values.get("timeouts")
        return result

    def __eq__(self, rhs: typing.Any) -> builtins.bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs: typing.Any) -> builtins.bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return "StorageQueueConfig(%s)" % ", ".join(
            k + "=" + repr(v) for k, v in self._values.items()
        )


@jsii.data_type(
    jsii_type="@cdktf/provider-azurerm.StorageQueueTimeouts",
    jsii_struct_bases=[],
    name_mapping={
        "create": "create",
        "delete": "delete",
        "read": "read",
        "update": "update",
    },
)
class StorageQueueTimeouts:
    def __init__(
        self,
        *,
        create: typing.Optional[builtins.str] = None,
        delete: typing.Optional[builtins.str] = None,
        read: typing.Optional[builtins.str] = None,
        update: typing.Optional[builtins.str] = None,
    ) -> None:
        """
        :param create: 
        :param delete: 
        :param read: 
        :param update: 
        """
        self._values: typing.Dict[str, typing.Any] = {}
        if create is not None:
            self._values["create"] = create
        if delete is not None:
            self._values["delete"] = delete
        if read is not None:
            self._values["read"] = read
        if update is not None:
            self._values["update"] = update

    @builtins.property
    def create(self) -> typing.Optional[builtins.str]:
        result = self._values.get("create")
        return result

    @builtins.property
    def delete(self) -> typing.Optional[builtins.str]:
        result = self._values.get("delete")
        return result

    @builtins.property
    def read(self) -> typing.Optional[builtins.str]:
        result = self._values.get("read")
        return result

    @builtins.property
    def update(self) -> typing.Optional[builtins.str]:
        result = self._values.get("update")
        return result

    def __eq__(self, rhs: typing.Any) -> builtins.bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs: typing.Any) -> builtins.bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return "StorageQueueTimeouts(%s)" % ", ".join(
            k + "=" + repr(v) for k, v in self._values.items()
        )


class StorageShare(
    cdktf.TerraformResource,
    metaclass=jsii.JSIIMeta,
    jsii_type="@cdktf/provider-azurerm.StorageShare",
):
    def __init__(
        self,
        scope: constructs.Construct,
        id: builtins.str,
        *,
        name: builtins.str,
        storage_account_name: builtins.str,
        acl: typing.Optional[typing.List["StorageShareAcl"]] = None,
        metadata: typing.Optional[typing.Mapping[builtins.str, builtins.str]] = None,
        quota: typing.Optional[jsii.Number] = None,
        timeouts: typing.Optional["StorageShareTimeouts"] = None,
        count: typing.Optional[jsii.Number] = None,
        depends_on: typing.Optional[typing.List[cdktf.TerraformResource]] = None,
        lifecycle: typing.Optional[cdktf.TerraformResourceLifecycle] = None,
        provider: typing.Optional[cdktf.TerraformProvider] = None,
    ) -> None:
        """
        :param scope: -
        :param id: -
        :param name: 
        :param storage_account_name: 
        :param acl: acl block.
        :param metadata: 
        :param quota: 
        :param timeouts: timeouts block.
        :param count: 
        :param depends_on: 
        :param lifecycle: 
        :param provider: 
        """
        config = StorageShareConfig(
            name=name,
            storage_account_name=storage_account_name,
            acl=acl,
            metadata=metadata,
            quota=quota,
            timeouts=timeouts,
            count=count,
            depends_on=depends_on,
            lifecycle=lifecycle,
            provider=provider,
        )

        jsii.create(StorageShare, self, [scope, id, config])

    @jsii.member(jsii_name="synthesizeAttributes")
    def _synthesize_attributes(self) -> typing.Mapping[builtins.str, typing.Any]:
        return jsii.invoke(self, "synthesizeAttributes", [])

    @builtins.property # type: ignore
    @jsii.member(jsii_name="url")
    def url(self) -> builtins.str:
        return jsii.get(self, "url")

    @builtins.property # type: ignore
    @jsii.member(jsii_name="name")
    def name(self) -> builtins.str:
        return jsii.get(self, "name")

    @name.setter # type: ignore
    def name(self, value: builtins.str) -> None:
        jsii.set(self, "name", value)

    @builtins.property # type: ignore
    @jsii.member(jsii_name="storageAccountName")
    def storage_account_name(self) -> builtins.str:
        return jsii.get(self, "storageAccountName")

    @storage_account_name.setter # type: ignore
    def storage_account_name(self, value: builtins.str) -> None:
        jsii.set(self, "storageAccountName", value)

    @builtins.property # type: ignore
    @jsii.member(jsii_name="acl")
    def acl(self) -> typing.Optional[typing.List["StorageShareAcl"]]:
        return jsii.get(self, "acl")

    @acl.setter # type: ignore
    def acl(self, value: typing.Optional[typing.List["StorageShareAcl"]]) -> None:
        jsii.set(self, "acl", value)

    @builtins.property # type: ignore
    @jsii.member(jsii_name="id")
    def id(self) -> typing.Optional[builtins.str]:
        return jsii.get(self, "id")

    @id.setter # type: ignore
    def id(self, value: typing.Optional[builtins.str]) -> None:
        jsii.set(self, "id", value)

    @builtins.property # type: ignore
    @jsii.member(jsii_name="metadata")
    def metadata(self) -> typing.Optional[typing.Mapping[builtins.str, builtins.str]]:
        return jsii.get(self, "metadata")

    @metadata.setter # type: ignore
    def metadata(
        self,
        value: typing.Optional[typing.Mapping[builtins.str, builtins.str]],
    ) -> None:
        jsii.set(self, "metadata", value)

    @builtins.property # type: ignore
    @jsii.member(jsii_name="quota")
    def quota(self) -> typing.Optional[jsii.Number]:
        return jsii.get(self, "quota")

    @quota.setter # type: ignore
    def quota(self, value: typing.Optional[jsii.Number]) -> None:
        jsii.set(self, "quota", value)

    @builtins.property # type: ignore
    @jsii.member(jsii_name="timeouts")
    def timeouts(self) -> typing.Optional["StorageShareTimeouts"]:
        return jsii.get(self, "timeouts")

    @timeouts.setter # type: ignore
    def timeouts(self, value: typing.Optional["StorageShareTimeouts"]) -> None:
        jsii.set(self, "timeouts", value)


@jsii.data_type(
    jsii_type="@cdktf/provider-azurerm.StorageShareAcl",
    jsii_struct_bases=[],
    name_mapping={"id": "id", "access_policy": "accessPolicy"},
)
class StorageShareAcl:
    def __init__(
        self,
        *,
        id: builtins.str,
        access_policy: typing.Optional[typing.List["StorageShareAclAccessPolicy"]] = None,
    ) -> None:
        """
        :param id: 
        :param access_policy: access_policy block.
        """
        self._values: typing.Dict[str, typing.Any] = {
            "id": id,
        }
        if access_policy is not None:
            self._values["access_policy"] = access_policy

    @builtins.property
    def id(self) -> builtins.str:
        result = self._values.get("id")
        assert result is not None, "Required property 'id' is missing"
        return result

    @builtins.property
    def access_policy(
        self,
    ) -> typing.Optional[typing.List["StorageShareAclAccessPolicy"]]:
        """access_policy block."""
        result = self._values.get("access_policy")
        return result

    def __eq__(self, rhs: typing.Any) -> builtins.bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs: typing.Any) -> builtins.bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return "StorageShareAcl(%s)" % ", ".join(
            k + "=" + repr(v) for k, v in self._values.items()
        )


@jsii.data_type(
    jsii_type="@cdktf/provider-azurerm.StorageShareAclAccessPolicy",
    jsii_struct_bases=[],
    name_mapping={"expiry": "expiry", "permissions": "permissions", "start": "start"},
)
class StorageShareAclAccessPolicy:
    def __init__(
        self,
        *,
        expiry: builtins.str,
        permissions: builtins.str,
        start: builtins.str,
    ) -> None:
        """
        :param expiry: 
        :param permissions: 
        :param start: 
        """
        self._values: typing.Dict[str, typing.Any] = {
            "expiry": expiry,
            "permissions": permissions,
            "start": start,
        }

    @builtins.property
    def expiry(self) -> builtins.str:
        result = self._values.get("expiry")
        assert result is not None, "Required property 'expiry' is missing"
        return result

    @builtins.property
    def permissions(self) -> builtins.str:
        result = self._values.get("permissions")
        assert result is not None, "Required property 'permissions' is missing"
        return result

    @builtins.property
    def start(self) -> builtins.str:
        result = self._values.get("start")
        assert result is not None, "Required property 'start' is missing"
        return result

    def __eq__(self, rhs: typing.Any) -> builtins.bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs: typing.Any) -> builtins.bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return "StorageShareAclAccessPolicy(%s)" % ", ".join(
            k + "=" + repr(v) for k, v in self._values.items()
        )


@jsii.data_type(
    jsii_type="@cdktf/provider-azurerm.StorageShareConfig",
    jsii_struct_bases=[cdktf.TerraformMetaArguments],
    name_mapping={
        "count": "count",
        "depends_on": "dependsOn",
        "lifecycle": "lifecycle",
        "provider": "provider",
        "name": "name",
        "storage_account_name": "storageAccountName",
        "acl": "acl",
        "metadata": "metadata",
        "quota": "quota",
        "timeouts": "timeouts",
    },
)
class StorageShareConfig(cdktf.TerraformMetaArguments):
    def __init__(
        self,
        *,
        count: typing.Optional[jsii.Number] = None,
        depends_on: typing.Optional[typing.List[cdktf.TerraformResource]] = None,
        lifecycle: typing.Optional[cdktf.TerraformResourceLifecycle] = None,
        provider: typing.Optional[cdktf.TerraformProvider] = None,
        name: builtins.str,
        storage_account_name: builtins.str,
        acl: typing.Optional[typing.List[StorageShareAcl]] = None,
        metadata: typing.Optional[typing.Mapping[builtins.str, builtins.str]] = None,
        quota: typing.Optional[jsii.Number] = None,
        timeouts: typing.Optional["StorageShareTimeouts"] = None,
    ) -> None:
        """
        :param count: 
        :param depends_on: 
        :param lifecycle: 
        :param provider: 
        :param name: 
        :param storage_account_name: 
        :param acl: acl block.
        :param metadata: 
        :param quota: 
        :param timeouts: timeouts block.
        """
        if isinstance(lifecycle, dict):
            lifecycle = cdktf.TerraformResourceLifecycle(**lifecycle)
        if isinstance(timeouts, dict):
            timeouts = StorageShareTimeouts(**timeouts)
        self._values: typing.Dict[str, typing.Any] = {
            "name": name,
            "storage_account_name": storage_account_name,
        }
        if count is not None:
            self._values["count"] = count
        if depends_on is not None:
            self._values["depends_on"] = depends_on
        if lifecycle is not None:
            self._values["lifecycle"] = lifecycle
        if provider is not None:
            self._values["provider"] = provider
        if acl is not None:
            self._values["acl"] = acl
        if metadata is not None:
            self._values["metadata"] = metadata
        if quota is not None:
            self._values["quota"] = quota
        if timeouts is not None:
            self._values["timeouts"] = timeouts

    @builtins.property
    def count(self) -> typing.Optional[jsii.Number]:
        """
        :stability: experimental
        """
        result = self._values.get("count")
        return result

    @builtins.property
    def depends_on(self) -> typing.Optional[typing.List[cdktf.TerraformResource]]:
        """
        :stability: experimental
        """
        result = self._values.get("depends_on")
        return result

    @builtins.property
    def lifecycle(self) -> typing.Optional[cdktf.TerraformResourceLifecycle]:
        """
        :stability: experimental
        """
        result = self._values.get("lifecycle")
        return result

    @builtins.property
    def provider(self) -> typing.Optional[cdktf.TerraformProvider]:
        """
        :stability: experimental
        """
        result = self._values.get("provider")
        return result

    @builtins.property
    def name(self) -> builtins.str:
        result = self._values.get("name")
        assert result is not None, "Required property 'name' is missing"
        return result

    @builtins.property
    def storage_account_name(self) -> builtins.str:
        result = self._values.get("storage_account_name")
        assert result is not None, "Required property 'storage_account_name' is missing"
        return result

    @builtins.property
    def acl(self) -> typing.Optional[typing.List[StorageShareAcl]]:
        """acl block."""
        result = self._values.get("acl")
        return result

    @builtins.property
    def metadata(self) -> typing.Optional[typing.Mapping[builtins.str, builtins.str]]:
        result = self._values.get("metadata")
        return result

    @builtins.property
    def quota(self) -> typing.Optional[jsii.Number]:
        result = self._values.get("quota")
        return result

    @builtins.property
    def timeouts(self) -> typing.Optional["StorageShareTimeouts"]:
        """timeouts block."""
        result = self._values.get("timeouts")
        return result

    def __eq__(self, rhs: typing.Any) -> builtins.bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs: typing.Any) -> builtins.bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return "StorageShareConfig(%s)" % ", ".join(
            k + "=" + repr(v) for k, v in self._values.items()
        )


class StorageShareDirectory(
    cdktf.TerraformResource,
    metaclass=jsii.JSIIMeta,
    jsii_type="@cdktf/provider-azurerm.StorageShareDirectory",
):
    def __init__(
        self,
        scope: constructs.Construct,
        id: builtins.str,
        *,
        name: builtins.str,
        share_name: builtins.str,
        storage_account_name: builtins.str,
        metadata: typing.Optional[typing.Mapping[builtins.str, builtins.str]] = None,
        timeouts: typing.Optional["StorageShareDirectoryTimeouts"] = None,
        count: typing.Optional[jsii.Number] = None,
        depends_on: typing.Optional[typing.List[cdktf.TerraformResource]] = None,
        lifecycle: typing.Optional[cdktf.TerraformResourceLifecycle] = None,
        provider: typing.Optional[cdktf.TerraformProvider] = None,
    ) -> None:
        """
        :param scope: -
        :param id: -
        :param name: 
        :param share_name: 
        :param storage_account_name: 
        :param metadata: 
        :param timeouts: timeouts block.
        :param count: 
        :param depends_on: 
        :param lifecycle: 
        :param provider: 
        """
        config = StorageShareDirectoryConfig(
            name=name,
            share_name=share_name,
            storage_account_name=storage_account_name,
            metadata=metadata,
            timeouts=timeouts,
            count=count,
            depends_on=depends_on,
            lifecycle=lifecycle,
            provider=provider,
        )

        jsii.create(StorageShareDirectory, self, [scope, id, config])

    @jsii.member(jsii_name="synthesizeAttributes")
    def _synthesize_attributes(self) -> typing.Mapping[builtins.str, typing.Any]:
        return jsii.invoke(self, "synthesizeAttributes", [])

    @builtins.property # type: ignore
    @jsii.member(jsii_name="name")
    def name(self) -> builtins.str:
        return jsii.get(self, "name")

    @name.setter # type: ignore
    def name(self, value: builtins.str) -> None:
        jsii.set(self, "name", value)

    @builtins.property # type: ignore
    @jsii.member(jsii_name="shareName")
    def share_name(self) -> builtins.str:
        return jsii.get(self, "shareName")

    @share_name.setter # type: ignore
    def share_name(self, value: builtins.str) -> None:
        jsii.set(self, "shareName", value)

    @builtins.property # type: ignore
    @jsii.member(jsii_name="storageAccountName")
    def storage_account_name(self) -> builtins.str:
        return jsii.get(self, "storageAccountName")

    @storage_account_name.setter # type: ignore
    def storage_account_name(self, value: builtins.str) -> None:
        jsii.set(self, "storageAccountName", value)

    @builtins.property # type: ignore
    @jsii.member(jsii_name="id")
    def id(self) -> typing.Optional[builtins.str]:
        return jsii.get(self, "id")

    @id.setter # type: ignore
    def id(self, value: typing.Optional[builtins.str]) -> None:
        jsii.set(self, "id", value)

    @builtins.property # type: ignore
    @jsii.member(jsii_name="metadata")
    def metadata(self) -> typing.Optional[typing.Mapping[builtins.str, builtins.str]]:
        return jsii.get(self, "metadata")

    @metadata.setter # type: ignore
    def metadata(
        self,
        value: typing.Optional[typing.Mapping[builtins.str, builtins.str]],
    ) -> None:
        jsii.set(self, "metadata", value)

    @builtins.property # type: ignore
    @jsii.member(jsii_name="timeouts")
    def timeouts(self) -> typing.Optional["StorageShareDirectoryTimeouts"]:
        return jsii.get(self, "timeouts")

    @timeouts.setter # type: ignore
    def timeouts(self, value: typing.Optional["StorageShareDirectoryTimeouts"]) -> None:
        jsii.set(self, "timeouts", value)


@jsii.data_type(
    jsii_type="@cdktf/provider-azurerm.StorageShareDirectoryConfig",
    jsii_struct_bases=[cdktf.TerraformMetaArguments],
    name_mapping={
        "count": "count",
        "depends_on": "dependsOn",
        "lifecycle": "lifecycle",
        "provider": "provider",
        "name": "name",
        "share_name": "shareName",
        "storage_account_name": "storageAccountName",
        "metadata": "metadata",
        "timeouts": "timeouts",
    },
)
class StorageShareDirectoryConfig(cdktf.TerraformMetaArguments):
    def __init__(
        self,
        *,
        count: typing.Optional[jsii.Number] = None,
        depends_on: typing.Optional[typing.List[cdktf.TerraformResource]] = None,
        lifecycle: typing.Optional[cdktf.TerraformResourceLifecycle] = None,
        provider: typing.Optional[cdktf.TerraformProvider] = None,
        name: builtins.str,
        share_name: builtins.str,
        storage_account_name: builtins.str,
        metadata: typing.Optional[typing.Mapping[builtins.str, builtins.str]] = None,
        timeouts: typing.Optional["StorageShareDirectoryTimeouts"] = None,
    ) -> None:
        """
        :param count: 
        :param depends_on: 
        :param lifecycle: 
        :param provider: 
        :param name: 
        :param share_name: 
        :param storage_account_name: 
        :param metadata: 
        :param timeouts: timeouts block.
        """
        if isinstance(lifecycle, dict):
            lifecycle = cdktf.TerraformResourceLifecycle(**lifecycle)
        if isinstance(timeouts, dict):
            timeouts = StorageShareDirectoryTimeouts(**timeouts)
        self._values: typing.Dict[str, typing.Any] = {
            "name": name,
            "share_name": share_name,
            "storage_account_name": storage_account_name,
        }
        if count is not None:
            self._values["count"] = count
        if depends_on is not None:
            self._values["depends_on"] = depends_on
        if lifecycle is not None:
            self._values["lifecycle"] = lifecycle
        if provider is not None:
            self._values["provider"] = provider
        if metadata is not None:
            self._values["metadata"] = metadata
        if timeouts is not None:
            self._values["timeouts"] = timeouts

    @builtins.property
    def count(self) -> typing.Optional[jsii.Number]:
        """
        :stability: experimental
        """
        result = self._values.get("count")
        return result

    @builtins.property
    def depends_on(self) -> typing.Optional[typing.List[cdktf.TerraformResource]]:
        """
        :stability: experimental
        """
        result = self._values.get("depends_on")
        return result

    @builtins.property
    def lifecycle(self) -> typing.Optional[cdktf.TerraformResourceLifecycle]:
        """
        :stability: experimental
        """
        result = self._values.get("lifecycle")
        return result

    @builtins.property
    def provider(self) -> typing.Optional[cdktf.TerraformProvider]:
        """
        :stability: experimental
        """
        result = self._values.get("provider")
        return result

    @builtins.property
    def name(self) -> builtins.str:
        result = self._values.get("name")
        assert result is not None, "Required property 'name' is missing"
        return result

    @builtins.property
    def share_name(self) -> builtins.str:
        result = self._values.get("share_name")
        assert result is not None, "Required property 'share_name' is missing"
        return result

    @builtins.property
    def storage_account_name(self) -> builtins.str:
        result = self._values.get("storage_account_name")
        assert result is not None, "Required property 'storage_account_name' is missing"
        return result

    @builtins.property
    def metadata(self) -> typing.Optional[typing.Mapping[builtins.str, builtins.str]]:
        result = self._values.get("metadata")
        return result

    @builtins.property
    def timeouts(self) -> typing.Optional["StorageShareDirectoryTimeouts"]:
        """timeouts block."""
        result = self._values.get("timeouts")
        return result

    def __eq__(self, rhs: typing.Any) -> builtins.bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs: typing.Any) -> builtins.bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return "StorageShareDirectoryConfig(%s)" % ", ".join(
            k + "=" + repr(v) for k, v in self._values.items()
        )


@jsii.data_type(
    jsii_type="@cdktf/provider-azurerm.StorageShareDirectoryTimeouts",
    jsii_struct_bases=[],
    name_mapping={
        "create": "create",
        "delete": "delete",
        "read": "read",
        "update": "update",
    },
)
class StorageShareDirectoryTimeouts:
    def __init__(
        self,
        *,
        create: typing.Optional[builtins.str] = None,
        delete: typing.Optional[builtins.str] = None,
        read: typing.Optional[builtins.str] = None,
        update: typing.Optional[builtins.str] = None,
    ) -> None:
        """
        :param create: 
        :param delete: 
        :param read: 
        :param update: 
        """
        self._values: typing.Dict[str, typing.Any] = {}
        if create is not None:
            self._values["create"] = create
        if delete is not None:
            self._values["delete"] = delete
        if read is not None:
            self._values["read"] = read
        if update is not None:
            self._values["update"] = update

    @builtins.property
    def create(self) -> typing.Optional[builtins.str]:
        result = self._values.get("create")
        return result

    @builtins.property
    def delete(self) -> typing.Optional[builtins.str]:
        result = self._values.get("delete")
        return result

    @builtins.property
    def read(self) -> typing.Optional[builtins.str]:
        result = self._values.get("read")
        return result

    @builtins.property
    def update(self) -> typing.Optional[builtins.str]:
        result = self._values.get("update")
        return result

    def __eq__(self, rhs: typing.Any) -> builtins.bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs: typing.Any) -> builtins.bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return "StorageShareDirectoryTimeouts(%s)" % ", ".join(
            k + "=" + repr(v) for k, v in self._values.items()
        )


@jsii.data_type(
    jsii_type="@cdktf/provider-azurerm.StorageShareTimeouts",
    jsii_struct_bases=[],
    name_mapping={
        "create": "create",
        "delete": "delete",
        "read": "read",
        "update": "update",
    },
)
class StorageShareTimeouts:
    def __init__(
        self,
        *,
        create: typing.Optional[builtins.str] = None,
        delete: typing.Optional[builtins.str] = None,
        read: typing.Optional[builtins.str] = None,
        update: typing.Optional[builtins.str] = None,
    ) -> None:
        """
        :param create: 
        :param delete: 
        :param read: 
        :param update: 
        """
        self._values: typing.Dict[str, typing.Any] = {}
        if create is not None:
            self._values["create"] = create
        if delete is not None:
            self._values["delete"] = delete
        if read is not None:
            self._values["read"] = read
        if update is not None:
            self._values["update"] = update

    @builtins.property
    def create(self) -> typing.Optional[builtins.str]:
        result = self._values.get("create")
        return result

    @builtins.property
    def delete(self) -> typing.Optional[builtins.str]:
        result = self._values.get("delete")
        return result

    @builtins.property
    def read(self) -> typing.Optional[builtins.str]:
        result = self._values.get("read")
        return result

    @builtins.property
    def update(self) -> typing.Optional[builtins.str]:
        result = self._values.get("update")
        return result

    def __eq__(self, rhs: typing.Any) -> builtins.bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs: typing.Any) -> builtins.bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return "StorageShareTimeouts(%s)" % ", ".join(
            k + "=" + repr(v) for k, v in self._values.items()
        )


class StorageTable(
    cdktf.TerraformResource,
    metaclass=jsii.JSIIMeta,
    jsii_type="@cdktf/provider-azurerm.StorageTable",
):
    def __init__(
        self,
        scope: constructs.Construct,
        id: builtins.str,
        *,
        name: builtins.str,
        storage_account_name: builtins.str,
        acl: typing.Optional[typing.List["StorageTableAcl"]] = None,
        timeouts: typing.Optional["StorageTableTimeouts"] = None,
        count: typing.Optional[jsii.Number] = None,
        depends_on: typing.Optional[typing.List[cdktf.TerraformResource]] = None,
        lifecycle: typing.Optional[cdktf.TerraformResourceLifecycle] = None,
        provider: typing.Optional[cdktf.TerraformProvider] = None,
    ) -> None:
        """
        :param scope: -
        :param id: -
        :param name: 
        :param storage_account_name: 
        :param acl: acl block.
        :param timeouts: timeouts block.
        :param count: 
        :param depends_on: 
        :param lifecycle: 
        :param provider: 
        """
        config = StorageTableConfig(
            name=name,
            storage_account_name=storage_account_name,
            acl=acl,
            timeouts=timeouts,
            count=count,
            depends_on=depends_on,
            lifecycle=lifecycle,
            provider=provider,
        )

        jsii.create(StorageTable, self, [scope, id, config])

    @jsii.member(jsii_name="synthesizeAttributes")
    def _synthesize_attributes(self) -> typing.Mapping[builtins.str, typing.Any]:
        return jsii.invoke(self, "synthesizeAttributes", [])

    @builtins.property # type: ignore
    @jsii.member(jsii_name="name")
    def name(self) -> builtins.str:
        return jsii.get(self, "name")

    @name.setter # type: ignore
    def name(self, value: builtins.str) -> None:
        jsii.set(self, "name", value)

    @builtins.property # type: ignore
    @jsii.member(jsii_name="storageAccountName")
    def storage_account_name(self) -> builtins.str:
        return jsii.get(self, "storageAccountName")

    @storage_account_name.setter # type: ignore
    def storage_account_name(self, value: builtins.str) -> None:
        jsii.set(self, "storageAccountName", value)

    @builtins.property # type: ignore
    @jsii.member(jsii_name="acl")
    def acl(self) -> typing.Optional[typing.List["StorageTableAcl"]]:
        return jsii.get(self, "acl")

    @acl.setter # type: ignore
    def acl(self, value: typing.Optional[typing.List["StorageTableAcl"]]) -> None:
        jsii.set(self, "acl", value)

    @builtins.property # type: ignore
    @jsii.member(jsii_name="id")
    def id(self) -> typing.Optional[builtins.str]:
        return jsii.get(self, "id")

    @id.setter # type: ignore
    def id(self, value: typing.Optional[builtins.str]) -> None:
        jsii.set(self, "id", value)

    @builtins.property # type: ignore
    @jsii.member(jsii_name="timeouts")
    def timeouts(self) -> typing.Optional["StorageTableTimeouts"]:
        return jsii.get(self, "timeouts")

    @timeouts.setter # type: ignore
    def timeouts(self, value: typing.Optional["StorageTableTimeouts"]) -> None:
        jsii.set(self, "timeouts", value)


@jsii.data_type(
    jsii_type="@cdktf/provider-azurerm.StorageTableAcl",
    jsii_struct_bases=[],
    name_mapping={"id": "id", "access_policy": "accessPolicy"},
)
class StorageTableAcl:
    def __init__(
        self,
        *,
        id: builtins.str,
        access_policy: typing.Optional[typing.List["StorageTableAclAccessPolicy"]] = None,
    ) -> None:
        """
        :param id: 
        :param access_policy: access_policy block.
        """
        self._values: typing.Dict[str, typing.Any] = {
            "id": id,
        }
        if access_policy is not None:
            self._values["access_policy"] = access_policy

    @builtins.property
    def id(self) -> builtins.str:
        result = self._values.get("id")
        assert result is not None, "Required property 'id' is missing"
        return result

    @builtins.property
    def access_policy(
        self,
    ) -> typing.Optional[typing.List["StorageTableAclAccessPolicy"]]:
        """access_policy block."""
        result = self._values.get("access_policy")
        return result

    def __eq__(self, rhs: typing.Any) -> builtins.bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs: typing.Any) -> builtins.bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return "StorageTableAcl(%s)" % ", ".join(
            k + "=" + repr(v) for k, v in self._values.items()
        )


@jsii.data_type(
    jsii_type="@cdktf/provider-azurerm.StorageTableAclAccessPolicy",
    jsii_struct_bases=[],
    name_mapping={"expiry": "expiry", "permissions": "permissions", "start": "start"},
)
class StorageTableAclAccessPolicy:
    def __init__(
        self,
        *,
        expiry: builtins.str,
        permissions: builtins.str,
        start: builtins.str,
    ) -> None:
        """
        :param expiry: 
        :param permissions: 
        :param start: 
        """
        self._values: typing.Dict[str, typing.Any] = {
            "expiry": expiry,
            "permissions": permissions,
            "start": start,
        }

    @builtins.property
    def expiry(self) -> builtins.str:
        result = self._values.get("expiry")
        assert result is not None, "Required property 'expiry' is missing"
        return result

    @builtins.property
    def permissions(self) -> builtins.str:
        result = self._values.get("permissions")
        assert result is not None, "Required property 'permissions' is missing"
        return result

    @builtins.property
    def start(self) -> builtins.str:
        result = self._values.get("start")
        assert result is not None, "Required property 'start' is missing"
        return result

    def __eq__(self, rhs: typing.Any) -> builtins.bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs: typing.Any) -> builtins.bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return "StorageTableAclAccessPolicy(%s)" % ", ".join(
            k + "=" + repr(v) for k, v in self._values.items()
        )


@jsii.data_type(
    jsii_type="@cdktf/provider-azurerm.StorageTableConfig",
    jsii_struct_bases=[cdktf.TerraformMetaArguments],
    name_mapping={
        "count": "count",
        "depends_on": "dependsOn",
        "lifecycle": "lifecycle",
        "provider": "provider",
        "name": "name",
        "storage_account_name": "storageAccountName",
        "acl": "acl",
        "timeouts": "timeouts",
    },
)
class StorageTableConfig(cdktf.TerraformMetaArguments):
    def __init__(
        self,
        *,
        count: typing.Optional[jsii.Number] = None,
        depends_on: typing.Optional[typing.List[cdktf.TerraformResource]] = None,
        lifecycle: typing.Optional[cdktf.TerraformResourceLifecycle] = None,
        provider: typing.Optional[cdktf.TerraformProvider] = None,
        name: builtins.str,
        storage_account_name: builtins.str,
        acl: typing.Optional[typing.List[StorageTableAcl]] = None,
        timeouts: typing.Optional["StorageTableTimeouts"] = None,
    ) -> None:
        """
        :param count: 
        :param depends_on: 
        :param lifecycle: 
        :param provider: 
        :param name: 
        :param storage_account_name: 
        :param acl: acl block.
        :param timeouts: timeouts block.
        """
        if isinstance(lifecycle, dict):
            lifecycle = cdktf.TerraformResourceLifecycle(**lifecycle)
        if isinstance(timeouts, dict):
            timeouts = StorageTableTimeouts(**timeouts)
        self._values: typing.Dict[str, typing.Any] = {
            "name": name,
            "storage_account_name": storage_account_name,
        }
        if count is not None:
            self._values["count"] = count
        if depends_on is not None:
            self._values["depends_on"] = depends_on
        if lifecycle is not None:
            self._values["lifecycle"] = lifecycle
        if provider is not None:
            self._values["provider"] = provider
        if acl is not None:
            self._values["acl"] = acl
        if timeouts is not None:
            self._values["timeouts"] = timeouts

    @builtins.property
    def count(self) -> typing.Optional[jsii.Number]:
        """
        :stability: experimental
        """
        result = self._values.get("count")
        return result

    @builtins.property
    def depends_on(self) -> typing.Optional[typing.List[cdktf.TerraformResource]]:
        """
        :stability: experimental
        """
        result = self._values.get("depends_on")
        return result

    @builtins.property
    def lifecycle(self) -> typing.Optional[cdktf.TerraformResourceLifecycle]:
        """
        :stability: experimental
        """
        result = self._values.get("lifecycle")
        return result

    @builtins.property
    def provider(self) -> typing.Optional[cdktf.TerraformProvider]:
        """
        :stability: experimental
        """
        result = self._values.get("provider")
        return result

    @builtins.property
    def name(self) -> builtins.str:
        result = self._values.get("name")
        assert result is not None, "Required property 'name' is missing"
        return result

    @builtins.property
    def storage_account_name(self) -> builtins.str:
        result = self._values.get("storage_account_name")
        assert result is not None, "Required property 'storage_account_name' is missing"
        return result

    @builtins.property
    def acl(self) -> typing.Optional[typing.List[StorageTableAcl]]:
        """acl block."""
        result = self._values.get("acl")
        return result

    @builtins.property
    def timeouts(self) -> typing.Optional["StorageTableTimeouts"]:
        """timeouts block."""
        result = self._values.get("timeouts")
        return result

    def __eq__(self, rhs: typing.Any) -> builtins.bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs: typing.Any) -> builtins.bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return "StorageTableConfig(%s)" % ", ".join(
            k + "=" + repr(v) for k, v in self._values.items()
        )


class StorageTableEntity(
    cdktf.TerraformResource,
    metaclass=jsii.JSIIMeta,
    jsii_type="@cdktf/provider-azurerm.StorageTableEntity",
):
    def __init__(
        self,
        scope: constructs.Construct,
        id: builtins.str,
        *,
        entity: typing.Mapping[builtins.str, builtins.str],
        partition_key: builtins.str,
        row_key: builtins.str,
        storage_account_name: builtins.str,
        table_name: builtins.str,
        timeouts: typing.Optional["StorageTableEntityTimeouts"] = None,
        count: typing.Optional[jsii.Number] = None,
        depends_on: typing.Optional[typing.List[cdktf.TerraformResource]] = None,
        lifecycle: typing.Optional[cdktf.TerraformResourceLifecycle] = None,
        provider: typing.Optional[cdktf.TerraformProvider] = None,
    ) -> None:
        """
        :param scope: -
        :param id: -
        :param entity: 
        :param partition_key: 
        :param row_key: 
        :param storage_account_name: 
        :param table_name: 
        :param timeouts: timeouts block.
        :param count: 
        :param depends_on: 
        :param lifecycle: 
        :param provider: 
        """
        config = StorageTableEntityConfig(
            entity=entity,
            partition_key=partition_key,
            row_key=row_key,
            storage_account_name=storage_account_name,
            table_name=table_name,
            timeouts=timeouts,
            count=count,
            depends_on=depends_on,
            lifecycle=lifecycle,
            provider=provider,
        )

        jsii.create(StorageTableEntity, self, [scope, id, config])

    @jsii.member(jsii_name="synthesizeAttributes")
    def _synthesize_attributes(self) -> typing.Mapping[builtins.str, typing.Any]:
        return jsii.invoke(self, "synthesizeAttributes", [])

    @builtins.property # type: ignore
    @jsii.member(jsii_name="entity")
    def entity(self) -> typing.Mapping[builtins.str, builtins.str]:
        return jsii.get(self, "entity")

    @entity.setter # type: ignore
    def entity(self, value: typing.Mapping[builtins.str, builtins.str]) -> None:
        jsii.set(self, "entity", value)

    @builtins.property # type: ignore
    @jsii.member(jsii_name="partitionKey")
    def partition_key(self) -> builtins.str:
        return jsii.get(self, "partitionKey")

    @partition_key.setter # type: ignore
    def partition_key(self, value: builtins.str) -> None:
        jsii.set(self, "partitionKey", value)

    @builtins.property # type: ignore
    @jsii.member(jsii_name="rowKey")
    def row_key(self) -> builtins.str:
        return jsii.get(self, "rowKey")

    @row_key.setter # type: ignore
    def row_key(self, value: builtins.str) -> None:
        jsii.set(self, "rowKey", value)

    @builtins.property # type: ignore
    @jsii.member(jsii_name="storageAccountName")
    def storage_account_name(self) -> builtins.str:
        return jsii.get(self, "storageAccountName")

    @storage_account_name.setter # type: ignore
    def storage_account_name(self, value: builtins.str) -> None:
        jsii.set(self, "storageAccountName", value)

    @builtins.property # type: ignore
    @jsii.member(jsii_name="tableName")
    def table_name(self) -> builtins.str:
        return jsii.get(self, "tableName")

    @table_name.setter # type: ignore
    def table_name(self, value: builtins.str) -> None:
        jsii.set(self, "tableName", value)

    @builtins.property # type: ignore
    @jsii.member(jsii_name="id")
    def id(self) -> typing.Optional[builtins.str]:
        return jsii.get(self, "id")

    @id.setter # type: ignore
    def id(self, value: typing.Optional[builtins.str]) -> None:
        jsii.set(self, "id", value)

    @builtins.property # type: ignore
    @jsii.member(jsii_name="timeouts")
    def timeouts(self) -> typing.Optional["StorageTableEntityTimeouts"]:
        return jsii.get(self, "timeouts")

    @timeouts.setter # type: ignore
    def timeouts(self, value: typing.Optional["StorageTableEntityTimeouts"]) -> None:
        jsii.set(self, "timeouts", value)


@jsii.data_type(
    jsii_type="@cdktf/provider-azurerm.StorageTableEntityConfig",
    jsii_struct_bases=[cdktf.TerraformMetaArguments],
    name_mapping={
        "count": "count",
        "depends_on": "dependsOn",
        "lifecycle": "lifecycle",
        "provider": "provider",
        "entity": "entity",
        "partition_key": "partitionKey",
        "row_key": "rowKey",
        "storage_account_name": "storageAccountName",
        "table_name": "tableName",
        "timeouts": "timeouts",
    },
)
class StorageTableEntityConfig(cdktf.TerraformMetaArguments):
    def __init__(
        self,
        *,
        count: typing.Optional[jsii.Number] = None,
        depends_on: typing.Optional[typing.List[cdktf.TerraformResource]] = None,
        lifecycle: typing.Optional[cdktf.TerraformResourceLifecycle] = None,
        provider: typing.Optional[cdktf.TerraformProvider] = None,
        entity: typing.Mapping[builtins.str, builtins.str],
        partition_key: builtins.str,
        row_key: builtins.str,
        storage_account_name: builtins.str,
        table_name: builtins.str,
        timeouts: typing.Optional["StorageTableEntityTimeouts"] = None,
    ) -> None:
        """
        :param count: 
        :param depends_on: 
        :param lifecycle: 
        :param provider: 
        :param entity: 
        :param partition_key: 
        :param row_key: 
        :param storage_account_name: 
        :param table_name: 
        :param timeouts: timeouts block.
        """
        if isinstance(lifecycle, dict):
            lifecycle = cdktf.TerraformResourceLifecycle(**lifecycle)
        if isinstance(timeouts, dict):
            timeouts = StorageTableEntityTimeouts(**timeouts)
        self._values: typing.Dict[str, typing.Any] = {
            "entity": entity,
            "partition_key": partition_key,
            "row_key": row_key,
            "storage_account_name": storage_account_name,
            "table_name": table_name,
        }
        if count is not None:
            self._values["count"] = count
        if depends_on is not None:
            self._values["depends_on"] = depends_on
        if lifecycle is not None:
            self._values["lifecycle"] = lifecycle
        if provider is not None:
            self._values["provider"] = provider
        if timeouts is not None:
            self._values["timeouts"] = timeouts

    @builtins.property
    def count(self) -> typing.Optional[jsii.Number]:
        """
        :stability: experimental
        """
        result = self._values.get("count")
        return result

    @builtins.property
    def depends_on(self) -> typing.Optional[typing.List[cdktf.TerraformResource]]:
        """
        :stability: experimental
        """
        result = self._values.get("depends_on")
        return result

    @builtins.property
    def lifecycle(self) -> typing.Optional[cdktf.TerraformResourceLifecycle]:
        """
        :stability: experimental
        """
        result = self._values.get("lifecycle")
        return result

    @builtins.property
    def provider(self) -> typing.Optional[cdktf.TerraformProvider]:
        """
        :stability: experimental
        """
        result = self._values.get("provider")
        return result

    @builtins.property
    def entity(self) -> typing.Mapping[builtins.str, builtins.str]:
        result = self._values.get("entity")
        assert result is not None, "Required property 'entity' is missing"
        return result

    @builtins.property
    def partition_key(self) -> builtins.str:
        result = self._values.get("partition_key")
        assert result is not None, "Required property 'partition_key' is missing"
        return result

    @builtins.property
    def row_key(self) -> builtins.str:
        result = self._values.get("row_key")
        assert result is not None, "Required property 'row_key' is missing"
        return result

    @builtins.property
    def storage_account_name(self) -> builtins.str:
        result = self._values.get("storage_account_name")
        assert result is not None, "Required property 'storage_account_name' is missing"
        return result

    @builtins.property
    def table_name(self) -> builtins.str:
        result = self._values.get("table_name")
        assert result is not None, "Required property 'table_name' is missing"
        return result

    @builtins.property
    def timeouts(self) -> typing.Optional["StorageTableEntityTimeouts"]:
        """timeouts block."""
        result = self._values.get("timeouts")
        return result

    def __eq__(self, rhs: typing.Any) -> builtins.bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs: typing.Any) -> builtins.bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return "StorageTableEntityConfig(%s)" % ", ".join(
            k + "=" + repr(v) for k, v in self._values.items()
        )


@jsii.data_type(
    jsii_type="@cdktf/provider-azurerm.StorageTableEntityTimeouts",
    jsii_struct_bases=[],
    name_mapping={
        "create": "create",
        "delete": "delete",
        "read": "read",
        "update": "update",
    },
)
class StorageTableEntityTimeouts:
    def __init__(
        self,
        *,
        create: typing.Optional[builtins.str] = None,
        delete: typing.Optional[builtins.str] = None,
        read: typing.Optional[builtins.str] = None,
        update: typing.Optional[builtins.str] = None,
    ) -> None:
        """
        :param create: 
        :param delete: 
        :param read: 
        :param update: 
        """
        self._values: typing.Dict[str, typing.Any] = {}
        if create is not None:
            self._values["create"] = create
        if delete is not None:
            self._values["delete"] = delete
        if read is not None:
            self._values["read"] = read
        if update is not None:
            self._values["update"] = update

    @builtins.property
    def create(self) -> typing.Optional[builtins.str]:
        result = self._values.get("create")
        return result

    @builtins.property
    def delete(self) -> typing.Optional[builtins.str]:
        result = self._values.get("delete")
        return result

    @builtins.property
    def read(self) -> typing.Optional[builtins.str]:
        result = self._values.get("read")
        return result

    @builtins.property
    def update(self) -> typing.Optional[builtins.str]:
        result = self._values.get("update")
        return result

    def __eq__(self, rhs: typing.Any) -> builtins.bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs: typing.Any) -> builtins.bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return "StorageTableEntityTimeouts(%s)" % ", ".join(
            k + "=" + repr(v) for k, v in self._values.items()
        )


@jsii.data_type(
    jsii_type="@cdktf/provider-azurerm.StorageTableTimeouts",
    jsii_struct_bases=[],
    name_mapping={
        "create": "create",
        "delete": "delete",
        "read": "read",
        "update": "update",
    },
)
class StorageTableTimeouts:
    def __init__(
        self,
        *,
        create: typing.Optional[builtins.str] = None,
        delete: typing.Optional[builtins.str] = None,
        read: typing.Optional[builtins.str] = None,
        update: typing.Optional[builtins.str] = None,
    ) -> None:
        """
        :param create: 
        :param delete: 
        :param read: 
        :param update: 
        """
        self._values: typing.Dict[str, typing.Any] = {}
        if create is not None:
            self._values["create"] = create
        if delete is not None:
            self._values["delete"] = delete
        if read is not None:
            self._values["read"] = read
        if update is not None:
            self._values["update"] = update

    @builtins.property
    def create(self) -> typing.Optional[builtins.str]:
        result = self._values.get("create")
        return result

    @builtins.property
    def delete(self) -> typing.Optional[builtins.str]:
        result = self._values.get("delete")
        return result

    @builtins.property
    def read(self) -> typing.Optional[builtins.str]:
        result = self._values.get("read")
        return result

    @builtins.property
    def update(self) -> typing.Optional[builtins.str]:
        result = self._values.get("update")
        return result

    def __eq__(self, rhs: typing.Any) -> builtins.bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs: typing.Any) -> builtins.bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return "StorageTableTimeouts(%s)" % ", ".join(
            k + "=" + repr(v) for k, v in self._values.items()
        )


class StreamAnalyticsFunctionJavascriptUdf(
    cdktf.TerraformResource,
    metaclass=jsii.JSIIMeta,
    jsii_type="@cdktf/provider-azurerm.StreamAnalyticsFunctionJavascriptUdf",
):
    def __init__(
        self,
        scope: constructs.Construct,
        id: builtins.str,
        *,
        input: typing.List["StreamAnalyticsFunctionJavascriptUdfInput"],
        name: builtins.str,
        output: typing.List["StreamAnalyticsFunctionJavascriptUdfOutput"],
        resource_group_name: builtins.str,
        script: builtins.str,
        stream_analytics_job_name: builtins.str,
        timeouts: typing.Optional["StreamAnalyticsFunctionJavascriptUdfTimeouts"] = None,
        count: typing.Optional[jsii.Number] = None,
        depends_on: typing.Optional[typing.List[cdktf.TerraformResource]] = None,
        lifecycle: typing.Optional[cdktf.TerraformResourceLifecycle] = None,
        provider: typing.Optional[cdktf.TerraformProvider] = None,
    ) -> None:
        """
        :param scope: -
        :param id: -
        :param input: input block.
        :param name: 
        :param output: output block.
        :param resource_group_name: 
        :param script: 
        :param stream_analytics_job_name: 
        :param timeouts: timeouts block.
        :param count: 
        :param depends_on: 
        :param lifecycle: 
        :param provider: 
        """
        config = StreamAnalyticsFunctionJavascriptUdfConfig(
            input=input,
            name=name,
            output=output,
            resource_group_name=resource_group_name,
            script=script,
            stream_analytics_job_name=stream_analytics_job_name,
            timeouts=timeouts,
            count=count,
            depends_on=depends_on,
            lifecycle=lifecycle,
            provider=provider,
        )

        jsii.create(StreamAnalyticsFunctionJavascriptUdf, self, [scope, id, config])

    @jsii.member(jsii_name="synthesizeAttributes")
    def _synthesize_attributes(self) -> typing.Mapping[builtins.str, typing.Any]:
        return jsii.invoke(self, "synthesizeAttributes", [])

    @builtins.property # type: ignore
    @jsii.member(jsii_name="input")
    def input(self) -> typing.List["StreamAnalyticsFunctionJavascriptUdfInput"]:
        return jsii.get(self, "input")

    @input.setter # type: ignore
    def input(
        self,
        value: typing.List["StreamAnalyticsFunctionJavascriptUdfInput"],
    ) -> None:
        jsii.set(self, "input", value)

    @builtins.property # type: ignore
    @jsii.member(jsii_name="name")
    def name(self) -> builtins.str:
        return jsii.get(self, "name")

    @name.setter # type: ignore
    def name(self, value: builtins.str) -> None:
        jsii.set(self, "name", value)

    @builtins.property # type: ignore
    @jsii.member(jsii_name="output")
    def output(self) -> typing.List["StreamAnalyticsFunctionJavascriptUdfOutput"]:
        return jsii.get(self, "output")

    @output.setter # type: ignore
    def output(
        self,
        value: typing.List["StreamAnalyticsFunctionJavascriptUdfOutput"],
    ) -> None:
        jsii.set(self, "output", value)

    @builtins.property # type: ignore
    @jsii.member(jsii_name="resourceGroupName")
    def resource_group_name(self) -> builtins.str:
        return jsii.get(self, "resourceGroupName")

    @resource_group_name.setter # type: ignore
    def resource_group_name(self, value: builtins.str) -> None:
        jsii.set(self, "resourceGroupName", value)

    @builtins.property # type: ignore
    @jsii.member(jsii_name="script")
    def script(self) -> builtins.str:
        return jsii.get(self, "script")

    @script.setter # type: ignore
    def script(self, value: builtins.str) -> None:
        jsii.set(self, "script", value)

    @builtins.property # type: ignore
    @jsii.member(jsii_name="streamAnalyticsJobName")
    def stream_analytics_job_name(self) -> builtins.str:
        return jsii.get(self, "streamAnalyticsJobName")

    @stream_analytics_job_name.setter # type: ignore
    def stream_analytics_job_name(self, value: builtins.str) -> None:
        jsii.set(self, "streamAnalyticsJobName", value)

    @builtins.property # type: ignore
    @jsii.member(jsii_name="id")
    def id(self) -> typing.Optional[builtins.str]:
        return jsii.get(self, "id")

    @id.setter # type: ignore
    def id(self, value: typing.Optional[builtins.str]) -> None:
        jsii.set(self, "id", value)

    @builtins.property # type: ignore
    @jsii.member(jsii_name="timeouts")
    def timeouts(
        self,
    ) -> typing.Optional["StreamAnalyticsFunctionJavascriptUdfTimeouts"]:
        return jsii.get(self, "timeouts")

    @timeouts.setter # type: ignore
    def timeouts(
        self,
        value: typing.Optional["StreamAnalyticsFunctionJavascriptUdfTimeouts"],
    ) -> None:
        jsii.set(self, "timeouts", value)


@jsii.data_type(
    jsii_type="@cdktf/provider-azurerm.StreamAnalyticsFunctionJavascriptUdfConfig",
    jsii_struct_bases=[cdktf.TerraformMetaArguments],
    name_mapping={
        "count": "count",
        "depends_on": "dependsOn",
        "lifecycle": "lifecycle",
        "provider": "provider",
        "input": "input",
        "name": "name",
        "output": "output",
        "resource_group_name": "resourceGroupName",
        "script": "script",
        "stream_analytics_job_name": "streamAnalyticsJobName",
        "timeouts": "timeouts",
    },
)
class StreamAnalyticsFunctionJavascriptUdfConfig(cdktf.TerraformMetaArguments):
    def __init__(
        self,
        *,
        count: typing.Optional[jsii.Number] = None,
        depends_on: typing.Optional[typing.List[cdktf.TerraformResource]] = None,
        lifecycle: typing.Optional[cdktf.TerraformResourceLifecycle] = None,
        provider: typing.Optional[cdktf.TerraformProvider] = None,
        input: typing.List["StreamAnalyticsFunctionJavascriptUdfInput"],
        name: builtins.str,
        output: typing.List["StreamAnalyticsFunctionJavascriptUdfOutput"],
        resource_group_name: builtins.str,
        script: builtins.str,
        stream_analytics_job_name: builtins.str,
        timeouts: typing.Optional["StreamAnalyticsFunctionJavascriptUdfTimeouts"] = None,
    ) -> None:
        """
        :param count: 
        :param depends_on: 
        :param lifecycle: 
        :param provider: 
        :param input: input block.
        :param name: 
        :param output: output block.
        :param resource_group_name: 
        :param script: 
        :param stream_analytics_job_name: 
        :param timeouts: timeouts block.
        """
        if isinstance(lifecycle, dict):
            lifecycle = cdktf.TerraformResourceLifecycle(**lifecycle)
        if isinstance(timeouts, dict):
            timeouts = StreamAnalyticsFunctionJavascriptUdfTimeouts(**timeouts)
        self._values: typing.Dict[str, typing.Any] = {
            "input": input,
            "name": name,
            "output": output,
            "resource_group_name": resource_group_name,
            "script": script,
            "stream_analytics_job_name": stream_analytics_job_name,
        }
        if count is not None:
            self._values["count"] = count
        if depends_on is not None:
            self._values["depends_on"] = depends_on
        if lifecycle is not None:
            self._values["lifecycle"] = lifecycle
        if provider is not None:
            self._values["provider"] = provider
        if timeouts is not None:
            self._values["timeouts"] = timeouts

    @builtins.property
    def count(self) -> typing.Optional[jsii.Number]:
        """
        :stability: experimental
        """
        result = self._values.get("count")
        return result

    @builtins.property
    def depends_on(self) -> typing.Optional[typing.List[cdktf.TerraformResource]]:
        """
        :stability: experimental
        """
        result = self._values.get("depends_on")
        return result

    @builtins.property
    def lifecycle(self) -> typing.Optional[cdktf.TerraformResourceLifecycle]:
        """
        :stability: experimental
        """
        result = self._values.get("lifecycle")
        return result

    @builtins.property
    def provider(self) -> typing.Optional[cdktf.TerraformProvider]:
        """
        :stability: experimental
        """
        result = self._values.get("provider")
        return result

    @builtins.property
    def input(self) -> typing.List["StreamAnalyticsFunctionJavascriptUdfInput"]:
        """input block."""
        result = self._values.get("input")
        assert result is not None, "Required property 'input' is missing"
        return result

    @builtins.property
    def name(self) -> builtins.str:
        result = self._values.get("name")
        assert result is not None, "Required property 'name' is missing"
        return result

    @builtins.property
    def output(self) -> typing.List["StreamAnalyticsFunctionJavascriptUdfOutput"]:
        """output block."""
        result = self._values.get("output")
        assert result is not None, "Required property 'output' is missing"
        return result

    @builtins.property
    def resource_group_name(self) -> builtins.str:
        result = self._values.get("resource_group_name")
        assert result is not None, "Required property 'resource_group_name' is missing"
        return result

    @builtins.property
    def script(self) -> builtins.str:
        result = self._values.get("script")
        assert result is not None, "Required property 'script' is missing"
        return result

    @builtins.property
    def stream_analytics_job_name(self) -> builtins.str:
        result = self._values.get("stream_analytics_job_name")
        assert result is not None, "Required property 'stream_analytics_job_name' is missing"
        return result

    @builtins.property
    def timeouts(
        self,
    ) -> typing.Optional["StreamAnalyticsFunctionJavascriptUdfTimeouts"]:
        """timeouts block."""
        result = self._values.get("timeouts")
        return result

    def __eq__(self, rhs: typing.Any) -> builtins.bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs: typing.Any) -> builtins.bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return "StreamAnalyticsFunctionJavascriptUdfConfig(%s)" % ", ".join(
            k + "=" + repr(v) for k, v in self._values.items()
        )


@jsii.data_type(
    jsii_type="@cdktf/provider-azurerm.StreamAnalyticsFunctionJavascriptUdfInput",
    jsii_struct_bases=[],
    name_mapping={"type": "type"},
)
class StreamAnalyticsFunctionJavascriptUdfInput:
    def __init__(self, *, type: builtins.str) -> None:
        """
        :param type: 
        """
        self._values: typing.Dict[str, typing.Any] = {
            "type": type,
        }

    @builtins.property
    def type(self) -> builtins.str:
        result = self._values.get("type")
        assert result is not None, "Required property 'type' is missing"
        return result

    def __eq__(self, rhs: typing.Any) -> builtins.bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs: typing.Any) -> builtins.bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return "StreamAnalyticsFunctionJavascriptUdfInput(%s)" % ", ".join(
            k + "=" + repr(v) for k, v in self._values.items()
        )


@jsii.data_type(
    jsii_type="@cdktf/provider-azurerm.StreamAnalyticsFunctionJavascriptUdfOutput",
    jsii_struct_bases=[],
    name_mapping={"type": "type"},
)
class StreamAnalyticsFunctionJavascriptUdfOutput:
    def __init__(self, *, type: builtins.str) -> None:
        """
        :param type: 
        """
        self._values: typing.Dict[str, typing.Any] = {
            "type": type,
        }

    @builtins.property
    def type(self) -> builtins.str:
        result = self._values.get("type")
        assert result is not None, "Required property 'type' is missing"
        return result

    def __eq__(self, rhs: typing.Any) -> builtins.bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs: typing.Any) -> builtins.bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return "StreamAnalyticsFunctionJavascriptUdfOutput(%s)" % ", ".join(
            k + "=" + repr(v) for k, v in self._values.items()
        )


@jsii.data_type(
    jsii_type="@cdktf/provider-azurerm.StreamAnalyticsFunctionJavascriptUdfTimeouts",
    jsii_struct_bases=[],
    name_mapping={
        "create": "create",
        "delete": "delete",
        "read": "read",
        "update": "update",
    },
)
class StreamAnalyticsFunctionJavascriptUdfTimeouts:
    def __init__(
        self,
        *,
        create: typing.Optional[builtins.str] = None,
        delete: typing.Optional[builtins.str] = None,
        read: typing.Optional[builtins.str] = None,
        update: typing.Optional[builtins.str] = None,
    ) -> None:
        """
        :param create: 
        :param delete: 
        :param read: 
        :param update: 
        """
        self._values: typing.Dict[str, typing.Any] = {}
        if create is not None:
            self._values["create"] = create
        if delete is not None:
            self._values["delete"] = delete
        if read is not None:
            self._values["read"] = read
        if update is not None:
            self._values["update"] = update

    @builtins.property
    def create(self) -> typing.Optional[builtins.str]:
        result = self._values.get("create")
        return result

    @builtins.property
    def delete(self) -> typing.Optional[builtins.str]:
        result = self._values.get("delete")
        return result

    @builtins.property
    def read(self) -> typing.Optional[builtins.str]:
        result = self._values.get("read")
        return result

    @builtins.property
    def update(self) -> typing.Optional[builtins.str]:
        result = self._values.get("update")
        return result

    def __eq__(self, rhs: typing.Any) -> builtins.bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs: typing.Any) -> builtins.bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return "StreamAnalyticsFunctionJavascriptUdfTimeouts(%s)" % ", ".join(
            k + "=" + repr(v) for k, v in self._values.items()
        )


class StreamAnalyticsJob(
    cdktf.TerraformResource,
    metaclass=jsii.JSIIMeta,
    jsii_type="@cdktf/provider-azurerm.StreamAnalyticsJob",
):
    def __init__(
        self,
        scope: constructs.Construct,
        id: builtins.str,
        *,
        location: builtins.str,
        name: builtins.str,
        resource_group_name: builtins.str,
        streaming_units: jsii.Number,
        transformation_query: builtins.str,
        compatibility_level: typing.Optional[builtins.str] = None,
        data_locale: typing.Optional[builtins.str] = None,
        events_late_arrival_max_delay_in_seconds: typing.Optional[jsii.Number] = None,
        events_out_of_order_max_delay_in_seconds: typing.Optional[jsii.Number] = None,
        events_out_of_order_policy: typing.Optional[builtins.str] = None,
        output_error_policy: typing.Optional[builtins.str] = None,
        tags: typing.Optional[typing.Mapping[builtins.str, builtins.str]] = None,
        timeouts: typing.Optional["StreamAnalyticsJobTimeouts"] = None,
        count: typing.Optional[jsii.Number] = None,
        depends_on: typing.Optional[typing.List[cdktf.TerraformResource]] = None,
        lifecycle: typing.Optional[cdktf.TerraformResourceLifecycle] = None,
        provider: typing.Optional[cdktf.TerraformProvider] = None,
    ) -> None:
        """
        :param scope: -
        :param id: -
        :param location: 
        :param name: 
        :param resource_group_name: 
        :param streaming_units: 
        :param transformation_query: 
        :param compatibility_level: 
        :param data_locale: 
        :param events_late_arrival_max_delay_in_seconds: 
        :param events_out_of_order_max_delay_in_seconds: 
        :param events_out_of_order_policy: 
        :param output_error_policy: 
        :param tags: 
        :param timeouts: timeouts block.
        :param count: 
        :param depends_on: 
        :param lifecycle: 
        :param provider: 
        """
        config = StreamAnalyticsJobConfig(
            location=location,
            name=name,
            resource_group_name=resource_group_name,
            streaming_units=streaming_units,
            transformation_query=transformation_query,
            compatibility_level=compatibility_level,
            data_locale=data_locale,
            events_late_arrival_max_delay_in_seconds=events_late_arrival_max_delay_in_seconds,
            events_out_of_order_max_delay_in_seconds=events_out_of_order_max_delay_in_seconds,
            events_out_of_order_policy=events_out_of_order_policy,
            output_error_policy=output_error_policy,
            tags=tags,
            timeouts=timeouts,
            count=count,
            depends_on=depends_on,
            lifecycle=lifecycle,
            provider=provider,
        )

        jsii.create(StreamAnalyticsJob, self, [scope, id, config])

    @jsii.member(jsii_name="synthesizeAttributes")
    def _synthesize_attributes(self) -> typing.Mapping[builtins.str, typing.Any]:
        return jsii.invoke(self, "synthesizeAttributes", [])

    @builtins.property # type: ignore
    @jsii.member(jsii_name="jobId")
    def job_id(self) -> builtins.str:
        return jsii.get(self, "jobId")

    @builtins.property # type: ignore
    @jsii.member(jsii_name="location")
    def location(self) -> builtins.str:
        return jsii.get(self, "location")

    @location.setter # type: ignore
    def location(self, value: builtins.str) -> None:
        jsii.set(self, "location", value)

    @builtins.property # type: ignore
    @jsii.member(jsii_name="name")
    def name(self) -> builtins.str:
        return jsii.get(self, "name")

    @name.setter # type: ignore
    def name(self, value: builtins.str) -> None:
        jsii.set(self, "name", value)

    @builtins.property # type: ignore
    @jsii.member(jsii_name="resourceGroupName")
    def resource_group_name(self) -> builtins.str:
        return jsii.get(self, "resourceGroupName")

    @resource_group_name.setter # type: ignore
    def resource_group_name(self, value: builtins.str) -> None:
        jsii.set(self, "resourceGroupName", value)

    @builtins.property # type: ignore
    @jsii.member(jsii_name="streamingUnits")
    def streaming_units(self) -> jsii.Number:
        return jsii.get(self, "streamingUnits")

    @streaming_units.setter # type: ignore
    def streaming_units(self, value: jsii.Number) -> None:
        jsii.set(self, "streamingUnits", value)

    @builtins.property # type: ignore
    @jsii.member(jsii_name="transformationQuery")
    def transformation_query(self) -> builtins.str:
        return jsii.get(self, "transformationQuery")

    @transformation_query.setter # type: ignore
    def transformation_query(self, value: builtins.str) -> None:
        jsii.set(self, "transformationQuery", value)

    @builtins.property # type: ignore
    @jsii.member(jsii_name="compatibilityLevel")
    def compatibility_level(self) -> typing.Optional[builtins.str]:
        return jsii.get(self, "compatibilityLevel")

    @compatibility_level.setter # type: ignore
    def compatibility_level(self, value: typing.Optional[builtins.str]) -> None:
        jsii.set(self, "compatibilityLevel", value)

    @builtins.property # type: ignore
    @jsii.member(jsii_name="dataLocale")
    def data_locale(self) -> typing.Optional[builtins.str]:
        return jsii.get(self, "dataLocale")

    @data_locale.setter # type: ignore
    def data_locale(self, value: typing.Optional[builtins.str]) -> None:
        jsii.set(self, "dataLocale", value)

    @builtins.property # type: ignore
    @jsii.member(jsii_name="eventsLateArrivalMaxDelayInSeconds")
    def events_late_arrival_max_delay_in_seconds(self) -> typing.Optional[jsii.Number]:
        return jsii.get(self, "eventsLateArrivalMaxDelayInSeconds")

    @events_late_arrival_max_delay_in_seconds.setter # type: ignore
    def events_late_arrival_max_delay_in_seconds(
        self,
        value: typing.Optional[jsii.Number],
    ) -> None:
        jsii.set(self, "eventsLateArrivalMaxDelayInSeconds", value)

    @builtins.property # type: ignore
    @jsii.member(jsii_name="eventsOutOfOrderMaxDelayInSeconds")
    def events_out_of_order_max_delay_in_seconds(self) -> typing.Optional[jsii.Number]:
        return jsii.get(self, "eventsOutOfOrderMaxDelayInSeconds")

    @events_out_of_order_max_delay_in_seconds.setter # type: ignore
    def events_out_of_order_max_delay_in_seconds(
        self,
        value: typing.Optional[jsii.Number],
    ) -> None:
        jsii.set(self, "eventsOutOfOrderMaxDelayInSeconds", value)

    @builtins.property # type: ignore
    @jsii.member(jsii_name="eventsOutOfOrderPolicy")
    def events_out_of_order_policy(self) -> typing.Optional[builtins.str]:
        return jsii.get(self, "eventsOutOfOrderPolicy")

    @events_out_of_order_policy.setter # type: ignore
    def events_out_of_order_policy(self, value: typing.Optional[builtins.str]) -> None:
        jsii.set(self, "eventsOutOfOrderPolicy", value)

    @builtins.property # type: ignore
    @jsii.member(jsii_name="id")
    def id(self) -> typing.Optional[builtins.str]:
        return jsii.get(self, "id")

    @id.setter # type: ignore
    def id(self, value: typing.Optional[builtins.str]) -> None:
        jsii.set(self, "id", value)

    @builtins.property # type: ignore
    @jsii.member(jsii_name="outputErrorPolicy")
    def output_error_policy(self) -> typing.Optional[builtins.str]:
        return jsii.get(self, "outputErrorPolicy")

    @output_error_policy.setter # type: ignore
    def output_error_policy(self, value: typing.Optional[builtins.str]) -> None:
        jsii.set(self, "outputErrorPolicy", value)

    @builtins.property # type: ignore
    @jsii.member(jsii_name="tags")
    def tags(self) -> typing.Optional[typing.Mapping[builtins.str, builtins.str]]:
        return jsii.get(self, "tags")

    @tags.setter # type: ignore
    def tags(
        self,
        value: typing.Optional[typing.Mapping[builtins.str, builtins.str]],
    ) -> None:
        jsii.set(self, "tags", value)

    @builtins.property # type: ignore
    @jsii.member(jsii_name="timeouts")
    def timeouts(self) -> typing.Optional["StreamAnalyticsJobTimeouts"]:
        return jsii.get(self, "timeouts")

    @timeouts.setter # type: ignore
    def timeouts(self, value: typing.Optional["StreamAnalyticsJobTimeouts"]) -> None:
        jsii.set(self, "timeouts", value)


@jsii.data_type(
    jsii_type="@cdktf/provider-azurerm.StreamAnalyticsJobConfig",
    jsii_struct_bases=[cdktf.TerraformMetaArguments],
    name_mapping={
        "count": "count",
        "depends_on": "dependsOn",
        "lifecycle": "lifecycle",
        "provider": "provider",
        "location": "location",
        "name": "name",
        "resource_group_name": "resourceGroupName",
        "streaming_units": "streamingUnits",
        "transformation_query": "transformationQuery",
        "compatibility_level": "compatibilityLevel",
        "data_locale": "dataLocale",
        "events_late_arrival_max_delay_in_seconds": "eventsLateArrivalMaxDelayInSeconds",
        "events_out_of_order_max_delay_in_seconds": "eventsOutOfOrderMaxDelayInSeconds",
        "events_out_of_order_policy": "eventsOutOfOrderPolicy",
        "output_error_policy": "outputErrorPolicy",
        "tags": "tags",
        "timeouts": "timeouts",
    },
)
class StreamAnalyticsJobConfig(cdktf.TerraformMetaArguments):
    def __init__(
        self,
        *,
        count: typing.Optional[jsii.Number] = None,
        depends_on: typing.Optional[typing.List[cdktf.TerraformResource]] = None,
        lifecycle: typing.Optional[cdktf.TerraformResourceLifecycle] = None,
        provider: typing.Optional[cdktf.TerraformProvider] = None,
        location: builtins.str,
        name: builtins.str,
        resource_group_name: builtins.str,
        streaming_units: jsii.Number,
        transformation_query: builtins.str,
        compatibility_level: typing.Optional[builtins.str] = None,
        data_locale: typing.Optional[builtins.str] = None,
        events_late_arrival_max_delay_in_seconds: typing.Optional[jsii.Number] = None,
        events_out_of_order_max_delay_in_seconds: typing.Optional[jsii.Number] = None,
        events_out_of_order_policy: typing.Optional[builtins.str] = None,
        output_error_policy: typing.Optional[builtins.str] = None,
        tags: typing.Optional[typing.Mapping[builtins.str, builtins.str]] = None,
        timeouts: typing.Optional["StreamAnalyticsJobTimeouts"] = None,
    ) -> None:
        """
        :param count: 
        :param depends_on: 
        :param lifecycle: 
        :param provider: 
        :param location: 
        :param name: 
        :param resource_group_name: 
        :param streaming_units: 
        :param transformation_query: 
        :param compatibility_level: 
        :param data_locale: 
        :param events_late_arrival_max_delay_in_seconds: 
        :param events_out_of_order_max_delay_in_seconds: 
        :param events_out_of_order_policy: 
        :param output_error_policy: 
        :param tags: 
        :param timeouts: timeouts block.
        """
        if isinstance(lifecycle, dict):
            lifecycle = cdktf.TerraformResourceLifecycle(**lifecycle)
        if isinstance(timeouts, dict):
            timeouts = StreamAnalyticsJobTimeouts(**timeouts)
        self._values: typing.Dict[str, typing.Any] = {
            "location": location,
            "name": name,
            "resource_group_name": resource_group_name,
            "streaming_units": streaming_units,
            "transformation_query": transformation_query,
        }
        if count is not None:
            self._values["count"] = count
        if depends_on is not None:
            self._values["depends_on"] = depends_on
        if lifecycle is not None:
            self._values["lifecycle"] = lifecycle
        if provider is not None:
            self._values["provider"] = provider
        if compatibility_level is not None:
            self._values["compatibility_level"] = compatibility_level
        if data_locale is not None:
            self._values["data_locale"] = data_locale
        if events_late_arrival_max_delay_in_seconds is not None:
            self._values["events_late_arrival_max_delay_in_seconds"] = events_late_arrival_max_delay_in_seconds
        if events_out_of_order_max_delay_in_seconds is not None:
            self._values["events_out_of_order_max_delay_in_seconds"] = events_out_of_order_max_delay_in_seconds
        if events_out_of_order_policy is not None:
            self._values["events_out_of_order_policy"] = events_out_of_order_policy
        if output_error_policy is not None:
            self._values["output_error_policy"] = output_error_policy
        if tags is not None:
            self._values["tags"] = tags
        if timeouts is not None:
            self._values["timeouts"] = timeouts

    @builtins.property
    def count(self) -> typing.Optional[jsii.Number]:
        """
        :stability: experimental
        """
        result = self._values.get("count")
        return result

    @builtins.property
    def depends_on(self) -> typing.Optional[typing.List[cdktf.TerraformResource]]:
        """
        :stability: experimental
        """
        result = self._values.get("depends_on")
        return result

    @builtins.property
    def lifecycle(self) -> typing.Optional[cdktf.TerraformResourceLifecycle]:
        """
        :stability: experimental
        """
        result = self._values.get("lifecycle")
        return result

    @builtins.property
    def provider(self) -> typing.Optional[cdktf.TerraformProvider]:
        """
        :stability: experimental
        """
        result = self._values.get("provider")
        return result

    @builtins.property
    def location(self) -> builtins.str:
        result = self._values.get("location")
        assert result is not None, "Required property 'location' is missing"
        return result

    @builtins.property
    def name(self) -> builtins.str:
        result = self._values.get("name")
        assert result is not None, "Required property 'name' is missing"
        return result

    @builtins.property
    def resource_group_name(self) -> builtins.str:
        result = self._values.get("resource_group_name")
        assert result is not None, "Required property 'resource_group_name' is missing"
        return result

    @builtins.property
    def streaming_units(self) -> jsii.Number:
        result = self._values.get("streaming_units")
        assert result is not None, "Required property 'streaming_units' is missing"
        return result

    @builtins.property
    def transformation_query(self) -> builtins.str:
        result = self._values.get("transformation_query")
        assert result is not None, "Required property 'transformation_query' is missing"
        return result

    @builtins.property
    def compatibility_level(self) -> typing.Optional[builtins.str]:
        result = self._values.get("compatibility_level")
        return result

    @builtins.property
    def data_locale(self) -> typing.Optional[builtins.str]:
        result = self._values.get("data_locale")
        return result

    @builtins.property
    def events_late_arrival_max_delay_in_seconds(self) -> typing.Optional[jsii.Number]:
        result = self._values.get("events_late_arrival_max_delay_in_seconds")
        return result

    @builtins.property
    def events_out_of_order_max_delay_in_seconds(self) -> typing.Optional[jsii.Number]:
        result = self._values.get("events_out_of_order_max_delay_in_seconds")
        return result

    @builtins.property
    def events_out_of_order_policy(self) -> typing.Optional[builtins.str]:
        result = self._values.get("events_out_of_order_policy")
        return result

    @builtins.property
    def output_error_policy(self) -> typing.Optional[builtins.str]:
        result = self._values.get("output_error_policy")
        return result

    @builtins.property
    def tags(self) -> typing.Optional[typing.Mapping[builtins.str, builtins.str]]:
        result = self._values.get("tags")
        return result

    @builtins.property
    def timeouts(self) -> typing.Optional["StreamAnalyticsJobTimeouts"]:
        """timeouts block."""
        result = self._values.get("timeouts")
        return result

    def __eq__(self, rhs: typing.Any) -> builtins.bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs: typing.Any) -> builtins.bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return "StreamAnalyticsJobConfig(%s)" % ", ".join(
            k + "=" + repr(v) for k, v in self._values.items()
        )


@jsii.data_type(
    jsii_type="@cdktf/provider-azurerm.StreamAnalyticsJobTimeouts",
    jsii_struct_bases=[],
    name_mapping={
        "create": "create",
        "delete": "delete",
        "read": "read",
        "update": "update",
    },
)
class StreamAnalyticsJobTimeouts:
    def __init__(
        self,
        *,
        create: typing.Optional[builtins.str] = None,
        delete: typing.Optional[builtins.str] = None,
        read: typing.Optional[builtins.str] = None,
        update: typing.Optional[builtins.str] = None,
    ) -> None:
        """
        :param create: 
        :param delete: 
        :param read: 
        :param update: 
        """
        self._values: typing.Dict[str, typing.Any] = {}
        if create is not None:
            self._values["create"] = create
        if delete is not None:
            self._values["delete"] = delete
        if read is not None:
            self._values["read"] = read
        if update is not None:
            self._values["update"] = update

    @builtins.property
    def create(self) -> typing.Optional[builtins.str]:
        result = self._values.get("create")
        return result

    @builtins.property
    def delete(self) -> typing.Optional[builtins.str]:
        result = self._values.get("delete")
        return result

    @builtins.property
    def read(self) -> typing.Optional[builtins.str]:
        result = self._values.get("read")
        return result

    @builtins.property
    def update(self) -> typing.Optional[builtins.str]:
        result = self._values.get("update")
        return result

    def __eq__(self, rhs: typing.Any) -> builtins.bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs: typing.Any) -> builtins.bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return "StreamAnalyticsJobTimeouts(%s)" % ", ".join(
            k + "=" + repr(v) for k, v in self._values.items()
        )


class StreamAnalyticsOutputBlob(
    cdktf.TerraformResource,
    metaclass=jsii.JSIIMeta,
    jsii_type="@cdktf/provider-azurerm.StreamAnalyticsOutputBlob",
):
    def __init__(
        self,
        scope: constructs.Construct,
        id: builtins.str,
        *,
        date_format: builtins.str,
        name: builtins.str,
        path_pattern: builtins.str,
        resource_group_name: builtins.str,
        serialization: typing.List["StreamAnalyticsOutputBlobSerialization"],
        storage_account_key: builtins.str,
        storage_account_name: builtins.str,
        storage_container_name: builtins.str,
        stream_analytics_job_name: builtins.str,
        time_format: builtins.str,
        timeouts: typing.Optional["StreamAnalyticsOutputBlobTimeouts"] = None,
        count: typing.Optional[jsii.Number] = None,
        depends_on: typing.Optional[typing.List[cdktf.TerraformResource]] = None,
        lifecycle: typing.Optional[cdktf.TerraformResourceLifecycle] = None,
        provider: typing.Optional[cdktf.TerraformProvider] = None,
    ) -> None:
        """
        :param scope: -
        :param id: -
        :param date_format: 
        :param name: 
        :param path_pattern: 
        :param resource_group_name: 
        :param serialization: serialization block.
        :param storage_account_key: 
        :param storage_account_name: 
        :param storage_container_name: 
        :param stream_analytics_job_name: 
        :param time_format: 
        :param timeouts: timeouts block.
        :param count: 
        :param depends_on: 
        :param lifecycle: 
        :param provider: 
        """
        config = StreamAnalyticsOutputBlobConfig(
            date_format=date_format,
            name=name,
            path_pattern=path_pattern,
            resource_group_name=resource_group_name,
            serialization=serialization,
            storage_account_key=storage_account_key,
            storage_account_name=storage_account_name,
            storage_container_name=storage_container_name,
            stream_analytics_job_name=stream_analytics_job_name,
            time_format=time_format,
            timeouts=timeouts,
            count=count,
            depends_on=depends_on,
            lifecycle=lifecycle,
            provider=provider,
        )

        jsii.create(StreamAnalyticsOutputBlob, self, [scope, id, config])

    @jsii.member(jsii_name="synthesizeAttributes")
    def _synthesize_attributes(self) -> typing.Mapping[builtins.str, typing.Any]:
        return jsii.invoke(self, "synthesizeAttributes", [])

    @builtins.property # type: ignore
    @jsii.member(jsii_name="dateFormat")
    def date_format(self) -> builtins.str:
        return jsii.get(self, "dateFormat")

    @date_format.setter # type: ignore
    def date_format(self, value: builtins.str) -> None:
        jsii.set(self, "dateFormat", value)

    @builtins.property # type: ignore
    @jsii.member(jsii_name="name")
    def name(self) -> builtins.str:
        return jsii.get(self, "name")

    @name.setter # type: ignore
    def name(self, value: builtins.str) -> None:
        jsii.set(self, "name", value)

    @builtins.property # type: ignore
    @jsii.member(jsii_name="pathPattern")
    def path_pattern(self) -> builtins.str:
        return jsii.get(self, "pathPattern")

    @path_pattern.setter # type: ignore
    def path_pattern(self, value: builtins.str) -> None:
        jsii.set(self, "pathPattern", value)

    @builtins.property # type: ignore
    @jsii.member(jsii_name="resourceGroupName")
    def resource_group_name(self) -> builtins.str:
        return jsii.get(self, "resourceGroupName")

    @resource_group_name.setter # type: ignore
    def resource_group_name(self, value: builtins.str) -> None:
        jsii.set(self, "resourceGroupName", value)

    @builtins.property # type: ignore
    @jsii.member(jsii_name="serialization")
    def serialization(self) -> typing.List["StreamAnalyticsOutputBlobSerialization"]:
        return jsii.get(self, "serialization")

    @serialization.setter # type: ignore
    def serialization(
        self,
        value: typing.List["StreamAnalyticsOutputBlobSerialization"],
    ) -> None:
        jsii.set(self, "serialization", value)

    @builtins.property # type: ignore
    @jsii.member(jsii_name="storageAccountKey")
    def storage_account_key(self) -> builtins.str:
        return jsii.get(self, "storageAccountKey")

    @storage_account_key.setter # type: ignore
    def storage_account_key(self, value: builtins.str) -> None:
        jsii.set(self, "storageAccountKey", value)

    @builtins.property # type: ignore
    @jsii.member(jsii_name="storageAccountName")
    def storage_account_name(self) -> builtins.str:
        return jsii.get(self, "storageAccountName")

    @storage_account_name.setter # type: ignore
    def storage_account_name(self, value: builtins.str) -> None:
        jsii.set(self, "storageAccountName", value)

    @builtins.property # type: ignore
    @jsii.member(jsii_name="storageContainerName")
    def storage_container_name(self) -> builtins.str:
        return jsii.get(self, "storageContainerName")

    @storage_container_name.setter # type: ignore
    def storage_container_name(self, value: builtins.str) -> None:
        jsii.set(self, "storageContainerName", value)

    @builtins.property # type: ignore
    @jsii.member(jsii_name="streamAnalyticsJobName")
    def stream_analytics_job_name(self) -> builtins.str:
        return jsii.get(self, "streamAnalyticsJobName")

    @stream_analytics_job_name.setter # type: ignore
    def stream_analytics_job_name(self, value: builtins.str) -> None:
        jsii.set(self, "streamAnalyticsJobName", value)

    @builtins.property # type: ignore
    @jsii.member(jsii_name="timeFormat")
    def time_format(self) -> builtins.str:
        return jsii.get(self, "timeFormat")

    @time_format.setter # type: ignore
    def time_format(self, value: builtins.str) -> None:
        jsii.set(self, "timeFormat", value)

    @builtins.property # type: ignore
    @jsii.member(jsii_name="id")
    def id(self) -> typing.Optional[builtins.str]:
        return jsii.get(self, "id")

    @id.setter # type: ignore
    def id(self, value: typing.Optional[builtins.str]) -> None:
        jsii.set(self, "id", value)

    @builtins.property # type: ignore
    @jsii.member(jsii_name="timeouts")
    def timeouts(self) -> typing.Optional["StreamAnalyticsOutputBlobTimeouts"]:
        return jsii.get(self, "timeouts")

    @timeouts.setter # type: ignore
    def timeouts(
        self,
        value: typing.Optional["StreamAnalyticsOutputBlobTimeouts"],
    ) -> None:
        jsii.set(self, "timeouts", value)


@jsii.data_type(
    jsii_type="@cdktf/provider-azurerm.StreamAnalyticsOutputBlobConfig",
    jsii_struct_bases=[cdktf.TerraformMetaArguments],
    name_mapping={
        "count": "count",
        "depends_on": "dependsOn",
        "lifecycle": "lifecycle",
        "provider": "provider",
        "date_format": "dateFormat",
        "name": "name",
        "path_pattern": "pathPattern",
        "resource_group_name": "resourceGroupName",
        "serialization": "serialization",
        "storage_account_key": "storageAccountKey",
        "storage_account_name": "storageAccountName",
        "storage_container_name": "storageContainerName",
        "stream_analytics_job_name": "streamAnalyticsJobName",
        "time_format": "timeFormat",
        "timeouts": "timeouts",
    },
)
class StreamAnalyticsOutputBlobConfig(cdktf.TerraformMetaArguments):
    def __init__(
        self,
        *,
        count: typing.Optional[jsii.Number] = None,
        depends_on: typing.Optional[typing.List[cdktf.TerraformResource]] = None,
        lifecycle: typing.Optional[cdktf.TerraformResourceLifecycle] = None,
        provider: typing.Optional[cdktf.TerraformProvider] = None,
        date_format: builtins.str,
        name: builtins.str,
        path_pattern: builtins.str,
        resource_group_name: builtins.str,
        serialization: typing.List["StreamAnalyticsOutputBlobSerialization"],
        storage_account_key: builtins.str,
        storage_account_name: builtins.str,
        storage_container_name: builtins.str,
        stream_analytics_job_name: builtins.str,
        time_format: builtins.str,
        timeouts: typing.Optional["StreamAnalyticsOutputBlobTimeouts"] = None,
    ) -> None:
        """
        :param count: 
        :param depends_on: 
        :param lifecycle: 
        :param provider: 
        :param date_format: 
        :param name: 
        :param path_pattern: 
        :param resource_group_name: 
        :param serialization: serialization block.
        :param storage_account_key: 
        :param storage_account_name: 
        :param storage_container_name: 
        :param stream_analytics_job_name: 
        :param time_format: 
        :param timeouts: timeouts block.
        """
        if isinstance(lifecycle, dict):
            lifecycle = cdktf.TerraformResourceLifecycle(**lifecycle)
        if isinstance(timeouts, dict):
            timeouts = StreamAnalyticsOutputBlobTimeouts(**timeouts)
        self._values: typing.Dict[str, typing.Any] = {
            "date_format": date_format,
            "name": name,
            "path_pattern": path_pattern,
            "resource_group_name": resource_group_name,
            "serialization": serialization,
            "storage_account_key": storage_account_key,
            "storage_account_name": storage_account_name,
            "storage_container_name": storage_container_name,
            "stream_analytics_job_name": stream_analytics_job_name,
            "time_format": time_format,
        }
        if count is not None:
            self._values["count"] = count
        if depends_on is not None:
            self._values["depends_on"] = depends_on
        if lifecycle is not None:
            self._values["lifecycle"] = lifecycle
        if provider is not None:
            self._values["provider"] = provider
        if timeouts is not None:
            self._values["timeouts"] = timeouts

    @builtins.property
    def count(self) -> typing.Optional[jsii.Number]:
        """
        :stability: experimental
        """
        result = self._values.get("count")
        return result

    @builtins.property
    def depends_on(self) -> typing.Optional[typing.List[cdktf.TerraformResource]]:
        """
        :stability: experimental
        """
        result = self._values.get("depends_on")
        return result

    @builtins.property
    def lifecycle(self) -> typing.Optional[cdktf.TerraformResourceLifecycle]:
        """
        :stability: experimental
        """
        result = self._values.get("lifecycle")
        return result

    @builtins.property
    def provider(self) -> typing.Optional[cdktf.TerraformProvider]:
        """
        :stability: experimental
        """
        result = self._values.get("provider")
        return result

    @builtins.property
    def date_format(self) -> builtins.str:
        result = self._values.get("date_format")
        assert result is not None, "Required property 'date_format' is missing"
        return result

    @builtins.property
    def name(self) -> builtins.str:
        result = self._values.get("name")
        assert result is not None, "Required property 'name' is missing"
        return result

    @builtins.property
    def path_pattern(self) -> builtins.str:
        result = self._values.get("path_pattern")
        assert result is not None, "Required property 'path_pattern' is missing"
        return result

    @builtins.property
    def resource_group_name(self) -> builtins.str:
        result = self._values.get("resource_group_name")
        assert result is not None, "Required property 'resource_group_name' is missing"
        return result

    @builtins.property
    def serialization(self) -> typing.List["StreamAnalyticsOutputBlobSerialization"]:
        """serialization block."""
        result = self._values.get("serialization")
        assert result is not None, "Required property 'serialization' is missing"
        return result

    @builtins.property
    def storage_account_key(self) -> builtins.str:
        result = self._values.get("storage_account_key")
        assert result is not None, "Required property 'storage_account_key' is missing"
        return result

    @builtins.property
    def storage_account_name(self) -> builtins.str:
        result = self._values.get("storage_account_name")
        assert result is not None, "Required property 'storage_account_name' is missing"
        return result

    @builtins.property
    def storage_container_name(self) -> builtins.str:
        result = self._values.get("storage_container_name")
        assert result is not None, "Required property 'storage_container_name' is missing"
        return result

    @builtins.property
    def stream_analytics_job_name(self) -> builtins.str:
        result = self._values.get("stream_analytics_job_name")
        assert result is not None, "Required property 'stream_analytics_job_name' is missing"
        return result

    @builtins.property
    def time_format(self) -> builtins.str:
        result = self._values.get("time_format")
        assert result is not None, "Required property 'time_format' is missing"
        return result

    @builtins.property
    def timeouts(self) -> typing.Optional["StreamAnalyticsOutputBlobTimeouts"]:
        """timeouts block."""
        result = self._values.get("timeouts")
        return result

    def __eq__(self, rhs: typing.Any) -> builtins.bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs: typing.Any) -> builtins.bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return "StreamAnalyticsOutputBlobConfig(%s)" % ", ".join(
            k + "=" + repr(v) for k, v in self._values.items()
        )


@jsii.data_type(
    jsii_type="@cdktf/provider-azurerm.StreamAnalyticsOutputBlobSerialization",
    jsii_struct_bases=[],
    name_mapping={
        "type": "type",
        "encoding": "encoding",
        "field_delimiter": "fieldDelimiter",
        "format": "format",
    },
)
class StreamAnalyticsOutputBlobSerialization:
    def __init__(
        self,
        *,
        type: builtins.str,
        encoding: typing.Optional[builtins.str] = None,
        field_delimiter: typing.Optional[builtins.str] = None,
        format: typing.Optional[builtins.str] = None,
    ) -> None:
        """
        :param type: 
        :param encoding: 
        :param field_delimiter: 
        :param format: 
        """
        self._values: typing.Dict[str, typing.Any] = {
            "type": type,
        }
        if encoding is not None:
            self._values["encoding"] = encoding
        if field_delimiter is not None:
            self._values["field_delimiter"] = field_delimiter
        if format is not None:
            self._values["format"] = format

    @builtins.property
    def type(self) -> builtins.str:
        result = self._values.get("type")
        assert result is not None, "Required property 'type' is missing"
        return result

    @builtins.property
    def encoding(self) -> typing.Optional[builtins.str]:
        result = self._values.get("encoding")
        return result

    @builtins.property
    def field_delimiter(self) -> typing.Optional[builtins.str]:
        result = self._values.get("field_delimiter")
        return result

    @builtins.property
    def format(self) -> typing.Optional[builtins.str]:
        result = self._values.get("format")
        return result

    def __eq__(self, rhs: typing.Any) -> builtins.bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs: typing.Any) -> builtins.bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return "StreamAnalyticsOutputBlobSerialization(%s)" % ", ".join(
            k + "=" + repr(v) for k, v in self._values.items()
        )


@jsii.data_type(
    jsii_type="@cdktf/provider-azurerm.StreamAnalyticsOutputBlobTimeouts",
    jsii_struct_bases=[],
    name_mapping={
        "create": "create",
        "delete": "delete",
        "read": "read",
        "update": "update",
    },
)
class StreamAnalyticsOutputBlobTimeouts:
    def __init__(
        self,
        *,
        create: typing.Optional[builtins.str] = None,
        delete: typing.Optional[builtins.str] = None,
        read: typing.Optional[builtins.str] = None,
        update: typing.Optional[builtins.str] = None,
    ) -> None:
        """
        :param create: 
        :param delete: 
        :param read: 
        :param update: 
        """
        self._values: typing.Dict[str, typing.Any] = {}
        if create is not None:
            self._values["create"] = create
        if delete is not None:
            self._values["delete"] = delete
        if read is not None:
            self._values["read"] = read
        if update is not None:
            self._values["update"] = update

    @builtins.property
    def create(self) -> typing.Optional[builtins.str]:
        result = self._values.get("create")
        return result

    @builtins.property
    def delete(self) -> typing.Optional[builtins.str]:
        result = self._values.get("delete")
        return result

    @builtins.property
    def read(self) -> typing.Optional[builtins.str]:
        result = self._values.get("read")
        return result

    @builtins.property
    def update(self) -> typing.Optional[builtins.str]:
        result = self._values.get("update")
        return result

    def __eq__(self, rhs: typing.Any) -> builtins.bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs: typing.Any) -> builtins.bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return "StreamAnalyticsOutputBlobTimeouts(%s)" % ", ".join(
            k + "=" + repr(v) for k, v in self._values.items()
        )


class StreamAnalyticsOutputEventhub(
    cdktf.TerraformResource,
    metaclass=jsii.JSIIMeta,
    jsii_type="@cdktf/provider-azurerm.StreamAnalyticsOutputEventhub",
):
    def __init__(
        self,
        scope: constructs.Construct,
        id: builtins.str,
        *,
        eventhub_name: builtins.str,
        name: builtins.str,
        resource_group_name: builtins.str,
        serialization: typing.List["StreamAnalyticsOutputEventhubSerialization"],
        servicebus_namespace: builtins.str,
        shared_access_policy_key: builtins.str,
        shared_access_policy_name: builtins.str,
        stream_analytics_job_name: builtins.str,
        timeouts: typing.Optional["StreamAnalyticsOutputEventhubTimeouts"] = None,
        count: typing.Optional[jsii.Number] = None,
        depends_on: typing.Optional[typing.List[cdktf.TerraformResource]] = None,
        lifecycle: typing.Optional[cdktf.TerraformResourceLifecycle] = None,
        provider: typing.Optional[cdktf.TerraformProvider] = None,
    ) -> None:
        """
        :param scope: -
        :param id: -
        :param eventhub_name: 
        :param name: 
        :param resource_group_name: 
        :param serialization: serialization block.
        :param servicebus_namespace: 
        :param shared_access_policy_key: 
        :param shared_access_policy_name: 
        :param stream_analytics_job_name: 
        :param timeouts: timeouts block.
        :param count: 
        :param depends_on: 
        :param lifecycle: 
        :param provider: 
        """
        config = StreamAnalyticsOutputEventhubConfig(
            eventhub_name=eventhub_name,
            name=name,
            resource_group_name=resource_group_name,
            serialization=serialization,
            servicebus_namespace=servicebus_namespace,
            shared_access_policy_key=shared_access_policy_key,
            shared_access_policy_name=shared_access_policy_name,
            stream_analytics_job_name=stream_analytics_job_name,
            timeouts=timeouts,
            count=count,
            depends_on=depends_on,
            lifecycle=lifecycle,
            provider=provider,
        )

        jsii.create(StreamAnalyticsOutputEventhub, self, [scope, id, config])

    @jsii.member(jsii_name="synthesizeAttributes")
    def _synthesize_attributes(self) -> typing.Mapping[builtins.str, typing.Any]:
        return jsii.invoke(self, "synthesizeAttributes", [])

    @builtins.property # type: ignore
    @jsii.member(jsii_name="eventhubName")
    def eventhub_name(self) -> builtins.str:
        return jsii.get(self, "eventhubName")

    @eventhub_name.setter # type: ignore
    def eventhub_name(self, value: builtins.str) -> None:
        jsii.set(self, "eventhubName", value)

    @builtins.property # type: ignore
    @jsii.member(jsii_name="name")
    def name(self) -> builtins.str:
        return jsii.get(self, "name")

    @name.setter # type: ignore
    def name(self, value: builtins.str) -> None:
        jsii.set(self, "name", value)

    @builtins.property # type: ignore
    @jsii.member(jsii_name="resourceGroupName")
    def resource_group_name(self) -> builtins.str:
        return jsii.get(self, "resourceGroupName")

    @resource_group_name.setter # type: ignore
    def resource_group_name(self, value: builtins.str) -> None:
        jsii.set(self, "resourceGroupName", value)

    @builtins.property # type: ignore
    @jsii.member(jsii_name="serialization")
    def serialization(
        self,
    ) -> typing.List["StreamAnalyticsOutputEventhubSerialization"]:
        return jsii.get(self, "serialization")

    @serialization.setter # type: ignore
    def serialization(
        self,
        value: typing.List["StreamAnalyticsOutputEventhubSerialization"],
    ) -> None:
        jsii.set(self, "serialization", value)

    @builtins.property # type: ignore
    @jsii.member(jsii_name="servicebusNamespace")
    def servicebus_namespace(self) -> builtins.str:
        return jsii.get(self, "servicebusNamespace")

    @servicebus_namespace.setter # type: ignore
    def servicebus_namespace(self, value: builtins.str) -> None:
        jsii.set(self, "servicebusNamespace", value)

    @builtins.property # type: ignore
    @jsii.member(jsii_name="sharedAccessPolicyKey")
    def shared_access_policy_key(self) -> builtins.str:
        return jsii.get(self, "sharedAccessPolicyKey")

    @shared_access_policy_key.setter # type: ignore
    def shared_access_policy_key(self, value: builtins.str) -> None:
        jsii.set(self, "sharedAccessPolicyKey", value)

    @builtins.property # type: ignore
    @jsii.member(jsii_name="sharedAccessPolicyName")
    def shared_access_policy_name(self) -> builtins.str:
        return jsii.get(self, "sharedAccessPolicyName")

    @shared_access_policy_name.setter # type: ignore
    def shared_access_policy_name(self, value: builtins.str) -> None:
        jsii.set(self, "sharedAccessPolicyName", value)

    @builtins.property # type: ignore
    @jsii.member(jsii_name="streamAnalyticsJobName")
    def stream_analytics_job_name(self) -> builtins.str:
        return jsii.get(self, "streamAnalyticsJobName")

    @stream_analytics_job_name.setter # type: ignore
    def stream_analytics_job_name(self, value: builtins.str) -> None:
        jsii.set(self, "streamAnalyticsJobName", value)

    @builtins.property # type: ignore
    @jsii.member(jsii_name="id")
    def id(self) -> typing.Optional[builtins.str]:
        return jsii.get(self, "id")

    @id.setter # type: ignore
    def id(self, value: typing.Optional[builtins.str]) -> None:
        jsii.set(self, "id", value)

    @builtins.property # type: ignore
    @jsii.member(jsii_name="timeouts")
    def timeouts(self) -> typing.Optional["StreamAnalyticsOutputEventhubTimeouts"]:
        return jsii.get(self, "timeouts")

    @timeouts.setter # type: ignore
    def timeouts(
        self,
        value: typing.Optional["StreamAnalyticsOutputEventhubTimeouts"],
    ) -> None:
        jsii.set(self, "timeouts", value)


@jsii.data_type(
    jsii_type="@cdktf/provider-azurerm.StreamAnalyticsOutputEventhubConfig",
    jsii_struct_bases=[cdktf.TerraformMetaArguments],
    name_mapping={
        "count": "count",
        "depends_on": "dependsOn",
        "lifecycle": "lifecycle",
        "provider": "provider",
        "eventhub_name": "eventhubName",
        "name": "name",
        "resource_group_name": "resourceGroupName",
        "serialization": "serialization",
        "servicebus_namespace": "servicebusNamespace",
        "shared_access_policy_key": "sharedAccessPolicyKey",
        "shared_access_policy_name": "sharedAccessPolicyName",
        "stream_analytics_job_name": "streamAnalyticsJobName",
        "timeouts": "timeouts",
    },
)
class StreamAnalyticsOutputEventhubConfig(cdktf.TerraformMetaArguments):
    def __init__(
        self,
        *,
        count: typing.Optional[jsii.Number] = None,
        depends_on: typing.Optional[typing.List[cdktf.TerraformResource]] = None,
        lifecycle: typing.Optional[cdktf.TerraformResourceLifecycle] = None,
        provider: typing.Optional[cdktf.TerraformProvider] = None,
        eventhub_name: builtins.str,
        name: builtins.str,
        resource_group_name: builtins.str,
        serialization: typing.List["StreamAnalyticsOutputEventhubSerialization"],
        servicebus_namespace: builtins.str,
        shared_access_policy_key: builtins.str,
        shared_access_policy_name: builtins.str,
        stream_analytics_job_name: builtins.str,
        timeouts: typing.Optional["StreamAnalyticsOutputEventhubTimeouts"] = None,
    ) -> None:
        """
        :param count: 
        :param depends_on: 
        :param lifecycle: 
        :param provider: 
        :param eventhub_name: 
        :param name: 
        :param resource_group_name: 
        :param serialization: serialization block.
        :param servicebus_namespace: 
        :param shared_access_policy_key: 
        :param shared_access_policy_name: 
        :param stream_analytics_job_name: 
        :param timeouts: timeouts block.
        """
        if isinstance(lifecycle, dict):
            lifecycle = cdktf.TerraformResourceLifecycle(**lifecycle)
        if isinstance(timeouts, dict):
            timeouts = StreamAnalyticsOutputEventhubTimeouts(**timeouts)
        self._values: typing.Dict[str, typing.Any] = {
            "eventhub_name": eventhub_name,
            "name": name,
            "resource_group_name": resource_group_name,
            "serialization": serialization,
            "servicebus_namespace": servicebus_namespace,
            "shared_access_policy_key": shared_access_policy_key,
            "shared_access_policy_name": shared_access_policy_name,
            "stream_analytics_job_name": stream_analytics_job_name,
        }
        if count is not None:
            self._values["count"] = count
        if depends_on is not None:
            self._values["depends_on"] = depends_on
        if lifecycle is not None:
            self._values["lifecycle"] = lifecycle
        if provider is not None:
            self._values["provider"] = provider
        if timeouts is not None:
            self._values["timeouts"] = timeouts

    @builtins.property
    def count(self) -> typing.Optional[jsii.Number]:
        """
        :stability: experimental
        """
        result = self._values.get("count")
        return result

    @builtins.property
    def depends_on(self) -> typing.Optional[typing.List[cdktf.TerraformResource]]:
        """
        :stability: experimental
        """
        result = self._values.get("depends_on")
        return result

    @builtins.property
    def lifecycle(self) -> typing.Optional[cdktf.TerraformResourceLifecycle]:
        """
        :stability: experimental
        """
        result = self._values.get("lifecycle")
        return result

    @builtins.property
    def provider(self) -> typing.Optional[cdktf.TerraformProvider]:
        """
        :stability: experimental
        """
        result = self._values.get("provider")
        return result

    @builtins.property
    def eventhub_name(self) -> builtins.str:
        result = self._values.get("eventhub_name")
        assert result is not None, "Required property 'eventhub_name' is missing"
        return result

    @builtins.property
    def name(self) -> builtins.str:
        result = self._values.get("name")
        assert result is not None, "Required property 'name' is missing"
        return result

    @builtins.property
    def resource_group_name(self) -> builtins.str:
        result = self._values.get("resource_group_name")
        assert result is not None, "Required property 'resource_group_name' is missing"
        return result

    @builtins.property
    def serialization(
        self,
    ) -> typing.List["StreamAnalyticsOutputEventhubSerialization"]:
        """serialization block."""
        result = self._values.get("serialization")
        assert result is not None, "Required property 'serialization' is missing"
        return result

    @builtins.property
    def servicebus_namespace(self) -> builtins.str:
        result = self._values.get("servicebus_namespace")
        assert result is not None, "Required property 'servicebus_namespace' is missing"
        return result

    @builtins.property
    def shared_access_policy_key(self) -> builtins.str:
        result = self._values.get("shared_access_policy_key")
        assert result is not None, "Required property 'shared_access_policy_key' is missing"
        return result

    @builtins.property
    def shared_access_policy_name(self) -> builtins.str:
        result = self._values.get("shared_access_policy_name")
        assert result is not None, "Required property 'shared_access_policy_name' is missing"
        return result

    @builtins.property
    def stream_analytics_job_name(self) -> builtins.str:
        result = self._values.get("stream_analytics_job_name")
        assert result is not None, "Required property 'stream_analytics_job_name' is missing"
        return result

    @builtins.property
    def timeouts(self) -> typing.Optional["StreamAnalyticsOutputEventhubTimeouts"]:
        """timeouts block."""
        result = self._values.get("timeouts")
        return result

    def __eq__(self, rhs: typing.Any) -> builtins.bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs: typing.Any) -> builtins.bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return "StreamAnalyticsOutputEventhubConfig(%s)" % ", ".join(
            k + "=" + repr(v) for k, v in self._values.items()
        )


@jsii.data_type(
    jsii_type="@cdktf/provider-azurerm.StreamAnalyticsOutputEventhubSerialization",
    jsii_struct_bases=[],
    name_mapping={
        "type": "type",
        "encoding": "encoding",
        "field_delimiter": "fieldDelimiter",
        "format": "format",
    },
)
class StreamAnalyticsOutputEventhubSerialization:
    def __init__(
        self,
        *,
        type: builtins.str,
        encoding: typing.Optional[builtins.str] = None,
        field_delimiter: typing.Optional[builtins.str] = None,
        format: typing.Optional[builtins.str] = None,
    ) -> None:
        """
        :param type: 
        :param encoding: 
        :param field_delimiter: 
        :param format: 
        """
        self._values: typing.Dict[str, typing.Any] = {
            "type": type,
        }
        if encoding is not None:
            self._values["encoding"] = encoding
        if field_delimiter is not None:
            self._values["field_delimiter"] = field_delimiter
        if format is not None:
            self._values["format"] = format

    @builtins.property
    def type(self) -> builtins.str:
        result = self._values.get("type")
        assert result is not None, "Required property 'type' is missing"
        return result

    @builtins.property
    def encoding(self) -> typing.Optional[builtins.str]:
        result = self._values.get("encoding")
        return result

    @builtins.property
    def field_delimiter(self) -> typing.Optional[builtins.str]:
        result = self._values.get("field_delimiter")
        return result

    @builtins.property
    def format(self) -> typing.Optional[builtins.str]:
        result = self._values.get("format")
        return result

    def __eq__(self, rhs: typing.Any) -> builtins.bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs: typing.Any) -> builtins.bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return "StreamAnalyticsOutputEventhubSerialization(%s)" % ", ".join(
            k + "=" + repr(v) for k, v in self._values.items()
        )


@jsii.data_type(
    jsii_type="@cdktf/provider-azurerm.StreamAnalyticsOutputEventhubTimeouts",
    jsii_struct_bases=[],
    name_mapping={
        "create": "create",
        "delete": "delete",
        "read": "read",
        "update": "update",
    },
)
class StreamAnalyticsOutputEventhubTimeouts:
    def __init__(
        self,
        *,
        create: typing.Optional[builtins.str] = None,
        delete: typing.Optional[builtins.str] = None,
        read: typing.Optional[builtins.str] = None,
        update: typing.Optional[builtins.str] = None,
    ) -> None:
        """
        :param create: 
        :param delete: 
        :param read: 
        :param update: 
        """
        self._values: typing.Dict[str, typing.Any] = {}
        if create is not None:
            self._values["create"] = create
        if delete is not None:
            self._values["delete"] = delete
        if read is not None:
            self._values["read"] = read
        if update is not None:
            self._values["update"] = update

    @builtins.property
    def create(self) -> typing.Optional[builtins.str]:
        result = self._values.get("create")
        return result

    @builtins.property
    def delete(self) -> typing.Optional[builtins.str]:
        result = self._values.get("delete")
        return result

    @builtins.property
    def read(self) -> typing.Optional[builtins.str]:
        result = self._values.get("read")
        return result

    @builtins.property
    def update(self) -> typing.Optional[builtins.str]:
        result = self._values.get("update")
        return result

    def __eq__(self, rhs: typing.Any) -> builtins.bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs: typing.Any) -> builtins.bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return "StreamAnalyticsOutputEventhubTimeouts(%s)" % ", ".join(
            k + "=" + repr(v) for k, v in self._values.items()
        )


class StreamAnalyticsOutputMssql(
    cdktf.TerraformResource,
    metaclass=jsii.JSIIMeta,
    jsii_type="@cdktf/provider-azurerm.StreamAnalyticsOutputMssql",
):
    def __init__(
        self,
        scope: constructs.Construct,
        id: builtins.str,
        *,
        database: builtins.str,
        name: builtins.str,
        password: builtins.str,
        resource_group_name: builtins.str,
        server: builtins.str,
        stream_analytics_job_name: builtins.str,
        table: builtins.str,
        user: builtins.str,
        timeouts: typing.Optional["StreamAnalyticsOutputMssqlTimeouts"] = None,
        count: typing.Optional[jsii.Number] = None,
        depends_on: typing.Optional[typing.List[cdktf.TerraformResource]] = None,
        lifecycle: typing.Optional[cdktf.TerraformResourceLifecycle] = None,
        provider: typing.Optional[cdktf.TerraformProvider] = None,
    ) -> None:
        """
        :param scope: -
        :param id: -
        :param database: 
        :param name: 
        :param password: 
        :param resource_group_name: 
        :param server: 
        :param stream_analytics_job_name: 
        :param table: 
        :param user: 
        :param timeouts: timeouts block.
        :param count: 
        :param depends_on: 
        :param lifecycle: 
        :param provider: 
        """
        config = StreamAnalyticsOutputMssqlConfig(
            database=database,
            name=name,
            password=password,
            resource_group_name=resource_group_name,
            server=server,
            stream_analytics_job_name=stream_analytics_job_name,
            table=table,
            user=user,
            timeouts=timeouts,
            count=count,
            depends_on=depends_on,
            lifecycle=lifecycle,
            provider=provider,
        )

        jsii.create(StreamAnalyticsOutputMssql, self, [scope, id, config])

    @jsii.member(jsii_name="synthesizeAttributes")
    def _synthesize_attributes(self) -> typing.Mapping[builtins.str, typing.Any]:
        return jsii.invoke(self, "synthesizeAttributes", [])

    @builtins.property # type: ignore
    @jsii.member(jsii_name="database")
    def database(self) -> builtins.str:
        return jsii.get(self, "database")

    @database.setter # type: ignore
    def database(self, value: builtins.str) -> None:
        jsii.set(self, "database", value)

    @builtins.property # type: ignore
    @jsii.member(jsii_name="name")
    def name(self) -> builtins.str:
        return jsii.get(self, "name")

    @name.setter # type: ignore
    def name(self, value: builtins.str) -> None:
        jsii.set(self, "name", value)

    @builtins.property # type: ignore
    @jsii.member(jsii_name="password")
    def password(self) -> builtins.str:
        return jsii.get(self, "password")

    @password.setter # type: ignore
    def password(self, value: builtins.str) -> None:
        jsii.set(self, "password", value)

    @builtins.property # type: ignore
    @jsii.member(jsii_name="resourceGroupName")
    def resource_group_name(self) -> builtins.str:
        return jsii.get(self, "resourceGroupName")

    @resource_group_name.setter # type: ignore
    def resource_group_name(self, value: builtins.str) -> None:
        jsii.set(self, "resourceGroupName", value)

    @builtins.property # type: ignore
    @jsii.member(jsii_name="server")
    def server(self) -> builtins.str:
        return jsii.get(self, "server")

    @server.setter # type: ignore
    def server(self, value: builtins.str) -> None:
        jsii.set(self, "server", value)

    @builtins.property # type: ignore
    @jsii.member(jsii_name="streamAnalyticsJobName")
    def stream_analytics_job_name(self) -> builtins.str:
        return jsii.get(self, "streamAnalyticsJobName")

    @stream_analytics_job_name.setter # type: ignore
    def stream_analytics_job_name(self, value: builtins.str) -> None:
        jsii.set(self, "streamAnalyticsJobName", value)

    @builtins.property # type: ignore
    @jsii.member(jsii_name="table")
    def table(self) -> builtins.str:
        return jsii.get(self, "table")

    @table.setter # type: ignore
    def table(self, value: builtins.str) -> None:
        jsii.set(self, "table", value)

    @builtins.property # type: ignore
    @jsii.member(jsii_name="user")
    def user(self) -> builtins.str:
        return jsii.get(self, "user")

    @user.setter # type: ignore
    def user(self, value: builtins.str) -> None:
        jsii.set(self, "user", value)

    @builtins.property # type: ignore
    @jsii.member(jsii_name="id")
    def id(self) -> typing.Optional[builtins.str]:
        return jsii.get(self, "id")

    @id.setter # type: ignore
    def id(self, value: typing.Optional[builtins.str]) -> None:
        jsii.set(self, "id", value)

    @builtins.property # type: ignore
    @jsii.member(jsii_name="timeouts")
    def timeouts(self) -> typing.Optional["StreamAnalyticsOutputMssqlTimeouts"]:
        return jsii.get(self, "timeouts")

    @timeouts.setter # type: ignore
    def timeouts(
        self,
        value: typing.Optional["StreamAnalyticsOutputMssqlTimeouts"],
    ) -> None:
        jsii.set(self, "timeouts", value)


@jsii.data_type(
    jsii_type="@cdktf/provider-azurerm.StreamAnalyticsOutputMssqlConfig",
    jsii_struct_bases=[cdktf.TerraformMetaArguments],
    name_mapping={
        "count": "count",
        "depends_on": "dependsOn",
        "lifecycle": "lifecycle",
        "provider": "provider",
        "database": "database",
        "name": "name",
        "password": "password",
        "resource_group_name": "resourceGroupName",
        "server": "server",
        "stream_analytics_job_name": "streamAnalyticsJobName",
        "table": "table",
        "user": "user",
        "timeouts": "timeouts",
    },
)
class StreamAnalyticsOutputMssqlConfig(cdktf.TerraformMetaArguments):
    def __init__(
        self,
        *,
        count: typing.Optional[jsii.Number] = None,
        depends_on: typing.Optional[typing.List[cdktf.TerraformResource]] = None,
        lifecycle: typing.Optional[cdktf.TerraformResourceLifecycle] = None,
        provider: typing.Optional[cdktf.TerraformProvider] = None,
        database: builtins.str,
        name: builtins.str,
        password: builtins.str,
        resource_group_name: builtins.str,
        server: builtins.str,
        stream_analytics_job_name: builtins.str,
        table: builtins.str,
        user: builtins.str,
        timeouts: typing.Optional["StreamAnalyticsOutputMssqlTimeouts"] = None,
    ) -> None:
        """
        :param count: 
        :param depends_on: 
        :param lifecycle: 
        :param provider: 
        :param database: 
        :param name: 
        :param password: 
        :param resource_group_name: 
        :param server: 
        :param stream_analytics_job_name: 
        :param table: 
        :param user: 
        :param timeouts: timeouts block.
        """
        if isinstance(lifecycle, dict):
            lifecycle = cdktf.TerraformResourceLifecycle(**lifecycle)
        if isinstance(timeouts, dict):
            timeouts = StreamAnalyticsOutputMssqlTimeouts(**timeouts)
        self._values: typing.Dict[str, typing.Any] = {
            "database": database,
            "name": name,
            "password": password,
            "resource_group_name": resource_group_name,
            "server": server,
            "stream_analytics_job_name": stream_analytics_job_name,
            "table": table,
            "user": user,
        }
        if count is not None:
            self._values["count"] = count
        if depends_on is not None:
            self._values["depends_on"] = depends_on
        if lifecycle is not None:
            self._values["lifecycle"] = lifecycle
        if provider is not None:
            self._values["provider"] = provider
        if timeouts is not None:
            self._values["timeouts"] = timeouts

    @builtins.property
    def count(self) -> typing.Optional[jsii.Number]:
        """
        :stability: experimental
        """
        result = self._values.get("count")
        return result

    @builtins.property
    def depends_on(self) -> typing.Optional[typing.List[cdktf.TerraformResource]]:
        """
        :stability: experimental
        """
        result = self._values.get("depends_on")
        return result

    @builtins.property
    def lifecycle(self) -> typing.Optional[cdktf.TerraformResourceLifecycle]:
        """
        :stability: experimental
        """
        result = self._values.get("lifecycle")
        return result

    @builtins.property
    def provider(self) -> typing.Optional[cdktf.TerraformProvider]:
        """
        :stability: experimental
        """
        result = self._values.get("provider")
        return result

    @builtins.property
    def database(self) -> builtins.str:
        result = self._values.get("database")
        assert result is not None, "Required property 'database' is missing"
        return result

    @builtins.property
    def name(self) -> builtins.str:
        result = self._values.get("name")
        assert result is not None, "Required property 'name' is missing"
        return result

    @builtins.property
    def password(self) -> builtins.str:
        result = self._values.get("password")
        assert result is not None, "Required property 'password' is missing"
        return result

    @builtins.property
    def resource_group_name(self) -> builtins.str:
        result = self._values.get("resource_group_name")
        assert result is not None, "Required property 'resource_group_name' is missing"
        return result

    @builtins.property
    def server(self) -> builtins.str:
        result = self._values.get("server")
        assert result is not None, "Required property 'server' is missing"
        return result

    @builtins.property
    def stream_analytics_job_name(self) -> builtins.str:
        result = self._values.get("stream_analytics_job_name")
        assert result is not None, "Required property 'stream_analytics_job_name' is missing"
        return result

    @builtins.property
    def table(self) -> builtins.str:
        result = self._values.get("table")
        assert result is not None, "Required property 'table' is missing"
        return result

    @builtins.property
    def user(self) -> builtins.str:
        result = self._values.get("user")
        assert result is not None, "Required property 'user' is missing"
        return result

    @builtins.property
    def timeouts(self) -> typing.Optional["StreamAnalyticsOutputMssqlTimeouts"]:
        """timeouts block."""
        result = self._values.get("timeouts")
        return result

    def __eq__(self, rhs: typing.Any) -> builtins.bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs: typing.Any) -> builtins.bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return "StreamAnalyticsOutputMssqlConfig(%s)" % ", ".join(
            k + "=" + repr(v) for k, v in self._values.items()
        )


@jsii.data_type(
    jsii_type="@cdktf/provider-azurerm.StreamAnalyticsOutputMssqlTimeouts",
    jsii_struct_bases=[],
    name_mapping={
        "create": "create",
        "delete": "delete",
        "read": "read",
        "update": "update",
    },
)
class StreamAnalyticsOutputMssqlTimeouts:
    def __init__(
        self,
        *,
        create: typing.Optional[builtins.str] = None,
        delete: typing.Optional[builtins.str] = None,
        read: typing.Optional[builtins.str] = None,
        update: typing.Optional[builtins.str] = None,
    ) -> None:
        """
        :param create: 
        :param delete: 
        :param read: 
        :param update: 
        """
        self._values: typing.Dict[str, typing.Any] = {}
        if create is not None:
            self._values["create"] = create
        if delete is not None:
            self._values["delete"] = delete
        if read is not None:
            self._values["read"] = read
        if update is not None:
            self._values["update"] = update

    @builtins.property
    def create(self) -> typing.Optional[builtins.str]:
        result = self._values.get("create")
        return result

    @builtins.property
    def delete(self) -> typing.Optional[builtins.str]:
        result = self._values.get("delete")
        return result

    @builtins.property
    def read(self) -> typing.Optional[builtins.str]:
        result = self._values.get("read")
        return result

    @builtins.property
    def update(self) -> typing.Optional[builtins.str]:
        result = self._values.get("update")
        return result

    def __eq__(self, rhs: typing.Any) -> builtins.bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs: typing.Any) -> builtins.bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return "StreamAnalyticsOutputMssqlTimeouts(%s)" % ", ".join(
            k + "=" + repr(v) for k, v in self._values.items()
        )


class StreamAnalyticsOutputServicebusQueue(
    cdktf.TerraformResource,
    metaclass=jsii.JSIIMeta,
    jsii_type="@cdktf/provider-azurerm.StreamAnalyticsOutputServicebusQueue",
):
    def __init__(
        self,
        scope: constructs.Construct,
        id: builtins.str,
        *,
        name: builtins.str,
        queue_name: builtins.str,
        resource_group_name: builtins.str,
        serialization: typing.List["StreamAnalyticsOutputServicebusQueueSerialization"],
        servicebus_namespace: builtins.str,
        shared_access_policy_key: builtins.str,
        shared_access_policy_name: builtins.str,
        stream_analytics_job_name: builtins.str,
        timeouts: typing.Optional["StreamAnalyticsOutputServicebusQueueTimeouts"] = None,
        count: typing.Optional[jsii.Number] = None,
        depends_on: typing.Optional[typing.List[cdktf.TerraformResource]] = None,
        lifecycle: typing.Optional[cdktf.TerraformResourceLifecycle] = None,
        provider: typing.Optional[cdktf.TerraformProvider] = None,
    ) -> None:
        """
        :param scope: -
        :param id: -
        :param name: 
        :param queue_name: 
        :param resource_group_name: 
        :param serialization: serialization block.
        :param servicebus_namespace: 
        :param shared_access_policy_key: 
        :param shared_access_policy_name: 
        :param stream_analytics_job_name: 
        :param timeouts: timeouts block.
        :param count: 
        :param depends_on: 
        :param lifecycle: 
        :param provider: 
        """
        config = StreamAnalyticsOutputServicebusQueueConfig(
            name=name,
            queue_name=queue_name,
            resource_group_name=resource_group_name,
            serialization=serialization,
            servicebus_namespace=servicebus_namespace,
            shared_access_policy_key=shared_access_policy_key,
            shared_access_policy_name=shared_access_policy_name,
            stream_analytics_job_name=stream_analytics_job_name,
            timeouts=timeouts,
            count=count,
            depends_on=depends_on,
            lifecycle=lifecycle,
            provider=provider,
        )

        jsii.create(StreamAnalyticsOutputServicebusQueue, self, [scope, id, config])

    @jsii.member(jsii_name="synthesizeAttributes")
    def _synthesize_attributes(self) -> typing.Mapping[builtins.str, typing.Any]:
        return jsii.invoke(self, "synthesizeAttributes", [])

    @builtins.property # type: ignore
    @jsii.member(jsii_name="name")
    def name(self) -> builtins.str:
        return jsii.get(self, "name")

    @name.setter # type: ignore
    def name(self, value: builtins.str) -> None:
        jsii.set(self, "name", value)

    @builtins.property # type: ignore
    @jsii.member(jsii_name="queueName")
    def queue_name(self) -> builtins.str:
        return jsii.get(self, "queueName")

    @queue_name.setter # type: ignore
    def queue_name(self, value: builtins.str) -> None:
        jsii.set(self, "queueName", value)

    @builtins.property # type: ignore
    @jsii.member(jsii_name="resourceGroupName")
    def resource_group_name(self) -> builtins.str:
        return jsii.get(self, "resourceGroupName")

    @resource_group_name.setter # type: ignore
    def resource_group_name(self, value: builtins.str) -> None:
        jsii.set(self, "resourceGroupName", value)

    @builtins.property # type: ignore
    @jsii.member(jsii_name="serialization")
    def serialization(
        self,
    ) -> typing.List["StreamAnalyticsOutputServicebusQueueSerialization"]:
        return jsii.get(self, "serialization")

    @serialization.setter # type: ignore
    def serialization(
        self,
        value: typing.List["StreamAnalyticsOutputServicebusQueueSerialization"],
    ) -> None:
        jsii.set(self, "serialization", value)

    @builtins.property # type: ignore
    @jsii.member(jsii_name="servicebusNamespace")
    def servicebus_namespace(self) -> builtins.str:
        return jsii.get(self, "servicebusNamespace")

    @servicebus_namespace.setter # type: ignore
    def servicebus_namespace(self, value: builtins.str) -> None:
        jsii.set(self, "servicebusNamespace", value)

    @builtins.property # type: ignore
    @jsii.member(jsii_name="sharedAccessPolicyKey")
    def shared_access_policy_key(self) -> builtins.str:
        return jsii.get(self, "sharedAccessPolicyKey")

    @shared_access_policy_key.setter # type: ignore
    def shared_access_policy_key(self, value: builtins.str) -> None:
        jsii.set(self, "sharedAccessPolicyKey", value)

    @builtins.property # type: ignore
    @jsii.member(jsii_name="sharedAccessPolicyName")
    def shared_access_policy_name(self) -> builtins.str:
        return jsii.get(self, "sharedAccessPolicyName")

    @shared_access_policy_name.setter # type: ignore
    def shared_access_policy_name(self, value: builtins.str) -> None:
        jsii.set(self, "sharedAccessPolicyName", value)

    @builtins.property # type: ignore
    @jsii.member(jsii_name="streamAnalyticsJobName")
    def stream_analytics_job_name(self) -> builtins.str:
        return jsii.get(self, "streamAnalyticsJobName")

    @stream_analytics_job_name.setter # type: ignore
    def stream_analytics_job_name(self, value: builtins.str) -> None:
        jsii.set(self, "streamAnalyticsJobName", value)

    @builtins.property # type: ignore
    @jsii.member(jsii_name="id")
    def id(self) -> typing.Optional[builtins.str]:
        return jsii.get(self, "id")

    @id.setter # type: ignore
    def id(self, value: typing.Optional[builtins.str]) -> None:
        jsii.set(self, "id", value)

    @builtins.property # type: ignore
    @jsii.member(jsii_name="timeouts")
    def timeouts(
        self,
    ) -> typing.Optional["StreamAnalyticsOutputServicebusQueueTimeouts"]:
        return jsii.get(self, "timeouts")

    @timeouts.setter # type: ignore
    def timeouts(
        self,
        value: typing.Optional["StreamAnalyticsOutputServicebusQueueTimeouts"],
    ) -> None:
        jsii.set(self, "timeouts", value)


@jsii.data_type(
    jsii_type="@cdktf/provider-azurerm.StreamAnalyticsOutputServicebusQueueConfig",
    jsii_struct_bases=[cdktf.TerraformMetaArguments],
    name_mapping={
        "count": "count",
        "depends_on": "dependsOn",
        "lifecycle": "lifecycle",
        "provider": "provider",
        "name": "name",
        "queue_name": "queueName",
        "resource_group_name": "resourceGroupName",
        "serialization": "serialization",
        "servicebus_namespace": "servicebusNamespace",
        "shared_access_policy_key": "sharedAccessPolicyKey",
        "shared_access_policy_name": "sharedAccessPolicyName",
        "stream_analytics_job_name": "streamAnalyticsJobName",
        "timeouts": "timeouts",
    },
)
class StreamAnalyticsOutputServicebusQueueConfig(cdktf.TerraformMetaArguments):
    def __init__(
        self,
        *,
        count: typing.Optional[jsii.Number] = None,
        depends_on: typing.Optional[typing.List[cdktf.TerraformResource]] = None,
        lifecycle: typing.Optional[cdktf.TerraformResourceLifecycle] = None,
        provider: typing.Optional[cdktf.TerraformProvider] = None,
        name: builtins.str,
        queue_name: builtins.str,
        resource_group_name: builtins.str,
        serialization: typing.List["StreamAnalyticsOutputServicebusQueueSerialization"],
        servicebus_namespace: builtins.str,
        shared_access_policy_key: builtins.str,
        shared_access_policy_name: builtins.str,
        stream_analytics_job_name: builtins.str,
        timeouts: typing.Optional["StreamAnalyticsOutputServicebusQueueTimeouts"] = None,
    ) -> None:
        """
        :param count: 
        :param depends_on: 
        :param lifecycle: 
        :param provider: 
        :param name: 
        :param queue_name: 
        :param resource_group_name: 
        :param serialization: serialization block.
        :param servicebus_namespace: 
        :param shared_access_policy_key: 
        :param shared_access_policy_name: 
        :param stream_analytics_job_name: 
        :param timeouts: timeouts block.
        """
        if isinstance(lifecycle, dict):
            lifecycle = cdktf.TerraformResourceLifecycle(**lifecycle)
        if isinstance(timeouts, dict):
            timeouts = StreamAnalyticsOutputServicebusQueueTimeouts(**timeouts)
        self._values: typing.Dict[str, typing.Any] = {
            "name": name,
            "queue_name": queue_name,
            "resource_group_name": resource_group_name,
            "serialization": serialization,
            "servicebus_namespace": servicebus_namespace,
            "shared_access_policy_key": shared_access_policy_key,
            "shared_access_policy_name": shared_access_policy_name,
            "stream_analytics_job_name": stream_analytics_job_name,
        }
        if count is not None:
            self._values["count"] = count
        if depends_on is not None:
            self._values["depends_on"] = depends_on
        if lifecycle is not None:
            self._values["lifecycle"] = lifecycle
        if provider is not None:
            self._values["provider"] = provider
        if timeouts is not None:
            self._values["timeouts"] = timeouts

    @builtins.property
    def count(self) -> typing.Optional[jsii.Number]:
        """
        :stability: experimental
        """
        result = self._values.get("count")
        return result

    @builtins.property
    def depends_on(self) -> typing.Optional[typing.List[cdktf.TerraformResource]]:
        """
        :stability: experimental
        """
        result = self._values.get("depends_on")
        return result

    @builtins.property
    def lifecycle(self) -> typing.Optional[cdktf.TerraformResourceLifecycle]:
        """
        :stability: experimental
        """
        result = self._values.get("lifecycle")
        return result

    @builtins.property
    def provider(self) -> typing.Optional[cdktf.TerraformProvider]:
        """
        :stability: experimental
        """
        result = self._values.get("provider")
        return result

    @builtins.property
    def name(self) -> builtins.str:
        result = self._values.get("name")
        assert result is not None, "Required property 'name' is missing"
        return result

    @builtins.property
    def queue_name(self) -> builtins.str:
        result = self._values.get("queue_name")
        assert result is not None, "Required property 'queue_name' is missing"
        return result

    @builtins.property
    def resource_group_name(self) -> builtins.str:
        result = self._values.get("resource_group_name")
        assert result is not None, "Required property 'resource_group_name' is missing"
        return result

    @builtins.property
    def serialization(
        self,
    ) -> typing.List["StreamAnalyticsOutputServicebusQueueSerialization"]:
        """serialization block."""
        result = self._values.get("serialization")
        assert result is not None, "Required property 'serialization' is missing"
        return result

    @builtins.property
    def servicebus_namespace(self) -> builtins.str:
        result = self._values.get("servicebus_namespace")
        assert result is not None, "Required property 'servicebus_namespace' is missing"
        return result

    @builtins.property
    def shared_access_policy_key(self) -> builtins.str:
        result = self._values.get("shared_access_policy_key")
        assert result is not None, "Required property 'shared_access_policy_key' is missing"
        return result

    @builtins.property
    def shared_access_policy_name(self) -> builtins.str:
        result = self._values.get("shared_access_policy_name")
        assert result is not None, "Required property 'shared_access_policy_name' is missing"
        return result

    @builtins.property
    def stream_analytics_job_name(self) -> builtins.str:
        result = self._values.get("stream_analytics_job_name")
        assert result is not None, "Required property 'stream_analytics_job_name' is missing"
        return result

    @builtins.property
    def timeouts(
        self,
    ) -> typing.Optional["StreamAnalyticsOutputServicebusQueueTimeouts"]:
        """timeouts block."""
        result = self._values.get("timeouts")
        return result

    def __eq__(self, rhs: typing.Any) -> builtins.bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs: typing.Any) -> builtins.bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return "StreamAnalyticsOutputServicebusQueueConfig(%s)" % ", ".join(
            k + "=" + repr(v) for k, v in self._values.items()
        )


@jsii.data_type(
    jsii_type="@cdktf/provider-azurerm.StreamAnalyticsOutputServicebusQueueSerialization",
    jsii_struct_bases=[],
    name_mapping={
        "type": "type",
        "encoding": "encoding",
        "field_delimiter": "fieldDelimiter",
        "format": "format",
    },
)
class StreamAnalyticsOutputServicebusQueueSerialization:
    def __init__(
        self,
        *,
        type: builtins.str,
        encoding: typing.Optional[builtins.str] = None,
        field_delimiter: typing.Optional[builtins.str] = None,
        format: typing.Optional[builtins.str] = None,
    ) -> None:
        """
        :param type: 
        :param encoding: 
        :param field_delimiter: 
        :param format: 
        """
        self._values: typing.Dict[str, typing.Any] = {
            "type": type,
        }
        if encoding is not None:
            self._values["encoding"] = encoding
        if field_delimiter is not None:
            self._values["field_delimiter"] = field_delimiter
        if format is not None:
            self._values["format"] = format

    @builtins.property
    def type(self) -> builtins.str:
        result = self._values.get("type")
        assert result is not None, "Required property 'type' is missing"
        return result

    @builtins.property
    def encoding(self) -> typing.Optional[builtins.str]:
        result = self._values.get("encoding")
        return result

    @builtins.property
    def field_delimiter(self) -> typing.Optional[builtins.str]:
        result = self._values.get("field_delimiter")
        return result

    @builtins.property
    def format(self) -> typing.Optional[builtins.str]:
        result = self._values.get("format")
        return result

    def __eq__(self, rhs: typing.Any) -> builtins.bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs: typing.Any) -> builtins.bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return "StreamAnalyticsOutputServicebusQueueSerialization(%s)" % ", ".join(
            k + "=" + repr(v) for k, v in self._values.items()
        )


@jsii.data_type(
    jsii_type="@cdktf/provider-azurerm.StreamAnalyticsOutputServicebusQueueTimeouts",
    jsii_struct_bases=[],
    name_mapping={
        "create": "create",
        "delete": "delete",
        "read": "read",
        "update": "update",
    },
)
class StreamAnalyticsOutputServicebusQueueTimeouts:
    def __init__(
        self,
        *,
        create: typing.Optional[builtins.str] = None,
        delete: typing.Optional[builtins.str] = None,
        read: typing.Optional[builtins.str] = None,
        update: typing.Optional[builtins.str] = None,
    ) -> None:
        """
        :param create: 
        :param delete: 
        :param read: 
        :param update: 
        """
        self._values: typing.Dict[str, typing.Any] = {}
        if create is not None:
            self._values["create"] = create
        if delete is not None:
            self._values["delete"] = delete
        if read is not None:
            self._values["read"] = read
        if update is not None:
            self._values["update"] = update

    @builtins.property
    def create(self) -> typing.Optional[builtins.str]:
        result = self._values.get("create")
        return result

    @builtins.property
    def delete(self) -> typing.Optional[builtins.str]:
        result = self._values.get("delete")
        return result

    @builtins.property
    def read(self) -> typing.Optional[builtins.str]:
        result = self._values.get("read")
        return result

    @builtins.property
    def update(self) -> typing.Optional[builtins.str]:
        result = self._values.get("update")
        return result

    def __eq__(self, rhs: typing.Any) -> builtins.bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs: typing.Any) -> builtins.bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return "StreamAnalyticsOutputServicebusQueueTimeouts(%s)" % ", ".join(
            k + "=" + repr(v) for k, v in self._values.items()
        )


class StreamAnalyticsOutputServicebusTopic(
    cdktf.TerraformResource,
    metaclass=jsii.JSIIMeta,
    jsii_type="@cdktf/provider-azurerm.StreamAnalyticsOutputServicebusTopic",
):
    def __init__(
        self,
        scope: constructs.Construct,
        id: builtins.str,
        *,
        name: builtins.str,
        resource_group_name: builtins.str,
        serialization: typing.List["StreamAnalyticsOutputServicebusTopicSerialization"],
        servicebus_namespace: builtins.str,
        shared_access_policy_key: builtins.str,
        shared_access_policy_name: builtins.str,
        stream_analytics_job_name: builtins.str,
        topic_name: builtins.str,
        timeouts: typing.Optional["StreamAnalyticsOutputServicebusTopicTimeouts"] = None,
        count: typing.Optional[jsii.Number] = None,
        depends_on: typing.Optional[typing.List[cdktf.TerraformResource]] = None,
        lifecycle: typing.Optional[cdktf.TerraformResourceLifecycle] = None,
        provider: typing.Optional[cdktf.TerraformProvider] = None,
    ) -> None:
        """
        :param scope: -
        :param id: -
        :param name: 
        :param resource_group_name: 
        :param serialization: serialization block.
        :param servicebus_namespace: 
        :param shared_access_policy_key: 
        :param shared_access_policy_name: 
        :param stream_analytics_job_name: 
        :param topic_name: 
        :param timeouts: timeouts block.
        :param count: 
        :param depends_on: 
        :param lifecycle: 
        :param provider: 
        """
        config = StreamAnalyticsOutputServicebusTopicConfig(
            name=name,
            resource_group_name=resource_group_name,
            serialization=serialization,
            servicebus_namespace=servicebus_namespace,
            shared_access_policy_key=shared_access_policy_key,
            shared_access_policy_name=shared_access_policy_name,
            stream_analytics_job_name=stream_analytics_job_name,
            topic_name=topic_name,
            timeouts=timeouts,
            count=count,
            depends_on=depends_on,
            lifecycle=lifecycle,
            provider=provider,
        )

        jsii.create(StreamAnalyticsOutputServicebusTopic, self, [scope, id, config])

    @jsii.member(jsii_name="synthesizeAttributes")
    def _synthesize_attributes(self) -> typing.Mapping[builtins.str, typing.Any]:
        return jsii.invoke(self, "synthesizeAttributes", [])

    @builtins.property # type: ignore
    @jsii.member(jsii_name="name")
    def name(self) -> builtins.str:
        return jsii.get(self, "name")

    @name.setter # type: ignore
    def name(self, value: builtins.str) -> None:
        jsii.set(self, "name", value)

    @builtins.property # type: ignore
    @jsii.member(jsii_name="resourceGroupName")
    def resource_group_name(self) -> builtins.str:
        return jsii.get(self, "resourceGroupName")

    @resource_group_name.setter # type: ignore
    def resource_group_name(self, value: builtins.str) -> None:
        jsii.set(self, "resourceGroupName", value)

    @builtins.property # type: ignore
    @jsii.member(jsii_name="serialization")
    def serialization(
        self,
    ) -> typing.List["StreamAnalyticsOutputServicebusTopicSerialization"]:
        return jsii.get(self, "serialization")

    @serialization.setter # type: ignore
    def serialization(
        self,
        value: typing.List["StreamAnalyticsOutputServicebusTopicSerialization"],
    ) -> None:
        jsii.set(self, "serialization", value)

    @builtins.property # type: ignore
    @jsii.member(jsii_name="servicebusNamespace")
    def servicebus_namespace(self) -> builtins.str:
        return jsii.get(self, "servicebusNamespace")

    @servicebus_namespace.setter # type: ignore
    def servicebus_namespace(self, value: builtins.str) -> None:
        jsii.set(self, "servicebusNamespace", value)

    @builtins.property # type: ignore
    @jsii.member(jsii_name="sharedAccessPolicyKey")
    def shared_access_policy_key(self) -> builtins.str:
        return jsii.get(self, "sharedAccessPolicyKey")

    @shared_access_policy_key.setter # type: ignore
    def shared_access_policy_key(self, value: builtins.str) -> None:
        jsii.set(self, "sharedAccessPolicyKey", value)

    @builtins.property # type: ignore
    @jsii.member(jsii_name="sharedAccessPolicyName")
    def shared_access_policy_name(self) -> builtins.str:
        return jsii.get(self, "sharedAccessPolicyName")

    @shared_access_policy_name.setter # type: ignore
    def shared_access_policy_name(self, value: builtins.str) -> None:
        jsii.set(self, "sharedAccessPolicyName", value)

    @builtins.property # type: ignore
    @jsii.member(jsii_name="streamAnalyticsJobName")
    def stream_analytics_job_name(self) -> builtins.str:
        return jsii.get(self, "streamAnalyticsJobName")

    @stream_analytics_job_name.setter # type: ignore
    def stream_analytics_job_name(self, value: builtins.str) -> None:
        jsii.set(self, "streamAnalyticsJobName", value)

    @builtins.property # type: ignore
    @jsii.member(jsii_name="topicName")
    def topic_name(self) -> builtins.str:
        return jsii.get(self, "topicName")

    @topic_name.setter # type: ignore
    def topic_name(self, value: builtins.str) -> None:
        jsii.set(self, "topicName", value)

    @builtins.property # type: ignore
    @jsii.member(jsii_name="id")
    def id(self) -> typing.Optional[builtins.str]:
        return jsii.get(self, "id")

    @id.setter # type: ignore
    def id(self, value: typing.Optional[builtins.str]) -> None:
        jsii.set(self, "id", value)

    @builtins.property # type: ignore
    @jsii.member(jsii_name="timeouts")
    def timeouts(
        self,
    ) -> typing.Optional["StreamAnalyticsOutputServicebusTopicTimeouts"]:
        return jsii.get(self, "timeouts")

    @timeouts.setter # type: ignore
    def timeouts(
        self,
        value: typing.Optional["StreamAnalyticsOutputServicebusTopicTimeouts"],
    ) -> None:
        jsii.set(self, "timeouts", value)


@jsii.data_type(
    jsii_type="@cdktf/provider-azurerm.StreamAnalyticsOutputServicebusTopicConfig",
    jsii_struct_bases=[cdktf.TerraformMetaArguments],
    name_mapping={
        "count": "count",
        "depends_on": "dependsOn",
        "lifecycle": "lifecycle",
        "provider": "provider",
        "name": "name",
        "resource_group_name": "resourceGroupName",
        "serialization": "serialization",
        "servicebus_namespace": "servicebusNamespace",
        "shared_access_policy_key": "sharedAccessPolicyKey",
        "shared_access_policy_name": "sharedAccessPolicyName",
        "stream_analytics_job_name": "streamAnalyticsJobName",
        "topic_name": "topicName",
        "timeouts": "timeouts",
    },
)
class StreamAnalyticsOutputServicebusTopicConfig(cdktf.TerraformMetaArguments):
    def __init__(
        self,
        *,
        count: typing.Optional[jsii.Number] = None,
        depends_on: typing.Optional[typing.List[cdktf.TerraformResource]] = None,
        lifecycle: typing.Optional[cdktf.TerraformResourceLifecycle] = None,
        provider: typing.Optional[cdktf.TerraformProvider] = None,
        name: builtins.str,
        resource_group_name: builtins.str,
        serialization: typing.List["StreamAnalyticsOutputServicebusTopicSerialization"],
        servicebus_namespace: builtins.str,
        shared_access_policy_key: builtins.str,
        shared_access_policy_name: builtins.str,
        stream_analytics_job_name: builtins.str,
        topic_name: builtins.str,
        timeouts: typing.Optional["StreamAnalyticsOutputServicebusTopicTimeouts"] = None,
    ) -> None:
        """
        :param count: 
        :param depends_on: 
        :param lifecycle: 
        :param provider: 
        :param name: 
        :param resource_group_name: 
        :param serialization: serialization block.
        :param servicebus_namespace: 
        :param shared_access_policy_key: 
        :param shared_access_policy_name: 
        :param stream_analytics_job_name: 
        :param topic_name: 
        :param timeouts: timeouts block.
        """
        if isinstance(lifecycle, dict):
            lifecycle = cdktf.TerraformResourceLifecycle(**lifecycle)
        if isinstance(timeouts, dict):
            timeouts = StreamAnalyticsOutputServicebusTopicTimeouts(**timeouts)
        self._values: typing.Dict[str, typing.Any] = {
            "name": name,
            "resource_group_name": resource_group_name,
            "serialization": serialization,
            "servicebus_namespace": servicebus_namespace,
            "shared_access_policy_key": shared_access_policy_key,
            "shared_access_policy_name": shared_access_policy_name,
            "stream_analytics_job_name": stream_analytics_job_name,
            "topic_name": topic_name,
        }
        if count is not None:
            self._values["count"] = count
        if depends_on is not None:
            self._values["depends_on"] = depends_on
        if lifecycle is not None:
            self._values["lifecycle"] = lifecycle
        if provider is not None:
            self._values["provider"] = provider
        if timeouts is not None:
            self._values["timeouts"] = timeouts

    @builtins.property
    def count(self) -> typing.Optional[jsii.Number]:
        """
        :stability: experimental
        """
        result = self._values.get("count")
        return result

    @builtins.property
    def depends_on(self) -> typing.Optional[typing.List[cdktf.TerraformResource]]:
        """
        :stability: experimental
        """
        result = self._values.get("depends_on")
        return result

    @builtins.property
    def lifecycle(self) -> typing.Optional[cdktf.TerraformResourceLifecycle]:
        """
        :stability: experimental
        """
        result = self._values.get("lifecycle")
        return result

    @builtins.property
    def provider(self) -> typing.Optional[cdktf.TerraformProvider]:
        """
        :stability: experimental
        """
        result = self._values.get("provider")
        return result

    @builtins.property
    def name(self) -> builtins.str:
        result = self._values.get("name")
        assert result is not None, "Required property 'name' is missing"
        return result

    @builtins.property
    def resource_group_name(self) -> builtins.str:
        result = self._values.get("resource_group_name")
        assert result is not None, "Required property 'resource_group_name' is missing"
        return result

    @builtins.property
    def serialization(
        self,
    ) -> typing.List["StreamAnalyticsOutputServicebusTopicSerialization"]:
        """serialization block."""
        result = self._values.get("serialization")
        assert result is not None, "Required property 'serialization' is missing"
        return result

    @builtins.property
    def servicebus_namespace(self) -> builtins.str:
        result = self._values.get("servicebus_namespace")
        assert result is not None, "Required property 'servicebus_namespace' is missing"
        return result

    @builtins.property
    def shared_access_policy_key(self) -> builtins.str:
        result = self._values.get("shared_access_policy_key")
        assert result is not None, "Required property 'shared_access_policy_key' is missing"
        return result

    @builtins.property
    def shared_access_policy_name(self) -> builtins.str:
        result = self._values.get("shared_access_policy_name")
        assert result is not None, "Required property 'shared_access_policy_name' is missing"
        return result

    @builtins.property
    def stream_analytics_job_name(self) -> builtins.str:
        result = self._values.get("stream_analytics_job_name")
        assert result is not None, "Required property 'stream_analytics_job_name' is missing"
        return result

    @builtins.property
    def topic_name(self) -> builtins.str:
        result = self._values.get("topic_name")
        assert result is not None, "Required property 'topic_name' is missing"
        return result

    @builtins.property
    def timeouts(
        self,
    ) -> typing.Optional["StreamAnalyticsOutputServicebusTopicTimeouts"]:
        """timeouts block."""
        result = self._values.get("timeouts")
        return result

    def __eq__(self, rhs: typing.Any) -> builtins.bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs: typing.Any) -> builtins.bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return "StreamAnalyticsOutputServicebusTopicConfig(%s)" % ", ".join(
            k + "=" + repr(v) for k, v in self._values.items()
        )


@jsii.data_type(
    jsii_type="@cdktf/provider-azurerm.StreamAnalyticsOutputServicebusTopicSerialization",
    jsii_struct_bases=[],
    name_mapping={
        "type": "type",
        "encoding": "encoding",
        "field_delimiter": "fieldDelimiter",
        "format": "format",
    },
)
class StreamAnalyticsOutputServicebusTopicSerialization:
    def __init__(
        self,
        *,
        type: builtins.str,
        encoding: typing.Optional[builtins.str] = None,
        field_delimiter: typing.Optional[builtins.str] = None,
        format: typing.Optional[builtins.str] = None,
    ) -> None:
        """
        :param type: 
        :param encoding: 
        :param field_delimiter: 
        :param format: 
        """
        self._values: typing.Dict[str, typing.Any] = {
            "type": type,
        }
        if encoding is not None:
            self._values["encoding"] = encoding
        if field_delimiter is not None:
            self._values["field_delimiter"] = field_delimiter
        if format is not None:
            self._values["format"] = format

    @builtins.property
    def type(self) -> builtins.str:
        result = self._values.get("type")
        assert result is not None, "Required property 'type' is missing"
        return result

    @builtins.property
    def encoding(self) -> typing.Optional[builtins.str]:
        result = self._values.get("encoding")
        return result

    @builtins.property
    def field_delimiter(self) -> typing.Optional[builtins.str]:
        result = self._values.get("field_delimiter")
        return result

    @builtins.property
    def format(self) -> typing.Optional[builtins.str]:
        result = self._values.get("format")
        return result

    def __eq__(self, rhs: typing.Any) -> builtins.bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs: typing.Any) -> builtins.bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return "StreamAnalyticsOutputServicebusTopicSerialization(%s)" % ", ".join(
            k + "=" + repr(v) for k, v in self._values.items()
        )


@jsii.data_type(
    jsii_type="@cdktf/provider-azurerm.StreamAnalyticsOutputServicebusTopicTimeouts",
    jsii_struct_bases=[],
    name_mapping={
        "create": "create",
        "delete": "delete",
        "read": "read",
        "update": "update",
    },
)
class StreamAnalyticsOutputServicebusTopicTimeouts:
    def __init__(
        self,
        *,
        create: typing.Optional[builtins.str] = None,
        delete: typing.Optional[builtins.str] = None,
        read: typing.Optional[builtins.str] = None,
        update: typing.Optional[builtins.str] = None,
    ) -> None:
        """
        :param create: 
        :param delete: 
        :param read: 
        :param update: 
        """
        self._values: typing.Dict[str, typing.Any] = {}
        if create is not None:
            self._values["create"] = create
        if delete is not None:
            self._values["delete"] = delete
        if read is not None:
            self._values["read"] = read
        if update is not None:
            self._values["update"] = update

    @builtins.property
    def create(self) -> typing.Optional[builtins.str]:
        result = self._values.get("create")
        return result

    @builtins.property
    def delete(self) -> typing.Optional[builtins.str]:
        result = self._values.get("delete")
        return result

    @builtins.property
    def read(self) -> typing.Optional[builtins.str]:
        result = self._values.get("read")
        return result

    @builtins.property
    def update(self) -> typing.Optional[builtins.str]:
        result = self._values.get("update")
        return result

    def __eq__(self, rhs: typing.Any) -> builtins.bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs: typing.Any) -> builtins.bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return "StreamAnalyticsOutputServicebusTopicTimeouts(%s)" % ", ".join(
            k + "=" + repr(v) for k, v in self._values.items()
        )


class StreamAnalyticsReferenceInputBlob(
    cdktf.TerraformResource,
    metaclass=jsii.JSIIMeta,
    jsii_type="@cdktf/provider-azurerm.StreamAnalyticsReferenceInputBlob",
):
    def __init__(
        self,
        scope: constructs.Construct,
        id: builtins.str,
        *,
        date_format: builtins.str,
        name: builtins.str,
        path_pattern: builtins.str,
        resource_group_name: builtins.str,
        serialization: typing.List["StreamAnalyticsReferenceInputBlobSerialization"],
        storage_account_key: builtins.str,
        storage_account_name: builtins.str,
        storage_container_name: builtins.str,
        stream_analytics_job_name: builtins.str,
        time_format: builtins.str,
        timeouts: typing.Optional["StreamAnalyticsReferenceInputBlobTimeouts"] = None,
        count: typing.Optional[jsii.Number] = None,
        depends_on: typing.Optional[typing.List[cdktf.TerraformResource]] = None,
        lifecycle: typing.Optional[cdktf.TerraformResourceLifecycle] = None,
        provider: typing.Optional[cdktf.TerraformProvider] = None,
    ) -> None:
        """
        :param scope: -
        :param id: -
        :param date_format: 
        :param name: 
        :param path_pattern: 
        :param resource_group_name: 
        :param serialization: serialization block.
        :param storage_account_key: 
        :param storage_account_name: 
        :param storage_container_name: 
        :param stream_analytics_job_name: 
        :param time_format: 
        :param timeouts: timeouts block.
        :param count: 
        :param depends_on: 
        :param lifecycle: 
        :param provider: 
        """
        config = StreamAnalyticsReferenceInputBlobConfig(
            date_format=date_format,
            name=name,
            path_pattern=path_pattern,
            resource_group_name=resource_group_name,
            serialization=serialization,
            storage_account_key=storage_account_key,
            storage_account_name=storage_account_name,
            storage_container_name=storage_container_name,
            stream_analytics_job_name=stream_analytics_job_name,
            time_format=time_format,
            timeouts=timeouts,
            count=count,
            depends_on=depends_on,
            lifecycle=lifecycle,
            provider=provider,
        )

        jsii.create(StreamAnalyticsReferenceInputBlob, self, [scope, id, config])

    @jsii.member(jsii_name="synthesizeAttributes")
    def _synthesize_attributes(self) -> typing.Mapping[builtins.str, typing.Any]:
        return jsii.invoke(self, "synthesizeAttributes", [])

    @builtins.property # type: ignore
    @jsii.member(jsii_name="dateFormat")
    def date_format(self) -> builtins.str:
        return jsii.get(self, "dateFormat")

    @date_format.setter # type: ignore
    def date_format(self, value: builtins.str) -> None:
        jsii.set(self, "dateFormat", value)

    @builtins.property # type: ignore
    @jsii.member(jsii_name="name")
    def name(self) -> builtins.str:
        return jsii.get(self, "name")

    @name.setter # type: ignore
    def name(self, value: builtins.str) -> None:
        jsii.set(self, "name", value)

    @builtins.property # type: ignore
    @jsii.member(jsii_name="pathPattern")
    def path_pattern(self) -> builtins.str:
        return jsii.get(self, "pathPattern")

    @path_pattern.setter # type: ignore
    def path_pattern(self, value: builtins.str) -> None:
        jsii.set(self, "pathPattern", value)

    @builtins.property # type: ignore
    @jsii.member(jsii_name="resourceGroupName")
    def resource_group_name(self) -> builtins.str:
        return jsii.get(self, "resourceGroupName")

    @resource_group_name.setter # type: ignore
    def resource_group_name(self, value: builtins.str) -> None:
        jsii.set(self, "resourceGroupName", value)

    @builtins.property # type: ignore
    @jsii.member(jsii_name="serialization")
    def serialization(
        self,
    ) -> typing.List["StreamAnalyticsReferenceInputBlobSerialization"]:
        return jsii.get(self, "serialization")

    @serialization.setter # type: ignore
    def serialization(
        self,
        value: typing.List["StreamAnalyticsReferenceInputBlobSerialization"],
    ) -> None:
        jsii.set(self, "serialization", value)

    @builtins.property # type: ignore
    @jsii.member(jsii_name="storageAccountKey")
    def storage_account_key(self) -> builtins.str:
        return jsii.get(self, "storageAccountKey")

    @storage_account_key.setter # type: ignore
    def storage_account_key(self, value: builtins.str) -> None:
        jsii.set(self, "storageAccountKey", value)

    @builtins.property # type: ignore
    @jsii.member(jsii_name="storageAccountName")
    def storage_account_name(self) -> builtins.str:
        return jsii.get(self, "storageAccountName")

    @storage_account_name.setter # type: ignore
    def storage_account_name(self, value: builtins.str) -> None:
        jsii.set(self, "storageAccountName", value)

    @builtins.property # type: ignore
    @jsii.member(jsii_name="storageContainerName")
    def storage_container_name(self) -> builtins.str:
        return jsii.get(self, "storageContainerName")

    @storage_container_name.setter # type: ignore
    def storage_container_name(self, value: builtins.str) -> None:
        jsii.set(self, "storageContainerName", value)

    @builtins.property # type: ignore
    @jsii.member(jsii_name="streamAnalyticsJobName")
    def stream_analytics_job_name(self) -> builtins.str:
        return jsii.get(self, "streamAnalyticsJobName")

    @stream_analytics_job_name.setter # type: ignore
    def stream_analytics_job_name(self, value: builtins.str) -> None:
        jsii.set(self, "streamAnalyticsJobName", value)

    @builtins.property # type: ignore
    @jsii.member(jsii_name="timeFormat")
    def time_format(self) -> builtins.str:
        return jsii.get(self, "timeFormat")

    @time_format.setter # type: ignore
    def time_format(self, value: builtins.str) -> None:
        jsii.set(self, "timeFormat", value)

    @builtins.property # type: ignore
    @jsii.member(jsii_name="id")
    def id(self) -> typing.Optional[builtins.str]:
        return jsii.get(self, "id")

    @id.setter # type: ignore
    def id(self, value: typing.Optional[builtins.str]) -> None:
        jsii.set(self, "id", value)

    @builtins.property # type: ignore
    @jsii.member(jsii_name="timeouts")
    def timeouts(self) -> typing.Optional["StreamAnalyticsReferenceInputBlobTimeouts"]:
        return jsii.get(self, "timeouts")

    @timeouts.setter # type: ignore
    def timeouts(
        self,
        value: typing.Optional["StreamAnalyticsReferenceInputBlobTimeouts"],
    ) -> None:
        jsii.set(self, "timeouts", value)


@jsii.data_type(
    jsii_type="@cdktf/provider-azurerm.StreamAnalyticsReferenceInputBlobConfig",
    jsii_struct_bases=[cdktf.TerraformMetaArguments],
    name_mapping={
        "count": "count",
        "depends_on": "dependsOn",
        "lifecycle": "lifecycle",
        "provider": "provider",
        "date_format": "dateFormat",
        "name": "name",
        "path_pattern": "pathPattern",
        "resource_group_name": "resourceGroupName",
        "serialization": "serialization",
        "storage_account_key": "storageAccountKey",
        "storage_account_name": "storageAccountName",
        "storage_container_name": "storageContainerName",
        "stream_analytics_job_name": "streamAnalyticsJobName",
        "time_format": "timeFormat",
        "timeouts": "timeouts",
    },
)
class StreamAnalyticsReferenceInputBlobConfig(cdktf.TerraformMetaArguments):
    def __init__(
        self,
        *,
        count: typing.Optional[jsii.Number] = None,
        depends_on: typing.Optional[typing.List[cdktf.TerraformResource]] = None,
        lifecycle: typing.Optional[cdktf.TerraformResourceLifecycle] = None,
        provider: typing.Optional[cdktf.TerraformProvider] = None,
        date_format: builtins.str,
        name: builtins.str,
        path_pattern: builtins.str,
        resource_group_name: builtins.str,
        serialization: typing.List["StreamAnalyticsReferenceInputBlobSerialization"],
        storage_account_key: builtins.str,
        storage_account_name: builtins.str,
        storage_container_name: builtins.str,
        stream_analytics_job_name: builtins.str,
        time_format: builtins.str,
        timeouts: typing.Optional["StreamAnalyticsReferenceInputBlobTimeouts"] = None,
    ) -> None:
        """
        :param count: 
        :param depends_on: 
        :param lifecycle: 
        :param provider: 
        :param date_format: 
        :param name: 
        :param path_pattern: 
        :param resource_group_name: 
        :param serialization: serialization block.
        :param storage_account_key: 
        :param storage_account_name: 
        :param storage_container_name: 
        :param stream_analytics_job_name: 
        :param time_format: 
        :param timeouts: timeouts block.
        """
        if isinstance(lifecycle, dict):
            lifecycle = cdktf.TerraformResourceLifecycle(**lifecycle)
        if isinstance(timeouts, dict):
            timeouts = StreamAnalyticsReferenceInputBlobTimeouts(**timeouts)
        self._values: typing.Dict[str, typing.Any] = {
            "date_format": date_format,
            "name": name,
            "path_pattern": path_pattern,
            "resource_group_name": resource_group_name,
            "serialization": serialization,
            "storage_account_key": storage_account_key,
            "storage_account_name": storage_account_name,
            "storage_container_name": storage_container_name,
            "stream_analytics_job_name": stream_analytics_job_name,
            "time_format": time_format,
        }
        if count is not None:
            self._values["count"] = count
        if depends_on is not None:
            self._values["depends_on"] = depends_on
        if lifecycle is not None:
            self._values["lifecycle"] = lifecycle
        if provider is not None:
            self._values["provider"] = provider
        if timeouts is not None:
            self._values["timeouts"] = timeouts

    @builtins.property
    def count(self) -> typing.Optional[jsii.Number]:
        """
        :stability: experimental
        """
        result = self._values.get("count")
        return result

    @builtins.property
    def depends_on(self) -> typing.Optional[typing.List[cdktf.TerraformResource]]:
        """
        :stability: experimental
        """
        result = self._values.get("depends_on")
        return result

    @builtins.property
    def lifecycle(self) -> typing.Optional[cdktf.TerraformResourceLifecycle]:
        """
        :stability: experimental
        """
        result = self._values.get("lifecycle")
        return result

    @builtins.property
    def provider(self) -> typing.Optional[cdktf.TerraformProvider]:
        """
        :stability: experimental
        """
        result = self._values.get("provider")
        return result

    @builtins.property
    def date_format(self) -> builtins.str:
        result = self._values.get("date_format")
        assert result is not None, "Required property 'date_format' is missing"
        return result

    @builtins.property
    def name(self) -> builtins.str:
        result = self._values.get("name")
        assert result is not None, "Required property 'name' is missing"
        return result

    @builtins.property
    def path_pattern(self) -> builtins.str:
        result = self._values.get("path_pattern")
        assert result is not None, "Required property 'path_pattern' is missing"
        return result

    @builtins.property
    def resource_group_name(self) -> builtins.str:
        result = self._values.get("resource_group_name")
        assert result is not None, "Required property 'resource_group_name' is missing"
        return result

    @builtins.property
    def serialization(
        self,
    ) -> typing.List["StreamAnalyticsReferenceInputBlobSerialization"]:
        """serialization block."""
        result = self._values.get("serialization")
        assert result is not None, "Required property 'serialization' is missing"
        return result

    @builtins.property
    def storage_account_key(self) -> builtins.str:
        result = self._values.get("storage_account_key")
        assert result is not None, "Required property 'storage_account_key' is missing"
        return result

    @builtins.property
    def storage_account_name(self) -> builtins.str:
        result = self._values.get("storage_account_name")
        assert result is not None, "Required property 'storage_account_name' is missing"
        return result

    @builtins.property
    def storage_container_name(self) -> builtins.str:
        result = self._values.get("storage_container_name")
        assert result is not None, "Required property 'storage_container_name' is missing"
        return result

    @builtins.property
    def stream_analytics_job_name(self) -> builtins.str:
        result = self._values.get("stream_analytics_job_name")
        assert result is not None, "Required property 'stream_analytics_job_name' is missing"
        return result

    @builtins.property
    def time_format(self) -> builtins.str:
        result = self._values.get("time_format")
        assert result is not None, "Required property 'time_format' is missing"
        return result

    @builtins.property
    def timeouts(self) -> typing.Optional["StreamAnalyticsReferenceInputBlobTimeouts"]:
        """timeouts block."""
        result = self._values.get("timeouts")
        return result

    def __eq__(self, rhs: typing.Any) -> builtins.bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs: typing.Any) -> builtins.bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return "StreamAnalyticsReferenceInputBlobConfig(%s)" % ", ".join(
            k + "=" + repr(v) for k, v in self._values.items()
        )


@jsii.data_type(
    jsii_type="@cdktf/provider-azurerm.StreamAnalyticsReferenceInputBlobSerialization",
    jsii_struct_bases=[],
    name_mapping={
        "type": "type",
        "encoding": "encoding",
        "field_delimiter": "fieldDelimiter",
    },
)
class StreamAnalyticsReferenceInputBlobSerialization:
    def __init__(
        self,
        *,
        type: builtins.str,
        encoding: typing.Optional[builtins.str] = None,
        field_delimiter: typing.Optional[builtins.str] = None,
    ) -> None:
        """
        :param type: 
        :param encoding: 
        :param field_delimiter: 
        """
        self._values: typing.Dict[str, typing.Any] = {
            "type": type,
        }
        if encoding is not None:
            self._values["encoding"] = encoding
        if field_delimiter is not None:
            self._values["field_delimiter"] = field_delimiter

    @builtins.property
    def type(self) -> builtins.str:
        result = self._values.get("type")
        assert result is not None, "Required property 'type' is missing"
        return result

    @builtins.property
    def encoding(self) -> typing.Optional[builtins.str]:
        result = self._values.get("encoding")
        return result

    @builtins.property
    def field_delimiter(self) -> typing.Optional[builtins.str]:
        result = self._values.get("field_delimiter")
        return result

    def __eq__(self, rhs: typing.Any) -> builtins.bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs: typing.Any) -> builtins.bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return "StreamAnalyticsReferenceInputBlobSerialization(%s)" % ", ".join(
            k + "=" + repr(v) for k, v in self._values.items()
        )


@jsii.data_type(
    jsii_type="@cdktf/provider-azurerm.StreamAnalyticsReferenceInputBlobTimeouts",
    jsii_struct_bases=[],
    name_mapping={
        "create": "create",
        "delete": "delete",
        "read": "read",
        "update": "update",
    },
)
class StreamAnalyticsReferenceInputBlobTimeouts:
    def __init__(
        self,
        *,
        create: typing.Optional[builtins.str] = None,
        delete: typing.Optional[builtins.str] = None,
        read: typing.Optional[builtins.str] = None,
        update: typing.Optional[builtins.str] = None,
    ) -> None:
        """
        :param create: 
        :param delete: 
        :param read: 
        :param update: 
        """
        self._values: typing.Dict[str, typing.Any] = {}
        if create is not None:
            self._values["create"] = create
        if delete is not None:
            self._values["delete"] = delete
        if read is not None:
            self._values["read"] = read
        if update is not None:
            self._values["update"] = update

    @builtins.property
    def create(self) -> typing.Optional[builtins.str]:
        result = self._values.get("create")
        return result

    @builtins.property
    def delete(self) -> typing.Optional[builtins.str]:
        result = self._values.get("delete")
        return result

    @builtins.property
    def read(self) -> typing.Optional[builtins.str]:
        result = self._values.get("read")
        return result

    @builtins.property
    def update(self) -> typing.Optional[builtins.str]:
        result = self._values.get("update")
        return result

    def __eq__(self, rhs: typing.Any) -> builtins.bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs: typing.Any) -> builtins.bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return "StreamAnalyticsReferenceInputBlobTimeouts(%s)" % ", ".join(
            k + "=" + repr(v) for k, v in self._values.items()
        )


class StreamAnalyticsStreamInputBlob(
    cdktf.TerraformResource,
    metaclass=jsii.JSIIMeta,
    jsii_type="@cdktf/provider-azurerm.StreamAnalyticsStreamInputBlob",
):
    def __init__(
        self,
        scope: constructs.Construct,
        id: builtins.str,
        *,
        date_format: builtins.str,
        name: builtins.str,
        path_pattern: builtins.str,
        resource_group_name: builtins.str,
        serialization: typing.List["StreamAnalyticsStreamInputBlobSerialization"],
        storage_account_key: builtins.str,
        storage_account_name: builtins.str,
        storage_container_name: builtins.str,
        stream_analytics_job_name: builtins.str,
        time_format: builtins.str,
        timeouts: typing.Optional["StreamAnalyticsStreamInputBlobTimeouts"] = None,
        count: typing.Optional[jsii.Number] = None,
        depends_on: typing.Optional[typing.List[cdktf.TerraformResource]] = None,
        lifecycle: typing.Optional[cdktf.TerraformResourceLifecycle] = None,
        provider: typing.Optional[cdktf.TerraformProvider] = None,
    ) -> None:
        """
        :param scope: -
        :param id: -
        :param date_format: 
        :param name: 
        :param path_pattern: 
        :param resource_group_name: 
        :param serialization: serialization block.
        :param storage_account_key: 
        :param storage_account_name: 
        :param storage_container_name: 
        :param stream_analytics_job_name: 
        :param time_format: 
        :param timeouts: timeouts block.
        :param count: 
        :param depends_on: 
        :param lifecycle: 
        :param provider: 
        """
        config = StreamAnalyticsStreamInputBlobConfig(
            date_format=date_format,
            name=name,
            path_pattern=path_pattern,
            resource_group_name=resource_group_name,
            serialization=serialization,
            storage_account_key=storage_account_key,
            storage_account_name=storage_account_name,
            storage_container_name=storage_container_name,
            stream_analytics_job_name=stream_analytics_job_name,
            time_format=time_format,
            timeouts=timeouts,
            count=count,
            depends_on=depends_on,
            lifecycle=lifecycle,
            provider=provider,
        )

        jsii.create(StreamAnalyticsStreamInputBlob, self, [scope, id, config])

    @jsii.member(jsii_name="synthesizeAttributes")
    def _synthesize_attributes(self) -> typing.Mapping[builtins.str, typing.Any]:
        return jsii.invoke(self, "synthesizeAttributes", [])

    @builtins.property # type: ignore
    @jsii.member(jsii_name="dateFormat")
    def date_format(self) -> builtins.str:
        return jsii.get(self, "dateFormat")

    @date_format.setter # type: ignore
    def date_format(self, value: builtins.str) -> None:
        jsii.set(self, "dateFormat", value)

    @builtins.property # type: ignore
    @jsii.member(jsii_name="name")
    def name(self) -> builtins.str:
        return jsii.get(self, "name")

    @name.setter # type: ignore
    def name(self, value: builtins.str) -> None:
        jsii.set(self, "name", value)

    @builtins.property # type: ignore
    @jsii.member(jsii_name="pathPattern")
    def path_pattern(self) -> builtins.str:
        return jsii.get(self, "pathPattern")

    @path_pattern.setter # type: ignore
    def path_pattern(self, value: builtins.str) -> None:
        jsii.set(self, "pathPattern", value)

    @builtins.property # type: ignore
    @jsii.member(jsii_name="resourceGroupName")
    def resource_group_name(self) -> builtins.str:
        return jsii.get(self, "resourceGroupName")

    @resource_group_name.setter # type: ignore
    def resource_group_name(self, value: builtins.str) -> None:
        jsii.set(self, "resourceGroupName", value)

    @builtins.property # type: ignore
    @jsii.member(jsii_name="serialization")
    def serialization(
        self,
    ) -> typing.List["StreamAnalyticsStreamInputBlobSerialization"]:
        return jsii.get(self, "serialization")

    @serialization.setter # type: ignore
    def serialization(
        self,
        value: typing.List["StreamAnalyticsStreamInputBlobSerialization"],
    ) -> None:
        jsii.set(self, "serialization", value)

    @builtins.property # type: ignore
    @jsii.member(jsii_name="storageAccountKey")
    def storage_account_key(self) -> builtins.str:
        return jsii.get(self, "storageAccountKey")

    @storage_account_key.setter # type: ignore
    def storage_account_key(self, value: builtins.str) -> None:
        jsii.set(self, "storageAccountKey", value)

    @builtins.property # type: ignore
    @jsii.member(jsii_name="storageAccountName")
    def storage_account_name(self) -> builtins.str:
        return jsii.get(self, "storageAccountName")

    @storage_account_name.setter # type: ignore
    def storage_account_name(self, value: builtins.str) -> None:
        jsii.set(self, "storageAccountName", value)

    @builtins.property # type: ignore
    @jsii.member(jsii_name="storageContainerName")
    def storage_container_name(self) -> builtins.str:
        return jsii.get(self, "storageContainerName")

    @storage_container_name.setter # type: ignore
    def storage_container_name(self, value: builtins.str) -> None:
        jsii.set(self, "storageContainerName", value)

    @builtins.property # type: ignore
    @jsii.member(jsii_name="streamAnalyticsJobName")
    def stream_analytics_job_name(self) -> builtins.str:
        return jsii.get(self, "streamAnalyticsJobName")

    @stream_analytics_job_name.setter # type: ignore
    def stream_analytics_job_name(self, value: builtins.str) -> None:
        jsii.set(self, "streamAnalyticsJobName", value)

    @builtins.property # type: ignore
    @jsii.member(jsii_name="timeFormat")
    def time_format(self) -> builtins.str:
        return jsii.get(self, "timeFormat")

    @time_format.setter # type: ignore
    def time_format(self, value: builtins.str) -> None:
        jsii.set(self, "timeFormat", value)

    @builtins.property # type: ignore
    @jsii.member(jsii_name="id")
    def id(self) -> typing.Optional[builtins.str]:
        return jsii.get(self, "id")

    @id.setter # type: ignore
    def id(self, value: typing.Optional[builtins.str]) -> None:
        jsii.set(self, "id", value)

    @builtins.property # type: ignore
    @jsii.member(jsii_name="timeouts")
    def timeouts(self) -> typing.Optional["StreamAnalyticsStreamInputBlobTimeouts"]:
        return jsii.get(self, "timeouts")

    @timeouts.setter # type: ignore
    def timeouts(
        self,
        value: typing.Optional["StreamAnalyticsStreamInputBlobTimeouts"],
    ) -> None:
        jsii.set(self, "timeouts", value)


@jsii.data_type(
    jsii_type="@cdktf/provider-azurerm.StreamAnalyticsStreamInputBlobConfig",
    jsii_struct_bases=[cdktf.TerraformMetaArguments],
    name_mapping={
        "count": "count",
        "depends_on": "dependsOn",
        "lifecycle": "lifecycle",
        "provider": "provider",
        "date_format": "dateFormat",
        "name": "name",
        "path_pattern": "pathPattern",
        "resource_group_name": "resourceGroupName",
        "serialization": "serialization",
        "storage_account_key": "storageAccountKey",
        "storage_account_name": "storageAccountName",
        "storage_container_name": "storageContainerName",
        "stream_analytics_job_name": "streamAnalyticsJobName",
        "time_format": "timeFormat",
        "timeouts": "timeouts",
    },
)
class StreamAnalyticsStreamInputBlobConfig(cdktf.TerraformMetaArguments):
    def __init__(
        self,
        *,
        count: typing.Optional[jsii.Number] = None,
        depends_on: typing.Optional[typing.List[cdktf.TerraformResource]] = None,
        lifecycle: typing.Optional[cdktf.TerraformResourceLifecycle] = None,
        provider: typing.Optional[cdktf.TerraformProvider] = None,
        date_format: builtins.str,
        name: builtins.str,
        path_pattern: builtins.str,
        resource_group_name: builtins.str,
        serialization: typing.List["StreamAnalyticsStreamInputBlobSerialization"],
        storage_account_key: builtins.str,
        storage_account_name: builtins.str,
        storage_container_name: builtins.str,
        stream_analytics_job_name: builtins.str,
        time_format: builtins.str,
        timeouts: typing.Optional["StreamAnalyticsStreamInputBlobTimeouts"] = None,
    ) -> None:
        """
        :param count: 
        :param depends_on: 
        :param lifecycle: 
        :param provider: 
        :param date_format: 
        :param name: 
        :param path_pattern: 
        :param resource_group_name: 
        :param serialization: serialization block.
        :param storage_account_key: 
        :param storage_account_name: 
        :param storage_container_name: 
        :param stream_analytics_job_name: 
        :param time_format: 
        :param timeouts: timeouts block.
        """
        if isinstance(lifecycle, dict):
            lifecycle = cdktf.TerraformResourceLifecycle(**lifecycle)
        if isinstance(timeouts, dict):
            timeouts = StreamAnalyticsStreamInputBlobTimeouts(**timeouts)
        self._values: typing.Dict[str, typing.Any] = {
            "date_format": date_format,
            "name": name,
            "path_pattern": path_pattern,
            "resource_group_name": resource_group_name,
            "serialization": serialization,
            "storage_account_key": storage_account_key,
            "storage_account_name": storage_account_name,
            "storage_container_name": storage_container_name,
            "stream_analytics_job_name": stream_analytics_job_name,
            "time_format": time_format,
        }
        if count is not None:
            self._values["count"] = count
        if depends_on is not None:
            self._values["depends_on"] = depends_on
        if lifecycle is not None:
            self._values["lifecycle"] = lifecycle
        if provider is not None:
            self._values["provider"] = provider
        if timeouts is not None:
            self._values["timeouts"] = timeouts

    @builtins.property
    def count(self) -> typing.Optional[jsii.Number]:
        """
        :stability: experimental
        """
        result = self._values.get("count")
        return result

    @builtins.property
    def depends_on(self) -> typing.Optional[typing.List[cdktf.TerraformResource]]:
        """
        :stability: experimental
        """
        result = self._values.get("depends_on")
        return result

    @builtins.property
    def lifecycle(self) -> typing.Optional[cdktf.TerraformResourceLifecycle]:
        """
        :stability: experimental
        """
        result = self._values.get("lifecycle")
        return result

    @builtins.property
    def provider(self) -> typing.Optional[cdktf.TerraformProvider]:
        """
        :stability: experimental
        """
        result = self._values.get("provider")
        return result

    @builtins.property
    def date_format(self) -> builtins.str:
        result = self._values.get("date_format")
        assert result is not None, "Required property 'date_format' is missing"
        return result

    @builtins.property
    def name(self) -> builtins.str:
        result = self._values.get("name")
        assert result is not None, "Required property 'name' is missing"
        return result

    @builtins.property
    def path_pattern(self) -> builtins.str:
        result = self._values.get("path_pattern")
        assert result is not None, "Required property 'path_pattern' is missing"
        return result

    @builtins.property
    def resource_group_name(self) -> builtins.str:
        result = self._values.get("resource_group_name")
        assert result is not None, "Required property 'resource_group_name' is missing"
        return result

    @builtins.property
    def serialization(
        self,
    ) -> typing.List["StreamAnalyticsStreamInputBlobSerialization"]:
        """serialization block."""
        result = self._values.get("serialization")
        assert result is not None, "Required property 'serialization' is missing"
        return result

    @builtins.property
    def storage_account_key(self) -> builtins.str:
        result = self._values.get("storage_account_key")
        assert result is not None, "Required property 'storage_account_key' is missing"
        return result

    @builtins.property
    def storage_account_name(self) -> builtins.str:
        result = self._values.get("storage_account_name")
        assert result is not None, "Required property 'storage_account_name' is missing"
        return result

    @builtins.property
    def storage_container_name(self) -> builtins.str:
        result = self._values.get("storage_container_name")
        assert result is not None, "Required property 'storage_container_name' is missing"
        return result

    @builtins.property
    def stream_analytics_job_name(self) -> builtins.str:
        result = self._values.get("stream_analytics_job_name")
        assert result is not None, "Required property 'stream_analytics_job_name' is missing"
        return result

    @builtins.property
    def time_format(self) -> builtins.str:
        result = self._values.get("time_format")
        assert result is not None, "Required property 'time_format' is missing"
        return result

    @builtins.property
    def timeouts(self) -> typing.Optional["StreamAnalyticsStreamInputBlobTimeouts"]:
        """timeouts block."""
        result = self._values.get("timeouts")
        return result

    def __eq__(self, rhs: typing.Any) -> builtins.bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs: typing.Any) -> builtins.bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return "StreamAnalyticsStreamInputBlobConfig(%s)" % ", ".join(
            k + "=" + repr(v) for k, v in self._values.items()
        )


@jsii.data_type(
    jsii_type="@cdktf/provider-azurerm.StreamAnalyticsStreamInputBlobSerialization",
    jsii_struct_bases=[],
    name_mapping={
        "type": "type",
        "encoding": "encoding",
        "field_delimiter": "fieldDelimiter",
    },
)
class StreamAnalyticsStreamInputBlobSerialization:
    def __init__(
        self,
        *,
        type: builtins.str,
        encoding: typing.Optional[builtins.str] = None,
        field_delimiter: typing.Optional[builtins.str] = None,
    ) -> None:
        """
        :param type: 
        :param encoding: 
        :param field_delimiter: 
        """
        self._values: typing.Dict[str, typing.Any] = {
            "type": type,
        }
        if encoding is not None:
            self._values["encoding"] = encoding
        if field_delimiter is not None:
            self._values["field_delimiter"] = field_delimiter

    @builtins.property
    def type(self) -> builtins.str:
        result = self._values.get("type")
        assert result is not None, "Required property 'type' is missing"
        return result

    @builtins.property
    def encoding(self) -> typing.Optional[builtins.str]:
        result = self._values.get("encoding")
        return result

    @builtins.property
    def field_delimiter(self) -> typing.Optional[builtins.str]:
        result = self._values.get("field_delimiter")
        return result

    def __eq__(self, rhs: typing.Any) -> builtins.bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs: typing.Any) -> builtins.bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return "StreamAnalyticsStreamInputBlobSerialization(%s)" % ", ".join(
            k + "=" + repr(v) for k, v in self._values.items()
        )


@jsii.data_type(
    jsii_type="@cdktf/provider-azurerm.StreamAnalyticsStreamInputBlobTimeouts",
    jsii_struct_bases=[],
    name_mapping={
        "create": "create",
        "delete": "delete",
        "read": "read",
        "update": "update",
    },
)
class StreamAnalyticsStreamInputBlobTimeouts:
    def __init__(
        self,
        *,
        create: typing.Optional[builtins.str] = None,
        delete: typing.Optional[builtins.str] = None,
        read: typing.Optional[builtins.str] = None,
        update: typing.Optional[builtins.str] = None,
    ) -> None:
        """
        :param create: 
        :param delete: 
        :param read: 
        :param update: 
        """
        self._values: typing.Dict[str, typing.Any] = {}
        if create is not None:
            self._values["create"] = create
        if delete is not None:
            self._values["delete"] = delete
        if read is not None:
            self._values["read"] = read
        if update is not None:
            self._values["update"] = update

    @builtins.property
    def create(self) -> typing.Optional[builtins.str]:
        result = self._values.get("create")
        return result

    @builtins.property
    def delete(self) -> typing.Optional[builtins.str]:
        result = self._values.get("delete")
        return result

    @builtins.property
    def read(self) -> typing.Optional[builtins.str]:
        result = self._values.get("read")
        return result

    @builtins.property
    def update(self) -> typing.Optional[builtins.str]:
        result = self._values.get("update")
        return result

    def __eq__(self, rhs: typing.Any) -> builtins.bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs: typing.Any) -> builtins.bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return "StreamAnalyticsStreamInputBlobTimeouts(%s)" % ", ".join(
            k + "=" + repr(v) for k, v in self._values.items()
        )


class StreamAnalyticsStreamInputEventhub(
    cdktf.TerraformResource,
    metaclass=jsii.JSIIMeta,
    jsii_type="@cdktf/provider-azurerm.StreamAnalyticsStreamInputEventhub",
):
    def __init__(
        self,
        scope: constructs.Construct,
        id: builtins.str,
        *,
        eventhub_consumer_group_name: builtins.str,
        eventhub_name: builtins.str,
        name: builtins.str,
        resource_group_name: builtins.str,
        serialization: typing.List["StreamAnalyticsStreamInputEventhubSerialization"],
        servicebus_namespace: builtins.str,
        shared_access_policy_key: builtins.str,
        shared_access_policy_name: builtins.str,
        stream_analytics_job_name: builtins.str,
        timeouts: typing.Optional["StreamAnalyticsStreamInputEventhubTimeouts"] = None,
        count: typing.Optional[jsii.Number] = None,
        depends_on: typing.Optional[typing.List[cdktf.TerraformResource]] = None,
        lifecycle: typing.Optional[cdktf.TerraformResourceLifecycle] = None,
        provider: typing.Optional[cdktf.TerraformProvider] = None,
    ) -> None:
        """
        :param scope: -
        :param id: -
        :param eventhub_consumer_group_name: 
        :param eventhub_name: 
        :param name: 
        :param resource_group_name: 
        :param serialization: serialization block.
        :param servicebus_namespace: 
        :param shared_access_policy_key: 
        :param shared_access_policy_name: 
        :param stream_analytics_job_name: 
        :param timeouts: timeouts block.
        :param count: 
        :param depends_on: 
        :param lifecycle: 
        :param provider: 
        """
        config = StreamAnalyticsStreamInputEventhubConfig(
            eventhub_consumer_group_name=eventhub_consumer_group_name,
            eventhub_name=eventhub_name,
            name=name,
            resource_group_name=resource_group_name,
            serialization=serialization,
            servicebus_namespace=servicebus_namespace,
            shared_access_policy_key=shared_access_policy_key,
            shared_access_policy_name=shared_access_policy_name,
            stream_analytics_job_name=stream_analytics_job_name,
            timeouts=timeouts,
            count=count,
            depends_on=depends_on,
            lifecycle=lifecycle,
            provider=provider,
        )

        jsii.create(StreamAnalyticsStreamInputEventhub, self, [scope, id, config])

    @jsii.member(jsii_name="synthesizeAttributes")
    def _synthesize_attributes(self) -> typing.Mapping[builtins.str, typing.Any]:
        return jsii.invoke(self, "synthesizeAttributes", [])

    @builtins.property # type: ignore
    @jsii.member(jsii_name="eventhubConsumerGroupName")
    def eventhub_consumer_group_name(self) -> builtins.str:
        return jsii.get(self, "eventhubConsumerGroupName")

    @eventhub_consumer_group_name.setter # type: ignore
    def eventhub_consumer_group_name(self, value: builtins.str) -> None:
        jsii.set(self, "eventhubConsumerGroupName", value)

    @builtins.property # type: ignore
    @jsii.member(jsii_name="eventhubName")
    def eventhub_name(self) -> builtins.str:
        return jsii.get(self, "eventhubName")

    @eventhub_name.setter # type: ignore
    def eventhub_name(self, value: builtins.str) -> None:
        jsii.set(self, "eventhubName", value)

    @builtins.property # type: ignore
    @jsii.member(jsii_name="name")
    def name(self) -> builtins.str:
        return jsii.get(self, "name")

    @name.setter # type: ignore
    def name(self, value: builtins.str) -> None:
        jsii.set(self, "name", value)

    @builtins.property # type: ignore
    @jsii.member(jsii_name="resourceGroupName")
    def resource_group_name(self) -> builtins.str:
        return jsii.get(self, "resourceGroupName")

    @resource_group_name.setter # type: ignore
    def resource_group_name(self, value: builtins.str) -> None:
        jsii.set(self, "resourceGroupName", value)

    @builtins.property # type: ignore
    @jsii.member(jsii_name="serialization")
    def serialization(
        self,
    ) -> typing.List["StreamAnalyticsStreamInputEventhubSerialization"]:
        return jsii.get(self, "serialization")

    @serialization.setter # type: ignore
    def serialization(
        self,
        value: typing.List["StreamAnalyticsStreamInputEventhubSerialization"],
    ) -> None:
        jsii.set(self, "serialization", value)

    @builtins.property # type: ignore
    @jsii.member(jsii_name="servicebusNamespace")
    def servicebus_namespace(self) -> builtins.str:
        return jsii.get(self, "servicebusNamespace")

    @servicebus_namespace.setter # type: ignore
    def servicebus_namespace(self, value: builtins.str) -> None:
        jsii.set(self, "servicebusNamespace", value)

    @builtins.property # type: ignore
    @jsii.member(jsii_name="sharedAccessPolicyKey")
    def shared_access_policy_key(self) -> builtins.str:
        return jsii.get(self, "sharedAccessPolicyKey")

    @shared_access_policy_key.setter # type: ignore
    def shared_access_policy_key(self, value: builtins.str) -> None:
        jsii.set(self, "sharedAccessPolicyKey", value)

    @builtins.property # type: ignore
    @jsii.member(jsii_name="sharedAccessPolicyName")
    def shared_access_policy_name(self) -> builtins.str:
        return jsii.get(self, "sharedAccessPolicyName")

    @shared_access_policy_name.setter # type: ignore
    def shared_access_policy_name(self, value: builtins.str) -> None:
        jsii.set(self, "sharedAccessPolicyName", value)

    @builtins.property # type: ignore
    @jsii.member(jsii_name="streamAnalyticsJobName")
    def stream_analytics_job_name(self) -> builtins.str:
        return jsii.get(self, "streamAnalyticsJobName")

    @stream_analytics_job_name.setter # type: ignore
    def stream_analytics_job_name(self, value: builtins.str) -> None:
        jsii.set(self, "streamAnalyticsJobName", value)

    @builtins.property # type: ignore
    @jsii.member(jsii_name="id")
    def id(self) -> typing.Optional[builtins.str]:
        return jsii.get(self, "id")

    @id.setter # type: ignore
    def id(self, value: typing.Optional[builtins.str]) -> None:
        jsii.set(self, "id", value)

    @builtins.property # type: ignore
    @jsii.member(jsii_name="timeouts")
    def timeouts(self) -> typing.Optional["StreamAnalyticsStreamInputEventhubTimeouts"]:
        return jsii.get(self, "timeouts")

    @timeouts.setter # type: ignore
    def timeouts(
        self,
        value: typing.Optional["StreamAnalyticsStreamInputEventhubTimeouts"],
    ) -> None:
        jsii.set(self, "timeouts", value)


@jsii.data_type(
    jsii_type="@cdktf/provider-azurerm.StreamAnalyticsStreamInputEventhubConfig",
    jsii_struct_bases=[cdktf.TerraformMetaArguments],
    name_mapping={
        "count": "count",
        "depends_on": "dependsOn",
        "lifecycle": "lifecycle",
        "provider": "provider",
        "eventhub_consumer_group_name": "eventhubConsumerGroupName",
        "eventhub_name": "eventhubName",
        "name": "name",
        "resource_group_name": "resourceGroupName",
        "serialization": "serialization",
        "servicebus_namespace": "servicebusNamespace",
        "shared_access_policy_key": "sharedAccessPolicyKey",
        "shared_access_policy_name": "sharedAccessPolicyName",
        "stream_analytics_job_name": "streamAnalyticsJobName",
        "timeouts": "timeouts",
    },
)
class StreamAnalyticsStreamInputEventhubConfig(cdktf.TerraformMetaArguments):
    def __init__(
        self,
        *,
        count: typing.Optional[jsii.Number] = None,
        depends_on: typing.Optional[typing.List[cdktf.TerraformResource]] = None,
        lifecycle: typing.Optional[cdktf.TerraformResourceLifecycle] = None,
        provider: typing.Optional[cdktf.TerraformProvider] = None,
        eventhub_consumer_group_name: builtins.str,
        eventhub_name: builtins.str,
        name: builtins.str,
        resource_group_name: builtins.str,
        serialization: typing.List["StreamAnalyticsStreamInputEventhubSerialization"],
        servicebus_namespace: builtins.str,
        shared_access_policy_key: builtins.str,
        shared_access_policy_name: builtins.str,
        stream_analytics_job_name: builtins.str,
        timeouts: typing.Optional["StreamAnalyticsStreamInputEventhubTimeouts"] = None,
    ) -> None:
        """
        :param count: 
        :param depends_on: 
        :param lifecycle: 
        :param provider: 
        :param eventhub_consumer_group_name: 
        :param eventhub_name: 
        :param name: 
        :param resource_group_name: 
        :param serialization: serialization block.
        :param servicebus_namespace: 
        :param shared_access_policy_key: 
        :param shared_access_policy_name: 
        :param stream_analytics_job_name: 
        :param timeouts: timeouts block.
        """
        if isinstance(lifecycle, dict):
            lifecycle = cdktf.TerraformResourceLifecycle(**lifecycle)
        if isinstance(timeouts, dict):
            timeouts = StreamAnalyticsStreamInputEventhubTimeouts(**timeouts)
        self._values: typing.Dict[str, typing.Any] = {
            "eventhub_consumer_group_name": eventhub_consumer_group_name,
            "eventhub_name": eventhub_name,
            "name": name,
            "resource_group_name": resource_group_name,
            "serialization": serialization,
            "servicebus_namespace": servicebus_namespace,
            "shared_access_policy_key": shared_access_policy_key,
            "shared_access_policy_name": shared_access_policy_name,
            "stream_analytics_job_name": stream_analytics_job_name,
        }
        if count is not None:
            self._values["count"] = count
        if depends_on is not None:
            self._values["depends_on"] = depends_on
        if lifecycle is not None:
            self._values["lifecycle"] = lifecycle
        if provider is not None:
            self._values["provider"] = provider
        if timeouts is not None:
            self._values["timeouts"] = timeouts

    @builtins.property
    def count(self) -> typing.Optional[jsii.Number]:
        """
        :stability: experimental
        """
        result = self._values.get("count")
        return result

    @builtins.property
    def depends_on(self) -> typing.Optional[typing.List[cdktf.TerraformResource]]:
        """
        :stability: experimental
        """
        result = self._values.get("depends_on")
        return result

    @builtins.property
    def lifecycle(self) -> typing.Optional[cdktf.TerraformResourceLifecycle]:
        """
        :stability: experimental
        """
        result = self._values.get("lifecycle")
        return result

    @builtins.property
    def provider(self) -> typing.Optional[cdktf.TerraformProvider]:
        """
        :stability: experimental
        """
        result = self._values.get("provider")
        return result

    @builtins.property
    def eventhub_consumer_group_name(self) -> builtins.str:
        result = self._values.get("eventhub_consumer_group_name")
        assert result is not None, "Required property 'eventhub_consumer_group_name' is missing"
        return result

    @builtins.property
    def eventhub_name(self) -> builtins.str:
        result = self._values.get("eventhub_name")
        assert result is not None, "Required property 'eventhub_name' is missing"
        return result

    @builtins.property
    def name(self) -> builtins.str:
        result = self._values.get("name")
        assert result is not None, "Required property 'name' is missing"
        return result

    @builtins.property
    def resource_group_name(self) -> builtins.str:
        result = self._values.get("resource_group_name")
        assert result is not None, "Required property 'resource_group_name' is missing"
        return result

    @builtins.property
    def serialization(
        self,
    ) -> typing.List["StreamAnalyticsStreamInputEventhubSerialization"]:
        """serialization block."""
        result = self._values.get("serialization")
        assert result is not None, "Required property 'serialization' is missing"
        return result

    @builtins.property
    def servicebus_namespace(self) -> builtins.str:
        result = self._values.get("servicebus_namespace")
        assert result is not None, "Required property 'servicebus_namespace' is missing"
        return result

    @builtins.property
    def shared_access_policy_key(self) -> builtins.str:
        result = self._values.get("shared_access_policy_key")
        assert result is not None, "Required property 'shared_access_policy_key' is missing"
        return result

    @builtins.property
    def shared_access_policy_name(self) -> builtins.str:
        result = self._values.get("shared_access_policy_name")
        assert result is not None, "Required property 'shared_access_policy_name' is missing"
        return result

    @builtins.property
    def stream_analytics_job_name(self) -> builtins.str:
        result = self._values.get("stream_analytics_job_name")
        assert result is not None, "Required property 'stream_analytics_job_name' is missing"
        return result

    @builtins.property
    def timeouts(self) -> typing.Optional["StreamAnalyticsStreamInputEventhubTimeouts"]:
        """timeouts block."""
        result = self._values.get("timeouts")
        return result

    def __eq__(self, rhs: typing.Any) -> builtins.bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs: typing.Any) -> builtins.bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return "StreamAnalyticsStreamInputEventhubConfig(%s)" % ", ".join(
            k + "=" + repr(v) for k, v in self._values.items()
        )


@jsii.data_type(
    jsii_type="@cdktf/provider-azurerm.StreamAnalyticsStreamInputEventhubSerialization",
    jsii_struct_bases=[],
    name_mapping={
        "type": "type",
        "encoding": "encoding",
        "field_delimiter": "fieldDelimiter",
    },
)
class StreamAnalyticsStreamInputEventhubSerialization:
    def __init__(
        self,
        *,
        type: builtins.str,
        encoding: typing.Optional[builtins.str] = None,
        field_delimiter: typing.Optional[builtins.str] = None,
    ) -> None:
        """
        :param type: 
        :param encoding: 
        :param field_delimiter: 
        """
        self._values: typing.Dict[str, typing.Any] = {
            "type": type,
        }
        if encoding is not None:
            self._values["encoding"] = encoding
        if field_delimiter is not None:
            self._values["field_delimiter"] = field_delimiter

    @builtins.property
    def type(self) -> builtins.str:
        result = self._values.get("type")
        assert result is not None, "Required property 'type' is missing"
        return result

    @builtins.property
    def encoding(self) -> typing.Optional[builtins.str]:
        result = self._values.get("encoding")
        return result

    @builtins.property
    def field_delimiter(self) -> typing.Optional[builtins.str]:
        result = self._values.get("field_delimiter")
        return result

    def __eq__(self, rhs: typing.Any) -> builtins.bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs: typing.Any) -> builtins.bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return "StreamAnalyticsStreamInputEventhubSerialization(%s)" % ", ".join(
            k + "=" + repr(v) for k, v in self._values.items()
        )


@jsii.data_type(
    jsii_type="@cdktf/provider-azurerm.StreamAnalyticsStreamInputEventhubTimeouts",
    jsii_struct_bases=[],
    name_mapping={
        "create": "create",
        "delete": "delete",
        "read": "read",
        "update": "update",
    },
)
class StreamAnalyticsStreamInputEventhubTimeouts:
    def __init__(
        self,
        *,
        create: typing.Optional[builtins.str] = None,
        delete: typing.Optional[builtins.str] = None,
        read: typing.Optional[builtins.str] = None,
        update: typing.Optional[builtins.str] = None,
    ) -> None:
        """
        :param create: 
        :param delete: 
        :param read: 
        :param update: 
        """
        self._values: typing.Dict[str, typing.Any] = {}
        if create is not None:
            self._values["create"] = create
        if delete is not None:
            self._values["delete"] = delete
        if read is not None:
            self._values["read"] = read
        if update is not None:
            self._values["update"] = update

    @builtins.property
    def create(self) -> typing.Optional[builtins.str]:
        result = self._values.get("create")
        return result

    @builtins.property
    def delete(self) -> typing.Optional[builtins.str]:
        result = self._values.get("delete")
        return result

    @builtins.property
    def read(self) -> typing.Optional[builtins.str]:
        result = self._values.get("read")
        return result

    @builtins.property
    def update(self) -> typing.Optional[builtins.str]:
        result = self._values.get("update")
        return result

    def __eq__(self, rhs: typing.Any) -> builtins.bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs: typing.Any) -> builtins.bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return "StreamAnalyticsStreamInputEventhubTimeouts(%s)" % ", ".join(
            k + "=" + repr(v) for k, v in self._values.items()
        )


class StreamAnalyticsStreamInputIothub(
    cdktf.TerraformResource,
    metaclass=jsii.JSIIMeta,
    jsii_type="@cdktf/provider-azurerm.StreamAnalyticsStreamInputIothub",
):
    def __init__(
        self,
        scope: constructs.Construct,
        id: builtins.str,
        *,
        endpoint: builtins.str,
        eventhub_consumer_group_name: builtins.str,
        iothub_namespace: builtins.str,
        name: builtins.str,
        resource_group_name: builtins.str,
        serialization: typing.List["StreamAnalyticsStreamInputIothubSerialization"],
        shared_access_policy_key: builtins.str,
        shared_access_policy_name: builtins.str,
        stream_analytics_job_name: builtins.str,
        timeouts: typing.Optional["StreamAnalyticsStreamInputIothubTimeouts"] = None,
        count: typing.Optional[jsii.Number] = None,
        depends_on: typing.Optional[typing.List[cdktf.TerraformResource]] = None,
        lifecycle: typing.Optional[cdktf.TerraformResourceLifecycle] = None,
        provider: typing.Optional[cdktf.TerraformProvider] = None,
    ) -> None:
        """
        :param scope: -
        :param id: -
        :param endpoint: 
        :param eventhub_consumer_group_name: 
        :param iothub_namespace: 
        :param name: 
        :param resource_group_name: 
        :param serialization: serialization block.
        :param shared_access_policy_key: 
        :param shared_access_policy_name: 
        :param stream_analytics_job_name: 
        :param timeouts: timeouts block.
        :param count: 
        :param depends_on: 
        :param lifecycle: 
        :param provider: 
        """
        config = StreamAnalyticsStreamInputIothubConfig(
            endpoint=endpoint,
            eventhub_consumer_group_name=eventhub_consumer_group_name,
            iothub_namespace=iothub_namespace,
            name=name,
            resource_group_name=resource_group_name,
            serialization=serialization,
            shared_access_policy_key=shared_access_policy_key,
            shared_access_policy_name=shared_access_policy_name,
            stream_analytics_job_name=stream_analytics_job_name,
            timeouts=timeouts,
            count=count,
            depends_on=depends_on,
            lifecycle=lifecycle,
            provider=provider,
        )

        jsii.create(StreamAnalyticsStreamInputIothub, self, [scope, id, config])

    @jsii.member(jsii_name="synthesizeAttributes")
    def _synthesize_attributes(self) -> typing.Mapping[builtins.str, typing.Any]:
        return jsii.invoke(self, "synthesizeAttributes", [])

    @builtins.property # type: ignore
    @jsii.member(jsii_name="endpoint")
    def endpoint(self) -> builtins.str:
        return jsii.get(self, "endpoint")

    @endpoint.setter # type: ignore
    def endpoint(self, value: builtins.str) -> None:
        jsii.set(self, "endpoint", value)

    @builtins.property # type: ignore
    @jsii.member(jsii_name="eventhubConsumerGroupName")
    def eventhub_consumer_group_name(self) -> builtins.str:
        return jsii.get(self, "eventhubConsumerGroupName")

    @eventhub_consumer_group_name.setter # type: ignore
    def eventhub_consumer_group_name(self, value: builtins.str) -> None:
        jsii.set(self, "eventhubConsumerGroupName", value)

    @builtins.property # type: ignore
    @jsii.member(jsii_name="iothubNamespace")
    def iothub_namespace(self) -> builtins.str:
        return jsii.get(self, "iothubNamespace")

    @iothub_namespace.setter # type: ignore
    def iothub_namespace(self, value: builtins.str) -> None:
        jsii.set(self, "iothubNamespace", value)

    @builtins.property # type: ignore
    @jsii.member(jsii_name="name")
    def name(self) -> builtins.str:
        return jsii.get(self, "name")

    @name.setter # type: ignore
    def name(self, value: builtins.str) -> None:
        jsii.set(self, "name", value)

    @builtins.property # type: ignore
    @jsii.member(jsii_name="resourceGroupName")
    def resource_group_name(self) -> builtins.str:
        return jsii.get(self, "resourceGroupName")

    @resource_group_name.setter # type: ignore
    def resource_group_name(self, value: builtins.str) -> None:
        jsii.set(self, "resourceGroupName", value)

    @builtins.property # type: ignore
    @jsii.member(jsii_name="serialization")
    def serialization(
        self,
    ) -> typing.List["StreamAnalyticsStreamInputIothubSerialization"]:
        return jsii.get(self, "serialization")

    @serialization.setter # type: ignore
    def serialization(
        self,
        value: typing.List["StreamAnalyticsStreamInputIothubSerialization"],
    ) -> None:
        jsii.set(self, "serialization", value)

    @builtins.property # type: ignore
    @jsii.member(jsii_name="sharedAccessPolicyKey")
    def shared_access_policy_key(self) -> builtins.str:
        return jsii.get(self, "sharedAccessPolicyKey")

    @shared_access_policy_key.setter # type: ignore
    def shared_access_policy_key(self, value: builtins.str) -> None:
        jsii.set(self, "sharedAccessPolicyKey", value)

    @builtins.property # type: ignore
    @jsii.member(jsii_name="sharedAccessPolicyName")
    def shared_access_policy_name(self) -> builtins.str:
        return jsii.get(self, "sharedAccessPolicyName")

    @shared_access_policy_name.setter # type: ignore
    def shared_access_policy_name(self, value: builtins.str) -> None:
        jsii.set(self, "sharedAccessPolicyName", value)

    @builtins.property # type: ignore
    @jsii.member(jsii_name="streamAnalyticsJobName")
    def stream_analytics_job_name(self) -> builtins.str:
        return jsii.get(self, "streamAnalyticsJobName")

    @stream_analytics_job_name.setter # type: ignore
    def stream_analytics_job_name(self, value: builtins.str) -> None:
        jsii.set(self, "streamAnalyticsJobName", value)

    @builtins.property # type: ignore
    @jsii.member(jsii_name="id")
    def id(self) -> typing.Optional[builtins.str]:
        return jsii.get(self, "id")

    @id.setter # type: ignore
    def id(self, value: typing.Optional[builtins.str]) -> None:
        jsii.set(self, "id", value)

    @builtins.property # type: ignore
    @jsii.member(jsii_name="timeouts")
    def timeouts(self) -> typing.Optional["StreamAnalyticsStreamInputIothubTimeouts"]:
        return jsii.get(self, "timeouts")

    @timeouts.setter # type: ignore
    def timeouts(
        self,
        value: typing.Optional["StreamAnalyticsStreamInputIothubTimeouts"],
    ) -> None:
        jsii.set(self, "timeouts", value)


@jsii.data_type(
    jsii_type="@cdktf/provider-azurerm.StreamAnalyticsStreamInputIothubConfig",
    jsii_struct_bases=[cdktf.TerraformMetaArguments],
    name_mapping={
        "count": "count",
        "depends_on": "dependsOn",
        "lifecycle": "lifecycle",
        "provider": "provider",
        "endpoint": "endpoint",
        "eventhub_consumer_group_name": "eventhubConsumerGroupName",
        "iothub_namespace": "iothubNamespace",
        "name": "name",
        "resource_group_name": "resourceGroupName",
        "serialization": "serialization",
        "shared_access_policy_key": "sharedAccessPolicyKey",
        "shared_access_policy_name": "sharedAccessPolicyName",
        "stream_analytics_job_name": "streamAnalyticsJobName",
        "timeouts": "timeouts",
    },
)
class StreamAnalyticsStreamInputIothubConfig(cdktf.TerraformMetaArguments):
    def __init__(
        self,
        *,
        count: typing.Optional[jsii.Number] = None,
        depends_on: typing.Optional[typing.List[cdktf.TerraformResource]] = None,
        lifecycle: typing.Optional[cdktf.TerraformResourceLifecycle] = None,
        provider: typing.Optional[cdktf.TerraformProvider] = None,
        endpoint: builtins.str,
        eventhub_consumer_group_name: builtins.str,
        iothub_namespace: builtins.str,
        name: builtins.str,
        resource_group_name: builtins.str,
        serialization: typing.List["StreamAnalyticsStreamInputIothubSerialization"],
        shared_access_policy_key: builtins.str,
        shared_access_policy_name: builtins.str,
        stream_analytics_job_name: builtins.str,
        timeouts: typing.Optional["StreamAnalyticsStreamInputIothubTimeouts"] = None,
    ) -> None:
        """
        :param count: 
        :param depends_on: 
        :param lifecycle: 
        :param provider: 
        :param endpoint: 
        :param eventhub_consumer_group_name: 
        :param iothub_namespace: 
        :param name: 
        :param resource_group_name: 
        :param serialization: serialization block.
        :param shared_access_policy_key: 
        :param shared_access_policy_name: 
        :param stream_analytics_job_name: 
        :param timeouts: timeouts block.
        """
        if isinstance(lifecycle, dict):
            lifecycle = cdktf.TerraformResourceLifecycle(**lifecycle)
        if isinstance(timeouts, dict):
            timeouts = StreamAnalyticsStreamInputIothubTimeouts(**timeouts)
        self._values: typing.Dict[str, typing.Any] = {
            "endpoint": endpoint,
            "eventhub_consumer_group_name": eventhub_consumer_group_name,
            "iothub_namespace": iothub_namespace,
            "name": name,
            "resource_group_name": resource_group_name,
            "serialization": serialization,
            "shared_access_policy_key": shared_access_policy_key,
            "shared_access_policy_name": shared_access_policy_name,
            "stream_analytics_job_name": stream_analytics_job_name,
        }
        if count is not None:
            self._values["count"] = count
        if depends_on is not None:
            self._values["depends_on"] = depends_on
        if lifecycle is not None:
            self._values["lifecycle"] = lifecycle
        if provider is not None:
            self._values["provider"] = provider
        if timeouts is not None:
            self._values["timeouts"] = timeouts

    @builtins.property
    def count(self) -> typing.Optional[jsii.Number]:
        """
        :stability: experimental
        """
        result = self._values.get("count")
        return result

    @builtins.property
    def depends_on(self) -> typing.Optional[typing.List[cdktf.TerraformResource]]:
        """
        :stability: experimental
        """
        result = self._values.get("depends_on")
        return result

    @builtins.property
    def lifecycle(self) -> typing.Optional[cdktf.TerraformResourceLifecycle]:
        """
        :stability: experimental
        """
        result = self._values.get("lifecycle")
        return result

    @builtins.property
    def provider(self) -> typing.Optional[cdktf.TerraformProvider]:
        """
        :stability: experimental
        """
        result = self._values.get("provider")
        return result

    @builtins.property
    def endpoint(self) -> builtins.str:
        result = self._values.get("endpoint")
        assert result is not None, "Required property 'endpoint' is missing"
        return result

    @builtins.property
    def eventhub_consumer_group_name(self) -> builtins.str:
        result = self._values.get("eventhub_consumer_group_name")
        assert result is not None, "Required property 'eventhub_consumer_group_name' is missing"
        return result

    @builtins.property
    def iothub_namespace(self) -> builtins.str:
        result = self._values.get("iothub_namespace")
        assert result is not None, "Required property 'iothub_namespace' is missing"
        return result

    @builtins.property
    def name(self) -> builtins.str:
        result = self._values.get("name")
        assert result is not None, "Required property 'name' is missing"
        return result

    @builtins.property
    def resource_group_name(self) -> builtins.str:
        result = self._values.get("resource_group_name")
        assert result is not None, "Required property 'resource_group_name' is missing"
        return result

    @builtins.property
    def serialization(
        self,
    ) -> typing.List["StreamAnalyticsStreamInputIothubSerialization"]:
        """serialization block."""
        result = self._values.get("serialization")
        assert result is not None, "Required property 'serialization' is missing"
        return result

    @builtins.property
    def shared_access_policy_key(self) -> builtins.str:
        result = self._values.get("shared_access_policy_key")
        assert result is not None, "Required property 'shared_access_policy_key' is missing"
        return result

    @builtins.property
    def shared_access_policy_name(self) -> builtins.str:
        result = self._values.get("shared_access_policy_name")
        assert result is not None, "Required property 'shared_access_policy_name' is missing"
        return result

    @builtins.property
    def stream_analytics_job_name(self) -> builtins.str:
        result = self._values.get("stream_analytics_job_name")
        assert result is not None, "Required property 'stream_analytics_job_name' is missing"
        return result

    @builtins.property
    def timeouts(self) -> typing.Optional["StreamAnalyticsStreamInputIothubTimeouts"]:
        """timeouts block."""
        result = self._values.get("timeouts")
        return result

    def __eq__(self, rhs: typing.Any) -> builtins.bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs: typing.Any) -> builtins.bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return "StreamAnalyticsStreamInputIothubConfig(%s)" % ", ".join(
            k + "=" + repr(v) for k, v in self._values.items()
        )


@jsii.data_type(
    jsii_type="@cdktf/provider-azurerm.StreamAnalyticsStreamInputIothubSerialization",
    jsii_struct_bases=[],
    name_mapping={
        "type": "type",
        "encoding": "encoding",
        "field_delimiter": "fieldDelimiter",
    },
)
class StreamAnalyticsStreamInputIothubSerialization:
    def __init__(
        self,
        *,
        type: builtins.str,
        encoding: typing.Optional[builtins.str] = None,
        field_delimiter: typing.Optional[builtins.str] = None,
    ) -> None:
        """
        :param type: 
        :param encoding: 
        :param field_delimiter: 
        """
        self._values: typing.Dict[str, typing.Any] = {
            "type": type,
        }
        if encoding is not None:
            self._values["encoding"] = encoding
        if field_delimiter is not None:
            self._values["field_delimiter"] = field_delimiter

    @builtins.property
    def type(self) -> builtins.str:
        result = self._values.get("type")
        assert result is not None, "Required property 'type' is missing"
        return result

    @builtins.property
    def encoding(self) -> typing.Optional[builtins.str]:
        result = self._values.get("encoding")
        return result

    @builtins.property
    def field_delimiter(self) -> typing.Optional[builtins.str]:
        result = self._values.get("field_delimiter")
        return result

    def __eq__(self, rhs: typing.Any) -> builtins.bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs: typing.Any) -> builtins.bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return "StreamAnalyticsStreamInputIothubSerialization(%s)" % ", ".join(
            k + "=" + repr(v) for k, v in self._values.items()
        )


@jsii.data_type(
    jsii_type="@cdktf/provider-azurerm.StreamAnalyticsStreamInputIothubTimeouts",
    jsii_struct_bases=[],
    name_mapping={
        "create": "create",
        "delete": "delete",
        "read": "read",
        "update": "update",
    },
)
class StreamAnalyticsStreamInputIothubTimeouts:
    def __init__(
        self,
        *,
        create: typing.Optional[builtins.str] = None,
        delete: typing.Optional[builtins.str] = None,
        read: typing.Optional[builtins.str] = None,
        update: typing.Optional[builtins.str] = None,
    ) -> None:
        """
        :param create: 
        :param delete: 
        :param read: 
        :param update: 
        """
        self._values: typing.Dict[str, typing.Any] = {}
        if create is not None:
            self._values["create"] = create
        if delete is not None:
            self._values["delete"] = delete
        if read is not None:
            self._values["read"] = read
        if update is not None:
            self._values["update"] = update

    @builtins.property
    def create(self) -> typing.Optional[builtins.str]:
        result = self._values.get("create")
        return result

    @builtins.property
    def delete(self) -> typing.Optional[builtins.str]:
        result = self._values.get("delete")
        return result

    @builtins.property
    def read(self) -> typing.Optional[builtins.str]:
        result = self._values.get("read")
        return result

    @builtins.property
    def update(self) -> typing.Optional[builtins.str]:
        result = self._values.get("update")
        return result

    def __eq__(self, rhs: typing.Any) -> builtins.bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs: typing.Any) -> builtins.bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return "StreamAnalyticsStreamInputIothubTimeouts(%s)" % ", ".join(
            k + "=" + repr(v) for k, v in self._values.items()
        )


class Subnet(
    cdktf.TerraformResource,
    metaclass=jsii.JSIIMeta,
    jsii_type="@cdktf/provider-azurerm.Subnet",
):
    def __init__(
        self,
        scope: constructs.Construct,
        id: builtins.str,
        *,
        address_prefix: builtins.str,
        name: builtins.str,
        resource_group_name: builtins.str,
        virtual_network_name: builtins.str,
        delegation: typing.Optional[typing.List["SubnetDelegation"]] = None,
        enforce_private_link_endpoint_network_policies: typing.Optional[builtins.bool] = None,
        enforce_private_link_service_network_policies: typing.Optional[builtins.bool] = None,
        service_endpoints: typing.Optional[typing.List[builtins.str]] = None,
        timeouts: typing.Optional["SubnetTimeouts"] = None,
        count: typing.Optional[jsii.Number] = None,
        depends_on: typing.Optional[typing.List[cdktf.TerraformResource]] = None,
        lifecycle: typing.Optional[cdktf.TerraformResourceLifecycle] = None,
        provider: typing.Optional[cdktf.TerraformProvider] = None,
    ) -> None:
        """
        :param scope: -
        :param id: -
        :param address_prefix: 
        :param name: 
        :param resource_group_name: 
        :param virtual_network_name: 
        :param delegation: delegation block.
        :param enforce_private_link_endpoint_network_policies: 
        :param enforce_private_link_service_network_policies: 
        :param service_endpoints: 
        :param timeouts: timeouts block.
        :param count: 
        :param depends_on: 
        :param lifecycle: 
        :param provider: 
        """
        config = SubnetConfig(
            address_prefix=address_prefix,
            name=name,
            resource_group_name=resource_group_name,
            virtual_network_name=virtual_network_name,
            delegation=delegation,
            enforce_private_link_endpoint_network_policies=enforce_private_link_endpoint_network_policies,
            enforce_private_link_service_network_policies=enforce_private_link_service_network_policies,
            service_endpoints=service_endpoints,
            timeouts=timeouts,
            count=count,
            depends_on=depends_on,
            lifecycle=lifecycle,
            provider=provider,
        )

        jsii.create(Subnet, self, [scope, id, config])

    @jsii.member(jsii_name="synthesizeAttributes")
    def _synthesize_attributes(self) -> typing.Mapping[builtins.str, typing.Any]:
        return jsii.invoke(self, "synthesizeAttributes", [])

    @builtins.property # type: ignore
    @jsii.member(jsii_name="addressPrefix")
    def address_prefix(self) -> builtins.str:
        return jsii.get(self, "addressPrefix")

    @address_prefix.setter # type: ignore
    def address_prefix(self, value: builtins.str) -> None:
        jsii.set(self, "addressPrefix", value)

    @builtins.property # type: ignore
    @jsii.member(jsii_name="name")
    def name(self) -> builtins.str:
        return jsii.get(self, "name")

    @name.setter # type: ignore
    def name(self, value: builtins.str) -> None:
        jsii.set(self, "name", value)

    @builtins.property # type: ignore
    @jsii.member(jsii_name="resourceGroupName")
    def resource_group_name(self) -> builtins.str:
        return jsii.get(self, "resourceGroupName")

    @resource_group_name.setter # type: ignore
    def resource_group_name(self, value: builtins.str) -> None:
        jsii.set(self, "resourceGroupName", value)

    @builtins.property # type: ignore
    @jsii.member(jsii_name="virtualNetworkName")
    def virtual_network_name(self) -> builtins.str:
        return jsii.get(self, "virtualNetworkName")

    @virtual_network_name.setter # type: ignore
    def virtual_network_name(self, value: builtins.str) -> None:
        jsii.set(self, "virtualNetworkName", value)

    @builtins.property # type: ignore
    @jsii.member(jsii_name="delegation")
    def delegation(self) -> typing.Optional[typing.List["SubnetDelegation"]]:
        return jsii.get(self, "delegation")

    @delegation.setter # type: ignore
    def delegation(
        self,
        value: typing.Optional[typing.List["SubnetDelegation"]],
    ) -> None:
        jsii.set(self, "delegation", value)

    @builtins.property # type: ignore
    @jsii.member(jsii_name="enforcePrivateLinkEndpointNetworkPolicies")
    def enforce_private_link_endpoint_network_policies(
        self,
    ) -> typing.Optional[builtins.bool]:
        return jsii.get(self, "enforcePrivateLinkEndpointNetworkPolicies")

    @enforce_private_link_endpoint_network_policies.setter # type: ignore
    def enforce_private_link_endpoint_network_policies(
        self,
        value: typing.Optional[builtins.bool],
    ) -> None:
        jsii.set(self, "enforcePrivateLinkEndpointNetworkPolicies", value)

    @builtins.property # type: ignore
    @jsii.member(jsii_name="enforcePrivateLinkServiceNetworkPolicies")
    def enforce_private_link_service_network_policies(
        self,
    ) -> typing.Optional[builtins.bool]:
        return jsii.get(self, "enforcePrivateLinkServiceNetworkPolicies")

    @enforce_private_link_service_network_policies.setter # type: ignore
    def enforce_private_link_service_network_policies(
        self,
        value: typing.Optional[builtins.bool],
    ) -> None:
        jsii.set(self, "enforcePrivateLinkServiceNetworkPolicies", value)

    @builtins.property # type: ignore
    @jsii.member(jsii_name="id")
    def id(self) -> typing.Optional[builtins.str]:
        return jsii.get(self, "id")

    @id.setter # type: ignore
    def id(self, value: typing.Optional[builtins.str]) -> None:
        jsii.set(self, "id", value)

    @builtins.property # type: ignore
    @jsii.member(jsii_name="serviceEndpoints")
    def service_endpoints(self) -> typing.Optional[typing.List[builtins.str]]:
        return jsii.get(self, "serviceEndpoints")

    @service_endpoints.setter # type: ignore
    def service_endpoints(
        self,
        value: typing.Optional[typing.List[builtins.str]],
    ) -> None:
        jsii.set(self, "serviceEndpoints", value)

    @builtins.property # type: ignore
    @jsii.member(jsii_name="timeouts")
    def timeouts(self) -> typing.Optional["SubnetTimeouts"]:
        return jsii.get(self, "timeouts")

    @timeouts.setter # type: ignore
    def timeouts(self, value: typing.Optional["SubnetTimeouts"]) -> None:
        jsii.set(self, "timeouts", value)


@jsii.data_type(
    jsii_type="@cdktf/provider-azurerm.SubnetConfig",
    jsii_struct_bases=[cdktf.TerraformMetaArguments],
    name_mapping={
        "count": "count",
        "depends_on": "dependsOn",
        "lifecycle": "lifecycle",
        "provider": "provider",
        "address_prefix": "addressPrefix",
        "name": "name",
        "resource_group_name": "resourceGroupName",
        "virtual_network_name": "virtualNetworkName",
        "delegation": "delegation",
        "enforce_private_link_endpoint_network_policies": "enforcePrivateLinkEndpointNetworkPolicies",
        "enforce_private_link_service_network_policies": "enforcePrivateLinkServiceNetworkPolicies",
        "service_endpoints": "serviceEndpoints",
        "timeouts": "timeouts",
    },
)
class SubnetConfig(cdktf.TerraformMetaArguments):
    def __init__(
        self,
        *,
        count: typing.Optional[jsii.Number] = None,
        depends_on: typing.Optional[typing.List[cdktf.TerraformResource]] = None,
        lifecycle: typing.Optional[cdktf.TerraformResourceLifecycle] = None,
        provider: typing.Optional[cdktf.TerraformProvider] = None,
        address_prefix: builtins.str,
        name: builtins.str,
        resource_group_name: builtins.str,
        virtual_network_name: builtins.str,
        delegation: typing.Optional[typing.List["SubnetDelegation"]] = None,
        enforce_private_link_endpoint_network_policies: typing.Optional[builtins.bool] = None,
        enforce_private_link_service_network_policies: typing.Optional[builtins.bool] = None,
        service_endpoints: typing.Optional[typing.List[builtins.str]] = None,
        timeouts: typing.Optional["SubnetTimeouts"] = None,
    ) -> None:
        """
        :param count: 
        :param depends_on: 
        :param lifecycle: 
        :param provider: 
        :param address_prefix: 
        :param name: 
        :param resource_group_name: 
        :param virtual_network_name: 
        :param delegation: delegation block.
        :param enforce_private_link_endpoint_network_policies: 
        :param enforce_private_link_service_network_policies: 
        :param service_endpoints: 
        :param timeouts: timeouts block.
        """
        if isinstance(lifecycle, dict):
            lifecycle = cdktf.TerraformResourceLifecycle(**lifecycle)
        if isinstance(timeouts, dict):
            timeouts = SubnetTimeouts(**timeouts)
        self._values: typing.Dict[str, typing.Any] = {
            "address_prefix": address_prefix,
            "name": name,
            "resource_group_name": resource_group_name,
            "virtual_network_name": virtual_network_name,
        }
        if count is not None:
            self._values["count"] = count
        if depends_on is not None:
            self._values["depends_on"] = depends_on
        if lifecycle is not None:
            self._values["lifecycle"] = lifecycle
        if provider is not None:
            self._values["provider"] = provider
        if delegation is not None:
            self._values["delegation"] = delegation
        if enforce_private_link_endpoint_network_policies is not None:
            self._values["enforce_private_link_endpoint_network_policies"] = enforce_private_link_endpoint_network_policies
        if enforce_private_link_service_network_policies is not None:
            self._values["enforce_private_link_service_network_policies"] = enforce_private_link_service_network_policies
        if service_endpoints is not None:
            self._values["service_endpoints"] = service_endpoints
        if timeouts is not None:
            self._values["timeouts"] = timeouts

    @builtins.property
    def count(self) -> typing.Optional[jsii.Number]:
        """
        :stability: experimental
        """
        result = self._values.get("count")
        return result

    @builtins.property
    def depends_on(self) -> typing.Optional[typing.List[cdktf.TerraformResource]]:
        """
        :stability: experimental
        """
        result = self._values.get("depends_on")
        return result

    @builtins.property
    def lifecycle(self) -> typing.Optional[cdktf.TerraformResourceLifecycle]:
        """
        :stability: experimental
        """
        result = self._values.get("lifecycle")
        return result

    @builtins.property
    def provider(self) -> typing.Optional[cdktf.TerraformProvider]:
        """
        :stability: experimental
        """
        result = self._values.get("provider")
        return result

    @builtins.property
    def address_prefix(self) -> builtins.str:
        result = self._values.get("address_prefix")
        assert result is not None, "Required property 'address_prefix' is missing"
        return result

    @builtins.property
    def name(self) -> builtins.str:
        result = self._values.get("name")
        assert result is not None, "Required property 'name' is missing"
        return result

    @builtins.property
    def resource_group_name(self) -> builtins.str:
        result = self._values.get("resource_group_name")
        assert result is not None, "Required property 'resource_group_name' is missing"
        return result

    @builtins.property
    def virtual_network_name(self) -> builtins.str:
        result = self._values.get("virtual_network_name")
        assert result is not None, "Required property 'virtual_network_name' is missing"
        return result

    @builtins.property
    def delegation(self) -> typing.Optional[typing.List["SubnetDelegation"]]:
        """delegation block."""
        result = self._values.get("delegation")
        return result

    @builtins.property
    def enforce_private_link_endpoint_network_policies(
        self,
    ) -> typing.Optional[builtins.bool]:
        result = self._values.get("enforce_private_link_endpoint_network_policies")
        return result

    @builtins.property
    def enforce_private_link_service_network_policies(
        self,
    ) -> typing.Optional[builtins.bool]:
        result = self._values.get("enforce_private_link_service_network_policies")
        return result

    @builtins.property
    def service_endpoints(self) -> typing.Optional[typing.List[builtins.str]]:
        result = self._values.get("service_endpoints")
        return result

    @builtins.property
    def timeouts(self) -> typing.Optional["SubnetTimeouts"]:
        """timeouts block."""
        result = self._values.get("timeouts")
        return result

    def __eq__(self, rhs: typing.Any) -> builtins.bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs: typing.Any) -> builtins.bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return "SubnetConfig(%s)" % ", ".join(
            k + "=" + repr(v) for k, v in self._values.items()
        )


@jsii.data_type(
    jsii_type="@cdktf/provider-azurerm.SubnetDelegation",
    jsii_struct_bases=[],
    name_mapping={"name": "name", "service_delegation": "serviceDelegation"},
)
class SubnetDelegation:
    def __init__(
        self,
        *,
        name: builtins.str,
        service_delegation: typing.List["SubnetDelegationServiceDelegation"],
    ) -> None:
        """
        :param name: 
        :param service_delegation: service_delegation block.
        """
        self._values: typing.Dict[str, typing.Any] = {
            "name": name,
            "service_delegation": service_delegation,
        }

    @builtins.property
    def name(self) -> builtins.str:
        result = self._values.get("name")
        assert result is not None, "Required property 'name' is missing"
        return result

    @builtins.property
    def service_delegation(self) -> typing.List["SubnetDelegationServiceDelegation"]:
        """service_delegation block."""
        result = self._values.get("service_delegation")
        assert result is not None, "Required property 'service_delegation' is missing"
        return result

    def __eq__(self, rhs: typing.Any) -> builtins.bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs: typing.Any) -> builtins.bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return "SubnetDelegation(%s)" % ", ".join(
            k + "=" + repr(v) for k, v in self._values.items()
        )


@jsii.data_type(
    jsii_type="@cdktf/provider-azurerm.SubnetDelegationServiceDelegation",
    jsii_struct_bases=[],
    name_mapping={"name": "name", "actions": "actions"},
)
class SubnetDelegationServiceDelegation:
    def __init__(
        self,
        *,
        name: builtins.str,
        actions: typing.Optional[typing.List[builtins.str]] = None,
    ) -> None:
        """
        :param name: 
        :param actions: 
        """
        self._values: typing.Dict[str, typing.Any] = {
            "name": name,
        }
        if actions is not None:
            self._values["actions"] = actions

    @builtins.property
    def name(self) -> builtins.str:
        result = self._values.get("name")
        assert result is not None, "Required property 'name' is missing"
        return result

    @builtins.property
    def actions(self) -> typing.Optional[typing.List[builtins.str]]:
        result = self._values.get("actions")
        return result

    def __eq__(self, rhs: typing.Any) -> builtins.bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs: typing.Any) -> builtins.bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return "SubnetDelegationServiceDelegation(%s)" % ", ".join(
            k + "=" + repr(v) for k, v in self._values.items()
        )


class SubnetNatGatewayAssociation(
    cdktf.TerraformResource,
    metaclass=jsii.JSIIMeta,
    jsii_type="@cdktf/provider-azurerm.SubnetNatGatewayAssociation",
):
    def __init__(
        self,
        scope: constructs.Construct,
        id: builtins.str,
        *,
        nat_gateway_id: builtins.str,
        subnet_id: builtins.str,
        timeouts: typing.Optional["SubnetNatGatewayAssociationTimeouts"] = None,
        count: typing.Optional[jsii.Number] = None,
        depends_on: typing.Optional[typing.List[cdktf.TerraformResource]] = None,
        lifecycle: typing.Optional[cdktf.TerraformResourceLifecycle] = None,
        provider: typing.Optional[cdktf.TerraformProvider] = None,
    ) -> None:
        """
        :param scope: -
        :param id: -
        :param nat_gateway_id: 
        :param subnet_id: 
        :param timeouts: timeouts block.
        :param count: 
        :param depends_on: 
        :param lifecycle: 
        :param provider: 
        """
        config = SubnetNatGatewayAssociationConfig(
            nat_gateway_id=nat_gateway_id,
            subnet_id=subnet_id,
            timeouts=timeouts,
            count=count,
            depends_on=depends_on,
            lifecycle=lifecycle,
            provider=provider,
        )

        jsii.create(SubnetNatGatewayAssociation, self, [scope, id, config])

    @jsii.member(jsii_name="synthesizeAttributes")
    def _synthesize_attributes(self) -> typing.Mapping[builtins.str, typing.Any]:
        return jsii.invoke(self, "synthesizeAttributes", [])

    @builtins.property # type: ignore
    @jsii.member(jsii_name="natGatewayId")
    def nat_gateway_id(self) -> builtins.str:
        return jsii.get(self, "natGatewayId")

    @nat_gateway_id.setter # type: ignore
    def nat_gateway_id(self, value: builtins.str) -> None:
        jsii.set(self, "natGatewayId", value)

    @builtins.property # type: ignore
    @jsii.member(jsii_name="subnetId")
    def subnet_id(self) -> builtins.str:
        return jsii.get(self, "subnetId")

    @subnet_id.setter # type: ignore
    def subnet_id(self, value: builtins.str) -> None:
        jsii.set(self, "subnetId", value)

    @builtins.property # type: ignore
    @jsii.member(jsii_name="id")
    def id(self) -> typing.Optional[builtins.str]:
        return jsii.get(self, "id")

    @id.setter # type: ignore
    def id(self, value: typing.Optional[builtins.str]) -> None:
        jsii.set(self, "id", value)

    @builtins.property # type: ignore
    @jsii.member(jsii_name="timeouts")
    def timeouts(self) -> typing.Optional["SubnetNatGatewayAssociationTimeouts"]:
        return jsii.get(self, "timeouts")

    @timeouts.setter # type: ignore
    def timeouts(
        self,
        value: typing.Optional["SubnetNatGatewayAssociationTimeouts"],
    ) -> None:
        jsii.set(self, "timeouts", value)


@jsii.data_type(
    jsii_type="@cdktf/provider-azurerm.SubnetNatGatewayAssociationConfig",
    jsii_struct_bases=[cdktf.TerraformMetaArguments],
    name_mapping={
        "count": "count",
        "depends_on": "dependsOn",
        "lifecycle": "lifecycle",
        "provider": "provider",
        "nat_gateway_id": "natGatewayId",
        "subnet_id": "subnetId",
        "timeouts": "timeouts",
    },
)
class SubnetNatGatewayAssociationConfig(cdktf.TerraformMetaArguments):
    def __init__(
        self,
        *,
        count: typing.Optional[jsii.Number] = None,
        depends_on: typing.Optional[typing.List[cdktf.TerraformResource]] = None,
        lifecycle: typing.Optional[cdktf.TerraformResourceLifecycle] = None,
        provider: typing.Optional[cdktf.TerraformProvider] = None,
        nat_gateway_id: builtins.str,
        subnet_id: builtins.str,
        timeouts: typing.Optional["SubnetNatGatewayAssociationTimeouts"] = None,
    ) -> None:
        """
        :param count: 
        :param depends_on: 
        :param lifecycle: 
        :param provider: 
        :param nat_gateway_id: 
        :param subnet_id: 
        :param timeouts: timeouts block.
        """
        if isinstance(lifecycle, dict):
            lifecycle = cdktf.TerraformResourceLifecycle(**lifecycle)
        if isinstance(timeouts, dict):
            timeouts = SubnetNatGatewayAssociationTimeouts(**timeouts)
        self._values: typing.Dict[str, typing.Any] = {
            "nat_gateway_id": nat_gateway_id,
            "subnet_id": subnet_id,
        }
        if count is not None:
            self._values["count"] = count
        if depends_on is not None:
            self._values["depends_on"] = depends_on
        if lifecycle is not None:
            self._values["lifecycle"] = lifecycle
        if provider is not None:
            self._values["provider"] = provider
        if timeouts is not None:
            self._values["timeouts"] = timeouts

    @builtins.property
    def count(self) -> typing.Optional[jsii.Number]:
        """
        :stability: experimental
        """
        result = self._values.get("count")
        return result

    @builtins.property
    def depends_on(self) -> typing.Optional[typing.List[cdktf.TerraformResource]]:
        """
        :stability: experimental
        """
        result = self._values.get("depends_on")
        return result

    @builtins.property
    def lifecycle(self) -> typing.Optional[cdktf.TerraformResourceLifecycle]:
        """
        :stability: experimental
        """
        result = self._values.get("lifecycle")
        return result

    @builtins.property
    def provider(self) -> typing.Optional[cdktf.TerraformProvider]:
        """
        :stability: experimental
        """
        result = self._values.get("provider")
        return result

    @builtins.property
    def nat_gateway_id(self) -> builtins.str:
        result = self._values.get("nat_gateway_id")
        assert result is not None, "Required property 'nat_gateway_id' is missing"
        return result

    @builtins.property
    def subnet_id(self) -> builtins.str:
        result = self._values.get("subnet_id")
        assert result is not None, "Required property 'subnet_id' is missing"
        return result

    @builtins.property
    def timeouts(self) -> typing.Optional["SubnetNatGatewayAssociationTimeouts"]:
        """timeouts block."""
        result = self._values.get("timeouts")
        return result

    def __eq__(self, rhs: typing.Any) -> builtins.bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs: typing.Any) -> builtins.bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return "SubnetNatGatewayAssociationConfig(%s)" % ", ".join(
            k + "=" + repr(v) for k, v in self._values.items()
        )


@jsii.data_type(
    jsii_type="@cdktf/provider-azurerm.SubnetNatGatewayAssociationTimeouts",
    jsii_struct_bases=[],
    name_mapping={
        "create": "create",
        "delete": "delete",
        "read": "read",
        "update": "update",
    },
)
class SubnetNatGatewayAssociationTimeouts:
    def __init__(
        self,
        *,
        create: typing.Optional[builtins.str] = None,
        delete: typing.Optional[builtins.str] = None,
        read: typing.Optional[builtins.str] = None,
        update: typing.Optional[builtins.str] = None,
    ) -> None:
        """
        :param create: 
        :param delete: 
        :param read: 
        :param update: 
        """
        self._values: typing.Dict[str, typing.Any] = {}
        if create is not None:
            self._values["create"] = create
        if delete is not None:
            self._values["delete"] = delete
        if read is not None:
            self._values["read"] = read
        if update is not None:
            self._values["update"] = update

    @builtins.property
    def create(self) -> typing.Optional[builtins.str]:
        result = self._values.get("create")
        return result

    @builtins.property
    def delete(self) -> typing.Optional[builtins.str]:
        result = self._values.get("delete")
        return result

    @builtins.property
    def read(self) -> typing.Optional[builtins.str]:
        result = self._values.get("read")
        return result

    @builtins.property
    def update(self) -> typing.Optional[builtins.str]:
        result = self._values.get("update")
        return result

    def __eq__(self, rhs: typing.Any) -> builtins.bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs: typing.Any) -> builtins.bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return "SubnetNatGatewayAssociationTimeouts(%s)" % ", ".join(
            k + "=" + repr(v) for k, v in self._values.items()
        )


class SubnetNetworkSecurityGroupAssociation(
    cdktf.TerraformResource,
    metaclass=jsii.JSIIMeta,
    jsii_type="@cdktf/provider-azurerm.SubnetNetworkSecurityGroupAssociation",
):
    def __init__(
        self,
        scope: constructs.Construct,
        id: builtins.str,
        *,
        network_security_group_id: builtins.str,
        subnet_id: builtins.str,
        timeouts: typing.Optional["SubnetNetworkSecurityGroupAssociationTimeouts"] = None,
        count: typing.Optional[jsii.Number] = None,
        depends_on: typing.Optional[typing.List[cdktf.TerraformResource]] = None,
        lifecycle: typing.Optional[cdktf.TerraformResourceLifecycle] = None,
        provider: typing.Optional[cdktf.TerraformProvider] = None,
    ) -> None:
        """
        :param scope: -
        :param id: -
        :param network_security_group_id: 
        :param subnet_id: 
        :param timeouts: timeouts block.
        :param count: 
        :param depends_on: 
        :param lifecycle: 
        :param provider: 
        """
        config = SubnetNetworkSecurityGroupAssociationConfig(
            network_security_group_id=network_security_group_id,
            subnet_id=subnet_id,
            timeouts=timeouts,
            count=count,
            depends_on=depends_on,
            lifecycle=lifecycle,
            provider=provider,
        )

        jsii.create(SubnetNetworkSecurityGroupAssociation, self, [scope, id, config])

    @jsii.member(jsii_name="synthesizeAttributes")
    def _synthesize_attributes(self) -> typing.Mapping[builtins.str, typing.Any]:
        return jsii.invoke(self, "synthesizeAttributes", [])

    @builtins.property # type: ignore
    @jsii.member(jsii_name="networkSecurityGroupId")
    def network_security_group_id(self) -> builtins.str:
        return jsii.get(self, "networkSecurityGroupId")

    @network_security_group_id.setter # type: ignore
    def network_security_group_id(self, value: builtins.str) -> None:
        jsii.set(self, "networkSecurityGroupId", value)

    @builtins.property # type: ignore
    @jsii.member(jsii_name="subnetId")
    def subnet_id(self) -> builtins.str:
        return jsii.get(self, "subnetId")

    @subnet_id.setter # type: ignore
    def subnet_id(self, value: builtins.str) -> None:
        jsii.set(self, "subnetId", value)

    @builtins.property # type: ignore
    @jsii.member(jsii_name="id")
    def id(self) -> typing.Optional[builtins.str]:
        return jsii.get(self, "id")

    @id.setter # type: ignore
    def id(self, value: typing.Optional[builtins.str]) -> None:
        jsii.set(self, "id", value)

    @builtins.property # type: ignore
    @jsii.member(jsii_name="timeouts")
    def timeouts(
        self,
    ) -> typing.Optional["SubnetNetworkSecurityGroupAssociationTimeouts"]:
        return jsii.get(self, "timeouts")

    @timeouts.setter # type: ignore
    def timeouts(
        self,
        value: typing.Optional["SubnetNetworkSecurityGroupAssociationTimeouts"],
    ) -> None:
        jsii.set(self, "timeouts", value)


@jsii.data_type(
    jsii_type="@cdktf/provider-azurerm.SubnetNetworkSecurityGroupAssociationConfig",
    jsii_struct_bases=[cdktf.TerraformMetaArguments],
    name_mapping={
        "count": "count",
        "depends_on": "dependsOn",
        "lifecycle": "lifecycle",
        "provider": "provider",
        "network_security_group_id": "networkSecurityGroupId",
        "subnet_id": "subnetId",
        "timeouts": "timeouts",
    },
)
class SubnetNetworkSecurityGroupAssociationConfig(cdktf.TerraformMetaArguments):
    def __init__(
        self,
        *,
        count: typing.Optional[jsii.Number] = None,
        depends_on: typing.Optional[typing.List[cdktf.TerraformResource]] = None,
        lifecycle: typing.Optional[cdktf.TerraformResourceLifecycle] = None,
        provider: typing.Optional[cdktf.TerraformProvider] = None,
        network_security_group_id: builtins.str,
        subnet_id: builtins.str,
        timeouts: typing.Optional["SubnetNetworkSecurityGroupAssociationTimeouts"] = None,
    ) -> None:
        """
        :param count: 
        :param depends_on: 
        :param lifecycle: 
        :param provider: 
        :param network_security_group_id: 
        :param subnet_id: 
        :param timeouts: timeouts block.
        """
        if isinstance(lifecycle, dict):
            lifecycle = cdktf.TerraformResourceLifecycle(**lifecycle)
        if isinstance(timeouts, dict):
            timeouts = SubnetNetworkSecurityGroupAssociationTimeouts(**timeouts)
        self._values: typing.Dict[str, typing.Any] = {
            "network_security_group_id": network_security_group_id,
            "subnet_id": subnet_id,
        }
        if count is not None:
            self._values["count"] = count
        if depends_on is not None:
            self._values["depends_on"] = depends_on
        if lifecycle is not None:
            self._values["lifecycle"] = lifecycle
        if provider is not None:
            self._values["provider"] = provider
        if timeouts is not None:
            self._values["timeouts"] = timeouts

    @builtins.property
    def count(self) -> typing.Optional[jsii.Number]:
        """
        :stability: experimental
        """
        result = self._values.get("count")
        return result

    @builtins.property
    def depends_on(self) -> typing.Optional[typing.List[cdktf.TerraformResource]]:
        """
        :stability: experimental
        """
        result = self._values.get("depends_on")
        return result

    @builtins.property
    def lifecycle(self) -> typing.Optional[cdktf.TerraformResourceLifecycle]:
        """
        :stability: experimental
        """
        result = self._values.get("lifecycle")
        return result

    @builtins.property
    def provider(self) -> typing.Optional[cdktf.TerraformProvider]:
        """
        :stability: experimental
        """
        result = self._values.get("provider")
        return result

    @builtins.property
    def network_security_group_id(self) -> builtins.str:
        result = self._values.get("network_security_group_id")
        assert result is not None, "Required property 'network_security_group_id' is missing"
        return result

    @builtins.property
    def subnet_id(self) -> builtins.str:
        result = self._values.get("subnet_id")
        assert result is not None, "Required property 'subnet_id' is missing"
        return result

    @builtins.property
    def timeouts(
        self,
    ) -> typing.Optional["SubnetNetworkSecurityGroupAssociationTimeouts"]:
        """timeouts block."""
        result = self._values.get("timeouts")
        return result

    def __eq__(self, rhs: typing.Any) -> builtins.bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs: typing.Any) -> builtins.bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return "SubnetNetworkSecurityGroupAssociationConfig(%s)" % ", ".join(
            k + "=" + repr(v) for k, v in self._values.items()
        )


@jsii.data_type(
    jsii_type="@cdktf/provider-azurerm.SubnetNetworkSecurityGroupAssociationTimeouts",
    jsii_struct_bases=[],
    name_mapping={
        "create": "create",
        "delete": "delete",
        "read": "read",
        "update": "update",
    },
)
class SubnetNetworkSecurityGroupAssociationTimeouts:
    def __init__(
        self,
        *,
        create: typing.Optional[builtins.str] = None,
        delete: typing.Optional[builtins.str] = None,
        read: typing.Optional[builtins.str] = None,
        update: typing.Optional[builtins.str] = None,
    ) -> None:
        """
        :param create: 
        :param delete: 
        :param read: 
        :param update: 
        """
        self._values: typing.Dict[str, typing.Any] = {}
        if create is not None:
            self._values["create"] = create
        if delete is not None:
            self._values["delete"] = delete
        if read is not None:
            self._values["read"] = read
        if update is not None:
            self._values["update"] = update

    @builtins.property
    def create(self) -> typing.Optional[builtins.str]:
        result = self._values.get("create")
        return result

    @builtins.property
    def delete(self) -> typing.Optional[builtins.str]:
        result = self._values.get("delete")
        return result

    @builtins.property
    def read(self) -> typing.Optional[builtins.str]:
        result = self._values.get("read")
        return result

    @builtins.property
    def update(self) -> typing.Optional[builtins.str]:
        result = self._values.get("update")
        return result

    def __eq__(self, rhs: typing.Any) -> builtins.bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs: typing.Any) -> builtins.bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return "SubnetNetworkSecurityGroupAssociationTimeouts(%s)" % ", ".join(
            k + "=" + repr(v) for k, v in self._values.items()
        )


class SubnetRouteTableAssociation(
    cdktf.TerraformResource,
    metaclass=jsii.JSIIMeta,
    jsii_type="@cdktf/provider-azurerm.SubnetRouteTableAssociation",
):
    def __init__(
        self,
        scope: constructs.Construct,
        id: builtins.str,
        *,
        route_table_id: builtins.str,
        subnet_id: builtins.str,
        timeouts: typing.Optional["SubnetRouteTableAssociationTimeouts"] = None,
        count: typing.Optional[jsii.Number] = None,
        depends_on: typing.Optional[typing.List[cdktf.TerraformResource]] = None,
        lifecycle: typing.Optional[cdktf.TerraformResourceLifecycle] = None,
        provider: typing.Optional[cdktf.TerraformProvider] = None,
    ) -> None:
        """
        :param scope: -
        :param id: -
        :param route_table_id: 
        :param subnet_id: 
        :param timeouts: timeouts block.
        :param count: 
        :param depends_on: 
        :param lifecycle: 
        :param provider: 
        """
        config = SubnetRouteTableAssociationConfig(
            route_table_id=route_table_id,
            subnet_id=subnet_id,
            timeouts=timeouts,
            count=count,
            depends_on=depends_on,
            lifecycle=lifecycle,
            provider=provider,
        )

        jsii.create(SubnetRouteTableAssociation, self, [scope, id, config])

    @jsii.member(jsii_name="synthesizeAttributes")
    def _synthesize_attributes(self) -> typing.Mapping[builtins.str, typing.Any]:
        return jsii.invoke(self, "synthesizeAttributes", [])

    @builtins.property # type: ignore
    @jsii.member(jsii_name="routeTableId")
    def route_table_id(self) -> builtins.str:
        return jsii.get(self, "routeTableId")

    @route_table_id.setter # type: ignore
    def route_table_id(self, value: builtins.str) -> None:
        jsii.set(self, "routeTableId", value)

    @builtins.property # type: ignore
    @jsii.member(jsii_name="subnetId")
    def subnet_id(self) -> builtins.str:
        return jsii.get(self, "subnetId")

    @subnet_id.setter # type: ignore
    def subnet_id(self, value: builtins.str) -> None:
        jsii.set(self, "subnetId", value)

    @builtins.property # type: ignore
    @jsii.member(jsii_name="id")
    def id(self) -> typing.Optional[builtins.str]:
        return jsii.get(self, "id")

    @id.setter # type: ignore
    def id(self, value: typing.Optional[builtins.str]) -> None:
        jsii.set(self, "id", value)

    @builtins.property # type: ignore
    @jsii.member(jsii_name="timeouts")
    def timeouts(self) -> typing.Optional["SubnetRouteTableAssociationTimeouts"]:
        return jsii.get(self, "timeouts")

    @timeouts.setter # type: ignore
    def timeouts(
        self,
        value: typing.Optional["SubnetRouteTableAssociationTimeouts"],
    ) -> None:
        jsii.set(self, "timeouts", value)


@jsii.data_type(
    jsii_type="@cdktf/provider-azurerm.SubnetRouteTableAssociationConfig",
    jsii_struct_bases=[cdktf.TerraformMetaArguments],
    name_mapping={
        "count": "count",
        "depends_on": "dependsOn",
        "lifecycle": "lifecycle",
        "provider": "provider",
        "route_table_id": "routeTableId",
        "subnet_id": "subnetId",
        "timeouts": "timeouts",
    },
)
class SubnetRouteTableAssociationConfig(cdktf.TerraformMetaArguments):
    def __init__(
        self,
        *,
        count: typing.Optional[jsii.Number] = None,
        depends_on: typing.Optional[typing.List[cdktf.TerraformResource]] = None,
        lifecycle: typing.Optional[cdktf.TerraformResourceLifecycle] = None,
        provider: typing.Optional[cdktf.TerraformProvider] = None,
        route_table_id: builtins.str,
        subnet_id: builtins.str,
        timeouts: typing.Optional["SubnetRouteTableAssociationTimeouts"] = None,
    ) -> None:
        """
        :param count: 
        :param depends_on: 
        :param lifecycle: 
        :param provider: 
        :param route_table_id: 
        :param subnet_id: 
        :param timeouts: timeouts block.
        """
        if isinstance(lifecycle, dict):
            lifecycle = cdktf.TerraformResourceLifecycle(**lifecycle)
        if isinstance(timeouts, dict):
            timeouts = SubnetRouteTableAssociationTimeouts(**timeouts)
        self._values: typing.Dict[str, typing.Any] = {
            "route_table_id": route_table_id,
            "subnet_id": subnet_id,
        }
        if count is not None:
            self._values["count"] = count
        if depends_on is not None:
            self._values["depends_on"] = depends_on
        if lifecycle is not None:
            self._values["lifecycle"] = lifecycle
        if provider is not None:
            self._values["provider"] = provider
        if timeouts is not None:
            self._values["timeouts"] = timeouts

    @builtins.property
    def count(self) -> typing.Optional[jsii.Number]:
        """
        :stability: experimental
        """
        result = self._values.get("count")
        return result

    @builtins.property
    def depends_on(self) -> typing.Optional[typing.List[cdktf.TerraformResource]]:
        """
        :stability: experimental
        """
        result = self._values.get("depends_on")
        return result

    @builtins.property
    def lifecycle(self) -> typing.Optional[cdktf.TerraformResourceLifecycle]:
        """
        :stability: experimental
        """
        result = self._values.get("lifecycle")
        return result

    @builtins.property
    def provider(self) -> typing.Optional[cdktf.TerraformProvider]:
        """
        :stability: experimental
        """
        result = self._values.get("provider")
        return result

    @builtins.property
    def route_table_id(self) -> builtins.str:
        result = self._values.get("route_table_id")
        assert result is not None, "Required property 'route_table_id' is missing"
        return result

    @builtins.property
    def subnet_id(self) -> builtins.str:
        result = self._values.get("subnet_id")
        assert result is not None, "Required property 'subnet_id' is missing"
        return result

    @builtins.property
    def timeouts(self) -> typing.Optional["SubnetRouteTableAssociationTimeouts"]:
        """timeouts block."""
        result = self._values.get("timeouts")
        return result

    def __eq__(self, rhs: typing.Any) -> builtins.bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs: typing.Any) -> builtins.bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return "SubnetRouteTableAssociationConfig(%s)" % ", ".join(
            k + "=" + repr(v) for k, v in self._values.items()
        )


@jsii.data_type(
    jsii_type="@cdktf/provider-azurerm.SubnetRouteTableAssociationTimeouts",
    jsii_struct_bases=[],
    name_mapping={
        "create": "create",
        "delete": "delete",
        "read": "read",
        "update": "update",
    },
)
class SubnetRouteTableAssociationTimeouts:
    def __init__(
        self,
        *,
        create: typing.Optional[builtins.str] = None,
        delete: typing.Optional[builtins.str] = None,
        read: typing.Optional[builtins.str] = None,
        update: typing.Optional[builtins.str] = None,
    ) -> None:
        """
        :param create: 
        :param delete: 
        :param read: 
        :param update: 
        """
        self._values: typing.Dict[str, typing.Any] = {}
        if create is not None:
            self._values["create"] = create
        if delete is not None:
            self._values["delete"] = delete
        if read is not None:
            self._values["read"] = read
        if update is not None:
            self._values["update"] = update

    @builtins.property
    def create(self) -> typing.Optional[builtins.str]:
        result = self._values.get("create")
        return result

    @builtins.property
    def delete(self) -> typing.Optional[builtins.str]:
        result = self._values.get("delete")
        return result

    @builtins.property
    def read(self) -> typing.Optional[builtins.str]:
        result = self._values.get("read")
        return result

    @builtins.property
    def update(self) -> typing.Optional[builtins.str]:
        result = self._values.get("update")
        return result

    def __eq__(self, rhs: typing.Any) -> builtins.bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs: typing.Any) -> builtins.bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return "SubnetRouteTableAssociationTimeouts(%s)" % ", ".join(
            k + "=" + repr(v) for k, v in self._values.items()
        )


@jsii.data_type(
    jsii_type="@cdktf/provider-azurerm.SubnetTimeouts",
    jsii_struct_bases=[],
    name_mapping={
        "create": "create",
        "delete": "delete",
        "read": "read",
        "update": "update",
    },
)
class SubnetTimeouts:
    def __init__(
        self,
        *,
        create: typing.Optional[builtins.str] = None,
        delete: typing.Optional[builtins.str] = None,
        read: typing.Optional[builtins.str] = None,
        update: typing.Optional[builtins.str] = None,
    ) -> None:
        """
        :param create: 
        :param delete: 
        :param read: 
        :param update: 
        """
        self._values: typing.Dict[str, typing.Any] = {}
        if create is not None:
            self._values["create"] = create
        if delete is not None:
            self._values["delete"] = delete
        if read is not None:
            self._values["read"] = read
        if update is not None:
            self._values["update"] = update

    @builtins.property
    def create(self) -> typing.Optional[builtins.str]:
        result = self._values.get("create")
        return result

    @builtins.property
    def delete(self) -> typing.Optional[builtins.str]:
        result = self._values.get("delete")
        return result

    @builtins.property
    def read(self) -> typing.Optional[builtins.str]:
        result = self._values.get("read")
        return result

    @builtins.property
    def update(self) -> typing.Optional[builtins.str]:
        result = self._values.get("update")
        return result

    def __eq__(self, rhs: typing.Any) -> builtins.bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs: typing.Any) -> builtins.bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return "SubnetTimeouts(%s)" % ", ".join(
            k + "=" + repr(v) for k, v in self._values.items()
        )


class TemplateDeployment(
    cdktf.TerraformResource,
    metaclass=jsii.JSIIMeta,
    jsii_type="@cdktf/provider-azurerm.TemplateDeployment",
):
    def __init__(
        self,
        scope: constructs.Construct,
        id: builtins.str,
        *,
        deployment_mode: builtins.str,
        name: builtins.str,
        resource_group_name: builtins.str,
        parameters: typing.Optional[typing.Mapping[builtins.str, builtins.str]] = None,
        parameters_body: typing.Optional[builtins.str] = None,
        template_body: typing.Optional[builtins.str] = None,
        timeouts: typing.Optional["TemplateDeploymentTimeouts"] = None,
        count: typing.Optional[jsii.Number] = None,
        depends_on: typing.Optional[typing.List[cdktf.TerraformResource]] = None,
        lifecycle: typing.Optional[cdktf.TerraformResourceLifecycle] = None,
        provider: typing.Optional[cdktf.TerraformProvider] = None,
    ) -> None:
        """
        :param scope: -
        :param id: -
        :param deployment_mode: 
        :param name: 
        :param resource_group_name: 
        :param parameters: 
        :param parameters_body: 
        :param template_body: 
        :param timeouts: timeouts block.
        :param count: 
        :param depends_on: 
        :param lifecycle: 
        :param provider: 
        """
        config = TemplateDeploymentConfig(
            deployment_mode=deployment_mode,
            name=name,
            resource_group_name=resource_group_name,
            parameters=parameters,
            parameters_body=parameters_body,
            template_body=template_body,
            timeouts=timeouts,
            count=count,
            depends_on=depends_on,
            lifecycle=lifecycle,
            provider=provider,
        )

        jsii.create(TemplateDeployment, self, [scope, id, config])

    @jsii.member(jsii_name="outputs")
    def outputs(self, key: builtins.str) -> builtins.str:
        """
        :param key: -
        """
        return jsii.invoke(self, "outputs", [key])

    @jsii.member(jsii_name="synthesizeAttributes")
    def _synthesize_attributes(self) -> typing.Mapping[builtins.str, typing.Any]:
        return jsii.invoke(self, "synthesizeAttributes", [])

    @builtins.property # type: ignore
    @jsii.member(jsii_name="deploymentMode")
    def deployment_mode(self) -> builtins.str:
        return jsii.get(self, "deploymentMode")

    @deployment_mode.setter # type: ignore
    def deployment_mode(self, value: builtins.str) -> None:
        jsii.set(self, "deploymentMode", value)

    @builtins.property # type: ignore
    @jsii.member(jsii_name="name")
    def name(self) -> builtins.str:
        return jsii.get(self, "name")

    @name.setter # type: ignore
    def name(self, value: builtins.str) -> None:
        jsii.set(self, "name", value)

    @builtins.property # type: ignore
    @jsii.member(jsii_name="resourceGroupName")
    def resource_group_name(self) -> builtins.str:
        return jsii.get(self, "resourceGroupName")

    @resource_group_name.setter # type: ignore
    def resource_group_name(self, value: builtins.str) -> None:
        jsii.set(self, "resourceGroupName", value)

    @builtins.property # type: ignore
    @jsii.member(jsii_name="id")
    def id(self) -> typing.Optional[builtins.str]:
        return jsii.get(self, "id")

    @id.setter # type: ignore
    def id(self, value: typing.Optional[builtins.str]) -> None:
        jsii.set(self, "id", value)

    @builtins.property # type: ignore
    @jsii.member(jsii_name="parameters")
    def parameters(self) -> typing.Optional[typing.Mapping[builtins.str, builtins.str]]:
        return jsii.get(self, "parameters")

    @parameters.setter # type: ignore
    def parameters(
        self,
        value: typing.Optional[typing.Mapping[builtins.str, builtins.str]],
    ) -> None:
        jsii.set(self, "parameters", value)

    @builtins.property # type: ignore
    @jsii.member(jsii_name="parametersBody")
    def parameters_body(self) -> typing.Optional[builtins.str]:
        return jsii.get(self, "parametersBody")

    @parameters_body.setter # type: ignore
    def parameters_body(self, value: typing.Optional[builtins.str]) -> None:
        jsii.set(self, "parametersBody", value)

    @builtins.property # type: ignore
    @jsii.member(jsii_name="templateBody")
    def template_body(self) -> typing.Optional[builtins.str]:
        return jsii.get(self, "templateBody")

    @template_body.setter # type: ignore
    def template_body(self, value: typing.Optional[builtins.str]) -> None:
        jsii.set(self, "templateBody", value)

    @builtins.property # type: ignore
    @jsii.member(jsii_name="timeouts")
    def timeouts(self) -> typing.Optional["TemplateDeploymentTimeouts"]:
        return jsii.get(self, "timeouts")

    @timeouts.setter # type: ignore
    def timeouts(self, value: typing.Optional["TemplateDeploymentTimeouts"]) -> None:
        jsii.set(self, "timeouts", value)


@jsii.data_type(
    jsii_type="@cdktf/provider-azurerm.TemplateDeploymentConfig",
    jsii_struct_bases=[cdktf.TerraformMetaArguments],
    name_mapping={
        "count": "count",
        "depends_on": "dependsOn",
        "lifecycle": "lifecycle",
        "provider": "provider",
        "deployment_mode": "deploymentMode",
        "name": "name",
        "resource_group_name": "resourceGroupName",
        "parameters": "parameters",
        "parameters_body": "parametersBody",
        "template_body": "templateBody",
        "timeouts": "timeouts",
    },
)
class TemplateDeploymentConfig(cdktf.TerraformMetaArguments):
    def __init__(
        self,
        *,
        count: typing.Optional[jsii.Number] = None,
        depends_on: typing.Optional[typing.List[cdktf.TerraformResource]] = None,
        lifecycle: typing.Optional[cdktf.TerraformResourceLifecycle] = None,
        provider: typing.Optional[cdktf.TerraformProvider] = None,
        deployment_mode: builtins.str,
        name: builtins.str,
        resource_group_name: builtins.str,
        parameters: typing.Optional[typing.Mapping[builtins.str, builtins.str]] = None,
        parameters_body: typing.Optional[builtins.str] = None,
        template_body: typing.Optional[builtins.str] = None,
        timeouts: typing.Optional["TemplateDeploymentTimeouts"] = None,
    ) -> None:
        """
        :param count: 
        :param depends_on: 
        :param lifecycle: 
        :param provider: 
        :param deployment_mode: 
        :param name: 
        :param resource_group_name: 
        :param parameters: 
        :param parameters_body: 
        :param template_body: 
        :param timeouts: timeouts block.
        """
        if isinstance(lifecycle, dict):
            lifecycle = cdktf.TerraformResourceLifecycle(**lifecycle)
        if isinstance(timeouts, dict):
            timeouts = TemplateDeploymentTimeouts(**timeouts)
        self._values: typing.Dict[str, typing.Any] = {
            "deployment_mode": deployment_mode,
            "name": name,
            "resource_group_name": resource_group_name,
        }
        if count is not None:
            self._values["count"] = count
        if depends_on is not None:
            self._values["depends_on"] = depends_on
        if lifecycle is not None:
            self._values["lifecycle"] = lifecycle
        if provider is not None:
            self._values["provider"] = provider
        if parameters is not None:
            self._values["parameters"] = parameters
        if parameters_body is not None:
            self._values["parameters_body"] = parameters_body
        if template_body is not None:
            self._values["template_body"] = template_body
        if timeouts is not None:
            self._values["timeouts"] = timeouts

    @builtins.property
    def count(self) -> typing.Optional[jsii.Number]:
        """
        :stability: experimental
        """
        result = self._values.get("count")
        return result

    @builtins.property
    def depends_on(self) -> typing.Optional[typing.List[cdktf.TerraformResource]]:
        """
        :stability: experimental
        """
        result = self._values.get("depends_on")
        return result

    @builtins.property
    def lifecycle(self) -> typing.Optional[cdktf.TerraformResourceLifecycle]:
        """
        :stability: experimental
        """
        result = self._values.get("lifecycle")
        return result

    @builtins.property
    def provider(self) -> typing.Optional[cdktf.TerraformProvider]:
        """
        :stability: experimental
        """
        result = self._values.get("provider")
        return result

    @builtins.property
    def deployment_mode(self) -> builtins.str:
        result = self._values.get("deployment_mode")
        assert result is not None, "Required property 'deployment_mode' is missing"
        return result

    @builtins.property
    def name(self) -> builtins.str:
        result = self._values.get("name")
        assert result is not None, "Required property 'name' is missing"
        return result

    @builtins.property
    def resource_group_name(self) -> builtins.str:
        result = self._values.get("resource_group_name")
        assert result is not None, "Required property 'resource_group_name' is missing"
        return result

    @builtins.property
    def parameters(self) -> typing.Optional[typing.Mapping[builtins.str, builtins.str]]:
        result = self._values.get("parameters")
        return result

    @builtins.property
    def parameters_body(self) -> typing.Optional[builtins.str]:
        result = self._values.get("parameters_body")
        return result

    @builtins.property
    def template_body(self) -> typing.Optional[builtins.str]:
        result = self._values.get("template_body")
        return result

    @builtins.property
    def timeouts(self) -> typing.Optional["TemplateDeploymentTimeouts"]:
        """timeouts block."""
        result = self._values.get("timeouts")
        return result

    def __eq__(self, rhs: typing.Any) -> builtins.bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs: typing.Any) -> builtins.bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return "TemplateDeploymentConfig(%s)" % ", ".join(
            k + "=" + repr(v) for k, v in self._values.items()
        )


@jsii.data_type(
    jsii_type="@cdktf/provider-azurerm.TemplateDeploymentTimeouts",
    jsii_struct_bases=[],
    name_mapping={
        "create": "create",
        "delete": "delete",
        "read": "read",
        "update": "update",
    },
)
class TemplateDeploymentTimeouts:
    def __init__(
        self,
        *,
        create: typing.Optional[builtins.str] = None,
        delete: typing.Optional[builtins.str] = None,
        read: typing.Optional[builtins.str] = None,
        update: typing.Optional[builtins.str] = None,
    ) -> None:
        """
        :param create: 
        :param delete: 
        :param read: 
        :param update: 
        """
        self._values: typing.Dict[str, typing.Any] = {}
        if create is not None:
            self._values["create"] = create
        if delete is not None:
            self._values["delete"] = delete
        if read is not None:
            self._values["read"] = read
        if update is not None:
            self._values["update"] = update

    @builtins.property
    def create(self) -> typing.Optional[builtins.str]:
        result = self._values.get("create")
        return result

    @builtins.property
    def delete(self) -> typing.Optional[builtins.str]:
        result = self._values.get("delete")
        return result

    @builtins.property
    def read(self) -> typing.Optional[builtins.str]:
        result = self._values.get("read")
        return result

    @builtins.property
    def update(self) -> typing.Optional[builtins.str]:
        result = self._values.get("update")
        return result

    def __eq__(self, rhs: typing.Any) -> builtins.bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs: typing.Any) -> builtins.bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return "TemplateDeploymentTimeouts(%s)" % ", ".join(
            k + "=" + repr(v) for k, v in self._values.items()
        )


class TrafficManagerEndpoint(
    cdktf.TerraformResource,
    metaclass=jsii.JSIIMeta,
    jsii_type="@cdktf/provider-azurerm.TrafficManagerEndpoint",
):
    def __init__(
        self,
        scope: constructs.Construct,
        id: builtins.str,
        *,
        name: builtins.str,
        profile_name: builtins.str,
        resource_group_name: builtins.str,
        type: builtins.str,
        custom_header: typing.Optional[typing.List["TrafficManagerEndpointCustomHeader"]] = None,
        endpoint_location: typing.Optional[builtins.str] = None,
        endpoint_status: typing.Optional[builtins.str] = None,
        geo_mappings: typing.Optional[typing.List[builtins.str]] = None,
        min_child_endpoints: typing.Optional[jsii.Number] = None,
        priority: typing.Optional[jsii.Number] = None,
        subnet: typing.Optional[typing.List["TrafficManagerEndpointSubnet"]] = None,
        target: typing.Optional[builtins.str] = None,
        target_resource_id: typing.Optional[builtins.str] = None,
        timeouts: typing.Optional["TrafficManagerEndpointTimeouts"] = None,
        weight: typing.Optional[jsii.Number] = None,
        count: typing.Optional[jsii.Number] = None,
        depends_on: typing.Optional[typing.List[cdktf.TerraformResource]] = None,
        lifecycle: typing.Optional[cdktf.TerraformResourceLifecycle] = None,
        provider: typing.Optional[cdktf.TerraformProvider] = None,
    ) -> None:
        """
        :param scope: -
        :param id: -
        :param name: 
        :param profile_name: 
        :param resource_group_name: 
        :param type: 
        :param custom_header: custom_header block.
        :param endpoint_location: 
        :param endpoint_status: 
        :param geo_mappings: 
        :param min_child_endpoints: 
        :param priority: 
        :param subnet: subnet block.
        :param target: 
        :param target_resource_id: 
        :param timeouts: timeouts block.
        :param weight: 
        :param count: 
        :param depends_on: 
        :param lifecycle: 
        :param provider: 
        """
        config = TrafficManagerEndpointConfig(
            name=name,
            profile_name=profile_name,
            resource_group_name=resource_group_name,
            type=type,
            custom_header=custom_header,
            endpoint_location=endpoint_location,
            endpoint_status=endpoint_status,
            geo_mappings=geo_mappings,
            min_child_endpoints=min_child_endpoints,
            priority=priority,
            subnet=subnet,
            target=target,
            target_resource_id=target_resource_id,
            timeouts=timeouts,
            weight=weight,
            count=count,
            depends_on=depends_on,
            lifecycle=lifecycle,
            provider=provider,
        )

        jsii.create(TrafficManagerEndpoint, self, [scope, id, config])

    @jsii.member(jsii_name="synthesizeAttributes")
    def _synthesize_attributes(self) -> typing.Mapping[builtins.str, typing.Any]:
        return jsii.invoke(self, "synthesizeAttributes", [])

    @builtins.property # type: ignore
    @jsii.member(jsii_name="endpointMonitorStatus")
    def endpoint_monitor_status(self) -> builtins.str:
        return jsii.get(self, "endpointMonitorStatus")

    @builtins.property # type: ignore
    @jsii.member(jsii_name="name")
    def name(self) -> builtins.str:
        return jsii.get(self, "name")

    @name.setter # type: ignore
    def name(self, value: builtins.str) -> None:
        jsii.set(self, "name", value)

    @builtins.property # type: ignore
    @jsii.member(jsii_name="profileName")
    def profile_name(self) -> builtins.str:
        return jsii.get(self, "profileName")

    @profile_name.setter # type: ignore
    def profile_name(self, value: builtins.str) -> None:
        jsii.set(self, "profileName", value)

    @builtins.property # type: ignore
    @jsii.member(jsii_name="resourceGroupName")
    def resource_group_name(self) -> builtins.str:
        return jsii.get(self, "resourceGroupName")

    @resource_group_name.setter # type: ignore
    def resource_group_name(self, value: builtins.str) -> None:
        jsii.set(self, "resourceGroupName", value)

    @builtins.property # type: ignore
    @jsii.member(jsii_name="type")
    def type(self) -> builtins.str:
        return jsii.get(self, "type")

    @type.setter # type: ignore
    def type(self, value: builtins.str) -> None:
        jsii.set(self, "type", value)

    @builtins.property # type: ignore
    @jsii.member(jsii_name="customHeader")
    def custom_header(
        self,
    ) -> typing.Optional[typing.List["TrafficManagerEndpointCustomHeader"]]:
        return jsii.get(self, "customHeader")

    @custom_header.setter # type: ignore
    def custom_header(
        self,
        value: typing.Optional[typing.List["TrafficManagerEndpointCustomHeader"]],
    ) -> None:
        jsii.set(self, "customHeader", value)

    @builtins.property # type: ignore
    @jsii.member(jsii_name="endpointLocation")
    def endpoint_location(self) -> typing.Optional[builtins.str]:
        return jsii.get(self, "endpointLocation")

    @endpoint_location.setter # type: ignore
    def endpoint_location(self, value: typing.Optional[builtins.str]) -> None:
        jsii.set(self, "endpointLocation", value)

    @builtins.property # type: ignore
    @jsii.member(jsii_name="endpointStatus")
    def endpoint_status(self) -> typing.Optional[builtins.str]:
        return jsii.get(self, "endpointStatus")

    @endpoint_status.setter # type: ignore
    def endpoint_status(self, value: typing.Optional[builtins.str]) -> None:
        jsii.set(self, "endpointStatus", value)

    @builtins.property # type: ignore
    @jsii.member(jsii_name="geoMappings")
    def geo_mappings(self) -> typing.Optional[typing.List[builtins.str]]:
        return jsii.get(self, "geoMappings")

    @geo_mappings.setter # type: ignore
    def geo_mappings(self, value: typing.Optional[typing.List[builtins.str]]) -> None:
        jsii.set(self, "geoMappings", value)

    @builtins.property # type: ignore
    @jsii.member(jsii_name="id")
    def id(self) -> typing.Optional[builtins.str]:
        return jsii.get(self, "id")

    @id.setter # type: ignore
    def id(self, value: typing.Optional[builtins.str]) -> None:
        jsii.set(self, "id", value)

    @builtins.property # type: ignore
    @jsii.member(jsii_name="minChildEndpoints")
    def min_child_endpoints(self) -> typing.Optional[jsii.Number]:
        return jsii.get(self, "minChildEndpoints")

    @min_child_endpoints.setter # type: ignore
    def min_child_endpoints(self, value: typing.Optional[jsii.Number]) -> None:
        jsii.set(self, "minChildEndpoints", value)

    @builtins.property # type: ignore
    @jsii.member(jsii_name="priority")
    def priority(self) -> typing.Optional[jsii.Number]:
        return jsii.get(self, "priority")

    @priority.setter # type: ignore
    def priority(self, value: typing.Optional[jsii.Number]) -> None:
        jsii.set(self, "priority", value)

    @builtins.property # type: ignore
    @jsii.member(jsii_name="subnet")
    def subnet(self) -> typing.Optional[typing.List["TrafficManagerEndpointSubnet"]]:
        return jsii.get(self, "subnet")

    @subnet.setter # type: ignore
    def subnet(
        self,
        value: typing.Optional[typing.List["TrafficManagerEndpointSubnet"]],
    ) -> None:
        jsii.set(self, "subnet", value)

    @builtins.property # type: ignore
    @jsii.member(jsii_name="target")
    def target(self) -> typing.Optional[builtins.str]:
        return jsii.get(self, "target")

    @target.setter # type: ignore
    def target(self, value: typing.Optional[builtins.str]) -> None:
        jsii.set(self, "target", value)

    @builtins.property # type: ignore
    @jsii.member(jsii_name="targetResourceId")
    def target_resource_id(self) -> typing.Optional[builtins.str]:
        return jsii.get(self, "targetResourceId")

    @target_resource_id.setter # type: ignore
    def target_resource_id(self, value: typing.Optional[builtins.str]) -> None:
        jsii.set(self, "targetResourceId", value)

    @builtins.property # type: ignore
    @jsii.member(jsii_name="timeouts")
    def timeouts(self) -> typing.Optional["TrafficManagerEndpointTimeouts"]:
        return jsii.get(self, "timeouts")

    @timeouts.setter # type: ignore
    def timeouts(
        self,
        value: typing.Optional["TrafficManagerEndpointTimeouts"],
    ) -> None:
        jsii.set(self, "timeouts", value)

    @builtins.property # type: ignore
    @jsii.member(jsii_name="weight")
    def weight(self) -> typing.Optional[jsii.Number]:
        return jsii.get(self, "weight")

    @weight.setter # type: ignore
    def weight(self, value: typing.Optional[jsii.Number]) -> None:
        jsii.set(self, "weight", value)


@jsii.data_type(
    jsii_type="@cdktf/provider-azurerm.TrafficManagerEndpointConfig",
    jsii_struct_bases=[cdktf.TerraformMetaArguments],
    name_mapping={
        "count": "count",
        "depends_on": "dependsOn",
        "lifecycle": "lifecycle",
        "provider": "provider",
        "name": "name",
        "profile_name": "profileName",
        "resource_group_name": "resourceGroupName",
        "type": "type",
        "custom_header": "customHeader",
        "endpoint_location": "endpointLocation",
        "endpoint_status": "endpointStatus",
        "geo_mappings": "geoMappings",
        "min_child_endpoints": "minChildEndpoints",
        "priority": "priority",
        "subnet": "subnet",
        "target": "target",
        "target_resource_id": "targetResourceId",
        "timeouts": "timeouts",
        "weight": "weight",
    },
)
class TrafficManagerEndpointConfig(cdktf.TerraformMetaArguments):
    def __init__(
        self,
        *,
        count: typing.Optional[jsii.Number] = None,
        depends_on: typing.Optional[typing.List[cdktf.TerraformResource]] = None,
        lifecycle: typing.Optional[cdktf.TerraformResourceLifecycle] = None,
        provider: typing.Optional[cdktf.TerraformProvider] = None,
        name: builtins.str,
        profile_name: builtins.str,
        resource_group_name: builtins.str,
        type: builtins.str,
        custom_header: typing.Optional[typing.List["TrafficManagerEndpointCustomHeader"]] = None,
        endpoint_location: typing.Optional[builtins.str] = None,
        endpoint_status: typing.Optional[builtins.str] = None,
        geo_mappings: typing.Optional[typing.List[builtins.str]] = None,
        min_child_endpoints: typing.Optional[jsii.Number] = None,
        priority: typing.Optional[jsii.Number] = None,
        subnet: typing.Optional[typing.List["TrafficManagerEndpointSubnet"]] = None,
        target: typing.Optional[builtins.str] = None,
        target_resource_id: typing.Optional[builtins.str] = None,
        timeouts: typing.Optional["TrafficManagerEndpointTimeouts"] = None,
        weight: typing.Optional[jsii.Number] = None,
    ) -> None:
        """
        :param count: 
        :param depends_on: 
        :param lifecycle: 
        :param provider: 
        :param name: 
        :param profile_name: 
        :param resource_group_name: 
        :param type: 
        :param custom_header: custom_header block.
        :param endpoint_location: 
        :param endpoint_status: 
        :param geo_mappings: 
        :param min_child_endpoints: 
        :param priority: 
        :param subnet: subnet block.
        :param target: 
        :param target_resource_id: 
        :param timeouts: timeouts block.
        :param weight: 
        """
        if isinstance(lifecycle, dict):
            lifecycle = cdktf.TerraformResourceLifecycle(**lifecycle)
        if isinstance(timeouts, dict):
            timeouts = TrafficManagerEndpointTimeouts(**timeouts)
        self._values: typing.Dict[str, typing.Any] = {
            "name": name,
            "profile_name": profile_name,
            "resource_group_name": resource_group_name,
            "type": type,
        }
        if count is not None:
            self._values["count"] = count
        if depends_on is not None:
            self._values["depends_on"] = depends_on
        if lifecycle is not None:
            self._values["lifecycle"] = lifecycle
        if provider is not None:
            self._values["provider"] = provider
        if custom_header is not None:
            self._values["custom_header"] = custom_header
        if endpoint_location is not None:
            self._values["endpoint_location"] = endpoint_location
        if endpoint_status is not None:
            self._values["endpoint_status"] = endpoint_status
        if geo_mappings is not None:
            self._values["geo_mappings"] = geo_mappings
        if min_child_endpoints is not None:
            self._values["min_child_endpoints"] = min_child_endpoints
        if priority is not None:
            self._values["priority"] = priority
        if subnet is not None:
            self._values["subnet"] = subnet
        if target is not None:
            self._values["target"] = target
        if target_resource_id is not None:
            self._values["target_resource_id"] = target_resource_id
        if timeouts is not None:
            self._values["timeouts"] = timeouts
        if weight is not None:
            self._values["weight"] = weight

    @builtins.property
    def count(self) -> typing.Optional[jsii.Number]:
        """
        :stability: experimental
        """
        result = self._values.get("count")
        return result

    @builtins.property
    def depends_on(self) -> typing.Optional[typing.List[cdktf.TerraformResource]]:
        """
        :stability: experimental
        """
        result = self._values.get("depends_on")
        return result

    @builtins.property
    def lifecycle(self) -> typing.Optional[cdktf.TerraformResourceLifecycle]:
        """
        :stability: experimental
        """
        result = self._values.get("lifecycle")
        return result

    @builtins.property
    def provider(self) -> typing.Optional[cdktf.TerraformProvider]:
        """
        :stability: experimental
        """
        result = self._values.get("provider")
        return result

    @builtins.property
    def name(self) -> builtins.str:
        result = self._values.get("name")
        assert result is not None, "Required property 'name' is missing"
        return result

    @builtins.property
    def profile_name(self) -> builtins.str:
        result = self._values.get("profile_name")
        assert result is not None, "Required property 'profile_name' is missing"
        return result

    @builtins.property
    def resource_group_name(self) -> builtins.str:
        result = self._values.get("resource_group_name")
        assert result is not None, "Required property 'resource_group_name' is missing"
        return result

    @builtins.property
    def type(self) -> builtins.str:
        result = self._values.get("type")
        assert result is not None, "Required property 'type' is missing"
        return result

    @builtins.property
    def custom_header(
        self,
    ) -> typing.Optional[typing.List["TrafficManagerEndpointCustomHeader"]]:
        """custom_header block."""
        result = self._values.get("custom_header")
        return result

    @builtins.property
    def endpoint_location(self) -> typing.Optional[builtins.str]:
        result = self._values.get("endpoint_location")
        return result

    @builtins.property
    def endpoint_status(self) -> typing.Optional[builtins.str]:
        result = self._values.get("endpoint_status")
        return result

    @builtins.property
    def geo_mappings(self) -> typing.Optional[typing.List[builtins.str]]:
        result = self._values.get("geo_mappings")
        return result

    @builtins.property
    def min_child_endpoints(self) -> typing.Optional[jsii.Number]:
        result = self._values.get("min_child_endpoints")
        return result

    @builtins.property
    def priority(self) -> typing.Optional[jsii.Number]:
        result = self._values.get("priority")
        return result

    @builtins.property
    def subnet(self) -> typing.Optional[typing.List["TrafficManagerEndpointSubnet"]]:
        """subnet block."""
        result = self._values.get("subnet")
        return result

    @builtins.property
    def target(self) -> typing.Optional[builtins.str]:
        result = self._values.get("target")
        return result

    @builtins.property
    def target_resource_id(self) -> typing.Optional[builtins.str]:
        result = self._values.get("target_resource_id")
        return result

    @builtins.property
    def timeouts(self) -> typing.Optional["TrafficManagerEndpointTimeouts"]:
        """timeouts block."""
        result = self._values.get("timeouts")
        return result

    @builtins.property
    def weight(self) -> typing.Optional[jsii.Number]:
        result = self._values.get("weight")
        return result

    def __eq__(self, rhs: typing.Any) -> builtins.bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs: typing.Any) -> builtins.bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return "TrafficManagerEndpointConfig(%s)" % ", ".join(
            k + "=" + repr(v) for k, v in self._values.items()
        )


@jsii.data_type(
    jsii_type="@cdktf/provider-azurerm.TrafficManagerEndpointCustomHeader",
    jsii_struct_bases=[],
    name_mapping={"name": "name", "value": "value"},
)
class TrafficManagerEndpointCustomHeader:
    def __init__(self, *, name: builtins.str, value: builtins.str) -> None:
        """
        :param name: 
        :param value: 
        """
        self._values: typing.Dict[str, typing.Any] = {
            "name": name,
            "value": value,
        }

    @builtins.property
    def name(self) -> builtins.str:
        result = self._values.get("name")
        assert result is not None, "Required property 'name' is missing"
        return result

    @builtins.property
    def value(self) -> builtins.str:
        result = self._values.get("value")
        assert result is not None, "Required property 'value' is missing"
        return result

    def __eq__(self, rhs: typing.Any) -> builtins.bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs: typing.Any) -> builtins.bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return "TrafficManagerEndpointCustomHeader(%s)" % ", ".join(
            k + "=" + repr(v) for k, v in self._values.items()
        )


@jsii.data_type(
    jsii_type="@cdktf/provider-azurerm.TrafficManagerEndpointSubnet",
    jsii_struct_bases=[],
    name_mapping={"first": "first", "last": "last", "scope": "scope"},
)
class TrafficManagerEndpointSubnet:
    def __init__(
        self,
        *,
        first: builtins.str,
        last: typing.Optional[builtins.str] = None,
        scope: typing.Optional[jsii.Number] = None,
    ) -> None:
        """
        :param first: 
        :param last: 
        :param scope: 
        """
        self._values: typing.Dict[str, typing.Any] = {
            "first": first,
        }
        if last is not None:
            self._values["last"] = last
        if scope is not None:
            self._values["scope"] = scope

    @builtins.property
    def first(self) -> builtins.str:
        result = self._values.get("first")
        assert result is not None, "Required property 'first' is missing"
        return result

    @builtins.property
    def last(self) -> typing.Optional[builtins.str]:
        result = self._values.get("last")
        return result

    @builtins.property
    def scope(self) -> typing.Optional[jsii.Number]:
        result = self._values.get("scope")
        return result

    def __eq__(self, rhs: typing.Any) -> builtins.bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs: typing.Any) -> builtins.bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return "TrafficManagerEndpointSubnet(%s)" % ", ".join(
            k + "=" + repr(v) for k, v in self._values.items()
        )


@jsii.data_type(
    jsii_type="@cdktf/provider-azurerm.TrafficManagerEndpointTimeouts",
    jsii_struct_bases=[],
    name_mapping={
        "create": "create",
        "delete": "delete",
        "read": "read",
        "update": "update",
    },
)
class TrafficManagerEndpointTimeouts:
    def __init__(
        self,
        *,
        create: typing.Optional[builtins.str] = None,
        delete: typing.Optional[builtins.str] = None,
        read: typing.Optional[builtins.str] = None,
        update: typing.Optional[builtins.str] = None,
    ) -> None:
        """
        :param create: 
        :param delete: 
        :param read: 
        :param update: 
        """
        self._values: typing.Dict[str, typing.Any] = {}
        if create is not None:
            self._values["create"] = create
        if delete is not None:
            self._values["delete"] = delete
        if read is not None:
            self._values["read"] = read
        if update is not None:
            self._values["update"] = update

    @builtins.property
    def create(self) -> typing.Optional[builtins.str]:
        result = self._values.get("create")
        return result

    @builtins.property
    def delete(self) -> typing.Optional[builtins.str]:
        result = self._values.get("delete")
        return result

    @builtins.property
    def read(self) -> typing.Optional[builtins.str]:
        result = self._values.get("read")
        return result

    @builtins.property
    def update(self) -> typing.Optional[builtins.str]:
        result = self._values.get("update")
        return result

    def __eq__(self, rhs: typing.Any) -> builtins.bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs: typing.Any) -> builtins.bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return "TrafficManagerEndpointTimeouts(%s)" % ", ".join(
            k + "=" + repr(v) for k, v in self._values.items()
        )


class TrafficManagerProfile(
    cdktf.TerraformResource,
    metaclass=jsii.JSIIMeta,
    jsii_type="@cdktf/provider-azurerm.TrafficManagerProfile",
):
    def __init__(
        self,
        scope: constructs.Construct,
        id: builtins.str,
        *,
        dns_config: typing.List["TrafficManagerProfileDnsConfig"],
        monitor_config: typing.List["TrafficManagerProfileMonitorConfig"],
        name: builtins.str,
        resource_group_name: builtins.str,
        traffic_routing_method: builtins.str,
        profile_status: typing.Optional[builtins.str] = None,
        tags: typing.Optional[typing.Mapping[builtins.str, builtins.str]] = None,
        timeouts: typing.Optional["TrafficManagerProfileTimeouts"] = None,
        count: typing.Optional[jsii.Number] = None,
        depends_on: typing.Optional[typing.List[cdktf.TerraformResource]] = None,
        lifecycle: typing.Optional[cdktf.TerraformResourceLifecycle] = None,
        provider: typing.Optional[cdktf.TerraformProvider] = None,
    ) -> None:
        """
        :param scope: -
        :param id: -
        :param dns_config: dns_config block.
        :param monitor_config: monitor_config block.
        :param name: 
        :param resource_group_name: 
        :param traffic_routing_method: 
        :param profile_status: 
        :param tags: 
        :param timeouts: timeouts block.
        :param count: 
        :param depends_on: 
        :param lifecycle: 
        :param provider: 
        """
        config = TrafficManagerProfileConfig(
            dns_config=dns_config,
            monitor_config=monitor_config,
            name=name,
            resource_group_name=resource_group_name,
            traffic_routing_method=traffic_routing_method,
            profile_status=profile_status,
            tags=tags,
            timeouts=timeouts,
            count=count,
            depends_on=depends_on,
            lifecycle=lifecycle,
            provider=provider,
        )

        jsii.create(TrafficManagerProfile, self, [scope, id, config])

    @jsii.member(jsii_name="synthesizeAttributes")
    def _synthesize_attributes(self) -> typing.Mapping[builtins.str, typing.Any]:
        return jsii.invoke(self, "synthesizeAttributes", [])

    @builtins.property # type: ignore
    @jsii.member(jsii_name="fqdn")
    def fqdn(self) -> builtins.str:
        return jsii.get(self, "fqdn")

    @builtins.property # type: ignore
    @jsii.member(jsii_name="dnsConfig")
    def dns_config(self) -> typing.List["TrafficManagerProfileDnsConfig"]:
        return jsii.get(self, "dnsConfig")

    @dns_config.setter # type: ignore
    def dns_config(self, value: typing.List["TrafficManagerProfileDnsConfig"]) -> None:
        jsii.set(self, "dnsConfig", value)

    @builtins.property # type: ignore
    @jsii.member(jsii_name="monitorConfig")
    def monitor_config(self) -> typing.List["TrafficManagerProfileMonitorConfig"]:
        return jsii.get(self, "monitorConfig")

    @monitor_config.setter # type: ignore
    def monitor_config(
        self,
        value: typing.List["TrafficManagerProfileMonitorConfig"],
    ) -> None:
        jsii.set(self, "monitorConfig", value)

    @builtins.property # type: ignore
    @jsii.member(jsii_name="name")
    def name(self) -> builtins.str:
        return jsii.get(self, "name")

    @name.setter # type: ignore
    def name(self, value: builtins.str) -> None:
        jsii.set(self, "name", value)

    @builtins.property # type: ignore
    @jsii.member(jsii_name="resourceGroupName")
    def resource_group_name(self) -> builtins.str:
        return jsii.get(self, "resourceGroupName")

    @resource_group_name.setter # type: ignore
    def resource_group_name(self, value: builtins.str) -> None:
        jsii.set(self, "resourceGroupName", value)

    @builtins.property # type: ignore
    @jsii.member(jsii_name="trafficRoutingMethod")
    def traffic_routing_method(self) -> builtins.str:
        return jsii.get(self, "trafficRoutingMethod")

    @traffic_routing_method.setter # type: ignore
    def traffic_routing_method(self, value: builtins.str) -> None:
        jsii.set(self, "trafficRoutingMethod", value)

    @builtins.property # type: ignore
    @jsii.member(jsii_name="id")
    def id(self) -> typing.Optional[builtins.str]:
        return jsii.get(self, "id")

    @id.setter # type: ignore
    def id(self, value: typing.Optional[builtins.str]) -> None:
        jsii.set(self, "id", value)

    @builtins.property # type: ignore
    @jsii.member(jsii_name="profileStatus")
    def profile_status(self) -> typing.Optional[builtins.str]:
        return jsii.get(self, "profileStatus")

    @profile_status.setter # type: ignore
    def profile_status(self, value: typing.Optional[builtins.str]) -> None:
        jsii.set(self, "profileStatus", value)

    @builtins.property # type: ignore
    @jsii.member(jsii_name="tags")
    def tags(self) -> typing.Optional[typing.Mapping[builtins.str, builtins.str]]:
        return jsii.get(self, "tags")

    @tags.setter # type: ignore
    def tags(
        self,
        value: typing.Optional[typing.Mapping[builtins.str, builtins.str]],
    ) -> None:
        jsii.set(self, "tags", value)

    @builtins.property # type: ignore
    @jsii.member(jsii_name="timeouts")
    def timeouts(self) -> typing.Optional["TrafficManagerProfileTimeouts"]:
        return jsii.get(self, "timeouts")

    @timeouts.setter # type: ignore
    def timeouts(self, value: typing.Optional["TrafficManagerProfileTimeouts"]) -> None:
        jsii.set(self, "timeouts", value)


@jsii.data_type(
    jsii_type="@cdktf/provider-azurerm.TrafficManagerProfileConfig",
    jsii_struct_bases=[cdktf.TerraformMetaArguments],
    name_mapping={
        "count": "count",
        "depends_on": "dependsOn",
        "lifecycle": "lifecycle",
        "provider": "provider",
        "dns_config": "dnsConfig",
        "monitor_config": "monitorConfig",
        "name": "name",
        "resource_group_name": "resourceGroupName",
        "traffic_routing_method": "trafficRoutingMethod",
        "profile_status": "profileStatus",
        "tags": "tags",
        "timeouts": "timeouts",
    },
)
class TrafficManagerProfileConfig(cdktf.TerraformMetaArguments):
    def __init__(
        self,
        *,
        count: typing.Optional[jsii.Number] = None,
        depends_on: typing.Optional[typing.List[cdktf.TerraformResource]] = None,
        lifecycle: typing.Optional[cdktf.TerraformResourceLifecycle] = None,
        provider: typing.Optional[cdktf.TerraformProvider] = None,
        dns_config: typing.List["TrafficManagerProfileDnsConfig"],
        monitor_config: typing.List["TrafficManagerProfileMonitorConfig"],
        name: builtins.str,
        resource_group_name: builtins.str,
        traffic_routing_method: builtins.str,
        profile_status: typing.Optional[builtins.str] = None,
        tags: typing.Optional[typing.Mapping[builtins.str, builtins.str]] = None,
        timeouts: typing.Optional["TrafficManagerProfileTimeouts"] = None,
    ) -> None:
        """
        :param count: 
        :param depends_on: 
        :param lifecycle: 
        :param provider: 
        :param dns_config: dns_config block.
        :param monitor_config: monitor_config block.
        :param name: 
        :param resource_group_name: 
        :param traffic_routing_method: 
        :param profile_status: 
        :param tags: 
        :param timeouts: timeouts block.
        """
        if isinstance(lifecycle, dict):
            lifecycle = cdktf.TerraformResourceLifecycle(**lifecycle)
        if isinstance(timeouts, dict):
            timeouts = TrafficManagerProfileTimeouts(**timeouts)
        self._values: typing.Dict[str, typing.Any] = {
            "dns_config": dns_config,
            "monitor_config": monitor_config,
            "name": name,
            "resource_group_name": resource_group_name,
            "traffic_routing_method": traffic_routing_method,
        }
        if count is not None:
            self._values["count"] = count
        if depends_on is not None:
            self._values["depends_on"] = depends_on
        if lifecycle is not None:
            self._values["lifecycle"] = lifecycle
        if provider is not None:
            self._values["provider"] = provider
        if profile_status is not None:
            self._values["profile_status"] = profile_status
        if tags is not None:
            self._values["tags"] = tags
        if timeouts is not None:
            self._values["timeouts"] = timeouts

    @builtins.property
    def count(self) -> typing.Optional[jsii.Number]:
        """
        :stability: experimental
        """
        result = self._values.get("count")
        return result

    @builtins.property
    def depends_on(self) -> typing.Optional[typing.List[cdktf.TerraformResource]]:
        """
        :stability: experimental
        """
        result = self._values.get("depends_on")
        return result

    @builtins.property
    def lifecycle(self) -> typing.Optional[cdktf.TerraformResourceLifecycle]:
        """
        :stability: experimental
        """
        result = self._values.get("lifecycle")
        return result

    @builtins.property
    def provider(self) -> typing.Optional[cdktf.TerraformProvider]:
        """
        :stability: experimental
        """
        result = self._values.get("provider")
        return result

    @builtins.property
    def dns_config(self) -> typing.List["TrafficManagerProfileDnsConfig"]:
        """dns_config block."""
        result = self._values.get("dns_config")
        assert result is not None, "Required property 'dns_config' is missing"
        return result

    @builtins.property
    def monitor_config(self) -> typing.List["TrafficManagerProfileMonitorConfig"]:
        """monitor_config block."""
        result = self._values.get("monitor_config")
        assert result is not None, "Required property 'monitor_config' is missing"
        return result

    @builtins.property
    def name(self) -> builtins.str:
        result = self._values.get("name")
        assert result is not None, "Required property 'name' is missing"
        return result

    @builtins.property
    def resource_group_name(self) -> builtins.str:
        result = self._values.get("resource_group_name")
        assert result is not None, "Required property 'resource_group_name' is missing"
        return result

    @builtins.property
    def traffic_routing_method(self) -> builtins.str:
        result = self._values.get("traffic_routing_method")
        assert result is not None, "Required property 'traffic_routing_method' is missing"
        return result

    @builtins.property
    def profile_status(self) -> typing.Optional[builtins.str]:
        result = self._values.get("profile_status")
        return result

    @builtins.property
    def tags(self) -> typing.Optional[typing.Mapping[builtins.str, builtins.str]]:
        result = self._values.get("tags")
        return result

    @builtins.property
    def timeouts(self) -> typing.Optional["TrafficManagerProfileTimeouts"]:
        """timeouts block."""
        result = self._values.get("timeouts")
        return result

    def __eq__(self, rhs: typing.Any) -> builtins.bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs: typing.Any) -> builtins.bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return "TrafficManagerProfileConfig(%s)" % ", ".join(
            k + "=" + repr(v) for k, v in self._values.items()
        )


@jsii.data_type(
    jsii_type="@cdktf/provider-azurerm.TrafficManagerProfileDnsConfig",
    jsii_struct_bases=[],
    name_mapping={"relative_name": "relativeName", "ttl": "ttl"},
)
class TrafficManagerProfileDnsConfig:
    def __init__(self, *, relative_name: builtins.str, ttl: jsii.Number) -> None:
        """
        :param relative_name: 
        :param ttl: 
        """
        self._values: typing.Dict[str, typing.Any] = {
            "relative_name": relative_name,
            "ttl": ttl,
        }

    @builtins.property
    def relative_name(self) -> builtins.str:
        result = self._values.get("relative_name")
        assert result is not None, "Required property 'relative_name' is missing"
        return result

    @builtins.property
    def ttl(self) -> jsii.Number:
        result = self._values.get("ttl")
        assert result is not None, "Required property 'ttl' is missing"
        return result

    def __eq__(self, rhs: typing.Any) -> builtins.bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs: typing.Any) -> builtins.bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return "TrafficManagerProfileDnsConfig(%s)" % ", ".join(
            k + "=" + repr(v) for k, v in self._values.items()
        )


@jsii.data_type(
    jsii_type="@cdktf/provider-azurerm.TrafficManagerProfileMonitorConfig",
    jsii_struct_bases=[],
    name_mapping={
        "port": "port",
        "protocol": "protocol",
        "expected_status_code_ranges": "expectedStatusCodeRanges",
        "interval_in_seconds": "intervalInSeconds",
        "path": "path",
        "timeout_in_seconds": "timeoutInSeconds",
        "tolerated_number_of_failures": "toleratedNumberOfFailures",
    },
)
class TrafficManagerProfileMonitorConfig:
    def __init__(
        self,
        *,
        port: jsii.Number,
        protocol: builtins.str,
        expected_status_code_ranges: typing.Optional[typing.List[builtins.str]] = None,
        interval_in_seconds: typing.Optional[jsii.Number] = None,
        path: typing.Optional[builtins.str] = None,
        timeout_in_seconds: typing.Optional[jsii.Number] = None,
        tolerated_number_of_failures: typing.Optional[jsii.Number] = None,
    ) -> None:
        """
        :param port: 
        :param protocol: 
        :param expected_status_code_ranges: 
        :param interval_in_seconds: 
        :param path: 
        :param timeout_in_seconds: 
        :param tolerated_number_of_failures: 
        """
        self._values: typing.Dict[str, typing.Any] = {
            "port": port,
            "protocol": protocol,
        }
        if expected_status_code_ranges is not None:
            self._values["expected_status_code_ranges"] = expected_status_code_ranges
        if interval_in_seconds is not None:
            self._values["interval_in_seconds"] = interval_in_seconds
        if path is not None:
            self._values["path"] = path
        if timeout_in_seconds is not None:
            self._values["timeout_in_seconds"] = timeout_in_seconds
        if tolerated_number_of_failures is not None:
            self._values["tolerated_number_of_failures"] = tolerated_number_of_failures

    @builtins.property
    def port(self) -> jsii.Number:
        result = self._values.get("port")
        assert result is not None, "Required property 'port' is missing"
        return result

    @builtins.property
    def protocol(self) -> builtins.str:
        result = self._values.get("protocol")
        assert result is not None, "Required property 'protocol' is missing"
        return result

    @builtins.property
    def expected_status_code_ranges(self) -> typing.Optional[typing.List[builtins.str]]:
        result = self._values.get("expected_status_code_ranges")
        return result

    @builtins.property
    def interval_in_seconds(self) -> typing.Optional[jsii.Number]:
        result = self._values.get("interval_in_seconds")
        return result

    @builtins.property
    def path(self) -> typing.Optional[builtins.str]:
        result = self._values.get("path")
        return result

    @builtins.property
    def timeout_in_seconds(self) -> typing.Optional[jsii.Number]:
        result = self._values.get("timeout_in_seconds")
        return result

    @builtins.property
    def tolerated_number_of_failures(self) -> typing.Optional[jsii.Number]:
        result = self._values.get("tolerated_number_of_failures")
        return result

    def __eq__(self, rhs: typing.Any) -> builtins.bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs: typing.Any) -> builtins.bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return "TrafficManagerProfileMonitorConfig(%s)" % ", ".join(
            k + "=" + repr(v) for k, v in self._values.items()
        )


@jsii.data_type(
    jsii_type="@cdktf/provider-azurerm.TrafficManagerProfileTimeouts",
    jsii_struct_bases=[],
    name_mapping={
        "create": "create",
        "delete": "delete",
        "read": "read",
        "update": "update",
    },
)
class TrafficManagerProfileTimeouts:
    def __init__(
        self,
        *,
        create: typing.Optional[builtins.str] = None,
        delete: typing.Optional[builtins.str] = None,
        read: typing.Optional[builtins.str] = None,
        update: typing.Optional[builtins.str] = None,
    ) -> None:
        """
        :param create: 
        :param delete: 
        :param read: 
        :param update: 
        """
        self._values: typing.Dict[str, typing.Any] = {}
        if create is not None:
            self._values["create"] = create
        if delete is not None:
            self._values["delete"] = delete
        if read is not None:
            self._values["read"] = read
        if update is not None:
            self._values["update"] = update

    @builtins.property
    def create(self) -> typing.Optional[builtins.str]:
        result = self._values.get("create")
        return result

    @builtins.property
    def delete(self) -> typing.Optional[builtins.str]:
        result = self._values.get("delete")
        return result

    @builtins.property
    def read(self) -> typing.Optional[builtins.str]:
        result = self._values.get("read")
        return result

    @builtins.property
    def update(self) -> typing.Optional[builtins.str]:
        result = self._values.get("update")
        return result

    def __eq__(self, rhs: typing.Any) -> builtins.bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs: typing.Any) -> builtins.bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return "TrafficManagerProfileTimeouts(%s)" % ", ".join(
            k + "=" + repr(v) for k, v in self._values.items()
        )


class UserAssignedIdentity(
    cdktf.TerraformResource,
    metaclass=jsii.JSIIMeta,
    jsii_type="@cdktf/provider-azurerm.UserAssignedIdentity",
):
    def __init__(
        self,
        scope: constructs.Construct,
        id: builtins.str,
        *,
        location: builtins.str,
        name: builtins.str,
        resource_group_name: builtins.str,
        tags: typing.Optional[typing.Mapping[builtins.str, builtins.str]] = None,
        timeouts: typing.Optional["UserAssignedIdentityTimeouts"] = None,
        count: typing.Optional[jsii.Number] = None,
        depends_on: typing.Optional[typing.List[cdktf.TerraformResource]] = None,
        lifecycle: typing.Optional[cdktf.TerraformResourceLifecycle] = None,
        provider: typing.Optional[cdktf.TerraformProvider] = None,
    ) -> None:
        """
        :param scope: -
        :param id: -
        :param location: 
        :param name: 
        :param resource_group_name: 
        :param tags: 
        :param timeouts: timeouts block.
        :param count: 
        :param depends_on: 
        :param lifecycle: 
        :param provider: 
        """
        config = UserAssignedIdentityConfig(
            location=location,
            name=name,
            resource_group_name=resource_group_name,
            tags=tags,
            timeouts=timeouts,
            count=count,
            depends_on=depends_on,
            lifecycle=lifecycle,
            provider=provider,
        )

        jsii.create(UserAssignedIdentity, self, [scope, id, config])

    @jsii.member(jsii_name="synthesizeAttributes")
    def _synthesize_attributes(self) -> typing.Mapping[builtins.str, typing.Any]:
        return jsii.invoke(self, "synthesizeAttributes", [])

    @builtins.property # type: ignore
    @jsii.member(jsii_name="clientId")
    def client_id(self) -> builtins.str:
        return jsii.get(self, "clientId")

    @builtins.property # type: ignore
    @jsii.member(jsii_name="principalId")
    def principal_id(self) -> builtins.str:
        return jsii.get(self, "principalId")

    @builtins.property # type: ignore
    @jsii.member(jsii_name="location")
    def location(self) -> builtins.str:
        return jsii.get(self, "location")

    @location.setter # type: ignore
    def location(self, value: builtins.str) -> None:
        jsii.set(self, "location", value)

    @builtins.property # type: ignore
    @jsii.member(jsii_name="name")
    def name(self) -> builtins.str:
        return jsii.get(self, "name")

    @name.setter # type: ignore
    def name(self, value: builtins.str) -> None:
        jsii.set(self, "name", value)

    @builtins.property # type: ignore
    @jsii.member(jsii_name="resourceGroupName")
    def resource_group_name(self) -> builtins.str:
        return jsii.get(self, "resourceGroupName")

    @resource_group_name.setter # type: ignore
    def resource_group_name(self, value: builtins.str) -> None:
        jsii.set(self, "resourceGroupName", value)

    @builtins.property # type: ignore
    @jsii.member(jsii_name="id")
    def id(self) -> typing.Optional[builtins.str]:
        return jsii.get(self, "id")

    @id.setter # type: ignore
    def id(self, value: typing.Optional[builtins.str]) -> None:
        jsii.set(self, "id", value)

    @builtins.property # type: ignore
    @jsii.member(jsii_name="tags")
    def tags(self) -> typing.Optional[typing.Mapping[builtins.str, builtins.str]]:
        return jsii.get(self, "tags")

    @tags.setter # type: ignore
    def tags(
        self,
        value: typing.Optional[typing.Mapping[builtins.str, builtins.str]],
    ) -> None:
        jsii.set(self, "tags", value)

    @builtins.property # type: ignore
    @jsii.member(jsii_name="timeouts")
    def timeouts(self) -> typing.Optional["UserAssignedIdentityTimeouts"]:
        return jsii.get(self, "timeouts")

    @timeouts.setter # type: ignore
    def timeouts(self, value: typing.Optional["UserAssignedIdentityTimeouts"]) -> None:
        jsii.set(self, "timeouts", value)


@jsii.data_type(
    jsii_type="@cdktf/provider-azurerm.UserAssignedIdentityConfig",
    jsii_struct_bases=[cdktf.TerraformMetaArguments],
    name_mapping={
        "count": "count",
        "depends_on": "dependsOn",
        "lifecycle": "lifecycle",
        "provider": "provider",
        "location": "location",
        "name": "name",
        "resource_group_name": "resourceGroupName",
        "tags": "tags",
        "timeouts": "timeouts",
    },
)
class UserAssignedIdentityConfig(cdktf.TerraformMetaArguments):
    def __init__(
        self,
        *,
        count: typing.Optional[jsii.Number] = None,
        depends_on: typing.Optional[typing.List[cdktf.TerraformResource]] = None,
        lifecycle: typing.Optional[cdktf.TerraformResourceLifecycle] = None,
        provider: typing.Optional[cdktf.TerraformProvider] = None,
        location: builtins.str,
        name: builtins.str,
        resource_group_name: builtins.str,
        tags: typing.Optional[typing.Mapping[builtins.str, builtins.str]] = None,
        timeouts: typing.Optional["UserAssignedIdentityTimeouts"] = None,
    ) -> None:
        """
        :param count: 
        :param depends_on: 
        :param lifecycle: 
        :param provider: 
        :param location: 
        :param name: 
        :param resource_group_name: 
        :param tags: 
        :param timeouts: timeouts block.
        """
        if isinstance(lifecycle, dict):
            lifecycle = cdktf.TerraformResourceLifecycle(**lifecycle)
        if isinstance(timeouts, dict):
            timeouts = UserAssignedIdentityTimeouts(**timeouts)
        self._values: typing.Dict[str, typing.Any] = {
            "location": location,
            "name": name,
            "resource_group_name": resource_group_name,
        }
        if count is not None:
            self._values["count"] = count
        if depends_on is not None:
            self._values["depends_on"] = depends_on
        if lifecycle is not None:
            self._values["lifecycle"] = lifecycle
        if provider is not None:
            self._values["provider"] = provider
        if tags is not None:
            self._values["tags"] = tags
        if timeouts is not None:
            self._values["timeouts"] = timeouts

    @builtins.property
    def count(self) -> typing.Optional[jsii.Number]:
        """
        :stability: experimental
        """
        result = self._values.get("count")
        return result

    @builtins.property
    def depends_on(self) -> typing.Optional[typing.List[cdktf.TerraformResource]]:
        """
        :stability: experimental
        """
        result = self._values.get("depends_on")
        return result

    @builtins.property
    def lifecycle(self) -> typing.Optional[cdktf.TerraformResourceLifecycle]:
        """
        :stability: experimental
        """
        result = self._values.get("lifecycle")
        return result

    @builtins.property
    def provider(self) -> typing.Optional[cdktf.TerraformProvider]:
        """
        :stability: experimental
        """
        result = self._values.get("provider")
        return result

    @builtins.property
    def location(self) -> builtins.str:
        result = self._values.get("location")
        assert result is not None, "Required property 'location' is missing"
        return result

    @builtins.property
    def name(self) -> builtins.str:
        result = self._values.get("name")
        assert result is not None, "Required property 'name' is missing"
        return result

    @builtins.property
    def resource_group_name(self) -> builtins.str:
        result = self._values.get("resource_group_name")
        assert result is not None, "Required property 'resource_group_name' is missing"
        return result

    @builtins.property
    def tags(self) -> typing.Optional[typing.Mapping[builtins.str, builtins.str]]:
        result = self._values.get("tags")
        return result

    @builtins.property
    def timeouts(self) -> typing.Optional["UserAssignedIdentityTimeouts"]:
        """timeouts block."""
        result = self._values.get("timeouts")
        return result

    def __eq__(self, rhs: typing.Any) -> builtins.bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs: typing.Any) -> builtins.bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return "UserAssignedIdentityConfig(%s)" % ", ".join(
            k + "=" + repr(v) for k, v in self._values.items()
        )


@jsii.data_type(
    jsii_type="@cdktf/provider-azurerm.UserAssignedIdentityTimeouts",
    jsii_struct_bases=[],
    name_mapping={
        "create": "create",
        "delete": "delete",
        "read": "read",
        "update": "update",
    },
)
class UserAssignedIdentityTimeouts:
    def __init__(
        self,
        *,
        create: typing.Optional[builtins.str] = None,
        delete: typing.Optional[builtins.str] = None,
        read: typing.Optional[builtins.str] = None,
        update: typing.Optional[builtins.str] = None,
    ) -> None:
        """
        :param create: 
        :param delete: 
        :param read: 
        :param update: 
        """
        self._values: typing.Dict[str, typing.Any] = {}
        if create is not None:
            self._values["create"] = create
        if delete is not None:
            self._values["delete"] = delete
        if read is not None:
            self._values["read"] = read
        if update is not None:
            self._values["update"] = update

    @builtins.property
    def create(self) -> typing.Optional[builtins.str]:
        result = self._values.get("create")
        return result

    @builtins.property
    def delete(self) -> typing.Optional[builtins.str]:
        result = self._values.get("delete")
        return result

    @builtins.property
    def read(self) -> typing.Optional[builtins.str]:
        result = self._values.get("read")
        return result

    @builtins.property
    def update(self) -> typing.Optional[builtins.str]:
        result = self._values.get("update")
        return result

    def __eq__(self, rhs: typing.Any) -> builtins.bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs: typing.Any) -> builtins.bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return "UserAssignedIdentityTimeouts(%s)" % ", ".join(
            k + "=" + repr(v) for k, v in self._values.items()
        )


class VirtualHub(
    cdktf.TerraformResource,
    metaclass=jsii.JSIIMeta,
    jsii_type="@cdktf/provider-azurerm.VirtualHub",
):
    def __init__(
        self,
        scope: constructs.Construct,
        id: builtins.str,
        *,
        address_prefix: builtins.str,
        location: builtins.str,
        name: builtins.str,
        resource_group_name: builtins.str,
        virtual_wan_id: builtins.str,
        route: typing.Optional[typing.List["VirtualHubRoute"]] = None,
        tags: typing.Optional[typing.Mapping[builtins.str, builtins.str]] = None,
        timeouts: typing.Optional["VirtualHubTimeouts"] = None,
        count: typing.Optional[jsii.Number] = None,
        depends_on: typing.Optional[typing.List[cdktf.TerraformResource]] = None,
        lifecycle: typing.Optional[cdktf.TerraformResourceLifecycle] = None,
        provider: typing.Optional[cdktf.TerraformProvider] = None,
    ) -> None:
        """
        :param scope: -
        :param id: -
        :param address_prefix: 
        :param location: 
        :param name: 
        :param resource_group_name: 
        :param virtual_wan_id: 
        :param route: route block.
        :param tags: 
        :param timeouts: timeouts block.
        :param count: 
        :param depends_on: 
        :param lifecycle: 
        :param provider: 
        """
        config = VirtualHubConfig(
            address_prefix=address_prefix,
            location=location,
            name=name,
            resource_group_name=resource_group_name,
            virtual_wan_id=virtual_wan_id,
            route=route,
            tags=tags,
            timeouts=timeouts,
            count=count,
            depends_on=depends_on,
            lifecycle=lifecycle,
            provider=provider,
        )

        jsii.create(VirtualHub, self, [scope, id, config])

    @jsii.member(jsii_name="synthesizeAttributes")
    def _synthesize_attributes(self) -> typing.Mapping[builtins.str, typing.Any]:
        return jsii.invoke(self, "synthesizeAttributes", [])

    @builtins.property # type: ignore
    @jsii.member(jsii_name="addressPrefix")
    def address_prefix(self) -> builtins.str:
        return jsii.get(self, "addressPrefix")

    @address_prefix.setter # type: ignore
    def address_prefix(self, value: builtins.str) -> None:
        jsii.set(self, "addressPrefix", value)

    @builtins.property # type: ignore
    @jsii.member(jsii_name="location")
    def location(self) -> builtins.str:
        return jsii.get(self, "location")

    @location.setter # type: ignore
    def location(self, value: builtins.str) -> None:
        jsii.set(self, "location", value)

    @builtins.property # type: ignore
    @jsii.member(jsii_name="name")
    def name(self) -> builtins.str:
        return jsii.get(self, "name")

    @name.setter # type: ignore
    def name(self, value: builtins.str) -> None:
        jsii.set(self, "name", value)

    @builtins.property # type: ignore
    @jsii.member(jsii_name="resourceGroupName")
    def resource_group_name(self) -> builtins.str:
        return jsii.get(self, "resourceGroupName")

    @resource_group_name.setter # type: ignore
    def resource_group_name(self, value: builtins.str) -> None:
        jsii.set(self, "resourceGroupName", value)

    @builtins.property # type: ignore
    @jsii.member(jsii_name="virtualWanId")
    def virtual_wan_id(self) -> builtins.str:
        return jsii.get(self, "virtualWanId")

    @virtual_wan_id.setter # type: ignore
    def virtual_wan_id(self, value: builtins.str) -> None:
        jsii.set(self, "virtualWanId", value)

    @builtins.property # type: ignore
    @jsii.member(jsii_name="id")
    def id(self) -> typing.Optional[builtins.str]:
        return jsii.get(self, "id")

    @id.setter # type: ignore
    def id(self, value: typing.Optional[builtins.str]) -> None:
        jsii.set(self, "id", value)

    @builtins.property # type: ignore
    @jsii.member(jsii_name="route")
    def route(self) -> typing.Optional[typing.List["VirtualHubRoute"]]:
        return jsii.get(self, "route")

    @route.setter # type: ignore
    def route(self, value: typing.Optional[typing.List["VirtualHubRoute"]]) -> None:
        jsii.set(self, "route", value)

    @builtins.property # type: ignore
    @jsii.member(jsii_name="tags")
    def tags(self) -> typing.Optional[typing.Mapping[builtins.str, builtins.str]]:
        return jsii.get(self, "tags")

    @tags.setter # type: ignore
    def tags(
        self,
        value: typing.Optional[typing.Mapping[builtins.str, builtins.str]],
    ) -> None:
        jsii.set(self, "tags", value)

    @builtins.property # type: ignore
    @jsii.member(jsii_name="timeouts")
    def timeouts(self) -> typing.Optional["VirtualHubTimeouts"]:
        return jsii.get(self, "timeouts")

    @timeouts.setter # type: ignore
    def timeouts(self, value: typing.Optional["VirtualHubTimeouts"]) -> None:
        jsii.set(self, "timeouts", value)


@jsii.data_type(
    jsii_type="@cdktf/provider-azurerm.VirtualHubConfig",
    jsii_struct_bases=[cdktf.TerraformMetaArguments],
    name_mapping={
        "count": "count",
        "depends_on": "dependsOn",
        "lifecycle": "lifecycle",
        "provider": "provider",
        "address_prefix": "addressPrefix",
        "location": "location",
        "name": "name",
        "resource_group_name": "resourceGroupName",
        "virtual_wan_id": "virtualWanId",
        "route": "route",
        "tags": "tags",
        "timeouts": "timeouts",
    },
)
class VirtualHubConfig(cdktf.TerraformMetaArguments):
    def __init__(
        self,
        *,
        count: typing.Optional[jsii.Number] = None,
        depends_on: typing.Optional[typing.List[cdktf.TerraformResource]] = None,
        lifecycle: typing.Optional[cdktf.TerraformResourceLifecycle] = None,
        provider: typing.Optional[cdktf.TerraformProvider] = None,
        address_prefix: builtins.str,
        location: builtins.str,
        name: builtins.str,
        resource_group_name: builtins.str,
        virtual_wan_id: builtins.str,
        route: typing.Optional[typing.List["VirtualHubRoute"]] = None,
        tags: typing.Optional[typing.Mapping[builtins.str, builtins.str]] = None,
        timeouts: typing.Optional["VirtualHubTimeouts"] = None,
    ) -> None:
        """
        :param count: 
        :param depends_on: 
        :param lifecycle: 
        :param provider: 
        :param address_prefix: 
        :param location: 
        :param name: 
        :param resource_group_name: 
        :param virtual_wan_id: 
        :param route: route block.
        :param tags: 
        :param timeouts: timeouts block.
        """
        if isinstance(lifecycle, dict):
            lifecycle = cdktf.TerraformResourceLifecycle(**lifecycle)
        if isinstance(timeouts, dict):
            timeouts = VirtualHubTimeouts(**timeouts)
        self._values: typing.Dict[str, typing.Any] = {
            "address_prefix": address_prefix,
            "location": location,
            "name": name,
            "resource_group_name": resource_group_name,
            "virtual_wan_id": virtual_wan_id,
        }
        if count is not None:
            self._values["count"] = count
        if depends_on is not None:
            self._values["depends_on"] = depends_on
        if lifecycle is not None:
            self._values["lifecycle"] = lifecycle
        if provider is not None:
            self._values["provider"] = provider
        if route is not None:
            self._values["route"] = route
        if tags is not None:
            self._values["tags"] = tags
        if timeouts is not None:
            self._values["timeouts"] = timeouts

    @builtins.property
    def count(self) -> typing.Optional[jsii.Number]:
        """
        :stability: experimental
        """
        result = self._values.get("count")
        return result

    @builtins.property
    def depends_on(self) -> typing.Optional[typing.List[cdktf.TerraformResource]]:
        """
        :stability: experimental
        """
        result = self._values.get("depends_on")
        return result

    @builtins.property
    def lifecycle(self) -> typing.Optional[cdktf.TerraformResourceLifecycle]:
        """
        :stability: experimental
        """
        result = self._values.get("lifecycle")
        return result

    @builtins.property
    def provider(self) -> typing.Optional[cdktf.TerraformProvider]:
        """
        :stability: experimental
        """
        result = self._values.get("provider")
        return result

    @builtins.property
    def address_prefix(self) -> builtins.str:
        result = self._values.get("address_prefix")
        assert result is not None, "Required property 'address_prefix' is missing"
        return result

    @builtins.property
    def location(self) -> builtins.str:
        result = self._values.get("location")
        assert result is not None, "Required property 'location' is missing"
        return result

    @builtins.property
    def name(self) -> builtins.str:
        result = self._values.get("name")
        assert result is not None, "Required property 'name' is missing"
        return result

    @builtins.property
    def resource_group_name(self) -> builtins.str:
        result = self._values.get("resource_group_name")
        assert result is not None, "Required property 'resource_group_name' is missing"
        return result

    @builtins.property
    def virtual_wan_id(self) -> builtins.str:
        result = self._values.get("virtual_wan_id")
        assert result is not None, "Required property 'virtual_wan_id' is missing"
        return result

    @builtins.property
    def route(self) -> typing.Optional[typing.List["VirtualHubRoute"]]:
        """route block."""
        result = self._values.get("route")
        return result

    @builtins.property
    def tags(self) -> typing.Optional[typing.Mapping[builtins.str, builtins.str]]:
        result = self._values.get("tags")
        return result

    @builtins.property
    def timeouts(self) -> typing.Optional["VirtualHubTimeouts"]:
        """timeouts block."""
        result = self._values.get("timeouts")
        return result

    def __eq__(self, rhs: typing.Any) -> builtins.bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs: typing.Any) -> builtins.bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return "VirtualHubConfig(%s)" % ", ".join(
            k + "=" + repr(v) for k, v in self._values.items()
        )


@jsii.data_type(
    jsii_type="@cdktf/provider-azurerm.VirtualHubRoute",
    jsii_struct_bases=[],
    name_mapping={
        "address_prefixes": "addressPrefixes",
        "next_hop_ip_address": "nextHopIpAddress",
    },
)
class VirtualHubRoute:
    def __init__(
        self,
        *,
        address_prefixes: typing.List[builtins.str],
        next_hop_ip_address: builtins.str,
    ) -> None:
        """
        :param address_prefixes: 
        :param next_hop_ip_address: 
        """
        self._values: typing.Dict[str, typing.Any] = {
            "address_prefixes": address_prefixes,
            "next_hop_ip_address": next_hop_ip_address,
        }

    @builtins.property
    def address_prefixes(self) -> typing.List[builtins.str]:
        result = self._values.get("address_prefixes")
        assert result is not None, "Required property 'address_prefixes' is missing"
        return result

    @builtins.property
    def next_hop_ip_address(self) -> builtins.str:
        result = self._values.get("next_hop_ip_address")
        assert result is not None, "Required property 'next_hop_ip_address' is missing"
        return result

    def __eq__(self, rhs: typing.Any) -> builtins.bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs: typing.Any) -> builtins.bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return "VirtualHubRoute(%s)" % ", ".join(
            k + "=" + repr(v) for k, v in self._values.items()
        )


@jsii.data_type(
    jsii_type="@cdktf/provider-azurerm.VirtualHubTimeouts",
    jsii_struct_bases=[],
    name_mapping={
        "create": "create",
        "delete": "delete",
        "read": "read",
        "update": "update",
    },
)
class VirtualHubTimeouts:
    def __init__(
        self,
        *,
        create: typing.Optional[builtins.str] = None,
        delete: typing.Optional[builtins.str] = None,
        read: typing.Optional[builtins.str] = None,
        update: typing.Optional[builtins.str] = None,
    ) -> None:
        """
        :param create: 
        :param delete: 
        :param read: 
        :param update: 
        """
        self._values: typing.Dict[str, typing.Any] = {}
        if create is not None:
            self._values["create"] = create
        if delete is not None:
            self._values["delete"] = delete
        if read is not None:
            self._values["read"] = read
        if update is not None:
            self._values["update"] = update

    @builtins.property
    def create(self) -> typing.Optional[builtins.str]:
        result = self._values.get("create")
        return result

    @builtins.property
    def delete(self) -> typing.Optional[builtins.str]:
        result = self._values.get("delete")
        return result

    @builtins.property
    def read(self) -> typing.Optional[builtins.str]:
        result = self._values.get("read")
        return result

    @builtins.property
    def update(self) -> typing.Optional[builtins.str]:
        result = self._values.get("update")
        return result

    def __eq__(self, rhs: typing.Any) -> builtins.bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs: typing.Any) -> builtins.bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return "VirtualHubTimeouts(%s)" % ", ".join(
            k + "=" + repr(v) for k, v in self._values.items()
        )


class VirtualMachine(
    cdktf.TerraformResource,
    metaclass=jsii.JSIIMeta,
    jsii_type="@cdktf/provider-azurerm.VirtualMachine",
):
    def __init__(
        self,
        scope: constructs.Construct,
        id: builtins.str,
        *,
        location: builtins.str,
        name: builtins.str,
        network_interface_ids: typing.List[builtins.str],
        resource_group_name: builtins.str,
        storage_os_disk: typing.List["VirtualMachineStorageOsDisk"],
        vm_size: builtins.str,
        additional_capabilities: typing.Optional[typing.List["VirtualMachineAdditionalCapabilities"]] = None,
        availability_set_id: typing.Optional[builtins.str] = None,
        boot_diagnostics: typing.Optional[typing.List["VirtualMachineBootDiagnostics"]] = None,
        delete_data_disks_on_termination: typing.Optional[builtins.bool] = None,
        delete_os_disk_on_termination: typing.Optional[builtins.bool] = None,
        identity: typing.Optional[typing.List["VirtualMachineIdentity"]] = None,
        license_type: typing.Optional[builtins.str] = None,
        os_profile: typing.Optional[typing.List["VirtualMachineOsProfile"]] = None,
        os_profile_linux_config: typing.Optional[typing.List["VirtualMachineOsProfileLinuxConfig"]] = None,
        os_profile_secrets: typing.Optional[typing.List["VirtualMachineOsProfileSecrets"]] = None,
        os_profile_windows_config: typing.Optional[typing.List["VirtualMachineOsProfileWindowsConfig"]] = None,
        plan: typing.Optional[typing.List["VirtualMachinePlan"]] = None,
        primary_network_interface_id: typing.Optional[builtins.str] = None,
        proximity_placement_group_id: typing.Optional[builtins.str] = None,
        storage_data_disk: typing.Optional[typing.List["VirtualMachineStorageDataDisk"]] = None,
        storage_image_reference: typing.Optional[typing.List["VirtualMachineStorageImageReference"]] = None,
        tags: typing.Optional[typing.Mapping[builtins.str, builtins.str]] = None,
        timeouts: typing.Optional["VirtualMachineTimeouts"] = None,
        zones: typing.Optional[typing.List[builtins.str]] = None,
        count: typing.Optional[jsii.Number] = None,
        depends_on: typing.Optional[typing.List[cdktf.TerraformResource]] = None,
        lifecycle: typing.Optional[cdktf.TerraformResourceLifecycle] = None,
        provider: typing.Optional[cdktf.TerraformProvider] = None,
    ) -> None:
        """
        :param scope: -
        :param id: -
        :param location: 
        :param name: 
        :param network_interface_ids: 
        :param resource_group_name: 
        :param storage_os_disk: storage_os_disk block.
        :param vm_size: 
        :param additional_capabilities: additional_capabilities block.
        :param availability_set_id: 
        :param boot_diagnostics: boot_diagnostics block.
        :param delete_data_disks_on_termination: 
        :param delete_os_disk_on_termination: 
        :param identity: identity block.
        :param license_type: 
        :param os_profile: os_profile block.
        :param os_profile_linux_config: os_profile_linux_config block.
        :param os_profile_secrets: os_profile_secrets block.
        :param os_profile_windows_config: os_profile_windows_config block.
        :param plan: plan block.
        :param primary_network_interface_id: 
        :param proximity_placement_group_id: 
        :param storage_data_disk: storage_data_disk block.
        :param storage_image_reference: storage_image_reference block.
        :param tags: 
        :param timeouts: timeouts block.
        :param zones: 
        :param count: 
        :param depends_on: 
        :param lifecycle: 
        :param provider: 
        """
        config = VirtualMachineConfig(
            location=location,
            name=name,
            network_interface_ids=network_interface_ids,
            resource_group_name=resource_group_name,
            storage_os_disk=storage_os_disk,
            vm_size=vm_size,
            additional_capabilities=additional_capabilities,
            availability_set_id=availability_set_id,
            boot_diagnostics=boot_diagnostics,
            delete_data_disks_on_termination=delete_data_disks_on_termination,
            delete_os_disk_on_termination=delete_os_disk_on_termination,
            identity=identity,
            license_type=license_type,
            os_profile=os_profile,
            os_profile_linux_config=os_profile_linux_config,
            os_profile_secrets=os_profile_secrets,
            os_profile_windows_config=os_profile_windows_config,
            plan=plan,
            primary_network_interface_id=primary_network_interface_id,
            proximity_placement_group_id=proximity_placement_group_id,
            storage_data_disk=storage_data_disk,
            storage_image_reference=storage_image_reference,
            tags=tags,
            timeouts=timeouts,
            zones=zones,
            count=count,
            depends_on=depends_on,
            lifecycle=lifecycle,
            provider=provider,
        )

        jsii.create(VirtualMachine, self, [scope, id, config])

    @jsii.member(jsii_name="synthesizeAttributes")
    def _synthesize_attributes(self) -> typing.Mapping[builtins.str, typing.Any]:
        return jsii.invoke(self, "synthesizeAttributes", [])

    @builtins.property # type: ignore
    @jsii.member(jsii_name="location")
    def location(self) -> builtins.str:
        return jsii.get(self, "location")

    @location.setter # type: ignore
    def location(self, value: builtins.str) -> None:
        jsii.set(self, "location", value)

    @builtins.property # type: ignore
    @jsii.member(jsii_name="name")
    def name(self) -> builtins.str:
        return jsii.get(self, "name")

    @name.setter # type: ignore
    def name(self, value: builtins.str) -> None:
        jsii.set(self, "name", value)

    @builtins.property # type: ignore
    @jsii.member(jsii_name="networkInterfaceIds")
    def network_interface_ids(self) -> typing.List[builtins.str]:
        return jsii.get(self, "networkInterfaceIds")

    @network_interface_ids.setter # type: ignore
    def network_interface_ids(self, value: typing.List[builtins.str]) -> None:
        jsii.set(self, "networkInterfaceIds", value)

    @builtins.property # type: ignore
    @jsii.member(jsii_name="resourceGroupName")
    def resource_group_name(self) -> builtins.str:
        return jsii.get(self, "resourceGroupName")

    @resource_group_name.setter # type: ignore
    def resource_group_name(self, value: builtins.str) -> None:
        jsii.set(self, "resourceGroupName", value)

    @builtins.property # type: ignore
    @jsii.member(jsii_name="storageOsDisk")
    def storage_os_disk(self) -> typing.List["VirtualMachineStorageOsDisk"]:
        return jsii.get(self, "storageOsDisk")

    @storage_os_disk.setter # type: ignore
    def storage_os_disk(
        self,
        value: typing.List["VirtualMachineStorageOsDisk"],
    ) -> None:
        jsii.set(self, "storageOsDisk", value)

    @builtins.property # type: ignore
    @jsii.member(jsii_name="vmSize")
    def vm_size(self) -> builtins.str:
        return jsii.get(self, "vmSize")

    @vm_size.setter # type: ignore
    def vm_size(self, value: builtins.str) -> None:
        jsii.set(self, "vmSize", value)

    @builtins.property # type: ignore
    @jsii.member(jsii_name="additionalCapabilities")
    def additional_capabilities(
        self,
    ) -> typing.Optional[typing.List["VirtualMachineAdditionalCapabilities"]]:
        return jsii.get(self, "additionalCapabilities")

    @additional_capabilities.setter # type: ignore
    def additional_capabilities(
        self,
        value: typing.Optional[typing.List["VirtualMachineAdditionalCapabilities"]],
    ) -> None:
        jsii.set(self, "additionalCapabilities", value)

    @builtins.property # type: ignore
    @jsii.member(jsii_name="availabilitySetId")
    def availability_set_id(self) -> typing.Optional[builtins.str]:
        return jsii.get(self, "availabilitySetId")

    @availability_set_id.setter # type: ignore
    def availability_set_id(self, value: typing.Optional[builtins.str]) -> None:
        jsii.set(self, "availabilitySetId", value)

    @builtins.property # type: ignore
    @jsii.member(jsii_name="bootDiagnostics")
    def boot_diagnostics(
        self,
    ) -> typing.Optional[typing.List["VirtualMachineBootDiagnostics"]]:
        return jsii.get(self, "bootDiagnostics")

    @boot_diagnostics.setter # type: ignore
    def boot_diagnostics(
        self,
        value: typing.Optional[typing.List["VirtualMachineBootDiagnostics"]],
    ) -> None:
        jsii.set(self, "bootDiagnostics", value)

    @builtins.property # type: ignore
    @jsii.member(jsii_name="deleteDataDisksOnTermination")
    def delete_data_disks_on_termination(self) -> typing.Optional[builtins.bool]:
        return jsii.get(self, "deleteDataDisksOnTermination")

    @delete_data_disks_on_termination.setter # type: ignore
    def delete_data_disks_on_termination(
        self,
        value: typing.Optional[builtins.bool],
    ) -> None:
        jsii.set(self, "deleteDataDisksOnTermination", value)

    @builtins.property # type: ignore
    @jsii.member(jsii_name="deleteOsDiskOnTermination")
    def delete_os_disk_on_termination(self) -> typing.Optional[builtins.bool]:
        return jsii.get(self, "deleteOsDiskOnTermination")

    @delete_os_disk_on_termination.setter # type: ignore
    def delete_os_disk_on_termination(
        self,
        value: typing.Optional[builtins.bool],
    ) -> None:
        jsii.set(self, "deleteOsDiskOnTermination", value)

    @builtins.property # type: ignore
    @jsii.member(jsii_name="id")
    def id(self) -> typing.Optional[builtins.str]:
        return jsii.get(self, "id")

    @id.setter # type: ignore
    def id(self, value: typing.Optional[builtins.str]) -> None:
        jsii.set(self, "id", value)

    @builtins.property # type: ignore
    @jsii.member(jsii_name="identity")
    def identity(self) -> typing.Optional[typing.List["VirtualMachineIdentity"]]:
        return jsii.get(self, "identity")

    @identity.setter # type: ignore
    def identity(
        self,
        value: typing.Optional[typing.List["VirtualMachineIdentity"]],
    ) -> None:
        jsii.set(self, "identity", value)

    @builtins.property # type: ignore
    @jsii.member(jsii_name="licenseType")
    def license_type(self) -> typing.Optional[builtins.str]:
        return jsii.get(self, "licenseType")

    @license_type.setter # type: ignore
    def license_type(self, value: typing.Optional[builtins.str]) -> None:
        jsii.set(self, "licenseType", value)

    @builtins.property # type: ignore
    @jsii.member(jsii_name="osProfile")
    def os_profile(self) -> typing.Optional[typing.List["VirtualMachineOsProfile"]]:
        return jsii.get(self, "osProfile")

    @os_profile.setter # type: ignore
    def os_profile(
        self,
        value: typing.Optional[typing.List["VirtualMachineOsProfile"]],
    ) -> None:
        jsii.set(self, "osProfile", value)

    @builtins.property # type: ignore
    @jsii.member(jsii_name="osProfileLinuxConfig")
    def os_profile_linux_config(
        self,
    ) -> typing.Optional[typing.List["VirtualMachineOsProfileLinuxConfig"]]:
        return jsii.get(self, "osProfileLinuxConfig")

    @os_profile_linux_config.setter # type: ignore
    def os_profile_linux_config(
        self,
        value: typing.Optional[typing.List["VirtualMachineOsProfileLinuxConfig"]],
    ) -> None:
        jsii.set(self, "osProfileLinuxConfig", value)

    @builtins.property # type: ignore
    @jsii.member(jsii_name="osProfileSecrets")
    def os_profile_secrets(
        self,
    ) -> typing.Optional[typing.List["VirtualMachineOsProfileSecrets"]]:
        return jsii.get(self, "osProfileSecrets")

    @os_profile_secrets.setter # type: ignore
    def os_profile_secrets(
        self,
        value: typing.Optional[typing.List["VirtualMachineOsProfileSecrets"]],
    ) -> None:
        jsii.set(self, "osProfileSecrets", value)

    @builtins.property # type: ignore
    @jsii.member(jsii_name="osProfileWindowsConfig")
    def os_profile_windows_config(
        self,
    ) -> typing.Optional[typing.List["VirtualMachineOsProfileWindowsConfig"]]:
        return jsii.get(self, "osProfileWindowsConfig")

    @os_profile_windows_config.setter # type: ignore
    def os_profile_windows_config(
        self,
        value: typing.Optional[typing.List["VirtualMachineOsProfileWindowsConfig"]],
    ) -> None:
        jsii.set(self, "osProfileWindowsConfig", value)

    @builtins.property # type: ignore
    @jsii.member(jsii_name="plan")
    def plan(self) -> typing.Optional[typing.List["VirtualMachinePlan"]]:
        return jsii.get(self, "plan")

    @plan.setter # type: ignore
    def plan(self, value: typing.Optional[typing.List["VirtualMachinePlan"]]) -> None:
        jsii.set(self, "plan", value)

    @builtins.property # type: ignore
    @jsii.member(jsii_name="primaryNetworkInterfaceId")
    def primary_network_interface_id(self) -> typing.Optional[builtins.str]:
        return jsii.get(self, "primaryNetworkInterfaceId")

    @primary_network_interface_id.setter # type: ignore
    def primary_network_interface_id(
        self,
        value: typing.Optional[builtins.str],
    ) -> None:
        jsii.set(self, "primaryNetworkInterfaceId", value)

    @builtins.property # type: ignore
    @jsii.member(jsii_name="proximityPlacementGroupId")
    def proximity_placement_group_id(self) -> typing.Optional[builtins.str]:
        return jsii.get(self, "proximityPlacementGroupId")

    @proximity_placement_group_id.setter # type: ignore
    def proximity_placement_group_id(
        self,
        value: typing.Optional[builtins.str],
    ) -> None:
        jsii.set(self, "proximityPlacementGroupId", value)

    @builtins.property # type: ignore
    @jsii.member(jsii_name="storageDataDisk")
    def storage_data_disk(
        self,
    ) -> typing.Optional[typing.List["VirtualMachineStorageDataDisk"]]:
        return jsii.get(self, "storageDataDisk")

    @storage_data_disk.setter # type: ignore
    def storage_data_disk(
        self,
        value: typing.Optional[typing.List["VirtualMachineStorageDataDisk"]],
    ) -> None:
        jsii.set(self, "storageDataDisk", value)

    @builtins.property # type: ignore
    @jsii.member(jsii_name="storageImageReference")
    def storage_image_reference(
        self,
    ) -> typing.Optional[typing.List["VirtualMachineStorageImageReference"]]:
        return jsii.get(self, "storageImageReference")

    @storage_image_reference.setter # type: ignore
    def storage_image_reference(
        self,
        value: typing.Optional[typing.List["VirtualMachineStorageImageReference"]],
    ) -> None:
        jsii.set(self, "storageImageReference", value)

    @builtins.property # type: ignore
    @jsii.member(jsii_name="tags")
    def tags(self) -> typing.Optional[typing.Mapping[builtins.str, builtins.str]]:
        return jsii.get(self, "tags")

    @tags.setter # type: ignore
    def tags(
        self,
        value: typing.Optional[typing.Mapping[builtins.str, builtins.str]],
    ) -> None:
        jsii.set(self, "tags", value)

    @builtins.property # type: ignore
    @jsii.member(jsii_name="timeouts")
    def timeouts(self) -> typing.Optional["VirtualMachineTimeouts"]:
        return jsii.get(self, "timeouts")

    @timeouts.setter # type: ignore
    def timeouts(self, value: typing.Optional["VirtualMachineTimeouts"]) -> None:
        jsii.set(self, "timeouts", value)

    @builtins.property # type: ignore
    @jsii.member(jsii_name="zones")
    def zones(self) -> typing.Optional[typing.List[builtins.str]]:
        return jsii.get(self, "zones")

    @zones.setter # type: ignore
    def zones(self, value: typing.Optional[typing.List[builtins.str]]) -> None:
        jsii.set(self, "zones", value)


@jsii.data_type(
    jsii_type="@cdktf/provider-azurerm.VirtualMachineAdditionalCapabilities",
    jsii_struct_bases=[],
    name_mapping={"ultra_ssd_enabled": "ultraSsdEnabled"},
)
class VirtualMachineAdditionalCapabilities:
    def __init__(self, *, ultra_ssd_enabled: builtins.bool) -> None:
        """
        :param ultra_ssd_enabled: 
        """
        self._values: typing.Dict[str, typing.Any] = {
            "ultra_ssd_enabled": ultra_ssd_enabled,
        }

    @builtins.property
    def ultra_ssd_enabled(self) -> builtins.bool:
        result = self._values.get("ultra_ssd_enabled")
        assert result is not None, "Required property 'ultra_ssd_enabled' is missing"
        return result

    def __eq__(self, rhs: typing.Any) -> builtins.bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs: typing.Any) -> builtins.bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return "VirtualMachineAdditionalCapabilities(%s)" % ", ".join(
            k + "=" + repr(v) for k, v in self._values.items()
        )


@jsii.data_type(
    jsii_type="@cdktf/provider-azurerm.VirtualMachineBootDiagnostics",
    jsii_struct_bases=[],
    name_mapping={"enabled": "enabled", "storage_uri": "storageUri"},
)
class VirtualMachineBootDiagnostics:
    def __init__(self, *, enabled: builtins.bool, storage_uri: builtins.str) -> None:
        """
        :param enabled: 
        :param storage_uri: 
        """
        self._values: typing.Dict[str, typing.Any] = {
            "enabled": enabled,
            "storage_uri": storage_uri,
        }

    @builtins.property
    def enabled(self) -> builtins.bool:
        result = self._values.get("enabled")
        assert result is not None, "Required property 'enabled' is missing"
        return result

    @builtins.property
    def storage_uri(self) -> builtins.str:
        result = self._values.get("storage_uri")
        assert result is not None, "Required property 'storage_uri' is missing"
        return result

    def __eq__(self, rhs: typing.Any) -> builtins.bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs: typing.Any) -> builtins.bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return "VirtualMachineBootDiagnostics(%s)" % ", ".join(
            k + "=" + repr(v) for k, v in self._values.items()
        )


@jsii.data_type(
    jsii_type="@cdktf/provider-azurerm.VirtualMachineConfig",
    jsii_struct_bases=[cdktf.TerraformMetaArguments],
    name_mapping={
        "count": "count",
        "depends_on": "dependsOn",
        "lifecycle": "lifecycle",
        "provider": "provider",
        "location": "location",
        "name": "name",
        "network_interface_ids": "networkInterfaceIds",
        "resource_group_name": "resourceGroupName",
        "storage_os_disk": "storageOsDisk",
        "vm_size": "vmSize",
        "additional_capabilities": "additionalCapabilities",
        "availability_set_id": "availabilitySetId",
        "boot_diagnostics": "bootDiagnostics",
        "delete_data_disks_on_termination": "deleteDataDisksOnTermination",
        "delete_os_disk_on_termination": "deleteOsDiskOnTermination",
        "identity": "identity",
        "license_type": "licenseType",
        "os_profile": "osProfile",
        "os_profile_linux_config": "osProfileLinuxConfig",
        "os_profile_secrets": "osProfileSecrets",
        "os_profile_windows_config": "osProfileWindowsConfig",
        "plan": "plan",
        "primary_network_interface_id": "primaryNetworkInterfaceId",
        "proximity_placement_group_id": "proximityPlacementGroupId",
        "storage_data_disk": "storageDataDisk",
        "storage_image_reference": "storageImageReference",
        "tags": "tags",
        "timeouts": "timeouts",
        "zones": "zones",
    },
)
class VirtualMachineConfig(cdktf.TerraformMetaArguments):
    def __init__(
        self,
        *,
        count: typing.Optional[jsii.Number] = None,
        depends_on: typing.Optional[typing.List[cdktf.TerraformResource]] = None,
        lifecycle: typing.Optional[cdktf.TerraformResourceLifecycle] = None,
        provider: typing.Optional[cdktf.TerraformProvider] = None,
        location: builtins.str,
        name: builtins.str,
        network_interface_ids: typing.List[builtins.str],
        resource_group_name: builtins.str,
        storage_os_disk: typing.List["VirtualMachineStorageOsDisk"],
        vm_size: builtins.str,
        additional_capabilities: typing.Optional[typing.List[VirtualMachineAdditionalCapabilities]] = None,
        availability_set_id: typing.Optional[builtins.str] = None,
        boot_diagnostics: typing.Optional[typing.List[VirtualMachineBootDiagnostics]] = None,
        delete_data_disks_on_termination: typing.Optional[builtins.bool] = None,
        delete_os_disk_on_termination: typing.Optional[builtins.bool] = None,
        identity: typing.Optional[typing.List["VirtualMachineIdentity"]] = None,
        license_type: typing.Optional[builtins.str] = None,
        os_profile: typing.Optional[typing.List["VirtualMachineOsProfile"]] = None,
        os_profile_linux_config: typing.Optional[typing.List["VirtualMachineOsProfileLinuxConfig"]] = None,
        os_profile_secrets: typing.Optional[typing.List["VirtualMachineOsProfileSecrets"]] = None,
        os_profile_windows_config: typing.Optional[typing.List["VirtualMachineOsProfileWindowsConfig"]] = None,
        plan: typing.Optional[typing.List["VirtualMachinePlan"]] = None,
        primary_network_interface_id: typing.Optional[builtins.str] = None,
        proximity_placement_group_id: typing.Optional[builtins.str] = None,
        storage_data_disk: typing.Optional[typing.List["VirtualMachineStorageDataDisk"]] = None,
        storage_image_reference: typing.Optional[typing.List["VirtualMachineStorageImageReference"]] = None,
        tags: typing.Optional[typing.Mapping[builtins.str, builtins.str]] = None,
        timeouts: typing.Optional["VirtualMachineTimeouts"] = None,
        zones: typing.Optional[typing.List[builtins.str]] = None,
    ) -> None:
        """
        :param count: 
        :param depends_on: 
        :param lifecycle: 
        :param provider: 
        :param location: 
        :param name: 
        :param network_interface_ids: 
        :param resource_group_name: 
        :param storage_os_disk: storage_os_disk block.
        :param vm_size: 
        :param additional_capabilities: additional_capabilities block.
        :param availability_set_id: 
        :param boot_diagnostics: boot_diagnostics block.
        :param delete_data_disks_on_termination: 
        :param delete_os_disk_on_termination: 
        :param identity: identity block.
        :param license_type: 
        :param os_profile: os_profile block.
        :param os_profile_linux_config: os_profile_linux_config block.
        :param os_profile_secrets: os_profile_secrets block.
        :param os_profile_windows_config: os_profile_windows_config block.
        :param plan: plan block.
        :param primary_network_interface_id: 
        :param proximity_placement_group_id: 
        :param storage_data_disk: storage_data_disk block.
        :param storage_image_reference: storage_image_reference block.
        :param tags: 
        :param timeouts: timeouts block.
        :param zones: 
        """
        if isinstance(lifecycle, dict):
            lifecycle = cdktf.TerraformResourceLifecycle(**lifecycle)
        if isinstance(timeouts, dict):
            timeouts = VirtualMachineTimeouts(**timeouts)
        self._values: typing.Dict[str, typing.Any] = {
            "location": location,
            "name": name,
            "network_interface_ids": network_interface_ids,
            "resource_group_name": resource_group_name,
            "storage_os_disk": storage_os_disk,
            "vm_size": vm_size,
        }
        if count is not None:
            self._values["count"] = count
        if depends_on is not None:
            self._values["depends_on"] = depends_on
        if lifecycle is not None:
            self._values["lifecycle"] = lifecycle
        if provider is not None:
            self._values["provider"] = provider
        if additional_capabilities is not None:
            self._values["additional_capabilities"] = additional_capabilities
        if availability_set_id is not None:
            self._values["availability_set_id"] = availability_set_id
        if boot_diagnostics is not None:
            self._values["boot_diagnostics"] = boot_diagnostics
        if delete_data_disks_on_termination is not None:
            self._values["delete_data_disks_on_termination"] = delete_data_disks_on_termination
        if delete_os_disk_on_termination is not None:
            self._values["delete_os_disk_on_termination"] = delete_os_disk_on_termination
        if identity is not None:
            self._values["identity"] = identity
        if license_type is not None:
            self._values["license_type"] = license_type
        if os_profile is not None:
            self._values["os_profile"] = os_profile
        if os_profile_linux_config is not None:
            self._values["os_profile_linux_config"] = os_profile_linux_config
        if os_profile_secrets is not None:
            self._values["os_profile_secrets"] = os_profile_secrets
        if os_profile_windows_config is not None:
            self._values["os_profile_windows_config"] = os_profile_windows_config
        if plan is not None:
            self._values["plan"] = plan
        if primary_network_interface_id is not None:
            self._values["primary_network_interface_id"] = primary_network_interface_id
        if proximity_placement_group_id is not None:
            self._values["proximity_placement_group_id"] = proximity_placement_group_id
        if storage_data_disk is not None:
            self._values["storage_data_disk"] = storage_data_disk
        if storage_image_reference is not None:
            self._values["storage_image_reference"] = storage_image_reference
        if tags is not None:
            self._values["tags"] = tags
        if timeouts is not None:
            self._values["timeouts"] = timeouts
        if zones is not None:
            self._values["zones"] = zones

    @builtins.property
    def count(self) -> typing.Optional[jsii.Number]:
        """
        :stability: experimental
        """
        result = self._values.get("count")
        return result

    @builtins.property
    def depends_on(self) -> typing.Optional[typing.List[cdktf.TerraformResource]]:
        """
        :stability: experimental
        """
        result = self._values.get("depends_on")
        return result

    @builtins.property
    def lifecycle(self) -> typing.Optional[cdktf.TerraformResourceLifecycle]:
        """
        :stability: experimental
        """
        result = self._values.get("lifecycle")
        return result

    @builtins.property
    def provider(self) -> typing.Optional[cdktf.TerraformProvider]:
        """
        :stability: experimental
        """
        result = self._values.get("provider")
        return result

    @builtins.property
    def location(self) -> builtins.str:
        result = self._values.get("location")
        assert result is not None, "Required property 'location' is missing"
        return result

    @builtins.property
    def name(self) -> builtins.str:
        result = self._values.get("name")
        assert result is not None, "Required property 'name' is missing"
        return result

    @builtins.property
    def network_interface_ids(self) -> typing.List[builtins.str]:
        result = self._values.get("network_interface_ids")
        assert result is not None, "Required property 'network_interface_ids' is missing"
        return result

    @builtins.property
    def resource_group_name(self) -> builtins.str:
        result = self._values.get("resource_group_name")
        assert result is not None, "Required property 'resource_group_name' is missing"
        return result

    @builtins.property
    def storage_os_disk(self) -> typing.List["VirtualMachineStorageOsDisk"]:
        """storage_os_disk block."""
        result = self._values.get("storage_os_disk")
        assert result is not None, "Required property 'storage_os_disk' is missing"
        return result

    @builtins.property
    def vm_size(self) -> builtins.str:
        result = self._values.get("vm_size")
        assert result is not None, "Required property 'vm_size' is missing"
        return result

    @builtins.property
    def additional_capabilities(
        self,
    ) -> typing.Optional[typing.List[VirtualMachineAdditionalCapabilities]]:
        """additional_capabilities block."""
        result = self._values.get("additional_capabilities")
        return result

    @builtins.property
    def availability_set_id(self) -> typing.Optional[builtins.str]:
        result = self._values.get("availability_set_id")
        return result

    @builtins.property
    def boot_diagnostics(
        self,
    ) -> typing.Optional[typing.List[VirtualMachineBootDiagnostics]]:
        """boot_diagnostics block."""
        result = self._values.get("boot_diagnostics")
        return result

    @builtins.property
    def delete_data_disks_on_termination(self) -> typing.Optional[builtins.bool]:
        result = self._values.get("delete_data_disks_on_termination")
        return result

    @builtins.property
    def delete_os_disk_on_termination(self) -> typing.Optional[builtins.bool]:
        result = self._values.get("delete_os_disk_on_termination")
        return result

    @builtins.property
    def identity(self) -> typing.Optional[typing.List["VirtualMachineIdentity"]]:
        """identity block."""
        result = self._values.get("identity")
        return result

    @builtins.property
    def license_type(self) -> typing.Optional[builtins.str]:
        result = self._values.get("license_type")
        return result

    @builtins.property
    def os_profile(self) -> typing.Optional[typing.List["VirtualMachineOsProfile"]]:
        """os_profile block."""
        result = self._values.get("os_profile")
        return result

    @builtins.property
    def os_profile_linux_config(
        self,
    ) -> typing.Optional[typing.List["VirtualMachineOsProfileLinuxConfig"]]:
        """os_profile_linux_config block."""
        result = self._values.get("os_profile_linux_config")
        return result

    @builtins.property
    def os_profile_secrets(
        self,
    ) -> typing.Optional[typing.List["VirtualMachineOsProfileSecrets"]]:
        """os_profile_secrets block."""
        result = self._values.get("os_profile_secrets")
        return result

    @builtins.property
    def os_profile_windows_config(
        self,
    ) -> typing.Optional[typing.List["VirtualMachineOsProfileWindowsConfig"]]:
        """os_profile_windows_config block."""
        result = self._values.get("os_profile_windows_config")
        return result

    @builtins.property
    def plan(self) -> typing.Optional[typing.List["VirtualMachinePlan"]]:
        """plan block."""
        result = self._values.get("plan")
        return result

    @builtins.property
    def primary_network_interface_id(self) -> typing.Optional[builtins.str]:
        result = self._values.get("primary_network_interface_id")
        return result

    @builtins.property
    def proximity_placement_group_id(self) -> typing.Optional[builtins.str]:
        result = self._values.get("proximity_placement_group_id")
        return result

    @builtins.property
    def storage_data_disk(
        self,
    ) -> typing.Optional[typing.List["VirtualMachineStorageDataDisk"]]:
        """storage_data_disk block."""
        result = self._values.get("storage_data_disk")
        return result

    @builtins.property
    def storage_image_reference(
        self,
    ) -> typing.Optional[typing.List["VirtualMachineStorageImageReference"]]:
        """storage_image_reference block."""
        result = self._values.get("storage_image_reference")
        return result

    @builtins.property
    def tags(self) -> typing.Optional[typing.Mapping[builtins.str, builtins.str]]:
        result = self._values.get("tags")
        return result

    @builtins.property
    def timeouts(self) -> typing.Optional["VirtualMachineTimeouts"]:
        """timeouts block."""
        result = self._values.get("timeouts")
        return result

    @builtins.property
    def zones(self) -> typing.Optional[typing.List[builtins.str]]:
        result = self._values.get("zones")
        return result

    def __eq__(self, rhs: typing.Any) -> builtins.bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs: typing.Any) -> builtins.bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return "VirtualMachineConfig(%s)" % ", ".join(
            k + "=" + repr(v) for k, v in self._values.items()
        )


class VirtualMachineDataDiskAttachment(
    cdktf.TerraformResource,
    metaclass=jsii.JSIIMeta,
    jsii_type="@cdktf/provider-azurerm.VirtualMachineDataDiskAttachment",
):
    def __init__(
        self,
        scope: constructs.Construct,
        id: builtins.str,
        *,
        caching: builtins.str,
        lun: jsii.Number,
        managed_disk_id: builtins.str,
        virtual_machine_id: builtins.str,
        create_option: typing.Optional[builtins.str] = None,
        timeouts: typing.Optional["VirtualMachineDataDiskAttachmentTimeouts"] = None,
        write_accelerator_enabled: typing.Optional[builtins.bool] = None,
        count: typing.Optional[jsii.Number] = None,
        depends_on: typing.Optional[typing.List[cdktf.TerraformResource]] = None,
        lifecycle: typing.Optional[cdktf.TerraformResourceLifecycle] = None,
        provider: typing.Optional[cdktf.TerraformProvider] = None,
    ) -> None:
        """
        :param scope: -
        :param id: -
        :param caching: 
        :param lun: 
        :param managed_disk_id: 
        :param virtual_machine_id: 
        :param create_option: 
        :param timeouts: timeouts block.
        :param write_accelerator_enabled: 
        :param count: 
        :param depends_on: 
        :param lifecycle: 
        :param provider: 
        """
        config = VirtualMachineDataDiskAttachmentConfig(
            caching=caching,
            lun=lun,
            managed_disk_id=managed_disk_id,
            virtual_machine_id=virtual_machine_id,
            create_option=create_option,
            timeouts=timeouts,
            write_accelerator_enabled=write_accelerator_enabled,
            count=count,
            depends_on=depends_on,
            lifecycle=lifecycle,
            provider=provider,
        )

        jsii.create(VirtualMachineDataDiskAttachment, self, [scope, id, config])

    @jsii.member(jsii_name="synthesizeAttributes")
    def _synthesize_attributes(self) -> typing.Mapping[builtins.str, typing.Any]:
        return jsii.invoke(self, "synthesizeAttributes", [])

    @builtins.property # type: ignore
    @jsii.member(jsii_name="caching")
    def caching(self) -> builtins.str:
        return jsii.get(self, "caching")

    @caching.setter # type: ignore
    def caching(self, value: builtins.str) -> None:
        jsii.set(self, "caching", value)

    @builtins.property # type: ignore
    @jsii.member(jsii_name="lun")
    def lun(self) -> jsii.Number:
        return jsii.get(self, "lun")

    @lun.setter # type: ignore
    def lun(self, value: jsii.Number) -> None:
        jsii.set(self, "lun", value)

    @builtins.property # type: ignore
    @jsii.member(jsii_name="managedDiskId")
    def managed_disk_id(self) -> builtins.str:
        return jsii.get(self, "managedDiskId")

    @managed_disk_id.setter # type: ignore
    def managed_disk_id(self, value: builtins.str) -> None:
        jsii.set(self, "managedDiskId", value)

    @builtins.property # type: ignore
    @jsii.member(jsii_name="virtualMachineId")
    def virtual_machine_id(self) -> builtins.str:
        return jsii.get(self, "virtualMachineId")

    @virtual_machine_id.setter # type: ignore
    def virtual_machine_id(self, value: builtins.str) -> None:
        jsii.set(self, "virtualMachineId", value)

    @builtins.property # type: ignore
    @jsii.member(jsii_name="createOption")
    def create_option(self) -> typing.Optional[builtins.str]:
        return jsii.get(self, "createOption")

    @create_option.setter # type: ignore
    def create_option(self, value: typing.Optional[builtins.str]) -> None:
        jsii.set(self, "createOption", value)

    @builtins.property # type: ignore
    @jsii.member(jsii_name="id")
    def id(self) -> typing.Optional[builtins.str]:
        return jsii.get(self, "id")

    @id.setter # type: ignore
    def id(self, value: typing.Optional[builtins.str]) -> None:
        jsii.set(self, "id", value)

    @builtins.property # type: ignore
    @jsii.member(jsii_name="timeouts")
    def timeouts(self) -> typing.Optional["VirtualMachineDataDiskAttachmentTimeouts"]:
        return jsii.get(self, "timeouts")

    @timeouts.setter # type: ignore
    def timeouts(
        self,
        value: typing.Optional["VirtualMachineDataDiskAttachmentTimeouts"],
    ) -> None:
        jsii.set(self, "timeouts", value)

    @builtins.property # type: ignore
    @jsii.member(jsii_name="writeAcceleratorEnabled")
    def write_accelerator_enabled(self) -> typing.Optional[builtins.bool]:
        return jsii.get(self, "writeAcceleratorEnabled")

    @write_accelerator_enabled.setter # type: ignore
    def write_accelerator_enabled(self, value: typing.Optional[builtins.bool]) -> None:
        jsii.set(self, "writeAcceleratorEnabled", value)


@jsii.data_type(
    jsii_type="@cdktf/provider-azurerm.VirtualMachineDataDiskAttachmentConfig",
    jsii_struct_bases=[cdktf.TerraformMetaArguments],
    name_mapping={
        "count": "count",
        "depends_on": "dependsOn",
        "lifecycle": "lifecycle",
        "provider": "provider",
        "caching": "caching",
        "lun": "lun",
        "managed_disk_id": "managedDiskId",
        "virtual_machine_id": "virtualMachineId",
        "create_option": "createOption",
        "timeouts": "timeouts",
        "write_accelerator_enabled": "writeAcceleratorEnabled",
    },
)
class VirtualMachineDataDiskAttachmentConfig(cdktf.TerraformMetaArguments):
    def __init__(
        self,
        *,
        count: typing.Optional[jsii.Number] = None,
        depends_on: typing.Optional[typing.List[cdktf.TerraformResource]] = None,
        lifecycle: typing.Optional[cdktf.TerraformResourceLifecycle] = None,
        provider: typing.Optional[cdktf.TerraformProvider] = None,
        caching: builtins.str,
        lun: jsii.Number,
        managed_disk_id: builtins.str,
        virtual_machine_id: builtins.str,
        create_option: typing.Optional[builtins.str] = None,
        timeouts: typing.Optional["VirtualMachineDataDiskAttachmentTimeouts"] = None,
        write_accelerator_enabled: typing.Optional[builtins.bool] = None,
    ) -> None:
        """
        :param count: 
        :param depends_on: 
        :param lifecycle: 
        :param provider: 
        :param caching: 
        :param lun: 
        :param managed_disk_id: 
        :param virtual_machine_id: 
        :param create_option: 
        :param timeouts: timeouts block.
        :param write_accelerator_enabled: 
        """
        if isinstance(lifecycle, dict):
            lifecycle = cdktf.TerraformResourceLifecycle(**lifecycle)
        if isinstance(timeouts, dict):
            timeouts = VirtualMachineDataDiskAttachmentTimeouts(**timeouts)
        self._values: typing.Dict[str, typing.Any] = {
            "caching": caching,
            "lun": lun,
            "managed_disk_id": managed_disk_id,
            "virtual_machine_id": virtual_machine_id,
        }
        if count is not None:
            self._values["count"] = count
        if depends_on is not None:
            self._values["depends_on"] = depends_on
        if lifecycle is not None:
            self._values["lifecycle"] = lifecycle
        if provider is not None:
            self._values["provider"] = provider
        if create_option is not None:
            self._values["create_option"] = create_option
        if timeouts is not None:
            self._values["timeouts"] = timeouts
        if write_accelerator_enabled is not None:
            self._values["write_accelerator_enabled"] = write_accelerator_enabled

    @builtins.property
    def count(self) -> typing.Optional[jsii.Number]:
        """
        :stability: experimental
        """
        result = self._values.get("count")
        return result

    @builtins.property
    def depends_on(self) -> typing.Optional[typing.List[cdktf.TerraformResource]]:
        """
        :stability: experimental
        """
        result = self._values.get("depends_on")
        return result

    @builtins.property
    def lifecycle(self) -> typing.Optional[cdktf.TerraformResourceLifecycle]:
        """
        :stability: experimental
        """
        result = self._values.get("lifecycle")
        return result

    @builtins.property
    def provider(self) -> typing.Optional[cdktf.TerraformProvider]:
        """
        :stability: experimental
        """
        result = self._values.get("provider")
        return result

    @builtins.property
    def caching(self) -> builtins.str:
        result = self._values.get("caching")
        assert result is not None, "Required property 'caching' is missing"
        return result

    @builtins.property
    def lun(self) -> jsii.Number:
        result = self._values.get("lun")
        assert result is not None, "Required property 'lun' is missing"
        return result

    @builtins.property
    def managed_disk_id(self) -> builtins.str:
        result = self._values.get("managed_disk_id")
        assert result is not None, "Required property 'managed_disk_id' is missing"
        return result

    @builtins.property
    def virtual_machine_id(self) -> builtins.str:
        result = self._values.get("virtual_machine_id")
        assert result is not None, "Required property 'virtual_machine_id' is missing"
        return result

    @builtins.property
    def create_option(self) -> typing.Optional[builtins.str]:
        result = self._values.get("create_option")
        return result

    @builtins.property
    def timeouts(self) -> typing.Optional["VirtualMachineDataDiskAttachmentTimeouts"]:
        """timeouts block."""
        result = self._values.get("timeouts")
        return result

    @builtins.property
    def write_accelerator_enabled(self) -> typing.Optional[builtins.bool]:
        result = self._values.get("write_accelerator_enabled")
        return result

    def __eq__(self, rhs: typing.Any) -> builtins.bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs: typing.Any) -> builtins.bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return "VirtualMachineDataDiskAttachmentConfig(%s)" % ", ".join(
            k + "=" + repr(v) for k, v in self._values.items()
        )


@jsii.data_type(
    jsii_type="@cdktf/provider-azurerm.VirtualMachineDataDiskAttachmentTimeouts",
    jsii_struct_bases=[],
    name_mapping={
        "create": "create",
        "delete": "delete",
        "read": "read",
        "update": "update",
    },
)
class VirtualMachineDataDiskAttachmentTimeouts:
    def __init__(
        self,
        *,
        create: typing.Optional[builtins.str] = None,
        delete: typing.Optional[builtins.str] = None,
        read: typing.Optional[builtins.str] = None,
        update: typing.Optional[builtins.str] = None,
    ) -> None:
        """
        :param create: 
        :param delete: 
        :param read: 
        :param update: 
        """
        self._values: typing.Dict[str, typing.Any] = {}
        if create is not None:
            self._values["create"] = create
        if delete is not None:
            self._values["delete"] = delete
        if read is not None:
            self._values["read"] = read
        if update is not None:
            self._values["update"] = update

    @builtins.property
    def create(self) -> typing.Optional[builtins.str]:
        result = self._values.get("create")
        return result

    @builtins.property
    def delete(self) -> typing.Optional[builtins.str]:
        result = self._values.get("delete")
        return result

    @builtins.property
    def read(self) -> typing.Optional[builtins.str]:
        result = self._values.get("read")
        return result

    @builtins.property
    def update(self) -> typing.Optional[builtins.str]:
        result = self._values.get("update")
        return result

    def __eq__(self, rhs: typing.Any) -> builtins.bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs: typing.Any) -> builtins.bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return "VirtualMachineDataDiskAttachmentTimeouts(%s)" % ", ".join(
            k + "=" + repr(v) for k, v in self._values.items()
        )


class VirtualMachineExtension(
    cdktf.TerraformResource,
    metaclass=jsii.JSIIMeta,
    jsii_type="@cdktf/provider-azurerm.VirtualMachineExtension",
):
    def __init__(
        self,
        scope: constructs.Construct,
        id: builtins.str,
        *,
        name: builtins.str,
        publisher: builtins.str,
        type: builtins.str,
        type_handler_version: builtins.str,
        virtual_machine_id: builtins.str,
        auto_upgrade_minor_version: typing.Optional[builtins.bool] = None,
        protected_settings: typing.Optional[builtins.str] = None,
        settings: typing.Optional[builtins.str] = None,
        tags: typing.Optional[typing.Mapping[builtins.str, builtins.str]] = None,
        timeouts: typing.Optional["VirtualMachineExtensionTimeouts"] = None,
        count: typing.Optional[jsii.Number] = None,
        depends_on: typing.Optional[typing.List[cdktf.TerraformResource]] = None,
        lifecycle: typing.Optional[cdktf.TerraformResourceLifecycle] = None,
        provider: typing.Optional[cdktf.TerraformProvider] = None,
    ) -> None:
        """
        :param scope: -
        :param id: -
        :param name: 
        :param publisher: 
        :param type: 
        :param type_handler_version: 
        :param virtual_machine_id: 
        :param auto_upgrade_minor_version: 
        :param protected_settings: 
        :param settings: 
        :param tags: 
        :param timeouts: timeouts block.
        :param count: 
        :param depends_on: 
        :param lifecycle: 
        :param provider: 
        """
        config = VirtualMachineExtensionConfig(
            name=name,
            publisher=publisher,
            type=type,
            type_handler_version=type_handler_version,
            virtual_machine_id=virtual_machine_id,
            auto_upgrade_minor_version=auto_upgrade_minor_version,
            protected_settings=protected_settings,
            settings=settings,
            tags=tags,
            timeouts=timeouts,
            count=count,
            depends_on=depends_on,
            lifecycle=lifecycle,
            provider=provider,
        )

        jsii.create(VirtualMachineExtension, self, [scope, id, config])

    @jsii.member(jsii_name="synthesizeAttributes")
    def _synthesize_attributes(self) -> typing.Mapping[builtins.str, typing.Any]:
        return jsii.invoke(self, "synthesizeAttributes", [])

    @builtins.property # type: ignore
    @jsii.member(jsii_name="name")
    def name(self) -> builtins.str:
        return jsii.get(self, "name")

    @name.setter # type: ignore
    def name(self, value: builtins.str) -> None:
        jsii.set(self, "name", value)

    @builtins.property # type: ignore
    @jsii.member(jsii_name="publisher")
    def publisher(self) -> builtins.str:
        return jsii.get(self, "publisher")

    @publisher.setter # type: ignore
    def publisher(self, value: builtins.str) -> None:
        jsii.set(self, "publisher", value)

    @builtins.property # type: ignore
    @jsii.member(jsii_name="type")
    def type(self) -> builtins.str:
        return jsii.get(self, "type")

    @type.setter # type: ignore
    def type(self, value: builtins.str) -> None:
        jsii.set(self, "type", value)

    @builtins.property # type: ignore
    @jsii.member(jsii_name="typeHandlerVersion")
    def type_handler_version(self) -> builtins.str:
        return jsii.get(self, "typeHandlerVersion")

    @type_handler_version.setter # type: ignore
    def type_handler_version(self, value: builtins.str) -> None:
        jsii.set(self, "typeHandlerVersion", value)

    @builtins.property # type: ignore
    @jsii.member(jsii_name="virtualMachineId")
    def virtual_machine_id(self) -> builtins.str:
        return jsii.get(self, "virtualMachineId")

    @virtual_machine_id.setter # type: ignore
    def virtual_machine_id(self, value: builtins.str) -> None:
        jsii.set(self, "virtualMachineId", value)

    @builtins.property # type: ignore
    @jsii.member(jsii_name="autoUpgradeMinorVersion")
    def auto_upgrade_minor_version(self) -> typing.Optional[builtins.bool]:
        return jsii.get(self, "autoUpgradeMinorVersion")

    @auto_upgrade_minor_version.setter # type: ignore
    def auto_upgrade_minor_version(self, value: typing.Optional[builtins.bool]) -> None:
        jsii.set(self, "autoUpgradeMinorVersion", value)

    @builtins.property # type: ignore
    @jsii.member(jsii_name="id")
    def id(self) -> typing.Optional[builtins.str]:
        return jsii.get(self, "id")

    @id.setter # type: ignore
    def id(self, value: typing.Optional[builtins.str]) -> None:
        jsii.set(self, "id", value)

    @builtins.property # type: ignore
    @jsii.member(jsii_name="protectedSettings")
    def protected_settings(self) -> typing.Optional[builtins.str]:
        return jsii.get(self, "protectedSettings")

    @protected_settings.setter # type: ignore
    def protected_settings(self, value: typing.Optional[builtins.str]) -> None:
        jsii.set(self, "protectedSettings", value)

    @builtins.property # type: ignore
    @jsii.member(jsii_name="settings")
    def settings(self) -> typing.Optional[builtins.str]:
        return jsii.get(self, "settings")

    @settings.setter # type: ignore
    def settings(self, value: typing.Optional[builtins.str]) -> None:
        jsii.set(self, "settings", value)

    @builtins.property # type: ignore
    @jsii.member(jsii_name="tags")
    def tags(self) -> typing.Optional[typing.Mapping[builtins.str, builtins.str]]:
        return jsii.get(self, "tags")

    @tags.setter # type: ignore
    def tags(
        self,
        value: typing.Optional[typing.Mapping[builtins.str, builtins.str]],
    ) -> None:
        jsii.set(self, "tags", value)

    @builtins.property # type: ignore
    @jsii.member(jsii_name="timeouts")
    def timeouts(self) -> typing.Optional["VirtualMachineExtensionTimeouts"]:
        return jsii.get(self, "timeouts")

    @timeouts.setter # type: ignore
    def timeouts(
        self,
        value: typing.Optional["VirtualMachineExtensionTimeouts"],
    ) -> None:
        jsii.set(self, "timeouts", value)


@jsii.data_type(
    jsii_type="@cdktf/provider-azurerm.VirtualMachineExtensionConfig",
    jsii_struct_bases=[cdktf.TerraformMetaArguments],
    name_mapping={
        "count": "count",
        "depends_on": "dependsOn",
        "lifecycle": "lifecycle",
        "provider": "provider",
        "name": "name",
        "publisher": "publisher",
        "type": "type",
        "type_handler_version": "typeHandlerVersion",
        "virtual_machine_id": "virtualMachineId",
        "auto_upgrade_minor_version": "autoUpgradeMinorVersion",
        "protected_settings": "protectedSettings",
        "settings": "settings",
        "tags": "tags",
        "timeouts": "timeouts",
    },
)
class VirtualMachineExtensionConfig(cdktf.TerraformMetaArguments):
    def __init__(
        self,
        *,
        count: typing.Optional[jsii.Number] = None,
        depends_on: typing.Optional[typing.List[cdktf.TerraformResource]] = None,
        lifecycle: typing.Optional[cdktf.TerraformResourceLifecycle] = None,
        provider: typing.Optional[cdktf.TerraformProvider] = None,
        name: builtins.str,
        publisher: builtins.str,
        type: builtins.str,
        type_handler_version: builtins.str,
        virtual_machine_id: builtins.str,
        auto_upgrade_minor_version: typing.Optional[builtins.bool] = None,
        protected_settings: typing.Optional[builtins.str] = None,
        settings: typing.Optional[builtins.str] = None,
        tags: typing.Optional[typing.Mapping[builtins.str, builtins.str]] = None,
        timeouts: typing.Optional["VirtualMachineExtensionTimeouts"] = None,
    ) -> None:
        """
        :param count: 
        :param depends_on: 
        :param lifecycle: 
        :param provider: 
        :param name: 
        :param publisher: 
        :param type: 
        :param type_handler_version: 
        :param virtual_machine_id: 
        :param auto_upgrade_minor_version: 
        :param protected_settings: 
        :param settings: 
        :param tags: 
        :param timeouts: timeouts block.
        """
        if isinstance(lifecycle, dict):
            lifecycle = cdktf.TerraformResourceLifecycle(**lifecycle)
        if isinstance(timeouts, dict):
            timeouts = VirtualMachineExtensionTimeouts(**timeouts)
        self._values: typing.Dict[str, typing.Any] = {
            "name": name,
            "publisher": publisher,
            "type": type,
            "type_handler_version": type_handler_version,
            "virtual_machine_id": virtual_machine_id,
        }
        if count is not None:
            self._values["count"] = count
        if depends_on is not None:
            self._values["depends_on"] = depends_on
        if lifecycle is not None:
            self._values["lifecycle"] = lifecycle
        if provider is not None:
            self._values["provider"] = provider
        if auto_upgrade_minor_version is not None:
            self._values["auto_upgrade_minor_version"] = auto_upgrade_minor_version
        if protected_settings is not None:
            self._values["protected_settings"] = protected_settings
        if settings is not None:
            self._values["settings"] = settings
        if tags is not None:
            self._values["tags"] = tags
        if timeouts is not None:
            self._values["timeouts"] = timeouts

    @builtins.property
    def count(self) -> typing.Optional[jsii.Number]:
        """
        :stability: experimental
        """
        result = self._values.get("count")
        return result

    @builtins.property
    def depends_on(self) -> typing.Optional[typing.List[cdktf.TerraformResource]]:
        """
        :stability: experimental
        """
        result = self._values.get("depends_on")
        return result

    @builtins.property
    def lifecycle(self) -> typing.Optional[cdktf.TerraformResourceLifecycle]:
        """
        :stability: experimental
        """
        result = self._values.get("lifecycle")
        return result

    @builtins.property
    def provider(self) -> typing.Optional[cdktf.TerraformProvider]:
        """
        :stability: experimental
        """
        result = self._values.get("provider")
        return result

    @builtins.property
    def name(self) -> builtins.str:
        result = self._values.get("name")
        assert result is not None, "Required property 'name' is missing"
        return result

    @builtins.property
    def publisher(self) -> builtins.str:
        result = self._values.get("publisher")
        assert result is not None, "Required property 'publisher' is missing"
        return result

    @builtins.property
    def type(self) -> builtins.str:
        result = self._values.get("type")
        assert result is not None, "Required property 'type' is missing"
        return result

    @builtins.property
    def type_handler_version(self) -> builtins.str:
        result = self._values.get("type_handler_version")
        assert result is not None, "Required property 'type_handler_version' is missing"
        return result

    @builtins.property
    def virtual_machine_id(self) -> builtins.str:
        result = self._values.get("virtual_machine_id")
        assert result is not None, "Required property 'virtual_machine_id' is missing"
        return result

    @builtins.property
    def auto_upgrade_minor_version(self) -> typing.Optional[builtins.bool]:
        result = self._values.get("auto_upgrade_minor_version")
        return result

    @builtins.property
    def protected_settings(self) -> typing.Optional[builtins.str]:
        result = self._values.get("protected_settings")
        return result

    @builtins.property
    def settings(self) -> typing.Optional[builtins.str]:
        result = self._values.get("settings")
        return result

    @builtins.property
    def tags(self) -> typing.Optional[typing.Mapping[builtins.str, builtins.str]]:
        result = self._values.get("tags")
        return result

    @builtins.property
    def timeouts(self) -> typing.Optional["VirtualMachineExtensionTimeouts"]:
        """timeouts block."""
        result = self._values.get("timeouts")
        return result

    def __eq__(self, rhs: typing.Any) -> builtins.bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs: typing.Any) -> builtins.bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return "VirtualMachineExtensionConfig(%s)" % ", ".join(
            k + "=" + repr(v) for k, v in self._values.items()
        )


@jsii.data_type(
    jsii_type="@cdktf/provider-azurerm.VirtualMachineExtensionTimeouts",
    jsii_struct_bases=[],
    name_mapping={
        "create": "create",
        "delete": "delete",
        "read": "read",
        "update": "update",
    },
)
class VirtualMachineExtensionTimeouts:
    def __init__(
        self,
        *,
        create: typing.Optional[builtins.str] = None,
        delete: typing.Optional[builtins.str] = None,
        read: typing.Optional[builtins.str] = None,
        update: typing.Optional[builtins.str] = None,
    ) -> None:
        """
        :param create: 
        :param delete: 
        :param read: 
        :param update: 
        """
        self._values: typing.Dict[str, typing.Any] = {}
        if create is not None:
            self._values["create"] = create
        if delete is not None:
            self._values["delete"] = delete
        if read is not None:
            self._values["read"] = read
        if update is not None:
            self._values["update"] = update

    @builtins.property
    def create(self) -> typing.Optional[builtins.str]:
        result = self._values.get("create")
        return result

    @builtins.property
    def delete(self) -> typing.Optional[builtins.str]:
        result = self._values.get("delete")
        return result

    @builtins.property
    def read(self) -> typing.Optional[builtins.str]:
        result = self._values.get("read")
        return result

    @builtins.property
    def update(self) -> typing.Optional[builtins.str]:
        result = self._values.get("update")
        return result

    def __eq__(self, rhs: typing.Any) -> builtins.bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs: typing.Any) -> builtins.bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return "VirtualMachineExtensionTimeouts(%s)" % ", ".join(
            k + "=" + repr(v) for k, v in self._values.items()
        )


@jsii.data_type(
    jsii_type="@cdktf/provider-azurerm.VirtualMachineIdentity",
    jsii_struct_bases=[],
    name_mapping={"type": "type", "identity_ids": "identityIds"},
)
class VirtualMachineIdentity:
    def __init__(
        self,
        *,
        type: builtins.str,
        identity_ids: typing.Optional[typing.List[builtins.str]] = None,
    ) -> None:
        """
        :param type: 
        :param identity_ids: 
        """
        self._values: typing.Dict[str, typing.Any] = {
            "type": type,
        }
        if identity_ids is not None:
            self._values["identity_ids"] = identity_ids

    @builtins.property
    def type(self) -> builtins.str:
        result = self._values.get("type")
        assert result is not None, "Required property 'type' is missing"
        return result

    @builtins.property
    def identity_ids(self) -> typing.Optional[typing.List[builtins.str]]:
        result = self._values.get("identity_ids")
        return result

    def __eq__(self, rhs: typing.Any) -> builtins.bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs: typing.Any) -> builtins.bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return "VirtualMachineIdentity(%s)" % ", ".join(
            k + "=" + repr(v) for k, v in self._values.items()
        )


@jsii.data_type(
    jsii_type="@cdktf/provider-azurerm.VirtualMachineOsProfile",
    jsii_struct_bases=[],
    name_mapping={
        "admin_username": "adminUsername",
        "computer_name": "computerName",
        "admin_password": "adminPassword",
        "custom_data": "customData",
    },
)
class VirtualMachineOsProfile:
    def __init__(
        self,
        *,
        admin_username: builtins.str,
        computer_name: builtins.str,
        admin_password: typing.Optional[builtins.str] = None,
        custom_data: typing.Optional[builtins.str] = None,
    ) -> None:
        """
        :param admin_username: 
        :param computer_name: 
        :param admin_password: 
        :param custom_data: 
        """
        self._values: typing.Dict[str, typing.Any] = {
            "admin_username": admin_username,
            "computer_name": computer_name,
        }
        if admin_password is not None:
            self._values["admin_password"] = admin_password
        if custom_data is not None:
            self._values["custom_data"] = custom_data

    @builtins.property
    def admin_username(self) -> builtins.str:
        result = self._values.get("admin_username")
        assert result is not None, "Required property 'admin_username' is missing"
        return result

    @builtins.property
    def computer_name(self) -> builtins.str:
        result = self._values.get("computer_name")
        assert result is not None, "Required property 'computer_name' is missing"
        return result

    @builtins.property
    def admin_password(self) -> typing.Optional[builtins.str]:
        result = self._values.get("admin_password")
        return result

    @builtins.property
    def custom_data(self) -> typing.Optional[builtins.str]:
        result = self._values.get("custom_data")
        return result

    def __eq__(self, rhs: typing.Any) -> builtins.bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs: typing.Any) -> builtins.bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return "VirtualMachineOsProfile(%s)" % ", ".join(
            k + "=" + repr(v) for k, v in self._values.items()
        )


@jsii.data_type(
    jsii_type="@cdktf/provider-azurerm.VirtualMachineOsProfileLinuxConfig",
    jsii_struct_bases=[],
    name_mapping={
        "disable_password_authentication": "disablePasswordAuthentication",
        "ssh_keys": "sshKeys",
    },
)
class VirtualMachineOsProfileLinuxConfig:
    def __init__(
        self,
        *,
        disable_password_authentication: builtins.bool,
        ssh_keys: typing.Optional[typing.List["VirtualMachineOsProfileLinuxConfigSshKeys"]] = None,
    ) -> None:
        """
        :param disable_password_authentication: 
        :param ssh_keys: ssh_keys block.
        """
        self._values: typing.Dict[str, typing.Any] = {
            "disable_password_authentication": disable_password_authentication,
        }
        if ssh_keys is not None:
            self._values["ssh_keys"] = ssh_keys

    @builtins.property
    def disable_password_authentication(self) -> builtins.bool:
        result = self._values.get("disable_password_authentication")
        assert result is not None, "Required property 'disable_password_authentication' is missing"
        return result

    @builtins.property
    def ssh_keys(
        self,
    ) -> typing.Optional[typing.List["VirtualMachineOsProfileLinuxConfigSshKeys"]]:
        """ssh_keys block."""
        result = self._values.get("ssh_keys")
        return result

    def __eq__(self, rhs: typing.Any) -> builtins.bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs: typing.Any) -> builtins.bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return "VirtualMachineOsProfileLinuxConfig(%s)" % ", ".join(
            k + "=" + repr(v) for k, v in self._values.items()
        )


@jsii.data_type(
    jsii_type="@cdktf/provider-azurerm.VirtualMachineOsProfileLinuxConfigSshKeys",
    jsii_struct_bases=[],
    name_mapping={"key_data": "keyData", "path": "path"},
)
class VirtualMachineOsProfileLinuxConfigSshKeys:
    def __init__(self, *, key_data: builtins.str, path: builtins.str) -> None:
        """
        :param key_data: 
        :param path: 
        """
        self._values: typing.Dict[str, typing.Any] = {
            "key_data": key_data,
            "path": path,
        }

    @builtins.property
    def key_data(self) -> builtins.str:
        result = self._values.get("key_data")
        assert result is not None, "Required property 'key_data' is missing"
        return result

    @builtins.property
    def path(self) -> builtins.str:
        result = self._values.get("path")
        assert result is not None, "Required property 'path' is missing"
        return result

    def __eq__(self, rhs: typing.Any) -> builtins.bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs: typing.Any) -> builtins.bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return "VirtualMachineOsProfileLinuxConfigSshKeys(%s)" % ", ".join(
            k + "=" + repr(v) for k, v in self._values.items()
        )


@jsii.data_type(
    jsii_type="@cdktf/provider-azurerm.VirtualMachineOsProfileSecrets",
    jsii_struct_bases=[],
    name_mapping={
        "source_vault_id": "sourceVaultId",
        "vault_certificates": "vaultCertificates",
    },
)
class VirtualMachineOsProfileSecrets:
    def __init__(
        self,
        *,
        source_vault_id: builtins.str,
        vault_certificates: typing.Optional[typing.List["VirtualMachineOsProfileSecretsVaultCertificates"]] = None,
    ) -> None:
        """
        :param source_vault_id: 
        :param vault_certificates: vault_certificates block.
        """
        self._values: typing.Dict[str, typing.Any] = {
            "source_vault_id": source_vault_id,
        }
        if vault_certificates is not None:
            self._values["vault_certificates"] = vault_certificates

    @builtins.property
    def source_vault_id(self) -> builtins.str:
        result = self._values.get("source_vault_id")
        assert result is not None, "Required property 'source_vault_id' is missing"
        return result

    @builtins.property
    def vault_certificates(
        self,
    ) -> typing.Optional[typing.List["VirtualMachineOsProfileSecretsVaultCertificates"]]:
        """vault_certificates block."""
        result = self._values.get("vault_certificates")
        return result

    def __eq__(self, rhs: typing.Any) -> builtins.bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs: typing.Any) -> builtins.bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return "VirtualMachineOsProfileSecrets(%s)" % ", ".join(
            k + "=" + repr(v) for k, v in self._values.items()
        )


@jsii.data_type(
    jsii_type="@cdktf/provider-azurerm.VirtualMachineOsProfileSecretsVaultCertificates",
    jsii_struct_bases=[],
    name_mapping={
        "certificate_url": "certificateUrl",
        "certificate_store": "certificateStore",
    },
)
class VirtualMachineOsProfileSecretsVaultCertificates:
    def __init__(
        self,
        *,
        certificate_url: builtins.str,
        certificate_store: typing.Optional[builtins.str] = None,
    ) -> None:
        """
        :param certificate_url: 
        :param certificate_store: 
        """
        self._values: typing.Dict[str, typing.Any] = {
            "certificate_url": certificate_url,
        }
        if certificate_store is not None:
            self._values["certificate_store"] = certificate_store

    @builtins.property
    def certificate_url(self) -> builtins.str:
        result = self._values.get("certificate_url")
        assert result is not None, "Required property 'certificate_url' is missing"
        return result

    @builtins.property
    def certificate_store(self) -> typing.Optional[builtins.str]:
        result = self._values.get("certificate_store")
        return result

    def __eq__(self, rhs: typing.Any) -> builtins.bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs: typing.Any) -> builtins.bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return "VirtualMachineOsProfileSecretsVaultCertificates(%s)" % ", ".join(
            k + "=" + repr(v) for k, v in self._values.items()
        )


@jsii.data_type(
    jsii_type="@cdktf/provider-azurerm.VirtualMachineOsProfileWindowsConfig",
    jsii_struct_bases=[],
    name_mapping={
        "additional_unattend_config": "additionalUnattendConfig",
        "enable_automatic_upgrades": "enableAutomaticUpgrades",
        "provision_vm_agent": "provisionVmAgent",
        "timezone": "timezone",
        "winrm": "winrm",
    },
)
class VirtualMachineOsProfileWindowsConfig:
    def __init__(
        self,
        *,
        additional_unattend_config: typing.Optional[typing.List["VirtualMachineOsProfileWindowsConfigAdditionalUnattendConfig"]] = None,
        enable_automatic_upgrades: typing.Optional[builtins.bool] = None,
        provision_vm_agent: typing.Optional[builtins.bool] = None,
        timezone: typing.Optional[builtins.str] = None,
        winrm: typing.Optional[typing.List["VirtualMachineOsProfileWindowsConfigWinrm"]] = None,
    ) -> None:
        """
        :param additional_unattend_config: additional_unattend_config block.
        :param enable_automatic_upgrades: 
        :param provision_vm_agent: 
        :param timezone: 
        :param winrm: winrm block.
        """
        self._values: typing.Dict[str, typing.Any] = {}
        if additional_unattend_config is not None:
            self._values["additional_unattend_config"] = additional_unattend_config
        if enable_automatic_upgrades is not None:
            self._values["enable_automatic_upgrades"] = enable_automatic_upgrades
        if provision_vm_agent is not None:
            self._values["provision_vm_agent"] = provision_vm_agent
        if timezone is not None:
            self._values["timezone"] = timezone
        if winrm is not None:
            self._values["winrm"] = winrm

    @builtins.property
    def additional_unattend_config(
        self,
    ) -> typing.Optional[typing.List["VirtualMachineOsProfileWindowsConfigAdditionalUnattendConfig"]]:
        """additional_unattend_config block."""
        result = self._values.get("additional_unattend_config")
        return result

    @builtins.property
    def enable_automatic_upgrades(self) -> typing.Optional[builtins.bool]:
        result = self._values.get("enable_automatic_upgrades")
        return result

    @builtins.property
    def provision_vm_agent(self) -> typing.Optional[builtins.bool]:
        result = self._values.get("provision_vm_agent")
        return result

    @builtins.property
    def timezone(self) -> typing.Optional[builtins.str]:
        result = self._values.get("timezone")
        return result

    @builtins.property
    def winrm(
        self,
    ) -> typing.Optional[typing.List["VirtualMachineOsProfileWindowsConfigWinrm"]]:
        """winrm block."""
        result = self._values.get("winrm")
        return result

    def __eq__(self, rhs: typing.Any) -> builtins.bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs: typing.Any) -> builtins.bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return "VirtualMachineOsProfileWindowsConfig(%s)" % ", ".join(
            k + "=" + repr(v) for k, v in self._values.items()
        )


@jsii.data_type(
    jsii_type="@cdktf/provider-azurerm.VirtualMachineOsProfileWindowsConfigAdditionalUnattendConfig",
    jsii_struct_bases=[],
    name_mapping={
        "component": "component",
        "content": "content",
        "pass_": "pass",
        "setting_name": "settingName",
    },
)
class VirtualMachineOsProfileWindowsConfigAdditionalUnattendConfig:
    def __init__(
        self,
        *,
        component: builtins.str,
        content: builtins.str,
        pass_: builtins.str,
        setting_name: builtins.str,
    ) -> None:
        """
        :param component: 
        :param content: 
        :param pass_: 
        :param setting_name: 
        """
        self._values: typing.Dict[str, typing.Any] = {
            "component": component,
            "content": content,
            "pass_": pass_,
            "setting_name": setting_name,
        }

    @builtins.property
    def component(self) -> builtins.str:
        result = self._values.get("component")
        assert result is not None, "Required property 'component' is missing"
        return result

    @builtins.property
    def content(self) -> builtins.str:
        result = self._values.get("content")
        assert result is not None, "Required property 'content' is missing"
        return result

    @builtins.property
    def pass_(self) -> builtins.str:
        result = self._values.get("pass_")
        assert result is not None, "Required property 'pass_' is missing"
        return result

    @builtins.property
    def setting_name(self) -> builtins.str:
        result = self._values.get("setting_name")
        assert result is not None, "Required property 'setting_name' is missing"
        return result

    def __eq__(self, rhs: typing.Any) -> builtins.bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs: typing.Any) -> builtins.bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return "VirtualMachineOsProfileWindowsConfigAdditionalUnattendConfig(%s)" % ", ".join(
            k + "=" + repr(v) for k, v in self._values.items()
        )


@jsii.data_type(
    jsii_type="@cdktf/provider-azurerm.VirtualMachineOsProfileWindowsConfigWinrm",
    jsii_struct_bases=[],
    name_mapping={"protocol": "protocol", "certificate_url": "certificateUrl"},
)
class VirtualMachineOsProfileWindowsConfigWinrm:
    def __init__(
        self,
        *,
        protocol: builtins.str,
        certificate_url: typing.Optional[builtins.str] = None,
    ) -> None:
        """
        :param protocol: 
        :param certificate_url: 
        """
        self._values: typing.Dict[str, typing.Any] = {
            "protocol": protocol,
        }
        if certificate_url is not None:
            self._values["certificate_url"] = certificate_url

    @builtins.property
    def protocol(self) -> builtins.str:
        result = self._values.get("protocol")
        assert result is not None, "Required property 'protocol' is missing"
        return result

    @builtins.property
    def certificate_url(self) -> typing.Optional[builtins.str]:
        result = self._values.get("certificate_url")
        return result

    def __eq__(self, rhs: typing.Any) -> builtins.bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs: typing.Any) -> builtins.bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return "VirtualMachineOsProfileWindowsConfigWinrm(%s)" % ", ".join(
            k + "=" + repr(v) for k, v in self._values.items()
        )


@jsii.data_type(
    jsii_type="@cdktf/provider-azurerm.VirtualMachinePlan",
    jsii_struct_bases=[],
    name_mapping={"name": "name", "product": "product", "publisher": "publisher"},
)
class VirtualMachinePlan:
    def __init__(
        self,
        *,
        name: builtins.str,
        product: builtins.str,
        publisher: builtins.str,
    ) -> None:
        """
        :param name: 
        :param product: 
        :param publisher: 
        """
        self._values: typing.Dict[str, typing.Any] = {
            "name": name,
            "product": product,
            "publisher": publisher,
        }

    @builtins.property
    def name(self) -> builtins.str:
        result = self._values.get("name")
        assert result is not None, "Required property 'name' is missing"
        return result

    @builtins.property
    def product(self) -> builtins.str:
        result = self._values.get("product")
        assert result is not None, "Required property 'product' is missing"
        return result

    @builtins.property
    def publisher(self) -> builtins.str:
        result = self._values.get("publisher")
        assert result is not None, "Required property 'publisher' is missing"
        return result

    def __eq__(self, rhs: typing.Any) -> builtins.bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs: typing.Any) -> builtins.bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return "VirtualMachinePlan(%s)" % ", ".join(
            k + "=" + repr(v) for k, v in self._values.items()
        )


class VirtualMachineScaleSet(
    cdktf.TerraformResource,
    metaclass=jsii.JSIIMeta,
    jsii_type="@cdktf/provider-azurerm.VirtualMachineScaleSet",
):
    def __init__(
        self,
        scope: constructs.Construct,
        id: builtins.str,
        *,
        location: builtins.str,
        name: builtins.str,
        network_profile: typing.List["VirtualMachineScaleSetNetworkProfile"],
        os_profile: typing.List["VirtualMachineScaleSetOsProfile"],
        resource_group_name: builtins.str,
        sku: typing.List["VirtualMachineScaleSetSku"],
        storage_profile_os_disk: typing.List["VirtualMachineScaleSetStorageProfileOsDisk"],
        upgrade_policy_mode: builtins.str,
        automatic_os_upgrade: typing.Optional[builtins.bool] = None,
        boot_diagnostics: typing.Optional[typing.List["VirtualMachineScaleSetBootDiagnostics"]] = None,
        eviction_policy: typing.Optional[builtins.str] = None,
        extension: typing.Optional[typing.List["VirtualMachineScaleSetExtension"]] = None,
        health_probe_id: typing.Optional[builtins.str] = None,
        identity: typing.Optional[typing.List["VirtualMachineScaleSetIdentity"]] = None,
        license_type: typing.Optional[builtins.str] = None,
        os_profile_linux_config: typing.Optional[typing.List["VirtualMachineScaleSetOsProfileLinuxConfig"]] = None,
        os_profile_secrets: typing.Optional[typing.List["VirtualMachineScaleSetOsProfileSecrets"]] = None,
        os_profile_windows_config: typing.Optional[typing.List["VirtualMachineScaleSetOsProfileWindowsConfig"]] = None,
        overprovision: typing.Optional[builtins.bool] = None,
        plan: typing.Optional[typing.List["VirtualMachineScaleSetPlan"]] = None,
        priority: typing.Optional[builtins.str] = None,
        proximity_placement_group_id: typing.Optional[builtins.str] = None,
        rolling_upgrade_policy: typing.Optional[typing.List["VirtualMachineScaleSetRollingUpgradePolicy"]] = None,
        single_placement_group: typing.Optional[builtins.bool] = None,
        storage_profile_data_disk: typing.Optional[typing.List["VirtualMachineScaleSetStorageProfileDataDisk"]] = None,
        storage_profile_image_reference: typing.Optional[typing.List["VirtualMachineScaleSetStorageProfileImageReference"]] = None,
        tags: typing.Optional[typing.Mapping[builtins.str, builtins.str]] = None,
        timeouts: typing.Optional["VirtualMachineScaleSetTimeouts"] = None,
        zones: typing.Optional[typing.List[builtins.str]] = None,
        count: typing.Optional[jsii.Number] = None,
        depends_on: typing.Optional[typing.List[cdktf.TerraformResource]] = None,
        lifecycle: typing.Optional[cdktf.TerraformResourceLifecycle] = None,
        provider: typing.Optional[cdktf.TerraformProvider] = None,
    ) -> None:
        """
        :param scope: -
        :param id: -
        :param location: 
        :param name: 
        :param network_profile: network_profile block.
        :param os_profile: os_profile block.
        :param resource_group_name: 
        :param sku: sku block.
        :param storage_profile_os_disk: storage_profile_os_disk block.
        :param upgrade_policy_mode: 
        :param automatic_os_upgrade: 
        :param boot_diagnostics: boot_diagnostics block.
        :param eviction_policy: 
        :param extension: extension block.
        :param health_probe_id: 
        :param identity: identity block.
        :param license_type: 
        :param os_profile_linux_config: os_profile_linux_config block.
        :param os_profile_secrets: os_profile_secrets block.
        :param os_profile_windows_config: os_profile_windows_config block.
        :param overprovision: 
        :param plan: plan block.
        :param priority: 
        :param proximity_placement_group_id: 
        :param rolling_upgrade_policy: rolling_upgrade_policy block.
        :param single_placement_group: 
        :param storage_profile_data_disk: storage_profile_data_disk block.
        :param storage_profile_image_reference: storage_profile_image_reference block.
        :param tags: 
        :param timeouts: timeouts block.
        :param zones: 
        :param count: 
        :param depends_on: 
        :param lifecycle: 
        :param provider: 
        """
        config = VirtualMachineScaleSetConfig(
            location=location,
            name=name,
            network_profile=network_profile,
            os_profile=os_profile,
            resource_group_name=resource_group_name,
            sku=sku,
            storage_profile_os_disk=storage_profile_os_disk,
            upgrade_policy_mode=upgrade_policy_mode,
            automatic_os_upgrade=automatic_os_upgrade,
            boot_diagnostics=boot_diagnostics,
            eviction_policy=eviction_policy,
            extension=extension,
            health_probe_id=health_probe_id,
            identity=identity,
            license_type=license_type,
            os_profile_linux_config=os_profile_linux_config,
            os_profile_secrets=os_profile_secrets,
            os_profile_windows_config=os_profile_windows_config,
            overprovision=overprovision,
            plan=plan,
            priority=priority,
            proximity_placement_group_id=proximity_placement_group_id,
            rolling_upgrade_policy=rolling_upgrade_policy,
            single_placement_group=single_placement_group,
            storage_profile_data_disk=storage_profile_data_disk,
            storage_profile_image_reference=storage_profile_image_reference,
            tags=tags,
            timeouts=timeouts,
            zones=zones,
            count=count,
            depends_on=depends_on,
            lifecycle=lifecycle,
            provider=provider,
        )

        jsii.create(VirtualMachineScaleSet, self, [scope, id, config])

    @jsii.member(jsii_name="synthesizeAttributes")
    def _synthesize_attributes(self) -> typing.Mapping[builtins.str, typing.Any]:
        return jsii.invoke(self, "synthesizeAttributes", [])

    @builtins.property # type: ignore
    @jsii.member(jsii_name="location")
    def location(self) -> builtins.str:
        return jsii.get(self, "location")

    @location.setter # type: ignore
    def location(self, value: builtins.str) -> None:
        jsii.set(self, "location", value)

    @builtins.property # type: ignore
    @jsii.member(jsii_name="name")
    def name(self) -> builtins.str:
        return jsii.get(self, "name")

    @name.setter # type: ignore
    def name(self, value: builtins.str) -> None:
        jsii.set(self, "name", value)

    @builtins.property # type: ignore
    @jsii.member(jsii_name="networkProfile")
    def network_profile(self) -> typing.List["VirtualMachineScaleSetNetworkProfile"]:
        return jsii.get(self, "networkProfile")

    @network_profile.setter # type: ignore
    def network_profile(
        self,
        value: typing.List["VirtualMachineScaleSetNetworkProfile"],
    ) -> None:
        jsii.set(self, "networkProfile", value)

    @builtins.property # type: ignore
    @jsii.member(jsii_name="osProfile")
    def os_profile(self) -> typing.List["VirtualMachineScaleSetOsProfile"]:
        return jsii.get(self, "osProfile")

    @os_profile.setter # type: ignore
    def os_profile(self, value: typing.List["VirtualMachineScaleSetOsProfile"]) -> None:
        jsii.set(self, "osProfile", value)

    @builtins.property # type: ignore
    @jsii.member(jsii_name="resourceGroupName")
    def resource_group_name(self) -> builtins.str:
        return jsii.get(self, "resourceGroupName")

    @resource_group_name.setter # type: ignore
    def resource_group_name(self, value: builtins.str) -> None:
        jsii.set(self, "resourceGroupName", value)

    @builtins.property # type: ignore
    @jsii.member(jsii_name="sku")
    def sku(self) -> typing.List["VirtualMachineScaleSetSku"]:
        return jsii.get(self, "sku")

    @sku.setter # type: ignore
    def sku(self, value: typing.List["VirtualMachineScaleSetSku"]) -> None:
        jsii.set(self, "sku", value)

    @builtins.property # type: ignore
    @jsii.member(jsii_name="storageProfileOsDisk")
    def storage_profile_os_disk(
        self,
    ) -> typing.List["VirtualMachineScaleSetStorageProfileOsDisk"]:
        return jsii.get(self, "storageProfileOsDisk")

    @storage_profile_os_disk.setter # type: ignore
    def storage_profile_os_disk(
        self,
        value: typing.List["VirtualMachineScaleSetStorageProfileOsDisk"],
    ) -> None:
        jsii.set(self, "storageProfileOsDisk", value)

    @builtins.property # type: ignore
    @jsii.member(jsii_name="upgradePolicyMode")
    def upgrade_policy_mode(self) -> builtins.str:
        return jsii.get(self, "upgradePolicyMode")

    @upgrade_policy_mode.setter # type: ignore
    def upgrade_policy_mode(self, value: builtins.str) -> None:
        jsii.set(self, "upgradePolicyMode", value)

    @builtins.property # type: ignore
    @jsii.member(jsii_name="automaticOsUpgrade")
    def automatic_os_upgrade(self) -> typing.Optional[builtins.bool]:
        return jsii.get(self, "automaticOsUpgrade")

    @automatic_os_upgrade.setter # type: ignore
    def automatic_os_upgrade(self, value: typing.Optional[builtins.bool]) -> None:
        jsii.set(self, "automaticOsUpgrade", value)

    @builtins.property # type: ignore
    @jsii.member(jsii_name="bootDiagnostics")
    def boot_diagnostics(
        self,
    ) -> typing.Optional[typing.List["VirtualMachineScaleSetBootDiagnostics"]]:
        return jsii.get(self, "bootDiagnostics")

    @boot_diagnostics.setter # type: ignore
    def boot_diagnostics(
        self,
        value: typing.Optional[typing.List["VirtualMachineScaleSetBootDiagnostics"]],
    ) -> None:
        jsii.set(self, "bootDiagnostics", value)

    @builtins.property # type: ignore
    @jsii.member(jsii_name="evictionPolicy")
    def eviction_policy(self) -> typing.Optional[builtins.str]:
        return jsii.get(self, "evictionPolicy")

    @eviction_policy.setter # type: ignore
    def eviction_policy(self, value: typing.Optional[builtins.str]) -> None:
        jsii.set(self, "evictionPolicy", value)

    @builtins.property # type: ignore
    @jsii.member(jsii_name="extension")
    def extension(
        self,
    ) -> typing.Optional[typing.List["VirtualMachineScaleSetExtension"]]:
        return jsii.get(self, "extension")

    @extension.setter # type: ignore
    def extension(
        self,
        value: typing.Optional[typing.List["VirtualMachineScaleSetExtension"]],
    ) -> None:
        jsii.set(self, "extension", value)

    @builtins.property # type: ignore
    @jsii.member(jsii_name="healthProbeId")
    def health_probe_id(self) -> typing.Optional[builtins.str]:
        return jsii.get(self, "healthProbeId")

    @health_probe_id.setter # type: ignore
    def health_probe_id(self, value: typing.Optional[builtins.str]) -> None:
        jsii.set(self, "healthProbeId", value)

    @builtins.property # type: ignore
    @jsii.member(jsii_name="id")
    def id(self) -> typing.Optional[builtins.str]:
        return jsii.get(self, "id")

    @id.setter # type: ignore
    def id(self, value: typing.Optional[builtins.str]) -> None:
        jsii.set(self, "id", value)

    @builtins.property # type: ignore
    @jsii.member(jsii_name="identity")
    def identity(
        self,
    ) -> typing.Optional[typing.List["VirtualMachineScaleSetIdentity"]]:
        return jsii.get(self, "identity")

    @identity.setter # type: ignore
    def identity(
        self,
        value: typing.Optional[typing.List["VirtualMachineScaleSetIdentity"]],
    ) -> None:
        jsii.set(self, "identity", value)

    @builtins.property # type: ignore
    @jsii.member(jsii_name="licenseType")
    def license_type(self) -> typing.Optional[builtins.str]:
        return jsii.get(self, "licenseType")

    @license_type.setter # type: ignore
    def license_type(self, value: typing.Optional[builtins.str]) -> None:
        jsii.set(self, "licenseType", value)

    @builtins.property # type: ignore
    @jsii.member(jsii_name="osProfileLinuxConfig")
    def os_profile_linux_config(
        self,
    ) -> typing.Optional[typing.List["VirtualMachineScaleSetOsProfileLinuxConfig"]]:
        return jsii.get(self, "osProfileLinuxConfig")

    @os_profile_linux_config.setter # type: ignore
    def os_profile_linux_config(
        self,
        value: typing.Optional[typing.List["VirtualMachineScaleSetOsProfileLinuxConfig"]],
    ) -> None:
        jsii.set(self, "osProfileLinuxConfig", value)

    @builtins.property # type: ignore
    @jsii.member(jsii_name="osProfileSecrets")
    def os_profile_secrets(
        self,
    ) -> typing.Optional[typing.List["VirtualMachineScaleSetOsProfileSecrets"]]:
        return jsii.get(self, "osProfileSecrets")

    @os_profile_secrets.setter # type: ignore
    def os_profile_secrets(
        self,
        value: typing.Optional[typing.List["VirtualMachineScaleSetOsProfileSecrets"]],
    ) -> None:
        jsii.set(self, "osProfileSecrets", value)

    @builtins.property # type: ignore
    @jsii.member(jsii_name="osProfileWindowsConfig")
    def os_profile_windows_config(
        self,
    ) -> typing.Optional[typing.List["VirtualMachineScaleSetOsProfileWindowsConfig"]]:
        return jsii.get(self, "osProfileWindowsConfig")

    @os_profile_windows_config.setter # type: ignore
    def os_profile_windows_config(
        self,
        value: typing.Optional[typing.List["VirtualMachineScaleSetOsProfileWindowsConfig"]],
    ) -> None:
        jsii.set(self, "osProfileWindowsConfig", value)

    @builtins.property # type: ignore
    @jsii.member(jsii_name="overprovision")
    def overprovision(self) -> typing.Optional[builtins.bool]:
        return jsii.get(self, "overprovision")

    @overprovision.setter # type: ignore
    def overprovision(self, value: typing.Optional[builtins.bool]) -> None:
        jsii.set(self, "overprovision", value)

    @builtins.property # type: ignore
    @jsii.member(jsii_name="plan")
    def plan(self) -> typing.Optional[typing.List["VirtualMachineScaleSetPlan"]]:
        return jsii.get(self, "plan")

    @plan.setter # type: ignore
    def plan(
        self,
        value: typing.Optional[typing.List["VirtualMachineScaleSetPlan"]],
    ) -> None:
        jsii.set(self, "plan", value)

    @builtins.property # type: ignore
    @jsii.member(jsii_name="priority")
    def priority(self) -> typing.Optional[builtins.str]:
        return jsii.get(self, "priority")

    @priority.setter # type: ignore
    def priority(self, value: typing.Optional[builtins.str]) -> None:
        jsii.set(self, "priority", value)

    @builtins.property # type: ignore
    @jsii.member(jsii_name="proximityPlacementGroupId")
    def proximity_placement_group_id(self) -> typing.Optional[builtins.str]:
        return jsii.get(self, "proximityPlacementGroupId")

    @proximity_placement_group_id.setter # type: ignore
    def proximity_placement_group_id(
        self,
        value: typing.Optional[builtins.str],
    ) -> None:
        jsii.set(self, "proximityPlacementGroupId", value)

    @builtins.property # type: ignore
    @jsii.member(jsii_name="rollingUpgradePolicy")
    def rolling_upgrade_policy(
        self,
    ) -> typing.Optional[typing.List["VirtualMachineScaleSetRollingUpgradePolicy"]]:
        return jsii.get(self, "rollingUpgradePolicy")

    @rolling_upgrade_policy.setter # type: ignore
    def rolling_upgrade_policy(
        self,
        value: typing.Optional[typing.List["VirtualMachineScaleSetRollingUpgradePolicy"]],
    ) -> None:
        jsii.set(self, "rollingUpgradePolicy", value)

    @builtins.property # type: ignore
    @jsii.member(jsii_name="singlePlacementGroup")
    def single_placement_group(self) -> typing.Optional[builtins.bool]:
        return jsii.get(self, "singlePlacementGroup")

    @single_placement_group.setter # type: ignore
    def single_placement_group(self, value: typing.Optional[builtins.bool]) -> None:
        jsii.set(self, "singlePlacementGroup", value)

    @builtins.property # type: ignore
    @jsii.member(jsii_name="storageProfileDataDisk")
    def storage_profile_data_disk(
        self,
    ) -> typing.Optional[typing.List["VirtualMachineScaleSetStorageProfileDataDisk"]]:
        return jsii.get(self, "storageProfileDataDisk")

    @storage_profile_data_disk.setter # type: ignore
    def storage_profile_data_disk(
        self,
        value: typing.Optional[typing.List["VirtualMachineScaleSetStorageProfileDataDisk"]],
    ) -> None:
        jsii.set(self, "storageProfileDataDisk", value)

    @builtins.property # type: ignore
    @jsii.member(jsii_name="storageProfileImageReference")
    def storage_profile_image_reference(
        self,
    ) -> typing.Optional[typing.List["VirtualMachineScaleSetStorageProfileImageReference"]]:
        return jsii.get(self, "storageProfileImageReference")

    @storage_profile_image_reference.setter # type: ignore
    def storage_profile_image_reference(
        self,
        value: typing.Optional[typing.List["VirtualMachineScaleSetStorageProfileImageReference"]],
    ) -> None:
        jsii.set(self, "storageProfileImageReference", value)

    @builtins.property # type: ignore
    @jsii.member(jsii_name="tags")
    def tags(self) -> typing.Optional[typing.Mapping[builtins.str, builtins.str]]:
        return jsii.get(self, "tags")

    @tags.setter # type: ignore
    def tags(
        self,
        value: typing.Optional[typing.Mapping[builtins.str, builtins.str]],
    ) -> None:
        jsii.set(self, "tags", value)

    @builtins.property # type: ignore
    @jsii.member(jsii_name="timeouts")
    def timeouts(self) -> typing.Optional["VirtualMachineScaleSetTimeouts"]:
        return jsii.get(self, "timeouts")

    @timeouts.setter # type: ignore
    def timeouts(
        self,
        value: typing.Optional["VirtualMachineScaleSetTimeouts"],
    ) -> None:
        jsii.set(self, "timeouts", value)

    @builtins.property # type: ignore
    @jsii.member(jsii_name="zones")
    def zones(self) -> typing.Optional[typing.List[builtins.str]]:
        return jsii.get(self, "zones")

    @zones.setter # type: ignore
    def zones(self, value: typing.Optional[typing.List[builtins.str]]) -> None:
        jsii.set(self, "zones", value)


@jsii.data_type(
    jsii_type="@cdktf/provider-azurerm.VirtualMachineScaleSetBootDiagnostics",
    jsii_struct_bases=[],
    name_mapping={"storage_uri": "storageUri", "enabled": "enabled"},
)
class VirtualMachineScaleSetBootDiagnostics:
    def __init__(
        self,
        *,
        storage_uri: builtins.str,
        enabled: typing.Optional[builtins.bool] = None,
    ) -> None:
        """
        :param storage_uri: 
        :param enabled: 
        """
        self._values: typing.Dict[str, typing.Any] = {
            "storage_uri": storage_uri,
        }
        if enabled is not None:
            self._values["enabled"] = enabled

    @builtins.property
    def storage_uri(self) -> builtins.str:
        result = self._values.get("storage_uri")
        assert result is not None, "Required property 'storage_uri' is missing"
        return result

    @builtins.property
    def enabled(self) -> typing.Optional[builtins.bool]:
        result = self._values.get("enabled")
        return result

    def __eq__(self, rhs: typing.Any) -> builtins.bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs: typing.Any) -> builtins.bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return "VirtualMachineScaleSetBootDiagnostics(%s)" % ", ".join(
            k + "=" + repr(v) for k, v in self._values.items()
        )


@jsii.data_type(
    jsii_type="@cdktf/provider-azurerm.VirtualMachineScaleSetConfig",
    jsii_struct_bases=[cdktf.TerraformMetaArguments],
    name_mapping={
        "count": "count",
        "depends_on": "dependsOn",
        "lifecycle": "lifecycle",
        "provider": "provider",
        "location": "location",
        "name": "name",
        "network_profile": "networkProfile",
        "os_profile": "osProfile",
        "resource_group_name": "resourceGroupName",
        "sku": "sku",
        "storage_profile_os_disk": "storageProfileOsDisk",
        "upgrade_policy_mode": "upgradePolicyMode",
        "automatic_os_upgrade": "automaticOsUpgrade",
        "boot_diagnostics": "bootDiagnostics",
        "eviction_policy": "evictionPolicy",
        "extension": "extension",
        "health_probe_id": "healthProbeId",
        "identity": "identity",
        "license_type": "licenseType",
        "os_profile_linux_config": "osProfileLinuxConfig",
        "os_profile_secrets": "osProfileSecrets",
        "os_profile_windows_config": "osProfileWindowsConfig",
        "overprovision": "overprovision",
        "plan": "plan",
        "priority": "priority",
        "proximity_placement_group_id": "proximityPlacementGroupId",
        "rolling_upgrade_policy": "rollingUpgradePolicy",
        "single_placement_group": "singlePlacementGroup",
        "storage_profile_data_disk": "storageProfileDataDisk",
        "storage_profile_image_reference": "storageProfileImageReference",
        "tags": "tags",
        "timeouts": "timeouts",
        "zones": "zones",
    },
)
class VirtualMachineScaleSetConfig(cdktf.TerraformMetaArguments):
    def __init__(
        self,
        *,
        count: typing.Optional[jsii.Number] = None,
        depends_on: typing.Optional[typing.List[cdktf.TerraformResource]] = None,
        lifecycle: typing.Optional[cdktf.TerraformResourceLifecycle] = None,
        provider: typing.Optional[cdktf.TerraformProvider] = None,
        location: builtins.str,
        name: builtins.str,
        network_profile: typing.List["VirtualMachineScaleSetNetworkProfile"],
        os_profile: typing.List["VirtualMachineScaleSetOsProfile"],
        resource_group_name: builtins.str,
        sku: typing.List["VirtualMachineScaleSetSku"],
        storage_profile_os_disk: typing.List["VirtualMachineScaleSetStorageProfileOsDisk"],
        upgrade_policy_mode: builtins.str,
        automatic_os_upgrade: typing.Optional[builtins.bool] = None,
        boot_diagnostics: typing.Optional[typing.List[VirtualMachineScaleSetBootDiagnostics]] = None,
        eviction_policy: typing.Optional[builtins.str] = None,
        extension: typing.Optional[typing.List["VirtualMachineScaleSetExtension"]] = None,
        health_probe_id: typing.Optional[builtins.str] = None,
        identity: typing.Optional[typing.List["VirtualMachineScaleSetIdentity"]] = None,
        license_type: typing.Optional[builtins.str] = None,
        os_profile_linux_config: typing.Optional[typing.List["VirtualMachineScaleSetOsProfileLinuxConfig"]] = None,
        os_profile_secrets: typing.Optional[typing.List["VirtualMachineScaleSetOsProfileSecrets"]] = None,
        os_profile_windows_config: typing.Optional[typing.List["VirtualMachineScaleSetOsProfileWindowsConfig"]] = None,
        overprovision: typing.Optional[builtins.bool] = None,
        plan: typing.Optional[typing.List["VirtualMachineScaleSetPlan"]] = None,
        priority: typing.Optional[builtins.str] = None,
        proximity_placement_group_id: typing.Optional[builtins.str] = None,
        rolling_upgrade_policy: typing.Optional[typing.List["VirtualMachineScaleSetRollingUpgradePolicy"]] = None,
        single_placement_group: typing.Optional[builtins.bool] = None,
        storage_profile_data_disk: typing.Optional[typing.List["VirtualMachineScaleSetStorageProfileDataDisk"]] = None,
        storage_profile_image_reference: typing.Optional[typing.List["VirtualMachineScaleSetStorageProfileImageReference"]] = None,
        tags: typing.Optional[typing.Mapping[builtins.str, builtins.str]] = None,
        timeouts: typing.Optional["VirtualMachineScaleSetTimeouts"] = None,
        zones: typing.Optional[typing.List[builtins.str]] = None,
    ) -> None:
        """
        :param count: 
        :param depends_on: 
        :param lifecycle: 
        :param provider: 
        :param location: 
        :param name: 
        :param network_profile: network_profile block.
        :param os_profile: os_profile block.
        :param resource_group_name: 
        :param sku: sku block.
        :param storage_profile_os_disk: storage_profile_os_disk block.
        :param upgrade_policy_mode: 
        :param automatic_os_upgrade: 
        :param boot_diagnostics: boot_diagnostics block.
        :param eviction_policy: 
        :param extension: extension block.
        :param health_probe_id: 
        :param identity: identity block.
        :param license_type: 
        :param os_profile_linux_config: os_profile_linux_config block.
        :param os_profile_secrets: os_profile_secrets block.
        :param os_profile_windows_config: os_profile_windows_config block.
        :param overprovision: 
        :param plan: plan block.
        :param priority: 
        :param proximity_placement_group_id: 
        :param rolling_upgrade_policy: rolling_upgrade_policy block.
        :param single_placement_group: 
        :param storage_profile_data_disk: storage_profile_data_disk block.
        :param storage_profile_image_reference: storage_profile_image_reference block.
        :param tags: 
        :param timeouts: timeouts block.
        :param zones: 
        """
        if isinstance(lifecycle, dict):
            lifecycle = cdktf.TerraformResourceLifecycle(**lifecycle)
        if isinstance(timeouts, dict):
            timeouts = VirtualMachineScaleSetTimeouts(**timeouts)
        self._values: typing.Dict[str, typing.Any] = {
            "location": location,
            "name": name,
            "network_profile": network_profile,
            "os_profile": os_profile,
            "resource_group_name": resource_group_name,
            "sku": sku,
            "storage_profile_os_disk": storage_profile_os_disk,
            "upgrade_policy_mode": upgrade_policy_mode,
        }
        if count is not None:
            self._values["count"] = count
        if depends_on is not None:
            self._values["depends_on"] = depends_on
        if lifecycle is not None:
            self._values["lifecycle"] = lifecycle
        if provider is not None:
            self._values["provider"] = provider
        if automatic_os_upgrade is not None:
            self._values["automatic_os_upgrade"] = automatic_os_upgrade
        if boot_diagnostics is not None:
            self._values["boot_diagnostics"] = boot_diagnostics
        if eviction_policy is not None:
            self._values["eviction_policy"] = eviction_policy
        if extension is not None:
            self._values["extension"] = extension
        if health_probe_id is not None:
            self._values["health_probe_id"] = health_probe_id
        if identity is not None:
            self._values["identity"] = identity
        if license_type is not None:
            self._values["license_type"] = license_type
        if os_profile_linux_config is not None:
            self._values["os_profile_linux_config"] = os_profile_linux_config
        if os_profile_secrets is not None:
            self._values["os_profile_secrets"] = os_profile_secrets
        if os_profile_windows_config is not None:
            self._values["os_profile_windows_config"] = os_profile_windows_config
        if overprovision is not None:
            self._values["overprovision"] = overprovision
        if plan is not None:
            self._values["plan"] = plan
        if priority is not None:
            self._values["priority"] = priority
        if proximity_placement_group_id is not None:
            self._values["proximity_placement_group_id"] = proximity_placement_group_id
        if rolling_upgrade_policy is not None:
            self._values["rolling_upgrade_policy"] = rolling_upgrade_policy
        if single_placement_group is not None:
            self._values["single_placement_group"] = single_placement_group
        if storage_profile_data_disk is not None:
            self._values["storage_profile_data_disk"] = storage_profile_data_disk
        if storage_profile_image_reference is not None:
            self._values["storage_profile_image_reference"] = storage_profile_image_reference
        if tags is not None:
            self._values["tags"] = tags
        if timeouts is not None:
            self._values["timeouts"] = timeouts
        if zones is not None:
            self._values["zones"] = zones

    @builtins.property
    def count(self) -> typing.Optional[jsii.Number]:
        """
        :stability: experimental
        """
        result = self._values.get("count")
        return result

    @builtins.property
    def depends_on(self) -> typing.Optional[typing.List[cdktf.TerraformResource]]:
        """
        :stability: experimental
        """
        result = self._values.get("depends_on")
        return result

    @builtins.property
    def lifecycle(self) -> typing.Optional[cdktf.TerraformResourceLifecycle]:
        """
        :stability: experimental
        """
        result = self._values.get("lifecycle")
        return result

    @builtins.property
    def provider(self) -> typing.Optional[cdktf.TerraformProvider]:
        """
        :stability: experimental
        """
        result = self._values.get("provider")
        return result

    @builtins.property
    def location(self) -> builtins.str:
        result = self._values.get("location")
        assert result is not None, "Required property 'location' is missing"
        return result

    @builtins.property
    def name(self) -> builtins.str:
        result = self._values.get("name")
        assert result is not None, "Required property 'name' is missing"
        return result

    @builtins.property
    def network_profile(self) -> typing.List["VirtualMachineScaleSetNetworkProfile"]:
        """network_profile block."""
        result = self._values.get("network_profile")
        assert result is not None, "Required property 'network_profile' is missing"
        return result

    @builtins.property
    def os_profile(self) -> typing.List["VirtualMachineScaleSetOsProfile"]:
        """os_profile block."""
        result = self._values.get("os_profile")
        assert result is not None, "Required property 'os_profile' is missing"
        return result

    @builtins.property
    def resource_group_name(self) -> builtins.str:
        result = self._values.get("resource_group_name")
        assert result is not None, "Required property 'resource_group_name' is missing"
        return result

    @builtins.property
    def sku(self) -> typing.List["VirtualMachineScaleSetSku"]:
        """sku block."""
        result = self._values.get("sku")
        assert result is not None, "Required property 'sku' is missing"
        return result

    @builtins.property
    def storage_profile_os_disk(
        self,
    ) -> typing.List["VirtualMachineScaleSetStorageProfileOsDisk"]:
        """storage_profile_os_disk block."""
        result = self._values.get("storage_profile_os_disk")
        assert result is not None, "Required property 'storage_profile_os_disk' is missing"
        return result

    @builtins.property
    def upgrade_policy_mode(self) -> builtins.str:
        result = self._values.get("upgrade_policy_mode")
        assert result is not None, "Required property 'upgrade_policy_mode' is missing"
        return result

    @builtins.property
    def automatic_os_upgrade(self) -> typing.Optional[builtins.bool]:
        result = self._values.get("automatic_os_upgrade")
        return result

    @builtins.property
    def boot_diagnostics(
        self,
    ) -> typing.Optional[typing.List[VirtualMachineScaleSetBootDiagnostics]]:
        """boot_diagnostics block."""
        result = self._values.get("boot_diagnostics")
        return result

    @builtins.property
    def eviction_policy(self) -> typing.Optional[builtins.str]:
        result = self._values.get("eviction_policy")
        return result

    @builtins.property
    def extension(
        self,
    ) -> typing.Optional[typing.List["VirtualMachineScaleSetExtension"]]:
        """extension block."""
        result = self._values.get("extension")
        return result

    @builtins.property
    def health_probe_id(self) -> typing.Optional[builtins.str]:
        result = self._values.get("health_probe_id")
        return result

    @builtins.property
    def identity(
        self,
    ) -> typing.Optional[typing.List["VirtualMachineScaleSetIdentity"]]:
        """identity block."""
        result = self._values.get("identity")
        return result

    @builtins.property
    def license_type(self) -> typing.Optional[builtins.str]:
        result = self._values.get("license_type")
        return result

    @builtins.property
    def os_profile_linux_config(
        self,
    ) -> typing.Optional[typing.List["VirtualMachineScaleSetOsProfileLinuxConfig"]]:
        """os_profile_linux_config block."""
        result = self._values.get("os_profile_linux_config")
        return result

    @builtins.property
    def os_profile_secrets(
        self,
    ) -> typing.Optional[typing.List["VirtualMachineScaleSetOsProfileSecrets"]]:
        """os_profile_secrets block."""
        result = self._values.get("os_profile_secrets")
        return result

    @builtins.property
    def os_profile_windows_config(
        self,
    ) -> typing.Optional[typing.List["VirtualMachineScaleSetOsProfileWindowsConfig"]]:
        """os_profile_windows_config block."""
        result = self._values.get("os_profile_windows_config")
        return result

    @builtins.property
    def overprovision(self) -> typing.Optional[builtins.bool]:
        result = self._values.get("overprovision")
        return result

    @builtins.property
    def plan(self) -> typing.Optional[typing.List["VirtualMachineScaleSetPlan"]]:
        """plan block."""
        result = self._values.get("plan")
        return result

    @builtins.property
    def priority(self) -> typing.Optional[builtins.str]:
        result = self._values.get("priority")
        return result

    @builtins.property
    def proximity_placement_group_id(self) -> typing.Optional[builtins.str]:
        result = self._values.get("proximity_placement_group_id")
        return result

    @builtins.property
    def rolling_upgrade_policy(
        self,
    ) -> typing.Optional[typing.List["VirtualMachineScaleSetRollingUpgradePolicy"]]:
        """rolling_upgrade_policy block."""
        result = self._values.get("rolling_upgrade_policy")
        return result

    @builtins.property
    def single_placement_group(self) -> typing.Optional[builtins.bool]:
        result = self._values.get("single_placement_group")
        return result

    @builtins.property
    def storage_profile_data_disk(
        self,
    ) -> typing.Optional[typing.List["VirtualMachineScaleSetStorageProfileDataDisk"]]:
        """storage_profile_data_disk block."""
        result = self._values.get("storage_profile_data_disk")
        return result

    @builtins.property
    def storage_profile_image_reference(
        self,
    ) -> typing.Optional[typing.List["VirtualMachineScaleSetStorageProfileImageReference"]]:
        """storage_profile_image_reference block."""
        result = self._values.get("storage_profile_image_reference")
        return result

    @builtins.property
    def tags(self) -> typing.Optional[typing.Mapping[builtins.str, builtins.str]]:
        result = self._values.get("tags")
        return result

    @builtins.property
    def timeouts(self) -> typing.Optional["VirtualMachineScaleSetTimeouts"]:
        """timeouts block."""
        result = self._values.get("timeouts")
        return result

    @builtins.property
    def zones(self) -> typing.Optional[typing.List[builtins.str]]:
        result = self._values.get("zones")
        return result

    def __eq__(self, rhs: typing.Any) -> builtins.bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs: typing.Any) -> builtins.bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return "VirtualMachineScaleSetConfig(%s)" % ", ".join(
            k + "=" + repr(v) for k, v in self._values.items()
        )


@jsii.data_type(
    jsii_type="@cdktf/provider-azurerm.VirtualMachineScaleSetExtension",
    jsii_struct_bases=[],
    name_mapping={
        "name": "name",
        "publisher": "publisher",
        "type": "type",
        "type_handler_version": "typeHandlerVersion",
        "auto_upgrade_minor_version": "autoUpgradeMinorVersion",
        "protected_settings": "protectedSettings",
        "provision_after_extensions": "provisionAfterExtensions",
        "settings": "settings",
    },
)
class VirtualMachineScaleSetExtension:
    def __init__(
        self,
        *,
        name: builtins.str,
        publisher: builtins.str,
        type: builtins.str,
        type_handler_version: builtins.str,
        auto_upgrade_minor_version: typing.Optional[builtins.bool] = None,
        protected_settings: typing.Optional[builtins.str] = None,
        provision_after_extensions: typing.Optional[typing.List[builtins.str]] = None,
        settings: typing.Optional[builtins.str] = None,
    ) -> None:
        """
        :param name: 
        :param publisher: 
        :param type: 
        :param type_handler_version: 
        :param auto_upgrade_minor_version: 
        :param protected_settings: 
        :param provision_after_extensions: 
        :param settings: 
        """
        self._values: typing.Dict[str, typing.Any] = {
            "name": name,
            "publisher": publisher,
            "type": type,
            "type_handler_version": type_handler_version,
        }
        if auto_upgrade_minor_version is not None:
            self._values["auto_upgrade_minor_version"] = auto_upgrade_minor_version
        if protected_settings is not None:
            self._values["protected_settings"] = protected_settings
        if provision_after_extensions is not None:
            self._values["provision_after_extensions"] = provision_after_extensions
        if settings is not None:
            self._values["settings"] = settings

    @builtins.property
    def name(self) -> builtins.str:
        result = self._values.get("name")
        assert result is not None, "Required property 'name' is missing"
        return result

    @builtins.property
    def publisher(self) -> builtins.str:
        result = self._values.get("publisher")
        assert result is not None, "Required property 'publisher' is missing"
        return result

    @builtins.property
    def type(self) -> builtins.str:
        result = self._values.get("type")
        assert result is not None, "Required property 'type' is missing"
        return result

    @builtins.property
    def type_handler_version(self) -> builtins.str:
        result = self._values.get("type_handler_version")
        assert result is not None, "Required property 'type_handler_version' is missing"
        return result

    @builtins.property
    def auto_upgrade_minor_version(self) -> typing.Optional[builtins.bool]:
        result = self._values.get("auto_upgrade_minor_version")
        return result

    @builtins.property
    def protected_settings(self) -> typing.Optional[builtins.str]:
        result = self._values.get("protected_settings")
        return result

    @builtins.property
    def provision_after_extensions(self) -> typing.Optional[typing.List[builtins.str]]:
        result = self._values.get("provision_after_extensions")
        return result

    @builtins.property
    def settings(self) -> typing.Optional[builtins.str]:
        result = self._values.get("settings")
        return result

    def __eq__(self, rhs: typing.Any) -> builtins.bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs: typing.Any) -> builtins.bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return "VirtualMachineScaleSetExtension(%s)" % ", ".join(
            k + "=" + repr(v) for k, v in self._values.items()
        )


class VirtualMachineScaleSetExtensionA(
    cdktf.TerraformResource,
    metaclass=jsii.JSIIMeta,
    jsii_type="@cdktf/provider-azurerm.VirtualMachineScaleSetExtensionA",
):
    def __init__(
        self,
        scope: constructs.Construct,
        id: builtins.str,
        *,
        name: builtins.str,
        publisher: builtins.str,
        type: builtins.str,
        type_handler_version: builtins.str,
        virtual_machine_scale_set_id: builtins.str,
        auto_upgrade_minor_version: typing.Optional[builtins.bool] = None,
        force_update_tag: typing.Optional[builtins.str] = None,
        protected_settings: typing.Optional[builtins.str] = None,
        provision_after_extensions: typing.Optional[typing.List[builtins.str]] = None,
        settings: typing.Optional[builtins.str] = None,
        timeouts: typing.Optional["VirtualMachineScaleSetExtensionTimeouts"] = None,
        count: typing.Optional[jsii.Number] = None,
        depends_on: typing.Optional[typing.List[cdktf.TerraformResource]] = None,
        lifecycle: typing.Optional[cdktf.TerraformResourceLifecycle] = None,
        provider: typing.Optional[cdktf.TerraformProvider] = None,
    ) -> None:
        """
        :param scope: -
        :param id: -
        :param name: 
        :param publisher: 
        :param type: 
        :param type_handler_version: 
        :param virtual_machine_scale_set_id: 
        :param auto_upgrade_minor_version: 
        :param force_update_tag: 
        :param protected_settings: 
        :param provision_after_extensions: 
        :param settings: 
        :param timeouts: timeouts block.
        :param count: 
        :param depends_on: 
        :param lifecycle: 
        :param provider: 
        """
        config = VirtualMachineScaleSetExtensionAConfig(
            name=name,
            publisher=publisher,
            type=type,
            type_handler_version=type_handler_version,
            virtual_machine_scale_set_id=virtual_machine_scale_set_id,
            auto_upgrade_minor_version=auto_upgrade_minor_version,
            force_update_tag=force_update_tag,
            protected_settings=protected_settings,
            provision_after_extensions=provision_after_extensions,
            settings=settings,
            timeouts=timeouts,
            count=count,
            depends_on=depends_on,
            lifecycle=lifecycle,
            provider=provider,
        )

        jsii.create(VirtualMachineScaleSetExtensionA, self, [scope, id, config])

    @jsii.member(jsii_name="synthesizeAttributes")
    def _synthesize_attributes(self) -> typing.Mapping[builtins.str, typing.Any]:
        return jsii.invoke(self, "synthesizeAttributes", [])

    @builtins.property # type: ignore
    @jsii.member(jsii_name="name")
    def name(self) -> builtins.str:
        return jsii.get(self, "name")

    @name.setter # type: ignore
    def name(self, value: builtins.str) -> None:
        jsii.set(self, "name", value)

    @builtins.property # type: ignore
    @jsii.member(jsii_name="publisher")
    def publisher(self) -> builtins.str:
        return jsii.get(self, "publisher")

    @publisher.setter # type: ignore
    def publisher(self, value: builtins.str) -> None:
        jsii.set(self, "publisher", value)

    @builtins.property # type: ignore
    @jsii.member(jsii_name="type")
    def type(self) -> builtins.str:
        return jsii.get(self, "type")

    @type.setter # type: ignore
    def type(self, value: builtins.str) -> None:
        jsii.set(self, "type", value)

    @builtins.property # type: ignore
    @jsii.member(jsii_name="typeHandlerVersion")
    def type_handler_version(self) -> builtins.str:
        return jsii.get(self, "typeHandlerVersion")

    @type_handler_version.setter # type: ignore
    def type_handler_version(self, value: builtins.str) -> None:
        jsii.set(self, "typeHandlerVersion", value)

    @builtins.property # type: ignore
    @jsii.member(jsii_name="virtualMachineScaleSetId")
    def virtual_machine_scale_set_id(self) -> builtins.str:
        return jsii.get(self, "virtualMachineScaleSetId")

    @virtual_machine_scale_set_id.setter # type: ignore
    def virtual_machine_scale_set_id(self, value: builtins.str) -> None:
        jsii.set(self, "virtualMachineScaleSetId", value)

    @builtins.property # type: ignore
    @jsii.member(jsii_name="autoUpgradeMinorVersion")
    def auto_upgrade_minor_version(self) -> typing.Optional[builtins.bool]:
        return jsii.get(self, "autoUpgradeMinorVersion")

    @auto_upgrade_minor_version.setter # type: ignore
    def auto_upgrade_minor_version(self, value: typing.Optional[builtins.bool]) -> None:
        jsii.set(self, "autoUpgradeMinorVersion", value)

    @builtins.property # type: ignore
    @jsii.member(jsii_name="forceUpdateTag")
    def force_update_tag(self) -> typing.Optional[builtins.str]:
        return jsii.get(self, "forceUpdateTag")

    @force_update_tag.setter # type: ignore
    def force_update_tag(self, value: typing.Optional[builtins.str]) -> None:
        jsii.set(self, "forceUpdateTag", value)

    @builtins.property # type: ignore
    @jsii.member(jsii_name="id")
    def id(self) -> typing.Optional[builtins.str]:
        return jsii.get(self, "id")

    @id.setter # type: ignore
    def id(self, value: typing.Optional[builtins.str]) -> None:
        jsii.set(self, "id", value)

    @builtins.property # type: ignore
    @jsii.member(jsii_name="protectedSettings")
    def protected_settings(self) -> typing.Optional[builtins.str]:
        return jsii.get(self, "protectedSettings")

    @protected_settings.setter # type: ignore
    def protected_settings(self, value: typing.Optional[builtins.str]) -> None:
        jsii.set(self, "protectedSettings", value)

    @builtins.property # type: ignore
    @jsii.member(jsii_name="provisionAfterExtensions")
    def provision_after_extensions(self) -> typing.Optional[typing.List[builtins.str]]:
        return jsii.get(self, "provisionAfterExtensions")

    @provision_after_extensions.setter # type: ignore
    def provision_after_extensions(
        self,
        value: typing.Optional[typing.List[builtins.str]],
    ) -> None:
        jsii.set(self, "provisionAfterExtensions", value)

    @builtins.property # type: ignore
    @jsii.member(jsii_name="settings")
    def settings(self) -> typing.Optional[builtins.str]:
        return jsii.get(self, "settings")

    @settings.setter # type: ignore
    def settings(self, value: typing.Optional[builtins.str]) -> None:
        jsii.set(self, "settings", value)

    @builtins.property # type: ignore
    @jsii.member(jsii_name="timeouts")
    def timeouts(self) -> typing.Optional["VirtualMachineScaleSetExtensionTimeouts"]:
        return jsii.get(self, "timeouts")

    @timeouts.setter # type: ignore
    def timeouts(
        self,
        value: typing.Optional["VirtualMachineScaleSetExtensionTimeouts"],
    ) -> None:
        jsii.set(self, "timeouts", value)


@jsii.data_type(
    jsii_type="@cdktf/provider-azurerm.VirtualMachineScaleSetExtensionAConfig",
    jsii_struct_bases=[cdktf.TerraformMetaArguments],
    name_mapping={
        "count": "count",
        "depends_on": "dependsOn",
        "lifecycle": "lifecycle",
        "provider": "provider",
        "name": "name",
        "publisher": "publisher",
        "type": "type",
        "type_handler_version": "typeHandlerVersion",
        "virtual_machine_scale_set_id": "virtualMachineScaleSetId",
        "auto_upgrade_minor_version": "autoUpgradeMinorVersion",
        "force_update_tag": "forceUpdateTag",
        "protected_settings": "protectedSettings",
        "provision_after_extensions": "provisionAfterExtensions",
        "settings": "settings",
        "timeouts": "timeouts",
    },
)
class VirtualMachineScaleSetExtensionAConfig(cdktf.TerraformMetaArguments):
    def __init__(
        self,
        *,
        count: typing.Optional[jsii.Number] = None,
        depends_on: typing.Optional[typing.List[cdktf.TerraformResource]] = None,
        lifecycle: typing.Optional[cdktf.TerraformResourceLifecycle] = None,
        provider: typing.Optional[cdktf.TerraformProvider] = None,
        name: builtins.str,
        publisher: builtins.str,
        type: builtins.str,
        type_handler_version: builtins.str,
        virtual_machine_scale_set_id: builtins.str,
        auto_upgrade_minor_version: typing.Optional[builtins.bool] = None,
        force_update_tag: typing.Optional[builtins.str] = None,
        protected_settings: typing.Optional[builtins.str] = None,
        provision_after_extensions: typing.Optional[typing.List[builtins.str]] = None,
        settings: typing.Optional[builtins.str] = None,
        timeouts: typing.Optional["VirtualMachineScaleSetExtensionTimeouts"] = None,
    ) -> None:
        """
        :param count: 
        :param depends_on: 
        :param lifecycle: 
        :param provider: 
        :param name: 
        :param publisher: 
        :param type: 
        :param type_handler_version: 
        :param virtual_machine_scale_set_id: 
        :param auto_upgrade_minor_version: 
        :param force_update_tag: 
        :param protected_settings: 
        :param provision_after_extensions: 
        :param settings: 
        :param timeouts: timeouts block.
        """
        if isinstance(lifecycle, dict):
            lifecycle = cdktf.TerraformResourceLifecycle(**lifecycle)
        if isinstance(timeouts, dict):
            timeouts = VirtualMachineScaleSetExtensionTimeouts(**timeouts)
        self._values: typing.Dict[str, typing.Any] = {
            "name": name,
            "publisher": publisher,
            "type": type,
            "type_handler_version": type_handler_version,
            "virtual_machine_scale_set_id": virtual_machine_scale_set_id,
        }
        if count is not None:
            self._values["count"] = count
        if depends_on is not None:
            self._values["depends_on"] = depends_on
        if lifecycle is not None:
            self._values["lifecycle"] = lifecycle
        if provider is not None:
            self._values["provider"] = provider
        if auto_upgrade_minor_version is not None:
            self._values["auto_upgrade_minor_version"] = auto_upgrade_minor_version
        if force_update_tag is not None:
            self._values["force_update_tag"] = force_update_tag
        if protected_settings is not None:
            self._values["protected_settings"] = protected_settings
        if provision_after_extensions is not None:
            self._values["provision_after_extensions"] = provision_after_extensions
        if settings is not None:
            self._values["settings"] = settings
        if timeouts is not None:
            self._values["timeouts"] = timeouts

    @builtins.property
    def count(self) -> typing.Optional[jsii.Number]:
        """
        :stability: experimental
        """
        result = self._values.get("count")
        return result

    @builtins.property
    def depends_on(self) -> typing.Optional[typing.List[cdktf.TerraformResource]]:
        """
        :stability: experimental
        """
        result = self._values.get("depends_on")
        return result

    @builtins.property
    def lifecycle(self) -> typing.Optional[cdktf.TerraformResourceLifecycle]:
        """
        :stability: experimental
        """
        result = self._values.get("lifecycle")
        return result

    @builtins.property
    def provider(self) -> typing.Optional[cdktf.TerraformProvider]:
        """
        :stability: experimental
        """
        result = self._values.get("provider")
        return result

    @builtins.property
    def name(self) -> builtins.str:
        result = self._values.get("name")
        assert result is not None, "Required property 'name' is missing"
        return result

    @builtins.property
    def publisher(self) -> builtins.str:
        result = self._values.get("publisher")
        assert result is not None, "Required property 'publisher' is missing"
        return result

    @builtins.property
    def type(self) -> builtins.str:
        result = self._values.get("type")
        assert result is not None, "Required property 'type' is missing"
        return result

    @builtins.property
    def type_handler_version(self) -> builtins.str:
        result = self._values.get("type_handler_version")
        assert result is not None, "Required property 'type_handler_version' is missing"
        return result

    @builtins.property
    def virtual_machine_scale_set_id(self) -> builtins.str:
        result = self._values.get("virtual_machine_scale_set_id")
        assert result is not None, "Required property 'virtual_machine_scale_set_id' is missing"
        return result

    @builtins.property
    def auto_upgrade_minor_version(self) -> typing.Optional[builtins.bool]:
        result = self._values.get("auto_upgrade_minor_version")
        return result

    @builtins.property
    def force_update_tag(self) -> typing.Optional[builtins.str]:
        result = self._values.get("force_update_tag")
        return result

    @builtins.property
    def protected_settings(self) -> typing.Optional[builtins.str]:
        result = self._values.get("protected_settings")
        return result

    @builtins.property
    def provision_after_extensions(self) -> typing.Optional[typing.List[builtins.str]]:
        result = self._values.get("provision_after_extensions")
        return result

    @builtins.property
    def settings(self) -> typing.Optional[builtins.str]:
        result = self._values.get("settings")
        return result

    @builtins.property
    def timeouts(self) -> typing.Optional["VirtualMachineScaleSetExtensionTimeouts"]:
        """timeouts block."""
        result = self._values.get("timeouts")
        return result

    def __eq__(self, rhs: typing.Any) -> builtins.bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs: typing.Any) -> builtins.bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return "VirtualMachineScaleSetExtensionAConfig(%s)" % ", ".join(
            k + "=" + repr(v) for k, v in self._values.items()
        )


@jsii.data_type(
    jsii_type="@cdktf/provider-azurerm.VirtualMachineScaleSetExtensionTimeouts",
    jsii_struct_bases=[],
    name_mapping={
        "create": "create",
        "delete": "delete",
        "read": "read",
        "update": "update",
    },
)
class VirtualMachineScaleSetExtensionTimeouts:
    def __init__(
        self,
        *,
        create: typing.Optional[builtins.str] = None,
        delete: typing.Optional[builtins.str] = None,
        read: typing.Optional[builtins.str] = None,
        update: typing.Optional[builtins.str] = None,
    ) -> None:
        """
        :param create: 
        :param delete: 
        :param read: 
        :param update: 
        """
        self._values: typing.Dict[str, typing.Any] = {}
        if create is not None:
            self._values["create"] = create
        if delete is not None:
            self._values["delete"] = delete
        if read is not None:
            self._values["read"] = read
        if update is not None:
            self._values["update"] = update

    @builtins.property
    def create(self) -> typing.Optional[builtins.str]:
        result = self._values.get("create")
        return result

    @builtins.property
    def delete(self) -> typing.Optional[builtins.str]:
        result = self._values.get("delete")
        return result

    @builtins.property
    def read(self) -> typing.Optional[builtins.str]:
        result = self._values.get("read")
        return result

    @builtins.property
    def update(self) -> typing.Optional[builtins.str]:
        result = self._values.get("update")
        return result

    def __eq__(self, rhs: typing.Any) -> builtins.bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs: typing.Any) -> builtins.bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return "VirtualMachineScaleSetExtensionTimeouts(%s)" % ", ".join(
            k + "=" + repr(v) for k, v in self._values.items()
        )


@jsii.data_type(
    jsii_type="@cdktf/provider-azurerm.VirtualMachineScaleSetIdentity",
    jsii_struct_bases=[],
    name_mapping={"type": "type", "identity_ids": "identityIds"},
)
class VirtualMachineScaleSetIdentity:
    def __init__(
        self,
        *,
        type: builtins.str,
        identity_ids: typing.Optional[typing.List[builtins.str]] = None,
    ) -> None:
        """
        :param type: 
        :param identity_ids: 
        """
        self._values: typing.Dict[str, typing.Any] = {
            "type": type,
        }
        if identity_ids is not None:
            self._values["identity_ids"] = identity_ids

    @builtins.property
    def type(self) -> builtins.str:
        result = self._values.get("type")
        assert result is not None, "Required property 'type' is missing"
        return result

    @builtins.property
    def identity_ids(self) -> typing.Optional[typing.List[builtins.str]]:
        result = self._values.get("identity_ids")
        return result

    def __eq__(self, rhs: typing.Any) -> builtins.bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs: typing.Any) -> builtins.bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return "VirtualMachineScaleSetIdentity(%s)" % ", ".join(
            k + "=" + repr(v) for k, v in self._values.items()
        )


@jsii.data_type(
    jsii_type="@cdktf/provider-azurerm.VirtualMachineScaleSetNetworkProfile",
    jsii_struct_bases=[],
    name_mapping={
        "ip_configuration": "ipConfiguration",
        "name": "name",
        "primary": "primary",
        "accelerated_networking": "acceleratedNetworking",
        "dns_settings": "dnsSettings",
        "ip_forwarding": "ipForwarding",
        "network_security_group_id": "networkSecurityGroupId",
    },
)
class VirtualMachineScaleSetNetworkProfile:
    def __init__(
        self,
        *,
        ip_configuration: typing.List["VirtualMachineScaleSetNetworkProfileIpConfiguration"],
        name: builtins.str,
        primary: builtins.bool,
        accelerated_networking: typing.Optional[builtins.bool] = None,
        dns_settings: typing.Optional[typing.List["VirtualMachineScaleSetNetworkProfileDnsSettings"]] = None,
        ip_forwarding: typing.Optional[builtins.bool] = None,
        network_security_group_id: typing.Optional[builtins.str] = None,
    ) -> None:
        """
        :param ip_configuration: ip_configuration block.
        :param name: 
        :param primary: 
        :param accelerated_networking: 
        :param dns_settings: dns_settings block.
        :param ip_forwarding: 
        :param network_security_group_id: 
        """
        self._values: typing.Dict[str, typing.Any] = {
            "ip_configuration": ip_configuration,
            "name": name,
            "primary": primary,
        }
        if accelerated_networking is not None:
            self._values["accelerated_networking"] = accelerated_networking
        if dns_settings is not None:
            self._values["dns_settings"] = dns_settings
        if ip_forwarding is not None:
            self._values["ip_forwarding"] = ip_forwarding
        if network_security_group_id is not None:
            self._values["network_security_group_id"] = network_security_group_id

    @builtins.property
    def ip_configuration(
        self,
    ) -> typing.List["VirtualMachineScaleSetNetworkProfileIpConfiguration"]:
        """ip_configuration block."""
        result = self._values.get("ip_configuration")
        assert result is not None, "Required property 'ip_configuration' is missing"
        return result

    @builtins.property
    def name(self) -> builtins.str:
        result = self._values.get("name")
        assert result is not None, "Required property 'name' is missing"
        return result

    @builtins.property
    def primary(self) -> builtins.bool:
        result = self._values.get("primary")
        assert result is not None, "Required property 'primary' is missing"
        return result

    @builtins.property
    def accelerated_networking(self) -> typing.Optional[builtins.bool]:
        result = self._values.get("accelerated_networking")
        return result

    @builtins.property
    def dns_settings(
        self,
    ) -> typing.Optional[typing.List["VirtualMachineScaleSetNetworkProfileDnsSettings"]]:
        """dns_settings block."""
        result = self._values.get("dns_settings")
        return result

    @builtins.property
    def ip_forwarding(self) -> typing.Optional[builtins.bool]:
        result = self._values.get("ip_forwarding")
        return result

    @builtins.property
    def network_security_group_id(self) -> typing.Optional[builtins.str]:
        result = self._values.get("network_security_group_id")
        return result

    def __eq__(self, rhs: typing.Any) -> builtins.bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs: typing.Any) -> builtins.bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return "VirtualMachineScaleSetNetworkProfile(%s)" % ", ".join(
            k + "=" + repr(v) for k, v in self._values.items()
        )


@jsii.data_type(
    jsii_type="@cdktf/provider-azurerm.VirtualMachineScaleSetNetworkProfileDnsSettings",
    jsii_struct_bases=[],
    name_mapping={"dns_servers": "dnsServers"},
)
class VirtualMachineScaleSetNetworkProfileDnsSettings:
    def __init__(self, *, dns_servers: typing.List[builtins.str]) -> None:
        """
        :param dns_servers: 
        """
        self._values: typing.Dict[str, typing.Any] = {
            "dns_servers": dns_servers,
        }

    @builtins.property
    def dns_servers(self) -> typing.List[builtins.str]:
        result = self._values.get("dns_servers")
        assert result is not None, "Required property 'dns_servers' is missing"
        return result

    def __eq__(self, rhs: typing.Any) -> builtins.bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs: typing.Any) -> builtins.bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return "VirtualMachineScaleSetNetworkProfileDnsSettings(%s)" % ", ".join(
            k + "=" + repr(v) for k, v in self._values.items()
        )


@jsii.data_type(
    jsii_type="@cdktf/provider-azurerm.VirtualMachineScaleSetNetworkProfileIpConfiguration",
    jsii_struct_bases=[],
    name_mapping={
        "name": "name",
        "primary": "primary",
        "subnet_id": "subnetId",
        "application_gateway_backend_address_pool_ids": "applicationGatewayBackendAddressPoolIds",
        "application_security_group_ids": "applicationSecurityGroupIds",
        "load_balancer_backend_address_pool_ids": "loadBalancerBackendAddressPoolIds",
        "load_balancer_inbound_nat_rules_ids": "loadBalancerInboundNatRulesIds",
        "public_ip_address_configuration": "publicIpAddressConfiguration",
    },
)
class VirtualMachineScaleSetNetworkProfileIpConfiguration:
    def __init__(
        self,
        *,
        name: builtins.str,
        primary: builtins.bool,
        subnet_id: builtins.str,
        application_gateway_backend_address_pool_ids: typing.Optional[typing.List[builtins.str]] = None,
        application_security_group_ids: typing.Optional[typing.List[builtins.str]] = None,
        load_balancer_backend_address_pool_ids: typing.Optional[typing.List[builtins.str]] = None,
        load_balancer_inbound_nat_rules_ids: typing.Optional[typing.List[builtins.str]] = None,
        public_ip_address_configuration: typing.Optional[typing.List["VirtualMachineScaleSetNetworkProfileIpConfigurationPublicIpAddressConfiguration"]] = None,
    ) -> None:
        """
        :param name: 
        :param primary: 
        :param subnet_id: 
        :param application_gateway_backend_address_pool_ids: 
        :param application_security_group_ids: 
        :param load_balancer_backend_address_pool_ids: 
        :param load_balancer_inbound_nat_rules_ids: 
        :param public_ip_address_configuration: public_ip_address_configuration block.
        """
        self._values: typing.Dict[str, typing.Any] = {
            "name": name,
            "primary": primary,
            "subnet_id": subnet_id,
        }
        if application_gateway_backend_address_pool_ids is not None:
            self._values["application_gateway_backend_address_pool_ids"] = application_gateway_backend_address_pool_ids
        if application_security_group_ids is not None:
            self._values["application_security_group_ids"] = application_security_group_ids
        if load_balancer_backend_address_pool_ids is not None:
            self._values["load_balancer_backend_address_pool_ids"] = load_balancer_backend_address_pool_ids
        if load_balancer_inbound_nat_rules_ids is not None:
            self._values["load_balancer_inbound_nat_rules_ids"] = load_balancer_inbound_nat_rules_ids
        if public_ip_address_configuration is not None:
            self._values["public_ip_address_configuration"] = public_ip_address_configuration

    @builtins.property
    def name(self) -> builtins.str:
        result = self._values.get("name")
        assert result is not None, "Required property 'name' is missing"
        return result

    @builtins.property
    def primary(self) -> builtins.bool:
        result = self._values.get("primary")
        assert result is not None, "Required property 'primary' is missing"
        return result

    @builtins.property
    def subnet_id(self) -> builtins.str:
        result = self._values.get("subnet_id")
        assert result is not None, "Required property 'subnet_id' is missing"
        return result

    @builtins.property
    def application_gateway_backend_address_pool_ids(
        self,
    ) -> typing.Optional[typing.List[builtins.str]]:
        result = self._values.get("application_gateway_backend_address_pool_ids")
        return result

    @builtins.property
    def application_security_group_ids(
        self,
    ) -> typing.Optional[typing.List[builtins.str]]:
        result = self._values.get("application_security_group_ids")
        return result

    @builtins.property
    def load_balancer_backend_address_pool_ids(
        self,
    ) -> typing.Optional[typing.List[builtins.str]]:
        result = self._values.get("load_balancer_backend_address_pool_ids")
        return result

    @builtins.property
    def load_balancer_inbound_nat_rules_ids(
        self,
    ) -> typing.Optional[typing.List[builtins.str]]:
        result = self._values.get("load_balancer_inbound_nat_rules_ids")
        return result

    @builtins.property
    def public_ip_address_configuration(
        self,
    ) -> typing.Optional[typing.List["VirtualMachineScaleSetNetworkProfileIpConfigurationPublicIpAddressConfiguration"]]:
        """public_ip_address_configuration block."""
        result = self._values.get("public_ip_address_configuration")
        return result

    def __eq__(self, rhs: typing.Any) -> builtins.bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs: typing.Any) -> builtins.bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return "VirtualMachineScaleSetNetworkProfileIpConfiguration(%s)" % ", ".join(
            k + "=" + repr(v) for k, v in self._values.items()
        )


@jsii.data_type(
    jsii_type="@cdktf/provider-azurerm.VirtualMachineScaleSetNetworkProfileIpConfigurationPublicIpAddressConfiguration",
    jsii_struct_bases=[],
    name_mapping={
        "domain_name_label": "domainNameLabel",
        "idle_timeout": "idleTimeout",
        "name": "name",
    },
)
class VirtualMachineScaleSetNetworkProfileIpConfigurationPublicIpAddressConfiguration:
    def __init__(
        self,
        *,
        domain_name_label: builtins.str,
        idle_timeout: jsii.Number,
        name: builtins.str,
    ) -> None:
        """
        :param domain_name_label: 
        :param idle_timeout: 
        :param name: 
        """
        self._values: typing.Dict[str, typing.Any] = {
            "domain_name_label": domain_name_label,
            "idle_timeout": idle_timeout,
            "name": name,
        }

    @builtins.property
    def domain_name_label(self) -> builtins.str:
        result = self._values.get("domain_name_label")
        assert result is not None, "Required property 'domain_name_label' is missing"
        return result

    @builtins.property
    def idle_timeout(self) -> jsii.Number:
        result = self._values.get("idle_timeout")
        assert result is not None, "Required property 'idle_timeout' is missing"
        return result

    @builtins.property
    def name(self) -> builtins.str:
        result = self._values.get("name")
        assert result is not None, "Required property 'name' is missing"
        return result

    def __eq__(self, rhs: typing.Any) -> builtins.bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs: typing.Any) -> builtins.bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return "VirtualMachineScaleSetNetworkProfileIpConfigurationPublicIpAddressConfiguration(%s)" % ", ".join(
            k + "=" + repr(v) for k, v in self._values.items()
        )


@jsii.data_type(
    jsii_type="@cdktf/provider-azurerm.VirtualMachineScaleSetOsProfile",
    jsii_struct_bases=[],
    name_mapping={
        "admin_username": "adminUsername",
        "computer_name_prefix": "computerNamePrefix",
        "admin_password": "adminPassword",
        "custom_data": "customData",
    },
)
class VirtualMachineScaleSetOsProfile:
    def __init__(
        self,
        *,
        admin_username: builtins.str,
        computer_name_prefix: builtins.str,
        admin_password: typing.Optional[builtins.str] = None,
        custom_data: typing.Optional[builtins.str] = None,
    ) -> None:
        """
        :param admin_username: 
        :param computer_name_prefix: 
        :param admin_password: 
        :param custom_data: 
        """
        self._values: typing.Dict[str, typing.Any] = {
            "admin_username": admin_username,
            "computer_name_prefix": computer_name_prefix,
        }
        if admin_password is not None:
            self._values["admin_password"] = admin_password
        if custom_data is not None:
            self._values["custom_data"] = custom_data

    @builtins.property
    def admin_username(self) -> builtins.str:
        result = self._values.get("admin_username")
        assert result is not None, "Required property 'admin_username' is missing"
        return result

    @builtins.property
    def computer_name_prefix(self) -> builtins.str:
        result = self._values.get("computer_name_prefix")
        assert result is not None, "Required property 'computer_name_prefix' is missing"
        return result

    @builtins.property
    def admin_password(self) -> typing.Optional[builtins.str]:
        result = self._values.get("admin_password")
        return result

    @builtins.property
    def custom_data(self) -> typing.Optional[builtins.str]:
        result = self._values.get("custom_data")
        return result

    def __eq__(self, rhs: typing.Any) -> builtins.bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs: typing.Any) -> builtins.bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return "VirtualMachineScaleSetOsProfile(%s)" % ", ".join(
            k + "=" + repr(v) for k, v in self._values.items()
        )


@jsii.data_type(
    jsii_type="@cdktf/provider-azurerm.VirtualMachineScaleSetOsProfileLinuxConfig",
    jsii_struct_bases=[],
    name_mapping={
        "disable_password_authentication": "disablePasswordAuthentication",
        "ssh_keys": "sshKeys",
    },
)
class VirtualMachineScaleSetOsProfileLinuxConfig:
    def __init__(
        self,
        *,
        disable_password_authentication: typing.Optional[builtins.bool] = None,
        ssh_keys: typing.Optional[typing.List["VirtualMachineScaleSetOsProfileLinuxConfigSshKeys"]] = None,
    ) -> None:
        """
        :param disable_password_authentication: 
        :param ssh_keys: ssh_keys block.
        """
        self._values: typing.Dict[str, typing.Any] = {}
        if disable_password_authentication is not None:
            self._values["disable_password_authentication"] = disable_password_authentication
        if ssh_keys is not None:
            self._values["ssh_keys"] = ssh_keys

    @builtins.property
    def disable_password_authentication(self) -> typing.Optional[builtins.bool]:
        result = self._values.get("disable_password_authentication")
        return result

    @builtins.property
    def ssh_keys(
        self,
    ) -> typing.Optional[typing.List["VirtualMachineScaleSetOsProfileLinuxConfigSshKeys"]]:
        """ssh_keys block."""
        result = self._values.get("ssh_keys")
        return result

    def __eq__(self, rhs: typing.Any) -> builtins.bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs: typing.Any) -> builtins.bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return "VirtualMachineScaleSetOsProfileLinuxConfig(%s)" % ", ".join(
            k + "=" + repr(v) for k, v in self._values.items()
        )


@jsii.data_type(
    jsii_type="@cdktf/provider-azurerm.VirtualMachineScaleSetOsProfileLinuxConfigSshKeys",
    jsii_struct_bases=[],
    name_mapping={"path": "path", "key_data": "keyData"},
)
class VirtualMachineScaleSetOsProfileLinuxConfigSshKeys:
    def __init__(
        self,
        *,
        path: builtins.str,
        key_data: typing.Optional[builtins.str] = None,
    ) -> None:
        """
        :param path: 
        :param key_data: 
        """
        self._values: typing.Dict[str, typing.Any] = {
            "path": path,
        }
        if key_data is not None:
            self._values["key_data"] = key_data

    @builtins.property
    def path(self) -> builtins.str:
        result = self._values.get("path")
        assert result is not None, "Required property 'path' is missing"
        return result

    @builtins.property
    def key_data(self) -> typing.Optional[builtins.str]:
        result = self._values.get("key_data")
        return result

    def __eq__(self, rhs: typing.Any) -> builtins.bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs: typing.Any) -> builtins.bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return "VirtualMachineScaleSetOsProfileLinuxConfigSshKeys(%s)" % ", ".join(
            k + "=" + repr(v) for k, v in self._values.items()
        )


@jsii.data_type(
    jsii_type="@cdktf/provider-azurerm.VirtualMachineScaleSetOsProfileSecrets",
    jsii_struct_bases=[],
    name_mapping={
        "source_vault_id": "sourceVaultId",
        "vault_certificates": "vaultCertificates",
    },
)
class VirtualMachineScaleSetOsProfileSecrets:
    def __init__(
        self,
        *,
        source_vault_id: builtins.str,
        vault_certificates: typing.Optional[typing.List["VirtualMachineScaleSetOsProfileSecretsVaultCertificates"]] = None,
    ) -> None:
        """
        :param source_vault_id: 
        :param vault_certificates: vault_certificates block.
        """
        self._values: typing.Dict[str, typing.Any] = {
            "source_vault_id": source_vault_id,
        }
        if vault_certificates is not None:
            self._values["vault_certificates"] = vault_certificates

    @builtins.property
    def source_vault_id(self) -> builtins.str:
        result = self._values.get("source_vault_id")
        assert result is not None, "Required property 'source_vault_id' is missing"
        return result

    @builtins.property
    def vault_certificates(
        self,
    ) -> typing.Optional[typing.List["VirtualMachineScaleSetOsProfileSecretsVaultCertificates"]]:
        """vault_certificates block."""
        result = self._values.get("vault_certificates")
        return result

    def __eq__(self, rhs: typing.Any) -> builtins.bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs: typing.Any) -> builtins.bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return "VirtualMachineScaleSetOsProfileSecrets(%s)" % ", ".join(
            k + "=" + repr(v) for k, v in self._values.items()
        )


@jsii.data_type(
    jsii_type="@cdktf/provider-azurerm.VirtualMachineScaleSetOsProfileSecretsVaultCertificates",
    jsii_struct_bases=[],
    name_mapping={
        "certificate_url": "certificateUrl",
        "certificate_store": "certificateStore",
    },
)
class VirtualMachineScaleSetOsProfileSecretsVaultCertificates:
    def __init__(
        self,
        *,
        certificate_url: builtins.str,
        certificate_store: typing.Optional[builtins.str] = None,
    ) -> None:
        """
        :param certificate_url: 
        :param certificate_store: 
        """
        self._values: typing.Dict[str, typing.Any] = {
            "certificate_url": certificate_url,
        }
        if certificate_store is not None:
            self._values["certificate_store"] = certificate_store

    @builtins.property
    def certificate_url(self) -> builtins.str:
        result = self._values.get("certificate_url")
        assert result is not None, "Required property 'certificate_url' is missing"
        return result

    @builtins.property
    def certificate_store(self) -> typing.Optional[builtins.str]:
        result = self._values.get("certificate_store")
        return result

    def __eq__(self, rhs: typing.Any) -> builtins.bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs: typing.Any) -> builtins.bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return "VirtualMachineScaleSetOsProfileSecretsVaultCertificates(%s)" % ", ".join(
            k + "=" + repr(v) for k, v in self._values.items()
        )


@jsii.data_type(
    jsii_type="@cdktf/provider-azurerm.VirtualMachineScaleSetOsProfileWindowsConfig",
    jsii_struct_bases=[],
    name_mapping={
        "additional_unattend_config": "additionalUnattendConfig",
        "enable_automatic_upgrades": "enableAutomaticUpgrades",
        "provision_vm_agent": "provisionVmAgent",
        "winrm": "winrm",
    },
)
class VirtualMachineScaleSetOsProfileWindowsConfig:
    def __init__(
        self,
        *,
        additional_unattend_config: typing.Optional[typing.List["VirtualMachineScaleSetOsProfileWindowsConfigAdditionalUnattendConfig"]] = None,
        enable_automatic_upgrades: typing.Optional[builtins.bool] = None,
        provision_vm_agent: typing.Optional[builtins.bool] = None,
        winrm: typing.Optional[typing.List["VirtualMachineScaleSetOsProfileWindowsConfigWinrm"]] = None,
    ) -> None:
        """
        :param additional_unattend_config: additional_unattend_config block.
        :param enable_automatic_upgrades: 
        :param provision_vm_agent: 
        :param winrm: winrm block.
        """
        self._values: typing.Dict[str, typing.Any] = {}
        if additional_unattend_config is not None:
            self._values["additional_unattend_config"] = additional_unattend_config
        if enable_automatic_upgrades is not None:
            self._values["enable_automatic_upgrades"] = enable_automatic_upgrades
        if provision_vm_agent is not None:
            self._values["provision_vm_agent"] = provision_vm_agent
        if winrm is not None:
            self._values["winrm"] = winrm

    @builtins.property
    def additional_unattend_config(
        self,
    ) -> typing.Optional[typing.List["VirtualMachineScaleSetOsProfileWindowsConfigAdditionalUnattendConfig"]]:
        """additional_unattend_config block."""
        result = self._values.get("additional_unattend_config")
        return result

    @builtins.property
    def enable_automatic_upgrades(self) -> typing.Optional[builtins.bool]:
        result = self._values.get("enable_automatic_upgrades")
        return result

    @builtins.property
    def provision_vm_agent(self) -> typing.Optional[builtins.bool]:
        result = self._values.get("provision_vm_agent")
        return result

    @builtins.property
    def winrm(
        self,
    ) -> typing.Optional[typing.List["VirtualMachineScaleSetOsProfileWindowsConfigWinrm"]]:
        """winrm block."""
        result = self._values.get("winrm")
        return result

    def __eq__(self, rhs: typing.Any) -> builtins.bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs: typing.Any) -> builtins.bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return "VirtualMachineScaleSetOsProfileWindowsConfig(%s)" % ", ".join(
            k + "=" + repr(v) for k, v in self._values.items()
        )


@jsii.data_type(
    jsii_type="@cdktf/provider-azurerm.VirtualMachineScaleSetOsProfileWindowsConfigAdditionalUnattendConfig",
    jsii_struct_bases=[],
    name_mapping={
        "component": "component",
        "content": "content",
        "pass_": "pass",
        "setting_name": "settingName",
    },
)
class VirtualMachineScaleSetOsProfileWindowsConfigAdditionalUnattendConfig:
    def __init__(
        self,
        *,
        component: builtins.str,
        content: builtins.str,
        pass_: builtins.str,
        setting_name: builtins.str,
    ) -> None:
        """
        :param component: 
        :param content: 
        :param pass_: 
        :param setting_name: 
        """
        self._values: typing.Dict[str, typing.Any] = {
            "component": component,
            "content": content,
            "pass_": pass_,
            "setting_name": setting_name,
        }

    @builtins.property
    def component(self) -> builtins.str:
        result = self._values.get("component")
        assert result is not None, "Required property 'component' is missing"
        return result

    @builtins.property
    def content(self) -> builtins.str:
        result = self._values.get("content")
        assert result is not None, "Required property 'content' is missing"
        return result

    @builtins.property
    def pass_(self) -> builtins.str:
        result = self._values.get("pass_")
        assert result is not None, "Required property 'pass_' is missing"
        return result

    @builtins.property
    def setting_name(self) -> builtins.str:
        result = self._values.get("setting_name")
        assert result is not None, "Required property 'setting_name' is missing"
        return result

    def __eq__(self, rhs: typing.Any) -> builtins.bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs: typing.Any) -> builtins.bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return "VirtualMachineScaleSetOsProfileWindowsConfigAdditionalUnattendConfig(%s)" % ", ".join(
            k + "=" + repr(v) for k, v in self._values.items()
        )


@jsii.data_type(
    jsii_type="@cdktf/provider-azurerm.VirtualMachineScaleSetOsProfileWindowsConfigWinrm",
    jsii_struct_bases=[],
    name_mapping={"protocol": "protocol", "certificate_url": "certificateUrl"},
)
class VirtualMachineScaleSetOsProfileWindowsConfigWinrm:
    def __init__(
        self,
        *,
        protocol: builtins.str,
        certificate_url: typing.Optional[builtins.str] = None,
    ) -> None:
        """
        :param protocol: 
        :param certificate_url: 
        """
        self._values: typing.Dict[str, typing.Any] = {
            "protocol": protocol,
        }
        if certificate_url is not None:
            self._values["certificate_url"] = certificate_url

    @builtins.property
    def protocol(self) -> builtins.str:
        result = self._values.get("protocol")
        assert result is not None, "Required property 'protocol' is missing"
        return result

    @builtins.property
    def certificate_url(self) -> typing.Optional[builtins.str]:
        result = self._values.get("certificate_url")
        return result

    def __eq__(self, rhs: typing.Any) -> builtins.bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs: typing.Any) -> builtins.bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return "VirtualMachineScaleSetOsProfileWindowsConfigWinrm(%s)" % ", ".join(
            k + "=" + repr(v) for k, v in self._values.items()
        )


@jsii.data_type(
    jsii_type="@cdktf/provider-azurerm.VirtualMachineScaleSetPlan",
    jsii_struct_bases=[],
    name_mapping={"name": "name", "product": "product", "publisher": "publisher"},
)
class VirtualMachineScaleSetPlan:
    def __init__(
        self,
        *,
        name: builtins.str,
        product: builtins.str,
        publisher: builtins.str,
    ) -> None:
        """
        :param name: 
        :param product: 
        :param publisher: 
        """
        self._values: typing.Dict[str, typing.Any] = {
            "name": name,
            "product": product,
            "publisher": publisher,
        }

    @builtins.property
    def name(self) -> builtins.str:
        result = self._values.get("name")
        assert result is not None, "Required property 'name' is missing"
        return result

    @builtins.property
    def product(self) -> builtins.str:
        result = self._values.get("product")
        assert result is not None, "Required property 'product' is missing"
        return result

    @builtins.property
    def publisher(self) -> builtins.str:
        result = self._values.get("publisher")
        assert result is not None, "Required property 'publisher' is missing"
        return result

    def __eq__(self, rhs: typing.Any) -> builtins.bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs: typing.Any) -> builtins.bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return "VirtualMachineScaleSetPlan(%s)" % ", ".join(
            k + "=" + repr(v) for k, v in self._values.items()
        )


@jsii.data_type(
    jsii_type="@cdktf/provider-azurerm.VirtualMachineScaleSetRollingUpgradePolicy",
    jsii_struct_bases=[],
    name_mapping={
        "max_batch_instance_percent": "maxBatchInstancePercent",
        "max_unhealthy_instance_percent": "maxUnhealthyInstancePercent",
        "max_unhealthy_upgraded_instance_percent": "maxUnhealthyUpgradedInstancePercent",
        "pause_time_between_batches": "pauseTimeBetweenBatches",
    },
)
class VirtualMachineScaleSetRollingUpgradePolicy:
    def __init__(
        self,
        *,
        max_batch_instance_percent: typing.Optional[jsii.Number] = None,
        max_unhealthy_instance_percent: typing.Optional[jsii.Number] = None,
        max_unhealthy_upgraded_instance_percent: typing.Optional[jsii.Number] = None,
        pause_time_between_batches: typing.Optional[builtins.str] = None,
    ) -> None:
        """
        :param max_batch_instance_percent: 
        :param max_unhealthy_instance_percent: 
        :param max_unhealthy_upgraded_instance_percent: 
        :param pause_time_between_batches: 
        """
        self._values: typing.Dict[str, typing.Any] = {}
        if max_batch_instance_percent is not None:
            self._values["max_batch_instance_percent"] = max_batch_instance_percent
        if max_unhealthy_instance_percent is not None:
            self._values["max_unhealthy_instance_percent"] = max_unhealthy_instance_percent
        if max_unhealthy_upgraded_instance_percent is not None:
            self._values["max_unhealthy_upgraded_instance_percent"] = max_unhealthy_upgraded_instance_percent
        if pause_time_between_batches is not None:
            self._values["pause_time_between_batches"] = pause_time_between_batches

    @builtins.property
    def max_batch_instance_percent(self) -> typing.Optional[jsii.Number]:
        result = self._values.get("max_batch_instance_percent")
        return result

    @builtins.property
    def max_unhealthy_instance_percent(self) -> typing.Optional[jsii.Number]:
        result = self._values.get("max_unhealthy_instance_percent")
        return result

    @builtins.property
    def max_unhealthy_upgraded_instance_percent(self) -> typing.Optional[jsii.Number]:
        result = self._values.get("max_unhealthy_upgraded_instance_percent")
        return result

    @builtins.property
    def pause_time_between_batches(self) -> typing.Optional[builtins.str]:
        result = self._values.get("pause_time_between_batches")
        return result

    def __eq__(self, rhs: typing.Any) -> builtins.bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs: typing.Any) -> builtins.bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return "VirtualMachineScaleSetRollingUpgradePolicy(%s)" % ", ".join(
            k + "=" + repr(v) for k, v in self._values.items()
        )


@jsii.data_type(
    jsii_type="@cdktf/provider-azurerm.VirtualMachineScaleSetSku",
    jsii_struct_bases=[],
    name_mapping={"capacity": "capacity", "name": "name", "tier": "tier"},
)
class VirtualMachineScaleSetSku:
    def __init__(
        self,
        *,
        capacity: jsii.Number,
        name: builtins.str,
        tier: typing.Optional[builtins.str] = None,
    ) -> None:
        """
        :param capacity: 
        :param name: 
        :param tier: 
        """
        self._values: typing.Dict[str, typing.Any] = {
            "capacity": capacity,
            "name": name,
        }
        if tier is not None:
            self._values["tier"] = tier

    @builtins.property
    def capacity(self) -> jsii.Number:
        result = self._values.get("capacity")
        assert result is not None, "Required property 'capacity' is missing"
        return result

    @builtins.property
    def name(self) -> builtins.str:
        result = self._values.get("name")
        assert result is not None, "Required property 'name' is missing"
        return result

    @builtins.property
    def tier(self) -> typing.Optional[builtins.str]:
        result = self._values.get("tier")
        return result

    def __eq__(self, rhs: typing.Any) -> builtins.bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs: typing.Any) -> builtins.bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return "VirtualMachineScaleSetSku(%s)" % ", ".join(
            k + "=" + repr(v) for k, v in self._values.items()
        )


@jsii.data_type(
    jsii_type="@cdktf/provider-azurerm.VirtualMachineScaleSetStorageProfileDataDisk",
    jsii_struct_bases=[],
    name_mapping={
        "create_option": "createOption",
        "lun": "lun",
        "caching": "caching",
        "disk_size_gb": "diskSizeGb",
        "managed_disk_type": "managedDiskType",
    },
)
class VirtualMachineScaleSetStorageProfileDataDisk:
    def __init__(
        self,
        *,
        create_option: builtins.str,
        lun: jsii.Number,
        caching: typing.Optional[builtins.str] = None,
        disk_size_gb: typing.Optional[jsii.Number] = None,
        managed_disk_type: typing.Optional[builtins.str] = None,
    ) -> None:
        """
        :param create_option: 
        :param lun: 
        :param caching: 
        :param disk_size_gb: 
        :param managed_disk_type: 
        """
        self._values: typing.Dict[str, typing.Any] = {
            "create_option": create_option,
            "lun": lun,
        }
        if caching is not None:
            self._values["caching"] = caching
        if disk_size_gb is not None:
            self._values["disk_size_gb"] = disk_size_gb
        if managed_disk_type is not None:
            self._values["managed_disk_type"] = managed_disk_type

    @builtins.property
    def create_option(self) -> builtins.str:
        result = self._values.get("create_option")
        assert result is not None, "Required property 'create_option' is missing"
        return result

    @builtins.property
    def lun(self) -> jsii.Number:
        result = self._values.get("lun")
        assert result is not None, "Required property 'lun' is missing"
        return result

    @builtins.property
    def caching(self) -> typing.Optional[builtins.str]:
        result = self._values.get("caching")
        return result

    @builtins.property
    def disk_size_gb(self) -> typing.Optional[jsii.Number]:
        result = self._values.get("disk_size_gb")
        return result

    @builtins.property
    def managed_disk_type(self) -> typing.Optional[builtins.str]:
        result = self._values.get("managed_disk_type")
        return result

    def __eq__(self, rhs: typing.Any) -> builtins.bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs: typing.Any) -> builtins.bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return "VirtualMachineScaleSetStorageProfileDataDisk(%s)" % ", ".join(
            k + "=" + repr(v) for k, v in self._values.items()
        )


@jsii.data_type(
    jsii_type="@cdktf/provider-azurerm.VirtualMachineScaleSetStorageProfileImageReference",
    jsii_struct_bases=[],
    name_mapping={
        "id": "id",
        "offer": "offer",
        "publisher": "publisher",
        "sku": "sku",
        "version": "version",
    },
)
class VirtualMachineScaleSetStorageProfileImageReference:
    def __init__(
        self,
        *,
        id: typing.Optional[builtins.str] = None,
        offer: typing.Optional[builtins.str] = None,
        publisher: typing.Optional[builtins.str] = None,
        sku: typing.Optional[builtins.str] = None,
        version: typing.Optional[builtins.str] = None,
    ) -> None:
        """
        :param id: 
        :param offer: 
        :param publisher: 
        :param sku: 
        :param version: 
        """
        self._values: typing.Dict[str, typing.Any] = {}
        if id is not None:
            self._values["id"] = id
        if offer is not None:
            self._values["offer"] = offer
        if publisher is not None:
            self._values["publisher"] = publisher
        if sku is not None:
            self._values["sku"] = sku
        if version is not None:
            self._values["version"] = version

    @builtins.property
    def id(self) -> typing.Optional[builtins.str]:
        result = self._values.get("id")
        return result

    @builtins.property
    def offer(self) -> typing.Optional[builtins.str]:
        result = self._values.get("offer")
        return result

    @builtins.property
    def publisher(self) -> typing.Optional[builtins.str]:
        result = self._values.get("publisher")
        return result

    @builtins.property
    def sku(self) -> typing.Optional[builtins.str]:
        result = self._values.get("sku")
        return result

    @builtins.property
    def version(self) -> typing.Optional[builtins.str]:
        result = self._values.get("version")
        return result

    def __eq__(self, rhs: typing.Any) -> builtins.bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs: typing.Any) -> builtins.bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return "VirtualMachineScaleSetStorageProfileImageReference(%s)" % ", ".join(
            k + "=" + repr(v) for k, v in self._values.items()
        )


@jsii.data_type(
    jsii_type="@cdktf/provider-azurerm.VirtualMachineScaleSetStorageProfileOsDisk",
    jsii_struct_bases=[],
    name_mapping={
        "create_option": "createOption",
        "caching": "caching",
        "image": "image",
        "managed_disk_type": "managedDiskType",
        "name": "name",
        "os_type": "osType",
        "vhd_containers": "vhdContainers",
    },
)
class VirtualMachineScaleSetStorageProfileOsDisk:
    def __init__(
        self,
        *,
        create_option: builtins.str,
        caching: typing.Optional[builtins.str] = None,
        image: typing.Optional[builtins.str] = None,
        managed_disk_type: typing.Optional[builtins.str] = None,
        name: typing.Optional[builtins.str] = None,
        os_type: typing.Optional[builtins.str] = None,
        vhd_containers: typing.Optional[typing.List[builtins.str]] = None,
    ) -> None:
        """
        :param create_option: 
        :param caching: 
        :param image: 
        :param managed_disk_type: 
        :param name: 
        :param os_type: 
        :param vhd_containers: 
        """
        self._values: typing.Dict[str, typing.Any] = {
            "create_option": create_option,
        }
        if caching is not None:
            self._values["caching"] = caching
        if image is not None:
            self._values["image"] = image
        if managed_disk_type is not None:
            self._values["managed_disk_type"] = managed_disk_type
        if name is not None:
            self._values["name"] = name
        if os_type is not None:
            self._values["os_type"] = os_type
        if vhd_containers is not None:
            self._values["vhd_containers"] = vhd_containers

    @builtins.property
    def create_option(self) -> builtins.str:
        result = self._values.get("create_option")
        assert result is not None, "Required property 'create_option' is missing"
        return result

    @builtins.property
    def caching(self) -> typing.Optional[builtins.str]:
        result = self._values.get("caching")
        return result

    @builtins.property
    def image(self) -> typing.Optional[builtins.str]:
        result = self._values.get("image")
        return result

    @builtins.property
    def managed_disk_type(self) -> typing.Optional[builtins.str]:
        result = self._values.get("managed_disk_type")
        return result

    @builtins.property
    def name(self) -> typing.Optional[builtins.str]:
        result = self._values.get("name")
        return result

    @builtins.property
    def os_type(self) -> typing.Optional[builtins.str]:
        result = self._values.get("os_type")
        return result

    @builtins.property
    def vhd_containers(self) -> typing.Optional[typing.List[builtins.str]]:
        result = self._values.get("vhd_containers")
        return result

    def __eq__(self, rhs: typing.Any) -> builtins.bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs: typing.Any) -> builtins.bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return "VirtualMachineScaleSetStorageProfileOsDisk(%s)" % ", ".join(
            k + "=" + repr(v) for k, v in self._values.items()
        )


@jsii.data_type(
    jsii_type="@cdktf/provider-azurerm.VirtualMachineScaleSetTimeouts",
    jsii_struct_bases=[],
    name_mapping={
        "create": "create",
        "delete": "delete",
        "read": "read",
        "update": "update",
    },
)
class VirtualMachineScaleSetTimeouts:
    def __init__(
        self,
        *,
        create: typing.Optional[builtins.str] = None,
        delete: typing.Optional[builtins.str] = None,
        read: typing.Optional[builtins.str] = None,
        update: typing.Optional[builtins.str] = None,
    ) -> None:
        """
        :param create: 
        :param delete: 
        :param read: 
        :param update: 
        """
        self._values: typing.Dict[str, typing.Any] = {}
        if create is not None:
            self._values["create"] = create
        if delete is not None:
            self._values["delete"] = delete
        if read is not None:
            self._values["read"] = read
        if update is not None:
            self._values["update"] = update

    @builtins.property
    def create(self) -> typing.Optional[builtins.str]:
        result = self._values.get("create")
        return result

    @builtins.property
    def delete(self) -> typing.Optional[builtins.str]:
        result = self._values.get("delete")
        return result

    @builtins.property
    def read(self) -> typing.Optional[builtins.str]:
        result = self._values.get("read")
        return result

    @builtins.property
    def update(self) -> typing.Optional[builtins.str]:
        result = self._values.get("update")
        return result

    def __eq__(self, rhs: typing.Any) -> builtins.bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs: typing.Any) -> builtins.bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return "VirtualMachineScaleSetTimeouts(%s)" % ", ".join(
            k + "=" + repr(v) for k, v in self._values.items()
        )


@jsii.data_type(
    jsii_type="@cdktf/provider-azurerm.VirtualMachineStorageDataDisk",
    jsii_struct_bases=[],
    name_mapping={
        "create_option": "createOption",
        "lun": "lun",
        "name": "name",
        "caching": "caching",
        "disk_size_gb": "diskSizeGb",
        "managed_disk_id": "managedDiskId",
        "managed_disk_type": "managedDiskType",
        "vhd_uri": "vhdUri",
        "write_accelerator_enabled": "writeAcceleratorEnabled",
    },
)
class VirtualMachineStorageDataDisk:
    def __init__(
        self,
        *,
        create_option: builtins.str,
        lun: jsii.Number,
        name: builtins.str,
        caching: typing.Optional[builtins.str] = None,
        disk_size_gb: typing.Optional[jsii.Number] = None,
        managed_disk_id: typing.Optional[builtins.str] = None,
        managed_disk_type: typing.Optional[builtins.str] = None,
        vhd_uri: typing.Optional[builtins.str] = None,
        write_accelerator_enabled: typing.Optional[builtins.bool] = None,
    ) -> None:
        """
        :param create_option: 
        :param lun: 
        :param name: 
        :param caching: 
        :param disk_size_gb: 
        :param managed_disk_id: 
        :param managed_disk_type: 
        :param vhd_uri: 
        :param write_accelerator_enabled: 
        """
        self._values: typing.Dict[str, typing.Any] = {
            "create_option": create_option,
            "lun": lun,
            "name": name,
        }
        if caching is not None:
            self._values["caching"] = caching
        if disk_size_gb is not None:
            self._values["disk_size_gb"] = disk_size_gb
        if managed_disk_id is not None:
            self._values["managed_disk_id"] = managed_disk_id
        if managed_disk_type is not None:
            self._values["managed_disk_type"] = managed_disk_type
        if vhd_uri is not None:
            self._values["vhd_uri"] = vhd_uri
        if write_accelerator_enabled is not None:
            self._values["write_accelerator_enabled"] = write_accelerator_enabled

    @builtins.property
    def create_option(self) -> builtins.str:
        result = self._values.get("create_option")
        assert result is not None, "Required property 'create_option' is missing"
        return result

    @builtins.property
    def lun(self) -> jsii.Number:
        result = self._values.get("lun")
        assert result is not None, "Required property 'lun' is missing"
        return result

    @builtins.property
    def name(self) -> builtins.str:
        result = self._values.get("name")
        assert result is not None, "Required property 'name' is missing"
        return result

    @builtins.property
    def caching(self) -> typing.Optional[builtins.str]:
        result = self._values.get("caching")
        return result

    @builtins.property
    def disk_size_gb(self) -> typing.Optional[jsii.Number]:
        result = self._values.get("disk_size_gb")
        return result

    @builtins.property
    def managed_disk_id(self) -> typing.Optional[builtins.str]:
        result = self._values.get("managed_disk_id")
        return result

    @builtins.property
    def managed_disk_type(self) -> typing.Optional[builtins.str]:
        result = self._values.get("managed_disk_type")
        return result

    @builtins.property
    def vhd_uri(self) -> typing.Optional[builtins.str]:
        result = self._values.get("vhd_uri")
        return result

    @builtins.property
    def write_accelerator_enabled(self) -> typing.Optional[builtins.bool]:
        result = self._values.get("write_accelerator_enabled")
        return result

    def __eq__(self, rhs: typing.Any) -> builtins.bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs: typing.Any) -> builtins.bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return "VirtualMachineStorageDataDisk(%s)" % ", ".join(
            k + "=" + repr(v) for k, v in self._values.items()
        )


@jsii.data_type(
    jsii_type="@cdktf/provider-azurerm.VirtualMachineStorageImageReference",
    jsii_struct_bases=[],
    name_mapping={
        "id": "id",
        "offer": "offer",
        "publisher": "publisher",
        "sku": "sku",
        "version": "version",
    },
)
class VirtualMachineStorageImageReference:
    def __init__(
        self,
        *,
        id: typing.Optional[builtins.str] = None,
        offer: typing.Optional[builtins.str] = None,
        publisher: typing.Optional[builtins.str] = None,
        sku: typing.Optional[builtins.str] = None,
        version: typing.Optional[builtins.str] = None,
    ) -> None:
        """
        :param id: 
        :param offer: 
        :param publisher: 
        :param sku: 
        :param version: 
        """
        self._values: typing.Dict[str, typing.Any] = {}
        if id is not None:
            self._values["id"] = id
        if offer is not None:
            self._values["offer"] = offer
        if publisher is not None:
            self._values["publisher"] = publisher
        if sku is not None:
            self._values["sku"] = sku
        if version is not None:
            self._values["version"] = version

    @builtins.property
    def id(self) -> typing.Optional[builtins.str]:
        result = self._values.get("id")
        return result

    @builtins.property
    def offer(self) -> typing.Optional[builtins.str]:
        result = self._values.get("offer")
        return result

    @builtins.property
    def publisher(self) -> typing.Optional[builtins.str]:
        result = self._values.get("publisher")
        return result

    @builtins.property
    def sku(self) -> typing.Optional[builtins.str]:
        result = self._values.get("sku")
        return result

    @builtins.property
    def version(self) -> typing.Optional[builtins.str]:
        result = self._values.get("version")
        return result

    def __eq__(self, rhs: typing.Any) -> builtins.bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs: typing.Any) -> builtins.bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return "VirtualMachineStorageImageReference(%s)" % ", ".join(
            k + "=" + repr(v) for k, v in self._values.items()
        )


@jsii.data_type(
    jsii_type="@cdktf/provider-azurerm.VirtualMachineStorageOsDisk",
    jsii_struct_bases=[],
    name_mapping={
        "create_option": "createOption",
        "name": "name",
        "caching": "caching",
        "disk_size_gb": "diskSizeGb",
        "image_uri": "imageUri",
        "managed_disk_id": "managedDiskId",
        "managed_disk_type": "managedDiskType",
        "os_type": "osType",
        "vhd_uri": "vhdUri",
        "write_accelerator_enabled": "writeAcceleratorEnabled",
    },
)
class VirtualMachineStorageOsDisk:
    def __init__(
        self,
        *,
        create_option: builtins.str,
        name: builtins.str,
        caching: typing.Optional[builtins.str] = None,
        disk_size_gb: typing.Optional[jsii.Number] = None,
        image_uri: typing.Optional[builtins.str] = None,
        managed_disk_id: typing.Optional[builtins.str] = None,
        managed_disk_type: typing.Optional[builtins.str] = None,
        os_type: typing.Optional[builtins.str] = None,
        vhd_uri: typing.Optional[builtins.str] = None,
        write_accelerator_enabled: typing.Optional[builtins.bool] = None,
    ) -> None:
        """
        :param create_option: 
        :param name: 
        :param caching: 
        :param disk_size_gb: 
        :param image_uri: 
        :param managed_disk_id: 
        :param managed_disk_type: 
        :param os_type: 
        :param vhd_uri: 
        :param write_accelerator_enabled: 
        """
        self._values: typing.Dict[str, typing.Any] = {
            "create_option": create_option,
            "name": name,
        }
        if caching is not None:
            self._values["caching"] = caching
        if disk_size_gb is not None:
            self._values["disk_size_gb"] = disk_size_gb
        if image_uri is not None:
            self._values["image_uri"] = image_uri
        if managed_disk_id is not None:
            self._values["managed_disk_id"] = managed_disk_id
        if managed_disk_type is not None:
            self._values["managed_disk_type"] = managed_disk_type
        if os_type is not None:
            self._values["os_type"] = os_type
        if vhd_uri is not None:
            self._values["vhd_uri"] = vhd_uri
        if write_accelerator_enabled is not None:
            self._values["write_accelerator_enabled"] = write_accelerator_enabled

    @builtins.property
    def create_option(self) -> builtins.str:
        result = self._values.get("create_option")
        assert result is not None, "Required property 'create_option' is missing"
        return result

    @builtins.property
    def name(self) -> builtins.str:
        result = self._values.get("name")
        assert result is not None, "Required property 'name' is missing"
        return result

    @builtins.property
    def caching(self) -> typing.Optional[builtins.str]:
        result = self._values.get("caching")
        return result

    @builtins.property
    def disk_size_gb(self) -> typing.Optional[jsii.Number]:
        result = self._values.get("disk_size_gb")
        return result

    @builtins.property
    def image_uri(self) -> typing.Optional[builtins.str]:
        result = self._values.get("image_uri")
        return result

    @builtins.property
    def managed_disk_id(self) -> typing.Optional[builtins.str]:
        result = self._values.get("managed_disk_id")
        return result

    @builtins.property
    def managed_disk_type(self) -> typing.Optional[builtins.str]:
        result = self._values.get("managed_disk_type")
        return result

    @builtins.property
    def os_type(self) -> typing.Optional[builtins.str]:
        result = self._values.get("os_type")
        return result

    @builtins.property
    def vhd_uri(self) -> typing.Optional[builtins.str]:
        result = self._values.get("vhd_uri")
        return result

    @builtins.property
    def write_accelerator_enabled(self) -> typing.Optional[builtins.bool]:
        result = self._values.get("write_accelerator_enabled")
        return result

    def __eq__(self, rhs: typing.Any) -> builtins.bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs: typing.Any) -> builtins.bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return "VirtualMachineStorageOsDisk(%s)" % ", ".join(
            k + "=" + repr(v) for k, v in self._values.items()
        )


@jsii.data_type(
    jsii_type="@cdktf/provider-azurerm.VirtualMachineTimeouts",
    jsii_struct_bases=[],
    name_mapping={
        "create": "create",
        "delete": "delete",
        "read": "read",
        "update": "update",
    },
)
class VirtualMachineTimeouts:
    def __init__(
        self,
        *,
        create: typing.Optional[builtins.str] = None,
        delete: typing.Optional[builtins.str] = None,
        read: typing.Optional[builtins.str] = None,
        update: typing.Optional[builtins.str] = None,
    ) -> None:
        """
        :param create: 
        :param delete: 
        :param read: 
        :param update: 
        """
        self._values: typing.Dict[str, typing.Any] = {}
        if create is not None:
            self._values["create"] = create
        if delete is not None:
            self._values["delete"] = delete
        if read is not None:
            self._values["read"] = read
        if update is not None:
            self._values["update"] = update

    @builtins.property
    def create(self) -> typing.Optional[builtins.str]:
        result = self._values.get("create")
        return result

    @builtins.property
    def delete(self) -> typing.Optional[builtins.str]:
        result = self._values.get("delete")
        return result

    @builtins.property
    def read(self) -> typing.Optional[builtins.str]:
        result = self._values.get("read")
        return result

    @builtins.property
    def update(self) -> typing.Optional[builtins.str]:
        result = self._values.get("update")
        return result

    def __eq__(self, rhs: typing.Any) -> builtins.bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs: typing.Any) -> builtins.bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return "VirtualMachineTimeouts(%s)" % ", ".join(
            k + "=" + repr(v) for k, v in self._values.items()
        )


class VirtualNetwork(
    cdktf.TerraformResource,
    metaclass=jsii.JSIIMeta,
    jsii_type="@cdktf/provider-azurerm.VirtualNetwork",
):
    def __init__(
        self,
        scope: constructs.Construct,
        id: builtins.str,
        *,
        address_space: typing.List[builtins.str],
        location: builtins.str,
        name: builtins.str,
        resource_group_name: builtins.str,
        ddos_protection_plan: typing.Optional[typing.List["VirtualNetworkDdosProtectionPlan"]] = None,
        dns_servers: typing.Optional[typing.List[builtins.str]] = None,
        subnet: typing.Optional[typing.List["VirtualNetworkSubnet"]] = None,
        tags: typing.Optional[typing.Mapping[builtins.str, builtins.str]] = None,
        timeouts: typing.Optional["VirtualNetworkTimeouts"] = None,
        count: typing.Optional[jsii.Number] = None,
        depends_on: typing.Optional[typing.List[cdktf.TerraformResource]] = None,
        lifecycle: typing.Optional[cdktf.TerraformResourceLifecycle] = None,
        provider: typing.Optional[cdktf.TerraformProvider] = None,
    ) -> None:
        """
        :param scope: -
        :param id: -
        :param address_space: 
        :param location: 
        :param name: 
        :param resource_group_name: 
        :param ddos_protection_plan: ddos_protection_plan block.
        :param dns_servers: 
        :param subnet: subnet block.
        :param tags: 
        :param timeouts: timeouts block.
        :param count: 
        :param depends_on: 
        :param lifecycle: 
        :param provider: 
        """
        config = VirtualNetworkConfig(
            address_space=address_space,
            location=location,
            name=name,
            resource_group_name=resource_group_name,
            ddos_protection_plan=ddos_protection_plan,
            dns_servers=dns_servers,
            subnet=subnet,
            tags=tags,
            timeouts=timeouts,
            count=count,
            depends_on=depends_on,
            lifecycle=lifecycle,
            provider=provider,
        )

        jsii.create(VirtualNetwork, self, [scope, id, config])

    @jsii.member(jsii_name="synthesizeAttributes")
    def _synthesize_attributes(self) -> typing.Mapping[builtins.str, typing.Any]:
        return jsii.invoke(self, "synthesizeAttributes", [])

    @builtins.property # type: ignore
    @jsii.member(jsii_name="addressSpace")
    def address_space(self) -> typing.List[builtins.str]:
        return jsii.get(self, "addressSpace")

    @address_space.setter # type: ignore
    def address_space(self, value: typing.List[builtins.str]) -> None:
        jsii.set(self, "addressSpace", value)

    @builtins.property # type: ignore
    @jsii.member(jsii_name="location")
    def location(self) -> builtins.str:
        return jsii.get(self, "location")

    @location.setter # type: ignore
    def location(self, value: builtins.str) -> None:
        jsii.set(self, "location", value)

    @builtins.property # type: ignore
    @jsii.member(jsii_name="name")
    def name(self) -> builtins.str:
        return jsii.get(self, "name")

    @name.setter # type: ignore
    def name(self, value: builtins.str) -> None:
        jsii.set(self, "name", value)

    @builtins.property # type: ignore
    @jsii.member(jsii_name="resourceGroupName")
    def resource_group_name(self) -> builtins.str:
        return jsii.get(self, "resourceGroupName")

    @resource_group_name.setter # type: ignore
    def resource_group_name(self, value: builtins.str) -> None:
        jsii.set(self, "resourceGroupName", value)

    @builtins.property # type: ignore
    @jsii.member(jsii_name="ddosProtectionPlan")
    def ddos_protection_plan(
        self,
    ) -> typing.Optional[typing.List["VirtualNetworkDdosProtectionPlan"]]:
        return jsii.get(self, "ddosProtectionPlan")

    @ddos_protection_plan.setter # type: ignore
    def ddos_protection_plan(
        self,
        value: typing.Optional[typing.List["VirtualNetworkDdosProtectionPlan"]],
    ) -> None:
        jsii.set(self, "ddosProtectionPlan", value)

    @builtins.property # type: ignore
    @jsii.member(jsii_name="dnsServers")
    def dns_servers(self) -> typing.Optional[typing.List[builtins.str]]:
        return jsii.get(self, "dnsServers")

    @dns_servers.setter # type: ignore
    def dns_servers(self, value: typing.Optional[typing.List[builtins.str]]) -> None:
        jsii.set(self, "dnsServers", value)

    @builtins.property # type: ignore
    @jsii.member(jsii_name="id")
    def id(self) -> typing.Optional[builtins.str]:
        return jsii.get(self, "id")

    @id.setter # type: ignore
    def id(self, value: typing.Optional[builtins.str]) -> None:
        jsii.set(self, "id", value)

    @builtins.property # type: ignore
    @jsii.member(jsii_name="subnet")
    def subnet(self) -> typing.Optional[typing.List["VirtualNetworkSubnet"]]:
        return jsii.get(self, "subnet")

    @subnet.setter # type: ignore
    def subnet(
        self,
        value: typing.Optional[typing.List["VirtualNetworkSubnet"]],
    ) -> None:
        jsii.set(self, "subnet", value)

    @builtins.property # type: ignore
    @jsii.member(jsii_name="tags")
    def tags(self) -> typing.Optional[typing.Mapping[builtins.str, builtins.str]]:
        return jsii.get(self, "tags")

    @tags.setter # type: ignore
    def tags(
        self,
        value: typing.Optional[typing.Mapping[builtins.str, builtins.str]],
    ) -> None:
        jsii.set(self, "tags", value)

    @builtins.property # type: ignore
    @jsii.member(jsii_name="timeouts")
    def timeouts(self) -> typing.Optional["VirtualNetworkTimeouts"]:
        return jsii.get(self, "timeouts")

    @timeouts.setter # type: ignore
    def timeouts(self, value: typing.Optional["VirtualNetworkTimeouts"]) -> None:
        jsii.set(self, "timeouts", value)


@jsii.data_type(
    jsii_type="@cdktf/provider-azurerm.VirtualNetworkConfig",
    jsii_struct_bases=[cdktf.TerraformMetaArguments],
    name_mapping={
        "count": "count",
        "depends_on": "dependsOn",
        "lifecycle": "lifecycle",
        "provider": "provider",
        "address_space": "addressSpace",
        "location": "location",
        "name": "name",
        "resource_group_name": "resourceGroupName",
        "ddos_protection_plan": "ddosProtectionPlan",
        "dns_servers": "dnsServers",
        "subnet": "subnet",
        "tags": "tags",
        "timeouts": "timeouts",
    },
)
class VirtualNetworkConfig(cdktf.TerraformMetaArguments):
    def __init__(
        self,
        *,
        count: typing.Optional[jsii.Number] = None,
        depends_on: typing.Optional[typing.List[cdktf.TerraformResource]] = None,
        lifecycle: typing.Optional[cdktf.TerraformResourceLifecycle] = None,
        provider: typing.Optional[cdktf.TerraformProvider] = None,
        address_space: typing.List[builtins.str],
        location: builtins.str,
        name: builtins.str,
        resource_group_name: builtins.str,
        ddos_protection_plan: typing.Optional[typing.List["VirtualNetworkDdosProtectionPlan"]] = None,
        dns_servers: typing.Optional[typing.List[builtins.str]] = None,
        subnet: typing.Optional[typing.List["VirtualNetworkSubnet"]] = None,
        tags: typing.Optional[typing.Mapping[builtins.str, builtins.str]] = None,
        timeouts: typing.Optional["VirtualNetworkTimeouts"] = None,
    ) -> None:
        """
        :param count: 
        :param depends_on: 
        :param lifecycle: 
        :param provider: 
        :param address_space: 
        :param location: 
        :param name: 
        :param resource_group_name: 
        :param ddos_protection_plan: ddos_protection_plan block.
        :param dns_servers: 
        :param subnet: subnet block.
        :param tags: 
        :param timeouts: timeouts block.
        """
        if isinstance(lifecycle, dict):
            lifecycle = cdktf.TerraformResourceLifecycle(**lifecycle)
        if isinstance(timeouts, dict):
            timeouts = VirtualNetworkTimeouts(**timeouts)
        self._values: typing.Dict[str, typing.Any] = {
            "address_space": address_space,
            "location": location,
            "name": name,
            "resource_group_name": resource_group_name,
        }
        if count is not None:
            self._values["count"] = count
        if depends_on is not None:
            self._values["depends_on"] = depends_on
        if lifecycle is not None:
            self._values["lifecycle"] = lifecycle
        if provider is not None:
            self._values["provider"] = provider
        if ddos_protection_plan is not None:
            self._values["ddos_protection_plan"] = ddos_protection_plan
        if dns_servers is not None:
            self._values["dns_servers"] = dns_servers
        if subnet is not None:
            self._values["subnet"] = subnet
        if tags is not None:
            self._values["tags"] = tags
        if timeouts is not None:
            self._values["timeouts"] = timeouts

    @builtins.property
    def count(self) -> typing.Optional[jsii.Number]:
        """
        :stability: experimental
        """
        result = self._values.get("count")
        return result

    @builtins.property
    def depends_on(self) -> typing.Optional[typing.List[cdktf.TerraformResource]]:
        """
        :stability: experimental
        """
        result = self._values.get("depends_on")
        return result

    @builtins.property
    def lifecycle(self) -> typing.Optional[cdktf.TerraformResourceLifecycle]:
        """
        :stability: experimental
        """
        result = self._values.get("lifecycle")
        return result

    @builtins.property
    def provider(self) -> typing.Optional[cdktf.TerraformProvider]:
        """
        :stability: experimental
        """
        result = self._values.get("provider")
        return result

    @builtins.property
    def address_space(self) -> typing.List[builtins.str]:
        result = self._values.get("address_space")
        assert result is not None, "Required property 'address_space' is missing"
        return result

    @builtins.property
    def location(self) -> builtins.str:
        result = self._values.get("location")
        assert result is not None, "Required property 'location' is missing"
        return result

    @builtins.property
    def name(self) -> builtins.str:
        result = self._values.get("name")
        assert result is not None, "Required property 'name' is missing"
        return result

    @builtins.property
    def resource_group_name(self) -> builtins.str:
        result = self._values.get("resource_group_name")
        assert result is not None, "Required property 'resource_group_name' is missing"
        return result

    @builtins.property
    def ddos_protection_plan(
        self,
    ) -> typing.Optional[typing.List["VirtualNetworkDdosProtectionPlan"]]:
        """ddos_protection_plan block."""
        result = self._values.get("ddos_protection_plan")
        return result

    @builtins.property
    def dns_servers(self) -> typing.Optional[typing.List[builtins.str]]:
        result = self._values.get("dns_servers")
        return result

    @builtins.property
    def subnet(self) -> typing.Optional[typing.List["VirtualNetworkSubnet"]]:
        """subnet block."""
        result = self._values.get("subnet")
        return result

    @builtins.property
    def tags(self) -> typing.Optional[typing.Mapping[builtins.str, builtins.str]]:
        result = self._values.get("tags")
        return result

    @builtins.property
    def timeouts(self) -> typing.Optional["VirtualNetworkTimeouts"]:
        """timeouts block."""
        result = self._values.get("timeouts")
        return result

    def __eq__(self, rhs: typing.Any) -> builtins.bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs: typing.Any) -> builtins.bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return "VirtualNetworkConfig(%s)" % ", ".join(
            k + "=" + repr(v) for k, v in self._values.items()
        )


@jsii.data_type(
    jsii_type="@cdktf/provider-azurerm.VirtualNetworkDdosProtectionPlan",
    jsii_struct_bases=[],
    name_mapping={"enable": "enable", "id": "id"},
)
class VirtualNetworkDdosProtectionPlan:
    def __init__(self, *, enable: builtins.bool, id: builtins.str) -> None:
        """
        :param enable: 
        :param id: 
        """
        self._values: typing.Dict[str, typing.Any] = {
            "enable": enable,
            "id": id,
        }

    @builtins.property
    def enable(self) -> builtins.bool:
        result = self._values.get("enable")
        assert result is not None, "Required property 'enable' is missing"
        return result

    @builtins.property
    def id(self) -> builtins.str:
        result = self._values.get("id")
        assert result is not None, "Required property 'id' is missing"
        return result

    def __eq__(self, rhs: typing.Any) -> builtins.bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs: typing.Any) -> builtins.bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return "VirtualNetworkDdosProtectionPlan(%s)" % ", ".join(
            k + "=" + repr(v) for k, v in self._values.items()
        )


class VirtualNetworkGateway(
    cdktf.TerraformResource,
    metaclass=jsii.JSIIMeta,
    jsii_type="@cdktf/provider-azurerm.VirtualNetworkGateway",
):
    def __init__(
        self,
        scope: constructs.Construct,
        id: builtins.str,
        *,
        ip_configuration: typing.List["VirtualNetworkGatewayIpConfiguration"],
        location: builtins.str,
        name: builtins.str,
        resource_group_name: builtins.str,
        sku: builtins.str,
        type: builtins.str,
        active_active: typing.Optional[builtins.bool] = None,
        bgp_settings: typing.Optional[typing.List["VirtualNetworkGatewayBgpSettings"]] = None,
        default_local_network_gateway_id: typing.Optional[builtins.str] = None,
        enable_bgp: typing.Optional[builtins.bool] = None,
        generation: typing.Optional[builtins.str] = None,
        tags: typing.Optional[typing.Mapping[builtins.str, builtins.str]] = None,
        timeouts: typing.Optional["VirtualNetworkGatewayTimeouts"] = None,
        vpn_client_configuration: typing.Optional[typing.List["VirtualNetworkGatewayVpnClientConfiguration"]] = None,
        vpn_type: typing.Optional[builtins.str] = None,
        count: typing.Optional[jsii.Number] = None,
        depends_on: typing.Optional[typing.List[cdktf.TerraformResource]] = None,
        lifecycle: typing.Optional[cdktf.TerraformResourceLifecycle] = None,
        provider: typing.Optional[cdktf.TerraformProvider] = None,
    ) -> None:
        """
        :param scope: -
        :param id: -
        :param ip_configuration: ip_configuration block.
        :param location: 
        :param name: 
        :param resource_group_name: 
        :param sku: 
        :param type: 
        :param active_active: 
        :param bgp_settings: bgp_settings block.
        :param default_local_network_gateway_id: 
        :param enable_bgp: 
        :param generation: 
        :param tags: 
        :param timeouts: timeouts block.
        :param vpn_client_configuration: vpn_client_configuration block.
        :param vpn_type: 
        :param count: 
        :param depends_on: 
        :param lifecycle: 
        :param provider: 
        """
        config = VirtualNetworkGatewayConfig(
            ip_configuration=ip_configuration,
            location=location,
            name=name,
            resource_group_name=resource_group_name,
            sku=sku,
            type=type,
            active_active=active_active,
            bgp_settings=bgp_settings,
            default_local_network_gateway_id=default_local_network_gateway_id,
            enable_bgp=enable_bgp,
            generation=generation,
            tags=tags,
            timeouts=timeouts,
            vpn_client_configuration=vpn_client_configuration,
            vpn_type=vpn_type,
            count=count,
            depends_on=depends_on,
            lifecycle=lifecycle,
            provider=provider,
        )

        jsii.create(VirtualNetworkGateway, self, [scope, id, config])

    @jsii.member(jsii_name="synthesizeAttributes")
    def _synthesize_attributes(self) -> typing.Mapping[builtins.str, typing.Any]:
        return jsii.invoke(self, "synthesizeAttributes", [])

    @builtins.property # type: ignore
    @jsii.member(jsii_name="ipConfiguration")
    def ip_configuration(self) -> typing.List["VirtualNetworkGatewayIpConfiguration"]:
        return jsii.get(self, "ipConfiguration")

    @ip_configuration.setter # type: ignore
    def ip_configuration(
        self,
        value: typing.List["VirtualNetworkGatewayIpConfiguration"],
    ) -> None:
        jsii.set(self, "ipConfiguration", value)

    @builtins.property # type: ignore
    @jsii.member(jsii_name="location")
    def location(self) -> builtins.str:
        return jsii.get(self, "location")

    @location.setter # type: ignore
    def location(self, value: builtins.str) -> None:
        jsii.set(self, "location", value)

    @builtins.property # type: ignore
    @jsii.member(jsii_name="name")
    def name(self) -> builtins.str:
        return jsii.get(self, "name")

    @name.setter # type: ignore
    def name(self, value: builtins.str) -> None:
        jsii.set(self, "name", value)

    @builtins.property # type: ignore
    @jsii.member(jsii_name="resourceGroupName")
    def resource_group_name(self) -> builtins.str:
        return jsii.get(self, "resourceGroupName")

    @resource_group_name.setter # type: ignore
    def resource_group_name(self, value: builtins.str) -> None:
        jsii.set(self, "resourceGroupName", value)

    @builtins.property # type: ignore
    @jsii.member(jsii_name="sku")
    def sku(self) -> builtins.str:
        return jsii.get(self, "sku")

    @sku.setter # type: ignore
    def sku(self, value: builtins.str) -> None:
        jsii.set(self, "sku", value)

    @builtins.property # type: ignore
    @jsii.member(jsii_name="type")
    def type(self) -> builtins.str:
        return jsii.get(self, "type")

    @type.setter # type: ignore
    def type(self, value: builtins.str) -> None:
        jsii.set(self, "type", value)

    @builtins.property # type: ignore
    @jsii.member(jsii_name="activeActive")
    def active_active(self) -> typing.Optional[builtins.bool]:
        return jsii.get(self, "activeActive")

    @active_active.setter # type: ignore
    def active_active(self, value: typing.Optional[builtins.bool]) -> None:
        jsii.set(self, "activeActive", value)

    @builtins.property # type: ignore
    @jsii.member(jsii_name="bgpSettings")
    def bgp_settings(
        self,
    ) -> typing.Optional[typing.List["VirtualNetworkGatewayBgpSettings"]]:
        return jsii.get(self, "bgpSettings")

    @bgp_settings.setter # type: ignore
    def bgp_settings(
        self,
        value: typing.Optional[typing.List["VirtualNetworkGatewayBgpSettings"]],
    ) -> None:
        jsii.set(self, "bgpSettings", value)

    @builtins.property # type: ignore
    @jsii.member(jsii_name="defaultLocalNetworkGatewayId")
    def default_local_network_gateway_id(self) -> typing.Optional[builtins.str]:
        return jsii.get(self, "defaultLocalNetworkGatewayId")

    @default_local_network_gateway_id.setter # type: ignore
    def default_local_network_gateway_id(
        self,
        value: typing.Optional[builtins.str],
    ) -> None:
        jsii.set(self, "defaultLocalNetworkGatewayId", value)

    @builtins.property # type: ignore
    @jsii.member(jsii_name="enableBgp")
    def enable_bgp(self) -> typing.Optional[builtins.bool]:
        return jsii.get(self, "enableBgp")

    @enable_bgp.setter # type: ignore
    def enable_bgp(self, value: typing.Optional[builtins.bool]) -> None:
        jsii.set(self, "enableBgp", value)

    @builtins.property # type: ignore
    @jsii.member(jsii_name="generation")
    def generation(self) -> typing.Optional[builtins.str]:
        return jsii.get(self, "generation")

    @generation.setter # type: ignore
    def generation(self, value: typing.Optional[builtins.str]) -> None:
        jsii.set(self, "generation", value)

    @builtins.property # type: ignore
    @jsii.member(jsii_name="id")
    def id(self) -> typing.Optional[builtins.str]:
        return jsii.get(self, "id")

    @id.setter # type: ignore
    def id(self, value: typing.Optional[builtins.str]) -> None:
        jsii.set(self, "id", value)

    @builtins.property # type: ignore
    @jsii.member(jsii_name="tags")
    def tags(self) -> typing.Optional[typing.Mapping[builtins.str, builtins.str]]:
        return jsii.get(self, "tags")

    @tags.setter # type: ignore
    def tags(
        self,
        value: typing.Optional[typing.Mapping[builtins.str, builtins.str]],
    ) -> None:
        jsii.set(self, "tags", value)

    @builtins.property # type: ignore
    @jsii.member(jsii_name="timeouts")
    def timeouts(self) -> typing.Optional["VirtualNetworkGatewayTimeouts"]:
        return jsii.get(self, "timeouts")

    @timeouts.setter # type: ignore
    def timeouts(self, value: typing.Optional["VirtualNetworkGatewayTimeouts"]) -> None:
        jsii.set(self, "timeouts", value)

    @builtins.property # type: ignore
    @jsii.member(jsii_name="vpnClientConfiguration")
    def vpn_client_configuration(
        self,
    ) -> typing.Optional[typing.List["VirtualNetworkGatewayVpnClientConfiguration"]]:
        return jsii.get(self, "vpnClientConfiguration")

    @vpn_client_configuration.setter # type: ignore
    def vpn_client_configuration(
        self,
        value: typing.Optional[typing.List["VirtualNetworkGatewayVpnClientConfiguration"]],
    ) -> None:
        jsii.set(self, "vpnClientConfiguration", value)

    @builtins.property # type: ignore
    @jsii.member(jsii_name="vpnType")
    def vpn_type(self) -> typing.Optional[builtins.str]:
        return jsii.get(self, "vpnType")

    @vpn_type.setter # type: ignore
    def vpn_type(self, value: typing.Optional[builtins.str]) -> None:
        jsii.set(self, "vpnType", value)


@jsii.data_type(
    jsii_type="@cdktf/provider-azurerm.VirtualNetworkGatewayBgpSettings",
    jsii_struct_bases=[],
    name_mapping={
        "asn": "asn",
        "peering_address": "peeringAddress",
        "peer_weight": "peerWeight",
    },
)
class VirtualNetworkGatewayBgpSettings:
    def __init__(
        self,
        *,
        asn: typing.Optional[jsii.Number] = None,
        peering_address: typing.Optional[builtins.str] = None,
        peer_weight: typing.Optional[jsii.Number] = None,
    ) -> None:
        """
        :param asn: 
        :param peering_address: 
        :param peer_weight: 
        """
        self._values: typing.Dict[str, typing.Any] = {}
        if asn is not None:
            self._values["asn"] = asn
        if peering_address is not None:
            self._values["peering_address"] = peering_address
        if peer_weight is not None:
            self._values["peer_weight"] = peer_weight

    @builtins.property
    def asn(self) -> typing.Optional[jsii.Number]:
        result = self._values.get("asn")
        return result

    @builtins.property
    def peering_address(self) -> typing.Optional[builtins.str]:
        result = self._values.get("peering_address")
        return result

    @builtins.property
    def peer_weight(self) -> typing.Optional[jsii.Number]:
        result = self._values.get("peer_weight")
        return result

    def __eq__(self, rhs: typing.Any) -> builtins.bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs: typing.Any) -> builtins.bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return "VirtualNetworkGatewayBgpSettings(%s)" % ", ".join(
            k + "=" + repr(v) for k, v in self._values.items()
        )


@jsii.data_type(
    jsii_type="@cdktf/provider-azurerm.VirtualNetworkGatewayConfig",
    jsii_struct_bases=[cdktf.TerraformMetaArguments],
    name_mapping={
        "count": "count",
        "depends_on": "dependsOn",
        "lifecycle": "lifecycle",
        "provider": "provider",
        "ip_configuration": "ipConfiguration",
        "location": "location",
        "name": "name",
        "resource_group_name": "resourceGroupName",
        "sku": "sku",
        "type": "type",
        "active_active": "activeActive",
        "bgp_settings": "bgpSettings",
        "default_local_network_gateway_id": "defaultLocalNetworkGatewayId",
        "enable_bgp": "enableBgp",
        "generation": "generation",
        "tags": "tags",
        "timeouts": "timeouts",
        "vpn_client_configuration": "vpnClientConfiguration",
        "vpn_type": "vpnType",
    },
)
class VirtualNetworkGatewayConfig(cdktf.TerraformMetaArguments):
    def __init__(
        self,
        *,
        count: typing.Optional[jsii.Number] = None,
        depends_on: typing.Optional[typing.List[cdktf.TerraformResource]] = None,
        lifecycle: typing.Optional[cdktf.TerraformResourceLifecycle] = None,
        provider: typing.Optional[cdktf.TerraformProvider] = None,
        ip_configuration: typing.List["VirtualNetworkGatewayIpConfiguration"],
        location: builtins.str,
        name: builtins.str,
        resource_group_name: builtins.str,
        sku: builtins.str,
        type: builtins.str,
        active_active: typing.Optional[builtins.bool] = None,
        bgp_settings: typing.Optional[typing.List[VirtualNetworkGatewayBgpSettings]] = None,
        default_local_network_gateway_id: typing.Optional[builtins.str] = None,
        enable_bgp: typing.Optional[builtins.bool] = None,
        generation: typing.Optional[builtins.str] = None,
        tags: typing.Optional[typing.Mapping[builtins.str, builtins.str]] = None,
        timeouts: typing.Optional["VirtualNetworkGatewayTimeouts"] = None,
        vpn_client_configuration: typing.Optional[typing.List["VirtualNetworkGatewayVpnClientConfiguration"]] = None,
        vpn_type: typing.Optional[builtins.str] = None,
    ) -> None:
        """
        :param count: 
        :param depends_on: 
        :param lifecycle: 
        :param provider: 
        :param ip_configuration: ip_configuration block.
        :param location: 
        :param name: 
        :param resource_group_name: 
        :param sku: 
        :param type: 
        :param active_active: 
        :param bgp_settings: bgp_settings block.
        :param default_local_network_gateway_id: 
        :param enable_bgp: 
        :param generation: 
        :param tags: 
        :param timeouts: timeouts block.
        :param vpn_client_configuration: vpn_client_configuration block.
        :param vpn_type: 
        """
        if isinstance(lifecycle, dict):
            lifecycle = cdktf.TerraformResourceLifecycle(**lifecycle)
        if isinstance(timeouts, dict):
            timeouts = VirtualNetworkGatewayTimeouts(**timeouts)
        self._values: typing.Dict[str, typing.Any] = {
            "ip_configuration": ip_configuration,
            "location": location,
            "name": name,
            "resource_group_name": resource_group_name,
            "sku": sku,
            "type": type,
        }
        if count is not None:
            self._values["count"] = count
        if depends_on is not None:
            self._values["depends_on"] = depends_on
        if lifecycle is not None:
            self._values["lifecycle"] = lifecycle
        if provider is not None:
            self._values["provider"] = provider
        if active_active is not None:
            self._values["active_active"] = active_active
        if bgp_settings is not None:
            self._values["bgp_settings"] = bgp_settings
        if default_local_network_gateway_id is not None:
            self._values["default_local_network_gateway_id"] = default_local_network_gateway_id
        if enable_bgp is not None:
            self._values["enable_bgp"] = enable_bgp
        if generation is not None:
            self._values["generation"] = generation
        if tags is not None:
            self._values["tags"] = tags
        if timeouts is not None:
            self._values["timeouts"] = timeouts
        if vpn_client_configuration is not None:
            self._values["vpn_client_configuration"] = vpn_client_configuration
        if vpn_type is not None:
            self._values["vpn_type"] = vpn_type

    @builtins.property
    def count(self) -> typing.Optional[jsii.Number]:
        """
        :stability: experimental
        """
        result = self._values.get("count")
        return result

    @builtins.property
    def depends_on(self) -> typing.Optional[typing.List[cdktf.TerraformResource]]:
        """
        :stability: experimental
        """
        result = self._values.get("depends_on")
        return result

    @builtins.property
    def lifecycle(self) -> typing.Optional[cdktf.TerraformResourceLifecycle]:
        """
        :stability: experimental
        """
        result = self._values.get("lifecycle")
        return result

    @builtins.property
    def provider(self) -> typing.Optional[cdktf.TerraformProvider]:
        """
        :stability: experimental
        """
        result = self._values.get("provider")
        return result

    @builtins.property
    def ip_configuration(self) -> typing.List["VirtualNetworkGatewayIpConfiguration"]:
        """ip_configuration block."""
        result = self._values.get("ip_configuration")
        assert result is not None, "Required property 'ip_configuration' is missing"
        return result

    @builtins.property
    def location(self) -> builtins.str:
        result = self._values.get("location")
        assert result is not None, "Required property 'location' is missing"
        return result

    @builtins.property
    def name(self) -> builtins.str:
        result = self._values.get("name")
        assert result is not None, "Required property 'name' is missing"
        return result

    @builtins.property
    def resource_group_name(self) -> builtins.str:
        result = self._values.get("resource_group_name")
        assert result is not None, "Required property 'resource_group_name' is missing"
        return result

    @builtins.property
    def sku(self) -> builtins.str:
        result = self._values.get("sku")
        assert result is not None, "Required property 'sku' is missing"
        return result

    @builtins.property
    def type(self) -> builtins.str:
        result = self._values.get("type")
        assert result is not None, "Required property 'type' is missing"
        return result

    @builtins.property
    def active_active(self) -> typing.Optional[builtins.bool]:
        result = self._values.get("active_active")
        return result

    @builtins.property
    def bgp_settings(
        self,
    ) -> typing.Optional[typing.List[VirtualNetworkGatewayBgpSettings]]:
        """bgp_settings block."""
        result = self._values.get("bgp_settings")
        return result

    @builtins.property
    def default_local_network_gateway_id(self) -> typing.Optional[builtins.str]:
        result = self._values.get("default_local_network_gateway_id")
        return result

    @builtins.property
    def enable_bgp(self) -> typing.Optional[builtins.bool]:
        result = self._values.get("enable_bgp")
        return result

    @builtins.property
    def generation(self) -> typing.Optional[builtins.str]:
        result = self._values.get("generation")
        return result

    @builtins.property
    def tags(self) -> typing.Optional[typing.Mapping[builtins.str, builtins.str]]:
        result = self._values.get("tags")
        return result

    @builtins.property
    def timeouts(self) -> typing.Optional["VirtualNetworkGatewayTimeouts"]:
        """timeouts block."""
        result = self._values.get("timeouts")
        return result

    @builtins.property
    def vpn_client_configuration(
        self,
    ) -> typing.Optional[typing.List["VirtualNetworkGatewayVpnClientConfiguration"]]:
        """vpn_client_configuration block."""
        result = self._values.get("vpn_client_configuration")
        return result

    @builtins.property
    def vpn_type(self) -> typing.Optional[builtins.str]:
        result = self._values.get("vpn_type")
        return result

    def __eq__(self, rhs: typing.Any) -> builtins.bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs: typing.Any) -> builtins.bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return "VirtualNetworkGatewayConfig(%s)" % ", ".join(
            k + "=" + repr(v) for k, v in self._values.items()
        )


class VirtualNetworkGatewayConnection(
    cdktf.TerraformResource,
    metaclass=jsii.JSIIMeta,
    jsii_type="@cdktf/provider-azurerm.VirtualNetworkGatewayConnection",
):
    def __init__(
        self,
        scope: constructs.Construct,
        id: builtins.str,
        *,
        location: builtins.str,
        name: builtins.str,
        resource_group_name: builtins.str,
        type: builtins.str,
        virtual_network_gateway_id: builtins.str,
        authorization_key: typing.Optional[builtins.str] = None,
        connection_protocol: typing.Optional[builtins.str] = None,
        enable_bgp: typing.Optional[builtins.bool] = None,
        express_route_circuit_id: typing.Optional[builtins.str] = None,
        express_route_gateway_bypass: typing.Optional[builtins.bool] = None,
        ipsec_policy: typing.Optional[typing.List["VirtualNetworkGatewayConnectionIpsecPolicy"]] = None,
        local_network_gateway_id: typing.Optional[builtins.str] = None,
        peer_virtual_network_gateway_id: typing.Optional[builtins.str] = None,
        routing_weight: typing.Optional[jsii.Number] = None,
        shared_key: typing.Optional[builtins.str] = None,
        tags: typing.Optional[typing.Mapping[builtins.str, builtins.str]] = None,
        timeouts: typing.Optional["VirtualNetworkGatewayConnectionTimeouts"] = None,
        use_policy_based_traffic_selectors: typing.Optional[builtins.bool] = None,
        count: typing.Optional[jsii.Number] = None,
        depends_on: typing.Optional[typing.List[cdktf.TerraformResource]] = None,
        lifecycle: typing.Optional[cdktf.TerraformResourceLifecycle] = None,
        provider: typing.Optional[cdktf.TerraformProvider] = None,
    ) -> None:
        """
        :param scope: -
        :param id: -
        :param location: 
        :param name: 
        :param resource_group_name: 
        :param type: 
        :param virtual_network_gateway_id: 
        :param authorization_key: 
        :param connection_protocol: 
        :param enable_bgp: 
        :param express_route_circuit_id: 
        :param express_route_gateway_bypass: 
        :param ipsec_policy: ipsec_policy block.
        :param local_network_gateway_id: 
        :param peer_virtual_network_gateway_id: 
        :param routing_weight: 
        :param shared_key: 
        :param tags: 
        :param timeouts: timeouts block.
        :param use_policy_based_traffic_selectors: 
        :param count: 
        :param depends_on: 
        :param lifecycle: 
        :param provider: 
        """
        config = VirtualNetworkGatewayConnectionConfig(
            location=location,
            name=name,
            resource_group_name=resource_group_name,
            type=type,
            virtual_network_gateway_id=virtual_network_gateway_id,
            authorization_key=authorization_key,
            connection_protocol=connection_protocol,
            enable_bgp=enable_bgp,
            express_route_circuit_id=express_route_circuit_id,
            express_route_gateway_bypass=express_route_gateway_bypass,
            ipsec_policy=ipsec_policy,
            local_network_gateway_id=local_network_gateway_id,
            peer_virtual_network_gateway_id=peer_virtual_network_gateway_id,
            routing_weight=routing_weight,
            shared_key=shared_key,
            tags=tags,
            timeouts=timeouts,
            use_policy_based_traffic_selectors=use_policy_based_traffic_selectors,
            count=count,
            depends_on=depends_on,
            lifecycle=lifecycle,
            provider=provider,
        )

        jsii.create(VirtualNetworkGatewayConnection, self, [scope, id, config])

    @jsii.member(jsii_name="synthesizeAttributes")
    def _synthesize_attributes(self) -> typing.Mapping[builtins.str, typing.Any]:
        return jsii.invoke(self, "synthesizeAttributes", [])

    @builtins.property # type: ignore
    @jsii.member(jsii_name="location")
    def location(self) -> builtins.str:
        return jsii.get(self, "location")

    @location.setter # type: ignore
    def location(self, value: builtins.str) -> None:
        jsii.set(self, "location", value)

    @builtins.property # type: ignore
    @jsii.member(jsii_name="name")
    def name(self) -> builtins.str:
        return jsii.get(self, "name")

    @name.setter # type: ignore
    def name(self, value: builtins.str) -> None:
        jsii.set(self, "name", value)

    @builtins.property # type: ignore
    @jsii.member(jsii_name="resourceGroupName")
    def resource_group_name(self) -> builtins.str:
        return jsii.get(self, "resourceGroupName")

    @resource_group_name.setter # type: ignore
    def resource_group_name(self, value: builtins.str) -> None:
        jsii.set(self, "resourceGroupName", value)

    @builtins.property # type: ignore
    @jsii.member(jsii_name="type")
    def type(self) -> builtins.str:
        return jsii.get(self, "type")

    @type.setter # type: ignore
    def type(self, value: builtins.str) -> None:
        jsii.set(self, "type", value)

    @builtins.property # type: ignore
    @jsii.member(jsii_name="virtualNetworkGatewayId")
    def virtual_network_gateway_id(self) -> builtins.str:
        return jsii.get(self, "virtualNetworkGatewayId")

    @virtual_network_gateway_id.setter # type: ignore
    def virtual_network_gateway_id(self, value: builtins.str) -> None:
        jsii.set(self, "virtualNetworkGatewayId", value)

    @builtins.property # type: ignore
    @jsii.member(jsii_name="authorizationKey")
    def authorization_key(self) -> typing.Optional[builtins.str]:
        return jsii.get(self, "authorizationKey")

    @authorization_key.setter # type: ignore
    def authorization_key(self, value: typing.Optional[builtins.str]) -> None:
        jsii.set(self, "authorizationKey", value)

    @builtins.property # type: ignore
    @jsii.member(jsii_name="connectionProtocol")
    def connection_protocol(self) -> typing.Optional[builtins.str]:
        return jsii.get(self, "connectionProtocol")

    @connection_protocol.setter # type: ignore
    def connection_protocol(self, value: typing.Optional[builtins.str]) -> None:
        jsii.set(self, "connectionProtocol", value)

    @builtins.property # type: ignore
    @jsii.member(jsii_name="enableBgp")
    def enable_bgp(self) -> typing.Optional[builtins.bool]:
        return jsii.get(self, "enableBgp")

    @enable_bgp.setter # type: ignore
    def enable_bgp(self, value: typing.Optional[builtins.bool]) -> None:
        jsii.set(self, "enableBgp", value)

    @builtins.property # type: ignore
    @jsii.member(jsii_name="expressRouteCircuitId")
    def express_route_circuit_id(self) -> typing.Optional[builtins.str]:
        return jsii.get(self, "expressRouteCircuitId")

    @express_route_circuit_id.setter # type: ignore
    def express_route_circuit_id(self, value: typing.Optional[builtins.str]) -> None:
        jsii.set(self, "expressRouteCircuitId", value)

    @builtins.property # type: ignore
    @jsii.member(jsii_name="expressRouteGatewayBypass")
    def express_route_gateway_bypass(self) -> typing.Optional[builtins.bool]:
        return jsii.get(self, "expressRouteGatewayBypass")

    @express_route_gateway_bypass.setter # type: ignore
    def express_route_gateway_bypass(
        self,
        value: typing.Optional[builtins.bool],
    ) -> None:
        jsii.set(self, "expressRouteGatewayBypass", value)

    @builtins.property # type: ignore
    @jsii.member(jsii_name="id")
    def id(self) -> typing.Optional[builtins.str]:
        return jsii.get(self, "id")

    @id.setter # type: ignore
    def id(self, value: typing.Optional[builtins.str]) -> None:
        jsii.set(self, "id", value)

    @builtins.property # type: ignore
    @jsii.member(jsii_name="ipsecPolicy")
    def ipsec_policy(
        self,
    ) -> typing.Optional[typing.List["VirtualNetworkGatewayConnectionIpsecPolicy"]]:
        return jsii.get(self, "ipsecPolicy")

    @ipsec_policy.setter # type: ignore
    def ipsec_policy(
        self,
        value: typing.Optional[typing.List["VirtualNetworkGatewayConnectionIpsecPolicy"]],
    ) -> None:
        jsii.set(self, "ipsecPolicy", value)

    @builtins.property # type: ignore
    @jsii.member(jsii_name="localNetworkGatewayId")
    def local_network_gateway_id(self) -> typing.Optional[builtins.str]:
        return jsii.get(self, "localNetworkGatewayId")

    @local_network_gateway_id.setter # type: ignore
    def local_network_gateway_id(self, value: typing.Optional[builtins.str]) -> None:
        jsii.set(self, "localNetworkGatewayId", value)

    @builtins.property # type: ignore
    @jsii.member(jsii_name="peerVirtualNetworkGatewayId")
    def peer_virtual_network_gateway_id(self) -> typing.Optional[builtins.str]:
        return jsii.get(self, "peerVirtualNetworkGatewayId")

    @peer_virtual_network_gateway_id.setter # type: ignore
    def peer_virtual_network_gateway_id(
        self,
        value: typing.Optional[builtins.str],
    ) -> None:
        jsii.set(self, "peerVirtualNetworkGatewayId", value)

    @builtins.property # type: ignore
    @jsii.member(jsii_name="routingWeight")
    def routing_weight(self) -> typing.Optional[jsii.Number]:
        return jsii.get(self, "routingWeight")

    @routing_weight.setter # type: ignore
    def routing_weight(self, value: typing.Optional[jsii.Number]) -> None:
        jsii.set(self, "routingWeight", value)

    @builtins.property # type: ignore
    @jsii.member(jsii_name="sharedKey")
    def shared_key(self) -> typing.Optional[builtins.str]:
        return jsii.get(self, "sharedKey")

    @shared_key.setter # type: ignore
    def shared_key(self, value: typing.Optional[builtins.str]) -> None:
        jsii.set(self, "sharedKey", value)

    @builtins.property # type: ignore
    @jsii.member(jsii_name="tags")
    def tags(self) -> typing.Optional[typing.Mapping[builtins.str, builtins.str]]:
        return jsii.get(self, "tags")

    @tags.setter # type: ignore
    def tags(
        self,
        value: typing.Optional[typing.Mapping[builtins.str, builtins.str]],
    ) -> None:
        jsii.set(self, "tags", value)

    @builtins.property # type: ignore
    @jsii.member(jsii_name="timeouts")
    def timeouts(self) -> typing.Optional["VirtualNetworkGatewayConnectionTimeouts"]:
        return jsii.get(self, "timeouts")

    @timeouts.setter # type: ignore
    def timeouts(
        self,
        value: typing.Optional["VirtualNetworkGatewayConnectionTimeouts"],
    ) -> None:
        jsii.set(self, "timeouts", value)

    @builtins.property # type: ignore
    @jsii.member(jsii_name="usePolicyBasedTrafficSelectors")
    def use_policy_based_traffic_selectors(self) -> typing.Optional[builtins.bool]:
        return jsii.get(self, "usePolicyBasedTrafficSelectors")

    @use_policy_based_traffic_selectors.setter # type: ignore
    def use_policy_based_traffic_selectors(
        self,
        value: typing.Optional[builtins.bool],
    ) -> None:
        jsii.set(self, "usePolicyBasedTrafficSelectors", value)


@jsii.data_type(
    jsii_type="@cdktf/provider-azurerm.VirtualNetworkGatewayConnectionConfig",
    jsii_struct_bases=[cdktf.TerraformMetaArguments],
    name_mapping={
        "count": "count",
        "depends_on": "dependsOn",
        "lifecycle": "lifecycle",
        "provider": "provider",
        "location": "location",
        "name": "name",
        "resource_group_name": "resourceGroupName",
        "type": "type",
        "virtual_network_gateway_id": "virtualNetworkGatewayId",
        "authorization_key": "authorizationKey",
        "connection_protocol": "connectionProtocol",
        "enable_bgp": "enableBgp",
        "express_route_circuit_id": "expressRouteCircuitId",
        "express_route_gateway_bypass": "expressRouteGatewayBypass",
        "ipsec_policy": "ipsecPolicy",
        "local_network_gateway_id": "localNetworkGatewayId",
        "peer_virtual_network_gateway_id": "peerVirtualNetworkGatewayId",
        "routing_weight": "routingWeight",
        "shared_key": "sharedKey",
        "tags": "tags",
        "timeouts": "timeouts",
        "use_policy_based_traffic_selectors": "usePolicyBasedTrafficSelectors",
    },
)
class VirtualNetworkGatewayConnectionConfig(cdktf.TerraformMetaArguments):
    def __init__(
        self,
        *,
        count: typing.Optional[jsii.Number] = None,
        depends_on: typing.Optional[typing.List[cdktf.TerraformResource]] = None,
        lifecycle: typing.Optional[cdktf.TerraformResourceLifecycle] = None,
        provider: typing.Optional[cdktf.TerraformProvider] = None,
        location: builtins.str,
        name: builtins.str,
        resource_group_name: builtins.str,
        type: builtins.str,
        virtual_network_gateway_id: builtins.str,
        authorization_key: typing.Optional[builtins.str] = None,
        connection_protocol: typing.Optional[builtins.str] = None,
        enable_bgp: typing.Optional[builtins.bool] = None,
        express_route_circuit_id: typing.Optional[builtins.str] = None,
        express_route_gateway_bypass: typing.Optional[builtins.bool] = None,
        ipsec_policy: typing.Optional[typing.List["VirtualNetworkGatewayConnectionIpsecPolicy"]] = None,
        local_network_gateway_id: typing.Optional[builtins.str] = None,
        peer_virtual_network_gateway_id: typing.Optional[builtins.str] = None,
        routing_weight: typing.Optional[jsii.Number] = None,
        shared_key: typing.Optional[builtins.str] = None,
        tags: typing.Optional[typing.Mapping[builtins.str, builtins.str]] = None,
        timeouts: typing.Optional["VirtualNetworkGatewayConnectionTimeouts"] = None,
        use_policy_based_traffic_selectors: typing.Optional[builtins.bool] = None,
    ) -> None:
        """
        :param count: 
        :param depends_on: 
        :param lifecycle: 
        :param provider: 
        :param location: 
        :param name: 
        :param resource_group_name: 
        :param type: 
        :param virtual_network_gateway_id: 
        :param authorization_key: 
        :param connection_protocol: 
        :param enable_bgp: 
        :param express_route_circuit_id: 
        :param express_route_gateway_bypass: 
        :param ipsec_policy: ipsec_policy block.
        :param local_network_gateway_id: 
        :param peer_virtual_network_gateway_id: 
        :param routing_weight: 
        :param shared_key: 
        :param tags: 
        :param timeouts: timeouts block.
        :param use_policy_based_traffic_selectors: 
        """
        if isinstance(lifecycle, dict):
            lifecycle = cdktf.TerraformResourceLifecycle(**lifecycle)
        if isinstance(timeouts, dict):
            timeouts = VirtualNetworkGatewayConnectionTimeouts(**timeouts)
        self._values: typing.Dict[str, typing.Any] = {
            "location": location,
            "name": name,
            "resource_group_name": resource_group_name,
            "type": type,
            "virtual_network_gateway_id": virtual_network_gateway_id,
        }
        if count is not None:
            self._values["count"] = count
        if depends_on is not None:
            self._values["depends_on"] = depends_on
        if lifecycle is not None:
            self._values["lifecycle"] = lifecycle
        if provider is not None:
            self._values["provider"] = provider
        if authorization_key is not None:
            self._values["authorization_key"] = authorization_key
        if connection_protocol is not None:
            self._values["connection_protocol"] = connection_protocol
        if enable_bgp is not None:
            self._values["enable_bgp"] = enable_bgp
        if express_route_circuit_id is not None:
            self._values["express_route_circuit_id"] = express_route_circuit_id
        if express_route_gateway_bypass is not None:
            self._values["express_route_gateway_bypass"] = express_route_gateway_bypass
        if ipsec_policy is not None:
            self._values["ipsec_policy"] = ipsec_policy
        if local_network_gateway_id is not None:
            self._values["local_network_gateway_id"] = local_network_gateway_id
        if peer_virtual_network_gateway_id is not None:
            self._values["peer_virtual_network_gateway_id"] = peer_virtual_network_gateway_id
        if routing_weight is not None:
            self._values["routing_weight"] = routing_weight
        if shared_key is not None:
            self._values["shared_key"] = shared_key
        if tags is not None:
            self._values["tags"] = tags
        if timeouts is not None:
            self._values["timeouts"] = timeouts
        if use_policy_based_traffic_selectors is not None:
            self._values["use_policy_based_traffic_selectors"] = use_policy_based_traffic_selectors

    @builtins.property
    def count(self) -> typing.Optional[jsii.Number]:
        """
        :stability: experimental
        """
        result = self._values.get("count")
        return result

    @builtins.property
    def depends_on(self) -> typing.Optional[typing.List[cdktf.TerraformResource]]:
        """
        :stability: experimental
        """
        result = self._values.get("depends_on")
        return result

    @builtins.property
    def lifecycle(self) -> typing.Optional[cdktf.TerraformResourceLifecycle]:
        """
        :stability: experimental
        """
        result = self._values.get("lifecycle")
        return result

    @builtins.property
    def provider(self) -> typing.Optional[cdktf.TerraformProvider]:
        """
        :stability: experimental
        """
        result = self._values.get("provider")
        return result

    @builtins.property
    def location(self) -> builtins.str:
        result = self._values.get("location")
        assert result is not None, "Required property 'location' is missing"
        return result

    @builtins.property
    def name(self) -> builtins.str:
        result = self._values.get("name")
        assert result is not None, "Required property 'name' is missing"
        return result

    @builtins.property
    def resource_group_name(self) -> builtins.str:
        result = self._values.get("resource_group_name")
        assert result is not None, "Required property 'resource_group_name' is missing"
        return result

    @builtins.property
    def type(self) -> builtins.str:
        result = self._values.get("type")
        assert result is not None, "Required property 'type' is missing"
        return result

    @builtins.property
    def virtual_network_gateway_id(self) -> builtins.str:
        result = self._values.get("virtual_network_gateway_id")
        assert result is not None, "Required property 'virtual_network_gateway_id' is missing"
        return result

    @builtins.property
    def authorization_key(self) -> typing.Optional[builtins.str]:
        result = self._values.get("authorization_key")
        return result

    @builtins.property
    def connection_protocol(self) -> typing.Optional[builtins.str]:
        result = self._values.get("connection_protocol")
        return result

    @builtins.property
    def enable_bgp(self) -> typing.Optional[builtins.bool]:
        result = self._values.get("enable_bgp")
        return result

    @builtins.property
    def express_route_circuit_id(self) -> typing.Optional[builtins.str]:
        result = self._values.get("express_route_circuit_id")
        return result

    @builtins.property
    def express_route_gateway_bypass(self) -> typing.Optional[builtins.bool]:
        result = self._values.get("express_route_gateway_bypass")
        return result

    @builtins.property
    def ipsec_policy(
        self,
    ) -> typing.Optional[typing.List["VirtualNetworkGatewayConnectionIpsecPolicy"]]:
        """ipsec_policy block."""
        result = self._values.get("ipsec_policy")
        return result

    @builtins.property
    def local_network_gateway_id(self) -> typing.Optional[builtins.str]:
        result = self._values.get("local_network_gateway_id")
        return result

    @builtins.property
    def peer_virtual_network_gateway_id(self) -> typing.Optional[builtins.str]:
        result = self._values.get("peer_virtual_network_gateway_id")
        return result

    @builtins.property
    def routing_weight(self) -> typing.Optional[jsii.Number]:
        result = self._values.get("routing_weight")
        return result

    @builtins.property
    def shared_key(self) -> typing.Optional[builtins.str]:
        result = self._values.get("shared_key")
        return result

    @builtins.property
    def tags(self) -> typing.Optional[typing.Mapping[builtins.str, builtins.str]]:
        result = self._values.get("tags")
        return result

    @builtins.property
    def timeouts(self) -> typing.Optional["VirtualNetworkGatewayConnectionTimeouts"]:
        """timeouts block."""
        result = self._values.get("timeouts")
        return result

    @builtins.property
    def use_policy_based_traffic_selectors(self) -> typing.Optional[builtins.bool]:
        result = self._values.get("use_policy_based_traffic_selectors")
        return result

    def __eq__(self, rhs: typing.Any) -> builtins.bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs: typing.Any) -> builtins.bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return "VirtualNetworkGatewayConnectionConfig(%s)" % ", ".join(
            k + "=" + repr(v) for k, v in self._values.items()
        )


@jsii.data_type(
    jsii_type="@cdktf/provider-azurerm.VirtualNetworkGatewayConnectionIpsecPolicy",
    jsii_struct_bases=[],
    name_mapping={
        "dh_group": "dhGroup",
        "ike_encryption": "ikeEncryption",
        "ike_integrity": "ikeIntegrity",
        "ipsec_encryption": "ipsecEncryption",
        "ipsec_integrity": "ipsecIntegrity",
        "pfs_group": "pfsGroup",
        "sa_datasize": "saDatasize",
        "sa_lifetime": "saLifetime",
    },
)
class VirtualNetworkGatewayConnectionIpsecPolicy:
    def __init__(
        self,
        *,
        dh_group: builtins.str,
        ike_encryption: builtins.str,
        ike_integrity: builtins.str,
        ipsec_encryption: builtins.str,
        ipsec_integrity: builtins.str,
        pfs_group: builtins.str,
        sa_datasize: typing.Optional[jsii.Number] = None,
        sa_lifetime: typing.Optional[jsii.Number] = None,
    ) -> None:
        """
        :param dh_group: 
        :param ike_encryption: 
        :param ike_integrity: 
        :param ipsec_encryption: 
        :param ipsec_integrity: 
        :param pfs_group: 
        :param sa_datasize: 
        :param sa_lifetime: 
        """
        self._values: typing.Dict[str, typing.Any] = {
            "dh_group": dh_group,
            "ike_encryption": ike_encryption,
            "ike_integrity": ike_integrity,
            "ipsec_encryption": ipsec_encryption,
            "ipsec_integrity": ipsec_integrity,
            "pfs_group": pfs_group,
        }
        if sa_datasize is not None:
            self._values["sa_datasize"] = sa_datasize
        if sa_lifetime is not None:
            self._values["sa_lifetime"] = sa_lifetime

    @builtins.property
    def dh_group(self) -> builtins.str:
        result = self._values.get("dh_group")
        assert result is not None, "Required property 'dh_group' is missing"
        return result

    @builtins.property
    def ike_encryption(self) -> builtins.str:
        result = self._values.get("ike_encryption")
        assert result is not None, "Required property 'ike_encryption' is missing"
        return result

    @builtins.property
    def ike_integrity(self) -> builtins.str:
        result = self._values.get("ike_integrity")
        assert result is not None, "Required property 'ike_integrity' is missing"
        return result

    @builtins.property
    def ipsec_encryption(self) -> builtins.str:
        result = self._values.get("ipsec_encryption")
        assert result is not None, "Required property 'ipsec_encryption' is missing"
        return result

    @builtins.property
    def ipsec_integrity(self) -> builtins.str:
        result = self._values.get("ipsec_integrity")
        assert result is not None, "Required property 'ipsec_integrity' is missing"
        return result

    @builtins.property
    def pfs_group(self) -> builtins.str:
        result = self._values.get("pfs_group")
        assert result is not None, "Required property 'pfs_group' is missing"
        return result

    @builtins.property
    def sa_datasize(self) -> typing.Optional[jsii.Number]:
        result = self._values.get("sa_datasize")
        return result

    @builtins.property
    def sa_lifetime(self) -> typing.Optional[jsii.Number]:
        result = self._values.get("sa_lifetime")
        return result

    def __eq__(self, rhs: typing.Any) -> builtins.bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs: typing.Any) -> builtins.bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return "VirtualNetworkGatewayConnectionIpsecPolicy(%s)" % ", ".join(
            k + "=" + repr(v) for k, v in self._values.items()
        )


@jsii.data_type(
    jsii_type="@cdktf/provider-azurerm.VirtualNetworkGatewayConnectionTimeouts",
    jsii_struct_bases=[],
    name_mapping={
        "create": "create",
        "delete": "delete",
        "read": "read",
        "update": "update",
    },
)
class VirtualNetworkGatewayConnectionTimeouts:
    def __init__(
        self,
        *,
        create: typing.Optional[builtins.str] = None,
        delete: typing.Optional[builtins.str] = None,
        read: typing.Optional[builtins.str] = None,
        update: typing.Optional[builtins.str] = None,
    ) -> None:
        """
        :param create: 
        :param delete: 
        :param read: 
        :param update: 
        """
        self._values: typing.Dict[str, typing.Any] = {}
        if create is not None:
            self._values["create"] = create
        if delete is not None:
            self._values["delete"] = delete
        if read is not None:
            self._values["read"] = read
        if update is not None:
            self._values["update"] = update

    @builtins.property
    def create(self) -> typing.Optional[builtins.str]:
        result = self._values.get("create")
        return result

    @builtins.property
    def delete(self) -> typing.Optional[builtins.str]:
        result = self._values.get("delete")
        return result

    @builtins.property
    def read(self) -> typing.Optional[builtins.str]:
        result = self._values.get("read")
        return result

    @builtins.property
    def update(self) -> typing.Optional[builtins.str]:
        result = self._values.get("update")
        return result

    def __eq__(self, rhs: typing.Any) -> builtins.bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs: typing.Any) -> builtins.bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return "VirtualNetworkGatewayConnectionTimeouts(%s)" % ", ".join(
            k + "=" + repr(v) for k, v in self._values.items()
        )


@jsii.data_type(
    jsii_type="@cdktf/provider-azurerm.VirtualNetworkGatewayIpConfiguration",
    jsii_struct_bases=[],
    name_mapping={
        "subnet_id": "subnetId",
        "name": "name",
        "private_ip_address_allocation": "privateIpAddressAllocation",
        "public_ip_address_id": "publicIpAddressId",
    },
)
class VirtualNetworkGatewayIpConfiguration:
    def __init__(
        self,
        *,
        subnet_id: builtins.str,
        name: typing.Optional[builtins.str] = None,
        private_ip_address_allocation: typing.Optional[builtins.str] = None,
        public_ip_address_id: typing.Optional[builtins.str] = None,
    ) -> None:
        """
        :param subnet_id: 
        :param name: 
        :param private_ip_address_allocation: 
        :param public_ip_address_id: 
        """
        self._values: typing.Dict[str, typing.Any] = {
            "subnet_id": subnet_id,
        }
        if name is not None:
            self._values["name"] = name
        if private_ip_address_allocation is not None:
            self._values["private_ip_address_allocation"] = private_ip_address_allocation
        if public_ip_address_id is not None:
            self._values["public_ip_address_id"] = public_ip_address_id

    @builtins.property
    def subnet_id(self) -> builtins.str:
        result = self._values.get("subnet_id")
        assert result is not None, "Required property 'subnet_id' is missing"
        return result

    @builtins.property
    def name(self) -> typing.Optional[builtins.str]:
        result = self._values.get("name")
        return result

    @builtins.property
    def private_ip_address_allocation(self) -> typing.Optional[builtins.str]:
        result = self._values.get("private_ip_address_allocation")
        return result

    @builtins.property
    def public_ip_address_id(self) -> typing.Optional[builtins.str]:
        result = self._values.get("public_ip_address_id")
        return result

    def __eq__(self, rhs: typing.Any) -> builtins.bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs: typing.Any) -> builtins.bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return "VirtualNetworkGatewayIpConfiguration(%s)" % ", ".join(
            k + "=" + repr(v) for k, v in self._values.items()
        )


@jsii.data_type(
    jsii_type="@cdktf/provider-azurerm.VirtualNetworkGatewayTimeouts",
    jsii_struct_bases=[],
    name_mapping={
        "create": "create",
        "delete": "delete",
        "read": "read",
        "update": "update",
    },
)
class VirtualNetworkGatewayTimeouts:
    def __init__(
        self,
        *,
        create: typing.Optional[builtins.str] = None,
        delete: typing.Optional[builtins.str] = None,
        read: typing.Optional[builtins.str] = None,
        update: typing.Optional[builtins.str] = None,
    ) -> None:
        """
        :param create: 
        :param delete: 
        :param read: 
        :param update: 
        """
        self._values: typing.Dict[str, typing.Any] = {}
        if create is not None:
            self._values["create"] = create
        if delete is not None:
            self._values["delete"] = delete
        if read is not None:
            self._values["read"] = read
        if update is not None:
            self._values["update"] = update

    @builtins.property
    def create(self) -> typing.Optional[builtins.str]:
        result = self._values.get("create")
        return result

    @builtins.property
    def delete(self) -> typing.Optional[builtins.str]:
        result = self._values.get("delete")
        return result

    @builtins.property
    def read(self) -> typing.Optional[builtins.str]:
        result = self._values.get("read")
        return result

    @builtins.property
    def update(self) -> typing.Optional[builtins.str]:
        result = self._values.get("update")
        return result

    def __eq__(self, rhs: typing.Any) -> builtins.bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs: typing.Any) -> builtins.bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return "VirtualNetworkGatewayTimeouts(%s)" % ", ".join(
            k + "=" + repr(v) for k, v in self._values.items()
        )


@jsii.data_type(
    jsii_type="@cdktf/provider-azurerm.VirtualNetworkGatewayVpnClientConfiguration",
    jsii_struct_bases=[],
    name_mapping={
        "address_space": "addressSpace",
        "radius_server_address": "radiusServerAddress",
        "radius_server_secret": "radiusServerSecret",
        "revoked_certificate": "revokedCertificate",
        "root_certificate": "rootCertificate",
        "vpn_client_protocols": "vpnClientProtocols",
    },
)
class VirtualNetworkGatewayVpnClientConfiguration:
    def __init__(
        self,
        *,
        address_space: typing.List[builtins.str],
        radius_server_address: typing.Optional[builtins.str] = None,
        radius_server_secret: typing.Optional[builtins.str] = None,
        revoked_certificate: typing.Optional[typing.List["VirtualNetworkGatewayVpnClientConfigurationRevokedCertificate"]] = None,
        root_certificate: typing.Optional[typing.List["VirtualNetworkGatewayVpnClientConfigurationRootCertificate"]] = None,
        vpn_client_protocols: typing.Optional[typing.List[builtins.str]] = None,
    ) -> None:
        """
        :param address_space: 
        :param radius_server_address: 
        :param radius_server_secret: 
        :param revoked_certificate: revoked_certificate block.
        :param root_certificate: root_certificate block.
        :param vpn_client_protocols: 
        """
        self._values: typing.Dict[str, typing.Any] = {
            "address_space": address_space,
        }
        if radius_server_address is not None:
            self._values["radius_server_address"] = radius_server_address
        if radius_server_secret is not None:
            self._values["radius_server_secret"] = radius_server_secret
        if revoked_certificate is not None:
            self._values["revoked_certificate"] = revoked_certificate
        if root_certificate is not None:
            self._values["root_certificate"] = root_certificate
        if vpn_client_protocols is not None:
            self._values["vpn_client_protocols"] = vpn_client_protocols

    @builtins.property
    def address_space(self) -> typing.List[builtins.str]:
        result = self._values.get("address_space")
        assert result is not None, "Required property 'address_space' is missing"
        return result

    @builtins.property
    def radius_server_address(self) -> typing.Optional[builtins.str]:
        result = self._values.get("radius_server_address")
        return result

    @builtins.property
    def radius_server_secret(self) -> typing.Optional[builtins.str]:
        result = self._values.get("radius_server_secret")
        return result

    @builtins.property
    def revoked_certificate(
        self,
    ) -> typing.Optional[typing.List["VirtualNetworkGatewayVpnClientConfigurationRevokedCertificate"]]:
        """revoked_certificate block."""
        result = self._values.get("revoked_certificate")
        return result

    @builtins.property
    def root_certificate(
        self,
    ) -> typing.Optional[typing.List["VirtualNetworkGatewayVpnClientConfigurationRootCertificate"]]:
        """root_certificate block."""
        result = self._values.get("root_certificate")
        return result

    @builtins.property
    def vpn_client_protocols(self) -> typing.Optional[typing.List[builtins.str]]:
        result = self._values.get("vpn_client_protocols")
        return result

    def __eq__(self, rhs: typing.Any) -> builtins.bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs: typing.Any) -> builtins.bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return "VirtualNetworkGatewayVpnClientConfiguration(%s)" % ", ".join(
            k + "=" + repr(v) for k, v in self._values.items()
        )


@jsii.data_type(
    jsii_type="@cdktf/provider-azurerm.VirtualNetworkGatewayVpnClientConfigurationRevokedCertificate",
    jsii_struct_bases=[],
    name_mapping={"name": "name", "thumbprint": "thumbprint"},
)
class VirtualNetworkGatewayVpnClientConfigurationRevokedCertificate:
    def __init__(self, *, name: builtins.str, thumbprint: builtins.str) -> None:
        """
        :param name: 
        :param thumbprint: 
        """
        self._values: typing.Dict[str, typing.Any] = {
            "name": name,
            "thumbprint": thumbprint,
        }

    @builtins.property
    def name(self) -> builtins.str:
        result = self._values.get("name")
        assert result is not None, "Required property 'name' is missing"
        return result

    @builtins.property
    def thumbprint(self) -> builtins.str:
        result = self._values.get("thumbprint")
        assert result is not None, "Required property 'thumbprint' is missing"
        return result

    def __eq__(self, rhs: typing.Any) -> builtins.bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs: typing.Any) -> builtins.bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return "VirtualNetworkGatewayVpnClientConfigurationRevokedCertificate(%s)" % ", ".join(
            k + "=" + repr(v) for k, v in self._values.items()
        )


@jsii.data_type(
    jsii_type="@cdktf/provider-azurerm.VirtualNetworkGatewayVpnClientConfigurationRootCertificate",
    jsii_struct_bases=[],
    name_mapping={"name": "name", "public_cert_data": "publicCertData"},
)
class VirtualNetworkGatewayVpnClientConfigurationRootCertificate:
    def __init__(self, *, name: builtins.str, public_cert_data: builtins.str) -> None:
        """
        :param name: 
        :param public_cert_data: 
        """
        self._values: typing.Dict[str, typing.Any] = {
            "name": name,
            "public_cert_data": public_cert_data,
        }

    @builtins.property
    def name(self) -> builtins.str:
        result = self._values.get("name")
        assert result is not None, "Required property 'name' is missing"
        return result

    @builtins.property
    def public_cert_data(self) -> builtins.str:
        result = self._values.get("public_cert_data")
        assert result is not None, "Required property 'public_cert_data' is missing"
        return result

    def __eq__(self, rhs: typing.Any) -> builtins.bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs: typing.Any) -> builtins.bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return "VirtualNetworkGatewayVpnClientConfigurationRootCertificate(%s)" % ", ".join(
            k + "=" + repr(v) for k, v in self._values.items()
        )


class VirtualNetworkPeering(
    cdktf.TerraformResource,
    metaclass=jsii.JSIIMeta,
    jsii_type="@cdktf/provider-azurerm.VirtualNetworkPeering",
):
    def __init__(
        self,
        scope: constructs.Construct,
        id: builtins.str,
        *,
        name: builtins.str,
        remote_virtual_network_id: builtins.str,
        resource_group_name: builtins.str,
        virtual_network_name: builtins.str,
        allow_forwarded_traffic: typing.Optional[builtins.bool] = None,
        allow_gateway_transit: typing.Optional[builtins.bool] = None,
        allow_virtual_network_access: typing.Optional[builtins.bool] = None,
        timeouts: typing.Optional["VirtualNetworkPeeringTimeouts"] = None,
        use_remote_gateways: typing.Optional[builtins.bool] = None,
        count: typing.Optional[jsii.Number] = None,
        depends_on: typing.Optional[typing.List[cdktf.TerraformResource]] = None,
        lifecycle: typing.Optional[cdktf.TerraformResourceLifecycle] = None,
        provider: typing.Optional[cdktf.TerraformProvider] = None,
    ) -> None:
        """
        :param scope: -
        :param id: -
        :param name: 
        :param remote_virtual_network_id: 
        :param resource_group_name: 
        :param virtual_network_name: 
        :param allow_forwarded_traffic: 
        :param allow_gateway_transit: 
        :param allow_virtual_network_access: 
        :param timeouts: timeouts block.
        :param use_remote_gateways: 
        :param count: 
        :param depends_on: 
        :param lifecycle: 
        :param provider: 
        """
        config = VirtualNetworkPeeringConfig(
            name=name,
            remote_virtual_network_id=remote_virtual_network_id,
            resource_group_name=resource_group_name,
            virtual_network_name=virtual_network_name,
            allow_forwarded_traffic=allow_forwarded_traffic,
            allow_gateway_transit=allow_gateway_transit,
            allow_virtual_network_access=allow_virtual_network_access,
            timeouts=timeouts,
            use_remote_gateways=use_remote_gateways,
            count=count,
            depends_on=depends_on,
            lifecycle=lifecycle,
            provider=provider,
        )

        jsii.create(VirtualNetworkPeering, self, [scope, id, config])

    @jsii.member(jsii_name="synthesizeAttributes")
    def _synthesize_attributes(self) -> typing.Mapping[builtins.str, typing.Any]:
        return jsii.invoke(self, "synthesizeAttributes", [])

    @builtins.property # type: ignore
    @jsii.member(jsii_name="name")
    def name(self) -> builtins.str:
        return jsii.get(self, "name")

    @name.setter # type: ignore
    def name(self, value: builtins.str) -> None:
        jsii.set(self, "name", value)

    @builtins.property # type: ignore
    @jsii.member(jsii_name="remoteVirtualNetworkId")
    def remote_virtual_network_id(self) -> builtins.str:
        return jsii.get(self, "remoteVirtualNetworkId")

    @remote_virtual_network_id.setter # type: ignore
    def remote_virtual_network_id(self, value: builtins.str) -> None:
        jsii.set(self, "remoteVirtualNetworkId", value)

    @builtins.property # type: ignore
    @jsii.member(jsii_name="resourceGroupName")
    def resource_group_name(self) -> builtins.str:
        return jsii.get(self, "resourceGroupName")

    @resource_group_name.setter # type: ignore
    def resource_group_name(self, value: builtins.str) -> None:
        jsii.set(self, "resourceGroupName", value)

    @builtins.property # type: ignore
    @jsii.member(jsii_name="virtualNetworkName")
    def virtual_network_name(self) -> builtins.str:
        return jsii.get(self, "virtualNetworkName")

    @virtual_network_name.setter # type: ignore
    def virtual_network_name(self, value: builtins.str) -> None:
        jsii.set(self, "virtualNetworkName", value)

    @builtins.property # type: ignore
    @jsii.member(jsii_name="allowForwardedTraffic")
    def allow_forwarded_traffic(self) -> typing.Optional[builtins.bool]:
        return jsii.get(self, "allowForwardedTraffic")

    @allow_forwarded_traffic.setter # type: ignore
    def allow_forwarded_traffic(self, value: typing.Optional[builtins.bool]) -> None:
        jsii.set(self, "allowForwardedTraffic", value)

    @builtins.property # type: ignore
    @jsii.member(jsii_name="allowGatewayTransit")
    def allow_gateway_transit(self) -> typing.Optional[builtins.bool]:
        return jsii.get(self, "allowGatewayTransit")

    @allow_gateway_transit.setter # type: ignore
    def allow_gateway_transit(self, value: typing.Optional[builtins.bool]) -> None:
        jsii.set(self, "allowGatewayTransit", value)

    @builtins.property # type: ignore
    @jsii.member(jsii_name="allowVirtualNetworkAccess")
    def allow_virtual_network_access(self) -> typing.Optional[builtins.bool]:
        return jsii.get(self, "allowVirtualNetworkAccess")

    @allow_virtual_network_access.setter # type: ignore
    def allow_virtual_network_access(
        self,
        value: typing.Optional[builtins.bool],
    ) -> None:
        jsii.set(self, "allowVirtualNetworkAccess", value)

    @builtins.property # type: ignore
    @jsii.member(jsii_name="id")
    def id(self) -> typing.Optional[builtins.str]:
        return jsii.get(self, "id")

    @id.setter # type: ignore
    def id(self, value: typing.Optional[builtins.str]) -> None:
        jsii.set(self, "id", value)

    @builtins.property # type: ignore
    @jsii.member(jsii_name="timeouts")
    def timeouts(self) -> typing.Optional["VirtualNetworkPeeringTimeouts"]:
        return jsii.get(self, "timeouts")

    @timeouts.setter # type: ignore
    def timeouts(self, value: typing.Optional["VirtualNetworkPeeringTimeouts"]) -> None:
        jsii.set(self, "timeouts", value)

    @builtins.property # type: ignore
    @jsii.member(jsii_name="useRemoteGateways")
    def use_remote_gateways(self) -> typing.Optional[builtins.bool]:
        return jsii.get(self, "useRemoteGateways")

    @use_remote_gateways.setter # type: ignore
    def use_remote_gateways(self, value: typing.Optional[builtins.bool]) -> None:
        jsii.set(self, "useRemoteGateways", value)


@jsii.data_type(
    jsii_type="@cdktf/provider-azurerm.VirtualNetworkPeeringConfig",
    jsii_struct_bases=[cdktf.TerraformMetaArguments],
    name_mapping={
        "count": "count",
        "depends_on": "dependsOn",
        "lifecycle": "lifecycle",
        "provider": "provider",
        "name": "name",
        "remote_virtual_network_id": "remoteVirtualNetworkId",
        "resource_group_name": "resourceGroupName",
        "virtual_network_name": "virtualNetworkName",
        "allow_forwarded_traffic": "allowForwardedTraffic",
        "allow_gateway_transit": "allowGatewayTransit",
        "allow_virtual_network_access": "allowVirtualNetworkAccess",
        "timeouts": "timeouts",
        "use_remote_gateways": "useRemoteGateways",
    },
)
class VirtualNetworkPeeringConfig(cdktf.TerraformMetaArguments):
    def __init__(
        self,
        *,
        count: typing.Optional[jsii.Number] = None,
        depends_on: typing.Optional[typing.List[cdktf.TerraformResource]] = None,
        lifecycle: typing.Optional[cdktf.TerraformResourceLifecycle] = None,
        provider: typing.Optional[cdktf.TerraformProvider] = None,
        name: builtins.str,
        remote_virtual_network_id: builtins.str,
        resource_group_name: builtins.str,
        virtual_network_name: builtins.str,
        allow_forwarded_traffic: typing.Optional[builtins.bool] = None,
        allow_gateway_transit: typing.Optional[builtins.bool] = None,
        allow_virtual_network_access: typing.Optional[builtins.bool] = None,
        timeouts: typing.Optional["VirtualNetworkPeeringTimeouts"] = None,
        use_remote_gateways: typing.Optional[builtins.bool] = None,
    ) -> None:
        """
        :param count: 
        :param depends_on: 
        :param lifecycle: 
        :param provider: 
        :param name: 
        :param remote_virtual_network_id: 
        :param resource_group_name: 
        :param virtual_network_name: 
        :param allow_forwarded_traffic: 
        :param allow_gateway_transit: 
        :param allow_virtual_network_access: 
        :param timeouts: timeouts block.
        :param use_remote_gateways: 
        """
        if isinstance(lifecycle, dict):
            lifecycle = cdktf.TerraformResourceLifecycle(**lifecycle)
        if isinstance(timeouts, dict):
            timeouts = VirtualNetworkPeeringTimeouts(**timeouts)
        self._values: typing.Dict[str, typing.Any] = {
            "name": name,
            "remote_virtual_network_id": remote_virtual_network_id,
            "resource_group_name": resource_group_name,
            "virtual_network_name": virtual_network_name,
        }
        if count is not None:
            self._values["count"] = count
        if depends_on is not None:
            self._values["depends_on"] = depends_on
        if lifecycle is not None:
            self._values["lifecycle"] = lifecycle
        if provider is not None:
            self._values["provider"] = provider
        if allow_forwarded_traffic is not None:
            self._values["allow_forwarded_traffic"] = allow_forwarded_traffic
        if allow_gateway_transit is not None:
            self._values["allow_gateway_transit"] = allow_gateway_transit
        if allow_virtual_network_access is not None:
            self._values["allow_virtual_network_access"] = allow_virtual_network_access
        if timeouts is not None:
            self._values["timeouts"] = timeouts
        if use_remote_gateways is not None:
            self._values["use_remote_gateways"] = use_remote_gateways

    @builtins.property
    def count(self) -> typing.Optional[jsii.Number]:
        """
        :stability: experimental
        """
        result = self._values.get("count")
        return result

    @builtins.property
    def depends_on(self) -> typing.Optional[typing.List[cdktf.TerraformResource]]:
        """
        :stability: experimental
        """
        result = self._values.get("depends_on")
        return result

    @builtins.property
    def lifecycle(self) -> typing.Optional[cdktf.TerraformResourceLifecycle]:
        """
        :stability: experimental
        """
        result = self._values.get("lifecycle")
        return result

    @builtins.property
    def provider(self) -> typing.Optional[cdktf.TerraformProvider]:
        """
        :stability: experimental
        """
        result = self._values.get("provider")
        return result

    @builtins.property
    def name(self) -> builtins.str:
        result = self._values.get("name")
        assert result is not None, "Required property 'name' is missing"
        return result

    @builtins.property
    def remote_virtual_network_id(self) -> builtins.str:
        result = self._values.get("remote_virtual_network_id")
        assert result is not None, "Required property 'remote_virtual_network_id' is missing"
        return result

    @builtins.property
    def resource_group_name(self) -> builtins.str:
        result = self._values.get("resource_group_name")
        assert result is not None, "Required property 'resource_group_name' is missing"
        return result

    @builtins.property
    def virtual_network_name(self) -> builtins.str:
        result = self._values.get("virtual_network_name")
        assert result is not None, "Required property 'virtual_network_name' is missing"
        return result

    @builtins.property
    def allow_forwarded_traffic(self) -> typing.Optional[builtins.bool]:
        result = self._values.get("allow_forwarded_traffic")
        return result

    @builtins.property
    def allow_gateway_transit(self) -> typing.Optional[builtins.bool]:
        result = self._values.get("allow_gateway_transit")
        return result

    @builtins.property
    def allow_virtual_network_access(self) -> typing.Optional[builtins.bool]:
        result = self._values.get("allow_virtual_network_access")
        return result

    @builtins.property
    def timeouts(self) -> typing.Optional["VirtualNetworkPeeringTimeouts"]:
        """timeouts block."""
        result = self._values.get("timeouts")
        return result

    @builtins.property
    def use_remote_gateways(self) -> typing.Optional[builtins.bool]:
        result = self._values.get("use_remote_gateways")
        return result

    def __eq__(self, rhs: typing.Any) -> builtins.bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs: typing.Any) -> builtins.bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return "VirtualNetworkPeeringConfig(%s)" % ", ".join(
            k + "=" + repr(v) for k, v in self._values.items()
        )


@jsii.data_type(
    jsii_type="@cdktf/provider-azurerm.VirtualNetworkPeeringTimeouts",
    jsii_struct_bases=[],
    name_mapping={
        "create": "create",
        "delete": "delete",
        "read": "read",
        "update": "update",
    },
)
class VirtualNetworkPeeringTimeouts:
    def __init__(
        self,
        *,
        create: typing.Optional[builtins.str] = None,
        delete: typing.Optional[builtins.str] = None,
        read: typing.Optional[builtins.str] = None,
        update: typing.Optional[builtins.str] = None,
    ) -> None:
        """
        :param create: 
        :param delete: 
        :param read: 
        :param update: 
        """
        self._values: typing.Dict[str, typing.Any] = {}
        if create is not None:
            self._values["create"] = create
        if delete is not None:
            self._values["delete"] = delete
        if read is not None:
            self._values["read"] = read
        if update is not None:
            self._values["update"] = update

    @builtins.property
    def create(self) -> typing.Optional[builtins.str]:
        result = self._values.get("create")
        return result

    @builtins.property
    def delete(self) -> typing.Optional[builtins.str]:
        result = self._values.get("delete")
        return result

    @builtins.property
    def read(self) -> typing.Optional[builtins.str]:
        result = self._values.get("read")
        return result

    @builtins.property
    def update(self) -> typing.Optional[builtins.str]:
        result = self._values.get("update")
        return result

    def __eq__(self, rhs: typing.Any) -> builtins.bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs: typing.Any) -> builtins.bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return "VirtualNetworkPeeringTimeouts(%s)" % ", ".join(
            k + "=" + repr(v) for k, v in self._values.items()
        )


@jsii.data_type(
    jsii_type="@cdktf/provider-azurerm.VirtualNetworkSubnet",
    jsii_struct_bases=[],
    name_mapping={
        "address_prefix": "addressPrefix",
        "name": "name",
        "security_group": "securityGroup",
    },
)
class VirtualNetworkSubnet:
    def __init__(
        self,
        *,
        address_prefix: builtins.str,
        name: builtins.str,
        security_group: typing.Optional[builtins.str] = None,
    ) -> None:
        """
        :param address_prefix: 
        :param name: 
        :param security_group: 
        """
        self._values: typing.Dict[str, typing.Any] = {
            "address_prefix": address_prefix,
            "name": name,
        }
        if security_group is not None:
            self._values["security_group"] = security_group

    @builtins.property
    def address_prefix(self) -> builtins.str:
        result = self._values.get("address_prefix")
        assert result is not None, "Required property 'address_prefix' is missing"
        return result

    @builtins.property
    def name(self) -> builtins.str:
        result = self._values.get("name")
        assert result is not None, "Required property 'name' is missing"
        return result

    @builtins.property
    def security_group(self) -> typing.Optional[builtins.str]:
        result = self._values.get("security_group")
        return result

    def __eq__(self, rhs: typing.Any) -> builtins.bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs: typing.Any) -> builtins.bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return "VirtualNetworkSubnet(%s)" % ", ".join(
            k + "=" + repr(v) for k, v in self._values.items()
        )


@jsii.data_type(
    jsii_type="@cdktf/provider-azurerm.VirtualNetworkTimeouts",
    jsii_struct_bases=[],
    name_mapping={
        "create": "create",
        "delete": "delete",
        "read": "read",
        "update": "update",
    },
)
class VirtualNetworkTimeouts:
    def __init__(
        self,
        *,
        create: typing.Optional[builtins.str] = None,
        delete: typing.Optional[builtins.str] = None,
        read: typing.Optional[builtins.str] = None,
        update: typing.Optional[builtins.str] = None,
    ) -> None:
        """
        :param create: 
        :param delete: 
        :param read: 
        :param update: 
        """
        self._values: typing.Dict[str, typing.Any] = {}
        if create is not None:
            self._values["create"] = create
        if delete is not None:
            self._values["delete"] = delete
        if read is not None:
            self._values["read"] = read
        if update is not None:
            self._values["update"] = update

    @builtins.property
    def create(self) -> typing.Optional[builtins.str]:
        result = self._values.get("create")
        return result

    @builtins.property
    def delete(self) -> typing.Optional[builtins.str]:
        result = self._values.get("delete")
        return result

    @builtins.property
    def read(self) -> typing.Optional[builtins.str]:
        result = self._values.get("read")
        return result

    @builtins.property
    def update(self) -> typing.Optional[builtins.str]:
        result = self._values.get("update")
        return result

    def __eq__(self, rhs: typing.Any) -> builtins.bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs: typing.Any) -> builtins.bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return "VirtualNetworkTimeouts(%s)" % ", ".join(
            k + "=" + repr(v) for k, v in self._values.items()
        )


class VirtualWan(
    cdktf.TerraformResource,
    metaclass=jsii.JSIIMeta,
    jsii_type="@cdktf/provider-azurerm.VirtualWan",
):
    def __init__(
        self,
        scope: constructs.Construct,
        id: builtins.str,
        *,
        location: builtins.str,
        name: builtins.str,
        resource_group_name: builtins.str,
        allow_branch_to_branch_traffic: typing.Optional[builtins.bool] = None,
        allow_vnet_to_vnet_traffic: typing.Optional[builtins.bool] = None,
        disable_vpn_encryption: typing.Optional[builtins.bool] = None,
        office365_local_breakout_category: typing.Optional[builtins.str] = None,
        tags: typing.Optional[typing.Mapping[builtins.str, builtins.str]] = None,
        timeouts: typing.Optional["VirtualWanTimeouts"] = None,
        count: typing.Optional[jsii.Number] = None,
        depends_on: typing.Optional[typing.List[cdktf.TerraformResource]] = None,
        lifecycle: typing.Optional[cdktf.TerraformResourceLifecycle] = None,
        provider: typing.Optional[cdktf.TerraformProvider] = None,
    ) -> None:
        """
        :param scope: -
        :param id: -
        :param location: 
        :param name: 
        :param resource_group_name: 
        :param allow_branch_to_branch_traffic: 
        :param allow_vnet_to_vnet_traffic: 
        :param disable_vpn_encryption: 
        :param office365_local_breakout_category: 
        :param tags: 
        :param timeouts: timeouts block.
        :param count: 
        :param depends_on: 
        :param lifecycle: 
        :param provider: 
        """
        config = VirtualWanConfig(
            location=location,
            name=name,
            resource_group_name=resource_group_name,
            allow_branch_to_branch_traffic=allow_branch_to_branch_traffic,
            allow_vnet_to_vnet_traffic=allow_vnet_to_vnet_traffic,
            disable_vpn_encryption=disable_vpn_encryption,
            office365_local_breakout_category=office365_local_breakout_category,
            tags=tags,
            timeouts=timeouts,
            count=count,
            depends_on=depends_on,
            lifecycle=lifecycle,
            provider=provider,
        )

        jsii.create(VirtualWan, self, [scope, id, config])

    @jsii.member(jsii_name="synthesizeAttributes")
    def _synthesize_attributes(self) -> typing.Mapping[builtins.str, typing.Any]:
        return jsii.invoke(self, "synthesizeAttributes", [])

    @builtins.property # type: ignore
    @jsii.member(jsii_name="location")
    def location(self) -> builtins.str:
        return jsii.get(self, "location")

    @location.setter # type: ignore
    def location(self, value: builtins.str) -> None:
        jsii.set(self, "location", value)

    @builtins.property # type: ignore
    @jsii.member(jsii_name="name")
    def name(self) -> builtins.str:
        return jsii.get(self, "name")

    @name.setter # type: ignore
    def name(self, value: builtins.str) -> None:
        jsii.set(self, "name", value)

    @builtins.property # type: ignore
    @jsii.member(jsii_name="resourceGroupName")
    def resource_group_name(self) -> builtins.str:
        return jsii.get(self, "resourceGroupName")

    @resource_group_name.setter # type: ignore
    def resource_group_name(self, value: builtins.str) -> None:
        jsii.set(self, "resourceGroupName", value)

    @builtins.property # type: ignore
    @jsii.member(jsii_name="allowBranchToBranchTraffic")
    def allow_branch_to_branch_traffic(self) -> typing.Optional[builtins.bool]:
        return jsii.get(self, "allowBranchToBranchTraffic")

    @allow_branch_to_branch_traffic.setter # type: ignore
    def allow_branch_to_branch_traffic(
        self,
        value: typing.Optional[builtins.bool],
    ) -> None:
        jsii.set(self, "allowBranchToBranchTraffic", value)

    @builtins.property # type: ignore
    @jsii.member(jsii_name="allowVnetToVnetTraffic")
    def allow_vnet_to_vnet_traffic(self) -> typing.Optional[builtins.bool]:
        return jsii.get(self, "allowVnetToVnetTraffic")

    @allow_vnet_to_vnet_traffic.setter # type: ignore
    def allow_vnet_to_vnet_traffic(self, value: typing.Optional[builtins.bool]) -> None:
        jsii.set(self, "allowVnetToVnetTraffic", value)

    @builtins.property # type: ignore
    @jsii.member(jsii_name="disableVpnEncryption")
    def disable_vpn_encryption(self) -> typing.Optional[builtins.bool]:
        return jsii.get(self, "disableVpnEncryption")

    @disable_vpn_encryption.setter # type: ignore
    def disable_vpn_encryption(self, value: typing.Optional[builtins.bool]) -> None:
        jsii.set(self, "disableVpnEncryption", value)

    @builtins.property # type: ignore
    @jsii.member(jsii_name="id")
    def id(self) -> typing.Optional[builtins.str]:
        return jsii.get(self, "id")

    @id.setter # type: ignore
    def id(self, value: typing.Optional[builtins.str]) -> None:
        jsii.set(self, "id", value)

    @builtins.property # type: ignore
    @jsii.member(jsii_name="office365LocalBreakoutCategory")
    def office365_local_breakout_category(self) -> typing.Optional[builtins.str]:
        return jsii.get(self, "office365LocalBreakoutCategory")

    @office365_local_breakout_category.setter # type: ignore
    def office365_local_breakout_category(
        self,
        value: typing.Optional[builtins.str],
    ) -> None:
        jsii.set(self, "office365LocalBreakoutCategory", value)

    @builtins.property # type: ignore
    @jsii.member(jsii_name="tags")
    def tags(self) -> typing.Optional[typing.Mapping[builtins.str, builtins.str]]:
        return jsii.get(self, "tags")

    @tags.setter # type: ignore
    def tags(
        self,
        value: typing.Optional[typing.Mapping[builtins.str, builtins.str]],
    ) -> None:
        jsii.set(self, "tags", value)

    @builtins.property # type: ignore
    @jsii.member(jsii_name="timeouts")
    def timeouts(self) -> typing.Optional["VirtualWanTimeouts"]:
        return jsii.get(self, "timeouts")

    @timeouts.setter # type: ignore
    def timeouts(self, value: typing.Optional["VirtualWanTimeouts"]) -> None:
        jsii.set(self, "timeouts", value)


@jsii.data_type(
    jsii_type="@cdktf/provider-azurerm.VirtualWanConfig",
    jsii_struct_bases=[cdktf.TerraformMetaArguments],
    name_mapping={
        "count": "count",
        "depends_on": "dependsOn",
        "lifecycle": "lifecycle",
        "provider": "provider",
        "location": "location",
        "name": "name",
        "resource_group_name": "resourceGroupName",
        "allow_branch_to_branch_traffic": "allowBranchToBranchTraffic",
        "allow_vnet_to_vnet_traffic": "allowVnetToVnetTraffic",
        "disable_vpn_encryption": "disableVpnEncryption",
        "office365_local_breakout_category": "office365LocalBreakoutCategory",
        "tags": "tags",
        "timeouts": "timeouts",
    },
)
class VirtualWanConfig(cdktf.TerraformMetaArguments):
    def __init__(
        self,
        *,
        count: typing.Optional[jsii.Number] = None,
        depends_on: typing.Optional[typing.List[cdktf.TerraformResource]] = None,
        lifecycle: typing.Optional[cdktf.TerraformResourceLifecycle] = None,
        provider: typing.Optional[cdktf.TerraformProvider] = None,
        location: builtins.str,
        name: builtins.str,
        resource_group_name: builtins.str,
        allow_branch_to_branch_traffic: typing.Optional[builtins.bool] = None,
        allow_vnet_to_vnet_traffic: typing.Optional[builtins.bool] = None,
        disable_vpn_encryption: typing.Optional[builtins.bool] = None,
        office365_local_breakout_category: typing.Optional[builtins.str] = None,
        tags: typing.Optional[typing.Mapping[builtins.str, builtins.str]] = None,
        timeouts: typing.Optional["VirtualWanTimeouts"] = None,
    ) -> None:
        """
        :param count: 
        :param depends_on: 
        :param lifecycle: 
        :param provider: 
        :param location: 
        :param name: 
        :param resource_group_name: 
        :param allow_branch_to_branch_traffic: 
        :param allow_vnet_to_vnet_traffic: 
        :param disable_vpn_encryption: 
        :param office365_local_breakout_category: 
        :param tags: 
        :param timeouts: timeouts block.
        """
        if isinstance(lifecycle, dict):
            lifecycle = cdktf.TerraformResourceLifecycle(**lifecycle)
        if isinstance(timeouts, dict):
            timeouts = VirtualWanTimeouts(**timeouts)
        self._values: typing.Dict[str, typing.Any] = {
            "location": location,
            "name": name,
            "resource_group_name": resource_group_name,
        }
        if count is not None:
            self._values["count"] = count
        if depends_on is not None:
            self._values["depends_on"] = depends_on
        if lifecycle is not None:
            self._values["lifecycle"] = lifecycle
        if provider is not None:
            self._values["provider"] = provider
        if allow_branch_to_branch_traffic is not None:
            self._values["allow_branch_to_branch_traffic"] = allow_branch_to_branch_traffic
        if allow_vnet_to_vnet_traffic is not None:
            self._values["allow_vnet_to_vnet_traffic"] = allow_vnet_to_vnet_traffic
        if disable_vpn_encryption is not None:
            self._values["disable_vpn_encryption"] = disable_vpn_encryption
        if office365_local_breakout_category is not None:
            self._values["office365_local_breakout_category"] = office365_local_breakout_category
        if tags is not None:
            self._values["tags"] = tags
        if timeouts is not None:
            self._values["timeouts"] = timeouts

    @builtins.property
    def count(self) -> typing.Optional[jsii.Number]:
        """
        :stability: experimental
        """
        result = self._values.get("count")
        return result

    @builtins.property
    def depends_on(self) -> typing.Optional[typing.List[cdktf.TerraformResource]]:
        """
        :stability: experimental
        """
        result = self._values.get("depends_on")
        return result

    @builtins.property
    def lifecycle(self) -> typing.Optional[cdktf.TerraformResourceLifecycle]:
        """
        :stability: experimental
        """
        result = self._values.get("lifecycle")
        return result

    @builtins.property
    def provider(self) -> typing.Optional[cdktf.TerraformProvider]:
        """
        :stability: experimental
        """
        result = self._values.get("provider")
        return result

    @builtins.property
    def location(self) -> builtins.str:
        result = self._values.get("location")
        assert result is not None, "Required property 'location' is missing"
        return result

    @builtins.property
    def name(self) -> builtins.str:
        result = self._values.get("name")
        assert result is not None, "Required property 'name' is missing"
        return result

    @builtins.property
    def resource_group_name(self) -> builtins.str:
        result = self._values.get("resource_group_name")
        assert result is not None, "Required property 'resource_group_name' is missing"
        return result

    @builtins.property
    def allow_branch_to_branch_traffic(self) -> typing.Optional[builtins.bool]:
        result = self._values.get("allow_branch_to_branch_traffic")
        return result

    @builtins.property
    def allow_vnet_to_vnet_traffic(self) -> typing.Optional[builtins.bool]:
        result = self._values.get("allow_vnet_to_vnet_traffic")
        return result

    @builtins.property
    def disable_vpn_encryption(self) -> typing.Optional[builtins.bool]:
        result = self._values.get("disable_vpn_encryption")
        return result

    @builtins.property
    def office365_local_breakout_category(self) -> typing.Optional[builtins.str]:
        result = self._values.get("office365_local_breakout_category")
        return result

    @builtins.property
    def tags(self) -> typing.Optional[typing.Mapping[builtins.str, builtins.str]]:
        result = self._values.get("tags")
        return result

    @builtins.property
    def timeouts(self) -> typing.Optional["VirtualWanTimeouts"]:
        """timeouts block."""
        result = self._values.get("timeouts")
        return result

    def __eq__(self, rhs: typing.Any) -> builtins.bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs: typing.Any) -> builtins.bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return "VirtualWanConfig(%s)" % ", ".join(
            k + "=" + repr(v) for k, v in self._values.items()
        )


@jsii.data_type(
    jsii_type="@cdktf/provider-azurerm.VirtualWanTimeouts",
    jsii_struct_bases=[],
    name_mapping={
        "create": "create",
        "delete": "delete",
        "read": "read",
        "update": "update",
    },
)
class VirtualWanTimeouts:
    def __init__(
        self,
        *,
        create: typing.Optional[builtins.str] = None,
        delete: typing.Optional[builtins.str] = None,
        read: typing.Optional[builtins.str] = None,
        update: typing.Optional[builtins.str] = None,
    ) -> None:
        """
        :param create: 
        :param delete: 
        :param read: 
        :param update: 
        """
        self._values: typing.Dict[str, typing.Any] = {}
        if create is not None:
            self._values["create"] = create
        if delete is not None:
            self._values["delete"] = delete
        if read is not None:
            self._values["read"] = read
        if update is not None:
            self._values["update"] = update

    @builtins.property
    def create(self) -> typing.Optional[builtins.str]:
        result = self._values.get("create")
        return result

    @builtins.property
    def delete(self) -> typing.Optional[builtins.str]:
        result = self._values.get("delete")
        return result

    @builtins.property
    def read(self) -> typing.Optional[builtins.str]:
        result = self._values.get("read")
        return result

    @builtins.property
    def update(self) -> typing.Optional[builtins.str]:
        result = self._values.get("update")
        return result

    def __eq__(self, rhs: typing.Any) -> builtins.bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs: typing.Any) -> builtins.bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return "VirtualWanTimeouts(%s)" % ", ".join(
            k + "=" + repr(v) for k, v in self._values.items()
        )


class VpnGateway(
    cdktf.TerraformResource,
    metaclass=jsii.JSIIMeta,
    jsii_type="@cdktf/provider-azurerm.VpnGateway",
):
    def __init__(
        self,
        scope: constructs.Construct,
        id: builtins.str,
        *,
        location: builtins.str,
        name: builtins.str,
        resource_group_name: builtins.str,
        virtual_hub_id: builtins.str,
        bgp_settings: typing.Optional[typing.List["VpnGatewayBgpSettings"]] = None,
        scale_unit: typing.Optional[jsii.Number] = None,
        tags: typing.Optional[typing.Mapping[builtins.str, builtins.str]] = None,
        timeouts: typing.Optional["VpnGatewayTimeouts"] = None,
        count: typing.Optional[jsii.Number] = None,
        depends_on: typing.Optional[typing.List[cdktf.TerraformResource]] = None,
        lifecycle: typing.Optional[cdktf.TerraformResourceLifecycle] = None,
        provider: typing.Optional[cdktf.TerraformProvider] = None,
    ) -> None:
        """
        :param scope: -
        :param id: -
        :param location: 
        :param name: 
        :param resource_group_name: 
        :param virtual_hub_id: 
        :param bgp_settings: bgp_settings block.
        :param scale_unit: 
        :param tags: 
        :param timeouts: timeouts block.
        :param count: 
        :param depends_on: 
        :param lifecycle: 
        :param provider: 
        """
        config = VpnGatewayConfig(
            location=location,
            name=name,
            resource_group_name=resource_group_name,
            virtual_hub_id=virtual_hub_id,
            bgp_settings=bgp_settings,
            scale_unit=scale_unit,
            tags=tags,
            timeouts=timeouts,
            count=count,
            depends_on=depends_on,
            lifecycle=lifecycle,
            provider=provider,
        )

        jsii.create(VpnGateway, self, [scope, id, config])

    @jsii.member(jsii_name="synthesizeAttributes")
    def _synthesize_attributes(self) -> typing.Mapping[builtins.str, typing.Any]:
        return jsii.invoke(self, "synthesizeAttributes", [])

    @builtins.property # type: ignore
    @jsii.member(jsii_name="location")
    def location(self) -> builtins.str:
        return jsii.get(self, "location")

    @location.setter # type: ignore
    def location(self, value: builtins.str) -> None:
        jsii.set(self, "location", value)

    @builtins.property # type: ignore
    @jsii.member(jsii_name="name")
    def name(self) -> builtins.str:
        return jsii.get(self, "name")

    @name.setter # type: ignore
    def name(self, value: builtins.str) -> None:
        jsii.set(self, "name", value)

    @builtins.property # type: ignore
    @jsii.member(jsii_name="resourceGroupName")
    def resource_group_name(self) -> builtins.str:
        return jsii.get(self, "resourceGroupName")

    @resource_group_name.setter # type: ignore
    def resource_group_name(self, value: builtins.str) -> None:
        jsii.set(self, "resourceGroupName", value)

    @builtins.property # type: ignore
    @jsii.member(jsii_name="virtualHubId")
    def virtual_hub_id(self) -> builtins.str:
        return jsii.get(self, "virtualHubId")

    @virtual_hub_id.setter # type: ignore
    def virtual_hub_id(self, value: builtins.str) -> None:
        jsii.set(self, "virtualHubId", value)

    @builtins.property # type: ignore
    @jsii.member(jsii_name="bgpSettings")
    def bgp_settings(self) -> typing.Optional[typing.List["VpnGatewayBgpSettings"]]:
        return jsii.get(self, "bgpSettings")

    @bgp_settings.setter # type: ignore
    def bgp_settings(
        self,
        value: typing.Optional[typing.List["VpnGatewayBgpSettings"]],
    ) -> None:
        jsii.set(self, "bgpSettings", value)

    @builtins.property # type: ignore
    @jsii.member(jsii_name="id")
    def id(self) -> typing.Optional[builtins.str]:
        return jsii.get(self, "id")

    @id.setter # type: ignore
    def id(self, value: typing.Optional[builtins.str]) -> None:
        jsii.set(self, "id", value)

    @builtins.property # type: ignore
    @jsii.member(jsii_name="scaleUnit")
    def scale_unit(self) -> typing.Optional[jsii.Number]:
        return jsii.get(self, "scaleUnit")

    @scale_unit.setter # type: ignore
    def scale_unit(self, value: typing.Optional[jsii.Number]) -> None:
        jsii.set(self, "scaleUnit", value)

    @builtins.property # type: ignore
    @jsii.member(jsii_name="tags")
    def tags(self) -> typing.Optional[typing.Mapping[builtins.str, builtins.str]]:
        return jsii.get(self, "tags")

    @tags.setter # type: ignore
    def tags(
        self,
        value: typing.Optional[typing.Mapping[builtins.str, builtins.str]],
    ) -> None:
        jsii.set(self, "tags", value)

    @builtins.property # type: ignore
    @jsii.member(jsii_name="timeouts")
    def timeouts(self) -> typing.Optional["VpnGatewayTimeouts"]:
        return jsii.get(self, "timeouts")

    @timeouts.setter # type: ignore
    def timeouts(self, value: typing.Optional["VpnGatewayTimeouts"]) -> None:
        jsii.set(self, "timeouts", value)


@jsii.data_type(
    jsii_type="@cdktf/provider-azurerm.VpnGatewayBgpSettings",
    jsii_struct_bases=[],
    name_mapping={"asn": "asn", "peer_weight": "peerWeight"},
)
class VpnGatewayBgpSettings:
    def __init__(self, *, asn: jsii.Number, peer_weight: jsii.Number) -> None:
        """
        :param asn: 
        :param peer_weight: 
        """
        self._values: typing.Dict[str, typing.Any] = {
            "asn": asn,
            "peer_weight": peer_weight,
        }

    @builtins.property
    def asn(self) -> jsii.Number:
        result = self._values.get("asn")
        assert result is not None, "Required property 'asn' is missing"
        return result

    @builtins.property
    def peer_weight(self) -> jsii.Number:
        result = self._values.get("peer_weight")
        assert result is not None, "Required property 'peer_weight' is missing"
        return result

    def __eq__(self, rhs: typing.Any) -> builtins.bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs: typing.Any) -> builtins.bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return "VpnGatewayBgpSettings(%s)" % ", ".join(
            k + "=" + repr(v) for k, v in self._values.items()
        )


@jsii.data_type(
    jsii_type="@cdktf/provider-azurerm.VpnGatewayConfig",
    jsii_struct_bases=[cdktf.TerraformMetaArguments],
    name_mapping={
        "count": "count",
        "depends_on": "dependsOn",
        "lifecycle": "lifecycle",
        "provider": "provider",
        "location": "location",
        "name": "name",
        "resource_group_name": "resourceGroupName",
        "virtual_hub_id": "virtualHubId",
        "bgp_settings": "bgpSettings",
        "scale_unit": "scaleUnit",
        "tags": "tags",
        "timeouts": "timeouts",
    },
)
class VpnGatewayConfig(cdktf.TerraformMetaArguments):
    def __init__(
        self,
        *,
        count: typing.Optional[jsii.Number] = None,
        depends_on: typing.Optional[typing.List[cdktf.TerraformResource]] = None,
        lifecycle: typing.Optional[cdktf.TerraformResourceLifecycle] = None,
        provider: typing.Optional[cdktf.TerraformProvider] = None,
        location: builtins.str,
        name: builtins.str,
        resource_group_name: builtins.str,
        virtual_hub_id: builtins.str,
        bgp_settings: typing.Optional[typing.List[VpnGatewayBgpSettings]] = None,
        scale_unit: typing.Optional[jsii.Number] = None,
        tags: typing.Optional[typing.Mapping[builtins.str, builtins.str]] = None,
        timeouts: typing.Optional["VpnGatewayTimeouts"] = None,
    ) -> None:
        """
        :param count: 
        :param depends_on: 
        :param lifecycle: 
        :param provider: 
        :param location: 
        :param name: 
        :param resource_group_name: 
        :param virtual_hub_id: 
        :param bgp_settings: bgp_settings block.
        :param scale_unit: 
        :param tags: 
        :param timeouts: timeouts block.
        """
        if isinstance(lifecycle, dict):
            lifecycle = cdktf.TerraformResourceLifecycle(**lifecycle)
        if isinstance(timeouts, dict):
            timeouts = VpnGatewayTimeouts(**timeouts)
        self._values: typing.Dict[str, typing.Any] = {
            "location": location,
            "name": name,
            "resource_group_name": resource_group_name,
            "virtual_hub_id": virtual_hub_id,
        }
        if count is not None:
            self._values["count"] = count
        if depends_on is not None:
            self._values["depends_on"] = depends_on
        if lifecycle is not None:
            self._values["lifecycle"] = lifecycle
        if provider is not None:
            self._values["provider"] = provider
        if bgp_settings is not None:
            self._values["bgp_settings"] = bgp_settings
        if scale_unit is not None:
            self._values["scale_unit"] = scale_unit
        if tags is not None:
            self._values["tags"] = tags
        if timeouts is not None:
            self._values["timeouts"] = timeouts

    @builtins.property
    def count(self) -> typing.Optional[jsii.Number]:
        """
        :stability: experimental
        """
        result = self._values.get("count")
        return result

    @builtins.property
    def depends_on(self) -> typing.Optional[typing.List[cdktf.TerraformResource]]:
        """
        :stability: experimental
        """
        result = self._values.get("depends_on")
        return result

    @builtins.property
    def lifecycle(self) -> typing.Optional[cdktf.TerraformResourceLifecycle]:
        """
        :stability: experimental
        """
        result = self._values.get("lifecycle")
        return result

    @builtins.property
    def provider(self) -> typing.Optional[cdktf.TerraformProvider]:
        """
        :stability: experimental
        """
        result = self._values.get("provider")
        return result

    @builtins.property
    def location(self) -> builtins.str:
        result = self._values.get("location")
        assert result is not None, "Required property 'location' is missing"
        return result

    @builtins.property
    def name(self) -> builtins.str:
        result = self._values.get("name")
        assert result is not None, "Required property 'name' is missing"
        return result

    @builtins.property
    def resource_group_name(self) -> builtins.str:
        result = self._values.get("resource_group_name")
        assert result is not None, "Required property 'resource_group_name' is missing"
        return result

    @builtins.property
    def virtual_hub_id(self) -> builtins.str:
        result = self._values.get("virtual_hub_id")
        assert result is not None, "Required property 'virtual_hub_id' is missing"
        return result

    @builtins.property
    def bgp_settings(self) -> typing.Optional[typing.List[VpnGatewayBgpSettings]]:
        """bgp_settings block."""
        result = self._values.get("bgp_settings")
        return result

    @builtins.property
    def scale_unit(self) -> typing.Optional[jsii.Number]:
        result = self._values.get("scale_unit")
        return result

    @builtins.property
    def tags(self) -> typing.Optional[typing.Mapping[builtins.str, builtins.str]]:
        result = self._values.get("tags")
        return result

    @builtins.property
    def timeouts(self) -> typing.Optional["VpnGatewayTimeouts"]:
        """timeouts block."""
        result = self._values.get("timeouts")
        return result

    def __eq__(self, rhs: typing.Any) -> builtins.bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs: typing.Any) -> builtins.bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return "VpnGatewayConfig(%s)" % ", ".join(
            k + "=" + repr(v) for k, v in self._values.items()
        )


@jsii.data_type(
    jsii_type="@cdktf/provider-azurerm.VpnGatewayTimeouts",
    jsii_struct_bases=[],
    name_mapping={
        "create": "create",
        "delete": "delete",
        "read": "read",
        "update": "update",
    },
)
class VpnGatewayTimeouts:
    def __init__(
        self,
        *,
        create: typing.Optional[builtins.str] = None,
        delete: typing.Optional[builtins.str] = None,
        read: typing.Optional[builtins.str] = None,
        update: typing.Optional[builtins.str] = None,
    ) -> None:
        """
        :param create: 
        :param delete: 
        :param read: 
        :param update: 
        """
        self._values: typing.Dict[str, typing.Any] = {}
        if create is not None:
            self._values["create"] = create
        if delete is not None:
            self._values["delete"] = delete
        if read is not None:
            self._values["read"] = read
        if update is not None:
            self._values["update"] = update

    @builtins.property
    def create(self) -> typing.Optional[builtins.str]:
        result = self._values.get("create")
        return result

    @builtins.property
    def delete(self) -> typing.Optional[builtins.str]:
        result = self._values.get("delete")
        return result

    @builtins.property
    def read(self) -> typing.Optional[builtins.str]:
        result = self._values.get("read")
        return result

    @builtins.property
    def update(self) -> typing.Optional[builtins.str]:
        result = self._values.get("update")
        return result

    def __eq__(self, rhs: typing.Any) -> builtins.bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs: typing.Any) -> builtins.bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return "VpnGatewayTimeouts(%s)" % ", ".join(
            k + "=" + repr(v) for k, v in self._values.items()
        )


class VpnServerConfiguration(
    cdktf.TerraformResource,
    metaclass=jsii.JSIIMeta,
    jsii_type="@cdktf/provider-azurerm.VpnServerConfiguration",
):
    def __init__(
        self,
        scope: constructs.Construct,
        id: builtins.str,
        *,
        location: builtins.str,
        name: builtins.str,
        resource_group_name: builtins.str,
        vpn_authentication_types: typing.List[builtins.str],
        azure_active_directory_authentication: typing.Optional[typing.List["VpnServerConfigurationAzureActiveDirectoryAuthentication"]] = None,
        client_revoked_certificate: typing.Optional[typing.List["VpnServerConfigurationClientRevokedCertificate"]] = None,
        client_root_certificate: typing.Optional[typing.List["VpnServerConfigurationClientRootCertificate"]] = None,
        ipsec_policy: typing.Optional[typing.List["VpnServerConfigurationIpsecPolicy"]] = None,
        radius_server: typing.Optional[typing.List["VpnServerConfigurationRadiusServer"]] = None,
        tags: typing.Optional[typing.Mapping[builtins.str, builtins.str]] = None,
        timeouts: typing.Optional["VpnServerConfigurationTimeouts"] = None,
        vpn_protocols: typing.Optional[typing.List[builtins.str]] = None,
        count: typing.Optional[jsii.Number] = None,
        depends_on: typing.Optional[typing.List[cdktf.TerraformResource]] = None,
        lifecycle: typing.Optional[cdktf.TerraformResourceLifecycle] = None,
        provider: typing.Optional[cdktf.TerraformProvider] = None,
    ) -> None:
        """
        :param scope: -
        :param id: -
        :param location: 
        :param name: 
        :param resource_group_name: 
        :param vpn_authentication_types: 
        :param azure_active_directory_authentication: azure_active_directory_authentication block.
        :param client_revoked_certificate: client_revoked_certificate block.
        :param client_root_certificate: client_root_certificate block.
        :param ipsec_policy: ipsec_policy block.
        :param radius_server: radius_server block.
        :param tags: 
        :param timeouts: timeouts block.
        :param vpn_protocols: 
        :param count: 
        :param depends_on: 
        :param lifecycle: 
        :param provider: 
        """
        config = VpnServerConfigurationConfig(
            location=location,
            name=name,
            resource_group_name=resource_group_name,
            vpn_authentication_types=vpn_authentication_types,
            azure_active_directory_authentication=azure_active_directory_authentication,
            client_revoked_certificate=client_revoked_certificate,
            client_root_certificate=client_root_certificate,
            ipsec_policy=ipsec_policy,
            radius_server=radius_server,
            tags=tags,
            timeouts=timeouts,
            vpn_protocols=vpn_protocols,
            count=count,
            depends_on=depends_on,
            lifecycle=lifecycle,
            provider=provider,
        )

        jsii.create(VpnServerConfiguration, self, [scope, id, config])

    @jsii.member(jsii_name="synthesizeAttributes")
    def _synthesize_attributes(self) -> typing.Mapping[builtins.str, typing.Any]:
        return jsii.invoke(self, "synthesizeAttributes", [])

    @builtins.property # type: ignore
    @jsii.member(jsii_name="location")
    def location(self) -> builtins.str:
        return jsii.get(self, "location")

    @location.setter # type: ignore
    def location(self, value: builtins.str) -> None:
        jsii.set(self, "location", value)

    @builtins.property # type: ignore
    @jsii.member(jsii_name="name")
    def name(self) -> builtins.str:
        return jsii.get(self, "name")

    @name.setter # type: ignore
    def name(self, value: builtins.str) -> None:
        jsii.set(self, "name", value)

    @builtins.property # type: ignore
    @jsii.member(jsii_name="resourceGroupName")
    def resource_group_name(self) -> builtins.str:
        return jsii.get(self, "resourceGroupName")

    @resource_group_name.setter # type: ignore
    def resource_group_name(self, value: builtins.str) -> None:
        jsii.set(self, "resourceGroupName", value)

    @builtins.property # type: ignore
    @jsii.member(jsii_name="vpnAuthenticationTypes")
    def vpn_authentication_types(self) -> typing.List[builtins.str]:
        return jsii.get(self, "vpnAuthenticationTypes")

    @vpn_authentication_types.setter # type: ignore
    def vpn_authentication_types(self, value: typing.List[builtins.str]) -> None:
        jsii.set(self, "vpnAuthenticationTypes", value)

    @builtins.property # type: ignore
    @jsii.member(jsii_name="azureActiveDirectoryAuthentication")
    def azure_active_directory_authentication(
        self,
    ) -> typing.Optional[typing.List["VpnServerConfigurationAzureActiveDirectoryAuthentication"]]:
        return jsii.get(self, "azureActiveDirectoryAuthentication")

    @azure_active_directory_authentication.setter # type: ignore
    def azure_active_directory_authentication(
        self,
        value: typing.Optional[typing.List["VpnServerConfigurationAzureActiveDirectoryAuthentication"]],
    ) -> None:
        jsii.set(self, "azureActiveDirectoryAuthentication", value)

    @builtins.property # type: ignore
    @jsii.member(jsii_name="clientRevokedCertificate")
    def client_revoked_certificate(
        self,
    ) -> typing.Optional[typing.List["VpnServerConfigurationClientRevokedCertificate"]]:
        return jsii.get(self, "clientRevokedCertificate")

    @client_revoked_certificate.setter # type: ignore
    def client_revoked_certificate(
        self,
        value: typing.Optional[typing.List["VpnServerConfigurationClientRevokedCertificate"]],
    ) -> None:
        jsii.set(self, "clientRevokedCertificate", value)

    @builtins.property # type: ignore
    @jsii.member(jsii_name="clientRootCertificate")
    def client_root_certificate(
        self,
    ) -> typing.Optional[typing.List["VpnServerConfigurationClientRootCertificate"]]:
        return jsii.get(self, "clientRootCertificate")

    @client_root_certificate.setter # type: ignore
    def client_root_certificate(
        self,
        value: typing.Optional[typing.List["VpnServerConfigurationClientRootCertificate"]],
    ) -> None:
        jsii.set(self, "clientRootCertificate", value)

    @builtins.property # type: ignore
    @jsii.member(jsii_name="id")
    def id(self) -> typing.Optional[builtins.str]:
        return jsii.get(self, "id")

    @id.setter # type: ignore
    def id(self, value: typing.Optional[builtins.str]) -> None:
        jsii.set(self, "id", value)

    @builtins.property # type: ignore
    @jsii.member(jsii_name="ipsecPolicy")
    def ipsec_policy(
        self,
    ) -> typing.Optional[typing.List["VpnServerConfigurationIpsecPolicy"]]:
        return jsii.get(self, "ipsecPolicy")

    @ipsec_policy.setter # type: ignore
    def ipsec_policy(
        self,
        value: typing.Optional[typing.List["VpnServerConfigurationIpsecPolicy"]],
    ) -> None:
        jsii.set(self, "ipsecPolicy", value)

    @builtins.property # type: ignore
    @jsii.member(jsii_name="radiusServer")
    def radius_server(
        self,
    ) -> typing.Optional[typing.List["VpnServerConfigurationRadiusServer"]]:
        return jsii.get(self, "radiusServer")

    @radius_server.setter # type: ignore
    def radius_server(
        self,
        value: typing.Optional[typing.List["VpnServerConfigurationRadiusServer"]],
    ) -> None:
        jsii.set(self, "radiusServer", value)

    @builtins.property # type: ignore
    @jsii.member(jsii_name="tags")
    def tags(self) -> typing.Optional[typing.Mapping[builtins.str, builtins.str]]:
        return jsii.get(self, "tags")

    @tags.setter # type: ignore
    def tags(
        self,
        value: typing.Optional[typing.Mapping[builtins.str, builtins.str]],
    ) -> None:
        jsii.set(self, "tags", value)

    @builtins.property # type: ignore
    @jsii.member(jsii_name="timeouts")
    def timeouts(self) -> typing.Optional["VpnServerConfigurationTimeouts"]:
        return jsii.get(self, "timeouts")

    @timeouts.setter # type: ignore
    def timeouts(
        self,
        value: typing.Optional["VpnServerConfigurationTimeouts"],
    ) -> None:
        jsii.set(self, "timeouts", value)

    @builtins.property # type: ignore
    @jsii.member(jsii_name="vpnProtocols")
    def vpn_protocols(self) -> typing.Optional[typing.List[builtins.str]]:
        return jsii.get(self, "vpnProtocols")

    @vpn_protocols.setter # type: ignore
    def vpn_protocols(self, value: typing.Optional[typing.List[builtins.str]]) -> None:
        jsii.set(self, "vpnProtocols", value)


@jsii.data_type(
    jsii_type="@cdktf/provider-azurerm.VpnServerConfigurationAzureActiveDirectoryAuthentication",
    jsii_struct_bases=[],
    name_mapping={"audience": "audience", "issuer": "issuer", "tenant": "tenant"},
)
class VpnServerConfigurationAzureActiveDirectoryAuthentication:
    def __init__(
        self,
        *,
        audience: builtins.str,
        issuer: builtins.str,
        tenant: builtins.str,
    ) -> None:
        """
        :param audience: 
        :param issuer: 
        :param tenant: 
        """
        self._values: typing.Dict[str, typing.Any] = {
            "audience": audience,
            "issuer": issuer,
            "tenant": tenant,
        }

    @builtins.property
    def audience(self) -> builtins.str:
        result = self._values.get("audience")
        assert result is not None, "Required property 'audience' is missing"
        return result

    @builtins.property
    def issuer(self) -> builtins.str:
        result = self._values.get("issuer")
        assert result is not None, "Required property 'issuer' is missing"
        return result

    @builtins.property
    def tenant(self) -> builtins.str:
        result = self._values.get("tenant")
        assert result is not None, "Required property 'tenant' is missing"
        return result

    def __eq__(self, rhs: typing.Any) -> builtins.bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs: typing.Any) -> builtins.bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return "VpnServerConfigurationAzureActiveDirectoryAuthentication(%s)" % ", ".join(
            k + "=" + repr(v) for k, v in self._values.items()
        )


@jsii.data_type(
    jsii_type="@cdktf/provider-azurerm.VpnServerConfigurationClientRevokedCertificate",
    jsii_struct_bases=[],
    name_mapping={"name": "name", "thumbprint": "thumbprint"},
)
class VpnServerConfigurationClientRevokedCertificate:
    def __init__(self, *, name: builtins.str, thumbprint: builtins.str) -> None:
        """
        :param name: 
        :param thumbprint: 
        """
        self._values: typing.Dict[str, typing.Any] = {
            "name": name,
            "thumbprint": thumbprint,
        }

    @builtins.property
    def name(self) -> builtins.str:
        result = self._values.get("name")
        assert result is not None, "Required property 'name' is missing"
        return result

    @builtins.property
    def thumbprint(self) -> builtins.str:
        result = self._values.get("thumbprint")
        assert result is not None, "Required property 'thumbprint' is missing"
        return result

    def __eq__(self, rhs: typing.Any) -> builtins.bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs: typing.Any) -> builtins.bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return "VpnServerConfigurationClientRevokedCertificate(%s)" % ", ".join(
            k + "=" + repr(v) for k, v in self._values.items()
        )


@jsii.data_type(
    jsii_type="@cdktf/provider-azurerm.VpnServerConfigurationClientRootCertificate",
    jsii_struct_bases=[],
    name_mapping={"name": "name", "public_cert_data": "publicCertData"},
)
class VpnServerConfigurationClientRootCertificate:
    def __init__(self, *, name: builtins.str, public_cert_data: builtins.str) -> None:
        """
        :param name: 
        :param public_cert_data: 
        """
        self._values: typing.Dict[str, typing.Any] = {
            "name": name,
            "public_cert_data": public_cert_data,
        }

    @builtins.property
    def name(self) -> builtins.str:
        result = self._values.get("name")
        assert result is not None, "Required property 'name' is missing"
        return result

    @builtins.property
    def public_cert_data(self) -> builtins.str:
        result = self._values.get("public_cert_data")
        assert result is not None, "Required property 'public_cert_data' is missing"
        return result

    def __eq__(self, rhs: typing.Any) -> builtins.bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs: typing.Any) -> builtins.bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return "VpnServerConfigurationClientRootCertificate(%s)" % ", ".join(
            k + "=" + repr(v) for k, v in self._values.items()
        )


@jsii.data_type(
    jsii_type="@cdktf/provider-azurerm.VpnServerConfigurationConfig",
    jsii_struct_bases=[cdktf.TerraformMetaArguments],
    name_mapping={
        "count": "count",
        "depends_on": "dependsOn",
        "lifecycle": "lifecycle",
        "provider": "provider",
        "location": "location",
        "name": "name",
        "resource_group_name": "resourceGroupName",
        "vpn_authentication_types": "vpnAuthenticationTypes",
        "azure_active_directory_authentication": "azureActiveDirectoryAuthentication",
        "client_revoked_certificate": "clientRevokedCertificate",
        "client_root_certificate": "clientRootCertificate",
        "ipsec_policy": "ipsecPolicy",
        "radius_server": "radiusServer",
        "tags": "tags",
        "timeouts": "timeouts",
        "vpn_protocols": "vpnProtocols",
    },
)
class VpnServerConfigurationConfig(cdktf.TerraformMetaArguments):
    def __init__(
        self,
        *,
        count: typing.Optional[jsii.Number] = None,
        depends_on: typing.Optional[typing.List[cdktf.TerraformResource]] = None,
        lifecycle: typing.Optional[cdktf.TerraformResourceLifecycle] = None,
        provider: typing.Optional[cdktf.TerraformProvider] = None,
        location: builtins.str,
        name: builtins.str,
        resource_group_name: builtins.str,
        vpn_authentication_types: typing.List[builtins.str],
        azure_active_directory_authentication: typing.Optional[typing.List[VpnServerConfigurationAzureActiveDirectoryAuthentication]] = None,
        client_revoked_certificate: typing.Optional[typing.List[VpnServerConfigurationClientRevokedCertificate]] = None,
        client_root_certificate: typing.Optional[typing.List[VpnServerConfigurationClientRootCertificate]] = None,
        ipsec_policy: typing.Optional[typing.List["VpnServerConfigurationIpsecPolicy"]] = None,
        radius_server: typing.Optional[typing.List["VpnServerConfigurationRadiusServer"]] = None,
        tags: typing.Optional[typing.Mapping[builtins.str, builtins.str]] = None,
        timeouts: typing.Optional["VpnServerConfigurationTimeouts"] = None,
        vpn_protocols: typing.Optional[typing.List[builtins.str]] = None,
    ) -> None:
        """
        :param count: 
        :param depends_on: 
        :param lifecycle: 
        :param provider: 
        :param location: 
        :param name: 
        :param resource_group_name: 
        :param vpn_authentication_types: 
        :param azure_active_directory_authentication: azure_active_directory_authentication block.
        :param client_revoked_certificate: client_revoked_certificate block.
        :param client_root_certificate: client_root_certificate block.
        :param ipsec_policy: ipsec_policy block.
        :param radius_server: radius_server block.
        :param tags: 
        :param timeouts: timeouts block.
        :param vpn_protocols: 
        """
        if isinstance(lifecycle, dict):
            lifecycle = cdktf.TerraformResourceLifecycle(**lifecycle)
        if isinstance(timeouts, dict):
            timeouts = VpnServerConfigurationTimeouts(**timeouts)
        self._values: typing.Dict[str, typing.Any] = {
            "location": location,
            "name": name,
            "resource_group_name": resource_group_name,
            "vpn_authentication_types": vpn_authentication_types,
        }
        if count is not None:
            self._values["count"] = count
        if depends_on is not None:
            self._values["depends_on"] = depends_on
        if lifecycle is not None:
            self._values["lifecycle"] = lifecycle
        if provider is not None:
            self._values["provider"] = provider
        if azure_active_directory_authentication is not None:
            self._values["azure_active_directory_authentication"] = azure_active_directory_authentication
        if client_revoked_certificate is not None:
            self._values["client_revoked_certificate"] = client_revoked_certificate
        if client_root_certificate is not None:
            self._values["client_root_certificate"] = client_root_certificate
        if ipsec_policy is not None:
            self._values["ipsec_policy"] = ipsec_policy
        if radius_server is not None:
            self._values["radius_server"] = radius_server
        if tags is not None:
            self._values["tags"] = tags
        if timeouts is not None:
            self._values["timeouts"] = timeouts
        if vpn_protocols is not None:
            self._values["vpn_protocols"] = vpn_protocols

    @builtins.property
    def count(self) -> typing.Optional[jsii.Number]:
        """
        :stability: experimental
        """
        result = self._values.get("count")
        return result

    @builtins.property
    def depends_on(self) -> typing.Optional[typing.List[cdktf.TerraformResource]]:
        """
        :stability: experimental
        """
        result = self._values.get("depends_on")
        return result

    @builtins.property
    def lifecycle(self) -> typing.Optional[cdktf.TerraformResourceLifecycle]:
        """
        :stability: experimental
        """
        result = self._values.get("lifecycle")
        return result

    @builtins.property
    def provider(self) -> typing.Optional[cdktf.TerraformProvider]:
        """
        :stability: experimental
        """
        result = self._values.get("provider")
        return result

    @builtins.property
    def location(self) -> builtins.str:
        result = self._values.get("location")
        assert result is not None, "Required property 'location' is missing"
        return result

    @builtins.property
    def name(self) -> builtins.str:
        result = self._values.get("name")
        assert result is not None, "Required property 'name' is missing"
        return result

    @builtins.property
    def resource_group_name(self) -> builtins.str:
        result = self._values.get("resource_group_name")
        assert result is not None, "Required property 'resource_group_name' is missing"
        return result

    @builtins.property
    def vpn_authentication_types(self) -> typing.List[builtins.str]:
        result = self._values.get("vpn_authentication_types")
        assert result is not None, "Required property 'vpn_authentication_types' is missing"
        return result

    @builtins.property
    def azure_active_directory_authentication(
        self,
    ) -> typing.Optional[typing.List[VpnServerConfigurationAzureActiveDirectoryAuthentication]]:
        """azure_active_directory_authentication block."""
        result = self._values.get("azure_active_directory_authentication")
        return result

    @builtins.property
    def client_revoked_certificate(
        self,
    ) -> typing.Optional[typing.List[VpnServerConfigurationClientRevokedCertificate]]:
        """client_revoked_certificate block."""
        result = self._values.get("client_revoked_certificate")
        return result

    @builtins.property
    def client_root_certificate(
        self,
    ) -> typing.Optional[typing.List[VpnServerConfigurationClientRootCertificate]]:
        """client_root_certificate block."""
        result = self._values.get("client_root_certificate")
        return result

    @builtins.property
    def ipsec_policy(
        self,
    ) -> typing.Optional[typing.List["VpnServerConfigurationIpsecPolicy"]]:
        """ipsec_policy block."""
        result = self._values.get("ipsec_policy")
        return result

    @builtins.property
    def radius_server(
        self,
    ) -> typing.Optional[typing.List["VpnServerConfigurationRadiusServer"]]:
        """radius_server block."""
        result = self._values.get("radius_server")
        return result

    @builtins.property
    def tags(self) -> typing.Optional[typing.Mapping[builtins.str, builtins.str]]:
        result = self._values.get("tags")
        return result

    @builtins.property
    def timeouts(self) -> typing.Optional["VpnServerConfigurationTimeouts"]:
        """timeouts block."""
        result = self._values.get("timeouts")
        return result

    @builtins.property
    def vpn_protocols(self) -> typing.Optional[typing.List[builtins.str]]:
        result = self._values.get("vpn_protocols")
        return result

    def __eq__(self, rhs: typing.Any) -> builtins.bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs: typing.Any) -> builtins.bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return "VpnServerConfigurationConfig(%s)" % ", ".join(
            k + "=" + repr(v) for k, v in self._values.items()
        )


@jsii.data_type(
    jsii_type="@cdktf/provider-azurerm.VpnServerConfigurationIpsecPolicy",
    jsii_struct_bases=[],
    name_mapping={
        "dh_group": "dhGroup",
        "ike_encryption": "ikeEncryption",
        "ike_integrity": "ikeIntegrity",
        "ipsec_encryption": "ipsecEncryption",
        "ipsec_integrity": "ipsecIntegrity",
        "pfs_group": "pfsGroup",
        "sa_data_size_kilobytes": "saDataSizeKilobytes",
        "sa_lifetime_seconds": "saLifetimeSeconds",
    },
)
class VpnServerConfigurationIpsecPolicy:
    def __init__(
        self,
        *,
        dh_group: builtins.str,
        ike_encryption: builtins.str,
        ike_integrity: builtins.str,
        ipsec_encryption: builtins.str,
        ipsec_integrity: builtins.str,
        pfs_group: builtins.str,
        sa_data_size_kilobytes: jsii.Number,
        sa_lifetime_seconds: jsii.Number,
    ) -> None:
        """
        :param dh_group: 
        :param ike_encryption: 
        :param ike_integrity: 
        :param ipsec_encryption: 
        :param ipsec_integrity: 
        :param pfs_group: 
        :param sa_data_size_kilobytes: 
        :param sa_lifetime_seconds: 
        """
        self._values: typing.Dict[str, typing.Any] = {
            "dh_group": dh_group,
            "ike_encryption": ike_encryption,
            "ike_integrity": ike_integrity,
            "ipsec_encryption": ipsec_encryption,
            "ipsec_integrity": ipsec_integrity,
            "pfs_group": pfs_group,
            "sa_data_size_kilobytes": sa_data_size_kilobytes,
            "sa_lifetime_seconds": sa_lifetime_seconds,
        }

    @builtins.property
    def dh_group(self) -> builtins.str:
        result = self._values.get("dh_group")
        assert result is not None, "Required property 'dh_group' is missing"
        return result

    @builtins.property
    def ike_encryption(self) -> builtins.str:
        result = self._values.get("ike_encryption")
        assert result is not None, "Required property 'ike_encryption' is missing"
        return result

    @builtins.property
    def ike_integrity(self) -> builtins.str:
        result = self._values.get("ike_integrity")
        assert result is not None, "Required property 'ike_integrity' is missing"
        return result

    @builtins.property
    def ipsec_encryption(self) -> builtins.str:
        result = self._values.get("ipsec_encryption")
        assert result is not None, "Required property 'ipsec_encryption' is missing"
        return result

    @builtins.property
    def ipsec_integrity(self) -> builtins.str:
        result = self._values.get("ipsec_integrity")
        assert result is not None, "Required property 'ipsec_integrity' is missing"
        return result

    @builtins.property
    def pfs_group(self) -> builtins.str:
        result = self._values.get("pfs_group")
        assert result is not None, "Required property 'pfs_group' is missing"
        return result

    @builtins.property
    def sa_data_size_kilobytes(self) -> jsii.Number:
        result = self._values.get("sa_data_size_kilobytes")
        assert result is not None, "Required property 'sa_data_size_kilobytes' is missing"
        return result

    @builtins.property
    def sa_lifetime_seconds(self) -> jsii.Number:
        result = self._values.get("sa_lifetime_seconds")
        assert result is not None, "Required property 'sa_lifetime_seconds' is missing"
        return result

    def __eq__(self, rhs: typing.Any) -> builtins.bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs: typing.Any) -> builtins.bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return "VpnServerConfigurationIpsecPolicy(%s)" % ", ".join(
            k + "=" + repr(v) for k, v in self._values.items()
        )


@jsii.data_type(
    jsii_type="@cdktf/provider-azurerm.VpnServerConfigurationRadiusServer",
    jsii_struct_bases=[],
    name_mapping={
        "address": "address",
        "secret": "secret",
        "server_root_certificate": "serverRootCertificate",
        "client_root_certificate": "clientRootCertificate",
    },
)
class VpnServerConfigurationRadiusServer:
    def __init__(
        self,
        *,
        address: builtins.str,
        secret: builtins.str,
        server_root_certificate: typing.List["VpnServerConfigurationRadiusServerServerRootCertificate"],
        client_root_certificate: typing.Optional[typing.List["VpnServerConfigurationRadiusServerClientRootCertificate"]] = None,
    ) -> None:
        """
        :param address: 
        :param secret: 
        :param server_root_certificate: server_root_certificate block.
        :param client_root_certificate: client_root_certificate block.
        """
        self._values: typing.Dict[str, typing.Any] = {
            "address": address,
            "secret": secret,
            "server_root_certificate": server_root_certificate,
        }
        if client_root_certificate is not None:
            self._values["client_root_certificate"] = client_root_certificate

    @builtins.property
    def address(self) -> builtins.str:
        result = self._values.get("address")
        assert result is not None, "Required property 'address' is missing"
        return result

    @builtins.property
    def secret(self) -> builtins.str:
        result = self._values.get("secret")
        assert result is not None, "Required property 'secret' is missing"
        return result

    @builtins.property
    def server_root_certificate(
        self,
    ) -> typing.List["VpnServerConfigurationRadiusServerServerRootCertificate"]:
        """server_root_certificate block."""
        result = self._values.get("server_root_certificate")
        assert result is not None, "Required property 'server_root_certificate' is missing"
        return result

    @builtins.property
    def client_root_certificate(
        self,
    ) -> typing.Optional[typing.List["VpnServerConfigurationRadiusServerClientRootCertificate"]]:
        """client_root_certificate block."""
        result = self._values.get("client_root_certificate")
        return result

    def __eq__(self, rhs: typing.Any) -> builtins.bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs: typing.Any) -> builtins.bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return "VpnServerConfigurationRadiusServer(%s)" % ", ".join(
            k + "=" + repr(v) for k, v in self._values.items()
        )


@jsii.data_type(
    jsii_type="@cdktf/provider-azurerm.VpnServerConfigurationRadiusServerClientRootCertificate",
    jsii_struct_bases=[],
    name_mapping={"name": "name", "thumbprint": "thumbprint"},
)
class VpnServerConfigurationRadiusServerClientRootCertificate:
    def __init__(self, *, name: builtins.str, thumbprint: builtins.str) -> None:
        """
        :param name: 
        :param thumbprint: 
        """
        self._values: typing.Dict[str, typing.Any] = {
            "name": name,
            "thumbprint": thumbprint,
        }

    @builtins.property
    def name(self) -> builtins.str:
        result = self._values.get("name")
        assert result is not None, "Required property 'name' is missing"
        return result

    @builtins.property
    def thumbprint(self) -> builtins.str:
        result = self._values.get("thumbprint")
        assert result is not None, "Required property 'thumbprint' is missing"
        return result

    def __eq__(self, rhs: typing.Any) -> builtins.bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs: typing.Any) -> builtins.bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return "VpnServerConfigurationRadiusServerClientRootCertificate(%s)" % ", ".join(
            k + "=" + repr(v) for k, v in self._values.items()
        )


@jsii.data_type(
    jsii_type="@cdktf/provider-azurerm.VpnServerConfigurationRadiusServerServerRootCertificate",
    jsii_struct_bases=[],
    name_mapping={"name": "name", "public_cert_data": "publicCertData"},
)
class VpnServerConfigurationRadiusServerServerRootCertificate:
    def __init__(self, *, name: builtins.str, public_cert_data: builtins.str) -> None:
        """
        :param name: 
        :param public_cert_data: 
        """
        self._values: typing.Dict[str, typing.Any] = {
            "name": name,
            "public_cert_data": public_cert_data,
        }

    @builtins.property
    def name(self) -> builtins.str:
        result = self._values.get("name")
        assert result is not None, "Required property 'name' is missing"
        return result

    @builtins.property
    def public_cert_data(self) -> builtins.str:
        result = self._values.get("public_cert_data")
        assert result is not None, "Required property 'public_cert_data' is missing"
        return result

    def __eq__(self, rhs: typing.Any) -> builtins.bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs: typing.Any) -> builtins.bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return "VpnServerConfigurationRadiusServerServerRootCertificate(%s)" % ", ".join(
            k + "=" + repr(v) for k, v in self._values.items()
        )


@jsii.data_type(
    jsii_type="@cdktf/provider-azurerm.VpnServerConfigurationTimeouts",
    jsii_struct_bases=[],
    name_mapping={
        "create": "create",
        "delete": "delete",
        "read": "read",
        "update": "update",
    },
)
class VpnServerConfigurationTimeouts:
    def __init__(
        self,
        *,
        create: typing.Optional[builtins.str] = None,
        delete: typing.Optional[builtins.str] = None,
        read: typing.Optional[builtins.str] = None,
        update: typing.Optional[builtins.str] = None,
    ) -> None:
        """
        :param create: 
        :param delete: 
        :param read: 
        :param update: 
        """
        self._values: typing.Dict[str, typing.Any] = {}
        if create is not None:
            self._values["create"] = create
        if delete is not None:
            self._values["delete"] = delete
        if read is not None:
            self._values["read"] = read
        if update is not None:
            self._values["update"] = update

    @builtins.property
    def create(self) -> typing.Optional[builtins.str]:
        result = self._values.get("create")
        return result

    @builtins.property
    def delete(self) -> typing.Optional[builtins.str]:
        result = self._values.get("delete")
        return result

    @builtins.property
    def read(self) -> typing.Optional[builtins.str]:
        result = self._values.get("read")
        return result

    @builtins.property
    def update(self) -> typing.Optional[builtins.str]:
        result = self._values.get("update")
        return result

    def __eq__(self, rhs: typing.Any) -> builtins.bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs: typing.Any) -> builtins.bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return "VpnServerConfigurationTimeouts(%s)" % ", ".join(
            k + "=" + repr(v) for k, v in self._values.items()
        )


class WebApplicationFirewallPolicy(
    cdktf.TerraformResource,
    metaclass=jsii.JSIIMeta,
    jsii_type="@cdktf/provider-azurerm.WebApplicationFirewallPolicy",
):
    def __init__(
        self,
        scope: constructs.Construct,
        id: builtins.str,
        *,
        location: builtins.str,
        name: builtins.str,
        resource_group_name: builtins.str,
        custom_rules: typing.Optional[typing.List["WebApplicationFirewallPolicyCustomRules"]] = None,
        policy_settings: typing.Optional[typing.List["WebApplicationFirewallPolicyPolicySettings"]] = None,
        tags: typing.Optional[typing.Mapping[builtins.str, builtins.str]] = None,
        timeouts: typing.Optional["WebApplicationFirewallPolicyTimeouts"] = None,
        count: typing.Optional[jsii.Number] = None,
        depends_on: typing.Optional[typing.List[cdktf.TerraformResource]] = None,
        lifecycle: typing.Optional[cdktf.TerraformResourceLifecycle] = None,
        provider: typing.Optional[cdktf.TerraformProvider] = None,
    ) -> None:
        """
        :param scope: -
        :param id: -
        :param location: 
        :param name: 
        :param resource_group_name: 
        :param custom_rules: custom_rules block.
        :param policy_settings: policy_settings block.
        :param tags: 
        :param timeouts: timeouts block.
        :param count: 
        :param depends_on: 
        :param lifecycle: 
        :param provider: 
        """
        config = WebApplicationFirewallPolicyConfig(
            location=location,
            name=name,
            resource_group_name=resource_group_name,
            custom_rules=custom_rules,
            policy_settings=policy_settings,
            tags=tags,
            timeouts=timeouts,
            count=count,
            depends_on=depends_on,
            lifecycle=lifecycle,
            provider=provider,
        )

        jsii.create(WebApplicationFirewallPolicy, self, [scope, id, config])

    @jsii.member(jsii_name="synthesizeAttributes")
    def _synthesize_attributes(self) -> typing.Mapping[builtins.str, typing.Any]:
        return jsii.invoke(self, "synthesizeAttributes", [])

    @builtins.property # type: ignore
    @jsii.member(jsii_name="location")
    def location(self) -> builtins.str:
        return jsii.get(self, "location")

    @location.setter # type: ignore
    def location(self, value: builtins.str) -> None:
        jsii.set(self, "location", value)

    @builtins.property # type: ignore
    @jsii.member(jsii_name="name")
    def name(self) -> builtins.str:
        return jsii.get(self, "name")

    @name.setter # type: ignore
    def name(self, value: builtins.str) -> None:
        jsii.set(self, "name", value)

    @builtins.property # type: ignore
    @jsii.member(jsii_name="resourceGroupName")
    def resource_group_name(self) -> builtins.str:
        return jsii.get(self, "resourceGroupName")

    @resource_group_name.setter # type: ignore
    def resource_group_name(self, value: builtins.str) -> None:
        jsii.set(self, "resourceGroupName", value)

    @builtins.property # type: ignore
    @jsii.member(jsii_name="customRules")
    def custom_rules(
        self,
    ) -> typing.Optional[typing.List["WebApplicationFirewallPolicyCustomRules"]]:
        return jsii.get(self, "customRules")

    @custom_rules.setter # type: ignore
    def custom_rules(
        self,
        value: typing.Optional[typing.List["WebApplicationFirewallPolicyCustomRules"]],
    ) -> None:
        jsii.set(self, "customRules", value)

    @builtins.property # type: ignore
    @jsii.member(jsii_name="id")
    def id(self) -> typing.Optional[builtins.str]:
        return jsii.get(self, "id")

    @id.setter # type: ignore
    def id(self, value: typing.Optional[builtins.str]) -> None:
        jsii.set(self, "id", value)

    @builtins.property # type: ignore
    @jsii.member(jsii_name="policySettings")
    def policy_settings(
        self,
    ) -> typing.Optional[typing.List["WebApplicationFirewallPolicyPolicySettings"]]:
        return jsii.get(self, "policySettings")

    @policy_settings.setter # type: ignore
    def policy_settings(
        self,
        value: typing.Optional[typing.List["WebApplicationFirewallPolicyPolicySettings"]],
    ) -> None:
        jsii.set(self, "policySettings", value)

    @builtins.property # type: ignore
    @jsii.member(jsii_name="tags")
    def tags(self) -> typing.Optional[typing.Mapping[builtins.str, builtins.str]]:
        return jsii.get(self, "tags")

    @tags.setter # type: ignore
    def tags(
        self,
        value: typing.Optional[typing.Mapping[builtins.str, builtins.str]],
    ) -> None:
        jsii.set(self, "tags", value)

    @builtins.property # type: ignore
    @jsii.member(jsii_name="timeouts")
    def timeouts(self) -> typing.Optional["WebApplicationFirewallPolicyTimeouts"]:
        return jsii.get(self, "timeouts")

    @timeouts.setter # type: ignore
    def timeouts(
        self,
        value: typing.Optional["WebApplicationFirewallPolicyTimeouts"],
    ) -> None:
        jsii.set(self, "timeouts", value)


@jsii.data_type(
    jsii_type="@cdktf/provider-azurerm.WebApplicationFirewallPolicyConfig",
    jsii_struct_bases=[cdktf.TerraformMetaArguments],
    name_mapping={
        "count": "count",
        "depends_on": "dependsOn",
        "lifecycle": "lifecycle",
        "provider": "provider",
        "location": "location",
        "name": "name",
        "resource_group_name": "resourceGroupName",
        "custom_rules": "customRules",
        "policy_settings": "policySettings",
        "tags": "tags",
        "timeouts": "timeouts",
    },
)
class WebApplicationFirewallPolicyConfig(cdktf.TerraformMetaArguments):
    def __init__(
        self,
        *,
        count: typing.Optional[jsii.Number] = None,
        depends_on: typing.Optional[typing.List[cdktf.TerraformResource]] = None,
        lifecycle: typing.Optional[cdktf.TerraformResourceLifecycle] = None,
        provider: typing.Optional[cdktf.TerraformProvider] = None,
        location: builtins.str,
        name: builtins.str,
        resource_group_name: builtins.str,
        custom_rules: typing.Optional[typing.List["WebApplicationFirewallPolicyCustomRules"]] = None,
        policy_settings: typing.Optional[typing.List["WebApplicationFirewallPolicyPolicySettings"]] = None,
        tags: typing.Optional[typing.Mapping[builtins.str, builtins.str]] = None,
        timeouts: typing.Optional["WebApplicationFirewallPolicyTimeouts"] = None,
    ) -> None:
        """
        :param count: 
        :param depends_on: 
        :param lifecycle: 
        :param provider: 
        :param location: 
        :param name: 
        :param resource_group_name: 
        :param custom_rules: custom_rules block.
        :param policy_settings: policy_settings block.
        :param tags: 
        :param timeouts: timeouts block.
        """
        if isinstance(lifecycle, dict):
            lifecycle = cdktf.TerraformResourceLifecycle(**lifecycle)
        if isinstance(timeouts, dict):
            timeouts = WebApplicationFirewallPolicyTimeouts(**timeouts)
        self._values: typing.Dict[str, typing.Any] = {
            "location": location,
            "name": name,
            "resource_group_name": resource_group_name,
        }
        if count is not None:
            self._values["count"] = count
        if depends_on is not None:
            self._values["depends_on"] = depends_on
        if lifecycle is not None:
            self._values["lifecycle"] = lifecycle
        if provider is not None:
            self._values["provider"] = provider
        if custom_rules is not None:
            self._values["custom_rules"] = custom_rules
        if policy_settings is not None:
            self._values["policy_settings"] = policy_settings
        if tags is not None:
            self._values["tags"] = tags
        if timeouts is not None:
            self._values["timeouts"] = timeouts

    @builtins.property
    def count(self) -> typing.Optional[jsii.Number]:
        """
        :stability: experimental
        """
        result = self._values.get("count")
        return result

    @builtins.property
    def depends_on(self) -> typing.Optional[typing.List[cdktf.TerraformResource]]:
        """
        :stability: experimental
        """
        result = self._values.get("depends_on")
        return result

    @builtins.property
    def lifecycle(self) -> typing.Optional[cdktf.TerraformResourceLifecycle]:
        """
        :stability: experimental
        """
        result = self._values.get("lifecycle")
        return result

    @builtins.property
    def provider(self) -> typing.Optional[cdktf.TerraformProvider]:
        """
        :stability: experimental
        """
        result = self._values.get("provider")
        return result

    @builtins.property
    def location(self) -> builtins.str:
        result = self._values.get("location")
        assert result is not None, "Required property 'location' is missing"
        return result

    @builtins.property
    def name(self) -> builtins.str:
        result = self._values.get("name")
        assert result is not None, "Required property 'name' is missing"
        return result

    @builtins.property
    def resource_group_name(self) -> builtins.str:
        result = self._values.get("resource_group_name")
        assert result is not None, "Required property 'resource_group_name' is missing"
        return result

    @builtins.property
    def custom_rules(
        self,
    ) -> typing.Optional[typing.List["WebApplicationFirewallPolicyCustomRules"]]:
        """custom_rules block."""
        result = self._values.get("custom_rules")
        return result

    @builtins.property
    def policy_settings(
        self,
    ) -> typing.Optional[typing.List["WebApplicationFirewallPolicyPolicySettings"]]:
        """policy_settings block."""
        result = self._values.get("policy_settings")
        return result

    @builtins.property
    def tags(self) -> typing.Optional[typing.Mapping[builtins.str, builtins.str]]:
        result = self._values.get("tags")
        return result

    @builtins.property
    def timeouts(self) -> typing.Optional["WebApplicationFirewallPolicyTimeouts"]:
        """timeouts block."""
        result = self._values.get("timeouts")
        return result

    def __eq__(self, rhs: typing.Any) -> builtins.bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs: typing.Any) -> builtins.bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return "WebApplicationFirewallPolicyConfig(%s)" % ", ".join(
            k + "=" + repr(v) for k, v in self._values.items()
        )


@jsii.data_type(
    jsii_type="@cdktf/provider-azurerm.WebApplicationFirewallPolicyCustomRules",
    jsii_struct_bases=[],
    name_mapping={
        "action": "action",
        "match_conditions": "matchConditions",
        "priority": "priority",
        "rule_type": "ruleType",
        "name": "name",
    },
)
class WebApplicationFirewallPolicyCustomRules:
    def __init__(
        self,
        *,
        action: builtins.str,
        match_conditions: typing.List["WebApplicationFirewallPolicyCustomRulesMatchConditions"],
        priority: jsii.Number,
        rule_type: builtins.str,
        name: typing.Optional[builtins.str] = None,
    ) -> None:
        """
        :param action: 
        :param match_conditions: match_conditions block.
        :param priority: 
        :param rule_type: 
        :param name: 
        """
        self._values: typing.Dict[str, typing.Any] = {
            "action": action,
            "match_conditions": match_conditions,
            "priority": priority,
            "rule_type": rule_type,
        }
        if name is not None:
            self._values["name"] = name

    @builtins.property
    def action(self) -> builtins.str:
        result = self._values.get("action")
        assert result is not None, "Required property 'action' is missing"
        return result

    @builtins.property
    def match_conditions(
        self,
    ) -> typing.List["WebApplicationFirewallPolicyCustomRulesMatchConditions"]:
        """match_conditions block."""
        result = self._values.get("match_conditions")
        assert result is not None, "Required property 'match_conditions' is missing"
        return result

    @builtins.property
    def priority(self) -> jsii.Number:
        result = self._values.get("priority")
        assert result is not None, "Required property 'priority' is missing"
        return result

    @builtins.property
    def rule_type(self) -> builtins.str:
        result = self._values.get("rule_type")
        assert result is not None, "Required property 'rule_type' is missing"
        return result

    @builtins.property
    def name(self) -> typing.Optional[builtins.str]:
        result = self._values.get("name")
        return result

    def __eq__(self, rhs: typing.Any) -> builtins.bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs: typing.Any) -> builtins.bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return "WebApplicationFirewallPolicyCustomRules(%s)" % ", ".join(
            k + "=" + repr(v) for k, v in self._values.items()
        )


@jsii.data_type(
    jsii_type="@cdktf/provider-azurerm.WebApplicationFirewallPolicyCustomRulesMatchConditions",
    jsii_struct_bases=[],
    name_mapping={
        "match_values": "matchValues",
        "match_variables": "matchVariables",
        "operator": "operator",
        "negation_condition": "negationCondition",
    },
)
class WebApplicationFirewallPolicyCustomRulesMatchConditions:
    def __init__(
        self,
        *,
        match_values: typing.List[builtins.str],
        match_variables: typing.List["WebApplicationFirewallPolicyCustomRulesMatchConditionsMatchVariables"],
        operator: builtins.str,
        negation_condition: typing.Optional[builtins.bool] = None,
    ) -> None:
        """
        :param match_values: 
        :param match_variables: match_variables block.
        :param operator: 
        :param negation_condition: 
        """
        self._values: typing.Dict[str, typing.Any] = {
            "match_values": match_values,
            "match_variables": match_variables,
            "operator": operator,
        }
        if negation_condition is not None:
            self._values["negation_condition"] = negation_condition

    @builtins.property
    def match_values(self) -> typing.List[builtins.str]:
        result = self._values.get("match_values")
        assert result is not None, "Required property 'match_values' is missing"
        return result

    @builtins.property
    def match_variables(
        self,
    ) -> typing.List["WebApplicationFirewallPolicyCustomRulesMatchConditionsMatchVariables"]:
        """match_variables block."""
        result = self._values.get("match_variables")
        assert result is not None, "Required property 'match_variables' is missing"
        return result

    @builtins.property
    def operator(self) -> builtins.str:
        result = self._values.get("operator")
        assert result is not None, "Required property 'operator' is missing"
        return result

    @builtins.property
    def negation_condition(self) -> typing.Optional[builtins.bool]:
        result = self._values.get("negation_condition")
        return result

    def __eq__(self, rhs: typing.Any) -> builtins.bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs: typing.Any) -> builtins.bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return "WebApplicationFirewallPolicyCustomRulesMatchConditions(%s)" % ", ".join(
            k + "=" + repr(v) for k, v in self._values.items()
        )


@jsii.data_type(
    jsii_type="@cdktf/provider-azurerm.WebApplicationFirewallPolicyCustomRulesMatchConditionsMatchVariables",
    jsii_struct_bases=[],
    name_mapping={"variable_name": "variableName", "selector": "selector"},
)
class WebApplicationFirewallPolicyCustomRulesMatchConditionsMatchVariables:
    def __init__(
        self,
        *,
        variable_name: builtins.str,
        selector: typing.Optional[builtins.str] = None,
    ) -> None:
        """
        :param variable_name: 
        :param selector: 
        """
        self._values: typing.Dict[str, typing.Any] = {
            "variable_name": variable_name,
        }
        if selector is not None:
            self._values["selector"] = selector

    @builtins.property
    def variable_name(self) -> builtins.str:
        result = self._values.get("variable_name")
        assert result is not None, "Required property 'variable_name' is missing"
        return result

    @builtins.property
    def selector(self) -> typing.Optional[builtins.str]:
        result = self._values.get("selector")
        return result

    def __eq__(self, rhs: typing.Any) -> builtins.bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs: typing.Any) -> builtins.bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return "WebApplicationFirewallPolicyCustomRulesMatchConditionsMatchVariables(%s)" % ", ".join(
            k + "=" + repr(v) for k, v in self._values.items()
        )


@jsii.data_type(
    jsii_type="@cdktf/provider-azurerm.WebApplicationFirewallPolicyPolicySettings",
    jsii_struct_bases=[],
    name_mapping={"enabled": "enabled", "mode": "mode"},
)
class WebApplicationFirewallPolicyPolicySettings:
    def __init__(
        self,
        *,
        enabled: typing.Optional[builtins.bool] = None,
        mode: typing.Optional[builtins.str] = None,
    ) -> None:
        """
        :param enabled: 
        :param mode: 
        """
        self._values: typing.Dict[str, typing.Any] = {}
        if enabled is not None:
            self._values["enabled"] = enabled
        if mode is not None:
            self._values["mode"] = mode

    @builtins.property
    def enabled(self) -> typing.Optional[builtins.bool]:
        result = self._values.get("enabled")
        return result

    @builtins.property
    def mode(self) -> typing.Optional[builtins.str]:
        result = self._values.get("mode")
        return result

    def __eq__(self, rhs: typing.Any) -> builtins.bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs: typing.Any) -> builtins.bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return "WebApplicationFirewallPolicyPolicySettings(%s)" % ", ".join(
            k + "=" + repr(v) for k, v in self._values.items()
        )


@jsii.data_type(
    jsii_type="@cdktf/provider-azurerm.WebApplicationFirewallPolicyTimeouts",
    jsii_struct_bases=[],
    name_mapping={
        "create": "create",
        "delete": "delete",
        "read": "read",
        "update": "update",
    },
)
class WebApplicationFirewallPolicyTimeouts:
    def __init__(
        self,
        *,
        create: typing.Optional[builtins.str] = None,
        delete: typing.Optional[builtins.str] = None,
        read: typing.Optional[builtins.str] = None,
        update: typing.Optional[builtins.str] = None,
    ) -> None:
        """
        :param create: 
        :param delete: 
        :param read: 
        :param update: 
        """
        self._values: typing.Dict[str, typing.Any] = {}
        if create is not None:
            self._values["create"] = create
        if delete is not None:
            self._values["delete"] = delete
        if read is not None:
            self._values["read"] = read
        if update is not None:
            self._values["update"] = update

    @builtins.property
    def create(self) -> typing.Optional[builtins.str]:
        result = self._values.get("create")
        return result

    @builtins.property
    def delete(self) -> typing.Optional[builtins.str]:
        result = self._values.get("delete")
        return result

    @builtins.property
    def read(self) -> typing.Optional[builtins.str]:
        result = self._values.get("read")
        return result

    @builtins.property
    def update(self) -> typing.Optional[builtins.str]:
        result = self._values.get("update")
        return result

    def __eq__(self, rhs: typing.Any) -> builtins.bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs: typing.Any) -> builtins.bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return "WebApplicationFirewallPolicyTimeouts(%s)" % ", ".join(
            k + "=" + repr(v) for k, v in self._values.items()
        )


class WindowsVirtualMachine(
    cdktf.TerraformResource,
    metaclass=jsii.JSIIMeta,
    jsii_type="@cdktf/provider-azurerm.WindowsVirtualMachine",
):
    def __init__(
        self,
        scope: constructs.Construct,
        id: builtins.str,
        *,
        admin_password: builtins.str,
        admin_username: builtins.str,
        location: builtins.str,
        name: builtins.str,
        network_interface_ids: typing.List[builtins.str],
        os_disk: typing.List["WindowsVirtualMachineOsDisk"],
        resource_group_name: builtins.str,
        size: builtins.str,
        additional_capabilities: typing.Optional[typing.List["WindowsVirtualMachineAdditionalCapabilities"]] = None,
        additional_unattend_content: typing.Optional[typing.List["WindowsVirtualMachineAdditionalUnattendContent"]] = None,
        allow_extension_operations: typing.Optional[builtins.bool] = None,
        availability_set_id: typing.Optional[builtins.str] = None,
        boot_diagnostics: typing.Optional[typing.List["WindowsVirtualMachineBootDiagnostics"]] = None,
        computer_name: typing.Optional[builtins.str] = None,
        custom_data: typing.Optional[builtins.str] = None,
        dedicated_host_id: typing.Optional[builtins.str] = None,
        enable_automatic_updates: typing.Optional[builtins.bool] = None,
        eviction_policy: typing.Optional[builtins.str] = None,
        identity: typing.Optional[typing.List["WindowsVirtualMachineIdentity"]] = None,
        license_type: typing.Optional[builtins.str] = None,
        max_bid_price: typing.Optional[jsii.Number] = None,
        plan: typing.Optional[typing.List["WindowsVirtualMachinePlan"]] = None,
        priority: typing.Optional[builtins.str] = None,
        provision_vm_agent: typing.Optional[builtins.bool] = None,
        proximity_placement_group_id: typing.Optional[builtins.str] = None,
        secret: typing.Optional[typing.List["WindowsVirtualMachineSecret"]] = None,
        source_image_id: typing.Optional[builtins.str] = None,
        source_image_reference: typing.Optional[typing.List["WindowsVirtualMachineSourceImageReference"]] = None,
        tags: typing.Optional[typing.Mapping[builtins.str, builtins.str]] = None,
        timeouts: typing.Optional["WindowsVirtualMachineTimeouts"] = None,
        timezone: typing.Optional[builtins.str] = None,
        winrm_listener: typing.Optional[typing.List["WindowsVirtualMachineWinrmListener"]] = None,
        zone: typing.Optional[builtins.str] = None,
        count: typing.Optional[jsii.Number] = None,
        depends_on: typing.Optional[typing.List[cdktf.TerraformResource]] = None,
        lifecycle: typing.Optional[cdktf.TerraformResourceLifecycle] = None,
        provider: typing.Optional[cdktf.TerraformProvider] = None,
    ) -> None:
        """
        :param scope: -
        :param id: -
        :param admin_password: 
        :param admin_username: 
        :param location: 
        :param name: 
        :param network_interface_ids: 
        :param os_disk: os_disk block.
        :param resource_group_name: 
        :param size: 
        :param additional_capabilities: additional_capabilities block.
        :param additional_unattend_content: additional_unattend_content block.
        :param allow_extension_operations: 
        :param availability_set_id: 
        :param boot_diagnostics: boot_diagnostics block.
        :param computer_name: 
        :param custom_data: 
        :param dedicated_host_id: 
        :param enable_automatic_updates: 
        :param eviction_policy: 
        :param identity: identity block.
        :param license_type: 
        :param max_bid_price: 
        :param plan: plan block.
        :param priority: 
        :param provision_vm_agent: 
        :param proximity_placement_group_id: 
        :param secret: secret block.
        :param source_image_id: 
        :param source_image_reference: source_image_reference block.
        :param tags: 
        :param timeouts: timeouts block.
        :param timezone: 
        :param winrm_listener: winrm_listener block.
        :param zone: 
        :param count: 
        :param depends_on: 
        :param lifecycle: 
        :param provider: 
        """
        config = WindowsVirtualMachineConfig(
            admin_password=admin_password,
            admin_username=admin_username,
            location=location,
            name=name,
            network_interface_ids=network_interface_ids,
            os_disk=os_disk,
            resource_group_name=resource_group_name,
            size=size,
            additional_capabilities=additional_capabilities,
            additional_unattend_content=additional_unattend_content,
            allow_extension_operations=allow_extension_operations,
            availability_set_id=availability_set_id,
            boot_diagnostics=boot_diagnostics,
            computer_name=computer_name,
            custom_data=custom_data,
            dedicated_host_id=dedicated_host_id,
            enable_automatic_updates=enable_automatic_updates,
            eviction_policy=eviction_policy,
            identity=identity,
            license_type=license_type,
            max_bid_price=max_bid_price,
            plan=plan,
            priority=priority,
            provision_vm_agent=provision_vm_agent,
            proximity_placement_group_id=proximity_placement_group_id,
            secret=secret,
            source_image_id=source_image_id,
            source_image_reference=source_image_reference,
            tags=tags,
            timeouts=timeouts,
            timezone=timezone,
            winrm_listener=winrm_listener,
            zone=zone,
            count=count,
            depends_on=depends_on,
            lifecycle=lifecycle,
            provider=provider,
        )

        jsii.create(WindowsVirtualMachine, self, [scope, id, config])

    @jsii.member(jsii_name="synthesizeAttributes")
    def _synthesize_attributes(self) -> typing.Mapping[builtins.str, typing.Any]:
        return jsii.invoke(self, "synthesizeAttributes", [])

    @builtins.property # type: ignore
    @jsii.member(jsii_name="privateIpAddress")
    def private_ip_address(self) -> builtins.str:
        return jsii.get(self, "privateIpAddress")

    @builtins.property # type: ignore
    @jsii.member(jsii_name="privateIpAddresses")
    def private_ip_addresses(self) -> typing.List[builtins.str]:
        return jsii.get(self, "privateIpAddresses")

    @builtins.property # type: ignore
    @jsii.member(jsii_name="publicIpAddress")
    def public_ip_address(self) -> builtins.str:
        return jsii.get(self, "publicIpAddress")

    @builtins.property # type: ignore
    @jsii.member(jsii_name="publicIpAddresses")
    def public_ip_addresses(self) -> typing.List[builtins.str]:
        return jsii.get(self, "publicIpAddresses")

    @builtins.property # type: ignore
    @jsii.member(jsii_name="virtualMachineId")
    def virtual_machine_id(self) -> builtins.str:
        return jsii.get(self, "virtualMachineId")

    @builtins.property # type: ignore
    @jsii.member(jsii_name="adminPassword")
    def admin_password(self) -> builtins.str:
        return jsii.get(self, "adminPassword")

    @admin_password.setter # type: ignore
    def admin_password(self, value: builtins.str) -> None:
        jsii.set(self, "adminPassword", value)

    @builtins.property # type: ignore
    @jsii.member(jsii_name="adminUsername")
    def admin_username(self) -> builtins.str:
        return jsii.get(self, "adminUsername")

    @admin_username.setter # type: ignore
    def admin_username(self, value: builtins.str) -> None:
        jsii.set(self, "adminUsername", value)

    @builtins.property # type: ignore
    @jsii.member(jsii_name="location")
    def location(self) -> builtins.str:
        return jsii.get(self, "location")

    @location.setter # type: ignore
    def location(self, value: builtins.str) -> None:
        jsii.set(self, "location", value)

    @builtins.property # type: ignore
    @jsii.member(jsii_name="name")
    def name(self) -> builtins.str:
        return jsii.get(self, "name")

    @name.setter # type: ignore
    def name(self, value: builtins.str) -> None:
        jsii.set(self, "name", value)

    @builtins.property # type: ignore
    @jsii.member(jsii_name="networkInterfaceIds")
    def network_interface_ids(self) -> typing.List[builtins.str]:
        return jsii.get(self, "networkInterfaceIds")

    @network_interface_ids.setter # type: ignore
    def network_interface_ids(self, value: typing.List[builtins.str]) -> None:
        jsii.set(self, "networkInterfaceIds", value)

    @builtins.property # type: ignore
    @jsii.member(jsii_name="osDisk")
    def os_disk(self) -> typing.List["WindowsVirtualMachineOsDisk"]:
        return jsii.get(self, "osDisk")

    @os_disk.setter # type: ignore
    def os_disk(self, value: typing.List["WindowsVirtualMachineOsDisk"]) -> None:
        jsii.set(self, "osDisk", value)

    @builtins.property # type: ignore
    @jsii.member(jsii_name="resourceGroupName")
    def resource_group_name(self) -> builtins.str:
        return jsii.get(self, "resourceGroupName")

    @resource_group_name.setter # type: ignore
    def resource_group_name(self, value: builtins.str) -> None:
        jsii.set(self, "resourceGroupName", value)

    @builtins.property # type: ignore
    @jsii.member(jsii_name="size")
    def size(self) -> builtins.str:
        return jsii.get(self, "size")

    @size.setter # type: ignore
    def size(self, value: builtins.str) -> None:
        jsii.set(self, "size", value)

    @builtins.property # type: ignore
    @jsii.member(jsii_name="additionalCapabilities")
    def additional_capabilities(
        self,
    ) -> typing.Optional[typing.List["WindowsVirtualMachineAdditionalCapabilities"]]:
        return jsii.get(self, "additionalCapabilities")

    @additional_capabilities.setter # type: ignore
    def additional_capabilities(
        self,
        value: typing.Optional[typing.List["WindowsVirtualMachineAdditionalCapabilities"]],
    ) -> None:
        jsii.set(self, "additionalCapabilities", value)

    @builtins.property # type: ignore
    @jsii.member(jsii_name="additionalUnattendContent")
    def additional_unattend_content(
        self,
    ) -> typing.Optional[typing.List["WindowsVirtualMachineAdditionalUnattendContent"]]:
        return jsii.get(self, "additionalUnattendContent")

    @additional_unattend_content.setter # type: ignore
    def additional_unattend_content(
        self,
        value: typing.Optional[typing.List["WindowsVirtualMachineAdditionalUnattendContent"]],
    ) -> None:
        jsii.set(self, "additionalUnattendContent", value)

    @builtins.property # type: ignore
    @jsii.member(jsii_name="allowExtensionOperations")
    def allow_extension_operations(self) -> typing.Optional[builtins.bool]:
        return jsii.get(self, "allowExtensionOperations")

    @allow_extension_operations.setter # type: ignore
    def allow_extension_operations(self, value: typing.Optional[builtins.bool]) -> None:
        jsii.set(self, "allowExtensionOperations", value)

    @builtins.property # type: ignore
    @jsii.member(jsii_name="availabilitySetId")
    def availability_set_id(self) -> typing.Optional[builtins.str]:
        return jsii.get(self, "availabilitySetId")

    @availability_set_id.setter # type: ignore
    def availability_set_id(self, value: typing.Optional[builtins.str]) -> None:
        jsii.set(self, "availabilitySetId", value)

    @builtins.property # type: ignore
    @jsii.member(jsii_name="bootDiagnostics")
    def boot_diagnostics(
        self,
    ) -> typing.Optional[typing.List["WindowsVirtualMachineBootDiagnostics"]]:
        return jsii.get(self, "bootDiagnostics")

    @boot_diagnostics.setter # type: ignore
    def boot_diagnostics(
        self,
        value: typing.Optional[typing.List["WindowsVirtualMachineBootDiagnostics"]],
    ) -> None:
        jsii.set(self, "bootDiagnostics", value)

    @builtins.property # type: ignore
    @jsii.member(jsii_name="computerName")
    def computer_name(self) -> typing.Optional[builtins.str]:
        return jsii.get(self, "computerName")

    @computer_name.setter # type: ignore
    def computer_name(self, value: typing.Optional[builtins.str]) -> None:
        jsii.set(self, "computerName", value)

    @builtins.property # type: ignore
    @jsii.member(jsii_name="customData")
    def custom_data(self) -> typing.Optional[builtins.str]:
        return jsii.get(self, "customData")

    @custom_data.setter # type: ignore
    def custom_data(self, value: typing.Optional[builtins.str]) -> None:
        jsii.set(self, "customData", value)

    @builtins.property # type: ignore
    @jsii.member(jsii_name="dedicatedHostId")
    def dedicated_host_id(self) -> typing.Optional[builtins.str]:
        return jsii.get(self, "dedicatedHostId")

    @dedicated_host_id.setter # type: ignore
    def dedicated_host_id(self, value: typing.Optional[builtins.str]) -> None:
        jsii.set(self, "dedicatedHostId", value)

    @builtins.property # type: ignore
    @jsii.member(jsii_name="enableAutomaticUpdates")
    def enable_automatic_updates(self) -> typing.Optional[builtins.bool]:
        return jsii.get(self, "enableAutomaticUpdates")

    @enable_automatic_updates.setter # type: ignore
    def enable_automatic_updates(self, value: typing.Optional[builtins.bool]) -> None:
        jsii.set(self, "enableAutomaticUpdates", value)

    @builtins.property # type: ignore
    @jsii.member(jsii_name="evictionPolicy")
    def eviction_policy(self) -> typing.Optional[builtins.str]:
        return jsii.get(self, "evictionPolicy")

    @eviction_policy.setter # type: ignore
    def eviction_policy(self, value: typing.Optional[builtins.str]) -> None:
        jsii.set(self, "evictionPolicy", value)

    @builtins.property # type: ignore
    @jsii.member(jsii_name="id")
    def id(self) -> typing.Optional[builtins.str]:
        return jsii.get(self, "id")

    @id.setter # type: ignore
    def id(self, value: typing.Optional[builtins.str]) -> None:
        jsii.set(self, "id", value)

    @builtins.property # type: ignore
    @jsii.member(jsii_name="identity")
    def identity(self) -> typing.Optional[typing.List["WindowsVirtualMachineIdentity"]]:
        return jsii.get(self, "identity")

    @identity.setter # type: ignore
    def identity(
        self,
        value: typing.Optional[typing.List["WindowsVirtualMachineIdentity"]],
    ) -> None:
        jsii.set(self, "identity", value)

    @builtins.property # type: ignore
    @jsii.member(jsii_name="licenseType")
    def license_type(self) -> typing.Optional[builtins.str]:
        return jsii.get(self, "licenseType")

    @license_type.setter # type: ignore
    def license_type(self, value: typing.Optional[builtins.str]) -> None:
        jsii.set(self, "licenseType", value)

    @builtins.property # type: ignore
    @jsii.member(jsii_name="maxBidPrice")
    def max_bid_price(self) -> typing.Optional[jsii.Number]:
        return jsii.get(self, "maxBidPrice")

    @max_bid_price.setter # type: ignore
    def max_bid_price(self, value: typing.Optional[jsii.Number]) -> None:
        jsii.set(self, "maxBidPrice", value)

    @builtins.property # type: ignore
    @jsii.member(jsii_name="plan")
    def plan(self) -> typing.Optional[typing.List["WindowsVirtualMachinePlan"]]:
        return jsii.get(self, "plan")

    @plan.setter # type: ignore
    def plan(
        self,
        value: typing.Optional[typing.List["WindowsVirtualMachinePlan"]],
    ) -> None:
        jsii.set(self, "plan", value)

    @builtins.property # type: ignore
    @jsii.member(jsii_name="priority")
    def priority(self) -> typing.Optional[builtins.str]:
        return jsii.get(self, "priority")

    @priority.setter # type: ignore
    def priority(self, value: typing.Optional[builtins.str]) -> None:
        jsii.set(self, "priority", value)

    @builtins.property # type: ignore
    @jsii.member(jsii_name="provisionVmAgent")
    def provision_vm_agent(self) -> typing.Optional[builtins.bool]:
        return jsii.get(self, "provisionVmAgent")

    @provision_vm_agent.setter # type: ignore
    def provision_vm_agent(self, value: typing.Optional[builtins.bool]) -> None:
        jsii.set(self, "provisionVmAgent", value)

    @builtins.property # type: ignore
    @jsii.member(jsii_name="proximityPlacementGroupId")
    def proximity_placement_group_id(self) -> typing.Optional[builtins.str]:
        return jsii.get(self, "proximityPlacementGroupId")

    @proximity_placement_group_id.setter # type: ignore
    def proximity_placement_group_id(
        self,
        value: typing.Optional[builtins.str],
    ) -> None:
        jsii.set(self, "proximityPlacementGroupId", value)

    @builtins.property # type: ignore
    @jsii.member(jsii_name="secret")
    def secret(self) -> typing.Optional[typing.List["WindowsVirtualMachineSecret"]]:
        return jsii.get(self, "secret")

    @secret.setter # type: ignore
    def secret(
        self,
        value: typing.Optional[typing.List["WindowsVirtualMachineSecret"]],
    ) -> None:
        jsii.set(self, "secret", value)

    @builtins.property # type: ignore
    @jsii.member(jsii_name="sourceImageId")
    def source_image_id(self) -> typing.Optional[builtins.str]:
        return jsii.get(self, "sourceImageId")

    @source_image_id.setter # type: ignore
    def source_image_id(self, value: typing.Optional[builtins.str]) -> None:
        jsii.set(self, "sourceImageId", value)

    @builtins.property # type: ignore
    @jsii.member(jsii_name="sourceImageReference")
    def source_image_reference(
        self,
    ) -> typing.Optional[typing.List["WindowsVirtualMachineSourceImageReference"]]:
        return jsii.get(self, "sourceImageReference")

    @source_image_reference.setter # type: ignore
    def source_image_reference(
        self,
        value: typing.Optional[typing.List["WindowsVirtualMachineSourceImageReference"]],
    ) -> None:
        jsii.set(self, "sourceImageReference", value)

    @builtins.property # type: ignore
    @jsii.member(jsii_name="tags")
    def tags(self) -> typing.Optional[typing.Mapping[builtins.str, builtins.str]]:
        return jsii.get(self, "tags")

    @tags.setter # type: ignore
    def tags(
        self,
        value: typing.Optional[typing.Mapping[builtins.str, builtins.str]],
    ) -> None:
        jsii.set(self, "tags", value)

    @builtins.property # type: ignore
    @jsii.member(jsii_name="timeouts")
    def timeouts(self) -> typing.Optional["WindowsVirtualMachineTimeouts"]:
        return jsii.get(self, "timeouts")

    @timeouts.setter # type: ignore
    def timeouts(self, value: typing.Optional["WindowsVirtualMachineTimeouts"]) -> None:
        jsii.set(self, "timeouts", value)

    @builtins.property # type: ignore
    @jsii.member(jsii_name="timezone")
    def timezone(self) -> typing.Optional[builtins.str]:
        return jsii.get(self, "timezone")

    @timezone.setter # type: ignore
    def timezone(self, value: typing.Optional[builtins.str]) -> None:
        jsii.set(self, "timezone", value)

    @builtins.property # type: ignore
    @jsii.member(jsii_name="winrmListener")
    def winrm_listener(
        self,
    ) -> typing.Optional[typing.List["WindowsVirtualMachineWinrmListener"]]:
        return jsii.get(self, "winrmListener")

    @winrm_listener.setter # type: ignore
    def winrm_listener(
        self,
        value: typing.Optional[typing.List["WindowsVirtualMachineWinrmListener"]],
    ) -> None:
        jsii.set(self, "winrmListener", value)

    @builtins.property # type: ignore
    @jsii.member(jsii_name="zone")
    def zone(self) -> typing.Optional[builtins.str]:
        return jsii.get(self, "zone")

    @zone.setter # type: ignore
    def zone(self, value: typing.Optional[builtins.str]) -> None:
        jsii.set(self, "zone", value)


@jsii.data_type(
    jsii_type="@cdktf/provider-azurerm.WindowsVirtualMachineAdditionalCapabilities",
    jsii_struct_bases=[],
    name_mapping={"ultra_ssd_enabled": "ultraSsdEnabled"},
)
class WindowsVirtualMachineAdditionalCapabilities:
    def __init__(
        self,
        *,
        ultra_ssd_enabled: typing.Optional[builtins.bool] = None,
    ) -> None:
        """
        :param ultra_ssd_enabled: 
        """
        self._values: typing.Dict[str, typing.Any] = {}
        if ultra_ssd_enabled is not None:
            self._values["ultra_ssd_enabled"] = ultra_ssd_enabled

    @builtins.property
    def ultra_ssd_enabled(self) -> typing.Optional[builtins.bool]:
        result = self._values.get("ultra_ssd_enabled")
        return result

    def __eq__(self, rhs: typing.Any) -> builtins.bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs: typing.Any) -> builtins.bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return "WindowsVirtualMachineAdditionalCapabilities(%s)" % ", ".join(
            k + "=" + repr(v) for k, v in self._values.items()
        )


@jsii.data_type(
    jsii_type="@cdktf/provider-azurerm.WindowsVirtualMachineAdditionalUnattendContent",
    jsii_struct_bases=[],
    name_mapping={"content": "content", "setting": "setting"},
)
class WindowsVirtualMachineAdditionalUnattendContent:
    def __init__(self, *, content: builtins.str, setting: builtins.str) -> None:
        """
        :param content: 
        :param setting: 
        """
        self._values: typing.Dict[str, typing.Any] = {
            "content": content,
            "setting": setting,
        }

    @builtins.property
    def content(self) -> builtins.str:
        result = self._values.get("content")
        assert result is not None, "Required property 'content' is missing"
        return result

    @builtins.property
    def setting(self) -> builtins.str:
        result = self._values.get("setting")
        assert result is not None, "Required property 'setting' is missing"
        return result

    def __eq__(self, rhs: typing.Any) -> builtins.bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs: typing.Any) -> builtins.bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return "WindowsVirtualMachineAdditionalUnattendContent(%s)" % ", ".join(
            k + "=" + repr(v) for k, v in self._values.items()
        )


@jsii.data_type(
    jsii_type="@cdktf/provider-azurerm.WindowsVirtualMachineBootDiagnostics",
    jsii_struct_bases=[],
    name_mapping={"storage_account_uri": "storageAccountUri"},
)
class WindowsVirtualMachineBootDiagnostics:
    def __init__(self, *, storage_account_uri: builtins.str) -> None:
        """
        :param storage_account_uri: 
        """
        self._values: typing.Dict[str, typing.Any] = {
            "storage_account_uri": storage_account_uri,
        }

    @builtins.property
    def storage_account_uri(self) -> builtins.str:
        result = self._values.get("storage_account_uri")
        assert result is not None, "Required property 'storage_account_uri' is missing"
        return result

    def __eq__(self, rhs: typing.Any) -> builtins.bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs: typing.Any) -> builtins.bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return "WindowsVirtualMachineBootDiagnostics(%s)" % ", ".join(
            k + "=" + repr(v) for k, v in self._values.items()
        )


@jsii.data_type(
    jsii_type="@cdktf/provider-azurerm.WindowsVirtualMachineConfig",
    jsii_struct_bases=[cdktf.TerraformMetaArguments],
    name_mapping={
        "count": "count",
        "depends_on": "dependsOn",
        "lifecycle": "lifecycle",
        "provider": "provider",
        "admin_password": "adminPassword",
        "admin_username": "adminUsername",
        "location": "location",
        "name": "name",
        "network_interface_ids": "networkInterfaceIds",
        "os_disk": "osDisk",
        "resource_group_name": "resourceGroupName",
        "size": "size",
        "additional_capabilities": "additionalCapabilities",
        "additional_unattend_content": "additionalUnattendContent",
        "allow_extension_operations": "allowExtensionOperations",
        "availability_set_id": "availabilitySetId",
        "boot_diagnostics": "bootDiagnostics",
        "computer_name": "computerName",
        "custom_data": "customData",
        "dedicated_host_id": "dedicatedHostId",
        "enable_automatic_updates": "enableAutomaticUpdates",
        "eviction_policy": "evictionPolicy",
        "identity": "identity",
        "license_type": "licenseType",
        "max_bid_price": "maxBidPrice",
        "plan": "plan",
        "priority": "priority",
        "provision_vm_agent": "provisionVmAgent",
        "proximity_placement_group_id": "proximityPlacementGroupId",
        "secret": "secret",
        "source_image_id": "sourceImageId",
        "source_image_reference": "sourceImageReference",
        "tags": "tags",
        "timeouts": "timeouts",
        "timezone": "timezone",
        "winrm_listener": "winrmListener",
        "zone": "zone",
    },
)
class WindowsVirtualMachineConfig(cdktf.TerraformMetaArguments):
    def __init__(
        self,
        *,
        count: typing.Optional[jsii.Number] = None,
        depends_on: typing.Optional[typing.List[cdktf.TerraformResource]] = None,
        lifecycle: typing.Optional[cdktf.TerraformResourceLifecycle] = None,
        provider: typing.Optional[cdktf.TerraformProvider] = None,
        admin_password: builtins.str,
        admin_username: builtins.str,
        location: builtins.str,
        name: builtins.str,
        network_interface_ids: typing.List[builtins.str],
        os_disk: typing.List["WindowsVirtualMachineOsDisk"],
        resource_group_name: builtins.str,
        size: builtins.str,
        additional_capabilities: typing.Optional[typing.List[WindowsVirtualMachineAdditionalCapabilities]] = None,
        additional_unattend_content: typing.Optional[typing.List[WindowsVirtualMachineAdditionalUnattendContent]] = None,
        allow_extension_operations: typing.Optional[builtins.bool] = None,
        availability_set_id: typing.Optional[builtins.str] = None,
        boot_diagnostics: typing.Optional[typing.List[WindowsVirtualMachineBootDiagnostics]] = None,
        computer_name: typing.Optional[builtins.str] = None,
        custom_data: typing.Optional[builtins.str] = None,
        dedicated_host_id: typing.Optional[builtins.str] = None,
        enable_automatic_updates: typing.Optional[builtins.bool] = None,
        eviction_policy: typing.Optional[builtins.str] = None,
        identity: typing.Optional[typing.List["WindowsVirtualMachineIdentity"]] = None,
        license_type: typing.Optional[builtins.str] = None,
        max_bid_price: typing.Optional[jsii.Number] = None,
        plan: typing.Optional[typing.List["WindowsVirtualMachinePlan"]] = None,
        priority: typing.Optional[builtins.str] = None,
        provision_vm_agent: typing.Optional[builtins.bool] = None,
        proximity_placement_group_id: typing.Optional[builtins.str] = None,
        secret: typing.Optional[typing.List["WindowsVirtualMachineSecret"]] = None,
        source_image_id: typing.Optional[builtins.str] = None,
        source_image_reference: typing.Optional[typing.List["WindowsVirtualMachineSourceImageReference"]] = None,
        tags: typing.Optional[typing.Mapping[builtins.str, builtins.str]] = None,
        timeouts: typing.Optional["WindowsVirtualMachineTimeouts"] = None,
        timezone: typing.Optional[builtins.str] = None,
        winrm_listener: typing.Optional[typing.List["WindowsVirtualMachineWinrmListener"]] = None,
        zone: typing.Optional[builtins.str] = None,
    ) -> None:
        """
        :param count: 
        :param depends_on: 
        :param lifecycle: 
        :param provider: 
        :param admin_password: 
        :param admin_username: 
        :param location: 
        :param name: 
        :param network_interface_ids: 
        :param os_disk: os_disk block.
        :param resource_group_name: 
        :param size: 
        :param additional_capabilities: additional_capabilities block.
        :param additional_unattend_content: additional_unattend_content block.
        :param allow_extension_operations: 
        :param availability_set_id: 
        :param boot_diagnostics: boot_diagnostics block.
        :param computer_name: 
        :param custom_data: 
        :param dedicated_host_id: 
        :param enable_automatic_updates: 
        :param eviction_policy: 
        :param identity: identity block.
        :param license_type: 
        :param max_bid_price: 
        :param plan: plan block.
        :param priority: 
        :param provision_vm_agent: 
        :param proximity_placement_group_id: 
        :param secret: secret block.
        :param source_image_id: 
        :param source_image_reference: source_image_reference block.
        :param tags: 
        :param timeouts: timeouts block.
        :param timezone: 
        :param winrm_listener: winrm_listener block.
        :param zone: 
        """
        if isinstance(lifecycle, dict):
            lifecycle = cdktf.TerraformResourceLifecycle(**lifecycle)
        if isinstance(timeouts, dict):
            timeouts = WindowsVirtualMachineTimeouts(**timeouts)
        self._values: typing.Dict[str, typing.Any] = {
            "admin_password": admin_password,
            "admin_username": admin_username,
            "location": location,
            "name": name,
            "network_interface_ids": network_interface_ids,
            "os_disk": os_disk,
            "resource_group_name": resource_group_name,
            "size": size,
        }
        if count is not None:
            self._values["count"] = count
        if depends_on is not None:
            self._values["depends_on"] = depends_on
        if lifecycle is not None:
            self._values["lifecycle"] = lifecycle
        if provider is not None:
            self._values["provider"] = provider
        if additional_capabilities is not None:
            self._values["additional_capabilities"] = additional_capabilities
        if additional_unattend_content is not None:
            self._values["additional_unattend_content"] = additional_unattend_content
        if allow_extension_operations is not None:
            self._values["allow_extension_operations"] = allow_extension_operations
        if availability_set_id is not None:
            self._values["availability_set_id"] = availability_set_id
        if boot_diagnostics is not None:
            self._values["boot_diagnostics"] = boot_diagnostics
        if computer_name is not None:
            self._values["computer_name"] = computer_name
        if custom_data is not None:
            self._values["custom_data"] = custom_data
        if dedicated_host_id is not None:
            self._values["dedicated_host_id"] = dedicated_host_id
        if enable_automatic_updates is not None:
            self._values["enable_automatic_updates"] = enable_automatic_updates
        if eviction_policy is not None:
            self._values["eviction_policy"] = eviction_policy
        if identity is not None:
            self._values["identity"] = identity
        if license_type is not None:
            self._values["license_type"] = license_type
        if max_bid_price is not None:
            self._values["max_bid_price"] = max_bid_price
        if plan is not None:
            self._values["plan"] = plan
        if priority is not None:
            self._values["priority"] = priority
        if provision_vm_agent is not None:
            self._values["provision_vm_agent"] = provision_vm_agent
        if proximity_placement_group_id is not None:
            self._values["proximity_placement_group_id"] = proximity_placement_group_id
        if secret is not None:
            self._values["secret"] = secret
        if source_image_id is not None:
            self._values["source_image_id"] = source_image_id
        if source_image_reference is not None:
            self._values["source_image_reference"] = source_image_reference
        if tags is not None:
            self._values["tags"] = tags
        if timeouts is not None:
            self._values["timeouts"] = timeouts
        if timezone is not None:
            self._values["timezone"] = timezone
        if winrm_listener is not None:
            self._values["winrm_listener"] = winrm_listener
        if zone is not None:
            self._values["zone"] = zone

    @builtins.property
    def count(self) -> typing.Optional[jsii.Number]:
        """
        :stability: experimental
        """
        result = self._values.get("count")
        return result

    @builtins.property
    def depends_on(self) -> typing.Optional[typing.List[cdktf.TerraformResource]]:
        """
        :stability: experimental
        """
        result = self._values.get("depends_on")
        return result

    @builtins.property
    def lifecycle(self) -> typing.Optional[cdktf.TerraformResourceLifecycle]:
        """
        :stability: experimental
        """
        result = self._values.get("lifecycle")
        return result

    @builtins.property
    def provider(self) -> typing.Optional[cdktf.TerraformProvider]:
        """
        :stability: experimental
        """
        result = self._values.get("provider")
        return result

    @builtins.property
    def admin_password(self) -> builtins.str:
        result = self._values.get("admin_password")
        assert result is not None, "Required property 'admin_password' is missing"
        return result

    @builtins.property
    def admin_username(self) -> builtins.str:
        result = self._values.get("admin_username")
        assert result is not None, "Required property 'admin_username' is missing"
        return result

    @builtins.property
    def location(self) -> builtins.str:
        result = self._values.get("location")
        assert result is not None, "Required property 'location' is missing"
        return result

    @builtins.property
    def name(self) -> builtins.str:
        result = self._values.get("name")
        assert result is not None, "Required property 'name' is missing"
        return result

    @builtins.property
    def network_interface_ids(self) -> typing.List[builtins.str]:
        result = self._values.get("network_interface_ids")
        assert result is not None, "Required property 'network_interface_ids' is missing"
        return result

    @builtins.property
    def os_disk(self) -> typing.List["WindowsVirtualMachineOsDisk"]:
        """os_disk block."""
        result = self._values.get("os_disk")
        assert result is not None, "Required property 'os_disk' is missing"
        return result

    @builtins.property
    def resource_group_name(self) -> builtins.str:
        result = self._values.get("resource_group_name")
        assert result is not None, "Required property 'resource_group_name' is missing"
        return result

    @builtins.property
    def size(self) -> builtins.str:
        result = self._values.get("size")
        assert result is not None, "Required property 'size' is missing"
        return result

    @builtins.property
    def additional_capabilities(
        self,
    ) -> typing.Optional[typing.List[WindowsVirtualMachineAdditionalCapabilities]]:
        """additional_capabilities block."""
        result = self._values.get("additional_capabilities")
        return result

    @builtins.property
    def additional_unattend_content(
        self,
    ) -> typing.Optional[typing.List[WindowsVirtualMachineAdditionalUnattendContent]]:
        """additional_unattend_content block."""
        result = self._values.get("additional_unattend_content")
        return result

    @builtins.property
    def allow_extension_operations(self) -> typing.Optional[builtins.bool]:
        result = self._values.get("allow_extension_operations")
        return result

    @builtins.property
    def availability_set_id(self) -> typing.Optional[builtins.str]:
        result = self._values.get("availability_set_id")
        return result

    @builtins.property
    def boot_diagnostics(
        self,
    ) -> typing.Optional[typing.List[WindowsVirtualMachineBootDiagnostics]]:
        """boot_diagnostics block."""
        result = self._values.get("boot_diagnostics")
        return result

    @builtins.property
    def computer_name(self) -> typing.Optional[builtins.str]:
        result = self._values.get("computer_name")
        return result

    @builtins.property
    def custom_data(self) -> typing.Optional[builtins.str]:
        result = self._values.get("custom_data")
        return result

    @builtins.property
    def dedicated_host_id(self) -> typing.Optional[builtins.str]:
        result = self._values.get("dedicated_host_id")
        return result

    @builtins.property
    def enable_automatic_updates(self) -> typing.Optional[builtins.bool]:
        result = self._values.get("enable_automatic_updates")
        return result

    @builtins.property
    def eviction_policy(self) -> typing.Optional[builtins.str]:
        result = self._values.get("eviction_policy")
        return result

    @builtins.property
    def identity(self) -> typing.Optional[typing.List["WindowsVirtualMachineIdentity"]]:
        """identity block."""
        result = self._values.get("identity")
        return result

    @builtins.property
    def license_type(self) -> typing.Optional[builtins.str]:
        result = self._values.get("license_type")
        return result

    @builtins.property
    def max_bid_price(self) -> typing.Optional[jsii.Number]:
        result = self._values.get("max_bid_price")
        return result

    @builtins.property
    def plan(self) -> typing.Optional[typing.List["WindowsVirtualMachinePlan"]]:
        """plan block."""
        result = self._values.get("plan")
        return result

    @builtins.property
    def priority(self) -> typing.Optional[builtins.str]:
        result = self._values.get("priority")
        return result

    @builtins.property
    def provision_vm_agent(self) -> typing.Optional[builtins.bool]:
        result = self._values.get("provision_vm_agent")
        return result

    @builtins.property
    def proximity_placement_group_id(self) -> typing.Optional[builtins.str]:
        result = self._values.get("proximity_placement_group_id")
        return result

    @builtins.property
    def secret(self) -> typing.Optional[typing.List["WindowsVirtualMachineSecret"]]:
        """secret block."""
        result = self._values.get("secret")
        return result

    @builtins.property
    def source_image_id(self) -> typing.Optional[builtins.str]:
        result = self._values.get("source_image_id")
        return result

    @builtins.property
    def source_image_reference(
        self,
    ) -> typing.Optional[typing.List["WindowsVirtualMachineSourceImageReference"]]:
        """source_image_reference block."""
        result = self._values.get("source_image_reference")
        return result

    @builtins.property
    def tags(self) -> typing.Optional[typing.Mapping[builtins.str, builtins.str]]:
        result = self._values.get("tags")
        return result

    @builtins.property
    def timeouts(self) -> typing.Optional["WindowsVirtualMachineTimeouts"]:
        """timeouts block."""
        result = self._values.get("timeouts")
        return result

    @builtins.property
    def timezone(self) -> typing.Optional[builtins.str]:
        result = self._values.get("timezone")
        return result

    @builtins.property
    def winrm_listener(
        self,
    ) -> typing.Optional[typing.List["WindowsVirtualMachineWinrmListener"]]:
        """winrm_listener block."""
        result = self._values.get("winrm_listener")
        return result

    @builtins.property
    def zone(self) -> typing.Optional[builtins.str]:
        result = self._values.get("zone")
        return result

    def __eq__(self, rhs: typing.Any) -> builtins.bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs: typing.Any) -> builtins.bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return "WindowsVirtualMachineConfig(%s)" % ", ".join(
            k + "=" + repr(v) for k, v in self._values.items()
        )


@jsii.data_type(
    jsii_type="@cdktf/provider-azurerm.WindowsVirtualMachineIdentity",
    jsii_struct_bases=[],
    name_mapping={"type": "type", "identity_ids": "identityIds"},
)
class WindowsVirtualMachineIdentity:
    def __init__(
        self,
        *,
        type: builtins.str,
        identity_ids: typing.Optional[typing.List[builtins.str]] = None,
    ) -> None:
        """
        :param type: 
        :param identity_ids: 
        """
        self._values: typing.Dict[str, typing.Any] = {
            "type": type,
        }
        if identity_ids is not None:
            self._values["identity_ids"] = identity_ids

    @builtins.property
    def type(self) -> builtins.str:
        result = self._values.get("type")
        assert result is not None, "Required property 'type' is missing"
        return result

    @builtins.property
    def identity_ids(self) -> typing.Optional[typing.List[builtins.str]]:
        result = self._values.get("identity_ids")
        return result

    def __eq__(self, rhs: typing.Any) -> builtins.bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs: typing.Any) -> builtins.bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return "WindowsVirtualMachineIdentity(%s)" % ", ".join(
            k + "=" + repr(v) for k, v in self._values.items()
        )


@jsii.data_type(
    jsii_type="@cdktf/provider-azurerm.WindowsVirtualMachineOsDisk",
    jsii_struct_bases=[],
    name_mapping={
        "caching": "caching",
        "storage_account_type": "storageAccountType",
        "diff_disk_settings": "diffDiskSettings",
        "disk_encryption_set_id": "diskEncryptionSetId",
        "disk_size_gb": "diskSizeGb",
        "name": "name",
        "write_accelerator_enabled": "writeAcceleratorEnabled",
    },
)
class WindowsVirtualMachineOsDisk:
    def __init__(
        self,
        *,
        caching: builtins.str,
        storage_account_type: builtins.str,
        diff_disk_settings: typing.Optional[typing.List["WindowsVirtualMachineOsDiskDiffDiskSettings"]] = None,
        disk_encryption_set_id: typing.Optional[builtins.str] = None,
        disk_size_gb: typing.Optional[jsii.Number] = None,
        name: typing.Optional[builtins.str] = None,
        write_accelerator_enabled: typing.Optional[builtins.bool] = None,
    ) -> None:
        """
        :param caching: 
        :param storage_account_type: 
        :param diff_disk_settings: diff_disk_settings block.
        :param disk_encryption_set_id: 
        :param disk_size_gb: 
        :param name: 
        :param write_accelerator_enabled: 
        """
        self._values: typing.Dict[str, typing.Any] = {
            "caching": caching,
            "storage_account_type": storage_account_type,
        }
        if diff_disk_settings is not None:
            self._values["diff_disk_settings"] = diff_disk_settings
        if disk_encryption_set_id is not None:
            self._values["disk_encryption_set_id"] = disk_encryption_set_id
        if disk_size_gb is not None:
            self._values["disk_size_gb"] = disk_size_gb
        if name is not None:
            self._values["name"] = name
        if write_accelerator_enabled is not None:
            self._values["write_accelerator_enabled"] = write_accelerator_enabled

    @builtins.property
    def caching(self) -> builtins.str:
        result = self._values.get("caching")
        assert result is not None, "Required property 'caching' is missing"
        return result

    @builtins.property
    def storage_account_type(self) -> builtins.str:
        result = self._values.get("storage_account_type")
        assert result is not None, "Required property 'storage_account_type' is missing"
        return result

    @builtins.property
    def diff_disk_settings(
        self,
    ) -> typing.Optional[typing.List["WindowsVirtualMachineOsDiskDiffDiskSettings"]]:
        """diff_disk_settings block."""
        result = self._values.get("diff_disk_settings")
        return result

    @builtins.property
    def disk_encryption_set_id(self) -> typing.Optional[builtins.str]:
        result = self._values.get("disk_encryption_set_id")
        return result

    @builtins.property
    def disk_size_gb(self) -> typing.Optional[jsii.Number]:
        result = self._values.get("disk_size_gb")
        return result

    @builtins.property
    def name(self) -> typing.Optional[builtins.str]:
        result = self._values.get("name")
        return result

    @builtins.property
    def write_accelerator_enabled(self) -> typing.Optional[builtins.bool]:
        result = self._values.get("write_accelerator_enabled")
        return result

    def __eq__(self, rhs: typing.Any) -> builtins.bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs: typing.Any) -> builtins.bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return "WindowsVirtualMachineOsDisk(%s)" % ", ".join(
            k + "=" + repr(v) for k, v in self._values.items()
        )


@jsii.data_type(
    jsii_type="@cdktf/provider-azurerm.WindowsVirtualMachineOsDiskDiffDiskSettings",
    jsii_struct_bases=[],
    name_mapping={"option": "option"},
)
class WindowsVirtualMachineOsDiskDiffDiskSettings:
    def __init__(self, *, option: builtins.str) -> None:
        """
        :param option: 
        """
        self._values: typing.Dict[str, typing.Any] = {
            "option": option,
        }

    @builtins.property
    def option(self) -> builtins.str:
        result = self._values.get("option")
        assert result is not None, "Required property 'option' is missing"
        return result

    def __eq__(self, rhs: typing.Any) -> builtins.bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs: typing.Any) -> builtins.bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return "WindowsVirtualMachineOsDiskDiffDiskSettings(%s)" % ", ".join(
            k + "=" + repr(v) for k, v in self._values.items()
        )


@jsii.data_type(
    jsii_type="@cdktf/provider-azurerm.WindowsVirtualMachinePlan",
    jsii_struct_bases=[],
    name_mapping={"name": "name", "product": "product", "publisher": "publisher"},
)
class WindowsVirtualMachinePlan:
    def __init__(
        self,
        *,
        name: builtins.str,
        product: builtins.str,
        publisher: builtins.str,
    ) -> None:
        """
        :param name: 
        :param product: 
        :param publisher: 
        """
        self._values: typing.Dict[str, typing.Any] = {
            "name": name,
            "product": product,
            "publisher": publisher,
        }

    @builtins.property
    def name(self) -> builtins.str:
        result = self._values.get("name")
        assert result is not None, "Required property 'name' is missing"
        return result

    @builtins.property
    def product(self) -> builtins.str:
        result = self._values.get("product")
        assert result is not None, "Required property 'product' is missing"
        return result

    @builtins.property
    def publisher(self) -> builtins.str:
        result = self._values.get("publisher")
        assert result is not None, "Required property 'publisher' is missing"
        return result

    def __eq__(self, rhs: typing.Any) -> builtins.bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs: typing.Any) -> builtins.bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return "WindowsVirtualMachinePlan(%s)" % ", ".join(
            k + "=" + repr(v) for k, v in self._values.items()
        )


class WindowsVirtualMachineScaleSet(
    cdktf.TerraformResource,
    metaclass=jsii.JSIIMeta,
    jsii_type="@cdktf/provider-azurerm.WindowsVirtualMachineScaleSet",
):
    def __init__(
        self,
        scope: constructs.Construct,
        id: builtins.str,
        *,
        admin_password: builtins.str,
        admin_username: builtins.str,
        instances: jsii.Number,
        location: builtins.str,
        name: builtins.str,
        network_interface: typing.List["WindowsVirtualMachineScaleSetNetworkInterface"],
        os_disk: typing.List["WindowsVirtualMachineScaleSetOsDisk"],
        resource_group_name: builtins.str,
        sku: builtins.str,
        additional_capabilities: typing.Optional[typing.List["WindowsVirtualMachineScaleSetAdditionalCapabilities"]] = None,
        additional_unattend_content: typing.Optional[typing.List["WindowsVirtualMachineScaleSetAdditionalUnattendContent"]] = None,
        automatic_os_upgrade_policy: typing.Optional[typing.List["WindowsVirtualMachineScaleSetAutomaticOsUpgradePolicy"]] = None,
        boot_diagnostics: typing.Optional[typing.List["WindowsVirtualMachineScaleSetBootDiagnostics"]] = None,
        computer_name_prefix: typing.Optional[builtins.str] = None,
        custom_data: typing.Optional[builtins.str] = None,
        data_disk: typing.Optional[typing.List["WindowsVirtualMachineScaleSetDataDisk"]] = None,
        do_not_run_extensions_on_overprovisioned_machines: typing.Optional[builtins.bool] = None,
        enable_automatic_updates: typing.Optional[builtins.bool] = None,
        eviction_policy: typing.Optional[builtins.str] = None,
        health_probe_id: typing.Optional[builtins.str] = None,
        identity: typing.Optional[typing.List["WindowsVirtualMachineScaleSetIdentity"]] = None,
        license_type: typing.Optional[builtins.str] = None,
        max_bid_price: typing.Optional[jsii.Number] = None,
        overprovision: typing.Optional[builtins.bool] = None,
        plan: typing.Optional[typing.List["WindowsVirtualMachineScaleSetPlan"]] = None,
        priority: typing.Optional[builtins.str] = None,
        provision_vm_agent: typing.Optional[builtins.bool] = None,
        proximity_placement_group_id: typing.Optional[builtins.str] = None,
        rolling_upgrade_policy: typing.Optional[typing.List["WindowsVirtualMachineScaleSetRollingUpgradePolicy"]] = None,
        secret: typing.Optional[typing.List["WindowsVirtualMachineScaleSetSecret"]] = None,
        single_placement_group: typing.Optional[builtins.bool] = None,
        source_image_id: typing.Optional[builtins.str] = None,
        source_image_reference: typing.Optional[typing.List["WindowsVirtualMachineScaleSetSourceImageReference"]] = None,
        tags: typing.Optional[typing.Mapping[builtins.str, builtins.str]] = None,
        timeouts: typing.Optional["WindowsVirtualMachineScaleSetTimeouts"] = None,
        timezone: typing.Optional[builtins.str] = None,
        upgrade_mode: typing.Optional[builtins.str] = None,
        winrm_listener: typing.Optional[typing.List["WindowsVirtualMachineScaleSetWinrmListener"]] = None,
        zone_balance: typing.Optional[builtins.bool] = None,
        zones: typing.Optional[typing.List[builtins.str]] = None,
        count: typing.Optional[jsii.Number] = None,
        depends_on: typing.Optional[typing.List[cdktf.TerraformResource]] = None,
        lifecycle: typing.Optional[cdktf.TerraformResourceLifecycle] = None,
        provider: typing.Optional[cdktf.TerraformProvider] = None,
    ) -> None:
        """
        :param scope: -
        :param id: -
        :param admin_password: 
        :param admin_username: 
        :param instances: 
        :param location: 
        :param name: 
        :param network_interface: network_interface block.
        :param os_disk: os_disk block.
        :param resource_group_name: 
        :param sku: 
        :param additional_capabilities: additional_capabilities block.
        :param additional_unattend_content: additional_unattend_content block.
        :param automatic_os_upgrade_policy: automatic_os_upgrade_policy block.
        :param boot_diagnostics: boot_diagnostics block.
        :param computer_name_prefix: 
        :param custom_data: 
        :param data_disk: data_disk block.
        :param do_not_run_extensions_on_overprovisioned_machines: 
        :param enable_automatic_updates: 
        :param eviction_policy: 
        :param health_probe_id: 
        :param identity: identity block.
        :param license_type: 
        :param max_bid_price: 
        :param overprovision: 
        :param plan: plan block.
        :param priority: 
        :param provision_vm_agent: 
        :param proximity_placement_group_id: 
        :param rolling_upgrade_policy: rolling_upgrade_policy block.
        :param secret: secret block.
        :param single_placement_group: 
        :param source_image_id: 
        :param source_image_reference: source_image_reference block.
        :param tags: 
        :param timeouts: timeouts block.
        :param timezone: 
        :param upgrade_mode: 
        :param winrm_listener: winrm_listener block.
        :param zone_balance: 
        :param zones: 
        :param count: 
        :param depends_on: 
        :param lifecycle: 
        :param provider: 
        """
        config = WindowsVirtualMachineScaleSetConfig(
            admin_password=admin_password,
            admin_username=admin_username,
            instances=instances,
            location=location,
            name=name,
            network_interface=network_interface,
            os_disk=os_disk,
            resource_group_name=resource_group_name,
            sku=sku,
            additional_capabilities=additional_capabilities,
            additional_unattend_content=additional_unattend_content,
            automatic_os_upgrade_policy=automatic_os_upgrade_policy,
            boot_diagnostics=boot_diagnostics,
            computer_name_prefix=computer_name_prefix,
            custom_data=custom_data,
            data_disk=data_disk,
            do_not_run_extensions_on_overprovisioned_machines=do_not_run_extensions_on_overprovisioned_machines,
            enable_automatic_updates=enable_automatic_updates,
            eviction_policy=eviction_policy,
            health_probe_id=health_probe_id,
            identity=identity,
            license_type=license_type,
            max_bid_price=max_bid_price,
            overprovision=overprovision,
            plan=plan,
            priority=priority,
            provision_vm_agent=provision_vm_agent,
            proximity_placement_group_id=proximity_placement_group_id,
            rolling_upgrade_policy=rolling_upgrade_policy,
            secret=secret,
            single_placement_group=single_placement_group,
            source_image_id=source_image_id,
            source_image_reference=source_image_reference,
            tags=tags,
            timeouts=timeouts,
            timezone=timezone,
            upgrade_mode=upgrade_mode,
            winrm_listener=winrm_listener,
            zone_balance=zone_balance,
            zones=zones,
            count=count,
            depends_on=depends_on,
            lifecycle=lifecycle,
            provider=provider,
        )

        jsii.create(WindowsVirtualMachineScaleSet, self, [scope, id, config])

    @jsii.member(jsii_name="synthesizeAttributes")
    def _synthesize_attributes(self) -> typing.Mapping[builtins.str, typing.Any]:
        return jsii.invoke(self, "synthesizeAttributes", [])

    @builtins.property # type: ignore
    @jsii.member(jsii_name="uniqueId")
    def unique_id(self) -> builtins.str:
        return jsii.get(self, "uniqueId")

    @builtins.property # type: ignore
    @jsii.member(jsii_name="adminPassword")
    def admin_password(self) -> builtins.str:
        return jsii.get(self, "adminPassword")

    @admin_password.setter # type: ignore
    def admin_password(self, value: builtins.str) -> None:
        jsii.set(self, "adminPassword", value)

    @builtins.property # type: ignore
    @jsii.member(jsii_name="adminUsername")
    def admin_username(self) -> builtins.str:
        return jsii.get(self, "adminUsername")

    @admin_username.setter # type: ignore
    def admin_username(self, value: builtins.str) -> None:
        jsii.set(self, "adminUsername", value)

    @builtins.property # type: ignore
    @jsii.member(jsii_name="instances")
    def instances(self) -> jsii.Number:
        return jsii.get(self, "instances")

    @instances.setter # type: ignore
    def instances(self, value: jsii.Number) -> None:
        jsii.set(self, "instances", value)

    @builtins.property # type: ignore
    @jsii.member(jsii_name="location")
    def location(self) -> builtins.str:
        return jsii.get(self, "location")

    @location.setter # type: ignore
    def location(self, value: builtins.str) -> None:
        jsii.set(self, "location", value)

    @builtins.property # type: ignore
    @jsii.member(jsii_name="name")
    def name(self) -> builtins.str:
        return jsii.get(self, "name")

    @name.setter # type: ignore
    def name(self, value: builtins.str) -> None:
        jsii.set(self, "name", value)

    @builtins.property # type: ignore
    @jsii.member(jsii_name="networkInterface")
    def network_interface(
        self,
    ) -> typing.List["WindowsVirtualMachineScaleSetNetworkInterface"]:
        return jsii.get(self, "networkInterface")

    @network_interface.setter # type: ignore
    def network_interface(
        self,
        value: typing.List["WindowsVirtualMachineScaleSetNetworkInterface"],
    ) -> None:
        jsii.set(self, "networkInterface", value)

    @builtins.property # type: ignore
    @jsii.member(jsii_name="osDisk")
    def os_disk(self) -> typing.List["WindowsVirtualMachineScaleSetOsDisk"]:
        return jsii.get(self, "osDisk")

    @os_disk.setter # type: ignore
    def os_disk(
        self,
        value: typing.List["WindowsVirtualMachineScaleSetOsDisk"],
    ) -> None:
        jsii.set(self, "osDisk", value)

    @builtins.property # type: ignore
    @jsii.member(jsii_name="resourceGroupName")
    def resource_group_name(self) -> builtins.str:
        return jsii.get(self, "resourceGroupName")

    @resource_group_name.setter # type: ignore
    def resource_group_name(self, value: builtins.str) -> None:
        jsii.set(self, "resourceGroupName", value)

    @builtins.property # type: ignore
    @jsii.member(jsii_name="sku")
    def sku(self) -> builtins.str:
        return jsii.get(self, "sku")

    @sku.setter # type: ignore
    def sku(self, value: builtins.str) -> None:
        jsii.set(self, "sku", value)

    @builtins.property # type: ignore
    @jsii.member(jsii_name="additionalCapabilities")
    def additional_capabilities(
        self,
    ) -> typing.Optional[typing.List["WindowsVirtualMachineScaleSetAdditionalCapabilities"]]:
        return jsii.get(self, "additionalCapabilities")

    @additional_capabilities.setter # type: ignore
    def additional_capabilities(
        self,
        value: typing.Optional[typing.List["WindowsVirtualMachineScaleSetAdditionalCapabilities"]],
    ) -> None:
        jsii.set(self, "additionalCapabilities", value)

    @builtins.property # type: ignore
    @jsii.member(jsii_name="additionalUnattendContent")
    def additional_unattend_content(
        self,
    ) -> typing.Optional[typing.List["WindowsVirtualMachineScaleSetAdditionalUnattendContent"]]:
        return jsii.get(self, "additionalUnattendContent")

    @additional_unattend_content.setter # type: ignore
    def additional_unattend_content(
        self,
        value: typing.Optional[typing.List["WindowsVirtualMachineScaleSetAdditionalUnattendContent"]],
    ) -> None:
        jsii.set(self, "additionalUnattendContent", value)

    @builtins.property # type: ignore
    @jsii.member(jsii_name="automaticOsUpgradePolicy")
    def automatic_os_upgrade_policy(
        self,
    ) -> typing.Optional[typing.List["WindowsVirtualMachineScaleSetAutomaticOsUpgradePolicy"]]:
        return jsii.get(self, "automaticOsUpgradePolicy")

    @automatic_os_upgrade_policy.setter # type: ignore
    def automatic_os_upgrade_policy(
        self,
        value: typing.Optional[typing.List["WindowsVirtualMachineScaleSetAutomaticOsUpgradePolicy"]],
    ) -> None:
        jsii.set(self, "automaticOsUpgradePolicy", value)

    @builtins.property # type: ignore
    @jsii.member(jsii_name="bootDiagnostics")
    def boot_diagnostics(
        self,
    ) -> typing.Optional[typing.List["WindowsVirtualMachineScaleSetBootDiagnostics"]]:
        return jsii.get(self, "bootDiagnostics")

    @boot_diagnostics.setter # type: ignore
    def boot_diagnostics(
        self,
        value: typing.Optional[typing.List["WindowsVirtualMachineScaleSetBootDiagnostics"]],
    ) -> None:
        jsii.set(self, "bootDiagnostics", value)

    @builtins.property # type: ignore
    @jsii.member(jsii_name="computerNamePrefix")
    def computer_name_prefix(self) -> typing.Optional[builtins.str]:
        return jsii.get(self, "computerNamePrefix")

    @computer_name_prefix.setter # type: ignore
    def computer_name_prefix(self, value: typing.Optional[builtins.str]) -> None:
        jsii.set(self, "computerNamePrefix", value)

    @builtins.property # type: ignore
    @jsii.member(jsii_name="customData")
    def custom_data(self) -> typing.Optional[builtins.str]:
        return jsii.get(self, "customData")

    @custom_data.setter # type: ignore
    def custom_data(self, value: typing.Optional[builtins.str]) -> None:
        jsii.set(self, "customData", value)

    @builtins.property # type: ignore
    @jsii.member(jsii_name="dataDisk")
    def data_disk(
        self,
    ) -> typing.Optional[typing.List["WindowsVirtualMachineScaleSetDataDisk"]]:
        return jsii.get(self, "dataDisk")

    @data_disk.setter # type: ignore
    def data_disk(
        self,
        value: typing.Optional[typing.List["WindowsVirtualMachineScaleSetDataDisk"]],
    ) -> None:
        jsii.set(self, "dataDisk", value)

    @builtins.property # type: ignore
    @jsii.member(jsii_name="doNotRunExtensionsOnOverprovisionedMachines")
    def do_not_run_extensions_on_overprovisioned_machines(
        self,
    ) -> typing.Optional[builtins.bool]:
        return jsii.get(self, "doNotRunExtensionsOnOverprovisionedMachines")

    @do_not_run_extensions_on_overprovisioned_machines.setter # type: ignore
    def do_not_run_extensions_on_overprovisioned_machines(
        self,
        value: typing.Optional[builtins.bool],
    ) -> None:
        jsii.set(self, "doNotRunExtensionsOnOverprovisionedMachines", value)

    @builtins.property # type: ignore
    @jsii.member(jsii_name="enableAutomaticUpdates")
    def enable_automatic_updates(self) -> typing.Optional[builtins.bool]:
        return jsii.get(self, "enableAutomaticUpdates")

    @enable_automatic_updates.setter # type: ignore
    def enable_automatic_updates(self, value: typing.Optional[builtins.bool]) -> None:
        jsii.set(self, "enableAutomaticUpdates", value)

    @builtins.property # type: ignore
    @jsii.member(jsii_name="evictionPolicy")
    def eviction_policy(self) -> typing.Optional[builtins.str]:
        return jsii.get(self, "evictionPolicy")

    @eviction_policy.setter # type: ignore
    def eviction_policy(self, value: typing.Optional[builtins.str]) -> None:
        jsii.set(self, "evictionPolicy", value)

    @builtins.property # type: ignore
    @jsii.member(jsii_name="healthProbeId")
    def health_probe_id(self) -> typing.Optional[builtins.str]:
        return jsii.get(self, "healthProbeId")

    @health_probe_id.setter # type: ignore
    def health_probe_id(self, value: typing.Optional[builtins.str]) -> None:
        jsii.set(self, "healthProbeId", value)

    @builtins.property # type: ignore
    @jsii.member(jsii_name="id")
    def id(self) -> typing.Optional[builtins.str]:
        return jsii.get(self, "id")

    @id.setter # type: ignore
    def id(self, value: typing.Optional[builtins.str]) -> None:
        jsii.set(self, "id", value)

    @builtins.property # type: ignore
    @jsii.member(jsii_name="identity")
    def identity(
        self,
    ) -> typing.Optional[typing.List["WindowsVirtualMachineScaleSetIdentity"]]:
        return jsii.get(self, "identity")

    @identity.setter # type: ignore
    def identity(
        self,
        value: typing.Optional[typing.List["WindowsVirtualMachineScaleSetIdentity"]],
    ) -> None:
        jsii.set(self, "identity", value)

    @builtins.property # type: ignore
    @jsii.member(jsii_name="licenseType")
    def license_type(self) -> typing.Optional[builtins.str]:
        return jsii.get(self, "licenseType")

    @license_type.setter # type: ignore
    def license_type(self, value: typing.Optional[builtins.str]) -> None:
        jsii.set(self, "licenseType", value)

    @builtins.property # type: ignore
    @jsii.member(jsii_name="maxBidPrice")
    def max_bid_price(self) -> typing.Optional[jsii.Number]:
        return jsii.get(self, "maxBidPrice")

    @max_bid_price.setter # type: ignore
    def max_bid_price(self, value: typing.Optional[jsii.Number]) -> None:
        jsii.set(self, "maxBidPrice", value)

    @builtins.property # type: ignore
    @jsii.member(jsii_name="overprovision")
    def overprovision(self) -> typing.Optional[builtins.bool]:
        return jsii.get(self, "overprovision")

    @overprovision.setter # type: ignore
    def overprovision(self, value: typing.Optional[builtins.bool]) -> None:
        jsii.set(self, "overprovision", value)

    @builtins.property # type: ignore
    @jsii.member(jsii_name="plan")
    def plan(self) -> typing.Optional[typing.List["WindowsVirtualMachineScaleSetPlan"]]:
        return jsii.get(self, "plan")

    @plan.setter # type: ignore
    def plan(
        self,
        value: typing.Optional[typing.List["WindowsVirtualMachineScaleSetPlan"]],
    ) -> None:
        jsii.set(self, "plan", value)

    @builtins.property # type: ignore
    @jsii.member(jsii_name="priority")
    def priority(self) -> typing.Optional[builtins.str]:
        return jsii.get(self, "priority")

    @priority.setter # type: ignore
    def priority(self, value: typing.Optional[builtins.str]) -> None:
        jsii.set(self, "priority", value)

    @builtins.property # type: ignore
    @jsii.member(jsii_name="provisionVmAgent")
    def provision_vm_agent(self) -> typing.Optional[builtins.bool]:
        return jsii.get(self, "provisionVmAgent")

    @provision_vm_agent.setter # type: ignore
    def provision_vm_agent(self, value: typing.Optional[builtins.bool]) -> None:
        jsii.set(self, "provisionVmAgent", value)

    @builtins.property # type: ignore
    @jsii.member(jsii_name="proximityPlacementGroupId")
    def proximity_placement_group_id(self) -> typing.Optional[builtins.str]:
        return jsii.get(self, "proximityPlacementGroupId")

    @proximity_placement_group_id.setter # type: ignore
    def proximity_placement_group_id(
        self,
        value: typing.Optional[builtins.str],
    ) -> None:
        jsii.set(self, "proximityPlacementGroupId", value)

    @builtins.property # type: ignore
    @jsii.member(jsii_name="rollingUpgradePolicy")
    def rolling_upgrade_policy(
        self,
    ) -> typing.Optional[typing.List["WindowsVirtualMachineScaleSetRollingUpgradePolicy"]]:
        return jsii.get(self, "rollingUpgradePolicy")

    @rolling_upgrade_policy.setter # type: ignore
    def rolling_upgrade_policy(
        self,
        value: typing.Optional[typing.List["WindowsVirtualMachineScaleSetRollingUpgradePolicy"]],
    ) -> None:
        jsii.set(self, "rollingUpgradePolicy", value)

    @builtins.property # type: ignore
    @jsii.member(jsii_name="secret")
    def secret(
        self,
    ) -> typing.Optional[typing.List["WindowsVirtualMachineScaleSetSecret"]]:
        return jsii.get(self, "secret")

    @secret.setter # type: ignore
    def secret(
        self,
        value: typing.Optional[typing.List["WindowsVirtualMachineScaleSetSecret"]],
    ) -> None:
        jsii.set(self, "secret", value)

    @builtins.property # type: ignore
    @jsii.member(jsii_name="singlePlacementGroup")
    def single_placement_group(self) -> typing.Optional[builtins.bool]:
        return jsii.get(self, "singlePlacementGroup")

    @single_placement_group.setter # type: ignore
    def single_placement_group(self, value: typing.Optional[builtins.bool]) -> None:
        jsii.set(self, "singlePlacementGroup", value)

    @builtins.property # type: ignore
    @jsii.member(jsii_name="sourceImageId")
    def source_image_id(self) -> typing.Optional[builtins.str]:
        return jsii.get(self, "sourceImageId")

    @source_image_id.setter # type: ignore
    def source_image_id(self, value: typing.Optional[builtins.str]) -> None:
        jsii.set(self, "sourceImageId", value)

    @builtins.property # type: ignore
    @jsii.member(jsii_name="sourceImageReference")
    def source_image_reference(
        self,
    ) -> typing.Optional[typing.List["WindowsVirtualMachineScaleSetSourceImageReference"]]:
        return jsii.get(self, "sourceImageReference")

    @source_image_reference.setter # type: ignore
    def source_image_reference(
        self,
        value: typing.Optional[typing.List["WindowsVirtualMachineScaleSetSourceImageReference"]],
    ) -> None:
        jsii.set(self, "sourceImageReference", value)

    @builtins.property # type: ignore
    @jsii.member(jsii_name="tags")
    def tags(self) -> typing.Optional[typing.Mapping[builtins.str, builtins.str]]:
        return jsii.get(self, "tags")

    @tags.setter # type: ignore
    def tags(
        self,
        value: typing.Optional[typing.Mapping[builtins.str, builtins.str]],
    ) -> None:
        jsii.set(self, "tags", value)

    @builtins.property # type: ignore
    @jsii.member(jsii_name="timeouts")
    def timeouts(self) -> typing.Optional["WindowsVirtualMachineScaleSetTimeouts"]:
        return jsii.get(self, "timeouts")

    @timeouts.setter # type: ignore
    def timeouts(
        self,
        value: typing.Optional["WindowsVirtualMachineScaleSetTimeouts"],
    ) -> None:
        jsii.set(self, "timeouts", value)

    @builtins.property # type: ignore
    @jsii.member(jsii_name="timezone")
    def timezone(self) -> typing.Optional[builtins.str]:
        return jsii.get(self, "timezone")

    @timezone.setter # type: ignore
    def timezone(self, value: typing.Optional[builtins.str]) -> None:
        jsii.set(self, "timezone", value)

    @builtins.property # type: ignore
    @jsii.member(jsii_name="upgradeMode")
    def upgrade_mode(self) -> typing.Optional[builtins.str]:
        return jsii.get(self, "upgradeMode")

    @upgrade_mode.setter # type: ignore
    def upgrade_mode(self, value: typing.Optional[builtins.str]) -> None:
        jsii.set(self, "upgradeMode", value)

    @builtins.property # type: ignore
    @jsii.member(jsii_name="winrmListener")
    def winrm_listener(
        self,
    ) -> typing.Optional[typing.List["WindowsVirtualMachineScaleSetWinrmListener"]]:
        return jsii.get(self, "winrmListener")

    @winrm_listener.setter # type: ignore
    def winrm_listener(
        self,
        value: typing.Optional[typing.List["WindowsVirtualMachineScaleSetWinrmListener"]],
    ) -> None:
        jsii.set(self, "winrmListener", value)

    @builtins.property # type: ignore
    @jsii.member(jsii_name="zoneBalance")
    def zone_balance(self) -> typing.Optional[builtins.bool]:
        return jsii.get(self, "zoneBalance")

    @zone_balance.setter # type: ignore
    def zone_balance(self, value: typing.Optional[builtins.bool]) -> None:
        jsii.set(self, "zoneBalance", value)

    @builtins.property # type: ignore
    @jsii.member(jsii_name="zones")
    def zones(self) -> typing.Optional[typing.List[builtins.str]]:
        return jsii.get(self, "zones")

    @zones.setter # type: ignore
    def zones(self, value: typing.Optional[typing.List[builtins.str]]) -> None:
        jsii.set(self, "zones", value)


@jsii.data_type(
    jsii_type="@cdktf/provider-azurerm.WindowsVirtualMachineScaleSetAdditionalCapabilities",
    jsii_struct_bases=[],
    name_mapping={"ultra_ssd_enabled": "ultraSsdEnabled"},
)
class WindowsVirtualMachineScaleSetAdditionalCapabilities:
    def __init__(
        self,
        *,
        ultra_ssd_enabled: typing.Optional[builtins.bool] = None,
    ) -> None:
        """
        :param ultra_ssd_enabled: 
        """
        self._values: typing.Dict[str, typing.Any] = {}
        if ultra_ssd_enabled is not None:
            self._values["ultra_ssd_enabled"] = ultra_ssd_enabled

    @builtins.property
    def ultra_ssd_enabled(self) -> typing.Optional[builtins.bool]:
        result = self._values.get("ultra_ssd_enabled")
        return result

    def __eq__(self, rhs: typing.Any) -> builtins.bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs: typing.Any) -> builtins.bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return "WindowsVirtualMachineScaleSetAdditionalCapabilities(%s)" % ", ".join(
            k + "=" + repr(v) for k, v in self._values.items()
        )


@jsii.data_type(
    jsii_type="@cdktf/provider-azurerm.WindowsVirtualMachineScaleSetAdditionalUnattendContent",
    jsii_struct_bases=[],
    name_mapping={"content": "content", "setting": "setting"},
)
class WindowsVirtualMachineScaleSetAdditionalUnattendContent:
    def __init__(self, *, content: builtins.str, setting: builtins.str) -> None:
        """
        :param content: 
        :param setting: 
        """
        self._values: typing.Dict[str, typing.Any] = {
            "content": content,
            "setting": setting,
        }

    @builtins.property
    def content(self) -> builtins.str:
        result = self._values.get("content")
        assert result is not None, "Required property 'content' is missing"
        return result

    @builtins.property
    def setting(self) -> builtins.str:
        result = self._values.get("setting")
        assert result is not None, "Required property 'setting' is missing"
        return result

    def __eq__(self, rhs: typing.Any) -> builtins.bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs: typing.Any) -> builtins.bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return "WindowsVirtualMachineScaleSetAdditionalUnattendContent(%s)" % ", ".join(
            k + "=" + repr(v) for k, v in self._values.items()
        )


@jsii.data_type(
    jsii_type="@cdktf/provider-azurerm.WindowsVirtualMachineScaleSetAutomaticOsUpgradePolicy",
    jsii_struct_bases=[],
    name_mapping={
        "disable_automatic_rollback": "disableAutomaticRollback",
        "enable_automatic_os_upgrade": "enableAutomaticOsUpgrade",
    },
)
class WindowsVirtualMachineScaleSetAutomaticOsUpgradePolicy:
    def __init__(
        self,
        *,
        disable_automatic_rollback: builtins.bool,
        enable_automatic_os_upgrade: builtins.bool,
    ) -> None:
        """
        :param disable_automatic_rollback: 
        :param enable_automatic_os_upgrade: 
        """
        self._values: typing.Dict[str, typing.Any] = {
            "disable_automatic_rollback": disable_automatic_rollback,
            "enable_automatic_os_upgrade": enable_automatic_os_upgrade,
        }

    @builtins.property
    def disable_automatic_rollback(self) -> builtins.bool:
        result = self._values.get("disable_automatic_rollback")
        assert result is not None, "Required property 'disable_automatic_rollback' is missing"
        return result

    @builtins.property
    def enable_automatic_os_upgrade(self) -> builtins.bool:
        result = self._values.get("enable_automatic_os_upgrade")
        assert result is not None, "Required property 'enable_automatic_os_upgrade' is missing"
        return result

    def __eq__(self, rhs: typing.Any) -> builtins.bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs: typing.Any) -> builtins.bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return "WindowsVirtualMachineScaleSetAutomaticOsUpgradePolicy(%s)" % ", ".join(
            k + "=" + repr(v) for k, v in self._values.items()
        )


@jsii.data_type(
    jsii_type="@cdktf/provider-azurerm.WindowsVirtualMachineScaleSetBootDiagnostics",
    jsii_struct_bases=[],
    name_mapping={"storage_account_uri": "storageAccountUri"},
)
class WindowsVirtualMachineScaleSetBootDiagnostics:
    def __init__(self, *, storage_account_uri: builtins.str) -> None:
        """
        :param storage_account_uri: 
        """
        self._values: typing.Dict[str, typing.Any] = {
            "storage_account_uri": storage_account_uri,
        }

    @builtins.property
    def storage_account_uri(self) -> builtins.str:
        result = self._values.get("storage_account_uri")
        assert result is not None, "Required property 'storage_account_uri' is missing"
        return result

    def __eq__(self, rhs: typing.Any) -> builtins.bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs: typing.Any) -> builtins.bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return "WindowsVirtualMachineScaleSetBootDiagnostics(%s)" % ", ".join(
            k + "=" + repr(v) for k, v in self._values.items()
        )


@jsii.data_type(
    jsii_type="@cdktf/provider-azurerm.WindowsVirtualMachineScaleSetConfig",
    jsii_struct_bases=[cdktf.TerraformMetaArguments],
    name_mapping={
        "count": "count",
        "depends_on": "dependsOn",
        "lifecycle": "lifecycle",
        "provider": "provider",
        "admin_password": "adminPassword",
        "admin_username": "adminUsername",
        "instances": "instances",
        "location": "location",
        "name": "name",
        "network_interface": "networkInterface",
        "os_disk": "osDisk",
        "resource_group_name": "resourceGroupName",
        "sku": "sku",
        "additional_capabilities": "additionalCapabilities",
        "additional_unattend_content": "additionalUnattendContent",
        "automatic_os_upgrade_policy": "automaticOsUpgradePolicy",
        "boot_diagnostics": "bootDiagnostics",
        "computer_name_prefix": "computerNamePrefix",
        "custom_data": "customData",
        "data_disk": "dataDisk",
        "do_not_run_extensions_on_overprovisioned_machines": "doNotRunExtensionsOnOverprovisionedMachines",
        "enable_automatic_updates": "enableAutomaticUpdates",
        "eviction_policy": "evictionPolicy",
        "health_probe_id": "healthProbeId",
        "identity": "identity",
        "license_type": "licenseType",
        "max_bid_price": "maxBidPrice",
        "overprovision": "overprovision",
        "plan": "plan",
        "priority": "priority",
        "provision_vm_agent": "provisionVmAgent",
        "proximity_placement_group_id": "proximityPlacementGroupId",
        "rolling_upgrade_policy": "rollingUpgradePolicy",
        "secret": "secret",
        "single_placement_group": "singlePlacementGroup",
        "source_image_id": "sourceImageId",
        "source_image_reference": "sourceImageReference",
        "tags": "tags",
        "timeouts": "timeouts",
        "timezone": "timezone",
        "upgrade_mode": "upgradeMode",
        "winrm_listener": "winrmListener",
        "zone_balance": "zoneBalance",
        "zones": "zones",
    },
)
class WindowsVirtualMachineScaleSetConfig(cdktf.TerraformMetaArguments):
    def __init__(
        self,
        *,
        count: typing.Optional[jsii.Number] = None,
        depends_on: typing.Optional[typing.List[cdktf.TerraformResource]] = None,
        lifecycle: typing.Optional[cdktf.TerraformResourceLifecycle] = None,
        provider: typing.Optional[cdktf.TerraformProvider] = None,
        admin_password: builtins.str,
        admin_username: builtins.str,
        instances: jsii.Number,
        location: builtins.str,
        name: builtins.str,
        network_interface: typing.List["WindowsVirtualMachineScaleSetNetworkInterface"],
        os_disk: typing.List["WindowsVirtualMachineScaleSetOsDisk"],
        resource_group_name: builtins.str,
        sku: builtins.str,
        additional_capabilities: typing.Optional[typing.List[WindowsVirtualMachineScaleSetAdditionalCapabilities]] = None,
        additional_unattend_content: typing.Optional[typing.List[WindowsVirtualMachineScaleSetAdditionalUnattendContent]] = None,
        automatic_os_upgrade_policy: typing.Optional[typing.List[WindowsVirtualMachineScaleSetAutomaticOsUpgradePolicy]] = None,
        boot_diagnostics: typing.Optional[typing.List[WindowsVirtualMachineScaleSetBootDiagnostics]] = None,
        computer_name_prefix: typing.Optional[builtins.str] = None,
        custom_data: typing.Optional[builtins.str] = None,
        data_disk: typing.Optional[typing.List["WindowsVirtualMachineScaleSetDataDisk"]] = None,
        do_not_run_extensions_on_overprovisioned_machines: typing.Optional[builtins.bool] = None,
        enable_automatic_updates: typing.Optional[builtins.bool] = None,
        eviction_policy: typing.Optional[builtins.str] = None,
        health_probe_id: typing.Optional[builtins.str] = None,
        identity: typing.Optional[typing.List["WindowsVirtualMachineScaleSetIdentity"]] = None,
        license_type: typing.Optional[builtins.str] = None,
        max_bid_price: typing.Optional[jsii.Number] = None,
        overprovision: typing.Optional[builtins.bool] = None,
        plan: typing.Optional[typing.List["WindowsVirtualMachineScaleSetPlan"]] = None,
        priority: typing.Optional[builtins.str] = None,
        provision_vm_agent: typing.Optional[builtins.bool] = None,
        proximity_placement_group_id: typing.Optional[builtins.str] = None,
        rolling_upgrade_policy: typing.Optional[typing.List["WindowsVirtualMachineScaleSetRollingUpgradePolicy"]] = None,
        secret: typing.Optional[typing.List["WindowsVirtualMachineScaleSetSecret"]] = None,
        single_placement_group: typing.Optional[builtins.bool] = None,
        source_image_id: typing.Optional[builtins.str] = None,
        source_image_reference: typing.Optional[typing.List["WindowsVirtualMachineScaleSetSourceImageReference"]] = None,
        tags: typing.Optional[typing.Mapping[builtins.str, builtins.str]] = None,
        timeouts: typing.Optional["WindowsVirtualMachineScaleSetTimeouts"] = None,
        timezone: typing.Optional[builtins.str] = None,
        upgrade_mode: typing.Optional[builtins.str] = None,
        winrm_listener: typing.Optional[typing.List["WindowsVirtualMachineScaleSetWinrmListener"]] = None,
        zone_balance: typing.Optional[builtins.bool] = None,
        zones: typing.Optional[typing.List[builtins.str]] = None,
    ) -> None:
        """
        :param count: 
        :param depends_on: 
        :param lifecycle: 
        :param provider: 
        :param admin_password: 
        :param admin_username: 
        :param instances: 
        :param location: 
        :param name: 
        :param network_interface: network_interface block.
        :param os_disk: os_disk block.
        :param resource_group_name: 
        :param sku: 
        :param additional_capabilities: additional_capabilities block.
        :param additional_unattend_content: additional_unattend_content block.
        :param automatic_os_upgrade_policy: automatic_os_upgrade_policy block.
        :param boot_diagnostics: boot_diagnostics block.
        :param computer_name_prefix: 
        :param custom_data: 
        :param data_disk: data_disk block.
        :param do_not_run_extensions_on_overprovisioned_machines: 
        :param enable_automatic_updates: 
        :param eviction_policy: 
        :param health_probe_id: 
        :param identity: identity block.
        :param license_type: 
        :param max_bid_price: 
        :param overprovision: 
        :param plan: plan block.
        :param priority: 
        :param provision_vm_agent: 
        :param proximity_placement_group_id: 
        :param rolling_upgrade_policy: rolling_upgrade_policy block.
        :param secret: secret block.
        :param single_placement_group: 
        :param source_image_id: 
        :param source_image_reference: source_image_reference block.
        :param tags: 
        :param timeouts: timeouts block.
        :param timezone: 
        :param upgrade_mode: 
        :param winrm_listener: winrm_listener block.
        :param zone_balance: 
        :param zones: 
        """
        if isinstance(lifecycle, dict):
            lifecycle = cdktf.TerraformResourceLifecycle(**lifecycle)
        if isinstance(timeouts, dict):
            timeouts = WindowsVirtualMachineScaleSetTimeouts(**timeouts)
        self._values: typing.Dict[str, typing.Any] = {
            "admin_password": admin_password,
            "admin_username": admin_username,
            "instances": instances,
            "location": location,
            "name": name,
            "network_interface": network_interface,
            "os_disk": os_disk,
            "resource_group_name": resource_group_name,
            "sku": sku,
        }
        if count is not None:
            self._values["count"] = count
        if depends_on is not None:
            self._values["depends_on"] = depends_on
        if lifecycle is not None:
            self._values["lifecycle"] = lifecycle
        if provider is not None:
            self._values["provider"] = provider
        if additional_capabilities is not None:
            self._values["additional_capabilities"] = additional_capabilities
        if additional_unattend_content is not None:
            self._values["additional_unattend_content"] = additional_unattend_content
        if automatic_os_upgrade_policy is not None:
            self._values["automatic_os_upgrade_policy"] = automatic_os_upgrade_policy
        if boot_diagnostics is not None:
            self._values["boot_diagnostics"] = boot_diagnostics
        if computer_name_prefix is not None:
            self._values["computer_name_prefix"] = computer_name_prefix
        if custom_data is not None:
            self._values["custom_data"] = custom_data
        if data_disk is not None:
            self._values["data_disk"] = data_disk
        if do_not_run_extensions_on_overprovisioned_machines is not None:
            self._values["do_not_run_extensions_on_overprovisioned_machines"] = do_not_run_extensions_on_overprovisioned_machines
        if enable_automatic_updates is not None:
            self._values["enable_automatic_updates"] = enable_automatic_updates
        if eviction_policy is not None:
            self._values["eviction_policy"] = eviction_policy
        if health_probe_id is not None:
            self._values["health_probe_id"] = health_probe_id
        if identity is not None:
            self._values["identity"] = identity
        if license_type is not None:
            self._values["license_type"] = license_type
        if max_bid_price is not None:
            self._values["max_bid_price"] = max_bid_price
        if overprovision is not None:
            self._values["overprovision"] = overprovision
        if plan is not None:
            self._values["plan"] = plan
        if priority is not None:
            self._values["priority"] = priority
        if provision_vm_agent is not None:
            self._values["provision_vm_agent"] = provision_vm_agent
        if proximity_placement_group_id is not None:
            self._values["proximity_placement_group_id"] = proximity_placement_group_id
        if rolling_upgrade_policy is not None:
            self._values["rolling_upgrade_policy"] = rolling_upgrade_policy
        if secret is not None:
            self._values["secret"] = secret
        if single_placement_group is not None:
            self._values["single_placement_group"] = single_placement_group
        if source_image_id is not None:
            self._values["source_image_id"] = source_image_id
        if source_image_reference is not None:
            self._values["source_image_reference"] = source_image_reference
        if tags is not None:
            self._values["tags"] = tags
        if timeouts is not None:
            self._values["timeouts"] = timeouts
        if timezone is not None:
            self._values["timezone"] = timezone
        if upgrade_mode is not None:
            self._values["upgrade_mode"] = upgrade_mode
        if winrm_listener is not None:
            self._values["winrm_listener"] = winrm_listener
        if zone_balance is not None:
            self._values["zone_balance"] = zone_balance
        if zones is not None:
            self._values["zones"] = zones

    @builtins.property
    def count(self) -> typing.Optional[jsii.Number]:
        """
        :stability: experimental
        """
        result = self._values.get("count")
        return result

    @builtins.property
    def depends_on(self) -> typing.Optional[typing.List[cdktf.TerraformResource]]:
        """
        :stability: experimental
        """
        result = self._values.get("depends_on")
        return result

    @builtins.property
    def lifecycle(self) -> typing.Optional[cdktf.TerraformResourceLifecycle]:
        """
        :stability: experimental
        """
        result = self._values.get("lifecycle")
        return result

    @builtins.property
    def provider(self) -> typing.Optional[cdktf.TerraformProvider]:
        """
        :stability: experimental
        """
        result = self._values.get("provider")
        return result

    @builtins.property
    def admin_password(self) -> builtins.str:
        result = self._values.get("admin_password")
        assert result is not None, "Required property 'admin_password' is missing"
        return result

    @builtins.property
    def admin_username(self) -> builtins.str:
        result = self._values.get("admin_username")
        assert result is not None, "Required property 'admin_username' is missing"
        return result

    @builtins.property
    def instances(self) -> jsii.Number:
        result = self._values.get("instances")
        assert result is not None, "Required property 'instances' is missing"
        return result

    @builtins.property
    def location(self) -> builtins.str:
        result = self._values.get("location")
        assert result is not None, "Required property 'location' is missing"
        return result

    @builtins.property
    def name(self) -> builtins.str:
        result = self._values.get("name")
        assert result is not None, "Required property 'name' is missing"
        return result

    @builtins.property
    def network_interface(
        self,
    ) -> typing.List["WindowsVirtualMachineScaleSetNetworkInterface"]:
        """network_interface block."""
        result = self._values.get("network_interface")
        assert result is not None, "Required property 'network_interface' is missing"
        return result

    @builtins.property
    def os_disk(self) -> typing.List["WindowsVirtualMachineScaleSetOsDisk"]:
        """os_disk block."""
        result = self._values.get("os_disk")
        assert result is not None, "Required property 'os_disk' is missing"
        return result

    @builtins.property
    def resource_group_name(self) -> builtins.str:
        result = self._values.get("resource_group_name")
        assert result is not None, "Required property 'resource_group_name' is missing"
        return result

    @builtins.property
    def sku(self) -> builtins.str:
        result = self._values.get("sku")
        assert result is not None, "Required property 'sku' is missing"
        return result

    @builtins.property
    def additional_capabilities(
        self,
    ) -> typing.Optional[typing.List[WindowsVirtualMachineScaleSetAdditionalCapabilities]]:
        """additional_capabilities block."""
        result = self._values.get("additional_capabilities")
        return result

    @builtins.property
    def additional_unattend_content(
        self,
    ) -> typing.Optional[typing.List[WindowsVirtualMachineScaleSetAdditionalUnattendContent]]:
        """additional_unattend_content block."""
        result = self._values.get("additional_unattend_content")
        return result

    @builtins.property
    def automatic_os_upgrade_policy(
        self,
    ) -> typing.Optional[typing.List[WindowsVirtualMachineScaleSetAutomaticOsUpgradePolicy]]:
        """automatic_os_upgrade_policy block."""
        result = self._values.get("automatic_os_upgrade_policy")
        return result

    @builtins.property
    def boot_diagnostics(
        self,
    ) -> typing.Optional[typing.List[WindowsVirtualMachineScaleSetBootDiagnostics]]:
        """boot_diagnostics block."""
        result = self._values.get("boot_diagnostics")
        return result

    @builtins.property
    def computer_name_prefix(self) -> typing.Optional[builtins.str]:
        result = self._values.get("computer_name_prefix")
        return result

    @builtins.property
    def custom_data(self) -> typing.Optional[builtins.str]:
        result = self._values.get("custom_data")
        return result

    @builtins.property
    def data_disk(
        self,
    ) -> typing.Optional[typing.List["WindowsVirtualMachineScaleSetDataDisk"]]:
        """data_disk block."""
        result = self._values.get("data_disk")
        return result

    @builtins.property
    def do_not_run_extensions_on_overprovisioned_machines(
        self,
    ) -> typing.Optional[builtins.bool]:
        result = self._values.get("do_not_run_extensions_on_overprovisioned_machines")
        return result

    @builtins.property
    def enable_automatic_updates(self) -> typing.Optional[builtins.bool]:
        result = self._values.get("enable_automatic_updates")
        return result

    @builtins.property
    def eviction_policy(self) -> typing.Optional[builtins.str]:
        result = self._values.get("eviction_policy")
        return result

    @builtins.property
    def health_probe_id(self) -> typing.Optional[builtins.str]:
        result = self._values.get("health_probe_id")
        return result

    @builtins.property
    def identity(
        self,
    ) -> typing.Optional[typing.List["WindowsVirtualMachineScaleSetIdentity"]]:
        """identity block."""
        result = self._values.get("identity")
        return result

    @builtins.property
    def license_type(self) -> typing.Optional[builtins.str]:
        result = self._values.get("license_type")
        return result

    @builtins.property
    def max_bid_price(self) -> typing.Optional[jsii.Number]:
        result = self._values.get("max_bid_price")
        return result

    @builtins.property
    def overprovision(self) -> typing.Optional[builtins.bool]:
        result = self._values.get("overprovision")
        return result

    @builtins.property
    def plan(self) -> typing.Optional[typing.List["WindowsVirtualMachineScaleSetPlan"]]:
        """plan block."""
        result = self._values.get("plan")
        return result

    @builtins.property
    def priority(self) -> typing.Optional[builtins.str]:
        result = self._values.get("priority")
        return result

    @builtins.property
    def provision_vm_agent(self) -> typing.Optional[builtins.bool]:
        result = self._values.get("provision_vm_agent")
        return result

    @builtins.property
    def proximity_placement_group_id(self) -> typing.Optional[builtins.str]:
        result = self._values.get("proximity_placement_group_id")
        return result

    @builtins.property
    def rolling_upgrade_policy(
        self,
    ) -> typing.Optional[typing.List["WindowsVirtualMachineScaleSetRollingUpgradePolicy"]]:
        """rolling_upgrade_policy block."""
        result = self._values.get("rolling_upgrade_policy")
        return result

    @builtins.property
    def secret(
        self,
    ) -> typing.Optional[typing.List["WindowsVirtualMachineScaleSetSecret"]]:
        """secret block."""
        result = self._values.get("secret")
        return result

    @builtins.property
    def single_placement_group(self) -> typing.Optional[builtins.bool]:
        result = self._values.get("single_placement_group")
        return result

    @builtins.property
    def source_image_id(self) -> typing.Optional[builtins.str]:
        result = self._values.get("source_image_id")
        return result

    @builtins.property
    def source_image_reference(
        self,
    ) -> typing.Optional[typing.List["WindowsVirtualMachineScaleSetSourceImageReference"]]:
        """source_image_reference block."""
        result = self._values.get("source_image_reference")
        return result

    @builtins.property
    def tags(self) -> typing.Optional[typing.Mapping[builtins.str, builtins.str]]:
        result = self._values.get("tags")
        return result

    @builtins.property
    def timeouts(self) -> typing.Optional["WindowsVirtualMachineScaleSetTimeouts"]:
        """timeouts block."""
        result = self._values.get("timeouts")
        return result

    @builtins.property
    def timezone(self) -> typing.Optional[builtins.str]:
        result = self._values.get("timezone")
        return result

    @builtins.property
    def upgrade_mode(self) -> typing.Optional[builtins.str]:
        result = self._values.get("upgrade_mode")
        return result

    @builtins.property
    def winrm_listener(
        self,
    ) -> typing.Optional[typing.List["WindowsVirtualMachineScaleSetWinrmListener"]]:
        """winrm_listener block."""
        result = self._values.get("winrm_listener")
        return result

    @builtins.property
    def zone_balance(self) -> typing.Optional[builtins.bool]:
        result = self._values.get("zone_balance")
        return result

    @builtins.property
    def zones(self) -> typing.Optional[typing.List[builtins.str]]:
        result = self._values.get("zones")
        return result

    def __eq__(self, rhs: typing.Any) -> builtins.bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs: typing.Any) -> builtins.bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return "WindowsVirtualMachineScaleSetConfig(%s)" % ", ".join(
            k + "=" + repr(v) for k, v in self._values.items()
        )


@jsii.data_type(
    jsii_type="@cdktf/provider-azurerm.WindowsVirtualMachineScaleSetDataDisk",
    jsii_struct_bases=[],
    name_mapping={
        "caching": "caching",
        "disk_size_gb": "diskSizeGb",
        "lun": "lun",
        "storage_account_type": "storageAccountType",
        "disk_encryption_set_id": "diskEncryptionSetId",
        "write_accelerator_enabled": "writeAcceleratorEnabled",
    },
)
class WindowsVirtualMachineScaleSetDataDisk:
    def __init__(
        self,
        *,
        caching: builtins.str,
        disk_size_gb: jsii.Number,
        lun: jsii.Number,
        storage_account_type: builtins.str,
        disk_encryption_set_id: typing.Optional[builtins.str] = None,
        write_accelerator_enabled: typing.Optional[builtins.bool] = None,
    ) -> None:
        """
        :param caching: 
        :param disk_size_gb: 
        :param lun: 
        :param storage_account_type: 
        :param disk_encryption_set_id: 
        :param write_accelerator_enabled: 
        """
        self._values: typing.Dict[str, typing.Any] = {
            "caching": caching,
            "disk_size_gb": disk_size_gb,
            "lun": lun,
            "storage_account_type": storage_account_type,
        }
        if disk_encryption_set_id is not None:
            self._values["disk_encryption_set_id"] = disk_encryption_set_id
        if write_accelerator_enabled is not None:
            self._values["write_accelerator_enabled"] = write_accelerator_enabled

    @builtins.property
    def caching(self) -> builtins.str:
        result = self._values.get("caching")
        assert result is not None, "Required property 'caching' is missing"
        return result

    @builtins.property
    def disk_size_gb(self) -> jsii.Number:
        result = self._values.get("disk_size_gb")
        assert result is not None, "Required property 'disk_size_gb' is missing"
        return result

    @builtins.property
    def lun(self) -> jsii.Number:
        result = self._values.get("lun")
        assert result is not None, "Required property 'lun' is missing"
        return result

    @builtins.property
    def storage_account_type(self) -> builtins.str:
        result = self._values.get("storage_account_type")
        assert result is not None, "Required property 'storage_account_type' is missing"
        return result

    @builtins.property
    def disk_encryption_set_id(self) -> typing.Optional[builtins.str]:
        result = self._values.get("disk_encryption_set_id")
        return result

    @builtins.property
    def write_accelerator_enabled(self) -> typing.Optional[builtins.bool]:
        result = self._values.get("write_accelerator_enabled")
        return result

    def __eq__(self, rhs: typing.Any) -> builtins.bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs: typing.Any) -> builtins.bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return "WindowsVirtualMachineScaleSetDataDisk(%s)" % ", ".join(
            k + "=" + repr(v) for k, v in self._values.items()
        )


@jsii.data_type(
    jsii_type="@cdktf/provider-azurerm.WindowsVirtualMachineScaleSetIdentity",
    jsii_struct_bases=[],
    name_mapping={"type": "type", "identity_ids": "identityIds"},
)
class WindowsVirtualMachineScaleSetIdentity:
    def __init__(
        self,
        *,
        type: builtins.str,
        identity_ids: typing.Optional[typing.List[builtins.str]] = None,
    ) -> None:
        """
        :param type: 
        :param identity_ids: 
        """
        self._values: typing.Dict[str, typing.Any] = {
            "type": type,
        }
        if identity_ids is not None:
            self._values["identity_ids"] = identity_ids

    @builtins.property
    def type(self) -> builtins.str:
        result = self._values.get("type")
        assert result is not None, "Required property 'type' is missing"
        return result

    @builtins.property
    def identity_ids(self) -> typing.Optional[typing.List[builtins.str]]:
        result = self._values.get("identity_ids")
        return result

    def __eq__(self, rhs: typing.Any) -> builtins.bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs: typing.Any) -> builtins.bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return "WindowsVirtualMachineScaleSetIdentity(%s)" % ", ".join(
            k + "=" + repr(v) for k, v in self._values.items()
        )


@jsii.data_type(
    jsii_type="@cdktf/provider-azurerm.WindowsVirtualMachineScaleSetNetworkInterface",
    jsii_struct_bases=[],
    name_mapping={
        "ip_configuration": "ipConfiguration",
        "name": "name",
        "dns_servers": "dnsServers",
        "enable_accelerated_networking": "enableAcceleratedNetworking",
        "enable_ip_forwarding": "enableIpForwarding",
        "network_security_group_id": "networkSecurityGroupId",
        "primary": "primary",
    },
)
class WindowsVirtualMachineScaleSetNetworkInterface:
    def __init__(
        self,
        *,
        ip_configuration: typing.List["WindowsVirtualMachineScaleSetNetworkInterfaceIpConfiguration"],
        name: builtins.str,
        dns_servers: typing.Optional[typing.List[builtins.str]] = None,
        enable_accelerated_networking: typing.Optional[builtins.bool] = None,
        enable_ip_forwarding: typing.Optional[builtins.bool] = None,
        network_security_group_id: typing.Optional[builtins.str] = None,
        primary: typing.Optional[builtins.bool] = None,
    ) -> None:
        """
        :param ip_configuration: ip_configuration block.
        :param name: 
        :param dns_servers: 
        :param enable_accelerated_networking: 
        :param enable_ip_forwarding: 
        :param network_security_group_id: 
        :param primary: 
        """
        self._values: typing.Dict[str, typing.Any] = {
            "ip_configuration": ip_configuration,
            "name": name,
        }
        if dns_servers is not None:
            self._values["dns_servers"] = dns_servers
        if enable_accelerated_networking is not None:
            self._values["enable_accelerated_networking"] = enable_accelerated_networking
        if enable_ip_forwarding is not None:
            self._values["enable_ip_forwarding"] = enable_ip_forwarding
        if network_security_group_id is not None:
            self._values["network_security_group_id"] = network_security_group_id
        if primary is not None:
            self._values["primary"] = primary

    @builtins.property
    def ip_configuration(
        self,
    ) -> typing.List["WindowsVirtualMachineScaleSetNetworkInterfaceIpConfiguration"]:
        """ip_configuration block."""
        result = self._values.get("ip_configuration")
        assert result is not None, "Required property 'ip_configuration' is missing"
        return result

    @builtins.property
    def name(self) -> builtins.str:
        result = self._values.get("name")
        assert result is not None, "Required property 'name' is missing"
        return result

    @builtins.property
    def dns_servers(self) -> typing.Optional[typing.List[builtins.str]]:
        result = self._values.get("dns_servers")
        return result

    @builtins.property
    def enable_accelerated_networking(self) -> typing.Optional[builtins.bool]:
        result = self._values.get("enable_accelerated_networking")
        return result

    @builtins.property
    def enable_ip_forwarding(self) -> typing.Optional[builtins.bool]:
        result = self._values.get("enable_ip_forwarding")
        return result

    @builtins.property
    def network_security_group_id(self) -> typing.Optional[builtins.str]:
        result = self._values.get("network_security_group_id")
        return result

    @builtins.property
    def primary(self) -> typing.Optional[builtins.bool]:
        result = self._values.get("primary")
        return result

    def __eq__(self, rhs: typing.Any) -> builtins.bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs: typing.Any) -> builtins.bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return "WindowsVirtualMachineScaleSetNetworkInterface(%s)" % ", ".join(
            k + "=" + repr(v) for k, v in self._values.items()
        )


@jsii.data_type(
    jsii_type="@cdktf/provider-azurerm.WindowsVirtualMachineScaleSetNetworkInterfaceIpConfiguration",
    jsii_struct_bases=[],
    name_mapping={
        "name": "name",
        "application_gateway_backend_address_pool_ids": "applicationGatewayBackendAddressPoolIds",
        "application_security_group_ids": "applicationSecurityGroupIds",
        "load_balancer_backend_address_pool_ids": "loadBalancerBackendAddressPoolIds",
        "load_balancer_inbound_nat_rules_ids": "loadBalancerInboundNatRulesIds",
        "primary": "primary",
        "public_ip_address": "publicIpAddress",
        "subnet_id": "subnetId",
        "version": "version",
    },
)
class WindowsVirtualMachineScaleSetNetworkInterfaceIpConfiguration:
    def __init__(
        self,
        *,
        name: builtins.str,
        application_gateway_backend_address_pool_ids: typing.Optional[typing.List[builtins.str]] = None,
        application_security_group_ids: typing.Optional[typing.List[builtins.str]] = None,
        load_balancer_backend_address_pool_ids: typing.Optional[typing.List[builtins.str]] = None,
        load_balancer_inbound_nat_rules_ids: typing.Optional[typing.List[builtins.str]] = None,
        primary: typing.Optional[builtins.bool] = None,
        public_ip_address: typing.Optional[typing.List["WindowsVirtualMachineScaleSetNetworkInterfaceIpConfigurationPublicIpAddress"]] = None,
        subnet_id: typing.Optional[builtins.str] = None,
        version: typing.Optional[builtins.str] = None,
    ) -> None:
        """
        :param name: 
        :param application_gateway_backend_address_pool_ids: 
        :param application_security_group_ids: 
        :param load_balancer_backend_address_pool_ids: 
        :param load_balancer_inbound_nat_rules_ids: 
        :param primary: 
        :param public_ip_address: public_ip_address block.
        :param subnet_id: 
        :param version: 
        """
        self._values: typing.Dict[str, typing.Any] = {
            "name": name,
        }
        if application_gateway_backend_address_pool_ids is not None:
            self._values["application_gateway_backend_address_pool_ids"] = application_gateway_backend_address_pool_ids
        if application_security_group_ids is not None:
            self._values["application_security_group_ids"] = application_security_group_ids
        if load_balancer_backend_address_pool_ids is not None:
            self._values["load_balancer_backend_address_pool_ids"] = load_balancer_backend_address_pool_ids
        if load_balancer_inbound_nat_rules_ids is not None:
            self._values["load_balancer_inbound_nat_rules_ids"] = load_balancer_inbound_nat_rules_ids
        if primary is not None:
            self._values["primary"] = primary
        if public_ip_address is not None:
            self._values["public_ip_address"] = public_ip_address
        if subnet_id is not None:
            self._values["subnet_id"] = subnet_id
        if version is not None:
            self._values["version"] = version

    @builtins.property
    def name(self) -> builtins.str:
        result = self._values.get("name")
        assert result is not None, "Required property 'name' is missing"
        return result

    @builtins.property
    def application_gateway_backend_address_pool_ids(
        self,
    ) -> typing.Optional[typing.List[builtins.str]]:
        result = self._values.get("application_gateway_backend_address_pool_ids")
        return result

    @builtins.property
    def application_security_group_ids(
        self,
    ) -> typing.Optional[typing.List[builtins.str]]:
        result = self._values.get("application_security_group_ids")
        return result

    @builtins.property
    def load_balancer_backend_address_pool_ids(
        self,
    ) -> typing.Optional[typing.List[builtins.str]]:
        result = self._values.get("load_balancer_backend_address_pool_ids")
        return result

    @builtins.property
    def load_balancer_inbound_nat_rules_ids(
        self,
    ) -> typing.Optional[typing.List[builtins.str]]:
        result = self._values.get("load_balancer_inbound_nat_rules_ids")
        return result

    @builtins.property
    def primary(self) -> typing.Optional[builtins.bool]:
        result = self._values.get("primary")
        return result

    @builtins.property
    def public_ip_address(
        self,
    ) -> typing.Optional[typing.List["WindowsVirtualMachineScaleSetNetworkInterfaceIpConfigurationPublicIpAddress"]]:
        """public_ip_address block."""
        result = self._values.get("public_ip_address")
        return result

    @builtins.property
    def subnet_id(self) -> typing.Optional[builtins.str]:
        result = self._values.get("subnet_id")
        return result

    @builtins.property
    def version(self) -> typing.Optional[builtins.str]:
        result = self._values.get("version")
        return result

    def __eq__(self, rhs: typing.Any) -> builtins.bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs: typing.Any) -> builtins.bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return "WindowsVirtualMachineScaleSetNetworkInterfaceIpConfiguration(%s)" % ", ".join(
            k + "=" + repr(v) for k, v in self._values.items()
        )


@jsii.data_type(
    jsii_type="@cdktf/provider-azurerm.WindowsVirtualMachineScaleSetNetworkInterfaceIpConfigurationPublicIpAddress",
    jsii_struct_bases=[],
    name_mapping={
        "name": "name",
        "domain_name_label": "domainNameLabel",
        "idle_timeout_in_minutes": "idleTimeoutInMinutes",
        "ip_tag": "ipTag",
        "public_ip_prefix_id": "publicIpPrefixId",
    },
)
class WindowsVirtualMachineScaleSetNetworkInterfaceIpConfigurationPublicIpAddress:
    def __init__(
        self,
        *,
        name: builtins.str,
        domain_name_label: typing.Optional[builtins.str] = None,
        idle_timeout_in_minutes: typing.Optional[jsii.Number] = None,
        ip_tag: typing.Optional[typing.List["WindowsVirtualMachineScaleSetNetworkInterfaceIpConfigurationPublicIpAddressIpTag"]] = None,
        public_ip_prefix_id: typing.Optional[builtins.str] = None,
    ) -> None:
        """
        :param name: 
        :param domain_name_label: 
        :param idle_timeout_in_minutes: 
        :param ip_tag: ip_tag block.
        :param public_ip_prefix_id: 
        """
        self._values: typing.Dict[str, typing.Any] = {
            "name": name,
        }
        if domain_name_label is not None:
            self._values["domain_name_label"] = domain_name_label
        if idle_timeout_in_minutes is not None:
            self._values["idle_timeout_in_minutes"] = idle_timeout_in_minutes
        if ip_tag is not None:
            self._values["ip_tag"] = ip_tag
        if public_ip_prefix_id is not None:
            self._values["public_ip_prefix_id"] = public_ip_prefix_id

    @builtins.property
    def name(self) -> builtins.str:
        result = self._values.get("name")
        assert result is not None, "Required property 'name' is missing"
        return result

    @builtins.property
    def domain_name_label(self) -> typing.Optional[builtins.str]:
        result = self._values.get("domain_name_label")
        return result

    @builtins.property
    def idle_timeout_in_minutes(self) -> typing.Optional[jsii.Number]:
        result = self._values.get("idle_timeout_in_minutes")
        return result

    @builtins.property
    def ip_tag(
        self,
    ) -> typing.Optional[typing.List["WindowsVirtualMachineScaleSetNetworkInterfaceIpConfigurationPublicIpAddressIpTag"]]:
        """ip_tag block."""
        result = self._values.get("ip_tag")
        return result

    @builtins.property
    def public_ip_prefix_id(self) -> typing.Optional[builtins.str]:
        result = self._values.get("public_ip_prefix_id")
        return result

    def __eq__(self, rhs: typing.Any) -> builtins.bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs: typing.Any) -> builtins.bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return "WindowsVirtualMachineScaleSetNetworkInterfaceIpConfigurationPublicIpAddress(%s)" % ", ".join(
            k + "=" + repr(v) for k, v in self._values.items()
        )


@jsii.data_type(
    jsii_type="@cdktf/provider-azurerm.WindowsVirtualMachineScaleSetNetworkInterfaceIpConfigurationPublicIpAddressIpTag",
    jsii_struct_bases=[],
    name_mapping={"tag": "tag", "type": "type"},
)
class WindowsVirtualMachineScaleSetNetworkInterfaceIpConfigurationPublicIpAddressIpTag:
    def __init__(self, *, tag: builtins.str, type: builtins.str) -> None:
        """
        :param tag: 
        :param type: 
        """
        self._values: typing.Dict[str, typing.Any] = {
            "tag": tag,
            "type": type,
        }

    @builtins.property
    def tag(self) -> builtins.str:
        result = self._values.get("tag")
        assert result is not None, "Required property 'tag' is missing"
        return result

    @builtins.property
    def type(self) -> builtins.str:
        result = self._values.get("type")
        assert result is not None, "Required property 'type' is missing"
        return result

    def __eq__(self, rhs: typing.Any) -> builtins.bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs: typing.Any) -> builtins.bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return "WindowsVirtualMachineScaleSetNetworkInterfaceIpConfigurationPublicIpAddressIpTag(%s)" % ", ".join(
            k + "=" + repr(v) for k, v in self._values.items()
        )


@jsii.data_type(
    jsii_type="@cdktf/provider-azurerm.WindowsVirtualMachineScaleSetOsDisk",
    jsii_struct_bases=[],
    name_mapping={
        "caching": "caching",
        "storage_account_type": "storageAccountType",
        "diff_disk_settings": "diffDiskSettings",
        "disk_encryption_set_id": "diskEncryptionSetId",
        "disk_size_gb": "diskSizeGb",
        "write_accelerator_enabled": "writeAcceleratorEnabled",
    },
)
class WindowsVirtualMachineScaleSetOsDisk:
    def __init__(
        self,
        *,
        caching: builtins.str,
        storage_account_type: builtins.str,
        diff_disk_settings: typing.Optional[typing.List["WindowsVirtualMachineScaleSetOsDiskDiffDiskSettings"]] = None,
        disk_encryption_set_id: typing.Optional[builtins.str] = None,
        disk_size_gb: typing.Optional[jsii.Number] = None,
        write_accelerator_enabled: typing.Optional[builtins.bool] = None,
    ) -> None:
        """
        :param caching: 
        :param storage_account_type: 
        :param diff_disk_settings: diff_disk_settings block.
        :param disk_encryption_set_id: 
        :param disk_size_gb: 
        :param write_accelerator_enabled: 
        """
        self._values: typing.Dict[str, typing.Any] = {
            "caching": caching,
            "storage_account_type": storage_account_type,
        }
        if diff_disk_settings is not None:
            self._values["diff_disk_settings"] = diff_disk_settings
        if disk_encryption_set_id is not None:
            self._values["disk_encryption_set_id"] = disk_encryption_set_id
        if disk_size_gb is not None:
            self._values["disk_size_gb"] = disk_size_gb
        if write_accelerator_enabled is not None:
            self._values["write_accelerator_enabled"] = write_accelerator_enabled

    @builtins.property
    def caching(self) -> builtins.str:
        result = self._values.get("caching")
        assert result is not None, "Required property 'caching' is missing"
        return result

    @builtins.property
    def storage_account_type(self) -> builtins.str:
        result = self._values.get("storage_account_type")
        assert result is not None, "Required property 'storage_account_type' is missing"
        return result

    @builtins.property
    def diff_disk_settings(
        self,
    ) -> typing.Optional[typing.List["WindowsVirtualMachineScaleSetOsDiskDiffDiskSettings"]]:
        """diff_disk_settings block."""
        result = self._values.get("diff_disk_settings")
        return result

    @builtins.property
    def disk_encryption_set_id(self) -> typing.Optional[builtins.str]:
        result = self._values.get("disk_encryption_set_id")
        return result

    @builtins.property
    def disk_size_gb(self) -> typing.Optional[jsii.Number]:
        result = self._values.get("disk_size_gb")
        return result

    @builtins.property
    def write_accelerator_enabled(self) -> typing.Optional[builtins.bool]:
        result = self._values.get("write_accelerator_enabled")
        return result

    def __eq__(self, rhs: typing.Any) -> builtins.bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs: typing.Any) -> builtins.bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return "WindowsVirtualMachineScaleSetOsDisk(%s)" % ", ".join(
            k + "=" + repr(v) for k, v in self._values.items()
        )


@jsii.data_type(
    jsii_type="@cdktf/provider-azurerm.WindowsVirtualMachineScaleSetOsDiskDiffDiskSettings",
    jsii_struct_bases=[],
    name_mapping={"option": "option"},
)
class WindowsVirtualMachineScaleSetOsDiskDiffDiskSettings:
    def __init__(self, *, option: builtins.str) -> None:
        """
        :param option: 
        """
        self._values: typing.Dict[str, typing.Any] = {
            "option": option,
        }

    @builtins.property
    def option(self) -> builtins.str:
        result = self._values.get("option")
        assert result is not None, "Required property 'option' is missing"
        return result

    def __eq__(self, rhs: typing.Any) -> builtins.bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs: typing.Any) -> builtins.bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return "WindowsVirtualMachineScaleSetOsDiskDiffDiskSettings(%s)" % ", ".join(
            k + "=" + repr(v) for k, v in self._values.items()
        )


@jsii.data_type(
    jsii_type="@cdktf/provider-azurerm.WindowsVirtualMachineScaleSetPlan",
    jsii_struct_bases=[],
    name_mapping={"name": "name", "product": "product", "publisher": "publisher"},
)
class WindowsVirtualMachineScaleSetPlan:
    def __init__(
        self,
        *,
        name: builtins.str,
        product: builtins.str,
        publisher: builtins.str,
    ) -> None:
        """
        :param name: 
        :param product: 
        :param publisher: 
        """
        self._values: typing.Dict[str, typing.Any] = {
            "name": name,
            "product": product,
            "publisher": publisher,
        }

    @builtins.property
    def name(self) -> builtins.str:
        result = self._values.get("name")
        assert result is not None, "Required property 'name' is missing"
        return result

    @builtins.property
    def product(self) -> builtins.str:
        result = self._values.get("product")
        assert result is not None, "Required property 'product' is missing"
        return result

    @builtins.property
    def publisher(self) -> builtins.str:
        result = self._values.get("publisher")
        assert result is not None, "Required property 'publisher' is missing"
        return result

    def __eq__(self, rhs: typing.Any) -> builtins.bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs: typing.Any) -> builtins.bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return "WindowsVirtualMachineScaleSetPlan(%s)" % ", ".join(
            k + "=" + repr(v) for k, v in self._values.items()
        )


@jsii.data_type(
    jsii_type="@cdktf/provider-azurerm.WindowsVirtualMachineScaleSetRollingUpgradePolicy",
    jsii_struct_bases=[],
    name_mapping={
        "max_batch_instance_percent": "maxBatchInstancePercent",
        "max_unhealthy_instance_percent": "maxUnhealthyInstancePercent",
        "max_unhealthy_upgraded_instance_percent": "maxUnhealthyUpgradedInstancePercent",
        "pause_time_between_batches": "pauseTimeBetweenBatches",
    },
)
class WindowsVirtualMachineScaleSetRollingUpgradePolicy:
    def __init__(
        self,
        *,
        max_batch_instance_percent: jsii.Number,
        max_unhealthy_instance_percent: jsii.Number,
        max_unhealthy_upgraded_instance_percent: jsii.Number,
        pause_time_between_batches: builtins.str,
    ) -> None:
        """
        :param max_batch_instance_percent: 
        :param max_unhealthy_instance_percent: 
        :param max_unhealthy_upgraded_instance_percent: 
        :param pause_time_between_batches: 
        """
        self._values: typing.Dict[str, typing.Any] = {
            "max_batch_instance_percent": max_batch_instance_percent,
            "max_unhealthy_instance_percent": max_unhealthy_instance_percent,
            "max_unhealthy_upgraded_instance_percent": max_unhealthy_upgraded_instance_percent,
            "pause_time_between_batches": pause_time_between_batches,
        }

    @builtins.property
    def max_batch_instance_percent(self) -> jsii.Number:
        result = self._values.get("max_batch_instance_percent")
        assert result is not None, "Required property 'max_batch_instance_percent' is missing"
        return result

    @builtins.property
    def max_unhealthy_instance_percent(self) -> jsii.Number:
        result = self._values.get("max_unhealthy_instance_percent")
        assert result is not None, "Required property 'max_unhealthy_instance_percent' is missing"
        return result

    @builtins.property
    def max_unhealthy_upgraded_instance_percent(self) -> jsii.Number:
        result = self._values.get("max_unhealthy_upgraded_instance_percent")
        assert result is not None, "Required property 'max_unhealthy_upgraded_instance_percent' is missing"
        return result

    @builtins.property
    def pause_time_between_batches(self) -> builtins.str:
        result = self._values.get("pause_time_between_batches")
        assert result is not None, "Required property 'pause_time_between_batches' is missing"
        return result

    def __eq__(self, rhs: typing.Any) -> builtins.bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs: typing.Any) -> builtins.bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return "WindowsVirtualMachineScaleSetRollingUpgradePolicy(%s)" % ", ".join(
            k + "=" + repr(v) for k, v in self._values.items()
        )


@jsii.data_type(
    jsii_type="@cdktf/provider-azurerm.WindowsVirtualMachineScaleSetSecret",
    jsii_struct_bases=[],
    name_mapping={"certificate": "certificate", "key_vault_id": "keyVaultId"},
)
class WindowsVirtualMachineScaleSetSecret:
    def __init__(
        self,
        *,
        certificate: typing.List["WindowsVirtualMachineScaleSetSecretCertificate"],
        key_vault_id: builtins.str,
    ) -> None:
        """
        :param certificate: certificate block.
        :param key_vault_id: 
        """
        self._values: typing.Dict[str, typing.Any] = {
            "certificate": certificate,
            "key_vault_id": key_vault_id,
        }

    @builtins.property
    def certificate(
        self,
    ) -> typing.List["WindowsVirtualMachineScaleSetSecretCertificate"]:
        """certificate block."""
        result = self._values.get("certificate")
        assert result is not None, "Required property 'certificate' is missing"
        return result

    @builtins.property
    def key_vault_id(self) -> builtins.str:
        result = self._values.get("key_vault_id")
        assert result is not None, "Required property 'key_vault_id' is missing"
        return result

    def __eq__(self, rhs: typing.Any) -> builtins.bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs: typing.Any) -> builtins.bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return "WindowsVirtualMachineScaleSetSecret(%s)" % ", ".join(
            k + "=" + repr(v) for k, v in self._values.items()
        )


@jsii.data_type(
    jsii_type="@cdktf/provider-azurerm.WindowsVirtualMachineScaleSetSecretCertificate",
    jsii_struct_bases=[],
    name_mapping={"store": "store", "url": "url"},
)
class WindowsVirtualMachineScaleSetSecretCertificate:
    def __init__(self, *, store: builtins.str, url: builtins.str) -> None:
        """
        :param store: 
        :param url: 
        """
        self._values: typing.Dict[str, typing.Any] = {
            "store": store,
            "url": url,
        }

    @builtins.property
    def store(self) -> builtins.str:
        result = self._values.get("store")
        assert result is not None, "Required property 'store' is missing"
        return result

    @builtins.property
    def url(self) -> builtins.str:
        result = self._values.get("url")
        assert result is not None, "Required property 'url' is missing"
        return result

    def __eq__(self, rhs: typing.Any) -> builtins.bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs: typing.Any) -> builtins.bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return "WindowsVirtualMachineScaleSetSecretCertificate(%s)" % ", ".join(
            k + "=" + repr(v) for k, v in self._values.items()
        )


@jsii.data_type(
    jsii_type="@cdktf/provider-azurerm.WindowsVirtualMachineScaleSetSourceImageReference",
    jsii_struct_bases=[],
    name_mapping={
        "offer": "offer",
        "publisher": "publisher",
        "sku": "sku",
        "version": "version",
    },
)
class WindowsVirtualMachineScaleSetSourceImageReference:
    def __init__(
        self,
        *,
        offer: builtins.str,
        publisher: builtins.str,
        sku: builtins.str,
        version: builtins.str,
    ) -> None:
        """
        :param offer: 
        :param publisher: 
        :param sku: 
        :param version: 
        """
        self._values: typing.Dict[str, typing.Any] = {
            "offer": offer,
            "publisher": publisher,
            "sku": sku,
            "version": version,
        }

    @builtins.property
    def offer(self) -> builtins.str:
        result = self._values.get("offer")
        assert result is not None, "Required property 'offer' is missing"
        return result

    @builtins.property
    def publisher(self) -> builtins.str:
        result = self._values.get("publisher")
        assert result is not None, "Required property 'publisher' is missing"
        return result

    @builtins.property
    def sku(self) -> builtins.str:
        result = self._values.get("sku")
        assert result is not None, "Required property 'sku' is missing"
        return result

    @builtins.property
    def version(self) -> builtins.str:
        result = self._values.get("version")
        assert result is not None, "Required property 'version' is missing"
        return result

    def __eq__(self, rhs: typing.Any) -> builtins.bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs: typing.Any) -> builtins.bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return "WindowsVirtualMachineScaleSetSourceImageReference(%s)" % ", ".join(
            k + "=" + repr(v) for k, v in self._values.items()
        )


@jsii.data_type(
    jsii_type="@cdktf/provider-azurerm.WindowsVirtualMachineScaleSetTimeouts",
    jsii_struct_bases=[],
    name_mapping={
        "create": "create",
        "delete": "delete",
        "read": "read",
        "update": "update",
    },
)
class WindowsVirtualMachineScaleSetTimeouts:
    def __init__(
        self,
        *,
        create: typing.Optional[builtins.str] = None,
        delete: typing.Optional[builtins.str] = None,
        read: typing.Optional[builtins.str] = None,
        update: typing.Optional[builtins.str] = None,
    ) -> None:
        """
        :param create: 
        :param delete: 
        :param read: 
        :param update: 
        """
        self._values: typing.Dict[str, typing.Any] = {}
        if create is not None:
            self._values["create"] = create
        if delete is not None:
            self._values["delete"] = delete
        if read is not None:
            self._values["read"] = read
        if update is not None:
            self._values["update"] = update

    @builtins.property
    def create(self) -> typing.Optional[builtins.str]:
        result = self._values.get("create")
        return result

    @builtins.property
    def delete(self) -> typing.Optional[builtins.str]:
        result = self._values.get("delete")
        return result

    @builtins.property
    def read(self) -> typing.Optional[builtins.str]:
        result = self._values.get("read")
        return result

    @builtins.property
    def update(self) -> typing.Optional[builtins.str]:
        result = self._values.get("update")
        return result

    def __eq__(self, rhs: typing.Any) -> builtins.bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs: typing.Any) -> builtins.bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return "WindowsVirtualMachineScaleSetTimeouts(%s)" % ", ".join(
            k + "=" + repr(v) for k, v in self._values.items()
        )


@jsii.data_type(
    jsii_type="@cdktf/provider-azurerm.WindowsVirtualMachineScaleSetWinrmListener",
    jsii_struct_bases=[],
    name_mapping={"protocol": "protocol", "certificate_url": "certificateUrl"},
)
class WindowsVirtualMachineScaleSetWinrmListener:
    def __init__(
        self,
        *,
        protocol: builtins.str,
        certificate_url: typing.Optional[builtins.str] = None,
    ) -> None:
        """
        :param protocol: 
        :param certificate_url: 
        """
        self._values: typing.Dict[str, typing.Any] = {
            "protocol": protocol,
        }
        if certificate_url is not None:
            self._values["certificate_url"] = certificate_url

    @builtins.property
    def protocol(self) -> builtins.str:
        result = self._values.get("protocol")
        assert result is not None, "Required property 'protocol' is missing"
        return result

    @builtins.property
    def certificate_url(self) -> typing.Optional[builtins.str]:
        result = self._values.get("certificate_url")
        return result

    def __eq__(self, rhs: typing.Any) -> builtins.bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs: typing.Any) -> builtins.bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return "WindowsVirtualMachineScaleSetWinrmListener(%s)" % ", ".join(
            k + "=" + repr(v) for k, v in self._values.items()
        )


@jsii.data_type(
    jsii_type="@cdktf/provider-azurerm.WindowsVirtualMachineSecret",
    jsii_struct_bases=[],
    name_mapping={"certificate": "certificate", "key_vault_id": "keyVaultId"},
)
class WindowsVirtualMachineSecret:
    def __init__(
        self,
        *,
        certificate: typing.List["WindowsVirtualMachineSecretCertificate"],
        key_vault_id: builtins.str,
    ) -> None:
        """
        :param certificate: certificate block.
        :param key_vault_id: 
        """
        self._values: typing.Dict[str, typing.Any] = {
            "certificate": certificate,
            "key_vault_id": key_vault_id,
        }

    @builtins.property
    def certificate(self) -> typing.List["WindowsVirtualMachineSecretCertificate"]:
        """certificate block."""
        result = self._values.get("certificate")
        assert result is not None, "Required property 'certificate' is missing"
        return result

    @builtins.property
    def key_vault_id(self) -> builtins.str:
        result = self._values.get("key_vault_id")
        assert result is not None, "Required property 'key_vault_id' is missing"
        return result

    def __eq__(self, rhs: typing.Any) -> builtins.bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs: typing.Any) -> builtins.bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return "WindowsVirtualMachineSecret(%s)" % ", ".join(
            k + "=" + repr(v) for k, v in self._values.items()
        )


@jsii.data_type(
    jsii_type="@cdktf/provider-azurerm.WindowsVirtualMachineSecretCertificate",
    jsii_struct_bases=[],
    name_mapping={"store": "store", "url": "url"},
)
class WindowsVirtualMachineSecretCertificate:
    def __init__(self, *, store: builtins.str, url: builtins.str) -> None:
        """
        :param store: 
        :param url: 
        """
        self._values: typing.Dict[str, typing.Any] = {
            "store": store,
            "url": url,
        }

    @builtins.property
    def store(self) -> builtins.str:
        result = self._values.get("store")
        assert result is not None, "Required property 'store' is missing"
        return result

    @builtins.property
    def url(self) -> builtins.str:
        result = self._values.get("url")
        assert result is not None, "Required property 'url' is missing"
        return result

    def __eq__(self, rhs: typing.Any) -> builtins.bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs: typing.Any) -> builtins.bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return "WindowsVirtualMachineSecretCertificate(%s)" % ", ".join(
            k + "=" + repr(v) for k, v in self._values.items()
        )


@jsii.data_type(
    jsii_type="@cdktf/provider-azurerm.WindowsVirtualMachineSourceImageReference",
    jsii_struct_bases=[],
    name_mapping={
        "offer": "offer",
        "publisher": "publisher",
        "sku": "sku",
        "version": "version",
    },
)
class WindowsVirtualMachineSourceImageReference:
    def __init__(
        self,
        *,
        offer: builtins.str,
        publisher: builtins.str,
        sku: builtins.str,
        version: builtins.str,
    ) -> None:
        """
        :param offer: 
        :param publisher: 
        :param sku: 
        :param version: 
        """
        self._values: typing.Dict[str, typing.Any] = {
            "offer": offer,
            "publisher": publisher,
            "sku": sku,
            "version": version,
        }

    @builtins.property
    def offer(self) -> builtins.str:
        result = self._values.get("offer")
        assert result is not None, "Required property 'offer' is missing"
        return result

    @builtins.property
    def publisher(self) -> builtins.str:
        result = self._values.get("publisher")
        assert result is not None, "Required property 'publisher' is missing"
        return result

    @builtins.property
    def sku(self) -> builtins.str:
        result = self._values.get("sku")
        assert result is not None, "Required property 'sku' is missing"
        return result

    @builtins.property
    def version(self) -> builtins.str:
        result = self._values.get("version")
        assert result is not None, "Required property 'version' is missing"
        return result

    def __eq__(self, rhs: typing.Any) -> builtins.bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs: typing.Any) -> builtins.bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return "WindowsVirtualMachineSourceImageReference(%s)" % ", ".join(
            k + "=" + repr(v) for k, v in self._values.items()
        )


@jsii.data_type(
    jsii_type="@cdktf/provider-azurerm.WindowsVirtualMachineTimeouts",
    jsii_struct_bases=[],
    name_mapping={
        "create": "create",
        "delete": "delete",
        "read": "read",
        "update": "update",
    },
)
class WindowsVirtualMachineTimeouts:
    def __init__(
        self,
        *,
        create: typing.Optional[builtins.str] = None,
        delete: typing.Optional[builtins.str] = None,
        read: typing.Optional[builtins.str] = None,
        update: typing.Optional[builtins.str] = None,
    ) -> None:
        """
        :param create: 
        :param delete: 
        :param read: 
        :param update: 
        """
        self._values: typing.Dict[str, typing.Any] = {}
        if create is not None:
            self._values["create"] = create
        if delete is not None:
            self._values["delete"] = delete
        if read is not None:
            self._values["read"] = read
        if update is not None:
            self._values["update"] = update

    @builtins.property
    def create(self) -> typing.Optional[builtins.str]:
        result = self._values.get("create")
        return result

    @builtins.property
    def delete(self) -> typing.Optional[builtins.str]:
        result = self._values.get("delete")
        return result

    @builtins.property
    def read(self) -> typing.Optional[builtins.str]:
        result = self._values.get("read")
        return result

    @builtins.property
    def update(self) -> typing.Optional[builtins.str]:
        result = self._values.get("update")
        return result

    def __eq__(self, rhs: typing.Any) -> builtins.bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs: typing.Any) -> builtins.bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return "WindowsVirtualMachineTimeouts(%s)" % ", ".join(
            k + "=" + repr(v) for k, v in self._values.items()
        )


@jsii.data_type(
    jsii_type="@cdktf/provider-azurerm.WindowsVirtualMachineWinrmListener",
    jsii_struct_bases=[],
    name_mapping={"protocol": "protocol", "certificate_url": "certificateUrl"},
)
class WindowsVirtualMachineWinrmListener:
    def __init__(
        self,
        *,
        protocol: builtins.str,
        certificate_url: typing.Optional[builtins.str] = None,
    ) -> None:
        """
        :param protocol: 
        :param certificate_url: 
        """
        self._values: typing.Dict[str, typing.Any] = {
            "protocol": protocol,
        }
        if certificate_url is not None:
            self._values["certificate_url"] = certificate_url

    @builtins.property
    def protocol(self) -> builtins.str:
        result = self._values.get("protocol")
        assert result is not None, "Required property 'protocol' is missing"
        return result

    @builtins.property
    def certificate_url(self) -> typing.Optional[builtins.str]:
        result = self._values.get("certificate_url")
        return result

    def __eq__(self, rhs: typing.Any) -> builtins.bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs: typing.Any) -> builtins.bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return "WindowsVirtualMachineWinrmListener(%s)" % ", ".join(
            k + "=" + repr(v) for k, v in self._values.items()
        )


__all__ = [
    "AdvancedThreatProtection",
    "AdvancedThreatProtectionConfig",
    "AdvancedThreatProtectionTimeouts",
    "AnalysisServicesServer",
    "AnalysisServicesServerConfig",
    "AnalysisServicesServerIpv4FirewallRule",
    "AnalysisServicesServerTimeouts",
    "ApiManagement",
    "ApiManagementAdditionalLocation",
    "ApiManagementApi",
    "ApiManagementApiConfig",
    "ApiManagementApiImport",
    "ApiManagementApiImportWsdlSelector",
    "ApiManagementApiOperation",
    "ApiManagementApiOperationConfig",
    "ApiManagementApiOperationPolicy",
    "ApiManagementApiOperationPolicyConfig",
    "ApiManagementApiOperationPolicyTimeouts",
    "ApiManagementApiOperationRequest",
    "ApiManagementApiOperationRequestHeader",
    "ApiManagementApiOperationRequestQueryParameter",
    "ApiManagementApiOperationRequestRepresentation",
    "ApiManagementApiOperationRequestRepresentationFormParameter",
    "ApiManagementApiOperationResponse",
    "ApiManagementApiOperationResponseHeader",
    "ApiManagementApiOperationResponseRepresentation",
    "ApiManagementApiOperationResponseRepresentationFormParameter",
    "ApiManagementApiOperationTemplateParameter",
    "ApiManagementApiOperationTimeouts",
    "ApiManagementApiPolicy",
    "ApiManagementApiPolicyConfig",
    "ApiManagementApiPolicyTimeouts",
    "ApiManagementApiSchema",
    "ApiManagementApiSchemaConfig",
    "ApiManagementApiSchemaTimeouts",
    "ApiManagementApiSubscriptionKeyParameterNames",
    "ApiManagementApiTimeouts",
    "ApiManagementApiVersionSet",
    "ApiManagementApiVersionSetConfig",
    "ApiManagementApiVersionSetTimeouts",
    "ApiManagementAuthorizationServer",
    "ApiManagementAuthorizationServerConfig",
    "ApiManagementAuthorizationServerTimeouts",
    "ApiManagementAuthorizationServerTokenBodyParameter",
    "ApiManagementBackend",
    "ApiManagementBackendConfig",
    "ApiManagementBackendCredentials",
    "ApiManagementBackendCredentialsAuthorization",
    "ApiManagementBackendProxy",
    "ApiManagementBackendServiceFabricCluster",
    "ApiManagementBackendServiceFabricClusterServerX509Name",
    "ApiManagementBackendTimeouts",
    "ApiManagementBackendTls",
    "ApiManagementCertificate",
    "ApiManagementCertificateA",
    "ApiManagementCertificateAConfig",
    "ApiManagementCertificateTimeouts",
    "ApiManagementConfig",
    "ApiManagementDiagnostic",
    "ApiManagementDiagnosticConfig",
    "ApiManagementDiagnosticTimeouts",
    "ApiManagementGroup",
    "ApiManagementGroupConfig",
    "ApiManagementGroupTimeouts",
    "ApiManagementGroupUser",
    "ApiManagementGroupUserConfig",
    "ApiManagementGroupUserTimeouts",
    "ApiManagementHostnameConfiguration",
    "ApiManagementHostnameConfigurationManagement",
    "ApiManagementHostnameConfigurationPortal",
    "ApiManagementHostnameConfigurationProxy",
    "ApiManagementHostnameConfigurationScm",
    "ApiManagementIdentity",
    "ApiManagementIdentityProviderAad",
    "ApiManagementIdentityProviderAadConfig",
    "ApiManagementIdentityProviderAadTimeouts",
    "ApiManagementIdentityProviderFacebook",
    "ApiManagementIdentityProviderFacebookConfig",
    "ApiManagementIdentityProviderFacebookTimeouts",
    "ApiManagementIdentityProviderGoogle",
    "ApiManagementIdentityProviderGoogleConfig",
    "ApiManagementIdentityProviderGoogleTimeouts",
    "ApiManagementIdentityProviderMicrosoft",
    "ApiManagementIdentityProviderMicrosoftConfig",
    "ApiManagementIdentityProviderMicrosoftTimeouts",
    "ApiManagementIdentityProviderTwitter",
    "ApiManagementIdentityProviderTwitterConfig",
    "ApiManagementIdentityProviderTwitterTimeouts",
    "ApiManagementLogger",
    "ApiManagementLoggerApplicationInsights",
    "ApiManagementLoggerConfig",
    "ApiManagementLoggerEventhub",
    "ApiManagementLoggerTimeouts",
    "ApiManagementOpenidConnectProvider",
    "ApiManagementOpenidConnectProviderConfig",
    "ApiManagementOpenidConnectProviderTimeouts",
    "ApiManagementPolicy",
    "ApiManagementProduct",
    "ApiManagementProductApi",
    "ApiManagementProductApiConfig",
    "ApiManagementProductApiTimeouts",
    "ApiManagementProductConfig",
    "ApiManagementProductGroup",
    "ApiManagementProductGroupConfig",
    "ApiManagementProductGroupTimeouts",
    "ApiManagementProductPolicy",
    "ApiManagementProductPolicyConfig",
    "ApiManagementProductPolicyTimeouts",
    "ApiManagementProductTimeouts",
    "ApiManagementProperty",
    "ApiManagementPropertyConfig",
    "ApiManagementPropertyTimeouts",
    "ApiManagementProtocols",
    "ApiManagementSecurity",
    "ApiManagementSignIn",
    "ApiManagementSignUp",
    "ApiManagementSignUpTermsOfService",
    "ApiManagementSubscription",
    "ApiManagementSubscriptionConfig",
    "ApiManagementSubscriptionTimeouts",
    "ApiManagementTimeouts",
    "ApiManagementUser",
    "ApiManagementUserConfig",
    "ApiManagementUserTimeouts",
    "AppConfiguration",
    "AppConfigurationConfig",
    "AppConfigurationPrimaryReadKey",
    "AppConfigurationPrimaryWriteKey",
    "AppConfigurationSecondaryReadKey",
    "AppConfigurationSecondaryWriteKey",
    "AppConfigurationTimeouts",
    "AppService",
    "AppServiceActiveSlot",
    "AppServiceActiveSlotConfig",
    "AppServiceActiveSlotTimeouts",
    "AppServiceAuthSettings",
    "AppServiceAuthSettingsActiveDirectory",
    "AppServiceAuthSettingsFacebook",
    "AppServiceAuthSettingsGoogle",
    "AppServiceAuthSettingsMicrosoft",
    "AppServiceAuthSettingsTwitter",
    "AppServiceBackup",
    "AppServiceBackupSchedule",
    "AppServiceCertificate",
    "AppServiceCertificateConfig",
    "AppServiceCertificateOrder",
    "AppServiceCertificateOrderCertificates",
    "AppServiceCertificateOrderConfig",
    "AppServiceCertificateOrderTimeouts",
    "AppServiceCertificateTimeouts",
    "AppServiceConfig",
    "AppServiceConnectionString",
    "AppServiceCustomHostnameBinding",
    "AppServiceCustomHostnameBindingConfig",
    "AppServiceCustomHostnameBindingTimeouts",
    "AppServiceEnvironment",
    "AppServiceEnvironmentConfig",
    "AppServiceEnvironmentTimeouts",
    "AppServiceIdentity",
    "AppServiceLogs",
    "AppServiceLogsApplicationLogs",
    "AppServiceLogsApplicationLogsAzureBlobStorage",
    "AppServiceLogsHttpLogs",
    "AppServiceLogsHttpLogsAzureBlobStorage",
    "AppServiceLogsHttpLogsFileSystem",
    "AppServicePlan",
    "AppServicePlanConfig",
    "AppServicePlanSku",
    "AppServicePlanTimeouts",
    "AppServiceSiteConfig",
    "AppServiceSiteConfigCors",
    "AppServiceSiteConfigIpRestriction",
    "AppServiceSiteCredential",
    "AppServiceSlot",
    "AppServiceSlotAuthSettings",
    "AppServiceSlotAuthSettingsActiveDirectory",
    "AppServiceSlotAuthSettingsFacebook",
    "AppServiceSlotAuthSettingsGoogle",
    "AppServiceSlotAuthSettingsMicrosoft",
    "AppServiceSlotAuthSettingsTwitter",
    "AppServiceSlotConfig",
    "AppServiceSlotConnectionString",
    "AppServiceSlotIdentity",
    "AppServiceSlotLogs",
    "AppServiceSlotLogsApplicationLogs",
    "AppServiceSlotLogsApplicationLogsAzureBlobStorage",
    "AppServiceSlotLogsHttpLogs",
    "AppServiceSlotLogsHttpLogsAzureBlobStorage",
    "AppServiceSlotLogsHttpLogsFileSystem",
    "AppServiceSlotSiteConfig",
    "AppServiceSlotSiteConfigCors",
    "AppServiceSlotSiteConfigIpRestriction",
    "AppServiceSlotSiteCredential",
    "AppServiceSlotTimeouts",
    "AppServiceSourceControl",
    "AppServiceSourceControlToken",
    "AppServiceSourceControlTokenConfig",
    "AppServiceSourceControlTokenTimeouts",
    "AppServiceStorageAccount",
    "AppServiceTimeouts",
    "AppServiceVirtualNetworkSwiftConnection",
    "AppServiceVirtualNetworkSwiftConnectionConfig",
    "AppServiceVirtualNetworkSwiftConnectionTimeouts",
    "ApplicationGateway",
    "ApplicationGatewayAuthenticationCertificate",
    "ApplicationGatewayAutoscaleConfiguration",
    "ApplicationGatewayBackendAddressPool",
    "ApplicationGatewayBackendHttpSettings",
    "ApplicationGatewayBackendHttpSettingsAuthenticationCertificate",
    "ApplicationGatewayBackendHttpSettingsConnectionDraining",
    "ApplicationGatewayConfig",
    "ApplicationGatewayCustomErrorConfiguration",
    "ApplicationGatewayFrontendIpConfiguration",
    "ApplicationGatewayFrontendPort",
    "ApplicationGatewayGatewayIpConfiguration",
    "ApplicationGatewayHttpListener",
    "ApplicationGatewayHttpListenerCustomErrorConfiguration",
    "ApplicationGatewayIdentity",
    "ApplicationGatewayProbe",
    "ApplicationGatewayProbeMatch",
    "ApplicationGatewayRedirectConfiguration",
    "ApplicationGatewayRequestRoutingRule",
    "ApplicationGatewayRewriteRuleSet",
    "ApplicationGatewayRewriteRuleSetRewriteRule",
    "ApplicationGatewayRewriteRuleSetRewriteRuleCondition",
    "ApplicationGatewayRewriteRuleSetRewriteRuleRequestHeaderConfiguration",
    "ApplicationGatewayRewriteRuleSetRewriteRuleResponseHeaderConfiguration",
    "ApplicationGatewaySku",
    "ApplicationGatewaySslCertificate",
    "ApplicationGatewaySslPolicy",
    "ApplicationGatewayTimeouts",
    "ApplicationGatewayTrustedRootCertificate",
    "ApplicationGatewayUrlPathMap",
    "ApplicationGatewayUrlPathMapPathRule",
    "ApplicationGatewayWafConfiguration",
    "ApplicationGatewayWafConfigurationDisabledRuleGroup",
    "ApplicationGatewayWafConfigurationExclusion",
    "ApplicationInsights",
    "ApplicationInsightsAnalyticsItem",
    "ApplicationInsightsAnalyticsItemConfig",
    "ApplicationInsightsAnalyticsItemTimeouts",
    "ApplicationInsightsApiKey",
    "ApplicationInsightsApiKeyConfig",
    "ApplicationInsightsApiKeyTimeouts",
    "ApplicationInsightsConfig",
    "ApplicationInsightsTimeouts",
    "ApplicationInsightsWebTest",
    "ApplicationInsightsWebTestConfig",
    "ApplicationInsightsWebTestTimeouts",
    "ApplicationSecurityGroup",
    "ApplicationSecurityGroupConfig",
    "ApplicationSecurityGroupTimeouts",
    "AutomationAccount",
    "AutomationAccountConfig",
    "AutomationAccountTimeouts",
    "AutomationCertificate",
    "AutomationCertificateConfig",
    "AutomationCertificateTimeouts",
    "AutomationCredential",
    "AutomationCredentialConfig",
    "AutomationCredentialTimeouts",
    "AutomationDscConfiguration",
    "AutomationDscConfigurationConfig",
    "AutomationDscConfigurationTimeouts",
    "AutomationDscNodeconfiguration",
    "AutomationDscNodeconfigurationConfig",
    "AutomationDscNodeconfigurationTimeouts",
    "AutomationJobSchedule",
    "AutomationJobScheduleConfig",
    "AutomationJobScheduleTimeouts",
    "AutomationModule",
    "AutomationModuleConfig",
    "AutomationModuleModuleLink",
    "AutomationModuleModuleLinkHash",
    "AutomationModuleTimeouts",
    "AutomationRunbook",
    "AutomationRunbookConfig",
    "AutomationRunbookPublishContentLink",
    "AutomationRunbookPublishContentLinkHash",
    "AutomationRunbookTimeouts",
    "AutomationSchedule",
    "AutomationScheduleConfig",
    "AutomationScheduleMonthlyOccurrence",
    "AutomationScheduleTimeouts",
    "AutomationVariableBool",
    "AutomationVariableBoolConfig",
    "AutomationVariableBoolTimeouts",
    "AutomationVariableDatetime",
    "AutomationVariableDatetimeConfig",
    "AutomationVariableDatetimeTimeouts",
    "AutomationVariableInt",
    "AutomationVariableIntConfig",
    "AutomationVariableIntTimeouts",
    "AutomationVariableString",
    "AutomationVariableStringConfig",
    "AutomationVariableStringTimeouts",
    "AvailabilitySet",
    "AvailabilitySetConfig",
    "AvailabilitySetTimeouts",
    "AzurermProvider",
    "AzurermProviderConfig",
    "AzurermProviderFeatures",
    "AzurermProviderFeaturesKeyVault",
    "AzurermProviderFeaturesVirtualMachine",
    "AzurermProviderFeaturesVirtualMachineScaleSet",
    "BackupContainerStorageAccount",
    "BackupContainerStorageAccountConfig",
    "BackupContainerStorageAccountTimeouts",
    "BackupPolicyFileShare",
    "BackupPolicyFileShareBackup",
    "BackupPolicyFileShareConfig",
    "BackupPolicyFileShareRetentionDaily",
    "BackupPolicyFileShareTimeouts",
    "BackupPolicyVm",
    "BackupPolicyVmBackup",
    "BackupPolicyVmConfig",
    "BackupPolicyVmRetentionDaily",
    "BackupPolicyVmRetentionMonthly",
    "BackupPolicyVmRetentionWeekly",
    "BackupPolicyVmRetentionYearly",
    "BackupPolicyVmTimeouts",
    "BackupProtectedFileShare",
    "BackupProtectedFileShareConfig",
    "BackupProtectedFileShareTimeouts",
    "BackupProtectedVm",
    "BackupProtectedVmConfig",
    "BackupProtectedVmTimeouts",
    "BastionHost",
    "BastionHostConfig",
    "BastionHostIpConfiguration",
    "BastionHostTimeouts",
    "BatchAccount",
    "BatchAccountConfig",
    "BatchAccountKeyVaultReference",
    "BatchAccountTimeouts",
    "BatchApplication",
    "BatchApplicationConfig",
    "BatchApplicationTimeouts",
    "BatchCertificate",
    "BatchCertificateConfig",
    "BatchCertificateTimeouts",
    "BatchPool",
    "BatchPoolAutoScale",
    "BatchPoolCertificate",
    "BatchPoolConfig",
    "BatchPoolContainerConfiguration",
    "BatchPoolContainerConfigurationContainerRegistries",
    "BatchPoolFixedScale",
    "BatchPoolNetworkConfiguration",
    "BatchPoolNetworkConfigurationEndpointConfiguration",
    "BatchPoolNetworkConfigurationEndpointConfigurationNetworkSecurityGroupRules",
    "BatchPoolStartTask",
    "BatchPoolStartTaskResourceFile",
    "BatchPoolStartTaskUserIdentity",
    "BatchPoolStartTaskUserIdentityAutoUser",
    "BatchPoolStorageImageReference",
    "BatchPoolTimeouts",
    "BotChannelEmail",
    "BotChannelEmailConfig",
    "BotChannelEmailTimeouts",
    "BotChannelMsTeams",
    "BotChannelMsTeamsConfig",
    "BotChannelMsTeamsTimeouts",
    "BotChannelSlack",
    "BotChannelSlackConfig",
    "BotChannelSlackTimeouts",
    "BotChannelsRegistration",
    "BotChannelsRegistrationConfig",
    "BotChannelsRegistrationTimeouts",
    "BotConnection",
    "BotConnectionConfig",
    "BotConnectionTimeouts",
    "BotWebApp",
    "BotWebAppConfig",
    "BotWebAppTimeouts",
    "CdnEndpoint",
    "CdnEndpointConfig",
    "CdnEndpointGeoFilter",
    "CdnEndpointOrigin",
    "CdnEndpointTimeouts",
    "CdnProfile",
    "CdnProfileConfig",
    "CdnProfileTimeouts",
    "CognitiveAccount",
    "CognitiveAccountConfig",
    "CognitiveAccountTimeouts",
    "ContainerGroup",
    "ContainerGroupConfig",
    "ContainerGroupContainer",
    "ContainerGroupContainerGpu",
    "ContainerGroupContainerLivenessProbe",
    "ContainerGroupContainerLivenessProbeHttpGet",
    "ContainerGroupContainerPorts",
    "ContainerGroupContainerReadinessProbe",
    "ContainerGroupContainerReadinessProbeHttpGet",
    "ContainerGroupContainerVolume",
    "ContainerGroupDiagnostics",
    "ContainerGroupDiagnosticsLogAnalytics",
    "ContainerGroupIdentity",
    "ContainerGroupImageRegistryCredential",
    "ContainerGroupTimeouts",
    "ContainerRegistry",
    "ContainerRegistryConfig",
    "ContainerRegistryNetworkRuleSet",
    "ContainerRegistryNetworkRuleSetIpRule",
    "ContainerRegistryNetworkRuleSetVirtualNetwork",
    "ContainerRegistryTimeouts",
    "ContainerRegistryWebhook",
    "ContainerRegistryWebhookConfig",
    "ContainerRegistryWebhookTimeouts",
    "CosmosdbAccount",
    "CosmosdbAccountCapabilities",
    "CosmosdbAccountConfig",
    "CosmosdbAccountConsistencyPolicy",
    "CosmosdbAccountGeoLocation",
    "CosmosdbAccountTimeouts",
    "CosmosdbAccountVirtualNetworkRule",
    "CosmosdbCassandraKeyspace",
    "CosmosdbCassandraKeyspaceConfig",
    "CosmosdbCassandraKeyspaceTimeouts",
    "CosmosdbGremlinDatabase",
    "CosmosdbGremlinDatabaseConfig",
    "CosmosdbGremlinDatabaseTimeouts",
    "CosmosdbGremlinGraph",
    "CosmosdbGremlinGraphConfig",
    "CosmosdbGremlinGraphConflictResolutionPolicy",
    "CosmosdbGremlinGraphIndexPolicy",
    "CosmosdbGremlinGraphTimeouts",
    "CosmosdbGremlinGraphUniqueKey",
    "CosmosdbMongoCollection",
    "CosmosdbMongoCollectionConfig",
    "CosmosdbMongoCollectionTimeouts",
    "CosmosdbMongoDatabase",
    "CosmosdbMongoDatabaseConfig",
    "CosmosdbMongoDatabaseTimeouts",
    "CosmosdbSqlContainer",
    "CosmosdbSqlContainerConfig",
    "CosmosdbSqlContainerTimeouts",
    "CosmosdbSqlContainerUniqueKey",
    "CosmosdbSqlDatabase",
    "CosmosdbSqlDatabaseConfig",
    "CosmosdbSqlDatabaseTimeouts",
    "CosmosdbTable",
    "CosmosdbTableConfig",
    "CosmosdbTableTimeouts",
    "Dashboard",
    "DashboardConfig",
    "DashboardTimeouts",
    "DataAzurermApiManagement",
    "DataAzurermApiManagementAdditionalLocation",
    "DataAzurermApiManagementApi",
    "DataAzurermApiManagementApiConfig",
    "DataAzurermApiManagementApiSubscriptionKeyParameterNames",
    "DataAzurermApiManagementApiTimeouts",
    "DataAzurermApiManagementApiVersionSet",
    "DataAzurermApiManagementApiVersionSetConfig",
    "DataAzurermApiManagementApiVersionSetTimeouts",
    "DataAzurermApiManagementConfig",
    "DataAzurermApiManagementGroup",
    "DataAzurermApiManagementGroupConfig",
    "DataAzurermApiManagementGroupTimeouts",
    "DataAzurermApiManagementHostnameConfiguration",
    "DataAzurermApiManagementHostnameConfigurationManagement",
    "DataAzurermApiManagementHostnameConfigurationPortal",
    "DataAzurermApiManagementHostnameConfigurationProxy",
    "DataAzurermApiManagementHostnameConfigurationScm",
    "DataAzurermApiManagementProduct",
    "DataAzurermApiManagementProductConfig",
    "DataAzurermApiManagementProductTimeouts",
    "DataAzurermApiManagementTimeouts",
    "DataAzurermApiManagementUser",
    "DataAzurermApiManagementUserConfig",
    "DataAzurermApiManagementUserTimeouts",
    "DataAzurermAppService",
    "DataAzurermAppServiceCertificate",
    "DataAzurermAppServiceCertificateConfig",
    "DataAzurermAppServiceCertificateOrder",
    "DataAzurermAppServiceCertificateOrderCertificates",
    "DataAzurermAppServiceCertificateOrderConfig",
    "DataAzurermAppServiceCertificateOrderTimeouts",
    "DataAzurermAppServiceCertificateTimeouts",
    "DataAzurermAppServiceConfig",
    "DataAzurermAppServiceConnectionString",
    "DataAzurermAppServiceEnvironment",
    "DataAzurermAppServiceEnvironmentConfig",
    "DataAzurermAppServiceEnvironmentTimeouts",
    "DataAzurermAppServicePlan",
    "DataAzurermAppServicePlanConfig",
    "DataAzurermAppServicePlanSku",
    "DataAzurermAppServicePlanTimeouts",
    "DataAzurermAppServiceSiteConfig",
    "DataAzurermAppServiceSiteConfigCors",
    "DataAzurermAppServiceSiteConfigIpRestriction",
    "DataAzurermAppServiceSiteCredential",
    "DataAzurermAppServiceSourceControl",
    "DataAzurermAppServiceTimeouts",
    "DataAzurermApplicationInsights",
    "DataAzurermApplicationInsightsConfig",
    "DataAzurermApplicationInsightsTimeouts",
    "DataAzurermApplicationSecurityGroup",
    "DataAzurermApplicationSecurityGroupConfig",
    "DataAzurermApplicationSecurityGroupTimeouts",
    "DataAzurermAutomationAccount",
    "DataAzurermAutomationAccountConfig",
    "DataAzurermAutomationAccountTimeouts",
    "DataAzurermAutomationVariableBool",
    "DataAzurermAutomationVariableBoolConfig",
    "DataAzurermAutomationVariableBoolTimeouts",
    "DataAzurermAutomationVariableDatetime",
    "DataAzurermAutomationVariableDatetimeConfig",
    "DataAzurermAutomationVariableDatetimeTimeouts",
    "DataAzurermAutomationVariableInt",
    "DataAzurermAutomationVariableIntConfig",
    "DataAzurermAutomationVariableIntTimeouts",
    "DataAzurermAutomationVariableString",
    "DataAzurermAutomationVariableStringConfig",
    "DataAzurermAutomationVariableStringTimeouts",
    "DataAzurermAvailabilitySet",
    "DataAzurermAvailabilitySetConfig",
    "DataAzurermAvailabilitySetTimeouts",
    "DataAzurermBackupPolicyVm",
    "DataAzurermBackupPolicyVmConfig",
    "DataAzurermBackupPolicyVmTimeouts",
    "DataAzurermBatchAccount",
    "DataAzurermBatchAccountConfig",
    "DataAzurermBatchAccountKeyVaultReference",
    "DataAzurermBatchAccountTimeouts",
    "DataAzurermBatchCertificate",
    "DataAzurermBatchCertificateConfig",
    "DataAzurermBatchCertificateTimeouts",
    "DataAzurermBatchPool",
    "DataAzurermBatchPoolAutoScale",
    "DataAzurermBatchPoolCertificate",
    "DataAzurermBatchPoolConfig",
    "DataAzurermBatchPoolContainerConfiguration",
    "DataAzurermBatchPoolContainerConfigurationContainerRegistries",
    "DataAzurermBatchPoolFixedScale",
    "DataAzurermBatchPoolNetworkConfiguration",
    "DataAzurermBatchPoolNetworkConfigurationEndpointConfiguration",
    "DataAzurermBatchPoolNetworkConfigurationEndpointConfigurationNetworkSecurityGroupRules",
    "DataAzurermBatchPoolStartTask",
    "DataAzurermBatchPoolStorageImageReference",
    "DataAzurermBatchPoolTimeouts",
    "DataAzurermCdnProfile",
    "DataAzurermCdnProfileConfig",
    "DataAzurermCdnProfileTimeouts",
    "DataAzurermClientConfig",
    "DataAzurermClientConfigConfig",
    "DataAzurermClientConfigTimeouts",
    "DataAzurermContainerRegistry",
    "DataAzurermContainerRegistryConfig",
    "DataAzurermContainerRegistryTimeouts",
    "DataAzurermCosmosdbAccount",
    "DataAzurermCosmosdbAccountCapabilities",
    "DataAzurermCosmosdbAccountConfig",
    "DataAzurermCosmosdbAccountConsistencyPolicy",
    "DataAzurermCosmosdbAccountGeoLocation",
    "DataAzurermCosmosdbAccountTimeouts",
    "DataAzurermCosmosdbAccountVirtualNetworkRule",
    "DataAzurermDataFactory",
    "DataAzurermDataFactoryConfig",
    "DataAzurermDataFactoryGithubConfiguration",
    "DataAzurermDataFactoryIdentity",
    "DataAzurermDataFactoryTimeouts",
    "DataAzurermDataFactoryVstsConfiguration",
    "DataAzurermDataLakeStore",
    "DataAzurermDataLakeStoreConfig",
    "DataAzurermDataLakeStoreTimeouts",
    "DataAzurermDedicatedHost",
    "DataAzurermDedicatedHostConfig",
    "DataAzurermDedicatedHostGroup",
    "DataAzurermDedicatedHostGroupConfig",
    "DataAzurermDedicatedHostGroupTimeouts",
    "DataAzurermDedicatedHostTimeouts",
    "DataAzurermDevTestLab",
    "DataAzurermDevTestLabConfig",
    "DataAzurermDevTestLabTimeouts",
    "DataAzurermDevTestVirtualNetwork",
    "DataAzurermDevTestVirtualNetworkAllowedSubnets",
    "DataAzurermDevTestVirtualNetworkConfig",
    "DataAzurermDevTestVirtualNetworkSubnetOverrides",
    "DataAzurermDevTestVirtualNetworkTimeouts",
    "DataAzurermDiskEncryptionSet",
    "DataAzurermDiskEncryptionSetConfig",
    "DataAzurermDiskEncryptionSetTimeouts",
    "DataAzurermDnsZone",
    "DataAzurermDnsZoneConfig",
    "DataAzurermDnsZoneTimeouts",
    "DataAzurermEventgridTopic",
    "DataAzurermEventgridTopicConfig",
    "DataAzurermEventgridTopicTimeouts",
    "DataAzurermEventhubAuthorizationRule",
    "DataAzurermEventhubAuthorizationRuleConfig",
    "DataAzurermEventhubAuthorizationRuleTimeouts",
    "DataAzurermEventhubConsumerGroup",
    "DataAzurermEventhubConsumerGroupConfig",
    "DataAzurermEventhubConsumerGroupTimeouts",
    "DataAzurermEventhubNamespace",
    "DataAzurermEventhubNamespaceAuthorizationRule",
    "DataAzurermEventhubNamespaceAuthorizationRuleConfig",
    "DataAzurermEventhubNamespaceAuthorizationRuleTimeouts",
    "DataAzurermEventhubNamespaceConfig",
    "DataAzurermEventhubNamespaceTimeouts",
    "DataAzurermExpressRouteCircuit",
    "DataAzurermExpressRouteCircuitConfig",
    "DataAzurermExpressRouteCircuitPeerings",
    "DataAzurermExpressRouteCircuitServiceProviderProperties",
    "DataAzurermExpressRouteCircuitSku",
    "DataAzurermExpressRouteCircuitTimeouts",
    "DataAzurermFirewall",
    "DataAzurermFirewallConfig",
    "DataAzurermFirewallIpConfiguration",
    "DataAzurermFirewallTimeouts",
    "DataAzurermFunctionApp",
    "DataAzurermFunctionAppConfig",
    "DataAzurermFunctionAppConnectionString",
    "DataAzurermFunctionAppSiteCredential",
    "DataAzurermFunctionAppTimeouts",
    "DataAzurermHdinsightCluster",
    "DataAzurermHdinsightClusterConfig",
    "DataAzurermHdinsightClusterGateway",
    "DataAzurermHdinsightClusterTimeouts",
    "DataAzurermHealthcareService",
    "DataAzurermHealthcareServiceAuthenticationConfiguration",
    "DataAzurermHealthcareServiceConfig",
    "DataAzurermHealthcareServiceCorsConfiguration",
    "DataAzurermHealthcareServiceTimeouts",
    "DataAzurermImage",
    "DataAzurermImageConfig",
    "DataAzurermImageDataDisk",
    "DataAzurermImageOsDisk",
    "DataAzurermImageTimeouts",
    "DataAzurermIothubDps",
    "DataAzurermIothubDpsConfig",
    "DataAzurermIothubDpsSharedAccessPolicy",
    "DataAzurermIothubDpsSharedAccessPolicyConfig",
    "DataAzurermIothubDpsSharedAccessPolicyTimeouts",
    "DataAzurermIothubDpsTimeouts",
    "DataAzurermIothubSharedAccessPolicy",
    "DataAzurermIothubSharedAccessPolicyConfig",
    "DataAzurermIothubSharedAccessPolicyTimeouts",
    "DataAzurermKeyVault",
    "DataAzurermKeyVaultAccessPolicy",
    "DataAzurermKeyVaultAccessPolicyA",
    "DataAzurermKeyVaultAccessPolicyAConfig",
    "DataAzurermKeyVaultAccessPolicyTimeouts",
    "DataAzurermKeyVaultConfig",
    "DataAzurermKeyVaultKey",
    "DataAzurermKeyVaultKeyConfig",
    "DataAzurermKeyVaultKeyTimeouts",
    "DataAzurermKeyVaultNetworkAcls",
    "DataAzurermKeyVaultSecret",
    "DataAzurermKeyVaultSecretConfig",
    "DataAzurermKeyVaultSecretTimeouts",
    "DataAzurermKeyVaultTimeouts",
    "DataAzurermKubernetesCluster",
    "DataAzurermKubernetesClusterAddonProfile",
    "DataAzurermKubernetesClusterAddonProfileAzurePolicy",
    "DataAzurermKubernetesClusterAddonProfileHttpApplicationRouting",
    "DataAzurermKubernetesClusterAddonProfileKubeDashboard",
    "DataAzurermKubernetesClusterAddonProfileOmsAgent",
    "DataAzurermKubernetesClusterAgentPoolProfile",
    "DataAzurermKubernetesClusterConfig",
    "DataAzurermKubernetesClusterKubeAdminConfig",
    "DataAzurermKubernetesClusterKubeConfig",
    "DataAzurermKubernetesClusterLinuxProfile",
    "DataAzurermKubernetesClusterLinuxProfileSshKey",
    "DataAzurermKubernetesClusterNetworkProfile",
    "DataAzurermKubernetesClusterRoleBasedAccessControl",
    "DataAzurermKubernetesClusterRoleBasedAccessControlAzureActiveDirectory",
    "DataAzurermKubernetesClusterServicePrincipal",
    "DataAzurermKubernetesClusterTimeouts",
    "DataAzurermKubernetesClusterWindowsProfile",
    "DataAzurermKubernetesServiceVersions",
    "DataAzurermKubernetesServiceVersionsConfig",
    "DataAzurermKubernetesServiceVersionsTimeouts",
    "DataAzurermLb",
    "DataAzurermLbBackendAddressPool",
    "DataAzurermLbBackendAddressPoolBackendIpConfigurations",
    "DataAzurermLbBackendAddressPoolConfig",
    "DataAzurermLbBackendAddressPoolTimeouts",
    "DataAzurermLbConfig",
    "DataAzurermLbFrontendIpConfiguration",
    "DataAzurermLbTimeouts",
    "DataAzurermLogAnalyticsWorkspace",
    "DataAzurermLogAnalyticsWorkspaceConfig",
    "DataAzurermLogAnalyticsWorkspaceTimeouts",
    "DataAzurermLogicAppWorkflow",
    "DataAzurermLogicAppWorkflowConfig",
    "DataAzurermLogicAppWorkflowTimeouts",
    "DataAzurermManagedDisk",
    "DataAzurermManagedDiskConfig",
    "DataAzurermManagedDiskTimeouts",
    "DataAzurermManagementGroup",
    "DataAzurermManagementGroupConfig",
    "DataAzurermManagementGroupTimeouts",
    "DataAzurermMapsAccount",
    "DataAzurermMapsAccountConfig",
    "DataAzurermMapsAccountTimeouts",
    "DataAzurermMariadbServer",
    "DataAzurermMariadbServerConfig",
    "DataAzurermMariadbServerStorageProfile",
    "DataAzurermMariadbServerTimeouts",
    "DataAzurermMonitorActionGroup",
    "DataAzurermMonitorActionGroupArmRoleReceiver",
    "DataAzurermMonitorActionGroupAutomationRunbookReceiver",
    "DataAzurermMonitorActionGroupAzureAppPushReceiver",
    "DataAzurermMonitorActionGroupAzureFunctionReceiver",
    "DataAzurermMonitorActionGroupConfig",
    "DataAzurermMonitorActionGroupEmailReceiver",
    "DataAzurermMonitorActionGroupItsmReceiver",
    "DataAzurermMonitorActionGroupLogicAppReceiver",
    "DataAzurermMonitorActionGroupSmsReceiver",
    "DataAzurermMonitorActionGroupTimeouts",
    "DataAzurermMonitorActionGroupVoiceReceiver",
    "DataAzurermMonitorActionGroupWebhookReceiver",
    "DataAzurermMonitorDiagnosticCategories",
    "DataAzurermMonitorDiagnosticCategoriesConfig",
    "DataAzurermMonitorDiagnosticCategoriesTimeouts",
    "DataAzurermMonitorLogProfile",
    "DataAzurermMonitorLogProfileConfig",
    "DataAzurermMonitorLogProfileRetentionPolicy",
    "DataAzurermMonitorLogProfileTimeouts",
    "DataAzurermMssqlElasticpool",
    "DataAzurermMssqlElasticpoolConfig",
    "DataAzurermMssqlElasticpoolTimeouts",
    "DataAzurermNatGateway",
    "DataAzurermNatGatewayConfig",
    "DataAzurermNatGatewayTimeouts",
    "DataAzurermNetappAccount",
    "DataAzurermNetappAccountConfig",
    "DataAzurermNetappAccountTimeouts",
    "DataAzurermNetappPool",
    "DataAzurermNetappPoolConfig",
    "DataAzurermNetappPoolTimeouts",
    "DataAzurermNetappSnapshot",
    "DataAzurermNetappSnapshotConfig",
    "DataAzurermNetappSnapshotTimeouts",
    "DataAzurermNetappVolume",
    "DataAzurermNetappVolumeConfig",
    "DataAzurermNetappVolumeTimeouts",
    "DataAzurermNetworkDdosProtectionPlan",
    "DataAzurermNetworkDdosProtectionPlanConfig",
    "DataAzurermNetworkDdosProtectionPlanTimeouts",
    "DataAzurermNetworkInterface",
    "DataAzurermNetworkInterfaceConfig",
    "DataAzurermNetworkInterfaceIpConfiguration",
    "DataAzurermNetworkInterfaceTimeouts",
    "DataAzurermNetworkSecurityGroup",
    "DataAzurermNetworkSecurityGroupConfig",
    "DataAzurermNetworkSecurityGroupSecurityRule",
    "DataAzurermNetworkSecurityGroupTimeouts",
    "DataAzurermNetworkWatcher",
    "DataAzurermNetworkWatcherConfig",
    "DataAzurermNetworkWatcherTimeouts",
    "DataAzurermNotificationHub",
    "DataAzurermNotificationHubApnsCredential",
    "DataAzurermNotificationHubConfig",
    "DataAzurermNotificationHubGcmCredential",
    "DataAzurermNotificationHubNamespace",
    "DataAzurermNotificationHubNamespaceConfig",
    "DataAzurermNotificationHubNamespaceSku",
    "DataAzurermNotificationHubNamespaceTimeouts",
    "DataAzurermNotificationHubTimeouts",
    "DataAzurermPlatformImage",
    "DataAzurermPlatformImageConfig",
    "DataAzurermPlatformImageTimeouts",
    "DataAzurermPolicyDefinition",
    "DataAzurermPolicyDefinitionConfig",
    "DataAzurermPolicyDefinitionTimeouts",
    "DataAzurermPostgresqlServer",
    "DataAzurermPostgresqlServerConfig",
    "DataAzurermPostgresqlServerTimeouts",
    "DataAzurermPrivateEndpointConnection",
    "DataAzurermPrivateEndpointConnectionConfig",
    "DataAzurermPrivateEndpointConnectionPrivateServiceConnection",
    "DataAzurermPrivateEndpointConnectionTimeouts",
    "DataAzurermPrivateLinkService",
    "DataAzurermPrivateLinkServiceConfig",
    "DataAzurermPrivateLinkServiceEndpointConnections",
    "DataAzurermPrivateLinkServiceEndpointConnectionsConfig",
    "DataAzurermPrivateLinkServiceEndpointConnectionsPrivateEndpointConnections",
    "DataAzurermPrivateLinkServiceEndpointConnectionsTimeouts",
    "DataAzurermPrivateLinkServiceNatIpConfiguration",
    "DataAzurermPrivateLinkServiceTimeouts",
    "DataAzurermProximityPlacementGroup",
    "DataAzurermProximityPlacementGroupConfig",
    "DataAzurermProximityPlacementGroupTimeouts",
    "DataAzurermPublicIp",
    "DataAzurermPublicIpConfig",
    "DataAzurermPublicIpPrefix",
    "DataAzurermPublicIpPrefixConfig",
    "DataAzurermPublicIpPrefixTimeouts",
    "DataAzurermPublicIpTimeouts",
    "DataAzurermPublicIps",
    "DataAzurermPublicIpsConfig",
    "DataAzurermPublicIpsPublicIps",
    "DataAzurermPublicIpsTimeouts",
    "DataAzurermRecoveryServicesVault",
    "DataAzurermRecoveryServicesVaultConfig",
    "DataAzurermRecoveryServicesVaultTimeouts",
    "DataAzurermRedisCache",
    "DataAzurermRedisCacheConfig",
    "DataAzurermRedisCachePatchSchedule",
    "DataAzurermRedisCacheRedisConfiguration",
    "DataAzurermRedisCacheTimeouts",
    "DataAzurermResourceGroup",
    "DataAzurermResourceGroupConfig",
    "DataAzurermResourceGroupTimeouts",
    "DataAzurermResources",
    "DataAzurermResourcesConfig",
    "DataAzurermResourcesResources",
    "DataAzurermResourcesTimeouts",
    "DataAzurermRoleDefinition",
    "DataAzurermRoleDefinitionConfig",
    "DataAzurermRoleDefinitionPermissions",
    "DataAzurermRoleDefinitionTimeouts",
    "DataAzurermRouteTable",
    "DataAzurermRouteTableConfig",
    "DataAzurermRouteTableRoute",
    "DataAzurermRouteTableTimeouts",
    "DataAzurermServicebusNamespace",
    "DataAzurermServicebusNamespaceAuthorizationRule",
    "DataAzurermServicebusNamespaceAuthorizationRuleConfig",
    "DataAzurermServicebusNamespaceAuthorizationRuleTimeouts",
    "DataAzurermServicebusNamespaceConfig",
    "DataAzurermServicebusNamespaceTimeouts",
    "DataAzurermSharedImage",
    "DataAzurermSharedImageConfig",
    "DataAzurermSharedImageGallery",
    "DataAzurermSharedImageGalleryConfig",
    "DataAzurermSharedImageGalleryTimeouts",
    "DataAzurermSharedImageIdentifier",
    "DataAzurermSharedImageTimeouts",
    "DataAzurermSharedImageVersion",
    "DataAzurermSharedImageVersionConfig",
    "DataAzurermSharedImageVersionTargetRegion",
    "DataAzurermSharedImageVersionTimeouts",
    "DataAzurermSignalrService",
    "DataAzurermSignalrServiceConfig",
    "DataAzurermSignalrServiceTimeouts",
    "DataAzurermSnapshot",
    "DataAzurermSnapshotConfig",
    "DataAzurermSnapshotEncryptionSettings",
    "DataAzurermSnapshotEncryptionSettingsDiskEncryptionKey",
    "DataAzurermSnapshotEncryptionSettingsKeyEncryptionKey",
    "DataAzurermSnapshotTimeouts",
    "DataAzurermSqlDatabase",
    "DataAzurermSqlDatabaseConfig",
    "DataAzurermSqlDatabaseTimeouts",
    "DataAzurermSqlServer",
    "DataAzurermSqlServerConfig",
    "DataAzurermSqlServerIdentity",
    "DataAzurermSqlServerTimeouts",
    "DataAzurermStorageAccount",
    "DataAzurermStorageAccountBlobContainerSas",
    "DataAzurermStorageAccountBlobContainerSasConfig",
    "DataAzurermStorageAccountBlobContainerSasPermissions",
    "DataAzurermStorageAccountBlobContainerSasTimeouts",
    "DataAzurermStorageAccountConfig",
    "DataAzurermStorageAccountCustomDomain",
    "DataAzurermStorageAccountSas",
    "DataAzurermStorageAccountSasConfig",
    "DataAzurermStorageAccountSasPermissions",
    "DataAzurermStorageAccountSasResourceTypes",
    "DataAzurermStorageAccountSasServices",
    "DataAzurermStorageAccountSasTimeouts",
    "DataAzurermStorageAccountTimeouts",
    "DataAzurermStorageContainer",
    "DataAzurermStorageContainerConfig",
    "DataAzurermStorageContainerTimeouts",
    "DataAzurermStorageManagementPolicy",
    "DataAzurermStorageManagementPolicyConfig",
    "DataAzurermStorageManagementPolicyRule",
    "DataAzurermStorageManagementPolicyRuleActions",
    "DataAzurermStorageManagementPolicyRuleActionsBaseBlob",
    "DataAzurermStorageManagementPolicyRuleActionsSnapshot",
    "DataAzurermStorageManagementPolicyRuleFilters",
    "DataAzurermStorageManagementPolicyTimeouts",
    "DataAzurermStreamAnalyticsJob",
    "DataAzurermStreamAnalyticsJobConfig",
    "DataAzurermStreamAnalyticsJobTimeouts",
    "DataAzurermSubnet",
    "DataAzurermSubnetConfig",
    "DataAzurermSubnetTimeouts",
    "DataAzurermSubscription",
    "DataAzurermSubscriptionConfig",
    "DataAzurermSubscriptionTimeouts",
    "DataAzurermSubscriptions",
    "DataAzurermSubscriptionsConfig",
    "DataAzurermSubscriptionsSubscriptions",
    "DataAzurermSubscriptionsTimeouts",
    "DataAzurermTrafficManagerGeographicalLocation",
    "DataAzurermTrafficManagerGeographicalLocationConfig",
    "DataAzurermTrafficManagerGeographicalLocationTimeouts",
    "DataAzurermUserAssignedIdentity",
    "DataAzurermUserAssignedIdentityConfig",
    "DataAzurermUserAssignedIdentityTimeouts",
    "DataAzurermVirtualHub",
    "DataAzurermVirtualHubConfig",
    "DataAzurermVirtualHubTimeouts",
    "DataAzurermVirtualMachine",
    "DataAzurermVirtualMachineConfig",
    "DataAzurermVirtualMachineTimeouts",
    "DataAzurermVirtualNetwork",
    "DataAzurermVirtualNetworkConfig",
    "DataAzurermVirtualNetworkGateway",
    "DataAzurermVirtualNetworkGatewayBgpSettings",
    "DataAzurermVirtualNetworkGatewayConfig",
    "DataAzurermVirtualNetworkGatewayConnection",
    "DataAzurermVirtualNetworkGatewayConnectionConfig",
    "DataAzurermVirtualNetworkGatewayConnectionIpsecPolicy",
    "DataAzurermVirtualNetworkGatewayConnectionTimeouts",
    "DataAzurermVirtualNetworkGatewayIpConfiguration",
    "DataAzurermVirtualNetworkGatewayTimeouts",
    "DataAzurermVirtualNetworkGatewayVpnClientConfiguration",
    "DataAzurermVirtualNetworkGatewayVpnClientConfigurationRevokedCertificate",
    "DataAzurermVirtualNetworkGatewayVpnClientConfigurationRootCertificate",
    "DataAzurermVirtualNetworkTimeouts",
    "DataFactory",
    "DataFactoryConfig",
    "DataFactoryDatasetMysql",
    "DataFactoryDatasetMysqlConfig",
    "DataFactoryDatasetMysqlSchemaColumn",
    "DataFactoryDatasetMysqlTimeouts",
    "DataFactoryDatasetPostgresql",
    "DataFactoryDatasetPostgresqlConfig",
    "DataFactoryDatasetPostgresqlSchemaColumn",
    "DataFactoryDatasetPostgresqlTimeouts",
    "DataFactoryDatasetSqlServerTable",
    "DataFactoryDatasetSqlServerTableConfig",
    "DataFactoryDatasetSqlServerTableSchemaColumn",
    "DataFactoryDatasetSqlServerTableTimeouts",
    "DataFactoryGithubConfiguration",
    "DataFactoryIdentity",
    "DataFactoryIntegrationRuntimeManaged",
    "DataFactoryIntegrationRuntimeManagedCatalogInfo",
    "DataFactoryIntegrationRuntimeManagedConfig",
    "DataFactoryIntegrationRuntimeManagedCustomSetupScript",
    "DataFactoryIntegrationRuntimeManagedTimeouts",
    "DataFactoryIntegrationRuntimeManagedVnetIntegration",
    "DataFactoryLinkedServiceDataLakeStorageGen2",
    "DataFactoryLinkedServiceDataLakeStorageGen2Config",
    "DataFactoryLinkedServiceDataLakeStorageGen2Timeouts",
    "DataFactoryLinkedServiceMysql",
    "DataFactoryLinkedServiceMysqlConfig",
    "DataFactoryLinkedServiceMysqlTimeouts",
    "DataFactoryLinkedServicePostgresql",
    "DataFactoryLinkedServicePostgresqlConfig",
    "DataFactoryLinkedServicePostgresqlTimeouts",
    "DataFactoryLinkedServiceSqlServer",
    "DataFactoryLinkedServiceSqlServerConfig",
    "DataFactoryLinkedServiceSqlServerTimeouts",
    "DataFactoryPipeline",
    "DataFactoryPipelineConfig",
    "DataFactoryPipelineTimeouts",
    "DataFactoryTimeouts",
    "DataFactoryTriggerSchedule",
    "DataFactoryTriggerScheduleConfig",
    "DataFactoryTriggerScheduleTimeouts",
    "DataFactoryVstsConfiguration",
    "DataLakeAnalyticsAccount",
    "DataLakeAnalyticsAccountConfig",
    "DataLakeAnalyticsAccountTimeouts",
    "DataLakeAnalyticsFirewallRule",
    "DataLakeAnalyticsFirewallRuleConfig",
    "DataLakeAnalyticsFirewallRuleTimeouts",
    "DataLakeStore",
    "DataLakeStoreConfig",
    "DataLakeStoreFile",
    "DataLakeStoreFileConfig",
    "DataLakeStoreFileTimeouts",
    "DataLakeStoreFirewallRule",
    "DataLakeStoreFirewallRuleConfig",
    "DataLakeStoreFirewallRuleTimeouts",
    "DataLakeStoreTimeouts",
    "DatabricksWorkspace",
    "DatabricksWorkspaceConfig",
    "DatabricksWorkspaceCustomParameters",
    "DatabricksWorkspaceTimeouts",
    "DedicatedHost",
    "DedicatedHostConfig",
    "DedicatedHostGroup",
    "DedicatedHostGroupConfig",
    "DedicatedHostGroupTimeouts",
    "DedicatedHostTimeouts",
    "DevTestLab",
    "DevTestLabConfig",
    "DevTestLabTimeouts",
    "DevTestLinuxVirtualMachine",
    "DevTestLinuxVirtualMachineConfig",
    "DevTestLinuxVirtualMachineGalleryImageReference",
    "DevTestLinuxVirtualMachineInboundNatRule",
    "DevTestLinuxVirtualMachineTimeouts",
    "DevTestPolicy",
    "DevTestPolicyConfig",
    "DevTestPolicyTimeouts",
    "DevTestSchedule",
    "DevTestScheduleConfig",
    "DevTestScheduleDailyRecurrence",
    "DevTestScheduleHourlyRecurrence",
    "DevTestScheduleNotificationSettings",
    "DevTestScheduleTimeouts",
    "DevTestScheduleWeeklyRecurrence",
    "DevTestVirtualNetwork",
    "DevTestVirtualNetworkConfig",
    "DevTestVirtualNetworkSubnet",
    "DevTestVirtualNetworkTimeouts",
    "DevTestWindowsVirtualMachine",
    "DevTestWindowsVirtualMachineConfig",
    "DevTestWindowsVirtualMachineGalleryImageReference",
    "DevTestWindowsVirtualMachineInboundNatRule",
    "DevTestWindowsVirtualMachineTimeouts",
    "DevspaceController",
    "DevspaceControllerConfig",
    "DevspaceControllerTimeouts",
    "DiskEncryptionSet",
    "DiskEncryptionSetConfig",
    "DiskEncryptionSetIdentity",
    "DiskEncryptionSetTimeouts",
    "DnsARecord",
    "DnsARecordConfig",
    "DnsARecordTimeouts",
    "DnsAaaaRecord",
    "DnsAaaaRecordConfig",
    "DnsAaaaRecordTimeouts",
    "DnsCaaRecord",
    "DnsCaaRecordConfig",
    "DnsCaaRecordRecord",
    "DnsCaaRecordTimeouts",
    "DnsCnameRecord",
    "DnsCnameRecordConfig",
    "DnsCnameRecordTimeouts",
    "DnsMxRecord",
    "DnsMxRecordConfig",
    "DnsMxRecordRecord",
    "DnsMxRecordTimeouts",
    "DnsNsRecord",
    "DnsNsRecordConfig",
    "DnsNsRecordTimeouts",
    "DnsPtrRecord",
    "DnsPtrRecordConfig",
    "DnsPtrRecordTimeouts",
    "DnsSrvRecord",
    "DnsSrvRecordConfig",
    "DnsSrvRecordRecord",
    "DnsSrvRecordTimeouts",
    "DnsTxtRecord",
    "DnsTxtRecordConfig",
    "DnsTxtRecordRecord",
    "DnsTxtRecordTimeouts",
    "DnsZone",
    "DnsZoneConfig",
    "DnsZoneTimeouts",
    "EventgridDomain",
    "EventgridDomainConfig",
    "EventgridDomainInputMappingDefaultValues",
    "EventgridDomainInputMappingFields",
    "EventgridDomainTimeouts",
    "EventgridEventSubscription",
    "EventgridEventSubscriptionConfig",
    "EventgridEventSubscriptionEventhubEndpoint",
    "EventgridEventSubscriptionHybridConnectionEndpoint",
    "EventgridEventSubscriptionRetryPolicy",
    "EventgridEventSubscriptionStorageBlobDeadLetterDestination",
    "EventgridEventSubscriptionStorageQueueEndpoint",
    "EventgridEventSubscriptionSubjectFilter",
    "EventgridEventSubscriptionTimeouts",
    "EventgridEventSubscriptionWebhookEndpoint",
    "EventgridTopic",
    "EventgridTopicConfig",
    "EventgridTopicTimeouts",
    "Eventhub",
    "EventhubAuthorizationRule",
    "EventhubAuthorizationRuleConfig",
    "EventhubAuthorizationRuleTimeouts",
    "EventhubCaptureDescription",
    "EventhubCaptureDescriptionDestination",
    "EventhubConfig",
    "EventhubConsumerGroup",
    "EventhubConsumerGroupConfig",
    "EventhubConsumerGroupTimeouts",
    "EventhubNamespace",
    "EventhubNamespaceAuthorizationRule",
    "EventhubNamespaceAuthorizationRuleConfig",
    "EventhubNamespaceAuthorizationRuleTimeouts",
    "EventhubNamespaceConfig",
    "EventhubNamespaceDisasterRecoveryConfig",
    "EventhubNamespaceDisasterRecoveryConfigConfig",
    "EventhubNamespaceDisasterRecoveryConfigTimeouts",
    "EventhubNamespaceNetworkRulesets",
    "EventhubNamespaceNetworkRulesetsIpRule",
    "EventhubNamespaceNetworkRulesetsVirtualNetworkRule",
    "EventhubNamespaceTimeouts",
    "EventhubTimeouts",
    "ExpressRouteCircuit",
    "ExpressRouteCircuitAuthorization",
    "ExpressRouteCircuitAuthorizationConfig",
    "ExpressRouteCircuitAuthorizationTimeouts",
    "ExpressRouteCircuitConfig",
    "ExpressRouteCircuitPeering",
    "ExpressRouteCircuitPeeringConfig",
    "ExpressRouteCircuitPeeringMicrosoftPeeringConfig",
    "ExpressRouteCircuitPeeringTimeouts",
    "ExpressRouteCircuitSku",
    "ExpressRouteCircuitTimeouts",
    "ExpressRouteGateway",
    "ExpressRouteGatewayConfig",
    "ExpressRouteGatewayTimeouts",
    "Firewall",
    "FirewallApplicationRuleCollection",
    "FirewallApplicationRuleCollectionConfig",
    "FirewallApplicationRuleCollectionRule",
    "FirewallApplicationRuleCollectionRuleProtocol",
    "FirewallApplicationRuleCollectionTimeouts",
    "FirewallConfig",
    "FirewallIpConfiguration",
    "FirewallNatRuleCollection",
    "FirewallNatRuleCollectionConfig",
    "FirewallNatRuleCollectionRule",
    "FirewallNatRuleCollectionTimeouts",
    "FirewallNetworkRuleCollection",
    "FirewallNetworkRuleCollectionConfig",
    "FirewallNetworkRuleCollectionRule",
    "FirewallNetworkRuleCollectionTimeouts",
    "FirewallTimeouts",
    "Frontdoor",
    "FrontdoorBackendPool",
    "FrontdoorBackendPoolBackend",
    "FrontdoorBackendPoolHealthProbe",
    "FrontdoorBackendPoolLoadBalancing",
    "FrontdoorConfig",
    "FrontdoorFirewallPolicy",
    "FrontdoorFirewallPolicyConfig",
    "FrontdoorFirewallPolicyCustomRule",
    "FrontdoorFirewallPolicyCustomRuleMatchCondition",
    "FrontdoorFirewallPolicyManagedRule",
    "FrontdoorFirewallPolicyManagedRuleExclusion",
    "FrontdoorFirewallPolicyManagedRuleOverride",
    "FrontdoorFirewallPolicyManagedRuleOverrideExclusion",
    "FrontdoorFirewallPolicyManagedRuleOverrideRule",
    "FrontdoorFirewallPolicyManagedRuleOverrideRuleExclusion",
    "FrontdoorFirewallPolicyTimeouts",
    "FrontdoorFrontendEndpoint",
    "FrontdoorFrontendEndpointCustomHttpsConfiguration",
    "FrontdoorRoutingRule",
    "FrontdoorRoutingRuleForwardingConfiguration",
    "FrontdoorRoutingRuleRedirectConfiguration",
    "FrontdoorTimeouts",
    "FunctionApp",
    "FunctionAppAuthSettings",
    "FunctionAppAuthSettingsActiveDirectory",
    "FunctionAppAuthSettingsFacebook",
    "FunctionAppAuthSettingsGoogle",
    "FunctionAppAuthSettingsMicrosoft",
    "FunctionAppAuthSettingsTwitter",
    "FunctionAppConfig",
    "FunctionAppConnectionString",
    "FunctionAppIdentity",
    "FunctionAppSiteConfig",
    "FunctionAppSiteConfigCors",
    "FunctionAppSiteConfigIpRestriction",
    "FunctionAppSiteCredential",
    "FunctionAppTimeouts",
    "HdinsightHadoopCluster",
    "HdinsightHadoopClusterComponentVersion",
    "HdinsightHadoopClusterConfig",
    "HdinsightHadoopClusterGateway",
    "HdinsightHadoopClusterRoles",
    "HdinsightHadoopClusterRolesEdgeNode",
    "HdinsightHadoopClusterRolesEdgeNodeInstallScriptAction",
    "HdinsightHadoopClusterRolesHeadNode",
    "HdinsightHadoopClusterRolesWorkerNode",
    "HdinsightHadoopClusterRolesZookeeperNode",
    "HdinsightHadoopClusterStorageAccount",
    "HdinsightHadoopClusterStorageAccountGen2",
    "HdinsightHadoopClusterTimeouts",
    "HdinsightHbaseCluster",
    "HdinsightHbaseClusterComponentVersion",
    "HdinsightHbaseClusterConfig",
    "HdinsightHbaseClusterGateway",
    "HdinsightHbaseClusterRoles",
    "HdinsightHbaseClusterRolesHeadNode",
    "HdinsightHbaseClusterRolesWorkerNode",
    "HdinsightHbaseClusterRolesZookeeperNode",
    "HdinsightHbaseClusterStorageAccount",
    "HdinsightHbaseClusterStorageAccountGen2",
    "HdinsightHbaseClusterTimeouts",
    "HdinsightInteractiveQueryCluster",
    "HdinsightInteractiveQueryClusterComponentVersion",
    "HdinsightInteractiveQueryClusterConfig",
    "HdinsightInteractiveQueryClusterGateway",
    "HdinsightInteractiveQueryClusterRoles",
    "HdinsightInteractiveQueryClusterRolesHeadNode",
    "HdinsightInteractiveQueryClusterRolesWorkerNode",
    "HdinsightInteractiveQueryClusterRolesZookeeperNode",
    "HdinsightInteractiveQueryClusterStorageAccount",
    "HdinsightInteractiveQueryClusterStorageAccountGen2",
    "HdinsightInteractiveQueryClusterTimeouts",
    "HdinsightKafkaCluster",
    "HdinsightKafkaClusterComponentVersion",
    "HdinsightKafkaClusterConfig",
    "HdinsightKafkaClusterGateway",
    "HdinsightKafkaClusterRoles",
    "HdinsightKafkaClusterRolesHeadNode",
    "HdinsightKafkaClusterRolesWorkerNode",
    "HdinsightKafkaClusterRolesZookeeperNode",
    "HdinsightKafkaClusterStorageAccount",
    "HdinsightKafkaClusterStorageAccountGen2",
    "HdinsightKafkaClusterTimeouts",
    "HdinsightMlServicesCluster",
    "HdinsightMlServicesClusterConfig",
    "HdinsightMlServicesClusterGateway",
    "HdinsightMlServicesClusterRoles",
    "HdinsightMlServicesClusterRolesEdgeNode",
    "HdinsightMlServicesClusterRolesHeadNode",
    "HdinsightMlServicesClusterRolesWorkerNode",
    "HdinsightMlServicesClusterRolesZookeeperNode",
    "HdinsightMlServicesClusterStorageAccount",
    "HdinsightMlServicesClusterTimeouts",
    "HdinsightRserverCluster",
    "HdinsightRserverClusterConfig",
    "HdinsightRserverClusterGateway",
    "HdinsightRserverClusterRoles",
    "HdinsightRserverClusterRolesEdgeNode",
    "HdinsightRserverClusterRolesHeadNode",
    "HdinsightRserverClusterRolesWorkerNode",
    "HdinsightRserverClusterRolesZookeeperNode",
    "HdinsightRserverClusterStorageAccount",
    "HdinsightRserverClusterTimeouts",
    "HdinsightSparkCluster",
    "HdinsightSparkClusterComponentVersion",
    "HdinsightSparkClusterConfig",
    "HdinsightSparkClusterGateway",
    "HdinsightSparkClusterRoles",
    "HdinsightSparkClusterRolesHeadNode",
    "HdinsightSparkClusterRolesWorkerNode",
    "HdinsightSparkClusterRolesZookeeperNode",
    "HdinsightSparkClusterStorageAccount",
    "HdinsightSparkClusterStorageAccountGen2",
    "HdinsightSparkClusterTimeouts",
    "HdinsightStormCluster",
    "HdinsightStormClusterComponentVersion",
    "HdinsightStormClusterConfig",
    "HdinsightStormClusterGateway",
    "HdinsightStormClusterRoles",
    "HdinsightStormClusterRolesHeadNode",
    "HdinsightStormClusterRolesWorkerNode",
    "HdinsightStormClusterRolesZookeeperNode",
    "HdinsightStormClusterStorageAccount",
    "HdinsightStormClusterTimeouts",
    "HealthcareService",
    "HealthcareServiceAuthenticationConfiguration",
    "HealthcareServiceConfig",
    "HealthcareServiceCorsConfiguration",
    "HealthcareServiceTimeouts",
    "Image",
    "ImageConfig",
    "ImageDataDisk",
    "ImageOsDisk",
    "ImageTimeouts",
    "Iothub",
    "IothubConfig",
    "IothubConsumerGroup",
    "IothubConsumerGroupConfig",
    "IothubConsumerGroupTimeouts",
    "IothubDps",
    "IothubDpsCertificate",
    "IothubDpsCertificateConfig",
    "IothubDpsCertificateTimeouts",
    "IothubDpsConfig",
    "IothubDpsLinkedHub",
    "IothubDpsSharedAccessPolicy",
    "IothubDpsSharedAccessPolicyConfig",
    "IothubDpsSharedAccessPolicyTimeouts",
    "IothubDpsSku",
    "IothubDpsTimeouts",
    "IothubEndpoint",
    "IothubEndpointEventhub",
    "IothubEndpointEventhubConfig",
    "IothubEndpointEventhubTimeouts",
    "IothubEndpointServicebusQueue",
    "IothubEndpointServicebusQueueConfig",
    "IothubEndpointServicebusQueueTimeouts",
    "IothubEndpointServicebusTopic",
    "IothubEndpointServicebusTopicConfig",
    "IothubEndpointServicebusTopicTimeouts",
    "IothubEndpointStorageContainer",
    "IothubEndpointStorageContainerConfig",
    "IothubEndpointStorageContainerTimeouts",
    "IothubFallbackRoute",
    "IothubFallbackRouteA",
    "IothubFallbackRouteAConfig",
    "IothubFallbackRouteTimeouts",
    "IothubFileUpload",
    "IothubIpFilterRule",
    "IothubRoute",
    "IothubRouteA",
    "IothubRouteAConfig",
    "IothubRouteTimeouts",
    "IothubSharedAccessPolicy",
    "IothubSharedAccessPolicyA",
    "IothubSharedAccessPolicyAConfig",
    "IothubSharedAccessPolicyTimeouts",
    "IothubSku",
    "IothubTimeouts",
    "KeyVault",
    "KeyVaultAccessPolicy",
    "KeyVaultAccessPolicyA",
    "KeyVaultAccessPolicyAConfig",
    "KeyVaultAccessPolicyTimeouts",
    "KeyVaultCertificate",
    "KeyVaultCertificateCertificate",
    "KeyVaultCertificateCertificatePolicy",
    "KeyVaultCertificateCertificatePolicyIssuerParameters",
    "KeyVaultCertificateCertificatePolicyKeyProperties",
    "KeyVaultCertificateCertificatePolicyLifetimeAction",
    "KeyVaultCertificateCertificatePolicyLifetimeActionAction",
    "KeyVaultCertificateCertificatePolicyLifetimeActionTrigger",
    "KeyVaultCertificateCertificatePolicySecretProperties",
    "KeyVaultCertificateCertificatePolicyX509CertificateProperties",
    "KeyVaultCertificateCertificatePolicyX509CertificatePropertiesSubjectAlternativeNames",
    "KeyVaultCertificateConfig",
    "KeyVaultCertificateTimeouts",
    "KeyVaultConfig",
    "KeyVaultKey",
    "KeyVaultKeyConfig",
    "KeyVaultKeyTimeouts",
    "KeyVaultNetworkAcls",
    "KeyVaultSecret",
    "KeyVaultSecretConfig",
    "KeyVaultSecretTimeouts",
    "KeyVaultTimeouts",
    "KubernetesCluster",
    "KubernetesClusterAddonProfile",
    "KubernetesClusterAddonProfileAciConnectorLinux",
    "KubernetesClusterAddonProfileAzurePolicy",
    "KubernetesClusterAddonProfileHttpApplicationRouting",
    "KubernetesClusterAddonProfileKubeDashboard",
    "KubernetesClusterAddonProfileOmsAgent",
    "KubernetesClusterConfig",
    "KubernetesClusterDefaultNodePool",
    "KubernetesClusterIdentity",
    "KubernetesClusterKubeAdminConfig",
    "KubernetesClusterKubeConfig",
    "KubernetesClusterLinuxProfile",
    "KubernetesClusterLinuxProfileSshKey",
    "KubernetesClusterNetworkProfile",
    "KubernetesClusterNetworkProfileLoadBalancerProfile",
    "KubernetesClusterNodePool",
    "KubernetesClusterNodePoolConfig",
    "KubernetesClusterNodePoolTimeouts",
    "KubernetesClusterRoleBasedAccessControl",
    "KubernetesClusterRoleBasedAccessControlAzureActiveDirectory",
    "KubernetesClusterServicePrincipal",
    "KubernetesClusterTimeouts",
    "KubernetesClusterWindowsProfile",
    "KustoCluster",
    "KustoClusterConfig",
    "KustoClusterSku",
    "KustoClusterTimeouts",
    "KustoDatabase",
    "KustoDatabaseConfig",
    "KustoDatabasePrincipal",
    "KustoDatabasePrincipalConfig",
    "KustoDatabasePrincipalTimeouts",
    "KustoDatabaseTimeouts",
    "KustoEventhubDataConnection",
    "KustoEventhubDataConnectionConfig",
    "KustoEventhubDataConnectionTimeouts",
    "Lb",
    "LbBackendAddressPool",
    "LbBackendAddressPoolConfig",
    "LbBackendAddressPoolTimeouts",
    "LbConfig",
    "LbFrontendIpConfiguration",
    "LbNatPool",
    "LbNatPoolConfig",
    "LbNatPoolTimeouts",
    "LbNatRule",
    "LbNatRuleConfig",
    "LbNatRuleTimeouts",
    "LbOutboundRule",
    "LbOutboundRuleConfig",
    "LbOutboundRuleFrontendIpConfiguration",
    "LbOutboundRuleTimeouts",
    "LbProbe",
    "LbProbeConfig",
    "LbProbeTimeouts",
    "LbRule",
    "LbRuleConfig",
    "LbRuleTimeouts",
    "LbTimeouts",
    "LinuxVirtualMachine",
    "LinuxVirtualMachineAdditionalCapabilities",
    "LinuxVirtualMachineAdminSshKey",
    "LinuxVirtualMachineBootDiagnostics",
    "LinuxVirtualMachineConfig",
    "LinuxVirtualMachineIdentity",
    "LinuxVirtualMachineOsDisk",
    "LinuxVirtualMachineOsDiskDiffDiskSettings",
    "LinuxVirtualMachinePlan",
    "LinuxVirtualMachineScaleSet",
    "LinuxVirtualMachineScaleSetAdditionalCapabilities",
    "LinuxVirtualMachineScaleSetAdminSshKey",
    "LinuxVirtualMachineScaleSetAutomaticOsUpgradePolicy",
    "LinuxVirtualMachineScaleSetBootDiagnostics",
    "LinuxVirtualMachineScaleSetConfig",
    "LinuxVirtualMachineScaleSetDataDisk",
    "LinuxVirtualMachineScaleSetIdentity",
    "LinuxVirtualMachineScaleSetNetworkInterface",
    "LinuxVirtualMachineScaleSetNetworkInterfaceIpConfiguration",
    "LinuxVirtualMachineScaleSetNetworkInterfaceIpConfigurationPublicIpAddress",
    "LinuxVirtualMachineScaleSetNetworkInterfaceIpConfigurationPublicIpAddressIpTag",
    "LinuxVirtualMachineScaleSetOsDisk",
    "LinuxVirtualMachineScaleSetOsDiskDiffDiskSettings",
    "LinuxVirtualMachineScaleSetPlan",
    "LinuxVirtualMachineScaleSetRollingUpgradePolicy",
    "LinuxVirtualMachineScaleSetSecret",
    "LinuxVirtualMachineScaleSetSecretCertificate",
    "LinuxVirtualMachineScaleSetSourceImageReference",
    "LinuxVirtualMachineScaleSetTimeouts",
    "LinuxVirtualMachineSecret",
    "LinuxVirtualMachineSecretCertificate",
    "LinuxVirtualMachineSourceImageReference",
    "LinuxVirtualMachineTimeouts",
    "LocalNetworkGateway",
    "LocalNetworkGatewayBgpSettings",
    "LocalNetworkGatewayConfig",
    "LocalNetworkGatewayTimeouts",
    "LogAnalyticsLinkedService",
    "LogAnalyticsLinkedServiceConfig",
    "LogAnalyticsLinkedServiceTimeouts",
    "LogAnalyticsSolution",
    "LogAnalyticsSolutionConfig",
    "LogAnalyticsSolutionPlan",
    "LogAnalyticsSolutionTimeouts",
    "LogAnalyticsWorkspace",
    "LogAnalyticsWorkspaceConfig",
    "LogAnalyticsWorkspaceTimeouts",
    "LogicAppActionCustom",
    "LogicAppActionCustomConfig",
    "LogicAppActionCustomTimeouts",
    "LogicAppActionHttp",
    "LogicAppActionHttpConfig",
    "LogicAppActionHttpTimeouts",
    "LogicAppTriggerCustom",
    "LogicAppTriggerCustomConfig",
    "LogicAppTriggerCustomTimeouts",
    "LogicAppTriggerHttpRequest",
    "LogicAppTriggerHttpRequestConfig",
    "LogicAppTriggerHttpRequestTimeouts",
    "LogicAppTriggerRecurrence",
    "LogicAppTriggerRecurrenceConfig",
    "LogicAppTriggerRecurrenceTimeouts",
    "LogicAppWorkflow",
    "LogicAppWorkflowConfig",
    "LogicAppWorkflowTimeouts",
    "ManagedDisk",
    "ManagedDiskConfig",
    "ManagedDiskEncryptionSettings",
    "ManagedDiskEncryptionSettingsDiskEncryptionKey",
    "ManagedDiskEncryptionSettingsKeyEncryptionKey",
    "ManagedDiskTimeouts",
    "ManagementGroup",
    "ManagementGroupConfig",
    "ManagementGroupTimeouts",
    "ManagementLock",
    "ManagementLockConfig",
    "ManagementLockTimeouts",
    "MapsAccount",
    "MapsAccountConfig",
    "MapsAccountTimeouts",
    "MariadbConfiguration",
    "MariadbConfigurationConfig",
    "MariadbConfigurationTimeouts",
    "MariadbDatabase",
    "MariadbDatabaseConfig",
    "MariadbDatabaseTimeouts",
    "MariadbFirewallRule",
    "MariadbFirewallRuleConfig",
    "MariadbFirewallRuleTimeouts",
    "MariadbServer",
    "MariadbServerConfig",
    "MariadbServerStorageProfile",
    "MariadbServerTimeouts",
    "MariadbVirtualNetworkRule",
    "MariadbVirtualNetworkRuleConfig",
    "MariadbVirtualNetworkRuleTimeouts",
    "MarketplaceAgreement",
    "MarketplaceAgreementConfig",
    "MarketplaceAgreementTimeouts",
    "MediaServicesAccount",
    "MediaServicesAccountConfig",
    "MediaServicesAccountStorageAccount",
    "MediaServicesAccountTimeouts",
    "MonitorActionGroup",
    "MonitorActionGroupArmRoleReceiver",
    "MonitorActionGroupAutomationRunbookReceiver",
    "MonitorActionGroupAzureAppPushReceiver",
    "MonitorActionGroupAzureFunctionReceiver",
    "MonitorActionGroupConfig",
    "MonitorActionGroupEmailReceiver",
    "MonitorActionGroupItsmReceiver",
    "MonitorActionGroupLogicAppReceiver",
    "MonitorActionGroupSmsReceiver",
    "MonitorActionGroupTimeouts",
    "MonitorActionGroupVoiceReceiver",
    "MonitorActionGroupWebhookReceiver",
    "MonitorActivityLogAlert",
    "MonitorActivityLogAlertAction",
    "MonitorActivityLogAlertConfig",
    "MonitorActivityLogAlertCriteria",
    "MonitorActivityLogAlertTimeouts",
    "MonitorAutoscaleSetting",
    "MonitorAutoscaleSettingConfig",
    "MonitorAutoscaleSettingNotification",
    "MonitorAutoscaleSettingNotificationEmail",
    "MonitorAutoscaleSettingNotificationWebhook",
    "MonitorAutoscaleSettingProfile",
    "MonitorAutoscaleSettingProfileCapacity",
    "MonitorAutoscaleSettingProfileFixedDate",
    "MonitorAutoscaleSettingProfileRecurrence",
    "MonitorAutoscaleSettingProfileRule",
    "MonitorAutoscaleSettingProfileRuleMetricTrigger",
    "MonitorAutoscaleSettingProfileRuleScaleAction",
    "MonitorAutoscaleSettingTimeouts",
    "MonitorDiagnosticSetting",
    "MonitorDiagnosticSettingConfig",
    "MonitorDiagnosticSettingLog",
    "MonitorDiagnosticSettingLogRetentionPolicy",
    "MonitorDiagnosticSettingMetric",
    "MonitorDiagnosticSettingMetricRetentionPolicy",
    "MonitorDiagnosticSettingTimeouts",
    "MonitorLogProfile",
    "MonitorLogProfileConfig",
    "MonitorLogProfileRetentionPolicy",
    "MonitorLogProfileTimeouts",
    "MonitorMetricAlert",
    "MonitorMetricAlertAction",
    "MonitorMetricAlertConfig",
    "MonitorMetricAlertCriteria",
    "MonitorMetricAlertCriteriaDimension",
    "MonitorMetricAlertTimeouts",
    "MssqlDatabaseVulnerabilityAssessmentRuleBaseline",
    "MssqlDatabaseVulnerabilityAssessmentRuleBaselineBaselineResult",
    "MssqlDatabaseVulnerabilityAssessmentRuleBaselineConfig",
    "MssqlDatabaseVulnerabilityAssessmentRuleBaselineTimeouts",
    "MssqlElasticpool",
    "MssqlElasticpoolConfig",
    "MssqlElasticpoolPerDatabaseSettings",
    "MssqlElasticpoolSku",
    "MssqlElasticpoolTimeouts",
    "MssqlServerSecurityAlertPolicy",
    "MssqlServerSecurityAlertPolicyConfig",
    "MssqlServerSecurityAlertPolicyTimeouts",
    "MssqlServerVulnerabilityAssessment",
    "MssqlServerVulnerabilityAssessmentConfig",
    "MssqlServerVulnerabilityAssessmentRecurringScans",
    "MssqlServerVulnerabilityAssessmentTimeouts",
    "MysqlConfiguration",
    "MysqlConfigurationConfig",
    "MysqlConfigurationTimeouts",
    "MysqlDatabase",
    "MysqlDatabaseConfig",
    "MysqlDatabaseTimeouts",
    "MysqlFirewallRule",
    "MysqlFirewallRuleConfig",
    "MysqlFirewallRuleTimeouts",
    "MysqlServer",
    "MysqlServerConfig",
    "MysqlServerStorageProfile",
    "MysqlServerTimeouts",
    "MysqlVirtualNetworkRule",
    "MysqlVirtualNetworkRuleConfig",
    "MysqlVirtualNetworkRuleTimeouts",
    "NatGateway",
    "NatGatewayConfig",
    "NatGatewayTimeouts",
    "NetappAccount",
    "NetappAccountActiveDirectory",
    "NetappAccountConfig",
    "NetappAccountTimeouts",
    "NetappPool",
    "NetappPoolConfig",
    "NetappPoolTimeouts",
    "NetappSnapshot",
    "NetappSnapshotConfig",
    "NetappSnapshotTimeouts",
    "NetappVolume",
    "NetappVolumeConfig",
    "NetappVolumeExportPolicyRule",
    "NetappVolumeTimeouts",
    "NetworkConnectionMonitor",
    "NetworkConnectionMonitorConfig",
    "NetworkConnectionMonitorDestination",
    "NetworkConnectionMonitorSource",
    "NetworkConnectionMonitorTimeouts",
    "NetworkDdosProtectionPlan",
    "NetworkDdosProtectionPlanConfig",
    "NetworkDdosProtectionPlanTimeouts",
    "NetworkInterface",
    "NetworkInterfaceApplicationGatewayBackendAddressPoolAssociation",
    "NetworkInterfaceApplicationGatewayBackendAddressPoolAssociationConfig",
    "NetworkInterfaceApplicationGatewayBackendAddressPoolAssociationTimeouts",
    "NetworkInterfaceApplicationSecurityGroupAssociation",
    "NetworkInterfaceApplicationSecurityGroupAssociationConfig",
    "NetworkInterfaceApplicationSecurityGroupAssociationTimeouts",
    "NetworkInterfaceBackendAddressPoolAssociation",
    "NetworkInterfaceBackendAddressPoolAssociationConfig",
    "NetworkInterfaceBackendAddressPoolAssociationTimeouts",
    "NetworkInterfaceConfig",
    "NetworkInterfaceIpConfiguration",
    "NetworkInterfaceNatRuleAssociation",
    "NetworkInterfaceNatRuleAssociationConfig",
    "NetworkInterfaceNatRuleAssociationTimeouts",
    "NetworkInterfaceSecurityGroupAssociation",
    "NetworkInterfaceSecurityGroupAssociationConfig",
    "NetworkInterfaceSecurityGroupAssociationTimeouts",
    "NetworkInterfaceTimeouts",
    "NetworkPacketCapture",
    "NetworkPacketCaptureConfig",
    "NetworkPacketCaptureFilter",
    "NetworkPacketCaptureStorageLocation",
    "NetworkPacketCaptureTimeouts",
    "NetworkProfile",
    "NetworkProfileConfig",
    "NetworkProfileContainerNetworkInterface",
    "NetworkProfileContainerNetworkInterfaceIpConfiguration",
    "NetworkProfileTimeouts",
    "NetworkSecurityGroup",
    "NetworkSecurityGroupConfig",
    "NetworkSecurityGroupSecurityRule",
    "NetworkSecurityGroupTimeouts",
    "NetworkSecurityRule",
    "NetworkSecurityRuleConfig",
    "NetworkSecurityRuleTimeouts",
    "NetworkWatcher",
    "NetworkWatcherConfig",
    "NetworkWatcherFlowLog",
    "NetworkWatcherFlowLogConfig",
    "NetworkWatcherFlowLogRetentionPolicy",
    "NetworkWatcherFlowLogTimeouts",
    "NetworkWatcherFlowLogTrafficAnalytics",
    "NetworkWatcherTimeouts",
    "NotificationHub",
    "NotificationHubApnsCredential",
    "NotificationHubAuthorizationRule",
    "NotificationHubAuthorizationRuleConfig",
    "NotificationHubAuthorizationRuleTimeouts",
    "NotificationHubConfig",
    "NotificationHubGcmCredential",
    "NotificationHubNamespace",
    "NotificationHubNamespaceConfig",
    "NotificationHubNamespaceTimeouts",
    "NotificationHubTimeouts",
    "PacketCapture",
    "PacketCaptureConfig",
    "PacketCaptureFilter",
    "PacketCaptureStorageLocation",
    "PacketCaptureTimeouts",
    "PointToSiteVpnGateway",
    "PointToSiteVpnGatewayConfig",
    "PointToSiteVpnGatewayConnectionConfiguration",
    "PointToSiteVpnGatewayConnectionConfigurationVpnClientAddressPool",
    "PointToSiteVpnGatewayTimeouts",
    "PolicyAssignment",
    "PolicyAssignmentConfig",
    "PolicyAssignmentIdentity",
    "PolicyAssignmentTimeouts",
    "PolicyDefinition",
    "PolicyDefinitionConfig",
    "PolicyDefinitionTimeouts",
    "PolicySetDefinition",
    "PolicySetDefinitionConfig",
    "PolicySetDefinitionTimeouts",
    "PostgresqlConfiguration",
    "PostgresqlConfigurationConfig",
    "PostgresqlConfigurationTimeouts",
    "PostgresqlDatabase",
    "PostgresqlDatabaseConfig",
    "PostgresqlDatabaseTimeouts",
    "PostgresqlFirewallRule",
    "PostgresqlFirewallRuleConfig",
    "PostgresqlFirewallRuleTimeouts",
    "PostgresqlServer",
    "PostgresqlServerConfig",
    "PostgresqlServerStorageProfile",
    "PostgresqlServerTimeouts",
    "PostgresqlVirtualNetworkRule",
    "PostgresqlVirtualNetworkRuleConfig",
    "PostgresqlVirtualNetworkRuleTimeouts",
    "PrivateDnsARecord",
    "PrivateDnsARecordConfig",
    "PrivateDnsARecordTimeouts",
    "PrivateDnsAaaaRecord",
    "PrivateDnsAaaaRecordConfig",
    "PrivateDnsAaaaRecordTimeouts",
    "PrivateDnsCnameRecord",
    "PrivateDnsCnameRecordConfig",
    "PrivateDnsCnameRecordTimeouts",
    "PrivateDnsMxRecord",
    "PrivateDnsMxRecordConfig",
    "PrivateDnsMxRecordRecord",
    "PrivateDnsMxRecordTimeouts",
    "PrivateDnsPtrRecord",
    "PrivateDnsPtrRecordConfig",
    "PrivateDnsPtrRecordTimeouts",
    "PrivateDnsSrvRecord",
    "PrivateDnsSrvRecordConfig",
    "PrivateDnsSrvRecordRecord",
    "PrivateDnsSrvRecordTimeouts",
    "PrivateDnsZone",
    "PrivateDnsZoneConfig",
    "PrivateDnsZoneTimeouts",
    "PrivateDnsZoneVirtualNetworkLink",
    "PrivateDnsZoneVirtualNetworkLinkConfig",
    "PrivateDnsZoneVirtualNetworkLinkTimeouts",
    "PrivateEndpoint",
    "PrivateEndpointConfig",
    "PrivateEndpointPrivateServiceConnection",
    "PrivateEndpointTimeouts",
    "PrivateLinkService",
    "PrivateLinkServiceConfig",
    "PrivateLinkServiceNatIpConfiguration",
    "PrivateLinkServiceTimeouts",
    "ProximityPlacementGroup",
    "ProximityPlacementGroupConfig",
    "ProximityPlacementGroupTimeouts",
    "PublicIp",
    "PublicIpConfig",
    "PublicIpPrefix",
    "PublicIpPrefixConfig",
    "PublicIpPrefixTimeouts",
    "PublicIpTimeouts",
    "RecoveryServicesVault",
    "RecoveryServicesVaultConfig",
    "RecoveryServicesVaultTimeouts",
    "RedisCache",
    "RedisCacheConfig",
    "RedisCachePatchSchedule",
    "RedisCacheRedisConfiguration",
    "RedisCacheTimeouts",
    "RedisFirewallRule",
    "RedisFirewallRuleConfig",
    "RedisFirewallRuleTimeouts",
    "RelayHybridConnection",
    "RelayHybridConnectionConfig",
    "RelayHybridConnectionTimeouts",
    "RelayNamespace",
    "RelayNamespaceConfig",
    "RelayNamespaceTimeouts",
    "ResourceGroup",
    "ResourceGroupConfig",
    "ResourceGroupTimeouts",
    "RoleAssignment",
    "RoleAssignmentConfig",
    "RoleAssignmentTimeouts",
    "RoleDefinition",
    "RoleDefinitionConfig",
    "RoleDefinitionPermissions",
    "RoleDefinitionTimeouts",
    "Route",
    "RouteConfig",
    "RouteTable",
    "RouteTableConfig",
    "RouteTableRoute",
    "RouteTableTimeouts",
    "RouteTimeouts",
    "SearchService",
    "SearchServiceConfig",
    "SearchServiceQueryKeys",
    "SearchServiceTimeouts",
    "SecurityCenterContact",
    "SecurityCenterContactConfig",
    "SecurityCenterContactTimeouts",
    "SecurityCenterSubscriptionPricing",
    "SecurityCenterSubscriptionPricingConfig",
    "SecurityCenterSubscriptionPricingTimeouts",
    "SecurityCenterWorkspace",
    "SecurityCenterWorkspaceConfig",
    "SecurityCenterWorkspaceTimeouts",
    "ServiceFabricCluster",
    "ServiceFabricClusterAzureActiveDirectory",
    "ServiceFabricClusterCertificate",
    "ServiceFabricClusterCertificateCommonNames",
    "ServiceFabricClusterCertificateCommonNamesCommonNames",
    "ServiceFabricClusterClientCertificateThumbprint",
    "ServiceFabricClusterConfig",
    "ServiceFabricClusterDiagnosticsConfig",
    "ServiceFabricClusterFabricSettings",
    "ServiceFabricClusterNodeType",
    "ServiceFabricClusterNodeTypeApplicationPorts",
    "ServiceFabricClusterNodeTypeEphemeralPorts",
    "ServiceFabricClusterReverseProxyCertificate",
    "ServiceFabricClusterTimeouts",
    "ServicebusNamespace",
    "ServicebusNamespaceAuthorizationRule",
    "ServicebusNamespaceAuthorizationRuleConfig",
    "ServicebusNamespaceAuthorizationRuleTimeouts",
    "ServicebusNamespaceConfig",
    "ServicebusNamespaceTimeouts",
    "ServicebusQueue",
    "ServicebusQueueAuthorizationRule",
    "ServicebusQueueAuthorizationRuleConfig",
    "ServicebusQueueAuthorizationRuleTimeouts",
    "ServicebusQueueConfig",
    "ServicebusQueueTimeouts",
    "ServicebusSubscription",
    "ServicebusSubscriptionConfig",
    "ServicebusSubscriptionRule",
    "ServicebusSubscriptionRuleConfig",
    "ServicebusSubscriptionRuleCorrelationFilter",
    "ServicebusSubscriptionRuleTimeouts",
    "ServicebusSubscriptionTimeouts",
    "ServicebusTopic",
    "ServicebusTopicAuthorizationRule",
    "ServicebusTopicAuthorizationRuleConfig",
    "ServicebusTopicAuthorizationRuleTimeouts",
    "ServicebusTopicConfig",
    "ServicebusTopicTimeouts",
    "SharedImage",
    "SharedImageConfig",
    "SharedImageGallery",
    "SharedImageGalleryConfig",
    "SharedImageGalleryTimeouts",
    "SharedImageIdentifier",
    "SharedImageTimeouts",
    "SharedImageVersion",
    "SharedImageVersionConfig",
    "SharedImageVersionTargetRegion",
    "SharedImageVersionTimeouts",
    "SignalrService",
    "SignalrServiceConfig",
    "SignalrServiceCors",
    "SignalrServiceFeatures",
    "SignalrServiceSku",
    "SignalrServiceTimeouts",
    "SiteRecoveryFabric",
    "SiteRecoveryFabricConfig",
    "SiteRecoveryFabricTimeouts",
    "SiteRecoveryNetworkMapping",
    "SiteRecoveryNetworkMappingConfig",
    "SiteRecoveryNetworkMappingTimeouts",
    "SiteRecoveryProtectionContainer",
    "SiteRecoveryProtectionContainerConfig",
    "SiteRecoveryProtectionContainerMapping",
    "SiteRecoveryProtectionContainerMappingConfig",
    "SiteRecoveryProtectionContainerMappingTimeouts",
    "SiteRecoveryProtectionContainerTimeouts",
    "SiteRecoveryReplicatedVm",
    "SiteRecoveryReplicatedVmConfig",
    "SiteRecoveryReplicatedVmManagedDisk",
    "SiteRecoveryReplicatedVmTimeouts",
    "SiteRecoveryReplicationPolicy",
    "SiteRecoveryReplicationPolicyConfig",
    "SiteRecoveryReplicationPolicyTimeouts",
    "Snapshot",
    "SnapshotConfig",
    "SnapshotEncryptionSettings",
    "SnapshotEncryptionSettingsDiskEncryptionKey",
    "SnapshotEncryptionSettingsKeyEncryptionKey",
    "SnapshotTimeouts",
    "SqlActiveDirectoryAdministrator",
    "SqlActiveDirectoryAdministratorConfig",
    "SqlActiveDirectoryAdministratorTimeouts",
    "SqlDatabase",
    "SqlDatabaseConfig",
    "SqlDatabaseImport",
    "SqlDatabaseThreatDetectionPolicy",
    "SqlDatabaseTimeouts",
    "SqlElasticpool",
    "SqlElasticpoolConfig",
    "SqlElasticpoolTimeouts",
    "SqlFailoverGroup",
    "SqlFailoverGroupConfig",
    "SqlFailoverGroupPartnerServers",
    "SqlFailoverGroupReadWriteEndpointFailoverPolicy",
    "SqlFailoverGroupReadonlyEndpointFailoverPolicy",
    "SqlFailoverGroupTimeouts",
    "SqlFirewallRule",
    "SqlFirewallRuleConfig",
    "SqlFirewallRuleTimeouts",
    "SqlServer",
    "SqlServerConfig",
    "SqlServerIdentity",
    "SqlServerTimeouts",
    "SqlVirtualNetworkRule",
    "SqlVirtualNetworkRuleConfig",
    "SqlVirtualNetworkRuleTimeouts",
    "StorageAccount",
    "StorageAccountBlobProperties",
    "StorageAccountBlobPropertiesCorsRule",
    "StorageAccountBlobPropertiesDeleteRetentionPolicy",
    "StorageAccountConfig",
    "StorageAccountCustomDomain",
    "StorageAccountCustomerManagedKey",
    "StorageAccountCustomerManagedKeyConfig",
    "StorageAccountCustomerManagedKeyTimeouts",
    "StorageAccountIdentity",
    "StorageAccountNetworkRules",
    "StorageAccountNetworkRulesA",
    "StorageAccountNetworkRulesAConfig",
    "StorageAccountNetworkRulesTimeouts",
    "StorageAccountQueueProperties",
    "StorageAccountQueuePropertiesCorsRule",
    "StorageAccountQueuePropertiesHourMetrics",
    "StorageAccountQueuePropertiesLogging",
    "StorageAccountQueuePropertiesMinuteMetrics",
    "StorageAccountStaticWebsite",
    "StorageAccountTimeouts",
    "StorageBlob",
    "StorageBlobConfig",
    "StorageBlobTimeouts",
    "StorageContainer",
    "StorageContainerConfig",
    "StorageContainerTimeouts",
    "StorageDataLakeGen2Filesystem",
    "StorageDataLakeGen2FilesystemConfig",
    "StorageDataLakeGen2FilesystemTimeouts",
    "StorageManagementPolicy",
    "StorageManagementPolicyConfig",
    "StorageManagementPolicyRule",
    "StorageManagementPolicyRuleActions",
    "StorageManagementPolicyRuleActionsBaseBlob",
    "StorageManagementPolicyRuleActionsSnapshot",
    "StorageManagementPolicyRuleFilters",
    "StorageManagementPolicyTimeouts",
    "StorageQueue",
    "StorageQueueConfig",
    "StorageQueueTimeouts",
    "StorageShare",
    "StorageShareAcl",
    "StorageShareAclAccessPolicy",
    "StorageShareConfig",
    "StorageShareDirectory",
    "StorageShareDirectoryConfig",
    "StorageShareDirectoryTimeouts",
    "StorageShareTimeouts",
    "StorageTable",
    "StorageTableAcl",
    "StorageTableAclAccessPolicy",
    "StorageTableConfig",
    "StorageTableEntity",
    "StorageTableEntityConfig",
    "StorageTableEntityTimeouts",
    "StorageTableTimeouts",
    "StreamAnalyticsFunctionJavascriptUdf",
    "StreamAnalyticsFunctionJavascriptUdfConfig",
    "StreamAnalyticsFunctionJavascriptUdfInput",
    "StreamAnalyticsFunctionJavascriptUdfOutput",
    "StreamAnalyticsFunctionJavascriptUdfTimeouts",
    "StreamAnalyticsJob",
    "StreamAnalyticsJobConfig",
    "StreamAnalyticsJobTimeouts",
    "StreamAnalyticsOutputBlob",
    "StreamAnalyticsOutputBlobConfig",
    "StreamAnalyticsOutputBlobSerialization",
    "StreamAnalyticsOutputBlobTimeouts",
    "StreamAnalyticsOutputEventhub",
    "StreamAnalyticsOutputEventhubConfig",
    "StreamAnalyticsOutputEventhubSerialization",
    "StreamAnalyticsOutputEventhubTimeouts",
    "StreamAnalyticsOutputMssql",
    "StreamAnalyticsOutputMssqlConfig",
    "StreamAnalyticsOutputMssqlTimeouts",
    "StreamAnalyticsOutputServicebusQueue",
    "StreamAnalyticsOutputServicebusQueueConfig",
    "StreamAnalyticsOutputServicebusQueueSerialization",
    "StreamAnalyticsOutputServicebusQueueTimeouts",
    "StreamAnalyticsOutputServicebusTopic",
    "StreamAnalyticsOutputServicebusTopicConfig",
    "StreamAnalyticsOutputServicebusTopicSerialization",
    "StreamAnalyticsOutputServicebusTopicTimeouts",
    "StreamAnalyticsReferenceInputBlob",
    "StreamAnalyticsReferenceInputBlobConfig",
    "StreamAnalyticsReferenceInputBlobSerialization",
    "StreamAnalyticsReferenceInputBlobTimeouts",
    "StreamAnalyticsStreamInputBlob",
    "StreamAnalyticsStreamInputBlobConfig",
    "StreamAnalyticsStreamInputBlobSerialization",
    "StreamAnalyticsStreamInputBlobTimeouts",
    "StreamAnalyticsStreamInputEventhub",
    "StreamAnalyticsStreamInputEventhubConfig",
    "StreamAnalyticsStreamInputEventhubSerialization",
    "StreamAnalyticsStreamInputEventhubTimeouts",
    "StreamAnalyticsStreamInputIothub",
    "StreamAnalyticsStreamInputIothubConfig",
    "StreamAnalyticsStreamInputIothubSerialization",
    "StreamAnalyticsStreamInputIothubTimeouts",
    "Subnet",
    "SubnetConfig",
    "SubnetDelegation",
    "SubnetDelegationServiceDelegation",
    "SubnetNatGatewayAssociation",
    "SubnetNatGatewayAssociationConfig",
    "SubnetNatGatewayAssociationTimeouts",
    "SubnetNetworkSecurityGroupAssociation",
    "SubnetNetworkSecurityGroupAssociationConfig",
    "SubnetNetworkSecurityGroupAssociationTimeouts",
    "SubnetRouteTableAssociation",
    "SubnetRouteTableAssociationConfig",
    "SubnetRouteTableAssociationTimeouts",
    "SubnetTimeouts",
    "TemplateDeployment",
    "TemplateDeploymentConfig",
    "TemplateDeploymentTimeouts",
    "TrafficManagerEndpoint",
    "TrafficManagerEndpointConfig",
    "TrafficManagerEndpointCustomHeader",
    "TrafficManagerEndpointSubnet",
    "TrafficManagerEndpointTimeouts",
    "TrafficManagerProfile",
    "TrafficManagerProfileConfig",
    "TrafficManagerProfileDnsConfig",
    "TrafficManagerProfileMonitorConfig",
    "TrafficManagerProfileTimeouts",
    "UserAssignedIdentity",
    "UserAssignedIdentityConfig",
    "UserAssignedIdentityTimeouts",
    "VirtualHub",
    "VirtualHubConfig",
    "VirtualHubRoute",
    "VirtualHubTimeouts",
    "VirtualMachine",
    "VirtualMachineAdditionalCapabilities",
    "VirtualMachineBootDiagnostics",
    "VirtualMachineConfig",
    "VirtualMachineDataDiskAttachment",
    "VirtualMachineDataDiskAttachmentConfig",
    "VirtualMachineDataDiskAttachmentTimeouts",
    "VirtualMachineExtension",
    "VirtualMachineExtensionConfig",
    "VirtualMachineExtensionTimeouts",
    "VirtualMachineIdentity",
    "VirtualMachineOsProfile",
    "VirtualMachineOsProfileLinuxConfig",
    "VirtualMachineOsProfileLinuxConfigSshKeys",
    "VirtualMachineOsProfileSecrets",
    "VirtualMachineOsProfileSecretsVaultCertificates",
    "VirtualMachineOsProfileWindowsConfig",
    "VirtualMachineOsProfileWindowsConfigAdditionalUnattendConfig",
    "VirtualMachineOsProfileWindowsConfigWinrm",
    "VirtualMachinePlan",
    "VirtualMachineScaleSet",
    "VirtualMachineScaleSetBootDiagnostics",
    "VirtualMachineScaleSetConfig",
    "VirtualMachineScaleSetExtension",
    "VirtualMachineScaleSetExtensionA",
    "VirtualMachineScaleSetExtensionAConfig",
    "VirtualMachineScaleSetExtensionTimeouts",
    "VirtualMachineScaleSetIdentity",
    "VirtualMachineScaleSetNetworkProfile",
    "VirtualMachineScaleSetNetworkProfileDnsSettings",
    "VirtualMachineScaleSetNetworkProfileIpConfiguration",
    "VirtualMachineScaleSetNetworkProfileIpConfigurationPublicIpAddressConfiguration",
    "VirtualMachineScaleSetOsProfile",
    "VirtualMachineScaleSetOsProfileLinuxConfig",
    "VirtualMachineScaleSetOsProfileLinuxConfigSshKeys",
    "VirtualMachineScaleSetOsProfileSecrets",
    "VirtualMachineScaleSetOsProfileSecretsVaultCertificates",
    "VirtualMachineScaleSetOsProfileWindowsConfig",
    "VirtualMachineScaleSetOsProfileWindowsConfigAdditionalUnattendConfig",
    "VirtualMachineScaleSetOsProfileWindowsConfigWinrm",
    "VirtualMachineScaleSetPlan",
    "VirtualMachineScaleSetRollingUpgradePolicy",
    "VirtualMachineScaleSetSku",
    "VirtualMachineScaleSetStorageProfileDataDisk",
    "VirtualMachineScaleSetStorageProfileImageReference",
    "VirtualMachineScaleSetStorageProfileOsDisk",
    "VirtualMachineScaleSetTimeouts",
    "VirtualMachineStorageDataDisk",
    "VirtualMachineStorageImageReference",
    "VirtualMachineStorageOsDisk",
    "VirtualMachineTimeouts",
    "VirtualNetwork",
    "VirtualNetworkConfig",
    "VirtualNetworkDdosProtectionPlan",
    "VirtualNetworkGateway",
    "VirtualNetworkGatewayBgpSettings",
    "VirtualNetworkGatewayConfig",
    "VirtualNetworkGatewayConnection",
    "VirtualNetworkGatewayConnectionConfig",
    "VirtualNetworkGatewayConnectionIpsecPolicy",
    "VirtualNetworkGatewayConnectionTimeouts",
    "VirtualNetworkGatewayIpConfiguration",
    "VirtualNetworkGatewayTimeouts",
    "VirtualNetworkGatewayVpnClientConfiguration",
    "VirtualNetworkGatewayVpnClientConfigurationRevokedCertificate",
    "VirtualNetworkGatewayVpnClientConfigurationRootCertificate",
    "VirtualNetworkPeering",
    "VirtualNetworkPeeringConfig",
    "VirtualNetworkPeeringTimeouts",
    "VirtualNetworkSubnet",
    "VirtualNetworkTimeouts",
    "VirtualWan",
    "VirtualWanConfig",
    "VirtualWanTimeouts",
    "VpnGateway",
    "VpnGatewayBgpSettings",
    "VpnGatewayConfig",
    "VpnGatewayTimeouts",
    "VpnServerConfiguration",
    "VpnServerConfigurationAzureActiveDirectoryAuthentication",
    "VpnServerConfigurationClientRevokedCertificate",
    "VpnServerConfigurationClientRootCertificate",
    "VpnServerConfigurationConfig",
    "VpnServerConfigurationIpsecPolicy",
    "VpnServerConfigurationRadiusServer",
    "VpnServerConfigurationRadiusServerClientRootCertificate",
    "VpnServerConfigurationRadiusServerServerRootCertificate",
    "VpnServerConfigurationTimeouts",
    "WebApplicationFirewallPolicy",
    "WebApplicationFirewallPolicyConfig",
    "WebApplicationFirewallPolicyCustomRules",
    "WebApplicationFirewallPolicyCustomRulesMatchConditions",
    "WebApplicationFirewallPolicyCustomRulesMatchConditionsMatchVariables",
    "WebApplicationFirewallPolicyPolicySettings",
    "WebApplicationFirewallPolicyTimeouts",
    "WindowsVirtualMachine",
    "WindowsVirtualMachineAdditionalCapabilities",
    "WindowsVirtualMachineAdditionalUnattendContent",
    "WindowsVirtualMachineBootDiagnostics",
    "WindowsVirtualMachineConfig",
    "WindowsVirtualMachineIdentity",
    "WindowsVirtualMachineOsDisk",
    "WindowsVirtualMachineOsDiskDiffDiskSettings",
    "WindowsVirtualMachinePlan",
    "WindowsVirtualMachineScaleSet",
    "WindowsVirtualMachineScaleSetAdditionalCapabilities",
    "WindowsVirtualMachineScaleSetAdditionalUnattendContent",
    "WindowsVirtualMachineScaleSetAutomaticOsUpgradePolicy",
    "WindowsVirtualMachineScaleSetBootDiagnostics",
    "WindowsVirtualMachineScaleSetConfig",
    "WindowsVirtualMachineScaleSetDataDisk",
    "WindowsVirtualMachineScaleSetIdentity",
    "WindowsVirtualMachineScaleSetNetworkInterface",
    "WindowsVirtualMachineScaleSetNetworkInterfaceIpConfiguration",
    "WindowsVirtualMachineScaleSetNetworkInterfaceIpConfigurationPublicIpAddress",
    "WindowsVirtualMachineScaleSetNetworkInterfaceIpConfigurationPublicIpAddressIpTag",
    "WindowsVirtualMachineScaleSetOsDisk",
    "WindowsVirtualMachineScaleSetOsDiskDiffDiskSettings",
    "WindowsVirtualMachineScaleSetPlan",
    "WindowsVirtualMachineScaleSetRollingUpgradePolicy",
    "WindowsVirtualMachineScaleSetSecret",
    "WindowsVirtualMachineScaleSetSecretCertificate",
    "WindowsVirtualMachineScaleSetSourceImageReference",
    "WindowsVirtualMachineScaleSetTimeouts",
    "WindowsVirtualMachineScaleSetWinrmListener",
    "WindowsVirtualMachineSecret",
    "WindowsVirtualMachineSecretCertificate",
    "WindowsVirtualMachineSourceImageReference",
    "WindowsVirtualMachineTimeouts",
    "WindowsVirtualMachineWinrmListener",
]

publication.publish()
